"""Data downloaded from NCBI Gene converted into Python namedtuples."""

from collections import namedtuple

WRITTEN = "2021_07_17" # 19645 items

#pylint: disable=line-too-long,too-many-lines,invalid-name
ntncbi = namedtuple('ntncbi', 'tax_id Org_name GeneID CurrentID Status Symbol Aliases description other_designations map_location chromosome genomic_nucleotide_accession_version start_position_on_the_genomic_accession end_position_on_the_genomic_accession orientation exon_count OMIM no_hdr0')

GENEID2NT = { # 19,645 items
    1 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1, CurrentID=0, Status='live', Symbol='A1BG', Aliases=['A1B', 'ABG', 'GAB', 'HYST2477'], description='alpha-1-B glycoprotein', other_designations='alpha-1B-glycoprotein|HEL-S-163pA|epididymis secretory sperm binding protein Li 163pA', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58345183, end_position_on_the_genomic_accession=58353492, orientation='minus', exon_count=8, OMIM=[138670], no_hdr0=''),
    2 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2, CurrentID=0, Status='live', Symbol='A2M', Aliases=['A2MD', 'CPAMD5', 'FWP007', 'S863-7'], description='alpha-2-macroglobulin', other_designations='alpha-2-macroglobulin|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 5|alpha-2-M', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9067708, end_position_on_the_genomic_accession=9116229, orientation='minus', exon_count=37, OMIM=[103950], no_hdr0=''),
    9 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9, CurrentID=0, Status='live', Symbol='NAT1', Aliases=['AAC1', 'MNAT', 'NAT-1', 'NATI'], description='N-acetyltransferase 1', other_designations='arylamine N-acetyltransferase 1|N-acetyltransferase 1 (arylamine N-acetyltransferase)|N-acetyltransferase type 1|arylamide acetylase 1|monomorphic arylamine N-acetyltransferase', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=18170419, end_position_on_the_genomic_accession=18223689, orientation='plus', exon_count=11, OMIM=[108345], no_hdr0=''),
    10 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10, CurrentID=0, Status='live', Symbol='NAT2', Aliases=['AAC2', 'NAT-2', 'PNAT'], description='N-acetyltransferase 2', other_designations='arylamine N-acetyltransferase 2|N-acetyltransferase 2 (arylamine N-acetyltransferase)|N-acetyltransferase type 2|arylamide acetylase 2', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=18386585, end_position_on_the_genomic_accession=18401219, orientation='plus', exon_count=3, OMIM=[612182], no_hdr0=''),
    12 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=12, CurrentID=0, Status='live', Symbol='SERPINA3', Aliases=['AACT', 'ACT', 'GIG24', 'GIG25'], description='serpin family A member 3', other_designations='alpha-1-antichymotrypsin|cell growth-inhibiting gene 24/25 protein|growth-inhibiting protein 24|growth-inhibiting protein 25|serine (or cysteine) proteinase inhibitor, clade A, member 3|serpin A3|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 3', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94612391, end_position_on_the_genomic_accession=94624053, orientation='plus', exon_count=7, OMIM=[107280], no_hdr0=''),
    13 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=13, CurrentID=0, Status='live', Symbol='AADAC', Aliases=['CES5A1', 'DAC'], description='arylacetamide deacetylase', other_designations='arylacetamide deacetylase|arylacetamide deacetylase (esterase)', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151814008, end_position_on_the_genomic_accession=151828488, orientation='plus', exon_count=5, OMIM=[600338], no_hdr0=''),
    14 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=14, CurrentID=0, Status='live', Symbol='AAMP', Aliases=[], description='angio associated migratory cell protein', other_designations='angio-associated migratory cell protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218264127, end_position_on_the_genomic_accession=218270181, orientation='minus', exon_count=10, OMIM=[603488], no_hdr0=''),
    15 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=15, CurrentID=0, Status='live', Symbol='AANAT', Aliases=['DSPS', 'SNAT'], description='aralkylamine N-acetyltransferase', other_designations='serotonin N-acetyltransferase|arylalkylamine N-acetyltransferase|serotonin acetylase', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76453351, end_position_on_the_genomic_accession=76470797, orientation='plus', exon_count=8, OMIM=[600950], no_hdr0=''),
    16 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=16, CurrentID=0, Status='live', Symbol='AARS1', Aliases=['AARS', 'CMT2N', 'DEE29', 'EIEE29'], description='alanyl-tRNA synthetase 1', other_designations='alanine--tRNA ligase, cytoplasmic|alaRS|alanine tRNA ligase 1, cytoplasmic|alanyl-tRNA synthetase, cytoplasmic|renal carcinoma antigen NY-REN-42', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70252295, end_position_on_the_genomic_accession=70289509, orientation='minus', exon_count=21, OMIM=[601065], no_hdr0=''),
    18 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=18, CurrentID=0, Status='live', Symbol='ABAT', Aliases=['GABA-AT', 'GABAT', 'NPD009'], description='4-aminobutyrate aminotransferase', other_designations='4-aminobutyrate aminotransferase, mitochondrial|(S)-3-amino-2-methylpropionate transaminase|4-aminobutyrate transaminase|GABA aminotransferase|GABA transaminase|GABA transferase|gamma-amino-N-butyrate transaminase|gamma-aminobutyrate aminotransferase', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8674617, end_position_on_the_genomic_accession=8784570, orientation='plus', exon_count=22, OMIM=[137150], no_hdr0=''),
    19 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=19, CurrentID=0, Status='live', Symbol='ABCA1', Aliases=['ABC-1', 'ABC1', 'CERP', 'HDLCQTL13', 'HDLDT1', 'HPALP1', 'TGD'], description='ATP binding cassette subfamily A member 1', other_designations='phospholipid-transporting ATPase ABCA1|ATP-binding cassette sub-family A member 1|ATP-binding cassette transporter A1|ATP-binding cassette, sub-family A (ABC1), member 1|cholesterol efflux regulatory protein|membrane-bound', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104781006, end_position_on_the_genomic_accession=104928155, orientation='minus', exon_count=50, OMIM=[600046], no_hdr0=''),
    20 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=20, CurrentID=0, Status='live', Symbol='ABCA2', Aliases=['ABC2', 'IDPOGSA'], description='ATP binding cassette subfamily A member 2', other_designations='ATP-binding cassette sub-family A member 2|ATP-binding cassette 2|ATP-binding cassette transporter 2|ATP-binding cassette, sub-family A (ABC1), member 2|ATP-binding cassette, sub-family A, member 2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137007234, end_position_on_the_genomic_accession=137028922, orientation='minus', exon_count=49, OMIM=[600047], no_hdr0=''),
    21 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=21, CurrentID=0, Status='live', Symbol='ABCA3', Aliases=['ABC-C', 'ABC3', 'EST111653', 'LBM180', 'SMDP3'], description='ATP binding cassette subfamily A member 3', other_designations='phospholipid-transporting ATPase ABCA3|ABC transporter 3|ABC-C transporter|ATP-binding cassette sub-family A member 3|ATP-binding cassette transporter 3|ATP-binding cassette, sub-family A (ABC1), member 3|xenobiotic-transporting ATPase ABCA3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2275881, end_position_on_the_genomic_accession=2340728, orientation='minus', exon_count=33, OMIM=[601615], no_hdr0=''),
    22 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22, CurrentID=0, Status='live', Symbol='ABCB7', Aliases=['ABC7', 'ASAT', 'Atm1p', 'EST140535'], description='ATP binding cassette subfamily B member 7', other_designations='iron-sulfur clusters transporter ABCB7, mitochondrial|ABC transporter 7 protein|ATP-binding cassette sub-family B member 7, mitochondrial|ATP-binding cassette transporter 7|ATP-binding cassette, sub-family B (MDR/TAP), member 7', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=75051048, end_position_on_the_genomic_accession=75156283, orientation='minus', exon_count=16, OMIM=[300135], no_hdr0=''),
    23 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23, CurrentID=0, Status='live', Symbol='ABCF1', Aliases=['ABC27', 'ABC50'], description='ATP binding cassette subfamily F member 1', other_designations='ATP-binding cassette sub-family F member 1|ATP-binding cassette 50 (TNF-alpha stimulated)|ATP-binding cassette, sub-family F (GCN20), member 1|TNF-alpha-stimulated ABC protein|TNFalpha-inducible ATP-binding protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30571442, end_position_on_the_genomic_accession=30591522, orientation='plus', exon_count=25, OMIM=[603429], no_hdr0=''),
    24 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24, CurrentID=0, Status='live', Symbol='ABCA4', Aliases=['ABC10', 'ABCR', 'ARMD2', 'CORD3', 'FFM', 'RMP', 'RP19', 'STGD', 'STGD1'], description='ATP binding cassette subfamily A member 4', other_designations='retinal-specific phospholipid-transporting ATPase ABCA4|ATP binding cassette transporter|ATP-binding cassette sub-family A member 4|ATP-binding cassette transporter, retinal-specific|ATP-binding cassette, sub-family A (ABC1), member 4|ATP-binding transporter, retina-specific|RIM ABC transporter|RIM protein|photoreceptor rim protein|retina-specific ABC transporter|retinal-specific ATP-binding cassette transporter|stargardt disease protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93992834, end_position_on_the_genomic_accession=94121148, orientation='minus', exon_count=50, OMIM=[601691], no_hdr0=''),
    25 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25, CurrentID=0, Status='live', Symbol='ABL1', Aliases=['ABL', 'BCR-ABL', 'CHDSKM', 'JTK7', 'bcr/abl', 'c-ABL', 'c-ABL1', 'p150', 'v-abl'], description='ABL proto-oncogene 1, non-receptor tyrosine kinase', other_designations='tyrosine-protein kinase ABL1|ABL protooncogene 1 nonreceptor tyrosine kinase|Abelson tyrosine-protein kinase 1|bcr/c-abl oncogene protein|c-abl oncogene 1, receptor tyrosine kinase|proto-oncogene c-Abl|proto-oncogene tyrosine-protein kinase ABL1|truncated ABL protooncogene 1 nonreceptor tyrosine kinase|v-abl Abelson murine leukemia viral oncogene homolog 1', map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130713043, end_position_on_the_genomic_accession=130887675, orientation='plus', exon_count=12, OMIM=[189980], no_hdr0=''),
    26 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26, CurrentID=0, Status='live', Symbol='AOC1', Aliases=['ABP', 'ABP1', 'DAO', 'DAO1', 'KAO'], description='amine oxidase copper containing 1', other_designations='amiloride-sensitive amine oxidase [copper-containing]|amiloride binding protein 1 (amine oxidase (copper-containing))|amiloride-binding protein 1|amiloride-sensitive amine oxidase|amine oxidase copper domain-containing protein 1|diamine oxidase|histaminase|kidney amine oxidase', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150824875, end_position_on_the_genomic_accession=150861504, orientation='plus', exon_count=10, OMIM=[104610], no_hdr0=''),
    27 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27, CurrentID=0, Status='live', Symbol='ABL2', Aliases=['ABLL', 'ARG'], description='ABL proto-oncogene 2, non-receptor tyrosine kinase', other_designations='tyrosine-protein kinase ABL2|Abelson tyrosine-protein kinase 2|abelson-related gene protein|c-abl oncogene 2, non-receptor tyrosine kinase|tyrosine-protein kinase ARG|v-abl Abelson murine leukemia viral oncogene homolog 2', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179099330, end_position_on_the_genomic_accession=179229693, orientation='minus', exon_count=16, OMIM=[164690], no_hdr0=''),
    28 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28, CurrentID=0, Status='live', Symbol='ABO', Aliases=['A3GALNT', 'A3GALT1', 'GTB', 'NAGAT'], description='ABO, alpha 1-3-N-acetylgalactosaminyltransferase and alpha 1-3-galactosyltransferase', other_designations='histo-blood group ABO system transferase|ABO blood group (transferase A, alpha 1-3-N-acetylgalactosaminyltransferase; transferase B, alpha 1-3-galactosyltransferase)|B(A) alpha-1,3-galactosyltransferase|histo-blood group A2 transferase', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133250401, end_position_on_the_genomic_accession=133275201, orientation='minus', exon_count=7, OMIM=[110300], no_hdr0=''),
    29 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29, CurrentID=0, Status='live', Symbol='ABR', Aliases=['MDB'], description='ABR activator of RhoGEF and GTPase', other_designations='active breakpoint cluster region-related protein|ABR, RhoGEF and GTPase activating protein|active BCR-related', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1003519, end_position_on_the_genomic_accession=1229722, orientation='minus', exon_count=36, OMIM=[600365], no_hdr0=''),
    30 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30, CurrentID=0, Status='live', Symbol='ACAA1', Aliases=['ACAA', 'PTHIO', 'THIO'], description='acetyl-CoA acyltransferase 1', other_designations='3-ketoacyl-CoA thiolase, peroxisomal|acetyl-CoA C-myristoyltransferase|acetyl-Coenzyme A acyltransferase 1|beta-ketothiolase|epididymis secretory sperm binding protein|peroxisomal 3-oxoacyl-CoA thiolase|peroxisomal 3-oxoacyl-Coenzyme A thiolase|testicular tissue protein Li 197', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38122710, end_position_on_the_genomic_accession=38137127, orientation='minus', exon_count=12, OMIM=[604054], no_hdr0=''),
    31 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=31, CurrentID=0, Status='live', Symbol='ACACA', Aliases=['ACACD', 'ACC', 'ACC1', 'ACCA', 'ACACA'], description='acetyl-CoA carboxylase alpha', other_designations='acetyl-CoA carboxylase 1|ACC-alpha|acetyl-Coenzyme A carboxylase alpha', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37084992, end_position_on_the_genomic_accession=37406836, orientation='minus', exon_count=63, OMIM=[200350], no_hdr0=''),
    32 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=32, CurrentID=0, Status='live', Symbol='ACACB', Aliases=['ACC-beta', 'ACC2', 'ACCB', 'HACC275'], description='acetyl-CoA carboxylase beta', other_designations='acetyl-CoA carboxylase 2|acetyl-Coenzyme A carboxylase beta', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109112666, end_position_on_the_genomic_accession=109268226, orientation='plus', exon_count=56, OMIM=[601557], no_hdr0=''),
    33 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=33, CurrentID=0, Status='live', Symbol='ACADL', Aliases=['ACAD4', 'LCAD'], description='acyl-CoA dehydrogenase long chain', other_designations='long-chain specific acyl-CoA dehydrogenase, mitochondrial|acyl-Coenzyme A dehydrogenase, long chain', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210187923, end_position_on_the_genomic_accession=210225447, orientation='minus', exon_count=12, OMIM=[609576], no_hdr0=''),
    34 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=34, CurrentID=0, Status='live', Symbol='ACADM', Aliases=['ACAD1', 'MCAD', 'MCADH'], description='acyl-CoA dehydrogenase medium chain', other_designations='medium-chain specific acyl-CoA dehydrogenase, mitochondrial|acyl-CoA dehydrogenase, C-4 to C-12 straight chain|acyl-Coenzyme A dehydrogenase, C-4 to C-12 straight chain|medium-chain acyl-CoA dehydrogenase|testicular tissue protein Li 7', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75724709, end_position_on_the_genomic_accession=75763679, orientation='plus', exon_count=13, OMIM=[607008], no_hdr0=''),
    35 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=35, CurrentID=0, Status='live', Symbol='ACADS', Aliases=['ACAD3', 'SCAD'], description='acyl-CoA dehydrogenase short chain', other_designations='short-chain specific acyl-CoA dehydrogenase, mitochondrial|acyl-CoA dehydrogenase, C-2 to C-3 short chain|acyl-Coenzyme A dehydrogenase, C-2 to C-3 short chain|butyryl-CoA dehydrogenase|epididymis secretory sperm binding protein|mitochondrial short-chain specific acyl-CoA dehydrogenase|unsaturated acyl-CoA reductase', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120725826, end_position_on_the_genomic_accession=120740008, orientation='plus', exon_count=11, OMIM=[606885], no_hdr0=''),
    36 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=36, CurrentID=0, Status='live', Symbol='ACADSB', Aliases=['2-MEBCAD', 'ACAD7', 'SBCAD'], description='acyl-CoA dehydrogenase short/branched chain', other_designations='short/branched chain specific acyl-CoA dehydrogenase, mitochondrial|2-methyl branched chain acyl-CoA dehydrogenase|2-methylbutyryl-coenzyme A dehydrogenase|acyl-Coenzyme A dehydrogenase, short/branched chain', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123009006, end_position_on_the_genomic_accession=123058290, orientation='plus', exon_count=11, OMIM=[600301], no_hdr0=''),
    37 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=37, CurrentID=0, Status='live', Symbol='ACADVL', Aliases=['ACAD6', 'LCACD', 'VLCAD'], description='acyl-CoA dehydrogenase very long chain', other_designations='very long-chain specific acyl-CoA dehydrogenase, mitochondrial|acyl-Coenzyme A dehydrogenase, very long chain', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7217125, end_position_on_the_genomic_accession=7225266, orientation='plus', exon_count=22, OMIM=[609575], no_hdr0=''),
    38 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=38, CurrentID=0, Status='live', Symbol='ACAT1', Aliases=['ACAT', 'MAT', 'T2', 'THIL'], description='acetyl-CoA acetyltransferase 1', other_designations='acetyl-CoA acetyltransferase, mitochondrial|acetoacetyl Coenzyme A thiolase|acetoacetyl-CoA thiolase|acetyl-Coenzyme A acetyltransferase 1|mitochondrial acetoacetyl-CoA thiolase|testicular tissue protein Li 198', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108116705, end_position_on_the_genomic_accession=108148822, orientation='plus', exon_count=17, OMIM=[607809], no_hdr0=''),
    39 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=39, CurrentID=0, Status='live', Symbol='ACAT2', Aliases=[], description='acetyl-CoA acetyltransferase 2', other_designations='acetyl-CoA acetyltransferase, cytosolic|acetoacetyl Coenzyme A thiolase|acetyl-CoA transferase-like protein|cytosolic acetoacetyl-CoA thiolase', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159762045, end_position_on_the_genomic_accession=159779112, orientation='plus', exon_count=10, OMIM=[100678], no_hdr0=''),
    40 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=40, CurrentID=0, Status='live', Symbol='ASIC2', Aliases=['ACCN', 'ACCN1a', 'BNC1', 'BNaC1', 'MDEG', 'hBNaC1', 'ASIC2'], description='acid sensing ion channel subunit 2', other_designations='acid-sensing ion channel 2|acid sensing (proton gated) ion channel 2|amiloride-sensitive cation channel 1, neuronal|brain sodium channel 1|mammalian degenerin homolog|neuronal amiloride-sensitive cation channel 1', map_location='17q11.2-q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=33013087, end_position_on_the_genomic_accession=34156768, orientation='minus', exon_count=11, OMIM=[601784], no_hdr0=''),
    41 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=41, CurrentID=0, Status='live', Symbol='ASIC1', Aliases=['ACCN2', 'ASIC', 'BNaC2'], description='acid sensing ion channel subunit 1', other_designations='acid-sensing ion channel 1|Cation channel, amiloride-sensitive, neuronal, 2|acid sensing (proton gated) ion channel 1|acid-sensing ion channel 1a protein|amiloride-sensitive cation channel 2, neuronal|brain sodium channel 2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50057596, end_position_on_the_genomic_accession=50083622, orientation='plus', exon_count=14, OMIM=[602866], no_hdr0=''),
    43 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=43, CurrentID=0, Status='live', Symbol='ACHE', Aliases=['ACEE', 'ARACHE', 'N-ACHE', 'YT'], description='acetylcholinesterase (Cartwright blood group)', other_designations='acetylcholinesterase|Yt blood group|acetylcholinesterase (Yt blood group)|apoptosis-related acetylcholinesterase', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100889994, end_position_on_the_genomic_accession=100896994, orientation='minus', exon_count=8, OMIM=[100740], no_hdr0=''),
    47 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=47, CurrentID=0, Status='live', Symbol='ACLY', Aliases=['ACL', 'ATPCL', 'CLATP'], description='ATP citrate lyase', other_designations='ATP-citrate synthase|ATP-citrate (pro-S-)-lyase|citrate cleavage enzyme', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41866916, end_position_on_the_genomic_accession=41930542, orientation='minus', exon_count=30, OMIM=[108728], no_hdr0=''),
    48 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=48, CurrentID=0, Status='live', Symbol='ACO1', Aliases=['ACONS', 'HEL60', 'IREB1', 'IREBP', 'IREBP1', 'IRP1'], description='aconitase 1', other_designations='cytoplasmic aconitate hydratase|aconitase 1, soluble|aconitate hydratase, cytoplasmic|citrate hydro-lyase|cytoplasmic aconitase|cytosplasmic aconitase|epididymis luminal protein 60|epididymis secretory sperm binding protein|ferritin repressor protein|iron regulatory protein 1|iron-responsive element-binding protein 1|soluble aconitase', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32384643, end_position_on_the_genomic_accession=32454769, orientation='plus', exon_count=23, OMIM=[100880], no_hdr0=''),
    49 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49, CurrentID=0, Status='live', Symbol='ACR', Aliases=[], description='acrosin', other_designations='acrosin|acrosin light and heavy chain prepropeptide|preproacrosin|proacrosin', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50738204, end_position_on_the_genomic_accession=50745339, orientation='plus', exon_count=5, OMIM=[102480], no_hdr0=''),
    50 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50, CurrentID=0, Status='live', Symbol='ACO2', Aliases=['ACONM', 'HEL-S-284', 'ICRD', 'OCA8', 'OPA9'], description='aconitase 2', other_designations='aconitate hydratase, mitochondrial|aconitase 2, mitochondrial|citrate hydro-lyase|epididymis secretory sperm binding protein Li 284|mitochondrial aconitase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41468756, end_position_on_the_genomic_accession=41528979, orientation='plus', exon_count=19, OMIM=[100850], no_hdr0=''),
    51 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51, CurrentID=0, Status='live', Symbol='ACOX1', Aliases=['ACOX', 'MITCH', 'PALMCOX', 'SCOX'], description='acyl-CoA oxidase 1', other_designations='peroxisomal acyl-coenzyme A oxidase 1|AOX|acyl-CoA oxidase 1, palmitoyl|acyl-CoA oxidase, straight-chain|acyl-Coenzyme A oxidase 1, palmitoyl|palmitoyl-CoA oxidase|peroxisomal fatty acyl-CoA oxidase|straight-chain acyl-CoA oxidase', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75941507, end_position_on_the_genomic_accession=75979199, orientation='minus', exon_count=15, OMIM=[609751], no_hdr0=''),
    52 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=52, CurrentID=0, Status='live', Symbol='ACP1', Aliases=['HAAP', 'LMW-PTP', 'LMWPTP'], description='acid phosphatase 1', other_designations='low molecular weight phosphotyrosine protein phosphatase|LMW-PTPase|acid phosphatase 1, soluble|acid phosphatase of erythrocyte|adipocyte acid phosphatase|cytoplasmic phosphotyrosyl protein phosphatase|low molecular weight cytosolic acid phosphatase|protein tyrosine phosphatase|red cell acid phosphatase 1|testicular secretory protein Li 37', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=264947, end_position_on_the_genomic_accession=278283, orientation='plus', exon_count=7, OMIM=[171500], no_hdr0=''),
    53 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53, CurrentID=0, Status='live', Symbol='ACP2', Aliases=['LAP'], description='acid phosphatase 2, lysosomal', other_designations='lysosomal acid phosphatase', map_location='11p12-p11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47239302, end_position_on_the_genomic_accession=47248814, orientation='minus', exon_count=12, OMIM=[171650], no_hdr0=''),
    54 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54, CurrentID=0, Status='live', Symbol='ACP5', Aliases=['HPAP', 'TRACP5a', 'TRACP5b', 'TRAP', 'TrATPase'], description='acid phosphatase 5, tartrate resistant', other_designations='tartrate-resistant acid phosphatase type 5|human purple acid phosphatase|tartrate-resistant acid ATPase|tartrate-resistant acid phosphatase 5a|tartrate-resistant acid phosphatase 5b', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11574660, end_position_on_the_genomic_accession=11578983, orientation='minus', exon_count=8, OMIM=[171640], no_hdr0=''),
    55 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55, CurrentID=0, Status='live', Symbol='ACP3', Aliases=["5'-NT", 'ACP-3', 'ACPP', 'TM-PAP'], description='acid phosphatase 3', other_designations="prostatic acid phosphatase|TMPase|acid phosphatase, prostate|ecto-5'-nucleotidase|prostatic acid phosphotase|protein tyrosine phosphatase ACP3|thiamine monophosphatase", map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132317403, end_position_on_the_genomic_accession=132368765, orientation='plus', exon_count=12, OMIM=[171790], no_hdr0=''),
    56 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56, CurrentID=0, Status='live', Symbol='ACRV1', Aliases=['D11S4365', 'SP-10', 'SPACA2'], description='acrosomal vesicle protein 1', other_designations='acrosomal protein SP-10|sperm protein 10', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125671522, end_position_on_the_genomic_accession=125680847, orientation='minus', exon_count=5, OMIM=[102525], no_hdr0=''),
    58 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58, CurrentID=0, Status='live', Symbol='ACTA1', Aliases=['ACTA', 'ASMA', 'CFTD', 'CFTD1', 'CFTDM', 'MPFD', 'NEM1', 'NEM2', 'NEM3', 'SHPM'], description='actin alpha 1, skeletal muscle', other_designations='actin, alpha skeletal muscle|nemaline myopathy type 3', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229431245, end_position_on_the_genomic_accession=229434094, orientation='minus', exon_count=7, OMIM=[102610], no_hdr0=''),
    59 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59, CurrentID=0, Status='live', Symbol='ACTA2', Aliases=['ACTSA'], description='actin alpha 2, smooth muscle', other_designations='actin, aortic smooth muscle|actin, alpha 2, smooth muscle, aorta|alpha-cardiac actin|cell growth-inhibiting gene 46 protein', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88935074, end_position_on_the_genomic_accession=88991397, orientation='minus', exon_count=10, OMIM=[102620], no_hdr0=''),
    60 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60, CurrentID=0, Status='live', Symbol='ACTB', Aliases=['BRWS1', 'PS1TP5BP1'], description='actin beta', other_designations='actin, cytoplasmic 1|I(2)-actin|PS1TP5-binding protein 1|beta cytoskeletal actin', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5527148, end_position_on_the_genomic_accession=5530601, orientation='minus', exon_count=6, OMIM=[102630], no_hdr0=''),
    70 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=70, CurrentID=0, Status='live', Symbol='ACTC1', Aliases=['ACTC', 'ASD5', 'CMD1R', 'CMH11', 'LVNC4'], description='actin alpha cardiac muscle 1', other_designations='actin, alpha cardiac muscle 1', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34790230, end_position_on_the_genomic_accession=34795549, orientation='minus', exon_count=7, OMIM=[102540], no_hdr0=''),
    71 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=71, CurrentID=0, Status='live', Symbol='ACTG1', Aliases=['ACT', 'ACTG', 'DFNA20', 'DFNA26', 'HEL-176'], description='actin gamma 1', other_designations='actin, cytoplasmic 2|cytoskeletal gamma-actin|epididymis luminal protein 176', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81509971, end_position_on_the_genomic_accession=81512799, orientation='minus', exon_count=7, OMIM=[102560], no_hdr0=''),
    72 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=72, CurrentID=0, Status='live', Symbol='ACTG2', Aliases=['ACT', 'ACTA3', 'ACTE', 'ACTL3', 'ACTSG', 'VSCM', 'VSCM1'], description='actin gamma 2, smooth muscle', other_designations='actin, gamma-enteric smooth muscle|actin, gamma 2, smooth muscle, enteric|actin-like protein|alpha-actin-3', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73893008, end_position_on_the_genomic_accession=73919865, orientation='plus', exon_count=9, OMIM=[102545], no_hdr0=''),
    81 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81, CurrentID=0, Status='live', Symbol='ACTN4', Aliases=['ACTININ-4', 'FSGS', 'FSGS1'], description='actinin alpha 4', other_designations='alpha-actinin-4|focal segmental glomerulosclerosis 1|non-muscle alpha-actinin 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38647649, end_position_on_the_genomic_accession=38731589, orientation='plus', exon_count=23, OMIM=[604638], no_hdr0=''),
    86 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=86, CurrentID=0, Status='live', Symbol='ACTL6A', Aliases=['ACTL6', 'ARPN-BETA', 'Arp4', 'BAF53A', 'INO80K'], description='actin like 6A', other_designations='actin-like protein 6A|53 kDa BRG1-associated factor A|BAF complex 53 kDa subunit|BAF53|BRG1-associated factor 53A|INO80 complex subunit K|actin-related protein 4|actin-related protein Baf53a|arpNbeta|hArpN beta', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179562926, end_position_on_the_genomic_accession=179588407, orientation='plus', exon_count=14, OMIM=[604958], no_hdr0=''),
    87 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=87, CurrentID=0, Status='live', Symbol='ACTN1', Aliases=['BDPLT15'], description='actinin alpha 1', other_designations='alpha-actinin-1|F-actin cross-linking protein|actinin 1 smooth muscle|epididymis secretory sperm binding protein|non-muscle alpha-actinin-1', map_location='14q22-q24', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=68874123, end_position_on_the_genomic_accession=68979302, orientation='minus', exon_count=23, OMIM=[102575], no_hdr0=''),
    88 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=88, CurrentID=0, Status='live', Symbol='ACTN2', Aliases=['CMD1AA', 'CMH23', 'MPD6', 'MYOCOZ'], description='actinin alpha 2', other_designations='alpha-actinin-2|F-actin cross-linking protein|alpha-actinin skeletal muscle|truncated actinin alpha 2', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236686499, end_position_on_the_genomic_accession=236764631, orientation='plus', exon_count=23, OMIM=[102573], no_hdr0=''),
    89 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89, CurrentID=0, Status='live', Symbol='ACTN3', Aliases=['ACTN3D'], description='actinin alpha 3', other_designations='alpha-actinin-3|F-actin cross-linking protein|alpha-actinin skeletal muscle', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66546395, end_position_on_the_genomic_accession=66563334, orientation='plus', exon_count=22, OMIM=[102574], no_hdr0=''),
    90 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90, CurrentID=0, Status='live', Symbol='ACVR1', Aliases=['ACTRIA', 'ACVRLK2', 'ALK2', 'FOP', 'SKR1', 'TSRI', 'ACVR1'], description='activin A receptor type 1', other_designations='activin receptor type-1|TGF-B superfamily receptor type I|activin A receptor, type I|activin A receptor, type II-like kinase 2|activin receptor type I|activin receptor-like kinase 2|hydroxyalkyl-protein kinase|serine/threonine-protein kinase receptor R1', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157736446, end_position_on_the_genomic_accession=157876330, orientation='minus', exon_count=16, OMIM=[102576], no_hdr0=''),
    91 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91, CurrentID=0, Status='live', Symbol='ACVR1B', Aliases=['ACTRIB', 'ACVRLK4', 'ALK4', 'SKR2'], description='activin A receptor type 1B', other_designations='activin receptor type-1B|activin A receptor, type IB|activin A receptor, type II-like kinase 4|activin receptor-like kinase 4|serine/threonine-protein kinase receptor R2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51951696, end_position_on_the_genomic_accession=51997078, orientation='plus', exon_count=12, OMIM=[601300], no_hdr0=''),
    92 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92, CurrentID=0, Status='live', Symbol='ACVR2A', Aliases=['ACTRII', 'ACVR2'], description='activin A receptor type 2A', other_designations='activin receptor type-2A|activin A receptor, type IIA', map_location='2q22.3-q23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=147844517, end_position_on_the_genomic_accession=147930822, orientation='plus', exon_count=12, OMIM=[102581], no_hdr0=''),
    93 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93, CurrentID=0, Status='live', Symbol='ACVR2B', Aliases=['ACTRIIB', 'ActR-IIB', 'HTX4'], description='activin A receptor type 2B', other_designations='activin receptor type-2B|activin A receptor, type IIB', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38453890, end_position_on_the_genomic_accession=38493142, orientation='plus', exon_count=14, OMIM=[602730], no_hdr0=''),
    94 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94, CurrentID=0, Status='live', Symbol='ACVRL1', Aliases=['ACVRLK1', 'ALK-1', 'ALK1', 'HHT', 'HHT2', 'ORW2', 'SKR3', 'TSR-I'], description='activin A receptor like type 1', other_designations='serine/threonine-protein kinase receptor R3|TGF-B superfamily receptor type I|activin A receptor type II-like 1|activin A receptor type IL|activin A receptor, type II-like kinase 1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51906913, end_position_on_the_genomic_accession=51923361, orientation='plus', exon_count=11, OMIM=[601284], no_hdr0=''),
    95 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=95, CurrentID=0, Status='live', Symbol='ACY1', Aliases=['ACY-1D', 'HEL-S-5', 'ACY1'], description='aminoacylase 1', other_designations='aminoacylase-1|N-acyl-L-amino-acid amidohydrolase|acylase|epididymis secretory protein Li 5', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51983535, end_position_on_the_genomic_accession=51989197, orientation='plus', exon_count=15, OMIM=[104620], no_hdr0=''),
    97 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=97, CurrentID=0, Status='live', Symbol='ACYP1', Aliases=['ACYPE'], description='acylphosphatase 1', other_designations='acylphosphatase-1|acylphosphatase 1, erythrocyte (common) type|acylphosphatase, erythrocyte isozyme|acylphosphatase, organ-common type isozyme|acylphosphate phosphohydrolase 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75053243, end_position_on_the_genomic_accession=75069490, orientation='minus', exon_count=5, OMIM=[600875], no_hdr0=''),
    98 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=98, CurrentID=0, Status='live', Symbol='ACYP2', Aliases=['ACYM', 'ACYP'], description='acylphosphatase 2', other_designations='acylphosphatase-2|acylphosphatase 2, muscle type|acylphosphatase, muscle type isozyme|acylphosphate phosphohydrolase 2|testicular tissue protein Li 11', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53971113, end_position_on_the_genomic_accession=54305300, orientation='plus', exon_count=11, OMIM=[102595], no_hdr0=''),
    100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100, CurrentID=0, Status='live', Symbol='ADA', Aliases=['ADA1'], description='adenosine deaminase', other_designations='adenosine deaminase|adenosine aminohydrolase', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44619522, end_position_on_the_genomic_accession=44651699, orientation='minus', exon_count=12, OMIM=[608958], no_hdr0=''),
    101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101, CurrentID=0, Status='live', Symbol='ADAM8', Aliases=['CD156', 'CD156a', 'MS2'], description='ADAM metallopeptidase domain 8', other_designations='disintegrin and metalloproteinase domain-containing protein 8|a disintegrin and metalloproteinase domain 8|cell surface antigen MS2|human leukocyte differentiation antigen', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133262422, end_position_on_the_genomic_accession=133276891, orientation='minus', exon_count=24, OMIM=[602267], no_hdr0=''),
    102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102, CurrentID=0, Status='live', Symbol='ADAM10', Aliases=['AD10', 'AD18', 'CD156c', 'CDw156', 'HsT18717', 'MADM', 'RAK', 'kuz'], description='ADAM metallopeptidase domain 10', other_designations='disintegrin and metalloproteinase domain-containing protein 10|a disintegrin and metalloprotease domain 10|kuzbanian protein homolog|mammalian disintegrin-metalloprotease', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58588809, end_position_on_the_genomic_accession=58749707, orientation='minus', exon_count=17, OMIM=[602192], no_hdr0=''),
    103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=103, CurrentID=0, Status='live', Symbol='ADAR', Aliases=['ADAR1', 'AGS6', 'DRADA', 'DSH', 'DSRAD', 'G1P1', 'IFI-4', 'IFI4', 'K88DSRBP', 'P136'], description='adenosine deaminase RNA specific', other_designations='double-stranded RNA-specific adenosine deaminase|136 kDa double-stranded RNA-binding protein|adenosine deaminase acting on RNA 1-A|dsRNA adenosine deaminase|dsRNA adeonosine deaminase|interferon-induced protein 4|interferon-inducible protein 4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154582057, end_position_on_the_genomic_accession=154627997, orientation='minus', exon_count=21, OMIM=[146920], no_hdr0=''),
    104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=104, CurrentID=0, Status='live', Symbol='ADARB1', Aliases=['ADAR2', 'DRABA2', 'DRADA2', 'NEDHYMS', 'RED1'], description='adenosine deaminase RNA specific B1', other_designations='double-stranded RNA-specific editase 1|RNA editing deaminase 1|RNA-editing enzyme 1|adenosine deaminase, RNA-specific, B1 (homolog of rat RED1)|dsRNA adenosine deaminase DRADA2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45074578, end_position_on_the_genomic_accession=45226563, orientation='plus', exon_count=24, OMIM=[601218], no_hdr0=''),
    105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105, CurrentID=0, Status='live', Symbol='ADARB2', Aliases=['ADAR3', 'RED2'], description='adenosine deaminase RNA specific B2 (inactive)', other_designations='double-stranded RNA-specific editase B2|RED2 homolog|RNA-dependent adenosine deaminase 3|RNA-editing deaminase 2|RNA-editing enzyme 2|adenosine deaminase, RNA-specific, B2 (RED1 homolog rat)|adenosine deaminase, RNA-specific, B2 (RED2 homolog rat)|adenosine deaminase, RNA-specific, B2 (non-functional)|dsRNA adenosine deaminase B2|homolog of rat BLUE', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=1177313, end_position_on_the_genomic_accession=1737525, orientation='minus', exon_count=10, OMIM=[602065], no_hdr0=''),
    107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107, CurrentID=0, Status='live', Symbol='ADCY1', Aliases=['AC1', 'DFNB44'], description='adenylate cyclase 1', other_designations="adenylate cyclase type 1|3',5'-cyclic AMP synthetase|ATP pyrophosphate-lyase 1|Ca(2+)/calmodulin-activated adenylyl cyclase|adenyl cyclase|adenylate cyclase 1 (brain)|adenylate cyclase type I|adenylyl cyclase 1|adenylyl cyclase subtype 1", map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45574140, end_position_on_the_genomic_accession=45723116, orientation='plus', exon_count=22, OMIM=[103072], no_hdr0=''),
    108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=108, CurrentID=0, Status='live', Symbol='ADCY2', Aliases=['AC2', 'HBAC2'], description='adenylate cyclase 2', other_designations="adenylate cyclase type 2|3',5'-cyclic AMP synthetase|ATP pyrophosphate-lyase 2|adenylate cyclase 2 (brain)|adenylate cyclase II|adenylate cyclase type II|adenylyl cyclase 2|type II adenylate cyclase", map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=7396138, end_position_on_the_genomic_accession=7830081, orientation='plus', exon_count=26, OMIM=[103071], no_hdr0=''),
    109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=109, CurrentID=0, Status='live', Symbol='ADCY3', Aliases=['AC-III', 'AC3', 'BMIQ19'], description='adenylate cyclase 3', other_designations='adenylate cyclase type 3|ATP pyrophosphate-lyase 3|adenylate cyclase type III|adenylate cyclase, olfactive type|adenylyl cyclase 3|adenylyl cyclase, type III', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24819169, end_position_on_the_genomic_accession=24920237, orientation='minus', exon_count=27, OMIM=[600291], no_hdr0=''),
    111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111, CurrentID=0, Status='live', Symbol='ADCY5', Aliases=['AC5', 'FDFM'], description='adenylate cyclase 5', other_designations='adenylate cyclase type 5|ATP pyrophosphate-lyase 5|adenylate cyclase type V|adenylyl cyclase 5|epididymis secretory sperm binding protein', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123282296, end_position_on_the_genomic_accession=123449090, orientation='minus', exon_count=30, OMIM=[600293], no_hdr0=''),
    112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112, CurrentID=0, Status='live', Symbol='ADCY6', Aliases=['AC6', 'LCCS8'], description='adenylate cyclase 6', other_designations='adenylate cyclase type 6|ATP pyrophosphate-lyase 6|adenylate cyclase type VI|ca(2+)-inhibitable adenylyl cyclase', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48766194, end_position_on_the_genomic_accession=48789089, orientation='minus', exon_count=23, OMIM=[600294], no_hdr0=''),
    113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113, CurrentID=0, Status='live', Symbol='ADCY7', Aliases=['AC7'], description='adenylate cyclase 7', other_designations='adenylate cyclase type 7|ATP pyrophosphate-lyase 7|adenylate cyclase type VII|adenylyl cyclase 7', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50246138, end_position_on_the_genomic_accession=50318135, orientation='plus', exon_count=30, OMIM=[600385], no_hdr0=''),
    114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114, CurrentID=0, Status='live', Symbol='ADCY8', Aliases=['AC8', 'ADCY3', 'HBAC1'], description='adenylate cyclase 8', other_designations='adenylate cyclase type 8|ATP pyrophosphate-lyase 8|HEL-S-172mP|adenylate cyclase 8 (brain)|adenylate cyclase type VIII|adenylyl cyclase 8|adenylyl cyclase-8, brain|ca(2+)/calmodulin-activated adenylyl cyclase|epididymis secretory sperm binding protein Li 172mP', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=130780300, end_position_on_the_genomic_accession=131041604, orientation='minus', exon_count=19, OMIM=[103070], no_hdr0=''),
    115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115, CurrentID=0, Status='live', Symbol='ADCY9', Aliases=['AC9', 'ACIX'], description='adenylate cyclase 9', other_designations='adenylate cyclase type 9|ATP pyrophosphate-lyase 9|adenylate cyclase type IX|adenylyl cyclase 9|type IX ATP pyrophosphate-lyase', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3953387, end_position_on_the_genomic_accession=4116442, orientation='minus', exon_count=12, OMIM=[603302], no_hdr0=''),
    116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116, CurrentID=0, Status='live', Symbol='ADCYAP1', Aliases=['PACAP'], description='adenylate cyclase activating polypeptide 1', other_designations='pituitary adenylate cyclase-activating polypeptide|adenylate cyclase activating polypeptide 1 (pituitary)|prepro-PACAP', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=904384, end_position_on_the_genomic_accession=912172, orientation='plus', exon_count=6, OMIM=[102980], no_hdr0=''),
    117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117, CurrentID=0, Status='live', Symbol='ADCYAP1R1', Aliases=['PAC1', 'PAC1R', 'PACAPR', 'PACAPRI'], description='ADCYAP receptor type I', other_designations='pituitary adenylate cyclase-activating polypeptide type I receptor|PACAP receptor 1|PACAP type I receptor|PACAP-R1|adenylate cyclase activating polypeptide 1 (pituitary) receptor type I|pituitary adenylate cyclase activating polypeptide 1 receptor type I Hiphop|pituitary adenylate cyclase-activating polypeptide type 1 receptor', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31052308, end_position_on_the_genomic_accession=31111474, orientation='plus', exon_count=18, OMIM=[102981], no_hdr0=''),
    118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118, CurrentID=0, Status='live', Symbol='ADD1', Aliases=['ADDA'], description='adducin 1', other_designations='alpha-adducin|adducin 1 (alpha)|erythrocyte adducin alpha subunit', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2843844, end_position_on_the_genomic_accession=2930065, orientation='plus', exon_count=19, OMIM=[102680], no_hdr0=''),
    119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119, CurrentID=0, Status='live', Symbol='ADD2', Aliases=['ADDB'], description='adducin 2', other_designations='beta-adducin|adducin 2 (beta)|erythrocyte adducin subunit beta', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70656784, end_position_on_the_genomic_accession=70768200, orientation='minus', exon_count=19, OMIM=[102681], no_hdr0=''),
    120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120, CurrentID=0, Status='live', Symbol='ADD3', Aliases=['ADDL', 'CPSQ3'], description='adducin 3', other_designations='gamma-adducin|adducin 3 (gamma)|adducin-like protein 70', map_location='10q25.1-q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=109996365, end_position_on_the_genomic_accession=110135565, orientation='plus', exon_count=23, OMIM=[601568], no_hdr0=''),
    123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123, CurrentID=0, Status='live', Symbol='PLIN2', Aliases=['ADFP', 'ADRP'], description='perilipin 2', other_designations='perilipin-2|adipophilin|adipose differentiation-related protein', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19108391, end_position_on_the_genomic_accession=19127518, orientation='minus', exon_count=9, OMIM=[103195], no_hdr0=''),
    124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124, CurrentID=0, Status='live', Symbol='ADH1A', Aliases=['ADH1'], description='alcohol dehydrogenase 1A (class I), alpha polypeptide', other_designations='alcohol dehydrogenase 1A|ADH, alpha subunit|alcohol dehydrogenase 1 (class I), alpha polypeptide|alcohol dehydrogenase subunit alpha|aldehyde reductase', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99276369, end_position_on_the_genomic_accession=99290985, orientation='minus', exon_count=9, OMIM=[103700], no_hdr0=''),
    125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125, CurrentID=0, Status='live', Symbol='ADH1B', Aliases=['ADH2', 'HEL-S-117'], description='alcohol dehydrogenase 1B (class I), beta polypeptide', other_designations='all-trans-retinol dehydrogenase [NAD(+)] ADH1B|ADH, beta subunit|alcohol dehydrogenase 2 (class I), beta polypeptide|alcohol dehydrogenase subunit beta|aldehyde reductase|epididymis secretory protein Li 117', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99304971, end_position_on_the_genomic_accession=99321401, orientation='minus', exon_count=10, OMIM=[103720], no_hdr0=''),
    126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126, CurrentID=0, Status='live', Symbol='ADH1C', Aliases=['ADH3'], description='alcohol dehydrogenase 1C (class I), gamma polypeptide', other_designations='alcohol dehydrogenase 1C|ADH, gamma subunit|alcohol dehydrogenase 3 (class I), gamma polypeptide|aldehyde reductase', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99336497, end_position_on_the_genomic_accession=99352746, orientation='minus', exon_count=9, OMIM=[103730], no_hdr0=''),
    127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127, CurrentID=0, Status='live', Symbol='ADH4', Aliases=['ADH-2', 'HEL-S-4'], description='alcohol dehydrogenase 4 (class II), pi polypeptide', other_designations='all-trans-retinol dehydrogenase [NAD(+)] ADH4|alcohol dehydrogenase class II pi chain|aldehyde reductase|epididymis secretory protein Li 4', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99123658, end_position_on_the_genomic_accession=99144297, orientation='minus', exon_count=10, OMIM=[103740], no_hdr0=''),
    128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128, CurrentID=0, Status='live', Symbol='ADH5', Aliases=['ADH-3', 'ADHX', 'AMEDS', 'BMFS7', 'FALDH', 'FDH', 'GSH-FDH', 'GSNOR', 'HEL-S-60p'], description='alcohol dehydrogenase 5 (class III), chi polypeptide', other_designations='alcohol dehydrogenase class-3|S-(hydroxymethyl)glutathione dehydrogenase|S-nitrosoglutathione reductase|alcohol dehydrogenase (class III), chi polypeptide|alcohol dehydrogenase class chi chain|alcohol dehydrogenase class-III|epididymis secretory sperm binding protein Li 60p|formaldehyde dehydrogenase|glutathione-dependent formaldehyde dehydrogenase', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99070978, end_position_on_the_genomic_accession=99088788, orientation='minus', exon_count=9, OMIM=[103710], no_hdr0=''),
    130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130, CurrentID=0, Status='live', Symbol='ADH6', Aliases=['ADH-5'], description='alcohol dehydrogenase 6 (class V)', other_designations='alcohol dehydrogenase 6|aldehyde reductase', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99202639, end_position_on_the_genomic_accession=99219246, orientation='minus', exon_count=9, OMIM=[103735], no_hdr0=''),
    131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131, CurrentID=0, Status='live', Symbol='ADH7', Aliases=['ADH4'], description='alcohol dehydrogenase 7 (class IV), mu or sigma polypeptide', other_designations='all-trans-retinol dehydrogenase [NAD(+)] ADH7|alcohol dehydrogenase VII|alcohol dehydrogenase class 4 mu/sigma chain|alcohol dehydrogenase class IV mu/sigma chain|alcohol dehydrogenase-7|class IV sigma-1 alcohol dehydrogenase|class IV sigmasigma alcohol dehydrogenase|gastric alcohol dehydrogenase|omega-hydroxydecanoate dehydrogenase ADH7|retinol dehydrogenase', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99412263, end_position_on_the_genomic_accession=99435342, orientation='minus', exon_count=10, OMIM=[600086], no_hdr0=''),
    132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132, CurrentID=0, Status='live', Symbol='ADK', Aliases=['AK'], description='adenosine kinase', other_designations="adenosine kinase|adenosine 5'-phosphotransferase|testicular tissue protein Li 14", map_location='10q11-q24', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=74151185, end_position_on_the_genomic_accession=74709300, orientation='plus', exon_count=16, OMIM=[102750], no_hdr0=''),
    133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133, CurrentID=0, Status='live', Symbol='ADM', Aliases=['AM', 'PAMP'], description='adrenomedullin', other_designations='pro-adrenomedullin|preproadrenomedullin|proadrenomedullin N-20 terminal peptide', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10305073, end_position_on_the_genomic_accession=10307397, orientation='plus', exon_count=4, OMIM=[103275], no_hdr0=''),
    134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134, CurrentID=0, Status='live', Symbol='ADORA1', Aliases=['RDC7'], description='adenosine A1 receptor', other_designations='adenosine receptor A1|adenosine A1 receptor variant 1|adenosine A1 receptor variant 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203127705, end_position_on_the_genomic_accession=203167405, orientation='plus', exon_count=4, OMIM=[102775], no_hdr0=''),
    135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135, CurrentID=0, Status='live', Symbol='ADORA2A', Aliases=['A2aR', 'ADORA2', 'RDC8'], description='adenosine A2a receptor', other_designations='adenosine receptor A2a|adenosine receptor subtype A2a', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24423597, end_position_on_the_genomic_accession=24442357, orientation='plus', exon_count=6, OMIM=[102776], no_hdr0=''),
    136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136, CurrentID=0, Status='live', Symbol='ADORA2B', Aliases=['ADORA2'], description='adenosine A2b receptor', other_designations='adenosine receptor A2b', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15927782, end_position_on_the_genomic_accession=15975746, orientation='plus', exon_count=6, OMIM=[600446], no_hdr0=''),
    140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140, CurrentID=0, Status='live', Symbol='ADORA3', Aliases=['A3AR'], description='adenosine A3 receptor', other_designations='adenosine receptor A3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111499429, end_position_on_the_genomic_accession=111503633, orientation='minus', exon_count=2, OMIM=[600445], no_hdr0=''),
    141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=141, CurrentID=0, Status='live', Symbol='ADPRH', Aliases=['ARH1', 'hARH1'], description='ADP-ribosylarginine hydrolase', other_designations='ADP-ribosylarginine hydrolase|ADP-ribose-L-arginine cleaving enzyme|[Protein ADP-ribosylarginine] hydrolase', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119579492, end_position_on_the_genomic_accession=119589945, orientation='plus', exon_count=5, OMIM=[603081], no_hdr0=''),
    142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142, CurrentID=0, Status='live', Symbol='PARP1', Aliases=['ADPRT', 'ADPRT 1', 'ADPRT1', 'ARTD1', 'PARP', 'PARP-1', 'PPOL', 'pADPRT-1'], description='poly(ADP-ribose) polymerase 1', other_designations='poly [ADP-ribose] polymerase 1|ADP-ribosyltransferase (NAD+; poly (ADP-ribose) polymerase)|ADP-ribosyltransferase NAD(+)|ADP-ribosyltransferase diphtheria toxin-like 1|DNA ADP-ribosyltransferase PARP1|NAD(+) ADP-ribosyltransferase 1|poly (ADP-ribose) polymerase family, member 1|poly(ADP-ribose) synthetase|poly(ADP-ribosyl)transferase|poly[ADP-ribose] synthase 1|protein poly-ADP-ribosyltransferase PARP1', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226360691, end_position_on_the_genomic_accession=226408093, orientation='minus', exon_count=23, OMIM=[173870], no_hdr0=''),
    143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143, CurrentID=0, Status='live', Symbol='PARP4', Aliases=['ADPRTL1', 'ARTD4', 'PARP-4', 'PARPL', 'PH5P', 'VAULT3', 'VPARP', 'VWA5C', 'p193'], description='poly(ADP-ribose) polymerase family member 4', other_designations='protein mono-ADP-ribosyltransferase PARP4|193 kDa vault protein|ADP-ribosyltransferase (NAD+; poly (ADP-ribose) polymerase)-like 1|ADP-ribosyltransferase diphtheria toxin-like 4|H5 proline-rich|I-alpha-I-related|PARP-related|PARP-related/IalphaI-related H5/proline-rich|poly [ADP-ribose] polymerase 4|poly(ADP-ribose) synthetase|poly(ADP-ribosyl)transferase-like 1|vault poly(ADP-ribose) polymerase|vault protein, 193-kDa|von Willebrand factor A domain containing 5C', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24420930, end_position_on_the_genomic_accession=24512993, orientation='minus', exon_count=36, OMIM=[607519], no_hdr0=''),
    146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146, CurrentID=0, Status='live', Symbol='ADRA1D', Aliases=['ADRA1', 'ADRA1A', 'ADRA1R', 'ALPHA1', 'DAR', 'dJ779E11.2'], description='adrenoceptor alpha 1D', other_designations='alpha-1D adrenergic receptor|adrenergic, alpha -1D-, receptor|adrenergic, alpha-1A-, receptor|alpha-1A adrenergic receptor|alpha-1D adrenoceptor|alpha-1D adrenoreceptor|alpha-adrenergic receptor 1a', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4220630, end_position_on_the_genomic_accession=4249287, orientation='minus', exon_count=2, OMIM=[104219], no_hdr0=''),
    147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147, CurrentID=0, Status='live', Symbol='ADRA1B', Aliases=['ADRA1', 'ALPHA1BAR'], description='adrenoceptor alpha 1B', other_designations='alpha-1B adrenergic receptor|adrenergic, alpha-1B-, receptor|alpha-1B adrenoceptor|alpha-1B adrenoreceptor', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=159916482, end_position_on_the_genomic_accession=159989205, orientation='plus', exon_count=7, OMIM=[104220], no_hdr0=''),
    148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148, CurrentID=0, Status='live', Symbol='ADRA1A', Aliases=['ADRA1C', 'ADRA1L1', 'ALPHA1AAR'], description='adrenoceptor alpha 1A', other_designations='alpha-1A adrenergic receptor|G protein coupled receptor|alpha-1A adrenoceptor|alpha-1A adrenoreceptor|alpha-1C adrenergic receptor', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=26738113, end_position_on_the_genomic_accession=26870994, orientation='minus', exon_count=11, OMIM=[104221], no_hdr0=''),
    150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150, CurrentID=0, Status='live', Symbol='ADRA2A', Aliases=['ADRA2', 'ADRA2R', 'ADRAR', 'ALPHA2AAR', 'ZNF32'], description='adrenoceptor alpha 2A', other_designations='alpha-2A adrenergic receptor|adrenergic, alpha-2A-, receptor|alpha-2 adrenergic receptor subtype C10|alpha-2-adrenergic receptor, platelet type|alpha-2A adrenoceptor|alpha-2A adrenoreceptor|alpha-2AAR subtype C10', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=111077029, end_position_on_the_genomic_accession=111080907, orientation='plus', exon_count=1, OMIM=[104210], no_hdr0=''),
    151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151, CurrentID=0, Status='live', Symbol='ADRA2B', Aliases=['ADRA2L1', 'ADRA2RL1', 'ADRARL1', 'ALPHA2BAR', 'FAME2', 'alpha-2BAR'], description='adrenoceptor alpha 2B', other_designations='alpha-2B adrenergic receptor|ADRA2B adrenergic, alpha-2B-, receptor|G-protein coupled receptor|alpha-2 adrenergic receptor subtype C2|alpha-2-adrenergic receptor-like 1|alpha-2B adrenoreceptor', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96112876, end_position_on_the_genomic_accession=96116571, orientation='minus', exon_count=1, OMIM=[104260], no_hdr0=''),
    152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152, CurrentID=0, Status='live', Symbol='ADRA2C', Aliases=['ADRA2L2', 'ADRA2RL2', 'ADRARL2', 'ALPHA2CAR'], description='adrenoceptor alpha 2C', other_designations='alpha-2C adrenergic receptor|adrenergic, alpha-2C-, receptor|alpha-2 adrenergic receptor subtype C4|alpha-2C adrenoceptor|alpha-2C adrenoreceptor|alpha-2CAR|alpha2-AR-C4', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3766385, end_position_on_the_genomic_accession=3768526, orientation='plus', exon_count=1, OMIM=[104250], no_hdr0=''),
    153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153, CurrentID=0, Status='live', Symbol='ADRB1', Aliases=['ADRB1R', 'B1AR', 'BETA1AR', 'FNSS2', 'RHR'], description='adrenoceptor beta 1', other_designations='beta-1 adrenergic receptor|adrenergic, beta-1-, receptor|beta-1 adrenoceptor|beta-1 adrenoreceptor', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114043866, end_position_on_the_genomic_accession=114046904, orientation='plus', exon_count=1, OMIM=[109630], no_hdr0=''),
    154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154, CurrentID=0, Status='live', Symbol='ADRB2', Aliases=['ADRB2R', 'ADRBR', 'B2AR', 'BAR', 'BETA2AR'], description='adrenoceptor beta 2', other_designations='beta-2 adrenergic receptor|adrenergic, beta-2-, receptor, surface|adrenoceptor beta 2 surface|beta-2 adrenoceptor|beta-2 adrenoreceptor|catecholamine receptor', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148826611, end_position_on_the_genomic_accession=148828623, orientation='plus', exon_count=1, OMIM=[109690], no_hdr0=''),
    155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155, CurrentID=0, Status='live', Symbol='ADRB3', Aliases=['BETA3AR'], description='adrenoceptor beta 3', other_designations='beta-3 adrenergic receptor|adrenergic, beta-3-, receptor|beta-3 adrenoceptor|beta-3 adrenoreceptor', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37962990, end_position_on_the_genomic_accession=37966599, orientation='minus', exon_count=2, OMIM=[109691], no_hdr0=''),
    156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=156, CurrentID=0, Status='live', Symbol='GRK2', Aliases=['ADRBK1', 'BARK1', 'BETA-ARK1'], description='G protein-coupled receptor kinase 2', other_designations='beta-adrenergic receptor kinase 1|adrenergic beta receptor kinase 1|beta-ARK-1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67266420, end_position_on_the_genomic_accession=67286556, orientation='plus', exon_count=23, OMIM=[109635], no_hdr0=''),
    157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157, CurrentID=0, Status='live', Symbol='GRK3', Aliases=['ADRBK2', 'BARK2'], description='G protein-coupled receptor kinase 3', other_designations='beta-adrenergic receptor kinase 2|adrenergic, beta, receptor kinase 2|beta-ARK-2', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=25564675, end_position_on_the_genomic_accession=25729294, orientation='plus', exon_count=23, OMIM=[109636], no_hdr0=''),
    158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158, CurrentID=0, Status='live', Symbol='ADSL', Aliases=['AMPS', 'ASASE', 'ASL'], description='adenylosuccinate lyase', other_designations='adenylosuccinate lyase|adenylosuccinase', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40346500, end_position_on_the_genomic_accession=40387527, orientation='plus', exon_count=14, OMIM=[608222], no_hdr0=''),
    159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159, CurrentID=0, Status='live', Symbol='ADSS2', Aliases=['ADEH', 'ADSS', 'ADSS 2'], description='adenylosuccinate synthase 2', other_designations='adenylosuccinate synthetase isozyme 2|AMPSase 2|IMP--aspartate ligase 2|L-type adenylosuccinate synthetase|adenylosuccinate synthetase (Ade(-)H-complementing)|adenylosuccinate synthetase, acidic isozyme|adenylosuccinate synthetase, liver isozyme|epididymis secretory sperm binding protein', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244408494, end_position_on_the_genomic_accession=244452060, orientation='minus', exon_count=14, OMIM=[103060], no_hdr0=''),
    160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160, CurrentID=0, Status='live', Symbol='AP2A1', Aliases=['ADTAA', 'AP2-ALPHA', 'CLAPA1'], description='adaptor related protein complex 2 subunit alpha 1', other_designations='AP-2 complex subunit alpha-1|100 kDa coated vesicle protein A|adapter-related protein complex 2 alpha-1 subunit|adapter-related protein complex 2 subunit alpha-1|adaptin, alpha A|adaptor protein complex AP-2 subunit alpha-1|adaptor related protein complex 2 alpha 1 subunit|alpha-adaptin A|alpha1-adaptin|clathrin assembly protein complex 2 alpha-A large chain|clathrin-associated/assembly/adaptor protein, large, alpha 1|plasma membrane adaptor HA2/AP2 adaptin alpha A subunit', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49767001, end_position_on_the_genomic_accession=49807114, orientation='plus', exon_count=25, OMIM=[601026], no_hdr0=''),
    161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161, CurrentID=0, Status='live', Symbol='AP2A2', Aliases=['ADTAB', 'CLAPA2', 'HIP-9', 'HIP9', 'HYPJ'], description='adaptor related protein complex 2 subunit alpha 2', other_designations='AP-2 complex subunit alpha-2|100 kDa coated vesicle protein C|adapter-related protein complex 2 subunit alpha-2|adaptin, alpha B|adaptor related protein complex 2 alpha 2 subunit|alpha-adaptin C; Huntingtin interacting protein J|alpha2-adaptin|clathrin assembly protein complex 2 alpha-C large chain|clathrin-associated/assembly/adaptor protein, large, alpha 2|huntingtin yeast partner J|huntingtin-interacting protein 9|plasma membrane adaptor HA2/AP2 adaptin alpha C subunit', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=925850, end_position_on_the_genomic_accession=1012240, orientation='plus', exon_count=24, OMIM=[607242], no_hdr0=''),
    162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162, CurrentID=0, Status='live', Symbol='AP1B1', Aliases=['ADTB1', 'AP105A', 'BAM22', 'CLAPB2', 'KIDAR'], description='adaptor related protein complex 1 subunit beta 1', other_designations='AP-1 complex subunit beta-1|ADTB1, CLAPB2|Golgi adaptor HA1/AP1 adaptin beta subunit|adapter-related protein complex 1 subunit beta-1|adaptor protein complex AP-1 subunit beta-1|adaptor related protein complex 1 beta 1 subunit|beta-1-adaptin|beta-adaptin 1|beta-prime-adaptin|beta1-adaptin|clathrin assembly protein complex 1 beta large chain|plasma membrane adaptor HA2/AP2 adaptor beta subunit', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29327680, end_position_on_the_genomic_accession=29388570, orientation='minus', exon_count=23, OMIM=[600157], no_hdr0=''),
    163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163, CurrentID=0, Status='live', Symbol='AP2B1', Aliases=['ADTB2', 'AP105B', 'AP2-BETA', 'CLAPB1'], description='adaptor related protein complex 2 subunit beta 1', other_designations='AP-2 complex subunit beta|adapter-related protein complex 2 beta subunit|adapter-related protein complex 2 subunit beta|adaptin, beta 2 (beta)|adaptor protein complex AP-2 subunit beta|adaptor related protein complex 2 beta 1 subunit|adaptor-related protein complex 2 subunit beta|beta-2-adaptin|beta-adaptin|beta2-adaptin|clathrin assembly protein complex 2 beta large chain|clathrin-associated/assembly/adaptor protein, large, beta 1|plasma membrane adaptor HA2/AP2 adaptin beta subunit|testicular tissue protein Li 22', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35587265, end_position_on_the_genomic_accession=35726413, orientation='plus', exon_count=26, OMIM=[601025], no_hdr0=''),
    164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164, CurrentID=0, Status='live', Symbol='AP1G1', Aliases=['ADTG', 'CLAPG1'], description='adaptor related protein complex 1 subunit gamma 1', other_designations='AP-1 complex subunit gamma-1|adapter-related protein complex 1 subunit gamma-1|adaptor protein complex AP-1 subunit gamma-1|adaptor related protein complex 1 gamma 1 subunit|clathrin assembly protein complex 1 gamma large chain|clathrin assembly protein complex 1 gamma-1 large chain|clathrin-associated/assembly/adaptor protein, large, gamma 1|gamma adaptin|gamma1-adaptin|golgi adaptor HA1/AP1 adaptin gamma subunit|golgi adaptor HA1/AP1 adaptin subunit gamma-1|testicular tissue protein Li 21', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71729000, end_position_on_the_genomic_accession=71808834, orientation='minus', exon_count=24, OMIM=[603533], no_hdr0=''),
    165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165, CurrentID=0, Status='live', Symbol='AEBP1', Aliases=['ACLP'], description='AE binding protein 1', other_designations='adipocyte enhancer-binding protein 1|aortic carboxypeptidase-like protein', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44104320, end_position_on_the_genomic_accession=44114564, orientation='plus', exon_count=21, OMIM=[602981], no_hdr0=''),
    166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166, CurrentID=0, Status='live', Symbol='TLE5', Aliases=['AES', 'AES-1', 'AES-2', 'ESP1', 'GRG', 'GRG5', 'Grg-5'], description='TLE family member 5, transcriptional modulator', other_designations='TLE family member 5|amino-terminal enhancer of split|gp130-associated protein GAM|groucho-related protein 5', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3052910, end_position_on_the_genomic_accession=3063107, orientation='minus', exon_count=8, OMIM=[600188], no_hdr0=''),
    167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167, CurrentID=0, Status='live', Symbol='CRISP1', Aliases=['AEGL1', 'ARP', 'CRISP-1', 'HEL-S-57', 'HSCRISP1D', 'HSCRISP1G', 'HUMARP'], description='cysteine rich secretory protein 1', other_designations='cysteine-rich secretory protein 1|AEG-like protein|AEG-related protein|acidic epididymal glycoprotein homolog|acidic epididymal glycoprotein-like 1|cysteine-rich secretory protein-1 delta|epididymis secretory protein Li 57', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49833939, end_position_on_the_genomic_accession=49877096, orientation='minus', exon_count=11, OMIM=[601193], no_hdr0=''),
    173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=173, CurrentID=0, Status='live', Symbol='AFM', Aliases=['ALB2', 'ALBA', 'ALF'], description='afamin', other_designations='afamin|alpha-Alb|alpha-albumin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73481745, end_position_on_the_genomic_accession=73504001, orientation='plus', exon_count=15, OMIM=[104145], no_hdr0=''),
    174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=174, CurrentID=0, Status='live', Symbol='AFP', Aliases=['AFPD', 'FETA', 'HPAFP'], description='alpha fetoprotein', other_designations='alpha-fetoprotein|alpha-1-fetoprotein|alpha-fetoglobulin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73436221, end_position_on_the_genomic_accession=73456174, orientation='plus', exon_count=15, OMIM=[104150], no_hdr0=''),
    175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=175, CurrentID=0, Status='live', Symbol='AGA', Aliases=['AGU', 'ASRG', 'GA'], description='aspartylglucosaminidase', other_designations='N(4)-(beta-N-acetylglucosaminyl)-L-asparaginase|N4-(N-acetyl-beta-glucosaminyl)-L-asparagine amidase|aspartylglucosylamine deaspartylase|glycosylasparaginase', map_location='4q34.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=177430774, end_position_on_the_genomic_accession=177442469, orientation='minus', exon_count=9, OMIM=[613228], no_hdr0=''),
    176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=176, CurrentID=0, Status='live', Symbol='ACAN', Aliases=['AGC1', 'AGCAN', 'CSPG1', 'CSPGCP', 'MSK16', 'SEDK', 'SSOAOD'], description='aggrecan', other_designations='aggrecan core protein|cartilage-specific proteoglycan core protein|chondroitin sulfate proteoglycan core protein 1|large aggregating proteoglycan', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88803436, end_position_on_the_genomic_accession=88875353, orientation='plus', exon_count=19, OMIM=[155760], no_hdr0=''),
    177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=177, CurrentID=0, Status='live', Symbol='AGER', Aliases=['RAGE', 'SCARJ1', 'sRAGE'], description='advanced glycosylation end-product specific receptor', other_designations='advanced glycosylation end product-specific receptor|receptor for advanced glycation end-products variant 20', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32180969, end_position_on_the_genomic_accession=32184380, orientation='minus', exon_count=11, OMIM=[600214], no_hdr0=''),
    178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=178, CurrentID=0, Status='live', Symbol='AGL', Aliases=['GDE'], description='amylo-alpha-1, 6-glucosidase, 4-alpha-glucanotransferase', other_designations='glycogen debranching enzyme|amylo-1, 6-glucosidase, 4-alpha-glucanotransferase|amylo-alpha-1, 6-glucosidase, 4-alpha-glucanotransferaseprovided|glycogen debrancher|glycogen debranching protein', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=99850077, end_position_on_the_genomic_accession=99924023, orientation='plus', exon_count=37, OMIM=[610860], no_hdr0=''),
    181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=181, CurrentID=0, Status='live', Symbol='AGRP', Aliases=['AGRT', 'ART', 'ASIP2'], description='agouti related neuropeptide', other_designations='agouti-related protein|agouti related protein homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67482571, end_position_on_the_genomic_accession=67483547, orientation='minus', exon_count=4, OMIM=[602311], no_hdr0=''),
    182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=182, CurrentID=0, Status='live', Symbol='JAG1', Aliases=['AGS', 'AGS1', 'AHD', 'AWS', 'CD339', 'DCHE', 'HJ1', 'JAGL1'], description='jagged canonical Notch ligand 1', other_designations='protein jagged-1', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=10637684, end_position_on_the_genomic_accession=10673999, orientation='minus', exon_count=26, OMIM=[601920], no_hdr0=''),
    183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=183, CurrentID=0, Status='live', Symbol='AGT', Aliases=['ANHU', 'SERPINA8', 'hFLT1'], description='angiotensinogen', other_designations='angiotensinogen|alpha-1 antiproteinase, antitrypsin|angiotensin I|angiotensin II|fetal-liver predominant transporter 1|pre-angiotensinogen|serine (or cysteine) proteinase inhibitor|serpin A8|serpin peptidase inhibitor, clade A, member 8', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230702523, end_position_on_the_genomic_accession=230745583, orientation='minus', exon_count=6, OMIM=[106150], no_hdr0=''),
    185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=185, CurrentID=0, Status='live', Symbol='AGTR1', Aliases=['AG2SB', 'AT1', 'AT1AR', 'AT1B', 'AT1BR', 'AT1R', 'AT2R1', 'HAT1R', 'AGTR1'], description='angiotensin II receptor type 1', other_designations='type-1 angiotensin II receptor|type-1B angiotensin II receptor', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=148697903, end_position_on_the_genomic_accession=148743003, orientation='plus', exon_count=5, OMIM=[106165], no_hdr0=''),
    186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=186, CurrentID=0, Status='live', Symbol='AGTR2', Aliases=['AT2', 'ATGR2', 'MRX88'], description='angiotensin II receptor type 2', other_designations='type-2 angiotensin II receptor|angiotensin II type-2 receptor', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=116170744, end_position_on_the_genomic_accession=116174974, orientation='plus', exon_count=3, OMIM=[300034], no_hdr0=''),
    187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=187, CurrentID=0, Status='live', Symbol='APLNR', Aliases=['AGTRL1', 'APJ', 'APJR', 'HG11'], description='apelin receptor', other_designations='apelin receptor|APJ (apelin) receptor|APJ receptor|G protein-coupled receptor APJ|G-protein coupled receptor HG11|HG11 orphan receptor|angiotensin II receptor-like 1|angiotensin receptor-like 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57233591, end_position_on_the_genomic_accession=57237250, orientation='minus', exon_count=1, OMIM=[600052], no_hdr0=''),
    189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=189, CurrentID=0, Status='live', Symbol='AGXT', Aliases=['AGT', 'AGT11', 'PH1', 'SPAT', 'SPT', 'TLH6', 'AGXT'], description='alanine--glyoxylate and serine--pyruvate aminotransferase', other_designations='serine--pyruvate aminotransferase|L-alanine: glyoxylate aminotransferase 1|alanine-glyoxylate aminotransferase|hepatic peroxisomal alanine:glyoxylate aminotransferase', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240868824, end_position_on_the_genomic_accession=240880500, orientation='plus', exon_count=11, OMIM=[604285], no_hdr0=''),
    190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=190, CurrentID=0, Status='live', Symbol='NR0B1', Aliases=['AHC', 'AHCH', 'AHX', 'DAX-1', 'DAX1', 'DSS', 'GTD', 'HHG', 'NROB1', 'SRXY2'], description='nuclear receptor subfamily 0 group B member 1', other_designations='nuclear receptor subfamily 0 group B member 1|DSS-AHC critical region on the X chromosome protein 1|nuclear hormone receptor|nuclear receptor DAX-1|truncated nuclear receptor subfamily 0 group B member 1', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30304206, end_position_on_the_genomic_accession=30309390, orientation='minus', exon_count=2, OMIM=[300473], no_hdr0=''),
    191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=191, CurrentID=0, Status='live', Symbol='AHCY', Aliases=['SAHH', 'adoHcyase'], description='adenosylhomocysteinase', other_designations='adenosylhomocysteinase|S-adenosyl-L-homocysteine hydrolase|S-adenosylhomocysteine hydrolase|epididymis secretory sperm binding protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34235012, end_position_on_the_genomic_accession=34311976, orientation='minus', exon_count=17, OMIM=[180960], no_hdr0=''),
    196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196, CurrentID=0, Status='live', Symbol='AHR', Aliases=['RP85', 'bHLHe76'], description='aryl hydrocarbon receptor', other_designations='aryl hydrocarbon receptor|AH-receptor|ah receptor|aromatic hydrocarbon receptor|class E basic helix-loop-helix protein 76', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=17298652, end_position_on_the_genomic_accession=17346147, orientation='plus', exon_count=11, OMIM=[600253], no_hdr0=''),
    197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197, CurrentID=0, Status='live', Symbol='AHSG', Aliases=['A2HS', 'AHS', 'APMR1', 'FETUA', 'HSGA'], description='alpha 2-HS glycoprotein', other_designations='alpha-2-HS-glycoprotein|alpha-2-Z-globulin|ba-alpha-2-glycoprotein|fetuin-A', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186613060, end_position_on_the_genomic_accession=186621318, orientation='plus', exon_count=7, OMIM=[138680], no_hdr0=''),
    199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199, CurrentID=0, Status='live', Symbol='AIF1', Aliases=['AIF-1', 'IBA1', 'IRT-1', 'IRT1'], description='allograft inflammatory factor 1', other_designations='allograft inflammatory factor 1|interferon gamma responsive transcript|ionized calcium-binding adapter molecule 1|protein G1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31615212, end_position_on_the_genomic_accession=31617015, orientation='plus', exon_count=5, OMIM=[601833], no_hdr0=''),
    202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202, CurrentID=0, Status='live', Symbol='CRYBG1', Aliases=['AIM1', 'ST4'], description='crystallin beta-gamma domain containing 1', other_designations='beta/gamma crystallin domain-containing protein 1|absent in melanoma 1 protein|beta-gamma crystallin domain containing 1|suppression of tumorigenicity 4 (malignant melanoma)', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106360717, end_position_on_the_genomic_accession=106572017, orientation='plus', exon_count=22, OMIM=[601797], no_hdr0=''),
    203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203, CurrentID=0, Status='live', Symbol='AK1', Aliases=['HTL-S-58j'], description='adenylate kinase 1', other_designations='adenylate kinase isoenzyme 1|ATP-AMP transphosphorylase 1|ATP:AMP phosphotransferase|adenylate monophosphate kinase|epididymis secretory sperm binding protein|myokinase|testis secretory sperm binding protein Li 58j', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127866480, end_position_on_the_genomic_accession=127885542, orientation='minus', exon_count=10, OMIM=[103000], no_hdr0=''),
    204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204, CurrentID=0, Status='live', Symbol='AK2', Aliases=['ADK2'], description='adenylate kinase 2', other_designations='adenylate kinase 2, mitochondrial|ATP-AMP transphosphorylase 2|ATP:AMP phosphotransferase|adenylate kinase isoenzyme 2, mitochondrial|adenylate monophosphate kinase|testis secretory sperm-binding protein Li 220n', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33007940, end_position_on_the_genomic_accession=33036883, orientation='minus', exon_count=9, OMIM=[103020], no_hdr0=''),
    205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205, CurrentID=0, Status='live', Symbol='AK4', Aliases=['AK 4', 'AK3', 'AK3L1', 'AK3L2'], description='adenylate kinase 4', other_designations='adenylate kinase 4, mitochondrial|ATP-AMP transphosphorylase|GTP:AMP phosphotransferase AK4, mitochondrial|adenylate kinase 3-like 1|adenylate kinase isoenzyme 4, mitochondrial|epididymis secretory sperm binding protein|mitochondrial adenylate kinase-3|nucleoside-triphosphate-adenylate kinase', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65147342, end_position_on_the_genomic_accession=65232145, orientation='plus', exon_count=8, OMIM=[103030], no_hdr0=''),
    207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=207, CurrentID=0, Status='live', Symbol='AKT1', Aliases=['AKT', 'PKB', 'PKB-ALPHA', 'PRKBA', 'RAC', 'RAC-ALPHA'], description='AKT serine/threonine kinase 1', other_designations='RAC-alpha serine/threonine-protein kinase|AKT1m|PKB alpha|RAC-PK-alpha|protein kinase B alpha|proto-oncogene c-Akt|rac protein kinase alpha|serine-threonine protein kinase|v-akt murine thymoma viral oncogene homolog 1|v-akt murine thymoma viral oncogene-like protein 1', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104769349, end_position_on_the_genomic_accession=104795748, orientation='minus', exon_count=15, OMIM=[164730], no_hdr0=''),
    208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=208, CurrentID=0, Status='live', Symbol='AKT2', Aliases=['HIHGHH', 'PKBB', 'PKBBETA', 'PRKBB', 'RAC-BETA'], description='AKT serine/threonine kinase 2', other_designations='RAC-beta serine/threonine-protein kinase|PKB beta|RAC-PK-beta|murine thymoma viral (v-akt) homolog-2|protein kinase Akt-2|protein kinase B beta|putative v-akt murine thymoma viral oncoprotein 2|rac protein kinase beta|v-akt murine thymoma viral oncogene homolog 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40230317, end_position_on_the_genomic_accession=40285531, orientation='minus', exon_count=22, OMIM=[164731], no_hdr0=''),
    210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=210, CurrentID=0, Status='live', Symbol='ALAD', Aliases=['ALADH', 'PBGS'], description='aminolevulinate dehydratase', other_designations='delta-aminolevulinic acid dehydratase|aminolevulinate, delta-, dehydratase|porphobilinogen synthase|testicular tissue protein Li 95', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113386312, end_position_on_the_genomic_accession=113401301, orientation='minus', exon_count=14, OMIM=[125270], no_hdr0=''),
    211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=211, CurrentID=0, Status='live', Symbol='ALAS1', Aliases=['ALAS', 'ALAS-H', 'ALAS3', 'ALASH', 'MIG4'], description="5'-aminolevulinate synthase 1", other_designations='5-aminolevulinate synthase, nonspecific, mitochondrial|5-aminolevulinic acid synthase 1|aminolevulinate, delta-, synthase 1|delta-ALA synthase 1|delta-aminolevulinate synthase 1|migration-inducing protein 4', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52198083, end_position_on_the_genomic_accession=52214327, orientation='plus', exon_count=12, OMIM=[125290], no_hdr0=''),
    212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=212, CurrentID=0, Status='live', Symbol='ALAS2', Aliases=['ALAS-E', 'ALASE', 'ANH1', 'ASB', 'SIDBA1', 'XLDPP', 'XLEPP', 'XLSA'], description="5'-aminolevulinate synthase 2", other_designations='5-aminolevulinate synthase, erythroid-specific, mitochondrial|5-aminolevulinic acid synthase 2|aminolevulinate, delta-, synthase 2|delta-ALA synthase 2|delta-ALA synthetase|delta-aminolevulinate synthase 2', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55009055, end_position_on_the_genomic_accession=55030977, orientation='minus', exon_count=12, OMIM=[301300], no_hdr0=''),
    213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=213, CurrentID=0, Status='live', Symbol='ALB', Aliases=['FDAHT', 'HSA', 'PRO0883', 'PRO0903', 'PRO1341'], description='albumin', other_designations='albumin|serum albumin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73404287, end_position_on_the_genomic_accession=73421482, orientation='plus', exon_count=15, OMIM=[103600], no_hdr0=''),
    214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=214, CurrentID=0, Status='live', Symbol='ALCAM', Aliases=['CD166', 'MEMD'], description='activated leukocyte cell adhesion molecule', other_designations='CD166 antigen', map_location='3q13.11', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=105366909, end_position_on_the_genomic_accession=105576900, orientation='plus', exon_count=16, OMIM=[601662], no_hdr0=''),
    215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=215, CurrentID=0, Status='live', Symbol='ABCD1', Aliases=['ABC42', 'ALD', 'ALDP', 'AMN'], description='ATP binding cassette subfamily D member 1', other_designations='ATP-binding cassette sub-family D member 1|ATP-binding cassette, sub-family D (ALD), member 1|adrenoleukodystrophy protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153724851, end_position_on_the_genomic_accession=153744755, orientation='plus', exon_count=11, OMIM=[300371], no_hdr0=''),
    216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=216, CurrentID=0, Status='live', Symbol='ALDH1A1', Aliases=['ALDC', 'ALDH-E1', 'ALDH1', 'ALDH11', 'HEL-9', 'HEL-S-53e', 'HEL12', 'PUMB1', 'RALDH1'], description='aldehyde dehydrogenase 1 family member A1', other_designations='retinal dehydrogenase 1|ALDH class 1|ALHDII|RALDH 1|acetaldehyde dehydrogenase 1|aldehyde dehydrogenase 1, soluble|aldehyde dehydrogenase, liver cytosolic|epididymis luminal protein 12|epididymis luminal protein 9|epididymis secretory sperm binding protein Li 53e|retinaldehyde dehydrogenase 1', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=72900671, end_position_on_the_genomic_accession=72953053, orientation='minus', exon_count=13, OMIM=[100640], no_hdr0=''),
    217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=217, CurrentID=0, Status='live', Symbol='ALDH2', Aliases=['ALDH-E2', 'ALDHI', 'ALDM'], description='aldehyde dehydrogenase 2 family member', other_designations='aldehyde dehydrogenase, mitochondrial|ALDH class 2|acetaldehyde dehydrogenase 2|aldehyde dehydrogenase 2 family (mitochondrial)|epididymis secretory sperm binding protein|liver mitochondrial ALDH|nucleus-encoded mitochondrial aldehyde dehydrogenase 2', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111766933, end_position_on_the_genomic_accession=111817532, orientation='plus', exon_count=13, OMIM=[100650], no_hdr0=''),
    218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=218, CurrentID=0, Status='live', Symbol='ALDH3A1', Aliases=['ALDH3', 'ALDHIII'], description='aldehyde dehydrogenase 3 family member A1', other_designations='aldehyde dehydrogenase, dimeric NADP-preferring|aldehyde dehydrogenase isozyme 3|aldehyde dehydrogenase type III|stomach aldehyde dehydrogenase', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19737984, end_position_on_the_genomic_accession=19748390, orientation='minus', exon_count=12, OMIM=[100660], no_hdr0=''),
    219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219, CurrentID=0, Status='live', Symbol='ALDH1B1', Aliases=['ALDH5', 'ALDHX'], description='aldehyde dehydrogenase 1 family member B1', other_designations='aldehyde dehydrogenase X, mitochondrial|ALDH class 2|acetaldehyde dehydrogenase 5|aldehyde dehydrogenase 5|epididymis secretory sperm binding protein', map_location='9p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=38392702, end_position_on_the_genomic_accession=38398665, orientation='plus', exon_count=3, OMIM=[100670], no_hdr0=''),
    220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220, CurrentID=0, Status='live', Symbol='ALDH1A3', Aliases=['ALDH1A6', 'ALDH6', 'MCOP8', 'RALDH3'], description='aldehyde dehydrogenase 1 family member A3', other_designations='aldehyde dehydrogenase family 1 member A3|acetaldehyde dehydrogenase 6|aldehyde dehydrogenase 6|retinaldehyde dehydrogenase 3', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=100879831, end_position_on_the_genomic_accession=100916626, orientation='plus', exon_count=13, OMIM=[600463], no_hdr0=''),
    221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221, CurrentID=0, Status='live', Symbol='ALDH3B1', Aliases=['ALDH4', 'ALDH7'], description='aldehyde dehydrogenase 3 family member B1', other_designations='aldehyde dehydrogenase family 3 member B1|aldehyde dehydrogenase 3B1|aldehyde dehydrogenase 7', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68008547, end_position_on_the_genomic_accession=68029276, orientation='plus', exon_count=11, OMIM=[600466], no_hdr0=''),
    222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222, CurrentID=0, Status='live', Symbol='ALDH3B2', Aliases=['ALDH8'], description='aldehyde dehydrogenase 3 family member B2', other_designations='aldehyde dehydrogenase family 3 member B2|acetaldehyde dehydrogenase 8|aldehyde dehydrogenase 8', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67662155, end_position_on_the_genomic_accession=67681252, orientation='minus', exon_count=12, OMIM=[601917], no_hdr0=''),
    223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=223, CurrentID=0, Status='live', Symbol='ALDH9A1', Aliases=['ALDH4', 'ALDH7', 'ALDH9', 'E3', 'TMABA-DH', 'TMABADH', 'TMABALDH'], description='aldehyde dehydrogenase 9 family member A1', other_designations='4-trimethylaminobutyraldehyde dehydrogenase|R-aminobutyraldehyde dehydrogenase|aldehyde dehydrogenase (NAD+)|aldehyde dehydrogenase E3 isozyme|aldehyde dehydrogenase family 9 member A1|gamma-aminobutyraldehyde dehydrogenase', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165662216, end_position_on_the_genomic_accession=165698562, orientation='minus', exon_count=11, OMIM=[602733], no_hdr0=''),
    224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=224, CurrentID=0, Status='live', Symbol='ALDH3A2', Aliases=['ALDH10', 'FALDH', 'SLS'], description='aldehyde dehydrogenase 3 family member A2', other_designations='aldehyde dehydrogenase family 3 member A2|aldehyde dehydrogenase 10|fatty aldehyde dehydrogenase|microsomal aldehyde dehydrogenase', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19648136, end_position_on_the_genomic_accession=19677596, orientation='plus', exon_count=14, OMIM=[609523], no_hdr0=''),
    225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=225, CurrentID=0, Status='live', Symbol='ABCD2', Aliases=['ABC39', 'ALDL1', 'ALDR', 'ALDRP', 'hALDR'], description='ATP binding cassette subfamily D member 2', other_designations='ATP-binding cassette sub-family D member 2|ATP-binding cassette, sub-family D (ALD), member 2|adrenoleukodystrophy-like 1|adrenoleukodystrophy-related protein', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=39530965, end_position_on_the_genomic_accession=39651333, orientation='minus', exon_count=13, OMIM=[601081], no_hdr0=''),
    226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=226, CurrentID=0, Status='live', Symbol='ALDOA', Aliases=['ALDA', 'GSD12', 'HEL-S-87p'], description='aldolase, fructose-bisphosphate A', other_designations='fructose-bisphosphate aldolase A|aldolase A, fructose-bisphosphate|epididymis secretory sperm binding protein Li 87p|fructose-1,6-bisphosphate triosephosphate-lyase|lung cancer antigen NY-LU-1|muscle-type aldolase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30064279, end_position_on_the_genomic_accession=30070420, orientation='plus', exon_count=11, OMIM=[103850], no_hdr0=''),
    229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=229, CurrentID=0, Status='live', Symbol='ALDOB', Aliases=['ALDB', 'ALDO2'], description='aldolase, fructose-bisphosphate B', other_designations='fructose-bisphosphate aldolase B|aldolase 2|aldolase B, fructose-bisphosphatase|aldolase B, fructose-bisphosphate|liver-type aldolase', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101420560, end_position_on_the_genomic_accession=101435774, orientation='minus', exon_count=9, OMIM=[612724], no_hdr0=''),
    230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=230, CurrentID=0, Status='live', Symbol='ALDOC', Aliases=['ALDC'], description='aldolase, fructose-bisphosphate C', other_designations='fructose-bisphosphate aldolase C|aldolase 3|aldolase C, fructose-bisphosphate|brain-type aldolase|epididymis secretory sperm binding protein|fructoaldolase C|fructose-1,6-biphosphate triosephosphate lyase', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28573115, end_position_on_the_genomic_accession=28576963, orientation='minus', exon_count=10, OMIM=[103870], no_hdr0=''),
    231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=231, CurrentID=0, Status='live', Symbol='AKR1B1', Aliases=['ADR', 'ALDR1', 'ALR2', 'AR'], description='aldo-keto reductase family 1 member B', other_designations='aldo-keto reductase family 1 member B1|Lii5-2 CTCL tumor antigen|aldehyde reductase 1|aldose reductase|low Km aldose reductase', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134442350, end_position_on_the_genomic_accession=134459239, orientation='minus', exon_count=11, OMIM=[103880], no_hdr0=''),
    238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=238, CurrentID=0, Status='live', Symbol='ALK', Aliases=['CD246', 'NBLST3'], description='ALK receptor tyrosine kinase', other_designations='ALK tyrosine kinase receptor|CD246 antigen|anaplastic lymphoma receptor tyrosine kinase|mutant anaplastic lymphoma kinase', map_location='2p23.2-p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=29190992, end_position_on_the_genomic_accession=29921589, orientation='minus', exon_count=29, OMIM=[105590], no_hdr0=''),
    239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=239, CurrentID=0, Status='live', Symbol='ALOX12', Aliases=['12-LOX', '12S-LOX', 'LOG12'], description='arachidonate 12-lipoxygenase, 12S type', other_designations='polyunsaturated fatty acid lipoxygenase ALOX12|12S-lipoxygenase|Arachidonate 12-lipoxygenase, 12S-type|arachidonate (12S)-lipoxygenase|arachidonate (15S)-lipoxygenase|arachidonate 15-lipoxygenase,15S-type|linoleate 13S-lipoxygenase|lipoxin synthase 12-LO|platelet 12-LOX|platelet-type 12-lipoxygenase|platelet-type lipoxygenase 12', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6993791, end_position_on_the_genomic_accession=7010754, orientation='plus', exon_count=14, OMIM=[152391], no_hdr0=''),
    240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=240, CurrentID=0, Status='live', Symbol='ALOX5', Aliases=['5-LO', '5-LOX', '5LPG', 'LOG5'], description='arachidonate 5-lipoxygenase', other_designations='polyunsaturated fatty acid 5-lipoxygenase|LOX-5|arachidonic acid 5-lipoxygenase|leukotriene A4 synthase', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45374209, end_position_on_the_genomic_accession=45446121, orientation='plus', exon_count=13, OMIM=[152390], no_hdr0=''),
    241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=241, CurrentID=0, Status='live', Symbol='ALOX5AP', Aliases=['FLAP'], description='arachidonate 5-lipoxygenase activating protein', other_designations='arachidonate 5-lipoxygenase-activating protein|MK-886-binding protein', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30713485, end_position_on_the_genomic_accession=30764426, orientation='plus', exon_count=7, OMIM=[603700], no_hdr0=''),
    242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=242, CurrentID=0, Status='live', Symbol='ALOX12B', Aliases=['12R-LOX', 'ARCI2'], description='arachidonate 12-lipoxygenase, 12R type', other_designations='arachidonate 12-lipoxygenase, 12R-type|12R-lipoxygenase|epidermis-type lipoxygenase 12', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8072636, end_position_on_the_genomic_accession=8087716, orientation='minus', exon_count=15, OMIM=[603741], no_hdr0=''),
    246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246, CurrentID=0, Status='live', Symbol='ALOX15', Aliases=['12-LOX', '15-LOX', '15-LOX-1', 'LOG15'], description='arachidonate 15-lipoxygenase', other_designations='polyunsaturated fatty acid lipoxygenase ALOX15|12/15-lipoxygenase|15-LOX type 1|15-lipooxygenase-1|15-lipoxygenase type 1|arachidonate 12-lipoxygenase, leukocyte-type|arachidonate omega-6 lipoxygenase|hepoxilin A3 synthase Alox15|linoleate 13S-lipoxygenase', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4630919, end_position_on_the_genomic_accession=4641678, orientation='minus', exon_count=14, OMIM=[152392], no_hdr0=''),
    247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=247, CurrentID=0, Status='live', Symbol='ALOX15B', Aliases=['15-LOX-2'], description='arachidonate 15-lipoxygenase type B', other_designations='polyunsaturated fatty acid lipoxygenase ALOX15B|15-LOX-B|15S-lipoxygenase|arachidonate 15-lipoxygenase 2|arachidonate 15-lipoxygenase type II|arachidonate 15-lipoxygenase, second type|arachidonate omega(6) lipoxygenase|linoleate 13-lipoxygenase 15-LOb', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8039059, end_position_on_the_genomic_accession=8049134, orientation='plus', exon_count=14, OMIM=[603697], no_hdr0=''),
    248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=248, CurrentID=0, Status='live', Symbol='ALPI', Aliases=['IAP'], description='alkaline phosphatase, intestinal', other_designations='intestinal-type alkaline phosphatase|Kasahara isozyme|alkaline phosphomonoesterase|glycerophosphatase|intestinal alkaline phosphatase', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232456153, end_position_on_the_genomic_accession=232460753, orientation='plus', exon_count=11, OMIM=[171740], no_hdr0=''),
    249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=249, CurrentID=0, Status='live', Symbol='ALPL', Aliases=['AP-TNAP', 'APTNAP', 'HOPS', 'HPPA', 'HPPC', 'HPPI', 'HPPO', 'TNALP', 'TNAP', 'TNSALP'], description='alkaline phosphatase, biomineralization associated', other_designations='alkaline phosphatase, tissue-nonspecific isozyme|alkaline phosphatase liver/bone/kidney isozyme|alkaline phosphatase, liver/bone/kidney|liver/bone/kidney-type alkaline phosphatase|tissue non-specific alkaline phosphatase|tissue-nonspecific ALP', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21508984, end_position_on_the_genomic_accession=21578412, orientation='plus', exon_count=14, OMIM=[171760], no_hdr0=''),
    250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=250, CurrentID=0, Status='live', Symbol='ALPP', Aliases=['ALP', 'ALPI', 'IAP', 'PALP', 'PLAP', 'PLAP-1'], description='alkaline phosphatase, placental', other_designations='alkaline phosphatase, placental type|Intestinal alkaline phosphatase|Intestinal-type alkaline phosphatase|alkaline phosphatase Regan isozyme|alkaline phosphomonoesterase|glycerophosphatase|placental alkaline phosphatase 1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232378751, end_position_on_the_genomic_accession=232382889, orientation='plus', exon_count=11, OMIM=[171800], no_hdr0=''),
    251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=251, CurrentID=0, Status='live', Symbol='ALPG', Aliases=['ALPPL', 'ALPPL2', 'GCAP'], description='alkaline phosphatase, germ cell', other_designations='alkaline phosphatase, germ cell type|ALP-1|Nagao isozyme|alkaline phosphatase Nagao isozyme|alkaline phosphatase, placental like 2|alkaline phosphatase, placental-like|germ cell alkaline phosphatase|placental-like alkaline phosphatase|testicular and thymus alkaline phosphatase', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232406844, end_position_on_the_genomic_accession=232410714, orientation='plus', exon_count=11, OMIM=[171810], no_hdr0=''),
    257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257, CurrentID=0, Status='live', Symbol='ALX3', Aliases=['FND', 'FND1'], description='ALX homeobox 3', other_designations='homeobox protein aristaless-like 3|aristaless-like homeobox 3|frontonasal dysplasia|proline-rich transcription factor ALX3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110059870, end_position_on_the_genomic_accession=110070672, orientation='minus', exon_count=4, OMIM=[606014], no_hdr0=''),
    258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=258, CurrentID=0, Status='live', Symbol='AMBN', Aliases=['AI1F'], description='ameloblastin', other_designations='ameloblastin|enamel matrix protein', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70592256, end_position_on_the_genomic_accession=70607288, orientation='plus', exon_count=13, OMIM=[601259], no_hdr0=''),
    259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259, CurrentID=0, Status='live', Symbol='AMBP', Aliases=['A1M', 'EDC1', 'HCP', 'HI30', 'IATIL', 'ITI', 'ITIL', 'ITILC', 'UTI'], description='alpha-1-microglobulin/bikunin precursor', other_designations='protein AMBP|bikunin|complex-forming glycoprotein heterogeneous in charge|growth-inhibiting protein 19|inter-alpha-trypsin inhibitor light chain|protein HC|trypstatin|uristatin|uronic-acid-rich protein', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114060127, end_position_on_the_genomic_accession=114078300, orientation='minus', exon_count=10, OMIM=[176870], no_hdr0=''),
    262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=262, CurrentID=0, Status='live', Symbol='AMD1', Aliases=['ADOMETDC', 'AMD', 'SAMDC'], description='adenosylmethionine decarboxylase 1', other_designations='S-adenosylmethionine decarboxylase proenzyme|S-adenosylmethionine decarboxylase 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110814617, end_position_on_the_genomic_accession=110895713, orientation='plus', exon_count=11, OMIM=[180980], no_hdr0=''),
    265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=265, CurrentID=0, Status='live', Symbol='AMELX', Aliases=['AI1E', 'AIH1', 'ALGN', 'AMG', 'AMGL', 'AMGX'], description='amelogenin X-linked', other_designations='amelogenin, X isoform|amelogenin (X chromosome, amelogenesis imperfecta 1)|amelogenin (amelogenesis imperfecta 1, X-linked)', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=11293413, end_position_on_the_genomic_accession=11304149, orientation='plus', exon_count=7, OMIM=[300391], no_hdr0=''),
    266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266, CurrentID=0, Status='live', Symbol='AMELY', Aliases=['AMGL', 'AMGY'], description='amelogenin Y-linked', other_designations='amelogenin, Y isoform|amelogenin (Y chromosome)', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=6865918, end_position_on_the_genomic_accession=6911752, orientation='minus', exon_count=8, OMIM=[410000], no_hdr0=''),
    267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=267, CurrentID=0, Status='live', Symbol='AMFR', Aliases=['GP78', 'RNF45'], description='autocrine motility factor receptor', other_designations='E3 ubiquitin-protein ligase AMFR|RING finger protein 45|RING-type E3 ubiquitin transferase AMFR', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56361452, end_position_on_the_genomic_accession=56425545, orientation='minus', exon_count=17, OMIM=[603243], no_hdr0=''),
    268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=268, CurrentID=0, Status='live', Symbol='AMH', Aliases=['MIF', 'MIS'], description='anti-Mullerian hormone', other_designations='muellerian-inhibiting factor|Mullerian inhibiting factor|Mullerian inhibiting substance|anti-Muellerian hormone|muellerian-inhibiting substance', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2249323, end_position_on_the_genomic_accession=2252073, orientation='plus', exon_count=5, OMIM=[600957], no_hdr0=''),
    269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=269, CurrentID=0, Status='live', Symbol='AMHR2', Aliases=['AMHR', 'MISR2', 'MISRII', 'MRII'], description='anti-Mullerian hormone receptor type 2', other_designations='anti-Muellerian hormone type-2 receptor|AMH type II receptor|MIS type II receptor|Muellerian inhibiting substance type II receptor|Mullerian inhibiting substance type II receptor|anti-Muellerian hormone type II receptor|anti-Mullerian hormone receptor, type II', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53423855, end_position_on_the_genomic_accession=53431672, orientation='plus', exon_count=13, OMIM=[600956], no_hdr0=''),
    270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=270, CurrentID=0, Status='live', Symbol='AMPD1', Aliases=['MAD', 'MADA', 'MMDD'], description='adenosine monophosphate deaminase 1', other_designations='AMP deaminase 1|AMPD|adenosine monophosphate deaminase 1 (isoform M)|adenosine monophosphate deaminase-1 (muscle)|myoadenylate deaminase|skeletal muscle AMPD', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114673098, end_position_on_the_genomic_accession=114695546, orientation='minus', exon_count=16, OMIM=[102770], no_hdr0=''),
    271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=271, CurrentID=0, Status='live', Symbol='AMPD2', Aliases=['PCH9', 'SPG63'], description='adenosine monophosphate deaminase 2', other_designations='AMP deaminase 2|AMPD|adenosine monophosphate deaminase 2 (isoform L)', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109619837, end_position_on_the_genomic_accession=109632055, orientation='plus', exon_count=20, OMIM=[102771], no_hdr0=''),
    272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=272, CurrentID=0, Status='live', Symbol='AMPD3', Aliases=[], description='adenosine monophosphate deaminase 3', other_designations='AMP deaminase 3|AMP aminohydrolase|adenosine monophosphate deaminase (isoform E)|erythrocyte AMP deaminase|erythrocyte type AMP deaminase|erythrocyte-specific AMP deaminase|myoadenylate deaminase', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10450388, end_position_on_the_genomic_accession=10507579, orientation='plus', exon_count=19, OMIM=[102772], no_hdr0=''),
    273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=273, CurrentID=0, Status='live', Symbol='AMPH', Aliases=['AMPH1'], description='amphiphysin', other_designations='amphiphysin|amphiphysin (Stiff-Mann syndrome with breast cancer 128kD autoantigen)|amphiphysin I', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38383694, end_position_on_the_genomic_accession=38631497, orientation='minus', exon_count=23, OMIM=[600418], no_hdr0=''),
    274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=274, CurrentID=0, Status='live', Symbol='BIN1', Aliases=['AMPH2', 'AMPHL', 'CNM2', 'SH3P9'], description='bridging integrator 1', other_designations='myc box-dependent-interacting protein 1|amphiphysin II|amphiphysin-like protein|box dependant MYC interacting protein 1|box-dependent myc-interacting protein 1', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127048023, end_position_on_the_genomic_accession=127107154, orientation='minus', exon_count=22, OMIM=[601248], no_hdr0=''),
    275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=275, CurrentID=0, Status='live', Symbol='AMT', Aliases=['GCE', 'GCST', 'GCVT', 'NKH'], description='aminomethyltransferase', other_designations='aminomethyltransferase, mitochondrial|glycine cleavage system T protein|nonketotic hyperglycinemia', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49416778, end_position_on_the_genomic_accession=49422473, orientation='minus', exon_count=9, OMIM=[238310], no_hdr0=''),
    276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=276, CurrentID=0, Status='live', Symbol='AMY1A', Aliases=['AMY1'], description='amylase alpha 1A', other_designations='alpha-amylase 1A|1,4-alpha-D-glucan glucanohydrolase 1|alpha-amylase 1|amylase alpha 1A (salivary)|amylase, salivary, alpha-1A|glycogenase|salivary alpha-amylase|salivary amylase alpha 1A', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103655519, end_position_on_the_genomic_accession=103664554, orientation='plus', exon_count=12, OMIM=[104700], no_hdr0=''),
    277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=277, CurrentID=0, Status='live', Symbol='AMY1B', Aliases=['AMY1'], description='amylase alpha 1B', other_designations='alpha-amylase 1B|1,4-alpha-D-glucan glucanohydrolase 1|alpha-amylase 1|alpha-amylase 1A|amylase alpha 1B (salivary)|amylase, salivary, alpha-1B|glycogenase|salivary alpha-amylase|salivary amylase alpha 1B', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103687415, end_position_on_the_genomic_accession=103696453, orientation='minus', exon_count=12, OMIM=[104701], no_hdr0=''),
    278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=278, CurrentID=0, Status='live', Symbol='AMY1C', Aliases=['AMY1'], description='amylase alpha 1C', other_designations='alpha-amylase 1C|1,4-alpha-D-glucan glucanohydrolase 1|alpha-amylase 1|alpha-amylase 1A|amylase alpha 1C (salivary)|amylase, salivary, alpha-1C|glycogenase|salivary alpha-amylase|salivary amylase alpha 1C', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103745430, end_position_on_the_genomic_accession=103758692, orientation='plus', exon_count=13, OMIM=[104702], no_hdr0=''),
    279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=279, CurrentID=0, Status='live', Symbol='AMY2A', Aliases=['AMY2', 'PA'], description='amylase alpha 2A', other_designations='pancreatic alpha-amylase|1,4-alpha-D-glucan glucanohydrolase|amylase alpha 2A (pancreatic)|glycogenase|pancreatic amylase alpha 2A', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103617427, end_position_on_the_genomic_accession=103625780, orientation='plus', exon_count=10, OMIM=[104650], no_hdr0=''),
    280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=280, CurrentID=0, Status='live', Symbol='AMY2B', Aliases=['AMY2', 'AMY3', 'HXA'], description='amylase alpha 2B', other_designations='alpha-amylase 2B|1,4-alpha-D-glucan glucanohydrolase 2B|amylase alpha 2B (pancreatic)|carcinoid alpha-amylase|glycogenase', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103554644, end_position_on_the_genomic_accession=103579534, orientation='plus', exon_count=13, OMIM=[104660], no_hdr0=''),
    283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283, CurrentID=0, Status='live', Symbol='ANG', Aliases=['ALS9', 'HEL168', 'RAA1', 'RNASE4', 'RNASE5'], description='angiogenin', other_designations='angiogenin|RNase 5|angiogenin, ribonuclease, RNase A family, 5|epididymis luminal protein 168|ribonuclease 5|ribonuclease A A1|ribonuclease A family member 5', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20684177, end_position_on_the_genomic_accession=20694186, orientation='plus', exon_count=4, OMIM=[105850], no_hdr0=''),
    284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284, CurrentID=0, Status='live', Symbol='ANGPT1', Aliases=['AGP1', 'AGPT', 'ANG1', 'HAE5'], description='angiopoietin 1', other_designations='angiopoietin-1|ANG-1', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=107249482, end_position_on_the_genomic_accession=107497918, orientation='minus', exon_count=10, OMIM=[601667], no_hdr0=''),
    285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285, CurrentID=0, Status='live', Symbol='ANGPT2', Aliases=['AGPT2', 'ANG2', 'LMPHM10'], description='angiopoietin 2', other_designations='angiopoietin-2|Tie2-ligand|angiopoietin-2B|angiopoietin-2a', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6499632, end_position_on_the_genomic_accession=6563245, orientation='minus', exon_count=9, OMIM=[601922], no_hdr0=''),
    286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286, CurrentID=0, Status='live', Symbol='ANK1', Aliases=['ANK', 'SPH1', 'SPH2'], description='ankyrin 1', other_designations='ankyrin-1|ANK-1|ankyrin 1, erythrocytic|ankyrin-R|erythrocyte ankyrin', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41653225, end_position_on_the_genomic_accession=41896741, orientation='minus', exon_count=49, OMIM=[612641], no_hdr0=''),
    287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=287, CurrentID=0, Status='live', Symbol='ANK2', Aliases=['ANK-2', 'CFAP87', 'FAP87', 'LQT4', 'brank-2'], description='ankyrin 2', other_designations='ankyrin-2|ankyrin 2, neuronal|ankyrin B|ankyrin, brain|ankyrin-2, nonerythrocytic|non-erythroid ankyrin', map_location='4q25-q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112705622, end_position_on_the_genomic_accession=113383736, orientation='plus', exon_count=61, OMIM=[106410], no_hdr0=''),
    288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=288, CurrentID=0, Status='live', Symbol='ANK3', Aliases=['ANKYRIN-G', 'MRT37'], description='ankyrin 3', other_designations='ankyrin-3|ankyrin 3, node of Ranvier (ankyrin G)', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=60026298, end_position_on_the_genomic_accession=60733528, orientation='minus', exon_count=50, OMIM=[600465], no_hdr0=''),
    290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=290, CurrentID=0, Status='live', Symbol='ANPEP', Aliases=['APN', 'CD13', 'GP150', 'LAP1', 'P150', 'PEPN'], description='alanyl aminopeptidase, membrane', other_designations='aminopeptidase N|AP-M|AP-N|alanyl (membrane) aminopeptidase|aminopeptidase M|hAPN|membrane alanyl aminopeptidase|microsomal aminopeptidase|myeloid plasma membrane glycoprotein CD13', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89784895, end_position_on_the_genomic_accession=89814852, orientation='minus', exon_count=21, OMIM=[151530], no_hdr0=''),
    291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=291, CurrentID=0, Status='live', Symbol='SLC25A4', Aliases=['AAC1', 'ANT', 'ANT 1', 'ANT1', 'MTDPS12', 'MTDPS12A', 'PEO2', 'PEO3', 'PEOA2', 'T1'], description='solute carrier family 25 member 4', other_designations='ADP/ATP translocase 1|ADP,ATP carrier protein 1|ADP,ATP carrier protein, heart/skeletal muscle|adenine nucleotide translocator 1 (skeletal muscle)|heart/skeletal muscle ATP/ADP translocator|solute carrier family 25 (mitochondrial carrier; adenine nucleotide translocator), member 4', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185143266, end_position_on_the_genomic_accession=185150382, orientation='plus', exon_count=4, OMIM=[103220], no_hdr0=''),
    292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=292, CurrentID=0, Status='live', Symbol='SLC25A5', Aliases=['2F1', 'AAC2', 'ANT2', 'T2', 'T3'], description='solute carrier family 25 member 5', other_designations='ADP/ATP translocase 2|adenine nucleotide translocator 2 (fibroblast)|solute carrier family 25 (mitochondrial carrier; adenine nucleotide translocator), member 5', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119468444, end_position_on_the_genomic_accession=119471396, orientation='plus', exon_count=4, OMIM=[300150], no_hdr0=''),
    293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=293, CurrentID=0, Status='live', Symbol='SLC25A6', Aliases=['AAC3', 'ANT', 'ANT 2', 'ANT 3', 'ANT3', 'ANT3Y'], description='solute carrier family 25 member 6', other_designations='ADP/ATP translocase 3|ADP,ATP carrier protein 3|ADP,ATP carrier protein, liver|ADP/ATP translocator of liver|adenine nucleotide translocator 3|epididymis secretory sperm binding protein|solute carrier family 25 (mitochondrial carrier; adenine nucleotide translocator), member 6', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1386152, end_position_on_the_genomic_accession=1392113, orientation='minus', exon_count=4, OMIM=[300151, 403000], no_hdr0=''),
    301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=301, CurrentID=0, Status='live', Symbol='ANXA1', Aliases=['ANX1', 'LPC1'], description='annexin A1', other_designations='annexin A1|annexin I (lipocortin I)|annexin-1|calpactin II|calpactin-2|chromobindin-9|epididymis secretory sperm binding protein|phospholipase A2 inhibitory protein', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=73151865, end_position_on_the_genomic_accession=73170393, orientation='plus', exon_count=15, OMIM=[151690], no_hdr0=''),
    302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=302, CurrentID=0, Status='live', Symbol='ANXA2', Aliases=['ANX2', 'ANX2L4', 'CAL1H', 'HEL-S-270', 'LIP2', 'LPC2', 'LPC2D', 'P36', 'PAP-IV'], description='annexin A2', other_designations='annexin A2|annexin II|annexin-2|calpactin I heavy chain|calpactin I heavy polypeptide|calpactin-1 heavy chain|chromobindin 8|epididymis secretory protein Li 270|epididymis secretory sperm binding protein|lipocortin II|placental anticoagulant protein IV|protein I', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=60347151, end_position_on_the_genomic_accession=60398025, orientation='minus', exon_count=16, OMIM=[151740], no_hdr0=''),
    306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=306, CurrentID=0, Status='live', Symbol='ANXA3', Aliases=['ANX3'], description='annexin A3', other_designations='annexin A3|35-alpha calcimedin|Annexin III (lipocortin III)|PAP-III|annexin III (lipocortin III, 1,2-cyclic-inositol-phosphate phosphodiesterase, placental anticoagulant protein III, calcimedin 35-alpha)|annexin-3|calcimedin 35-alpha|inositol 1,2-cyclic phosphate 2-phosphohydrolase|lipocortin III|placental anticoagulant protein III', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=78551761, end_position_on_the_genomic_accession=78610447, orientation='plus', exon_count=14, OMIM=[106490], no_hdr0=''),
    307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=307, CurrentID=0, Status='live', Symbol='ANXA4', Aliases=['ANX4', 'HEL-S-274', 'P32.5', 'PAP-II', 'PIG28', 'PP4-X', 'ZAP36'], description='annexin A4', other_designations='annexin A4|35-beta calcimedin|annexin IV (placental anticoagulant protein II)|annexin-4|carbohydrate-binding protein p33/p41|chromobindin-4|endonexin I|epididymis secretory protein Li 274|lipocortin IV|placental anticoagulant protein II|proliferation-inducing gene 28|proliferation-inducing protein 28|protein II', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69643808, end_position_on_the_genomic_accession=69827112, orientation='plus', exon_count=20, OMIM=[106491], no_hdr0=''),
    308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=308, CurrentID=0, Status='live', Symbol='ANXA5', Aliases=['ANX5', 'ENX2', 'HEL-S-7', 'PP4', 'RPRGL3'], description='annexin A5', other_designations='annexin A5|CBP-I|PAP-I|VAC-alpha|anchorin CII|annexin V|annexin-5|calphobindin I|endonexin II|epididymis secretory protein Li 7|lipocortin V|placental anticoagulant protein 4|placental anticoagulant protein I|thromboplastin inhibitor|vascular anticoagulant-alpha', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121667946, end_position_on_the_genomic_accession=121696994, orientation='minus', exon_count=14, OMIM=[131230], no_hdr0=''),
    309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=309, CurrentID=0, Status='live', Symbol='ANXA6', Aliases=['ANX6', 'CBP68', 'CPB-II', 'p68', 'p70'], description='annexin A6', other_designations='annexin A6|67 kDa calelectrin|annexin VI (p68)|annexin-6|calcium-binding protein p68|calelectrin|calphobindin II|chromobindin-20|lipocortin VI|testis secretory sperm-binding protein Li 198a', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151100706, end_position_on_the_genomic_accession=151157779, orientation='minus', exon_count=27, OMIM=[114070], no_hdr0=''),
    310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=310, CurrentID=0, Status='live', Symbol='ANXA7', Aliases=['ANX7', 'SNX', 'SYNEXIN'], description='annexin A7', other_designations='annexin A7|annexin VII|annexin-7', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73375101, end_position_on_the_genomic_accession=73414058, orientation='minus', exon_count=15, OMIM=[186360], no_hdr0=''),
    311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=311, CurrentID=0, Status='live', Symbol='ANXA11', Aliases=['ALS23', 'ANX11', 'CAP-50', 'CAP50'], description='annexin A11', other_designations='annexin A11|56 kDa autoantigen|annexin XI|annexin-11|calcyclin-associated annexin 50|epididymis secretory sperm binding protein', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80150889, end_position_on_the_genomic_accession=80205808, orientation='minus', exon_count=20, OMIM=[602572], no_hdr0=''),
    312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=312, CurrentID=0, Status='live', Symbol='ANXA13', Aliases=['ANX13', 'ISA'], description='annexin A13', other_designations='annexin A13|annexin XIII|annexin, intestine-specific|annexin-13|intestine-specific annexin', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123680794, end_position_on_the_genomic_accession=123737393, orientation='minus', exon_count=12, OMIM=[602573], no_hdr0=''),
    313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=313, CurrentID=0, Status='live', Symbol='AOAH', Aliases=[], description='acyloxyacyl hydrolase', other_designations='acyloxyacyl hydrolase|acyloxyacyl hydrolase (neutrophil)', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=36509313, end_position_on_the_genomic_accession=36724544, orientation='minus', exon_count=31, OMIM=[102593], no_hdr0=''),
    314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=314, CurrentID=0, Status='live', Symbol='AOC2', Aliases=['DAO2', 'RAO', 'SSAO'], description='amine oxidase copper containing 2', other_designations='retina-specific copper amine oxidase|amine oxidase, copper containing 2 (retina-specific)|semicarbazide-sensitive amine oxidase', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42844580, end_position_on_the_genomic_accession=42850707, orientation='plus', exon_count=4, OMIM=[602268], no_hdr0=''),
    316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=316, CurrentID=0, Status='live', Symbol='AOX1', Aliases=['AO', 'AOH1'], description='aldehyde oxidase 1', other_designations='aldehyde oxidase|azaheterocycle hydroxylase', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200585952, end_position_on_the_genomic_accession=200677064, orientation='plus', exon_count=36, OMIM=[602841], no_hdr0=''),
    317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317, CurrentID=0, Status='live', Symbol='APAF1', Aliases=['APAF-1', 'CED4'], description='apoptotic peptidase activating factor 1', other_designations='apoptotic protease-activating factor 1', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=98645141, end_position_on_the_genomic_accession=98735433, orientation='plus', exon_count=28, OMIM=[602233], no_hdr0=''),
    318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=318, CurrentID=0, Status='live', Symbol='NUDT2', Aliases=['APAH1'], description='nudix hydrolase 2', other_designations="bis(5'-nucleosyl)-tetraphosphatase [asymmetrical]|Ap4A hydrolase 1|Ap4Aase|bis(5'-nucleosyl)-tetraphosphatase (asymmetrical)|diadenosine 5',5'''-P1,P4-tetraphosphate asymmetrical hydrolase|diadenosine 5',5''-P1,P4-tetraphosphate pyrophosphohydrolase|diadenosine tetraphosphatase|nucleoside diphosphate-linked moiety X motif 2|nudix (nucleoside diphosphate linked moiety X)-type motif 2|nudix motif 2", map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34329569, end_position_on_the_genomic_accession=34343713, orientation='plus', exon_count=6, OMIM=[602852], no_hdr0=''),
    319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=319, CurrentID=0, Status='live', Symbol='APOF', Aliases=['Apo-F', 'LTIP'], description='apolipoprotein F', other_designations='apolipoprotein F|lipid transfer inhibitor protein', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56360568, end_position_on_the_genomic_accession=56362857, orientation='minus', exon_count=2, OMIM=[107760], no_hdr0=''),
    320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=320, CurrentID=0, Status='live', Symbol='APBA1', Aliases=['D9S411E', 'LIN10', 'MINT1', 'X11', 'X11A', 'X11ALPHA'], description='amyloid beta precursor protein binding family A member 1', other_designations='amyloid-beta A4 precursor protein-binding family A member 1|adapter protein X11alpha|adaptor protein X11alpha|amyloid beta (A4) precursor protein-binding, family A, member 1 (X11)|mint-1|neuron-specific X11 protein|neuronal munc18-1-interacting protein 1|phosphotyrosine-binding/-interacting domain (PTB)-bearing protein', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69427532, end_position_on_the_genomic_accession=69673012, orientation='minus', exon_count=15, OMIM=[602414], no_hdr0=''),
    321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=321, CurrentID=0, Status='live', Symbol='APBA2', Aliases=['D15S1518E', 'HsT16821', 'LIN-10', 'MGC:14091', 'MINT2', 'X11-BETA', 'X11L'], description='amyloid beta precursor protein binding family A member 2', other_designations='amyloid-beta A4 precursor protein-binding family A member 2|X11-like protein|adapter protein X11beta|amyloid beta (A4) precursor protein-binding, family A, member 2 (X11-like)|mint-2|neuron-specific X11L protein|neuronal munc18-1-interacting protein 2|phosphotyrosine-binding/-interacting domain (PTB)-bearing protein', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28885479, end_position_on_the_genomic_accession=29118315, orientation='plus', exon_count=23, OMIM=[602712], no_hdr0=''),
    322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=322, CurrentID=0, Status='live', Symbol='APBB1', Aliases=['FE65', 'MGC:9072', 'RIR'], description='amyloid beta precursor protein binding family B member 1', other_designations='amyloid-beta A4 precursor protein-binding family B member 1|adaptor protein FE65a2|amyloid beta (A4) precursor protein-binding, family B, member 1 (Fe65)|stat-like protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6395124, end_position_on_the_genomic_accession=6419453, orientation='minus', exon_count=19, OMIM=[602709], no_hdr0=''),
    323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=323, CurrentID=0, Status='live', Symbol='APBB2', Aliases=['FE65L', 'FE65L1'], description='amyloid beta precursor protein binding family B member 2', other_designations='amyloid-beta A4 precursor protein-binding family B member 2|Fe65-like 1|protein Fe65-like 1', map_location='4p14-p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40810027, end_position_on_the_genomic_accession=41216714, orientation='minus', exon_count=23, OMIM=[602710], no_hdr0=''),
    324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=324, CurrentID=0, Status='live', Symbol='APC', Aliases=['BTPS2', 'DESMD', 'DP2', 'DP2.5', 'DP3', 'GS', 'PPP1R46'], description='APC regulator of WNT signaling pathway', other_designations='adenomatous polyposis coli protein|APC, WNT signaling pathway regulator|WNT signaling pathway regulator|adenomatosis polyposis coli tumor suppressor|adenomatous polyposis coli (APC)|deleted in polyposis 2.5|epididymis secretory sperm binding protein|protein phosphatase 1, regulatory subunit 46|truncated adenomatosis polyposis coli', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=112707498, end_position_on_the_genomic_accession=112846239, orientation='plus', exon_count=20, OMIM=[611731], no_hdr0=''),
    325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=325, CurrentID=0, Status='live', Symbol='APCS', Aliases=['HEL-S-92n', 'PTX2', 'SAP'], description='amyloid P component, serum', other_designations='serum amyloid P-component|9.5S alpha-1-glycoprotein|epididymis secretory sperm binding protein Li 92n|pentaxin-related|pentraxin-2|pentraxin-related', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159587826, end_position_on_the_genomic_accession=159588865, orientation='plus', exon_count=2, OMIM=[104770], no_hdr0=''),
    326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=326, CurrentID=0, Status='live', Symbol='AIRE', Aliases=['AIRE1', 'APECED', 'APS1', 'APSI', 'PGA1'], description='autoimmune regulator', other_designations='autoimmune regulator|autoimmune polyendocrinopathy candidiasis ectodermal dystrophy protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44285876, end_position_on_the_genomic_accession=44298648, orientation='plus', exon_count=14, OMIM=[607358], no_hdr0=''),
    327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=327, CurrentID=0, Status='live', Symbol='APEH', Aliases=['AARE', 'ACPH', 'APH', 'D3F15S2', 'D3S48E', 'DNF15S2', 'OPH'], description='acylaminoacyl-peptide hydrolase', other_designations='acylamino-acid-releasing enzyme|N-acylaminoacyl-peptide hydrolase|acyl-peptide hydrolase|acylaminoacyl-peptidase|oxidized protein hydrolase', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49673102, end_position_on_the_genomic_accession=49683971, orientation='plus', exon_count=22, OMIM=[102645], no_hdr0=''),
    328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=328, CurrentID=0, Status='live', Symbol='APEX1', Aliases=['APE', 'APE1', 'APEN', 'APEX', 'APX', 'HAP1', 'REF1'], description='apurinic/apyrimidinic endodeoxyribonuclease 1', other_designations='DNA-(apurinic or apyrimidinic site) endonuclease|AP endonuclease class I|AP lyase|APEX nuclease (multifunctional DNA repair enzyme) 1|DNA-(apurinic or apyrimidinic site) lyase|apurinic-apyrimidinic endonuclease 1|apurinic/apyrimidinic (abasic) endonuclease|deoxyribonuclease (apurinic or apyrimidinic)|protein REF-1|redox factor-1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20455226, end_position_on_the_genomic_accession=20457767, orientation='plus', exon_count=5, OMIM=[107748], no_hdr0=''),
    329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=329, CurrentID=0, Status='live', Symbol='BIRC2', Aliases=['API1', 'HIAP2', 'Hiap-2', 'MIHB', 'RNF48', 'c-IAP1', 'cIAP1'], description='baculoviral IAP repeat containing 2', other_designations='baculoviral IAP repeat-containing protein 2|IAP homolog B|IAP-2|NFR2-TRAF signalling complex protein|RING finger protein 48|RING-type E3 ubiquitin transferase BIRC2|TNFR2-TRAF-signaling complex protein 2|apoptosis inhibitor 1|cellular inhibitor of apoptosis 1|inhibitor of apoptosis protein 2', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102347214, end_position_on_the_genomic_accession=102378670, orientation='plus', exon_count=9, OMIM=[601712], no_hdr0=''),
    330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=330, CurrentID=0, Status='live', Symbol='BIRC3', Aliases=['AIP1', 'API2', 'CIAP2', 'HAIP1', 'HIAP1', 'IAP-1', 'MALT2', 'MIHC', 'RNF49', 'c-IAP2'], description='baculoviral IAP repeat containing 3', other_designations='baculoviral IAP repeat-containing protein 3|IAP homolog C|RING finger protein 49|RING-type E3 ubiquitin transferase BIRC3|TNFR2-TRAF signaling complex protein|TNFR2-TRAF-signaling complex protein 1|apoptosis inhibitor 2|cellular inhibitor of apoptosis 2|inhibitor of apoptosis protein 1|mammalian IAP homolog C', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102317373, end_position_on_the_genomic_accession=102339403, orientation='plus', exon_count=9, OMIM=[601721], no_hdr0=''),
    331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=331, CurrentID=0, Status='live', Symbol='XIAP', Aliases=['API3', 'BIRC4', 'IAP-3', 'ILP1', 'MIHA', 'XLP2', 'hIAP-3', 'hIAP3'], description='X-linked inhibitor of apoptosis', other_designations='E3 ubiquitin-protein ligase XIAP|IAP-like protein 1|RING-type E3 ubiquitin transferase XIAP|X-linked IAP|X-linked inhibitor of apoptosis, E3 ubiquitin protein ligase|baculoviral IAP repeat-containing protein 4|inhibitor of apoptosis protein 3', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=123859708, end_position_on_the_genomic_accession=123913972, orientation='plus', exon_count=10, OMIM=[300079], no_hdr0=''),
    332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=332, CurrentID=0, Status='live', Symbol='BIRC5', Aliases=['API4', 'EPR-1'], description='baculoviral IAP repeat containing 5', other_designations='baculoviral IAP repeat-containing protein 5|apoptosis inhibitor 4|apoptosis inhibitor survivin|survivin variant 3 alpha', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78214253, end_position_on_the_genomic_accession=78225635, orientation='plus', exon_count=6, OMIM=[603352], no_hdr0=''),
    333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=333, CurrentID=0, Status='live', Symbol='APLP1', Aliases=['APLP'], description='amyloid beta precursor like protein 1', other_designations='amyloid-like protein 1|amyloid beta (A4) precursor-like protein 1|amyloid precursor-like protein 1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35868570, end_position_on_the_genomic_accession=35879795, orientation='plus', exon_count=17, OMIM=[104775], no_hdr0=''),
    334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=334, CurrentID=0, Status='live', Symbol='APLP2', Aliases=['APLP-2', 'APPH', 'APPL2', 'CDEBP'], description='amyloid beta precursor like protein 2', other_designations='amyloid-like protein 2|CDEI box-binding protein|amyloid beta (A4) precursor-like protein 2|amyloid precursor protein homolog HSD-2|testicular tissue protein Li 23', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130069894, end_position_on_the_genomic_accession=130144805, orientation='plus', exon_count=20, OMIM=[104776], no_hdr0=''),
    335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=335, CurrentID=0, Status='live', Symbol='APOA1', Aliases=['HPALP2', 'apo(a)'], description='apolipoprotein A1', other_designations='apolipoprotein A-I|apo-AI|epididymis secretory sperm binding protein', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116835751, end_position_on_the_genomic_accession=116837950, orientation='minus', exon_count=4, OMIM=[107680], no_hdr0=''),
    336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=336, CurrentID=0, Status='live', Symbol='APOA2', Aliases=['Apo-AII', 'ApoA-II', 'apoAII'], description='apolipoprotein A2', other_designations='apolipoprotein A-II', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161222292, end_position_on_the_genomic_accession=161223628, orientation='minus', exon_count=4, OMIM=[107670], no_hdr0=''),
    337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337, CurrentID=0, Status='live', Symbol='APOA4', Aliases=[], description='apolipoprotein A4', other_designations='apolipoprotein A-IV|apo-AIV|apoA-IV', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116820700, end_position_on_the_genomic_accession=116823304, orientation='minus', exon_count=3, OMIM=[107690], no_hdr0=''),
    338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338, CurrentID=0, Status='live', Symbol='APOB', Aliases=['FCHL2', 'FLDB', 'LDLCQ4', 'apoB-100', 'apoB-48'], description='apolipoprotein B', other_designations='apolipoprotein B-100|apolipoprotein B (including Ag(x) antigen)|apolipoprotein B48', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=21001429, end_position_on_the_genomic_accession=21044073, orientation='minus', exon_count=29, OMIM=[107730], no_hdr0=''),
    339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339, CurrentID=0, Status='live', Symbol='APOBEC1', Aliases=['APOBEC-1', 'BEDP', 'CDAR1', 'HEPR'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 1', other_designations='C->U-editing enzyme APOBEC-1|apolipoprotein B mRNA editing enzyme complex-1|apolipoprotein B mRNA editing enzyme, catalytic polypeptide 1|apolipoprotein B mRNA-editing enzyme 1|mRNA(cytosine(6666)) deaminase 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7649400, end_position_on_the_genomic_accession=7670599, orientation='minus', exon_count=6, OMIM=[600130], no_hdr0=''),
    341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341, CurrentID=0, Status='live', Symbol='APOC1', Aliases=['Apo-CI', 'ApoC-I', 'apo-CIB', 'apoC-IB'], description='apolipoprotein C1', other_designations='apolipoprotein C-I', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44914325, end_position_on_the_genomic_accession=44919346, orientation='plus', exon_count=5, OMIM=[107710], no_hdr0=''),
    343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343, CurrentID=0, Status='live', Symbol='AQP8', Aliases=['AQP-8'], description='aquaporin 8', other_designations='aquaporin-8', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=25216917, end_position_on_the_genomic_accession=25228932, orientation='plus', exon_count=6, OMIM=[603750], no_hdr0=''),
    344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344, CurrentID=0, Status='live', Symbol='APOC2', Aliases=['APO-CII', 'APOC-II'], description='apolipoprotein C2', other_designations='apolipoprotein C-II', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44946051, end_position_on_the_genomic_accession=44949565, orientation='plus', exon_count=4, OMIM=[608083], no_hdr0=''),
    345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345, CurrentID=0, Status='live', Symbol='APOC3', Aliases=['APOCIII'], description='apolipoprotein C3', other_designations='apolipoprotein C-III', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116829907, end_position_on_the_genomic_accession=116833072, orientation='plus', exon_count=4, OMIM=[107720], no_hdr0=''),
    346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346, CurrentID=0, Status='live', Symbol='APOC4', Aliases=['APO-CIV', 'APOC-IV'], description='apolipoprotein C4', other_designations='apolipoprotein C-IV', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44942237, end_position_on_the_genomic_accession=44945496, orientation='plus', exon_count=3, OMIM=[600745], no_hdr0=''),
    347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347, CurrentID=0, Status='live', Symbol='APOD', Aliases=[], description='apolipoprotein D', other_designations='apolipoprotein D|apo-D', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195568705, end_position_on_the_genomic_accession=195583940, orientation='minus', exon_count=5, OMIM=[107740], no_hdr0=''),
    348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348, CurrentID=0, Status='live', Symbol='APOE', Aliases=['AD2', 'APO-E', 'ApoE4', 'LDLCQ5', 'LPG'], description='apolipoprotein E', other_designations='apolipoprotein E|apolipoprotein E3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44905796, end_position_on_the_genomic_accession=44909393, orientation='plus', exon_count=6, OMIM=[107741], no_hdr0=''),
    350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=350, CurrentID=0, Status='live', Symbol='APOH', Aliases=['B2G1', 'B2GP1', 'BG'], description='apolipoprotein H', other_designations='beta-2-glycoprotein 1|APC inhibitor|B2GPI|activated protein C-binding protein|anticardiolipin cofactor|apo-H|apolipoprotein H (beta-2-glycoprotein I)|beta(2)GPI|epididymis secretory sperm binding protein', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=66212033, end_position_on_the_genomic_accession=66229415, orientation='minus', exon_count=8, OMIM=[138700], no_hdr0=''),
    351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=351, CurrentID=0, Status='live', Symbol='APP', Aliases=['AAA', 'ABETA', 'ABPP', 'AD1I', 'CTFgamma', 'CVAP', 'PN-II', 'PN2', 'alpha-sAPP', 'preA4', 'APP'], description='amyloid beta precursor protein', other_designations='amyloid-beta precursor protein|alzheimer disease amyloid protein|amyloid beta (A4) precursor protein|amyloid beta A4 protein|amyloid precursor protein|beta-amyloid peptide|beta-amyloid peptide(1-40)|beta-amyloid peptide(1-42)|beta-amyloid precursor protein|cerebral vascular amyloid peptide|peptidase nexin-II|protease nexin-II|testicular tissue protein Li 2', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=25880550, end_position_on_the_genomic_accession=26171128, orientation='minus', exon_count=20, OMIM=[104760], no_hdr0=''),
    353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353, CurrentID=0, Status='live', Symbol='APRT', Aliases=['AMPD', 'APRT'], description='adenine phosphoribosyltransferase', other_designations='adenine phosphoribosyltransferase|AMP diphosphorylase|AMP pyrophosphorylase|transphosphoribosidase', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88809339, end_position_on_the_genomic_accession=88811928, orientation='minus', exon_count=5, OMIM=[102600], no_hdr0=''),
    354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=354, CurrentID=0, Status='live', Symbol='KLK3', Aliases=['APS', 'KLK2A1', 'PSA', 'hK3'], description='kallikrein related peptidase 3', other_designations='prostate-specific antigen|P-30 antigen|gamma-seminoprotein|kallikrein-3|semenogelase|seminin', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50854915, end_position_on_the_genomic_accession=50860764, orientation='plus', exon_count=5, OMIM=[176820], no_hdr0=''),
    355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=355, CurrentID=0, Status='live', Symbol='FAS', Aliases=['ALPS1A', 'APO-1', 'APT1', 'CD951', 'FASTM', 'TNFRSF6', 'FAS'], description='Fas cell surface death receptor', other_designations='tumor necrosis factor receptor superfamily member 6|APO-1 cell surface antigen|CD95 antigen|FASLG receptor|Fas (TNF receptor superfamily, member 6)|Fas AMA|TNF receptor superfamily member 6|apoptosis antigen 1|apoptosis signaling receptor FAS|apoptosis-mediating surface antigen FAS|mutant tumor necrosis receptor superfamily member 6|tumor necrosis factor receptor superfamily, member 6', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88968429, end_position_on_the_genomic_accession=89017059, orientation='plus', exon_count=15, OMIM=[134637], no_hdr0=''),
    356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=356, CurrentID=0, Status='live', Symbol='FASLG', Aliases=['ALPS1B', 'APT1LG1', 'APTL', 'CD178', 'CD95-L', 'CD95L', 'FASL', 'TNFSF6', 'TNLG1A'], description='Fas ligand', other_designations='tumor necrosis factor ligand superfamily member 6|CD95 ligand|Fas ligand (TNF superfamily, member 6)|apoptosis (APO-1) antigen ligand 1|apoptosis antigen ligand|fas antigen ligand|mutant tumor necrosis factor family member 6|tumor necrosis factor ligand 1A', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=172659103, end_position_on_the_genomic_accession=172666876, orientation='plus', exon_count=4, OMIM=[134638], no_hdr0=''),
    357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=357, CurrentID=0, Status='live', Symbol='SHROOM2', Aliases=['APXL', 'HSAPXL'], description='shroom family member 2', other_designations='protein Shroom2|APX homolog of Xenopus|apical-like protein', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=9786406, end_position_on_the_genomic_accession=9949443, orientation='plus', exon_count=13, OMIM=[300103], no_hdr0=''),
    358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=358, CurrentID=0, Status='live', Symbol='AQP1', Aliases=['AQP-CHIP', 'CHIP28', 'CO'], description='aquaporin 1 (Colton blood group)', other_designations='aquaporin-1|Colton blood group antigen|aquaporin 1 (channel-forming integral protein, 28kDa, CO blood group)|aquaporin 1, Colton blood group antigen|aquaporin-CHIP|channel-like integral membrane protein, 28-kDa|urine water channel|water channel protein for red blood cells and kidney proximal tubule', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30911853, end_position_on_the_genomic_accession=30925516, orientation='plus', exon_count=4, OMIM=[107776], no_hdr0=''),
    359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=359, CurrentID=0, Status='live', Symbol='AQP2', Aliases=['AQP-CD', 'NDI2', 'WCH-CD'], description='aquaporin 2', other_designations='aquaporin-2|ADH water channel|AQP-2|aquaporin 2 (collecting duct)|aquaporin-CD|collecting duct water channel protein|water channel protein for renal collecting duct|water-channel aquaporin 2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49950737, end_position_on_the_genomic_accession=49958878, orientation='plus', exon_count=4, OMIM=[107777], no_hdr0=''),
    360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360, CurrentID=0, Status='live', Symbol='AQP3', Aliases=['AQP-3', 'GIL'], description='aquaporin 3 (Gill blood group)', other_designations='aquaporin-3|aquaglyceroporin-3|aquaporin 3 (GIL blood group)', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33441154, end_position_on_the_genomic_accession=33447596, orientation='minus', exon_count=6, OMIM=[600170], no_hdr0=''),
    361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=361, CurrentID=0, Status='live', Symbol='AQP4', Aliases=['MIWC', 'WCH4'], description='aquaporin 4', other_designations='aquaporin-4|aquaporin type4|mercurial-insensitive water channel', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26852038, end_position_on_the_genomic_accession=26865803, orientation='minus', exon_count=6, OMIM=[600308], no_hdr0=''),
    362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=362, CurrentID=0, Status='live', Symbol='AQP5', Aliases=['AQP-5', 'PPKB'], description='aquaporin 5', other_designations='aquaporin-5', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49961855, end_position_on_the_genomic_accession=49965682, orientation='plus', exon_count=5, OMIM=[600442], no_hdr0=''),
    363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=363, CurrentID=0, Status='live', Symbol='AQP6', Aliases=['AQP2L', 'KID'], description='aquaporin 6', other_designations='aquaporin-6|AQP-6|aquaporin 2-like, kidney specific|aquaporin-6, kidney specific|hKID|kidney-specific aquaporin', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49972947, end_position_on_the_genomic_accession=49977139, orientation='plus', exon_count=4, OMIM=[601383], no_hdr0=''),
    364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=364, CurrentID=0, Status='live', Symbol='AQP7', Aliases=['AQP7L', 'AQPap', 'GLYCQTL'], description='aquaporin 7', other_designations='aquaporin-7|aquaglyceroporin-7|aquaporin adipose', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33383135, end_position_on_the_genomic_accession=33402677, orientation='minus', exon_count=10, OMIM=[602974], no_hdr0=''),
    366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=366, CurrentID=0, Status='live', Symbol='AQP9', Aliases=['AQP-9', 'HsT17287', 'SSC1', 'T17287'], description='aquaporin 9', other_designations='aquaporin-9|aquaglyceroporin-9|small solute channel 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58138169, end_position_on_the_genomic_accession=58185911, orientation='plus', exon_count=7, OMIM=[602914], no_hdr0=''),
    367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=367, CurrentID=0, Status='live', Symbol='AR', Aliases=['AIS8', 'DHTR', 'HUMARA', 'HYSP1', 'KD', 'NR3C4', 'SBMA', 'SMAX1', 'TFM', 'AR'], description='androgen receptor', other_designations='androgen receptor|dihydrotestosterone receptor|nuclear receptor subfamily 3 group C member 4', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=67544021, end_position_on_the_genomic_accession=67730619, orientation='plus', exon_count=11, OMIM=[313700], no_hdr0=''),
    368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=368, CurrentID=0, Status='live', Symbol='ABCC6', Aliases=['ABC34', 'ARA', 'EST349056', 'GACI2', 'MLP1', 'MOAT-E', 'MOATE', 'MRP6', 'PXE', 'PXE1', 'URG7'], description='ATP binding cassette subfamily C member 6', other_designations='ATP-binding cassette sub-family C member 6|URG7 protein|ATP-binding cassette, sub-family C (CFTR/MRP), member 6|anthracycline resistance-associated protein|multi-specific organic anion transporter E|multidrug resistance-associated protein 6', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=16149565, end_position_on_the_genomic_accession=16223617, orientation='minus', exon_count=34, OMIM=[603234], no_hdr0=''),
    369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=369, CurrentID=0, Status='live', Symbol='ARAF', Aliases=['A-RAF1', 'PKS2', 'RAFA1', 'ARAF'], description='A-Raf proto-oncogene, serine/threonine kinase', other_designations='serine/threonine-protein kinase A-Raf|A-Raf proto-oncogene serine/threonine-protein kinase|Oncogene ARAF1|Ras-binding protein DA-Raf|proto-oncogene A-Raf-1|proto-oncogene Pks|v-raf murine sarcoma 3611 viral oncogene homolog 1|v-raf murine sarcoma 3611 viral oncogene-like protein', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47561205, end_position_on_the_genomic_accession=47571908, orientation='plus', exon_count=16, OMIM=[311010], no_hdr0=''),
    372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=372, CurrentID=0, Status='live', Symbol='ARCN1', Aliases=['COPD', 'SRMMD'], description='archain 1', other_designations='coatomer subunit delta|COPI coat complex subunit delta|archain vesicle transport protein 1|coatomer delta subunit|coatomer protein complex, subunit delta|coatomer protein delta-COP|delta-COP|delta-coat protein', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118572396, end_position_on_the_genomic_accession=118603033, orientation='plus', exon_count=10, OMIM=[600820], no_hdr0=''),
    373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=373, CurrentID=0, Status='live', Symbol='TRIM23', Aliases=['ARD1', 'ARFD1', 'RNF46'], description='tripartite motif containing 23', other_designations='E3 ubiquitin-protein ligase TRIM23|ADP-ribosylation factor domain protein 1, 64kDa|ADP-ribosylation factor domain-containing protein 1|ARF domain protein 1|GTP-binding protein ARD-1|RING finger protein 46|RING-type E3 ubiquitin transferase TRIM23|tripartite motif protein TRIM23|tripartite motif-containing protein 23', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65589690, end_position_on_the_genomic_accession=65624333, orientation='minus', exon_count=13, OMIM=[601747], no_hdr0=''),
    374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374, CurrentID=0, Status='live', Symbol='AREG', Aliases=['ARB', 'CRDGF', 'SDGF', 'AREG'], description='amphiregulin', other_designations='amphiregulin|amphiregulin B|colorectum cell-derived growth factor|schwannoma-derived growth factor', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74445136, end_position_on_the_genomic_accession=74455005, orientation='plus', exon_count=6, OMIM=[104640], no_hdr0=''),
    375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375, CurrentID=0, Status='live', Symbol='ARF1', Aliases=['PVNH8'], description='ADP ribosylation factor 1', other_designations='ADP-ribosylation factor 1', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228082708, end_position_on_the_genomic_accession=228099212, orientation='plus', exon_count=6, OMIM=[103180], no_hdr0=''),
    377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=377, CurrentID=0, Status='live', Symbol='ARF3', Aliases=[], description='ADP ribosylation factor 3', other_designations='ADP-ribosylation factor 3|small GTP binding protein', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48930252, end_position_on_the_genomic_accession=48957526, orientation='minus', exon_count=8, OMIM=[103190], no_hdr0=''),
    378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378, CurrentID=0, Status='live', Symbol='ARF4', Aliases=['ARF2'], description='ADP ribosylation factor 4', other_designations='ADP-ribosylation factor 4|ADP-ribosylation factor 2', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57571363, end_position_on_the_genomic_accession=57597344, orientation='minus', exon_count=6, OMIM=[601177], no_hdr0=''),
    379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=379, CurrentID=0, Status='live', Symbol='ARL4D', Aliases=['ARF4L'], description='ADP ribosylation factor like GTPase 4D', other_designations='ADP-ribosylation factor-like protein 4D|ADP-ribosylation factor-like 4D|ADP-ribosylation factor-like protein 4L', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43398993, end_position_on_the_genomic_accession=43401137, orientation='plus', exon_count=3, OMIM=[600732], no_hdr0=''),
    381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=381, CurrentID=0, Status='live', Symbol='ARF5', Aliases=[], description='ADP ribosylation factor 5', other_designations='ADP-ribosylation factor 5', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127588411, end_position_on_the_genomic_accession=127591700, orientation='plus', exon_count=6, OMIM=[103188], no_hdr0=''),
    382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=382, CurrentID=0, Status='live', Symbol='ARF6', Aliases=[], description='ADP ribosylation factor 6', other_designations='ADP-ribosylation factor 6', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49893082, end_position_on_the_genomic_accession=49897054, orientation='plus', exon_count=2, OMIM=[600464], no_hdr0=''),
    383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=383, CurrentID=0, Status='live', Symbol='ARG1', Aliases=[], description='arginase 1', other_designations='arginase-1|arginase, liver|liver-type arginase|type I arginase', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131573226, end_position_on_the_genomic_accession=131584329, orientation='plus', exon_count=8, OMIM=[608313], no_hdr0=''),
    384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=384, CurrentID=0, Status='live', Symbol='ARG2', Aliases=[], description='arginase 2', other_designations='arginase-2, mitochondrial|L-arginine amidinohydrolase|L-arginine ureahydrolase|arginase II|arginase, type II|kidney arginase|kidney-type arginase|non-hepatic arginase|nonhepatic arginase|type II arginase', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67619920, end_position_on_the_genomic_accession=67651708, orientation='plus', exon_count=8, OMIM=[107830], no_hdr0=''),
    387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387, CurrentID=0, Status='live', Symbol='RHOA', Aliases=['ARH12', 'ARHA', 'EDFAOB', 'RHO12', 'RHOH12'], description='ras homolog family member A', other_designations='transforming protein RhoA|Aplysia ras-related homolog 12|epididymis secretory sperm binding protein|oncogene RHO H12|small GTP binding protein RhoA', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49359145, end_position_on_the_genomic_accession=49411976, orientation='minus', exon_count=7, OMIM=[165390], no_hdr0=''),
    388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388, CurrentID=0, Status='live', Symbol='RHOB', Aliases=['ARH6', 'ARHB', 'MST081', 'MSTP081', 'RHOH6'], description='ras homolog family member B', other_designations='rho-related GTP-binding protein RhoB|Aplysia RAS-related homolog 6|h6|oncogene RHO H6|ras homolog gene family, member B|rho cDNA clone 6', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20447074, end_position_on_the_genomic_accession=20449440, orientation='plus', exon_count=1, OMIM=[165370], no_hdr0=''),
    389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389, CurrentID=0, Status='live', Symbol='RHOC', Aliases=['ARH9', 'ARHC', 'H9', 'RHOH9'], description='ras homolog family member C', other_designations='rho-related GTP-binding protein RhoC|RAS-related homolog 9|epididymis secretory sperm binding protein|oncogene RHO H9|ras homolog gene family, member C|rho cDNA clone 9|rhoC GTPase|small GTP binding protein RhoC', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112701131, end_position_on_the_genomic_accession=112707408, orientation='minus', exon_count=7, OMIM=[165380], no_hdr0=''),
    390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390, CurrentID=0, Status='live', Symbol='RND3', Aliases=['ARHE', 'Rho8', 'RhoE', 'memB'], description='Rho family GTPase 3', other_designations='rho-related GTP-binding protein RhoE|protein MemB|ras homolog gene family, member E|rho-related GTP-binding protein Rho8|small GTP binding protein Rho8', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=150468193, end_position_on_the_genomic_accession=150487695, orientation='minus', exon_count=6, OMIM=[602924], no_hdr0=''),
    391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391, CurrentID=0, Status='live', Symbol='RHOG', Aliases=['ARHG'], description='ras homolog family member G', other_designations='rho-related GTP-binding protein RhoG|ras homolog gene family, member G (rho G)', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3826978, end_position_on_the_genomic_accession=3840959, orientation='minus', exon_count=4, OMIM=[179505], no_hdr0=''),
    392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392, CurrentID=0, Status='live', Symbol='ARHGAP1', Aliases=['CDC42GAP', 'RHOGAP', 'RHOGAP1', 'p50rhoGAP'], description='Rho GTPase activating protein 1', other_designations='rho GTPase-activating protein 1|CDC42 GTPase-activating protein|GTPase-activating protein rhoGAP|GTPase-activating protein rhoOGAP|GTPase-activating protein, Rho, 1|rho-related small GTPase protein activator|rho-type GTPase-activating protein 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46677077, end_position_on_the_genomic_accession=46700660, orientation='minus', exon_count=14, OMIM=[602732], no_hdr0=''),
    393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=393, CurrentID=0, Status='live', Symbol='ARHGAP4', Aliases=['C1', 'RGC1', 'RhoGAP4', 'SrGAP4', 'p115'], description='Rho GTPase activating protein 4', other_designations='rho GTPase-activating protein 4|Rho-GAP hematopoietic protein C1|rho-type GTPase-activating protein 4', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153907378, end_position_on_the_genomic_accession=153926264, orientation='minus', exon_count=23, OMIM=[300023], no_hdr0=''),
    394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=394, CurrentID=0, Status='live', Symbol='ARHGAP5', Aliases=['GFI2', 'RhoGAP5', 'p190-B', 'p190BRhoGAP'], description='Rho GTPase activating protein 5', other_designations='rho GTPase-activating protein 5|growth factor independent 2|p100 RasGAP-associated p105 protein|p105 RhoGAP|rho-type GTPase-activating protein 5', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=32072588, end_position_on_the_genomic_accession=32159728, orientation='plus', exon_count=9, OMIM=[602680], no_hdr0=''),
    395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=395, CurrentID=0, Status='live', Symbol='ARHGAP6', Aliases=['RHOGAP6', 'RHOGAPX-1'], description='Rho GTPase activating protein 6', other_designations='rho GTPase-activating protein 6|Rho-type GTPase-activating protein RhoGAPX-1|rho-type GTPase-activating protein 6', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=11137544, end_position_on_the_genomic_accession=11665920, orientation='minus', exon_count=17, OMIM=[300118], no_hdr0=''),
    396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=396, CurrentID=0, Status='live', Symbol='ARHGDIA', Aliases=['GDIA1', 'HEL-S-47e', 'NPHS8', 'RHOGDI', 'RHOGDI-1'], description='Rho GDP dissociation inhibitor alpha', other_designations='rho GDP-dissociation inhibitor 1|GDP-dissociation inhibitor, aplysia RAS-related 1|Rho GDP dissociation inhibitor (GDI) alpha|epididymis secretory sperm binding protein Li 47e', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81867719, end_position_on_the_genomic_accession=81871337, orientation='minus', exon_count=7, OMIM=[601925], no_hdr0=''),
    397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=397, CurrentID=0, Status='live', Symbol='ARHGDIB', Aliases=['D4', 'GDIA2', 'GDID4', 'LYGDI', 'Ly-GDI', 'RAP1GN1', 'RhoGDI2'], description='Rho GDP dissociation inhibitor beta', other_designations='rho GDP-dissociation inhibitor 2|Rho GDI 2|Rho GDP dissociation inhibitor (GDI) beta|rho-GDI beta', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14942015, end_position_on_the_genomic_accession=14961601, orientation='minus', exon_count=10, OMIM=[602843], no_hdr0=''),
    398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=398, CurrentID=0, Status='live', Symbol='ARHGDIG', Aliases=['RHOGDI-3'], description='Rho GDP dissociation inhibitor gamma', other_designations='rho GDP-dissociation inhibitor 3|Rho GDP dissociation inhibitor (GDI) gamma|RhoGDI gamma|rho GDI 3|rho-GDI gamma', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=280591, end_position_on_the_genomic_accession=283010, orientation='plus', exon_count=6, OMIM=[602844], no_hdr0=''),
    399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399, CurrentID=0, Status='live', Symbol='RHOH', Aliases=['ARHH', 'TTF'], description='ras homolog family member H', other_designations='rho-related GTP-binding protein RhoH|GTP-binding protein TTF|TTF, translocation three four|ras homolog gene family, member H', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40191080, end_position_on_the_genomic_accession=40246967, orientation='plus', exon_count=11, OMIM=[602037], no_hdr0=''),
    400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400, CurrentID=0, Status='live', Symbol='ARL1', Aliases=['ARFL1'], description='ADP ribosylation factor like GTPase 1', other_designations='ADP-ribosylation factor-like protein 1|ADP-ribosylation factor-like 1', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101393116, end_position_on_the_genomic_accession=101407820, orientation='minus', exon_count=6, OMIM=[603425], no_hdr0=''),
    401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401, CurrentID=0, Status='live', Symbol='PHOX2A', Aliases=['ARIX', 'CFEOM2', 'FEOM2', 'NCAM2', 'PMX2A'], description='paired like homeobox 2A', other_designations='paired mesoderm homeobox protein 2A|ARIX1 homeodomain protein|aristaless homeobox homolog|aristaless homeobox protein homolog|arix homeodomain protein', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72239077, end_position_on_the_genomic_accession=72244176, orientation='minus', exon_count=3, OMIM=[602753], no_hdr0=''),
    402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402, CurrentID=0, Status='live', Symbol='ARL2', Aliases=['ARFL2', 'MRCS1'], description='ADP ribosylation factor like GTPase 2', other_designations='ADP-ribosylation factor-like protein 2|ADP-ribosylation factor-like 2', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65014160, end_position_on_the_genomic_accession=65022184, orientation='plus', exon_count=5, OMIM=[601175], no_hdr0=''),
    403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403, CurrentID=0, Status='live', Symbol='ARL3', Aliases=['ARFL3', 'JBTS35', 'RP83'], description='ADP ribosylation factor like GTPase 3', other_designations='ADP-ribosylation factor-like protein 3|ADP-ribosylation factor-like 3|ARF-like 3', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102673731, end_position_on_the_genomic_accession=102714397, orientation='minus', exon_count=7, OMIM=[604695], no_hdr0=''),
    405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=405, CurrentID=0, Status='live', Symbol='ARNT', Aliases=['HIF-1-beta', 'HIF-1beta', 'HIF1-beta', 'HIF1B', 'HIF1BETA', 'TANGO', 'bHLHe2'], description='aryl hydrocarbon receptor nuclear translocator', other_designations='aryl hydrocarbon receptor nuclear translocator|class E basic helix-loop-helix protein 2|dioxin receptor, nuclear translocator|hypoxia-inducible factor 1, beta subunit', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150809713, end_position_on_the_genomic_accession=150876737, orientation='minus', exon_count=25, OMIM=[126110], no_hdr0=''),
    406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=406, CurrentID=0, Status='live', Symbol='ARNTL', Aliases=['BMAL1', 'BMAL1c', 'JAP3', 'MOP3', 'PASD3', 'TIC', 'bHLHe5'], description='aryl hydrocarbon receptor nuclear translocator like', other_designations='aryl hydrocarbon receptor nuclear translocator-like protein 1|ARNT-like protein 1, brain and muscle|PAS domain containing 3|PAS domain-containing protein 3|bHLH-PAS protein JAP3|basic helix-loop-helix family member e5|basic-helix-loop-helix-PAS orphan MOP3|basic-helix-loop-helix-PAS protein MOP3|brain and muscle ARNT-like 1|class E basic helix-loop-helix protein 5|member of PAS protein 3|member of PAS superfamily 3|testis tissue sperm-binding protein Li 50e', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13276552, end_position_on_the_genomic_accession=13387268, orientation='plus', exon_count=25, OMIM=[602550], no_hdr0=''),
    407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=407, CurrentID=0, Status='live', Symbol='ARR3', Aliases=['ARRX', 'MYP26', 'cArr'], description='arrestin 3', other_designations='arrestin-C|C-arrestin|arrestin 3 retinal (X-arrestin)|arrestin 4|retinal cone arrestin-3', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70268334, end_position_on_the_genomic_accession=70281840, orientation='plus', exon_count=17, OMIM=[301770], no_hdr0=''),
    408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=408, CurrentID=0, Status='live', Symbol='ARRB1', Aliases=['ARB1', 'ARR1'], description='arrestin beta 1', other_designations='beta-arrestin-1|arrestin 2|non-visual arrestin-2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75260122, end_position_on_the_genomic_accession=75351662, orientation='minus', exon_count=20, OMIM=[107940], no_hdr0=''),
    409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=409, CurrentID=0, Status='live', Symbol='ARRB2', Aliases=['ARB2', 'ARR2', 'BARR2'], description='arrestin beta 2', other_designations='beta-arrestin-2|arrestin 3|non-visual arrestin-3', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4710619, end_position_on_the_genomic_accession=4721500, orientation='plus', exon_count=17, OMIM=[107941], no_hdr0=''),
    410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=410, CurrentID=0, Status='live', Symbol='ARSA', Aliases=['ASA', 'MLD'], description='arylsulfatase A', other_designations='arylsulfatase A|cerebroside-sulfatase|epididymis secretory sperm binding protein', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50622754, end_position_on_the_genomic_accession=50628152, orientation='minus', exon_count=9, OMIM=[607574], no_hdr0=''),
    411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=411, CurrentID=0, Status='live', Symbol='ARSB', Aliases=['ASB', 'G4S', 'MPS6'], description='arylsulfatase B', other_designations='arylsulfatase B|N-acetylgalactosamine-4-sulfatase', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=78777209, end_position_on_the_genomic_accession=78986087, orientation='minus', exon_count=15, OMIM=[611542], no_hdr0=''),
    412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=412, CurrentID=0, Status='live', Symbol='STS', Aliases=['ARSC', 'ARSC1', 'ASC', 'ES', 'SSDD', 'XLI'], description='steroid sulfatase', other_designations='steryl-sulfatase|arylsulfatase C|estrone sulfatase|steroid sulfatase (microsomal), isozyme S|steryl-sulfate sulfohydrolase', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=7147290, end_position_on_the_genomic_accession=7354641, orientation='plus', exon_count=16, OMIM=[300747], no_hdr0=''),
    414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414, CurrentID=0, Status='live', Symbol='ARSD', Aliases=['ASD'], description='arylsulfatase D', other_designations='arylsulfatase D|testis tissue sperm-binding protein Li 39a', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2903972, end_position_on_the_genomic_accession=2929345, orientation='minus', exon_count=11, OMIM=[300002], no_hdr0=''),
    415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=415, CurrentID=0, Status='live', Symbol='ARSL', Aliases=['ARSE', 'ASE', 'CDPX', 'CDPX1', 'CDPXR'], description='arylsulfatase L', other_designations='arylsulfatase L|arylsulfatase E (chondrodysplasia punctata 1)', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2934521, end_position_on_the_genomic_accession=2968245, orientation='minus', exon_count=13, OMIM=[300180], no_hdr0=''),
    416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=416, CurrentID=0, Status='live', Symbol='ARSF', Aliases=['ASF'], description='arylsulfatase F', other_designations='arylsulfatase F', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=3040234, end_position_on_the_genomic_accession=3112727, orientation='plus', exon_count=14, OMIM=[300003], no_hdr0=''),
    417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=417, CurrentID=0, Status='live', Symbol='ART1', Aliases=['ART2', 'ARTC1', 'CD296', 'RT6'], description='ADP-ribosyltransferase 1', other_designations='GPI-linked NAD(P)(+)--arginine ADP-ribosyltransferase 1|ADP-ribosyltransferase 2|ADP-ribosyltransferase C2 and C3 toxin-like 1|mono(ADP-ribosyl)transferase 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3645110, end_position_on_the_genomic_accession=3665516, orientation='plus', exon_count=6, OMIM=[601625], no_hdr0=''),
    419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=419, CurrentID=0, Status='live', Symbol='ART3', Aliases=['ARTC3'], description='ADP-ribosyltransferase 3 (inactive)', other_designations='ecto-ADP-ribosyltransferase 3|ADP-ribosyltransferase C2 and C3 toxin-like 3|NAD(P)(+)--arginine ADP-ribosyltransferase 3|mono(ADP-ribosyl)transferase 3|mono-ADP-ribosyltransferase', map_location='4p15.1-p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76011168, end_position_on_the_genomic_accession=76112791, orientation='plus', exon_count=17, OMIM=[603086], no_hdr0=''),
    420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=420, CurrentID=0, Status='live', Symbol='ART4', Aliases=['ARTC4', 'CD297', 'DO', 'DO/ART4', 'DOK1'], description='ADP-ribosyltransferase 4 (inactive) (Dombrock blood group)', other_designations='ecto-ADP-ribosyltransferase 4|ADP-ribosyltransferase 4 (DO blood group)|ADP-ribosyltransferase 4 (Dombrock blood group)|ADP-ribosyltransferase C2 and C3 toxin-like 4|Do glycoprotein|Dombrock blood group carrier molecule|Dombrock glycoprotein|NAD(+)--protein-arginine ADP-ribosyltransferase 4|NAD(P)(+)--arginine ADP-ribosyltransferase 4|mono-ADP-ribosyltransferase 4|truncated Dombrock blood group protein', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14825569, end_position_on_the_genomic_accession=14843526, orientation='minus', exon_count=3, OMIM=[110600], no_hdr0=''),
    421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=421, CurrentID=0, Status='live', Symbol='ARVCF', Aliases=[], description='ARVCF delta catenin family member', other_designations='armadillo repeat protein deleted in velo-cardio-facial syndrome|armadillo repeat gene deleted in velocardiofacial syndrome', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19966727, end_position_on_the_genomic_accession=20016823, orientation='minus', exon_count=27, OMIM=[602269], no_hdr0=''),
    427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=427, CurrentID=0, Status='live', Symbol='ASAH1', Aliases=['AC', 'ACDase', 'ASAH', 'PHP', 'PHP32', 'SMAPME'], description='N-acylsphingosine amidohydrolase 1', other_designations='acid ceramidase|N-acylethanolamine hydrolase ASAH1|N-acylsphingosine amidohydrolase (acid ceramidase) 1|acid CDase|acylsphingosine deacylase|putative 32 kDa heart protein', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=18055992, end_position_on_the_genomic_accession=18084961, orientation='minus', exon_count=17, OMIM=[613468], no_hdr0=''),
    429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=429, CurrentID=0, Status='live', Symbol='ASCL1', Aliases=['ASH1', 'HASH1', 'MASH1', 'bHLHa46'], description='achaete-scute family bHLH transcription factor 1', other_designations='achaete-scute homolog 1|ASH-1|achaete scute protein|achaete-scute complex homolog 1|achaete-scute complex-like 1|class A basic helix-loop-helix protein 46', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102957674, end_position_on_the_genomic_accession=102960513, orientation='plus', exon_count=2, OMIM=[100790], no_hdr0=''),
    430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=430, CurrentID=0, Status='live', Symbol='ASCL2', Aliases=['ASH2', 'HASH2', 'MASH2', 'bHLHa45'], description='achaete-scute family bHLH transcription factor 2', other_designations='achaete-scute homolog 2|achaete-scute complex homolog 2|achaete-scute complex-like 2|class A basic helix-loop-helix protein 45|mammalian achaete/scute homologue 2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2268498, end_position_on_the_genomic_accession=2270588, orientation='minus', exon_count=2, OMIM=[601886], no_hdr0=''),
    432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=432, CurrentID=0, Status='live', Symbol='ASGR1', Aliases=['ASGPR', 'ASGPR1', 'CLEC4H1', 'HL-1'], description='asialoglycoprotein receptor 1', other_designations='asialoglycoprotein receptor 1|C-type lectin domain family 4 member H1|hepatic lectin H1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7173431, end_position_on_the_genomic_accession=7179426, orientation='minus', exon_count=9, OMIM=[108360], no_hdr0=''),
    433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=433, CurrentID=0, Status='live', Symbol='ASGR2', Aliases=['ASGP-R2', 'ASGPR2', 'CLEC4H2', 'HBXBP', 'HL-2'], description='asialoglycoprotein receptor 2', other_designations='asialoglycoprotein receptor 2|C-type lectin domain family 4 member H2|HBxAg-binding protein|hepatic lectin H2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7101322, end_position_on_the_genomic_accession=7115538, orientation='minus', exon_count=11, OMIM=[108361], no_hdr0=''),
    434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=434, CurrentID=0, Status='live', Symbol='ASIP', Aliases=['AGSW', 'AGTI', 'AGTIL', 'ASP', 'SHEP9'], description='agouti signaling protein', other_designations='agouti-signaling protein|agouti signaling protein, nonagouti homolog|agouti switch protein|nonagouti homolog', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34186493, end_position_on_the_genomic_accession=34269344, orientation='plus', exon_count=8, OMIM=[600201], no_hdr0=''),
    435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=435, CurrentID=0, Status='live', Symbol='ASL', Aliases=['ASAL'], description='argininosuccinate lyase', other_designations='argininosuccinate lyase|argininosuccinase|arginosuccinase', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66075819, end_position_on_the_genomic_accession=66093576, orientation='plus', exon_count=16, OMIM=[608310], no_hdr0=''),
    438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=438, CurrentID=0, Status='live', Symbol='ASMT', Aliases=['ASMTY', 'HIOMT', 'HIOMTY'], description='acetylserotonin O-methyltransferase', other_designations='acetylserotonin O-methyltransferase|acetylserotonin N-methyltransferase|acetylserotonin methyltransferase (Y chromosome)|hydroxyindole O-methyltransferase', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1595455, end_position_on_the_genomic_accession=1643081, orientation='plus', exon_count=10, OMIM=[300015, 402500], no_hdr0=''),
    439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=439, CurrentID=0, Status='live', Symbol='GET3', Aliases=['ARSA-I', 'ARSA1', 'ASNA-I', 'ASNA1', 'TRC40'], description='guided entry of tail-anchored proteins factor 3, ATPase', other_designations='ATPase GET3|arsA arsenite transporter, ATP-binding, homolog 1|golgi to ER traffic 3 homolog|transmembrane domain recognition complex 40 kDa ATPase subunit', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12737106, end_position_on_the_genomic_accession=12748323, orientation='plus', exon_count=8, OMIM=[601913], no_hdr0=''),
    440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440, CurrentID=0, Status='live', Symbol='ASNS', Aliases=['ASNSD', 'TS11'], description='asparagine synthetase (glutamine-hydrolyzing)', other_designations='asparagine synthetase [glutamine-hydrolyzing]|TS11 cell cycle control protein|glutamine-dependent asparagine synthetase', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97851677, end_position_on_the_genomic_accession=97928441, orientation='minus', exon_count=16, OMIM=[108370], no_hdr0=''),
    443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=443, CurrentID=0, Status='live', Symbol='ASPA', Aliases=['ACY2', 'ASP'], description='aspartoacylase', other_designations='aspartoacylase|ACY-2|aminoacylase 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3473646, end_position_on_the_genomic_accession=3503405, orientation='plus', exon_count=10, OMIM=[608034], no_hdr0=''),
    444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=444, CurrentID=0, Status='live', Symbol='ASPH', Aliases=['AAH', 'BAH', 'CASQ2BP1', 'FDLAB', 'HAAH', 'JCTN', 'junctin'], description='aspartate beta-hydroxylase', other_designations='aspartyl/asparaginyl beta-hydroxylase|A beta H-J-J|ASP beta-hydroxylase|cardiac junctin|humbug|junctate|peptide-aspartate beta-dioxygenase', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=61500556, end_position_on_the_genomic_accession=61714609, orientation='minus', exon_count=33, OMIM=[600582], no_hdr0=''),
    445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445, CurrentID=0, Status='live', Symbol='ASS1', Aliases=['ASS', 'CTLN1'], description='argininosuccinate synthase 1', other_designations='argininosuccinate synthase|argininosuccinate synthetase 1|citrulline-aspartate ligase|epididymis secretory sperm binding protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130444707, end_position_on_the_genomic_accession=130501274, orientation='plus', exon_count=18, OMIM=[603470], no_hdr0=''),
    460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=460, CurrentID=0, Status='live', Symbol='ASTN1', Aliases=['ASTN'], description='astrotactin 1', other_designations='astrotactin-1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=176855117, end_position_on_the_genomic_accession=177164854, orientation='minus', exon_count=26, OMIM=[600904], no_hdr0=''),
    462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=462, CurrentID=0, Status='live', Symbol='SERPINC1', Aliases=['AT3', 'AT3D', 'ATIII', 'ATIII-R2', 'ATIII-T1', 'ATIII-T2', 'THPH7'], description='serpin family C member 1', other_designations='antithrombin-III|serine (or cysteine) proteinase inhibitor, clade C (antithrombin), member 1|serpin peptidase inhibitor clade C member 1|serpin peptidase inhibitor, clade C (antithrombin), member 1', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173903800, end_position_on_the_genomic_accession=173917327, orientation='minus', exon_count=9, OMIM=[107300], no_hdr0=''),
    463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=463, CurrentID=0, Status='live', Symbol='ZFHX3', Aliases=['ATBF1', 'ATBT', 'C16orf47', 'ZFH-3', 'ZNF927'], description='zinc finger homeobox 3', other_designations='zinc finger homeobox protein 3|AT motif-binding factor 1|AT-binding transcription factor 1|alpha-fetoprotein enhancer binding protein|zinc finger homeodomain protein 3', map_location='16q22.2-q22.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72782885, end_position_on_the_genomic_accession=73891931, orientation='minus', exon_count=23, OMIM=[104155], no_hdr0=''),
    466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=466, CurrentID=0, Status='live', Symbol='ATF1', Aliases=['EWS-ATF1', 'FUS/ATF-1', 'TREB36'], description='activating transcription factor 1', other_designations='cyclic AMP-dependent transcription factor ATF-1|cAMP-dependent transcription factor ATF-1', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50763682, end_position_on_the_genomic_accession=50821162, orientation='plus', exon_count=13, OMIM=[123803], no_hdr0=''),
    467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=467, CurrentID=0, Status='live', Symbol='ATF3', Aliases=[], description='activating transcription factor 3', other_designations='cyclic AMP-dependent transcription factor ATF-3|cAMP-dependent transcription factor ATF-3', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212565407, end_position_on_the_genomic_accession=212620777, orientation='plus', exon_count=7, OMIM=[603148], no_hdr0=''),
    468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=468, CurrentID=0, Status='live', Symbol='ATF4', Aliases=['CREB-2', 'CREB2', 'TAXREB67', 'TXREB'], description='activating transcription factor 4', other_designations='cyclic AMP-dependent transcription factor ATF-4|DNA-binding protein TAXREB67|cAMP response element-binding protein 2|cAMP-dependent transcription factor ATF-4|cAMP-responsive element-binding protein 2|cyclic AMP-responsive element-binding protein 2|tax-responsive enhancer element B67|tax-responsive enhancer element-binding protein 67', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39514494, end_position_on_the_genomic_accession=39522686, orientation='plus', exon_count=3, OMIM=[604064], no_hdr0=''),
    471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=471, CurrentID=0, Status='live', Symbol='ATIC', Aliases=['AICAR', 'AICARFT', 'HEL-S-70p', 'IMPCHASE', 'PURH'], description='5-aminoimidazole-4-carboxamide ribonucleotide formyltransferase/IMP cyclohydrolase', other_designations='bifunctional purine biosynthesis protein ATIC|5-aminoimidazole-4-carboxamide-1-beta-D-ribonucleotide transformylase/inosinicase|AICAR formyltransferase/IMP cyclohydrolase bifunctional enzyme|AICAR transformylase/inosine monophosphate cyclohydrolase|AICARFT/IMPCHASE|bifunctional purine biosynthesis protein PURH|epididymis secretory sperm binding protein Li 70p|phosphoribosylaminoimidazolecarboxamide formyltransferase/IMP cyclohydrolase', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=215311974, end_position_on_the_genomic_accession=215359745, orientation='plus', exon_count=17, OMIM=[601731], no_hdr0=''),
    472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=472, CurrentID=0, Status='live', Symbol='ATM', Aliases=['AT1', 'ATA', 'ATC', 'ATD', 'ATDC', 'ATE', 'TEL1', 'TELO1'], description='ATM serine/threonine kinase', other_designations='serine-protein kinase ATM|A-T mutated|AT mutated|TEL1, telomere maintenance 1, homolog|ataxia telangiectasia mutated', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108222484, end_position_on_the_genomic_accession=108369102, orientation='plus', exon_count=69, OMIM=[607585], no_hdr0=''),
    473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=473, CurrentID=0, Status='live', Symbol='RERE', Aliases=['ARG', 'ARP', 'ATN1L', 'DNB1', 'NEDBEH'], description='arginine-glutamic acid dipeptide repeats', other_designations='arginine-glutamic acid dipeptide repeats protein|arginine-glutamic acid dipeptide (RE) repeats|atrophin 2|atrophin-1 like protein|atrophin-1 related protein', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8352404, end_position_on_the_genomic_accession=8817640, orientation='minus', exon_count=25, OMIM=[605226], no_hdr0=''),
    474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474, CurrentID=0, Status='live', Symbol='ATOH1', Aliases=['ATH1', 'HATH1', 'MATH-1', 'bHLHa14'], description='atonal bHLH transcription factor 1', other_designations='protein atonal homolog 1|atonal homolog 1|atonal homolog bHLH transcription factor 1|class A basic helix-loop-helix protein 14|helix-loop-helix protein hATH-1', map_location='4q22.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=93828753, end_position_on_the_genomic_accession=93830964, orientation='plus', exon_count=1, OMIM=[601461], no_hdr0=''),
    475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=475, CurrentID=0, Status='live', Symbol='ATOX1', Aliases=['ATX1', 'HAH1'], description='antioxidant 1 copper chaperone', other_designations='copper transport protein ATOX1|ATX1 antioxidant protein 1 homolog|metal transport protein ATX1', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151742822, end_position_on_the_genomic_accession=151758631, orientation='minus', exon_count=4, OMIM=[602270], no_hdr0=''),
    476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=476, CurrentID=0, Status='live', Symbol='ATP1A1', Aliases=['CMT2DD', 'HOMGSMR2'], description='ATPase Na+/K+ transporting subunit alpha 1', other_designations='sodium/potassium-transporting ATPase subunit alpha-1|ATPase, Na+/K+ transporting, alpha 1 polypeptide|Na(+)/K(+) ATPase alpha-1 subunit|Na+/K+ ATPase 1|Na, K-ATPase, alpha-A catalytic polypeptide|Na,K-ATPase alpha-1 subunit|Na,K-ATPase catalytic subunit alpha-A protein|sodium pump subunit alpha-1|sodium-potassium ATPase catalytic subunit alpha-1|sodium-potassium-ATPase, alpha 1 polypeptide', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116372986, end_position_on_the_genomic_accession=116410259, orientation='plus', exon_count=26, OMIM=[182310], no_hdr0=''),
    477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=477, CurrentID=0, Status='live', Symbol='ATP1A2', Aliases=['FHM2', 'MHP2'], description='ATPase Na+/K+ transporting subunit alpha 2', other_designations='sodium/potassium-transporting ATPase subunit alpha-2|ATPase Na+/K+ transporting alpha 2 polypeptide|Na(+)/K(+) ATPase alpha-2 subunit|Na+/K+ ATPase, alpha-A(+) catalytic polypeptide|Na+/K+ ATPase, alpha-B polypeptide|sodium pump subunit alpha-2|sodium-potassium ATPase catalytic subunit alpha-2|sodium/potassium-transporting ATPase alpha-2 chain', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160115759, end_position_on_the_genomic_accession=160143591, orientation='plus', exon_count=23, OMIM=[182340], no_hdr0=''),
    478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=478, CurrentID=0, Status='live', Symbol='ATP1A3', Aliases=['AHC2', 'ATP1A1', 'CAPOS', 'DYT12', 'RDP'], description='ATPase Na+/K+ transporting subunit alpha 3', other_designations='sodium/potassium-transporting ATPase subunit alpha-3|ATPase, Na+/K+ transporting, alpha 3 polypeptide|Na(+)/K(+) ATPase alpha(III) subunit|Na(+)/K(+) ATPase alpha-3 subunit|Na+, K+ activated adenosine triphosphatase alpha subunit|Na+/K+ ATPase 3|sodium pump subunit alpha-3|sodium-potassium ATPase catalytic subunit alpha-3|sodium-potassium-ATPase, alpha 3 polypeptide|sodium/potassium-transporting ATPase alpha-3 chain', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41966582, end_position_on_the_genomic_accession=41994230, orientation='minus', exon_count=24, OMIM=[182350], no_hdr0=''),
    479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=479, CurrentID=0, Status='live', Symbol='ATP12A', Aliases=['ATP1AL1', 'H-K-ATPase', 'HK'], description='ATPase H+/K+ transporting non-gastric alpha2 subunit', other_designations='potassium-transporting ATPase alpha chain 2|ATPase, H+/K+ transporting, nongastric, alpha polypeptide|ATPase, Na+/K+ transporting, alpha polypeptide-like 1|HK alpha 2|non-gastric Na(+)/K(+) ATPase subunit alpha|sodium pump', map_location='13q12.1-q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24680408, end_position_on_the_genomic_accession=24712472, orientation='plus', exon_count=23, OMIM=[182360], no_hdr0=''),
    480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=480, CurrentID=0, Status='live', Symbol='ATP1A4', Aliases=['ATP1A1', 'ATP1AL2'], description='ATPase Na+/K+ transporting subunit alpha 4', other_designations='sodium/potassium-transporting ATPase subunit alpha-4|ATPase, Na+/K+ transporting, alpha 4 polypeptide|ATPase, Na+/K+ transporting, alpha polypeptide-like 2|Na(+)/K(+) ATPase alpha-4 subunit|Na+/K+ ATPase 4|Na+/K+ ATPase, alpha-D polypeptide|Na,K-ATPase subunit alpha-C|sodium pump 4|sodium pump subunit alpha-4|sodium-potassium ATPase catalytic subunit alpha-4|sodium/potassium-transporting ATPase alpha-4 chain', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160151603, end_position_on_the_genomic_accession=160186980, orientation='plus', exon_count=23, OMIM=[607321], no_hdr0=''),
    481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=481, CurrentID=0, Status='live', Symbol='ATP1B1', Aliases=['ATP1B'], description='ATPase Na+/K+ transporting subunit beta 1', other_designations='sodium/potassium-transporting ATPase subunit beta-1|ATPase, Na+/K+ transporting, beta 1 polypeptide|Beta 1-subunit of Na(+),K(+)-ATPase|Na, K-ATPase beta-1 polypeptide|adenosinetriphosphatase|sodium pump subunit beta-1|sodium-potassium ATPase subunit beta 1 (non-catalytic)|sodium/potassium-dependent ATPase beta-1 subunit|sodium/potassium-transporting ATPase beta-1 chain', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169106690, end_position_on_the_genomic_accession=169132719, orientation='plus', exon_count=6, OMIM=[182330], no_hdr0=''),
    482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=482, CurrentID=0, Status='live', Symbol='ATP1B2', Aliases=['AMOG'], description='ATPase Na+/K+ transporting subunit beta 2', other_designations='sodium/potassium-transporting ATPase subunit beta-2|ATPase, Na+/K+ transporting, beta 2 polypeptide|Na, K-ATPase beta-2 polypeptide|adhesion molecule in glia|adhesion molecule on glia|sodium pump subunit beta-2|sodium-potassium ATPase subunit beta 2 (non-catalytic)|sodium/potassium-dependent ATPase beta-2 subunit|sodium/potassium-dependent ATPase subunit beta-2|sodium/potassium-transporting ATPase beta-2 chain', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7646627, end_position_on_the_genomic_accession=7657770, orientation='plus', exon_count=8, OMIM=[182331], no_hdr0=''),
    483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=483, CurrentID=0, Status='live', Symbol='ATP1B3', Aliases=['ATPB-3', 'CD298'], description='ATPase Na+/K+ transporting subunit beta 3', other_designations='sodium/potassium-transporting ATPase subunit beta-3|ATPase, Na+/K+ transporting, beta 3 polypeptide|Na, K-ATPase beta-3 polypeptide|sodium pump subunit beta-3|sodium-potassium ATPase subunit beta 3 (non-catalytic)|sodium/potassium-dependent ATPase subunit beta-3|sodium/potassium-transporting ATPase beta-3 chain', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141876643, end_position_on_the_genomic_accession=141926549, orientation='plus', exon_count=7, OMIM=[601867], no_hdr0=''),
    486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=486, CurrentID=0, Status='live', Symbol='FXYD2', Aliases=['ATP1G1', 'HOMG2'], description='FXYD domain containing ion transport regulator 2', other_designations='sodium/potassium-transporting ATPase subunit gamma|ATPase, Na+/K+ transporting, gamma 1 polypeptide|Na(+)/K(+) ATPase subunit gamma|sodium pump gamma chain', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117820057, end_position_on_the_genomic_accession=117828089, orientation='minus', exon_count=7, OMIM=[601814], no_hdr0=''),
    487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=487, CurrentID=0, Status='live', Symbol='ATP2A1', Aliases=['ATP2A', 'SERCA1'], description='ATPase sarcoplasmic/endoplasmic reticulum Ca2+ transporting 1', other_designations='sarcoplasmic/endoplasmic reticulum calcium ATPase 1|ATPase, Ca++ transporting, cardiac muscle, fast twitch 1|SR Ca(2+)-ATPase 1|calcium pump 1|endoplasmic reticulum class 1/2 Ca(2+) ATPase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28878488, end_position_on_the_genomic_accession=28904466, orientation='plus', exon_count=24, OMIM=[108730], no_hdr0=''),
    488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=488, CurrentID=0, Status='live', Symbol='ATP2A2', Aliases=['ATP2B', 'DAR', 'DD', 'SERCA2'], description='ATPase sarcoplasmic/endoplasmic reticulum Ca2+ transporting 2', other_designations='sarcoplasmic/endoplasmic reticulum calcium ATPase 2|ATPase Ca++ transporting cardiac muscle slow twitch 2|ATPase, Ca++ dependent, slow-twitch, cardiac muscle-2|SR Ca(2+)-ATPase 2|calcium pump 2|cardiac Ca2+ ATPase|endoplasmic reticulum class 1/2 Ca(2+) ATPase', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110281247, end_position_on_the_genomic_accession=110351093, orientation='plus', exon_count=21, OMIM=[108740], no_hdr0=''),
    489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=489, CurrentID=0, Status='live', Symbol='ATP2A3', Aliases=['SERCA3'], description='ATPase sarcoplasmic/endoplasmic reticulum Ca2+ transporting 3', other_designations='sarcoplasmic/endoplasmic reticulum calcium ATPase 3|ATPase, Ca(2+)-transporting, ubiquitous|ATPase, Ca++ transporting, ubiquitous|SR Ca(2+)-ATPase 3|adenosine triphosphatase, calcium|calcium pump 3|calcium-translocating P-type ATPase|sarco/endoplasmic reticulum Ca2+ -ATPase', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3923869, end_position_on_the_genomic_accession=3964464, orientation='minus', exon_count=25, OMIM=[601929], no_hdr0=''),
    490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=490, CurrentID=0, Status='live', Symbol='ATP2B1', Aliases=['PMCA1', 'PMCA1kb'], description='ATPase plasma membrane Ca2+ transporting 1', other_designations='plasma membrane calcium-transporting ATPase 1|ATPase, Ca++ transporting, plasma membrane 1|plasma membrane calcium pump', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=89588049, end_position_on_the_genomic_accession=89709366, orientation='minus', exon_count=24, OMIM=[108731], no_hdr0=''),
    491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=491, CurrentID=0, Status='live', Symbol='ATP2B2', Aliases=['PMCA2', 'PMCA2a', 'PMCA2i'], description='ATPase plasma membrane Ca2+ transporting 2', other_designations='plasma membrane calcium-transporting ATPase 2|ATPase, Ca++ transporting, plasma membrane 2|plasma membrane Ca(2+)-ATPase|plasma membrane Ca2+ pump 2|plasma membrane calcium ATPase|plasma membrane calcium pump', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10324023, end_position_on_the_genomic_accession=10707962, orientation='minus', exon_count=32, OMIM=[108733], no_hdr0=''),
    492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=492, CurrentID=0, Status='live', Symbol='ATP2B3', Aliases=['CFAP39', 'CLA2', 'OPCA', 'PMCA3', 'PMCA3a', 'SCAX1'], description='ATPase plasma membrane Ca2+ transporting 3', other_designations='plasma membrane calcium-transporting ATPase 3|ATPase, Ca++ transporting, plasma membrane 3|cilia and flagella associated protein 39|plasma membrane calcium ATPase|plasma membrane calcium pump', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153517642, end_position_on_the_genomic_accession=153582929, orientation='plus', exon_count=25, OMIM=[300014], no_hdr0=''),
    493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493, CurrentID=0, Status='live', Symbol='ATP2B4', Aliases=['ATP2B2', 'MXRA1', 'PMCA4', 'PMCA4b', 'PMCA4x'], description='ATPase plasma membrane Ca2+ transporting 4', other_designations='plasma membrane calcium-transporting ATPase 4|ATPase, Ca++ transporting, plasma membrane 4|matrix-remodeling-associated protein 1|sarcolemmal calcium pump', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203626832, end_position_on_the_genomic_accession=203744081, orientation='plus', exon_count=23, OMIM=[108732], no_hdr0=''),
    495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=495, CurrentID=0, Status='live', Symbol='ATP4A', Aliases=['ATP6A'], description='ATPase H+/K+ transporting subunit alpha', other_designations='potassium-transporting ATPase alpha chain 1|ATPase H+/K+ transporting alpha subunit|ATPase, H+/K+ exchanging, alpha polypeptide|ATPase, H+/K+ transporting, alpha polypeptide|epididymis secretory sperm binding protein|gastric H+/K+ ATPase alpha subunit|gastric H,K-ATPase catalytic subunit|gastric hydrogen-potassium ATPase|proton pump', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35550031, end_position_on_the_genomic_accession=35563658, orientation='minus', exon_count=22, OMIM=[137216], no_hdr0=''),
    496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=496, CurrentID=0, Status='live', Symbol='ATP4B', Aliases=['ATP6B'], description='ATPase H+/K+ transporting subunit beta', other_designations='potassium-transporting ATPase subunit beta|ATPase H+/K+ transporting beta subunit|ATPase, H+/K+ exchanging, beta polypeptide|ATPase, H+/K+ transporting, beta polypeptide|gastric H(+)/K(+) ATPase subunit beta|gastric H+/K+ ATPase beta subunit|gastric hydrogen-potassium ATPase, beta|potassium-transporting ATPase beta chain|proton pump beta chain', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113648804, end_position_on_the_genomic_accession=113658198, orientation='minus', exon_count=7, OMIM=[137217], no_hdr0=''),
    498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=498, CurrentID=0, Status='live', Symbol='ATP5F1A', Aliases=['ATP5A', 'ATP5A1', 'ATP5AL2', 'ATPM', 'COXPD22', 'HEL-S-123m', 'MC5DN4', 'MOM2', 'OMR', 'ORM', 'hATP1'], description='ATP synthase F1 subunit alpha', other_designations='ATP synthase subunit alpha, mitochondrial|ATP synthase alpha chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, alpha subunit 1, cardiac muscle|ATP sythase (F1-ATPase) alpha subunit|epididymis secretory sperm binding protein Li 123m|mitochondrial ATP synthetase, oligomycin-resistant', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46080248, end_position_on_the_genomic_accession=46104227, orientation='minus', exon_count=13, OMIM=[164360], no_hdr0=''),
    501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=501, CurrentID=0, Status='live', Symbol='ALDH7A1', Aliases=['ATQ1', 'EPD', 'PDE'], description='aldehyde dehydrogenase 7 family member A1', other_designations='alpha-aminoadipic semialdehyde dehydrogenase|26g turgor protein homolog|P6c dehydrogenase|alpha-AASA dehydrogenase|antiquitin-1|betaine aldehyde dehydrogenase|delta1-piperideine-6-carboxylate dehydrogenase|epididymis secretory sperm binding protein', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126541841, end_position_on_the_genomic_accession=126595219, orientation='minus', exon_count=18, OMIM=[107323], no_hdr0=''),
    506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=506, CurrentID=0, Status='live', Symbol='ATP5F1B', Aliases=['ATP5B', 'ATPMB', 'ATPSB', 'HEL-S-271'], description='ATP synthase F1 subunit beta', other_designations='ATP synthase subunit beta, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, beta polypeptide|epididymis secretory protein Li 271|mitochondrial ATP synthase beta subunit|mitochondrial ATP synthetase, beta subunit', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56638175, end_position_on_the_genomic_accession=56645984, orientation='minus', exon_count=10, OMIM=[102910], no_hdr0=''),
    509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=509, CurrentID=0, Status='live', Symbol='ATP5F1C', Aliases=['ATP5C', 'ATP5C1', 'ATP5CL1'], description='ATP synthase F1 subunit gamma', other_designations='ATP synthase subunit gamma, mitochondrial|ATP synthase gamma chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, gamma polypeptide 1|F-ATPase gamma subunit|mitochondrial ATP synthase, gamma subunit 1', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7788159, end_position_on_the_genomic_accession=7807801, orientation='plus', exon_count=10, OMIM=[108729], no_hdr0=''),
    513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=513, CurrentID=0, Status='live', Symbol='ATP5F1D', Aliases=['ATP5D', 'MC5DN5'], description='ATP synthase F1 subunit delta', other_designations='ATP synthase subunit delta, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, delta subunit|F-ATPase delta subunit|mitochondrial ATP synthase complex delta-subunit precusor|mitochondrial ATP synthase, delta subunit', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1241751, end_position_on_the_genomic_accession=1244825, orientation='plus', exon_count=5, OMIM=[603150], no_hdr0=''),
    514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=514, CurrentID=0, Status='live', Symbol='ATP5F1E', Aliases=['ATP5E', 'ATPE', 'MC5DN3'], description='ATP synthase F1 subunit epsilon', other_designations='ATP synthase subunit epsilon, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, epsilon subunit|F(0)F(1)-ATPase|H(+)-transporting two-sector ATPase|mitochondrial ATP synthase epsilon chain|mitochondrial ATPase', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59025475, end_position_on_the_genomic_accession=59032335, orientation='minus', exon_count=3, OMIM=[606153], no_hdr0=''),
    515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=515, CurrentID=0, Status='live', Symbol='ATP5PB', Aliases=['ATP5F1', 'PIG47'], description='ATP synthase peripheral stalk-membrane subunit b', other_designations='ATP synthase F(0) complex subunit B1, mitochondrial|ATP synthase B chain, mitochondrial|ATP synthase proton-transporting mitochondrial F(0) complex subunit B1|ATP synthase subunit b, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit B1|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit b|ATP synthase, H+ transporting, mitochondrial Fo complex subunit B1|ATPase subunit b|H+-ATP synthase subunit b|cell proliferation-inducing protein 47', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111449464, end_position_on_the_genomic_accession=111462773, orientation='plus', exon_count=7, OMIM=[603270], no_hdr0=''),
    516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=516, CurrentID=0, Status='live', Symbol='ATP5MC1', Aliases=['ATP5A', 'ATP5G', 'ATP5G1'], description='ATP synthase membrane subunit c locus 1', other_designations='ATP synthase F(0) complex subunit C1, mitochondrial|ATP synthase lipid-binding protein, mitochondrial|ATP synthase proteolipid P1|ATP synthase proton-transporting mitochondrial F(0) complex subunit C1|ATP synthase subunit 9|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit C1 (subunit 9)|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit c (subunit 9)|ATP synthase, H+ transporting, mitochondrial Fo complex subunit C1 (subunit 9)|ATPase protein 9|ATPase subunit 9|ATPase subunit C|dicyclohexylcarbodiimide (DCCD)-reactive proteolipid subunit|mitochondrial ATP synthase, subunit 9|mitochondrial ATP synthase, subunit C', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48892787, end_position_on_the_genomic_accession=48895871, orientation='plus', exon_count=5, OMIM=[603192], no_hdr0=''),
    517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=517, CurrentID=0, Status='live', Symbol='ATP5MC2', Aliases=['ATP5A', 'ATP5G2'], description='ATP synthase membrane subunit c locus 2', other_designations='ATP synthase F(0) complex subunit C2, mitochondrial|ATP synthase c subunit|ATP synthase lipid-binding protein, mitochondrial|ATP synthase proteolipid P2|ATP synthase proton-transporting mitochondrial F(0) complex subunit C2|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit C2 (subunit 9)|ATP synthase, H+ transporting, mitochondrial Fo complex subunit C2 (subunit 9)|ATPase protein 9|ATPase subunit C|dicyclohexylcarbodiimide (DCCD)-reactive proteolipid subunit', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53665166, end_position_on_the_genomic_accession=53677546, orientation='minus', exon_count=10, OMIM=[603193], no_hdr0=''),
    518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=518, CurrentID=0, Status='live', Symbol='ATP5MC3', Aliases=['ATP5G3', 'P3'], description='ATP synthase membrane subunit c locus 3', other_designations='ATP synthase F(0) complex subunit C3, mitochondrial|ATP synthase lipid-binding protein, mitochondrial|ATP synthase proteolipid P3|ATP synthase proton-transporting mitochondrial F(0) complex subunit C3|ATP synthase subunit 9|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit C3 (subunit 9)|ATP synthase, H+ transporting, mitochondrial Fo complex subunit C3 (subunit 9)|ATP synthase, mitochondrial, C subunit-3|ATPase protein 9|ATPase subunit C|dicyclohexylcarbodiimide (DCCD)-reactive proteolipid subunit', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=175176258, end_position_on_the_genomic_accession=175181710, orientation='minus', exon_count=4, OMIM=[602736], no_hdr0=''),
    521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=521, CurrentID=0, Status='live', Symbol='ATP5ME', Aliases=['ATP5I', 'ATP5K'], description='ATP synthase membrane subunit e', other_designations='ATP synthase subunit e, mitochondrial|ATP synthase e chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit E|ATP synthase, H+ transporting, mitochondrial Fo complex subunit E|ATPase subunit e|F1F0-ATP synthase, murine e subunit', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=672436, end_position_on_the_genomic_accession=674276, orientation='minus', exon_count=4, OMIM=[601519], no_hdr0=''),
    522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=522, CurrentID=0, Status='live', Symbol='ATP5PF', Aliases=['ATP5', 'ATP5A', 'ATP5J', 'ATPM', 'CF6', 'F6'], description='ATP synthase peripheral stalk subunit F6', other_designations='ATP synthase-coupling factor 6, mitochondrial|ATP synthase subunit h|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit F6|ATP synthase, H+ transporting, mitochondrial Fo complex subunit F6|ATPase subunit F6|coupling factor 6|mitochondrial ATP synthase, coupling factor 6|mitochondrial ATP synthase, subunit F6|mitochondrial ATPase coupling factor 6|proliferation-inducing protein 36', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=25724500, end_position_on_the_genomic_accession=25735653, orientation='minus', exon_count=7, OMIM=[603152], no_hdr0=''),
    523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=523, CurrentID=0, Status='live', Symbol='ATP6V1A', Aliases=['ARCL2D', 'ATP6A11', 'DEE93', 'HO68', 'IECEE3', 'VA68', 'VPP2', 'Vma1', 'ATP6V1A'], description='ATPase H+ transporting V1 subunit A', other_designations='V-type proton ATPase catalytic subunit A|ATPase, H+ transporting, lysosomal 70kDa, V1 subunit A|ATPase, H+ transporting, lysosomal, subunit A1|H(+)-transporting two-sector ATPase, subunit A|H+-transporting ATPase chain A, vacuolar (VA68 type)|V-ATPase 69 kDa subunit 1|V-ATPase A subunit 1|V-ATPase subunit A|V-type proton ATPase (V-ATPase) catalytic subunit A|vacuolar proton pump alpha subunit 1|vacuolar proton pump subunit alpha', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113747035, end_position_on_the_genomic_accession=113812056, orientation='plus', exon_count=15, OMIM=[607027], no_hdr0=''),
    525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=525, CurrentID=0, Status='live', Symbol='ATP6V1B1', Aliases=['ATP6B1', 'DRTA2', 'RTA1B', 'VATB', 'VMA2', 'VPP3'], description='ATPase H+ transporting V1 subunit B1', other_designations='V-type proton ATPase subunit B, kidney isoform|ATPase, H+ transporting, lysosomal 56/58kDa, V1 subunit B1|H(+)-transporting two-sector ATPase, 58kD subunit|H+-ATPase beta 1 subunit|V-ATPase B1 subunit|V-ATPase subunit B 1|endomembrane proton pump 58 kDa subunit|vacuolar proton pump 3|vacuolar proton pump subunit B 1|vacuolar proton pump, subunit 3', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70935900, end_position_on_the_genomic_accession=70965431, orientation='plus', exon_count=15, OMIM=[192132], no_hdr0=''),
    526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=526, CurrentID=0, Status='live', Symbol='ATP6V1B2', Aliases=['ATP6B1B2', 'ATP6B2', 'DOOD', 'HO57', 'VATB', 'VPP3', 'Vma2', 'ZLS2'], description='ATPase H+ transporting V1 subunit B2', other_designations='V-type proton ATPase subunit B, brain isoform|ATPase, H+ transporting, lysosomal 56/58kDa, V1 subunit B2|H+ transporting two-sector ATPase|V-ATPase B2 subunit|V-ATPase subunit B 2|endomembrane proton pump 58 kDa subunit|testicular secretory protein Li 65|vacuolar H+-ATPase 56,000 subunit|vacuolar proton pump subunit B 2', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=20197375, end_position_on_the_genomic_accession=20226852, orientation='plus', exon_count=14, OMIM=[606939], no_hdr0=''),
    527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=527, CurrentID=0, Status='live', Symbol='ATP6V0C', Aliases=['ATP6C', 'ATP6L', 'ATPL', 'VATL', 'VPPC', 'Vma3'], description='ATPase H+ transporting V0 subunit c', other_designations='V-type proton ATPase 16 kDa proteolipid subunit|ATPase, H+ transporting, lysosomal 16kDa, V0 subunit c|H(+)-transporting two-sector ATPase, 16 kDa subunit|V-ATPase 16 kDa proteolipid subunit|vacuolar ATP synthase 16 kDa proteolipid subunit|vacuolar H+ ATPase proton channel subunit|vacuolar proton pump 16 kDa proteolipid subunit', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2513726, end_position_on_the_genomic_accession=2520218, orientation='plus', exon_count=4, OMIM=[108745], no_hdr0=''),
    528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=528, CurrentID=0, Status='live', Symbol='ATP6V1C1', Aliases=['ATP6C', 'ATP6D', 'VATC', 'Vma5'], description='ATPase H+ transporting V1 subunit C1', other_designations='V-type proton ATPase subunit C 1|ATPase, H+ transporting, lysosomal 42kDa, V1 subunit C1|H(+)-transporting two-sector ATPase, subunit C|H+ -ATPase C subunit|H+-transporting ATPase chain C, vacuolar|V-ATPase C subunit|V-ATPase subunit C 1|subunit C of vacuolar proton-ATPase V1 domain|testicular tissue protein Li 223|vacuolar ATP synthase subunit C|vacuolar proton pump C subunit|vacuolar proton pump subunit C 1|vacuolar proton pump, 42-kD subunit|vacuolar proton-ATPase, subunit C, VI domain', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103021083, end_position_on_the_genomic_accession=103073051, orientation='plus', exon_count=13, OMIM=[603097], no_hdr0=''),
    529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=529, CurrentID=0, Status='live', Symbol='ATP6V1E1', Aliases=['ARCL2C', 'ATP6E', 'ATP6E2', 'ATP6V1E', 'P31', 'Vma4'], description='ATPase H+ transporting V1 subunit E1', other_designations='V-type proton ATPase subunit E 1|ATPase, H+ transporting, lysosomal 31kDa, V1 subunit E1|H(+)-transporting two-sector ATPase, 31kDa subunit|H+-transporting ATP synthase chain E, vacuolar|V-ATPase 31 kDa subunit|V-ATPase subunit E 1|V-ATPase, subunit E|vacuolar proton pump subunit E 1', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17592136, end_position_on_the_genomic_accession=17628822, orientation='minus', exon_count=9, OMIM=[108746], no_hdr0=''),
    533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=533, CurrentID=0, Status='live', Symbol='ATP6V0B', Aliases=['ATP6F', 'HATPL', 'VMA16'], description='ATPase H+ transporting V0 subunit b', other_designations="V-type proton ATPase 21 kDa proteolipid subunit|ATPase, H+ transporting, lysosomal 21kDa, V0 subunit b|ATPase, H+ transporting, lysosomal, 21-KD, V0 subunit C-prime, prime|ATPase, H+ transporting, lysosomal, subunit F|H(+)-transporting two-sector ATPase, subunit F|V-ATPase 21 kDa proteolipid subunit|V-ATPase subunit b|V-ATPase subunit c''|vacuolar ATP synthase 21 kDa proteolipid subunit|vacuolar proton pump 21 kDa proteolipid subunit", map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43974960, end_position_on_the_genomic_accession=43978295, orientation='plus', exon_count=8, OMIM=[603717], no_hdr0=''),
    534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=534, CurrentID=0, Status='live', Symbol='ATP6V1G2', Aliases=['ATP6G', 'ATP6G2', 'NG38', 'VMA10'], description='ATPase H+ transporting V1 subunit G2', other_designations='V-type proton ATPase subunit G 2|ATPase, H+ transporting, lysosomal (vacuolar proton pump)|ATPase, H+ transporting, lysosomal 13kDa, V1 subunit G2|H(+)-transporting two-sector ATPase, subunit G2|V-ATPase 13 kDa subunit 2|vacuolar ATP synthase subunit G 2|vacuolar proton pump G subunit 2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31544444, end_position_on_the_genomic_accession=31546742, orientation='minus', exon_count=4, OMIM=[606853], no_hdr0=''),
    535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=535, CurrentID=0, Status='live', Symbol='ATP6V0A1', Aliases=['ATP6N1', 'ATP6N1A', 'Stv1', 'VPP1', 'Vph1', 'a1'], description='ATPase H+ transporting V0 subunit a1', other_designations='V-type proton ATPase 116 kDa subunit a1|ATPase, H+ transporting, lysosomal V0 subunit a1|ATPase, H+ transporting, lysosomal non-catalytic accessory protein 1 (110/116kD)|H(+)-transporting two-sector ATPase, 116 kDa accessory protein A1|V-ATPase 116 kDa subunit a1|V-ATPase subunit a1|V-type proton ATPase 116 kDa subunit a|clathrin-coated vesicle/synaptic vesicle proton pump 116 kDa subunit|vacuolar adenosine triphosphatase subunit Ac116|vacuolar proton pump subunit 1|vacuolar proton translocating ATPase 116 kDa subunit A|vacuolar-type H(+)-ATPase 115 kDa subunit', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42458874, end_position_on_the_genomic_accession=42522579, orientation='plus', exon_count=25, OMIM=[192130], no_hdr0=''),
    537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=537, CurrentID=0, Status='live', Symbol='ATP6AP1', Aliases=['16A', 'ATP6IP1', 'ATP6S1', 'Ac45', 'CF2', 'VATPS1', 'XAP-3', 'XAP3'], description='ATPase H+ transporting accessory protein 1', other_designations='V-type proton ATPase subunit S1|ATPase, H+ transporting, lysosomal (vacuolar proton pump), subunit 1|ATPase, H+ transporting, lysosomal accessory protein 1|ATPase, H+ transporting, lysosomal interacting protein 1|H-ATPase subunit|V-ATPase Ac45 subunit|V-ATPase S1 accessory protein|V-ATPase subunit S1|X-associated protein 3|epididymis secretory sperm binding protein|protein XAP-3|vacuolar ATPase subunit S1|vacuolar proton pump subunit S1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154428669, end_position_on_the_genomic_accession=154436516, orientation='plus', exon_count=11, OMIM=[300197], no_hdr0=''),
    538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=538, CurrentID=0, Status='live', Symbol='ATP7A', Aliases=['DSMAX', 'MK', 'MNK', 'SMAX3'], description='ATPase copper transporting alpha', other_designations='copper-transporting ATPase 1|ATPase, Cu++ transporting, alpha polypeptide|Cu++-transporting P-type ATPase|Menkes disease-associated protein|copper pump 1', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77910693, end_position_on_the_genomic_accession=78050395, orientation='plus', exon_count=23, OMIM=[300011], no_hdr0=''),
    539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=539, CurrentID=0, Status='live', Symbol='ATP5PO', Aliases=['ATP5O', 'ATPO', 'HMC08D05', 'OSCP'], description='ATP synthase peripheral stalk subunit OSCP', other_designations='ATP synthase subunit O, mitochondrial|ATP synthase, H+ transporting, mitochondrial F1 complex, O subunit|human ATP synthase OSCP subunit|oligomycin sensitivity conferral protein oscp-like protein|oligomycin sensitivity conferring protein', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33903453, end_position_on_the_genomic_accession=33915804, orientation='minus', exon_count=7, OMIM=[600828], no_hdr0=''),
    540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=540, CurrentID=0, Status='live', Symbol='ATP7B', Aliases=['PWD', 'WC1', 'WD', 'WND'], description='ATPase copper transporting beta', other_designations='copper-transporting ATPase 2|ATPase, Cu(2+)- transporting, beta polypeptide|ATPase, Cu++ transporting, beta polypeptide|Wilson disease-associated protein|copper pump 2|copper-transporting protein ATP7B', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51932669, end_position_on_the_genomic_accession=52012130, orientation='minus', exon_count=29, OMIM=[606882], no_hdr0=''),
    545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=545, CurrentID=0, Status='live', Symbol='ATR', Aliases=['FCTCS', 'FRP1', 'MEC1', 'SCKL', 'SCKL1'], description='ATR serine/threonine kinase', other_designations='serine/threonine-protein kinase ATR|FRAP-related protein-1|MEC1, mitosis entry checkpoint 1, homolog|ataxia telangiectasia and Rad3-related protein', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142449235, end_position_on_the_genomic_accession=142578793, orientation='minus', exon_count=49, OMIM=[601215], no_hdr0=''),
    546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=546, CurrentID=0, Status='live', Symbol='ATRX', Aliases=['JMS', 'MRX52', 'RAD54', 'RAD54L', 'XH2', 'XNP', 'ZNF-HX'], description='ATRX chromatin remodeler', other_designations='transcriptional regulator ATRX|ATP-dependent helicase ATRX|X-linked helicase II|X-linked nuclear protein|alpha thalassemia/mental retardation syndrome X-linked (RAD54 homolog, S. cerevisiae)', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77504880, end_position_on_the_genomic_accession=77786235, orientation='minus', exon_count=37, OMIM=[300032], no_hdr0=''),
    547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=547, CurrentID=0, Status='live', Symbol='KIF1A', Aliases=['ATSV', 'C2orf20', 'HSN2C', 'MRD9', 'NESCAVS', 'SPG30', 'UNC104'], description='kinesin family member 1A', other_designations='kinesin-like protein KIF1A|axonal transporter of synaptic vesicles|kinesin, heavy chain, member 1A, homolog of mouse|microtubule-based motor KIF1A|unc-104- and KIF1A-related protein', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240713767, end_position_on_the_genomic_accession=240821403, orientation='minus', exon_count=55, OMIM=[601255], no_hdr0=''),
    549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=549, CurrentID=0, Status='live', Symbol='AUH', Aliases=[], description='AU RNA binding methylglutaconyl-CoA hydratase', other_designations='methylglutaconyl-CoA hydratase, mitochondrial|3-methylglutaconyl-CoA hydratase|AU RNA binding protein/enoyl-CoA hydratase|AU RNA-binding protein/enoyl-Coenzyme A hydratase|AU-binding protein/Enoyl-CoA hydratase|AU-specific RNA-binding enoyl-CoA hydratase|itaconyl-CoA hydratase', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=91213823, end_position_on_the_genomic_accession=91361945, orientation='minus', exon_count=16, OMIM=[600529], no_hdr0=''),
    550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=550, CurrentID=0, Status='live', Symbol='AUP1', Aliases=[], description='AUP1 lipid droplet regulating VLDL assembly factor', other_designations='lipid droplet-regulating VLDL assembly factor AUP1|ancient ubiquitous protein 1', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74526652, end_position_on_the_genomic_accession=74529706, orientation='minus', exon_count=12, OMIM=[602434], no_hdr0=''),
    551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=551, CurrentID=0, Status='live', Symbol='AVP', Aliases=['ADH', 'ARVP-NPII', 'AVRP', 'VP', 'AVP'], description='arginine vasopressin', other_designations='vasopressin-neurophysin 2-copeptin|antidiuretic hormone|copeptin|neurohypophyseal|prepro-AVP-NP II|prepro-arginine-vasopressin-neurophysin II|vasopressin-neurophysin II-copeptin', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3082556, end_position_on_the_genomic_accession=3093521, orientation='minus', exon_count=4, OMIM=[192340], no_hdr0=''),
    552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=552, CurrentID=0, Status='live', Symbol='AVPR1A', Aliases=['AVPR V1a', 'AVPR1', 'V1aR'], description='arginine vasopressin receptor 1A', other_designations='vasopressin V1a receptor|SCCL vasopressin subtype 1a receptor|V1-vascular vasopressin receptor AVPR1A|V1a vasopressin receptor|antidiuretic hormone receptor 1A|vascular/hepatic-type arginine vasopressin receptor', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=63142759, end_position_on_the_genomic_accession=63151201, orientation='minus', exon_count=2, OMIM=[600821], no_hdr0=''),
    553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=553, CurrentID=0, Status='live', Symbol='AVPR1B', Aliases=['AVPR3', 'V1bR'], description='arginine vasopressin receptor 1B', other_designations='vasopressin V1b receptor|AVPR V1b|AVPR V3|antidiuretic hormone receptor 1B|arginine vasopressin receptor 3|pituitary vasopressin receptor 3|vasopressin V3 receptor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206106936, end_position_on_the_genomic_accession=206117388, orientation='minus', exon_count=2, OMIM=[600264], no_hdr0=''),
    554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554, CurrentID=0, Status='live', Symbol='AVPR2', Aliases=['ADHR', 'DI1', 'DIR', 'DIR3', 'NDI', 'NDI1', 'V2R'], description='arginine vasopressin receptor 2', other_designations='vasopressin V2 receptor|AVPR V2|antidiuretic hormone receptor|renal-type arginine vasopressin receptor', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153902625, end_position_on_the_genomic_accession=153907166, orientation='plus', exon_count=5, OMIM=[300538], no_hdr0=''),
    558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=558, CurrentID=0, Status='live', Symbol='AXL', Aliases=['ARK', 'JTK11', 'Tyro7', 'UFO'], description='AXL receptor tyrosine kinase', other_designations='tyrosine-protein kinase receptor UFO|AXL oncogene|AXL transforming sequence/gene', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41219223, end_position_on_the_genomic_accession=41261766, orientation='plus', exon_count=21, OMIM=[109135], no_hdr0=''),
    563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=563, CurrentID=0, Status='live', Symbol='AZGP1', Aliases=['ZA2G', 'ZAG'], description='alpha-2-glycoprotein 1, zinc-binding', other_designations='zinc-alpha-2-glycoprotein|Alpha-2-glycoprotein, zinc|Zn-alpha2-glycoprotein|testicular tissue protein Li 227|zn-alpha-2-GP|zn-alpha-2-glycoprotein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99966730, end_position_on_the_genomic_accession=99976031, orientation='minus', exon_count=4, OMIM=[194460], no_hdr0=''),
    566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=566, CurrentID=0, Status='live', Symbol='AZU1', Aliases=['AZAMP', 'AZU', 'CAP37', 'HBP', 'HUMAZUR', 'NAZC', 'hHBP'], description='azurocidin 1', other_designations='azurocidin|cationic antimicrobial protein 37|cationic antimicrobial protein CAP37|heparin-binding protein|neutrophil azurocidin', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=827837, end_position_on_the_genomic_accession=832018, orientation='plus', exon_count=5, OMIM=[162815], no_hdr0=''),
    567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=567, CurrentID=0, Status='live', Symbol='B2M', Aliases=['IMD43'], description='beta-2-microglobulin', other_designations='beta-2-microglobulin|beta chain of MHC class I molecules|beta-2-microglobin', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44711492, end_position_on_the_genomic_accession=44718145, orientation='plus', exon_count=3, OMIM=[109700], no_hdr0=''),
    570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=570, CurrentID=0, Status='live', Symbol='BAAT', Aliases=['BACAT', 'BACD1', 'BAT', 'HCHO'], description='bile acid-CoA:amino acid N-acyltransferase', other_designations='bile acid-CoA:amino acid N-acyltransferase|bile acid CoA: amino acid N-acyltransferase (glycine N-choloyltransferase)|bile acid Coenzyme A: amino acid N-acyltransferase (glycine N-choloyltransferase)|bile acid-CoA thioesterase|choloyl-CoA hydrolase|long-chain fatty-acyl-CoA hydrolase', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101360417, end_position_on_the_genomic_accession=101385006, orientation='minus', exon_count=6, OMIM=[602938], no_hdr0=''),
    571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=571, CurrentID=0, Status='live', Symbol='BACH1', Aliases=['BACH-1', 'BTBD24'], description='BTB domain and CNC homolog 1', other_designations='transcription regulator protein BACH1|BTB and CNC homology 1, basic leucine zipper transcription factor 1|basic region leucine zipper transcriptional regulator BACH1', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29298922, end_position_on_the_genomic_accession=29361894, orientation='plus', exon_count=11, OMIM=[602751], no_hdr0=''),
    572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=572, CurrentID=0, Status='live', Symbol='BAD', Aliases=['BBC2', 'BCL2L8'], description='BCL2 associated agonist of cell death', other_designations='bcl2-associated agonist of cell death|BCL-X/BCL-2 binding protein|BCL2-antagonist of cell death protein|BCL2-binding component 6|BCL2-binding protein|bcl-2-binding component 6|bcl-2-like protein 8|bcl-XL/Bcl-2-associated death promoter|bcl2 antagonist of cell death|bcl2-L-8', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64269828, end_position_on_the_genomic_accession=64284704, orientation='minus', exon_count=4, OMIM=[603167], no_hdr0=''),
    573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=573, CurrentID=0, Status='live', Symbol='BAG1', Aliases=['BAG-1', 'HAP', 'RAP46'], description='BAG cochaperone 1', other_designations='BAG family molecular chaperone regulator 1|BCL2 associated athanogene 1|BCL2-associated athanogene|Bcl-2 associating athanogene-1 protein|Bcl-2-binding protein|glucocortoid receptor-associated protein RAP46|receptor-associated protein, 46-KD', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33252471, end_position_on_the_genomic_accession=33264708, orientation='minus', exon_count=7, OMIM=[601497], no_hdr0=''),
    574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=574, CurrentID=0, Status='live', Symbol='BAGE', Aliases=['BAGE1', 'CT2.1'], description='B melanoma antigen', other_designations='B melanoma antigen 1|antigen MZ2-BA|cancer/testis antigen 2.1|cancer/testis antigen family 2, member 1', map_location='21p11.1', chromosome='21', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[605167], no_hdr0=''),
    575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=575, CurrentID=0, Status='live', Symbol='ADGRB1', Aliases=['BAI1', 'GDAIF'], description='adhesion G protein-coupled receptor B1', other_designations='adhesion G protein-coupled receptor B1|brain-specific angiogenesis inhibitor 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142449649, end_position_on_the_genomic_accession=142545009, orientation='plus', exon_count=35, OMIM=[602682], no_hdr0=''),
    576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=576, CurrentID=0, Status='live', Symbol='ADGRB2', Aliases=['BAI2'], description='adhesion G protein-coupled receptor B2', other_designations='adhesion G protein-coupled receptor B2|brain-specific angiogenesis inhibitor 2', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31727105, end_position_on_the_genomic_accession=31764340, orientation='minus', exon_count=32, OMIM=[602683], no_hdr0=''),
    577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=577, CurrentID=0, Status='live', Symbol='ADGRB3', Aliases=['BAI3'], description='adhesion G protein-coupled receptor B3', other_designations='adhesion G protein-coupled receptor B3|brain-specific angiogenesis inhibitor 3|dJ91B17.1 (brain-specific angiogenesis inhibitor 3)', map_location='6q12-q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=68635282, end_position_on_the_genomic_accession=69389506, orientation='plus', exon_count=32, OMIM=[602684], no_hdr0=''),
    578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=578, CurrentID=0, Status='live', Symbol='BAK1', Aliases=['BAK', 'BAK-LIKE', 'BCL2L7', 'CDN1'], description='BCL2 antagonist/killer 1', other_designations='bcl-2 homologous antagonist/killer|BCL2-like 7 protein|apoptosis regulator BAK|bcl-2-like protein 7|bcl2-L-7|pro-apoptotic protein BAK', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33572552, end_position_on_the_genomic_accession=33580296, orientation='minus', exon_count=7, OMIM=[600516], no_hdr0=''),
    579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=579, CurrentID=0, Status='live', Symbol='NKX3-2', Aliases=['BAPX1', 'NKX3.2', 'NKX3B', 'SMMD'], description='NK3 homeobox 2', other_designations='homeobox protein Nkx-3.2|bagpipe homeobox protein homolog 1|homeobox protein NK-3 homolog B', map_location='4p15.33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=13540830, end_position_on_the_genomic_accession=13544508, orientation='minus', exon_count=2, OMIM=[602183], no_hdr0=''),
    580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=580, CurrentID=0, Status='live', Symbol='BARD1', Aliases=[], description='BRCA1 associated RING domain 1', other_designations='BRCA1-associated RING domain protein 1|BRCA1-associated RING domain gene 1|RING-type E3 ubiquitin transferase BARD1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=214725645, end_position_on_the_genomic_accession=214809683, orientation='minus', exon_count=13, OMIM=[601593], no_hdr0=''),
    581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=581, CurrentID=0, Status='live', Symbol='BAX', Aliases=['BCL2L4'], description='BCL2 associated X, apoptosis regulator', other_designations='apoptosis regulator BAX|BCL2 associated X protein|BCL2-associated X protein omega|Baxdelta2G9|Baxdelta2G9omega|Baxdelta2omega|bcl-2-like protein 4|bcl2-L-4', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48954825, end_position_on_the_genomic_accession=48961798, orientation='plus', exon_count=7, OMIM=[600040], no_hdr0=''),
    582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=582, CurrentID=0, Status='live', Symbol='BBS1', Aliases=['BBS2L2'], description='Bardet-Biedl syndrome 1', other_designations='Bardet-Biedl syndrome 1 protein|BBS2-like protein 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66510635, end_position_on_the_genomic_accession=66533598, orientation='plus', exon_count=17, OMIM=[209901], no_hdr0=''),
    583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=583, CurrentID=0, Status='live', Symbol='BBS2', Aliases=['BBS', 'RP74'], description='Bardet-Biedl syndrome 2', other_designations='Bardet-Biedl syndrome 2 protein', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56470403, end_position_on_the_genomic_accession=56520095, orientation='minus', exon_count=18, OMIM=[606151], no_hdr0=''),
    585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=585, CurrentID=0, Status='live', Symbol='BBS4', Aliases=[], description='Bardet-Biedl syndrome 4', other_designations='Bardet-Biedl syndrome 4 protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72686204, end_position_on_the_genomic_accession=72738476, orientation='plus', exon_count=17, OMIM=[600374], no_hdr0=''),
    586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=586, CurrentID=0, Status='live', Symbol='BCAT1', Aliases=['BCATC', 'BCT1', 'ECA39', 'MECA39', 'PNAS121', 'PP18'], description='branched chain amino acid transaminase 1', other_designations='branched-chain-amino-acid aminotransferase, cytosolic|branched chain amino-acid transaminase 1, cytosolic|branched chain aminotransferase 1, cytosolic|placental protein 18', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=24810024, end_position_on_the_genomic_accession=24949101, orientation='minus', exon_count=14, OMIM=[113520], no_hdr0=''),
    587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=587, CurrentID=0, Status='live', Symbol='BCAT2', Aliases=['BCAM', 'BCATM', 'BCT2', 'HVLI', 'PP18'], description='branched chain amino acid transaminase 2', other_designations='branched-chain-amino-acid aminotransferase, mitochondrial|branched chain amino-acid transaminase 2, mitochondrial|branched chain aminotransferase 2, mitochondrial|placental protein 18', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48795064, end_position_on_the_genomic_accession=48811029, orientation='minus', exon_count=13, OMIM=[113530], no_hdr0=''),
    590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=590, CurrentID=0, Status='live', Symbol='BCHE', Aliases=['BCHED', 'CHE1', 'CHE2', 'E1'], description='butyrylcholinesterase', other_designations='cholinesterase|acylcholine acylhydrolase|butyrylcholine esterase|choline esterase II|cholinesterase (serum) 2|cholinesterase 1|pseudocholinesterase', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=165772904, end_position_on_the_genomic_accession=165837423, orientation='minus', exon_count=5, OMIM=[177400], no_hdr0=''),
    593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=593, CurrentID=0, Status='live', Symbol='BCKDHA', Aliases=['BCKDE1A', 'MSU', 'MSUD1', 'OVD1A'], description='branched chain keto acid dehydrogenase E1 subunit alpha', other_designations='2-oxoisovalerate dehydrogenase subunit alpha, mitochondrial|2-oxoisovalerate dehydrogenase (lipoamide)|BCKDH E1-alpha|branched chain keto acid dehydrogenase E1 alpha protein|branched chain keto acid dehydrogenase E1, alpha polypeptide|branched-chain alpha-keto acid dehydrogenase E1 component alpha chain', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41397818, end_position_on_the_genomic_accession=41425002, orientation='plus', exon_count=9, OMIM=[608348], no_hdr0=''),
    594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=594, CurrentID=0, Status='live', Symbol='BCKDHB', Aliases=['BCKDE1B', 'BCKDH E1-beta', 'E1B'], description='branched chain keto acid dehydrogenase E1 subunit beta', other_designations='2-oxoisovalerate dehydrogenase subunit beta, mitochondrial|E1b-beta subunit of the branched-chain complex|branched chain alpha-ketoacid dehydrogenase E1-beta subunit|branched chain keto acid dehydrogenase E1 beta|branched chain keto acid dehydrogenase E1, beta polypeptide|branched-chain alpha-keto acid dehydrogenase E1 component beta chain|testis secretory sperm-binding protein Li 240mP', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=80106610, end_position_on_the_genomic_accession=80469088, orientation='plus', exon_count=21, OMIM=[248611], no_hdr0=''),
    595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=595, CurrentID=0, Status='live', Symbol='CCND1', Aliases=['BCL1', 'D11S287E', 'PRAD1', 'U21B31'], description='cyclin D1', other_designations='G1/S-specific cyclin-D1|B-cell CLL/lymphoma 1|B-cell lymphoma 1 protein|BCL-1 oncogene|PRAD1 oncogene', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69641156, end_position_on_the_genomic_accession=69654474, orientation='plus', exon_count=5, OMIM=[168461], no_hdr0=''),
    596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=596, CurrentID=0, Status='live', Symbol='BCL2', Aliases=['Bcl-2', 'PPP1R50'], description='BCL2 apoptosis regulator', other_designations='apoptosis regulator Bcl-2|B-cell CLL/lymphoma 2|protein phosphatase 1, regulatory subunit 50', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63123346, end_position_on_the_genomic_accession=63320280, orientation='minus', exon_count=6, OMIM=[151430], no_hdr0=''),
    597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=597, CurrentID=0, Status='live', Symbol='BCL2A1', Aliases=['ACC-1', 'ACC-2', 'ACC1', 'ACC2', 'BCL2L5', 'BFL1', 'GRS', 'HBPA1'], description='BCL2 related protein A1', other_designations='bcl-2-related protein A1|bcl-2-like protein 5|bcl2-L-5|hematopoietic BCL2-related protein A1|hemopoietic-specific early response protein|protein BFL-1', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79960892, end_position_on_the_genomic_accession=79971196, orientation='minus', exon_count=3, OMIM=[601056], no_hdr0=''),
    598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=598, CurrentID=0, Status='live', Symbol='BCL2L1', Aliases=['BCL-XL/S', 'BCL2L', 'BCLX', 'Bcl-X', 'PPP1R52'], description='BCL2 like 1', other_designations='bcl-2-like protein 1|apoptosis regulator Bcl-X|protein phosphatase 1, regulatory subunit 52', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31664452, end_position_on_the_genomic_accession=31723963, orientation='minus', exon_count=6, OMIM=[600039], no_hdr0=''),
    599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=599, CurrentID=0, Status='live', Symbol='BCL2L2', Aliases=['BCL-W', 'BCL2-L-2', 'BCLW', 'PPP1R51'], description='BCL2 like 2', other_designations='bcl-2-like protein 2|apoptosis regulator BCL-W|protein phosphatase 1, regulatory subunit 51', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23306833, end_position_on_the_genomic_accession=23311751, orientation='plus', exon_count=4, OMIM=[601931], no_hdr0=''),
    602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=602, CurrentID=0, Status='live', Symbol='BCL3', Aliases=['BCL4', 'D19S37'], description='BCL3 transcription coactivator', other_designations='B-cell lymphoma 3 protein|B cell CLL/lymphoma 3|B-cell leukemia/lymphoma 3|B-cell lymphoma 3-encoded protein|BCL-3|chronic lymphatic leukemia protein|proto-oncogene BCL3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44742620, end_position_on_the_genomic_accession=44760044, orientation='plus', exon_count=13, OMIM=[109560], no_hdr0=''),
    604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=604, CurrentID=0, Status='live', Symbol='BCL6', Aliases=['BCL5A', 'LAZ3', 'ZBTB27', 'ZNF51', 'BCL6'], description='BCL6 transcription repressor', other_designations='B-cell lymphoma 6 protein|B cell CLL/lymphoma 6|B-cell lymphoma 5 protein|B-cell lymphoma 6 protein transcript|BCL-5|BCL-6|cys-his2 zinc finger transcription factor|lymphoma-associated zinc finger gene on chromosome 3|protein LAZ-3|zinc finger and BTB domain-containing protein 27|zinc finger protein 51|zinc finger transcription factor BCL6S', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187721377, end_position_on_the_genomic_accession=187745472, orientation='minus', exon_count=12, OMIM=[109565], no_hdr0=''),
    605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=605, CurrentID=0, Status='live', Symbol='BCL7A', Aliases=['BCL7'], description='BAF chromatin remodeling complex subunit BCL7A', other_designations='B-cell CLL/lymphoma 7 protein family member A|B-cell CLL/lymphoma 7A|B-cell CLL/lymphoma-7|BCL tumor suppressor 7A|BCL7A, BAF complex component', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122021884, end_position_on_the_genomic_accession=122062044, orientation='plus', exon_count=6, OMIM=[601406], no_hdr0=''),
    607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=607, CurrentID=0, Status='live', Symbol='BCL9', Aliases=['LGS'], description='BCL9 transcription coactivator', other_designations='B-cell CLL/lymphoma 9 protein|B cell CLL/lymphoma 9|B-cell lymphoma 9 protein|bcl-9|protein legless homolog', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147541501, end_position_on_the_genomic_accession=147626217, orientation='plus', exon_count=11, OMIM=[602597], no_hdr0=''),
    608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=608, CurrentID=0, Status='live', Symbol='TNFRSF17', Aliases=['BCM', 'BCMA', 'CD269', 'TNFRSF13A'], description='TNF receptor superfamily member 17', other_designations='tumor necrosis factor receptor superfamily member 17|B cell maturation antigen|B-cell maturation factor|B-cell maturation protein', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11965210, end_position_on_the_genomic_accession=11968068, orientation='plus', exon_count=3, OMIM=[109545], no_hdr0=''),
    610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=610, CurrentID=0, Status='live', Symbol='HCN2', Aliases=['BCNG-2', 'BCNG2', 'HAC-1'], description='hyperpolarization activated cyclic nucleotide gated potassium and sodium channel 2', other_designations='potassium/sodium hyperpolarization-activated cyclic nucleotide-gated channel 2|brain cyclic nucleotide-gated channel 2|hyperpolarization activated cyclic nucleotide gated potassium channel 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=589881, end_position_on_the_genomic_accession=617159, orientation='plus', exon_count=8, OMIM=[602781], no_hdr0=''),
    611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=611, CurrentID=0, Status='live', Symbol='OPN1SW', Aliases=['BCP', 'BOP', 'CBT'], description='opsin 1, short wave sensitive', other_designations='short-wave-sensitive opsin 1|blue cone photoreceptor pigment|blue-sensitive opsin|opsin 1 (cone pigments), short-wave-sensitive', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128772485, end_position_on_the_genomic_accession=128775794, orientation='minus', exon_count=5, OMIM=[613522], no_hdr0=''),
    613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613, CurrentID=0, Status='live', Symbol='BCR', Aliases=['ALL1', 'CML', 'D22S11', 'D22S662', 'PHL', 'BCR'], description='BCR activator of RhoGEF and GTPase', other_designations='breakpoint cluster region protein|BCR, RhoGEF and GTPase activating protein|BCR/FGFR1 chimera protein|FGFR1/BCR chimera protein|breakpoint cluster region|renal carcinoma antigen NY-REN-26', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23180509, end_position_on_the_genomic_accession=23318037, orientation='plus', exon_count=23, OMIM=[151410], no_hdr0=''),
    617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=617, CurrentID=0, Status='live', Symbol='BCS1L', Aliases=['BCS', 'BCS1', 'BJS', 'FLNMS', 'GRACILE', 'Hs.6719', 'MC3DN1', 'PTD', 'h-BCS', 'h-BCS1'], description='BCS1 homolog, ubiquinol-cytochrome c reductase complex chaperone', other_designations='mitochondrial chaperone BCS1|BC1 (ubiquinol-cytochrome c reductase) synthesis-like|BCS1-like protein|mitochondrial complex III assembly', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218659683, end_position_on_the_genomic_accession=218663443, orientation='plus', exon_count=8, OMIM=[603647], no_hdr0=''),
    622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=622, CurrentID=0, Status='live', Symbol='BDH1', Aliases=['BDH', 'SDR9C1'], description='3-hydroxybutyrate dehydrogenase 1', other_designations='D-beta-hydroxybutyrate dehydrogenase, mitochondrial|(R)-3-hydroxybutyrate dehydrogenase|3-hydroxybutyrate dehydrogenase (heart, mitochondrial)|3-hydroxybutyrate dehydrogenase, type 1|epididymis secretory sperm binding protein|short chain dehydrogenase/reductase family 9C member 1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197509783, end_position_on_the_genomic_accession=197573343, orientation='minus', exon_count=19, OMIM=[603063], no_hdr0=''),
    623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=623, CurrentID=0, Status='live', Symbol='BDKRB1', Aliases=['B1BKR', 'B1R', 'BKB1R', 'BKR1', 'BRADYB1'], description='bradykinin receptor B1', other_designations='B1 bradykinin receptor|BK-1 receptor|bradykinin B1 receptor|bradykinin receptor 1', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96256210, end_position_on_the_genomic_accession=96264763, orientation='plus', exon_count=3, OMIM=[600337], no_hdr0=''),
    624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=624, CurrentID=0, Status='live', Symbol='BDKRB2', Aliases=['B2R', 'BK-2', 'BK2', 'BKR2', 'BRB2'], description='bradykinin receptor B2', other_designations='B2 bradykinin receptor|BK-2 receptor', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96204839, end_position_on_the_genomic_accession=96244164, orientation='plus', exon_count=3, OMIM=[113503], no_hdr0=''),
    627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=627, CurrentID=0, Status='live', Symbol='BDNF', Aliases=['ANON2', 'BULN2'], description='brain derived neurotrophic factor', other_designations='brain-derived neurotrophic factor|abrineurin|neurotrophin', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=27654893, end_position_on_the_genomic_accession=27722030, orientation='minus', exon_count=12, OMIM=[113505], no_hdr0=''),
    629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=629, CurrentID=0, Status='live', Symbol='CFB', Aliases=['AHUS4', 'ARMD14', 'BF', 'BFD', 'CFABD', 'FB', 'FBI12', 'GBG', 'H2-Bf', 'PBF2', 'CFB'], description='complement factor B', other_designations='complement factor B|B-factor, properdin|C3 proaccelerator|C3 proactivator|C3/C5 convertase|glycine-rich beta-glycoprotein|properdin factor B', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31946095, end_position_on_the_genomic_accession=31952084, orientation='plus', exon_count=18, OMIM=[138470], no_hdr0=''),
    631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=631, CurrentID=0, Status='live', Symbol='BFSP1', Aliases=['CP115', 'CP94', 'CTRCT33', 'LIFL-H'], description='beaded filament structural protein 1', other_designations='filensin|beaded filament structural protein 1, filensin|cytoskeletal protein, 115 KD|lens fiber cell beaded-filament structural protein CP 115|lens intermediate filament-like heavy', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17493905, end_position_on_the_genomic_accession=17569220, orientation='minus', exon_count=13, OMIM=[603307], no_hdr0=''),
    632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=632, CurrentID=0, Status='live', Symbol='BGLAP', Aliases=['BGP', 'OC', 'OCN'], description='bone gamma-carboxyglutamate protein', other_designations='osteocalcin|bone gamma-carboxyglutamate (gla) protein (osteocalcin)|gamma-carboxyglutamic acid-containing protein', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156242184, end_position_on_the_genomic_accession=156243317, orientation='plus', exon_count=4, OMIM=[112260], no_hdr0=''),
    633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=633, CurrentID=0, Status='live', Symbol='BGN', Aliases=['DSPG1', 'MRLS', 'PG-S1', 'PGI', 'SEMDX', 'SLRR1A'], description='biglycan', other_designations='biglycan|bone/cartilage proteoglycan-I|dermatan sulphate proteoglycan I|small leucine-rich protein 1A', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153494980, end_position_on_the_genomic_accession=153509546, orientation='plus', exon_count=8, OMIM=[301870], no_hdr0=''),
    634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=634, CurrentID=0, Status='live', Symbol='CEACAM1', Aliases=['BGP', 'BGP1', 'BGPI'], description='CEA cell adhesion molecule 1', other_designations='carcinoembryonic antigen-related cell adhesion molecule 1|CD66a antigen|antigen CD66|carcinoembryonic antigen related cell adhesion molecule 1|carcinoembryonic antigen-related cell adhesion molecule 1 (biliary glycoprotein)', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42507306, end_position_on_the_genomic_accession=42528482, orientation='minus', exon_count=10, OMIM=[109770], no_hdr0=''),
    635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=635, CurrentID=0, Status='live', Symbol='BHMT', Aliases=['BHMT1', 'HEL-S-61p'], description='betaine--homocysteine S-methyltransferase', other_designations='betaine--homocysteine S-methyltransferase 1|epididymis secretory sperm binding protein Li 61p', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79111809, end_position_on_the_genomic_accession=79132288, orientation='plus', exon_count=8, OMIM=[602888], no_hdr0=''),
    636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=636, CurrentID=0, Status='live', Symbol='BICD1', Aliases=['BICD', 'bic-D 1'], description='BICD cargo adaptor 1', other_designations='protein bicaudal D homolog 1|bicaudal D homolog 1|cytoskeleton-like bicaudal D protein homolog 1', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=32106773, end_position_on_the_genomic_accession=32383637, orientation='plus', exon_count=13, OMIM=[602204], no_hdr0=''),
    637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=637, CurrentID=0, Status='live', Symbol='BID', Aliases=['FP497'], description='BH3 interacting domain death agonist', other_designations='BH3-interacting domain death agonist|Human BID coding sequence|apoptic death agonist|desmocollin type 4|p22 BID', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17734138, end_position_on_the_genomic_accession=17774665, orientation='minus', exon_count=8, OMIM=[601997], no_hdr0=''),
    638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=638, CurrentID=0, Status='live', Symbol='BIK', Aliases=['BIP1', 'BP4', 'NBK'], description='BCL2 interacting killer', other_designations='bcl-2-interacting killer|BCL2-interacting killer (apoptosis-inducing)|apoptosis inducer NBK|apoptosis-inducing NBK|natural born killer', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43110750, end_position_on_the_genomic_accession=43129712, orientation='plus', exon_count=5, OMIM=[603392], no_hdr0=''),
    639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=639, CurrentID=0, Status='live', Symbol='PRDM1', Aliases=['BLIMP1', 'PRDI-BF1'], description='PR/SET domain 1', other_designations='PR domain zinc finger protein 1|B-lymphocyte-induced maturation protein 1|BLIMP-1|PR domain 1|PR domain containing 1, with ZNF domain|PRDI-binding factor-1|beta-interferon gene positive-regulatory domain I binding factor', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106046729, end_position_on_the_genomic_accession=106109938, orientation='plus', exon_count=11, OMIM=[603423], no_hdr0=''),
    640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=640, CurrentID=0, Status='live', Symbol='BLK', Aliases=['MODY11'], description='BLK proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Blk|B lymphoid tyrosine kinase|BLK nonreceptor tyrosine kinase|b lymphocyte kinase|p55-Blk', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11493991, end_position_on_the_genomic_accession=11564599, orientation='plus', exon_count=15, OMIM=[191305], no_hdr0=''),
    641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641, CurrentID=0, Status='live', Symbol='BLM', Aliases=['BS', 'MGRISCE1', 'RECQ2', 'RECQL2', 'RECQL3'], description='BLM RecQ like helicase', other_designations='Bloom syndrome protein|Bloom syndrome RecQ like helicase|Bloom syndrome, RecQ helicase-like|DNA helicase, RecQ-like type 2|recQ protein-like 3', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90717346, end_position_on_the_genomic_accession=90816166, orientation='plus', exon_count=25, OMIM=[604610], no_hdr0=''),
    642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642, CurrentID=0, Status='live', Symbol='BLMH', Aliases=['BH', 'BMH'], description='bleomycin hydrolase', other_designations='bleomycin hydrolase|BLM hydrolase', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30248203, end_position_on_the_genomic_accession=30291944, orientation='minus', exon_count=12, OMIM=[602403], no_hdr0=''),
    643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643, CurrentID=0, Status='live', Symbol='CXCR5', Aliases=['BLR1', 'CD185', 'MDR15'], description='C-X-C motif chemokine receptor 5', other_designations='C-X-C chemokine receptor type 5|Burkitt lymphoma receptor 1, GTP binding protein (chemokine (C-X-C motif) receptor 5)|Burkitt lymphoma receptor 1, GTP-binding protein|CXC-R5|CXCR-5|MDR-15|chemokine (C-X-C motif) receptor 5|monocyte-derived receptor 15', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118883892, end_position_on_the_genomic_accession=118897787, orientation='plus', exon_count=2, OMIM=[601613], no_hdr0=''),
    644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644, CurrentID=0, Status='live', Symbol='BLVRA', Aliases=['BLVR', 'BVR', 'BVRA'], description='biliverdin reductase A', other_designations='biliverdin reductase A|BVR A|biliverdin-IX alpha-reductase|testis tissue sperm-binding protein Li 61n', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43758122, end_position_on_the_genomic_accession=43807342, orientation='plus', exon_count=12, OMIM=[109750], no_hdr0=''),
    645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645, CurrentID=0, Status='live', Symbol='BLVRB', Aliases=['BVRB', 'FLR', 'HEL-S-10', 'SDR43U1'], description='biliverdin reductase B', other_designations='flavin reductase (NADPH)|BVR-B|FR|GHBP|NADPH-dependent diaphorase|NADPH-flavin reductase|biliverdin-IX beta-reductase|epididymis secretory protein Li 10|green heme-binding protein|short chain dehydrogenase/reductase family 43U, member 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40447768, end_position_on_the_genomic_accession=40465745, orientation='minus', exon_count=5, OMIM=[600941], no_hdr0=''),
    646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646, CurrentID=0, Status='live', Symbol='BNC1', Aliases=['BNC', 'BSN1', 'HsT19447', 'POF16'], description='basonuclin 1', other_designations='zinc finger protein basonuclin-1', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83255884, end_position_on_the_genomic_accession=83284664, orientation='minus', exon_count=7, OMIM=[601930], no_hdr0=''),
    648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=648, CurrentID=0, Status='live', Symbol='BMI1', Aliases=['FLVI2/BMI1', 'PCGF4', 'RNF51', 'flvi-2/bmi-1'], description='BMI1 proto-oncogene, polycomb ring finger', other_designations='polycomb complex protein BMI-1|B lymphoma Mo-MLV insertion region 1 homolog|BMI1 polycomb ring finger oncogene|BMI1 polycomb ring finger proto-oncogene|murine leukemia viral (bmi-1) oncogene homolog|polycomb group RING finger protein 4|polycomb group protein Bmi1|ring finger protein 51', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22321099, end_position_on_the_genomic_accession=22331484, orientation='plus', exon_count=10, OMIM=[164831], no_hdr0=''),
    649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=649, CurrentID=0, Status='live', Symbol='BMP1', Aliases=['OI13', 'PCOLC', 'PCP', 'PCP2', 'TLD'], description='bone morphogenetic protein 1', other_designations='bone morphogenetic protein 1|mammalian tolloid protein|procollagen C-endopeptidase|procollagen C-proteinase 3|tolloid-like', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22165372, end_position_on_the_genomic_accession=22212326, orientation='plus', exon_count=21, OMIM=[112264], no_hdr0=''),
    650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=650, CurrentID=0, Status='live', Symbol='BMP2', Aliases=['BDA2A', 'SSFSC', 'SSFSC1', 'BMP2'], description='bone morphogenetic protein 2', other_designations='bone morphogenetic protein 2|bone morphogenetic protein 2A', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=6767686, end_position_on_the_genomic_accession=6780246, orientation='plus', exon_count=3, OMIM=[112261], no_hdr0=''),
    651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=651, CurrentID=0, Status='live', Symbol='BMP3', Aliases=['BMP-3A'], description='bone morphogenetic protein 3', other_designations='bone morphogenetic protein 3|bone morphogenetic protein 3 (osteogenic)|bone morphogenetic protein 3A|osteogenin', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=81030708, end_position_on_the_genomic_accession=81057627, orientation='plus', exon_count=3, OMIM=[112263], no_hdr0=''),
    652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=652, CurrentID=0, Status='live', Symbol='BMP4', Aliases=['BMP2B', 'BMP2B1', 'MCOPS6', 'OFC11', 'ZYME'], description='bone morphogenetic protein 4', other_designations='bone morphogenetic protein 4|bone morphogenetic protein 2B', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=53949736, end_position_on_the_genomic_accession=53956891, orientation='minus', exon_count=6, OMIM=[112262], no_hdr0=''),
    653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653, CurrentID=0, Status='live', Symbol='BMP5', Aliases=[], description='bone morphogenetic protein 5', other_designations='bone morphogenetic protein 5', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=55753653, end_position_on_the_genomic_accession=55875590, orientation='minus', exon_count=9, OMIM=[112265], no_hdr0=''),
    654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654, CurrentID=0, Status='live', Symbol='BMP6', Aliases=['VGR', 'VGR1'], description='bone morphogenetic protein 6', other_designations='bone morphogenetic protein 6|VG-1-R|VG-1-related protein|vegetal related growth factor (TGFB-related)', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7726099, end_position_on_the_genomic_accession=7881728, orientation='plus', exon_count=7, OMIM=[112266], no_hdr0=''),
    655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=655, CurrentID=0, Status='live', Symbol='BMP7', Aliases=['OP-1'], description='bone morphogenetic protein 7', other_designations='bone morphogenetic protein 7|osteogenic protein 1', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57168753, end_position_on_the_genomic_accession=57266641, orientation='minus', exon_count=7, OMIM=[112267], no_hdr0=''),
    656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=656, CurrentID=0, Status='live', Symbol='BMP8B', Aliases=['BMP8', 'OP2'], description='bone morphogenetic protein 8b', other_designations='bone morphogenetic protein 8B|bone morphogenetic protein 8 (osteogenic protein 2)|osteogenic protein 2', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39757182, end_position_on_the_genomic_accession=39788865, orientation='minus', exon_count=12, OMIM=[602284], no_hdr0=''),
    657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=657, CurrentID=0, Status='live', Symbol='BMPR1A', Aliases=['10q23del', 'ACVRLK3', 'ALK3', 'CD292', 'SKR5'], description='bone morphogenetic protein receptor type 1A', other_designations='bone morphogenetic protein receptor type-1A|ALK-3|BMP type-1A receptor|BMPR-1A|activin A receptor, type II-like kinase 3|activin receptor-like kinase 3|bone morphogenetic protein receptor, type IA|serine/threonine-protein kinase receptor R5', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86755786, end_position_on_the_genomic_accession=86927969, orientation='plus', exon_count=15, OMIM=[601299], no_hdr0=''),
    658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=658, CurrentID=0, Status='live', Symbol='BMPR1B', Aliases=['ALK-6', 'ALK6', 'AMDD', 'BDA1D', 'BDA2', 'CDw293'], description='bone morphogenetic protein receptor type 1B', other_designations='bone morphogenetic protein receptor type-1B|BMP type-1B receptor|BMPR-1B|activin receptor-like kinase 6|bone morphogenetic protein receptor, type IB|serine/threonine receptor kinase', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=94757955, end_position_on_the_genomic_accession=95158453, orientation='plus', exon_count=18, OMIM=[603248], no_hdr0=''),
    659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=659, CurrentID=0, Status='live', Symbol='BMPR2', Aliases=['BMPR-II', 'BMPR3', 'BMR2', 'BRK-3', 'POVD1', 'PPH1', 'T-ALK'], description='bone morphogenetic protein receptor type 2', other_designations='bone morphogenetic protein receptor type-2|BMP type II receptor|BMP type-2 receptor|bone morphogenetic protein receptor type II|bone morphogenetic protein receptor, type II (serine/threonine kinase)|type II activin receptor-like kinase|type II receptor for bone morphogenetic protein-4', map_location='2q33.1-q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202376310, end_position_on_the_genomic_accession=202567751, orientation='plus', exon_count=13, OMIM=[600799], no_hdr0=''),
    660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=660, CurrentID=0, Status='live', Symbol='BMX', Aliases=['ETK', 'PSCTK2', 'PSCTK3'], description='BMX non-receptor tyrosine kinase', other_designations='cytoplasmic tyrosine-protein kinase BMX|BTK-like on X chromosome|Etk/Bmx cytosolic tyrosine kinase|NTK38 tyrosine kinase|bone marrow tyrosine kinase gene in chromosome X protein|epithelial and endothelial tyrosine kinase', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15500777, end_position_on_the_genomic_accession=15556519, orientation='plus', exon_count=20, OMIM=[300101], no_hdr0=''),
    661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=661, CurrentID=0, Status='live', Symbol='POLR3D', Aliases=['BN51T', 'C53', 'RPC4', 'RPC53', 'TSBN51'], description='RNA polymerase III subunit D', other_designations='DNA-directed RNA polymerase III subunit RPC4|BN51 (BHK21) temperature sensitivity complementing|DNA-directed RNA polymerase III 47 kDa polypeptide|DNA-directed RNA polymerase III subunit D|RNA polymerase III 47 kDa subunit|RNA polymerase III subunit C4|RPC53 homolog|polymerase (RNA) III (DNA directed) polypeptide D, 44kDa|polymerase (RNA) III subunit D|temperature sensitive complementation, cell cycle specific, tsBN51', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22245104, end_position_on_the_genomic_accession=22254601, orientation='plus', exon_count=9, OMIM=[187280], no_hdr0=''),
    662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=662, CurrentID=0, Status='live', Symbol='BNIP1', Aliases=['NIP1', 'SEC20', 'TRG-8'], description='BCL2 interacting protein 1', other_designations='vesicle transport protein SEC20|BCL2/adenovirus E1B 19 kDa protein-interacting protein 1|BCL2/adenovirus E1B 19kDa interacting protein 1|transformation-related gene 8 protein', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173144447, end_position_on_the_genomic_accession=173164387, orientation='plus', exon_count=9, OMIM=[603291], no_hdr0=''),
    663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=663, CurrentID=0, Status='live', Symbol='BNIP2', Aliases=['BNIP-2', 'NIP2'], description='BCL2 interacting protein 2', other_designations='BCL2/adenovirus E1B 19 kDa protein-interacting protein 2|BCL2/adenovirus E1B 19kDa interacting protein 2', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59659146, end_position_on_the_genomic_accession=59689320, orientation='minus', exon_count=12, OMIM=[603292], no_hdr0=''),
    664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=664, CurrentID=0, Status='live', Symbol='BNIP3', Aliases=['NIP3'], description='BCL2 interacting protein 3', other_designations='BCL2/adenovirus E1B 19 kDa protein-interacting protein 3|BCL2/adenovirus E1B 19kDa interacting protein 3|BCL2/adenovirus E1B interacting protein 3|nineteen kD interacting protein-3', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=131967684, end_position_on_the_genomic_accession=131981923, orientation='minus', exon_count=6, OMIM=[603293], no_hdr0=''),
    665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=665, CurrentID=0, Status='live', Symbol='BNIP3L', Aliases=['BNIP3a', 'NIX'], description='BCL2 interacting protein 3 like', other_designations='BCL2/adenovirus E1B 19 kDa protein-interacting protein 3-like|BCL2/adenovirus E1B 19 kDa protein-interacting protein 3A|BCL2/adenovirus E1B 19-kd protein-interacting protein 3a|BCL2/adenovirus E1B 19kDa interacting protein 3 like|NIP-3-like protein X|NIP3-like protein X|NIP3L|adenovirus E1B19k-binding protein B5', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=26383054, end_position_on_the_genomic_accession=26413127, orientation='plus', exon_count=7, OMIM=[605368], no_hdr0=''),
    666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=666, CurrentID=0, Status='live', Symbol='BOK', Aliases=['BCL2L9L', 'BOK'], description='BCL2 family apoptosis regulator BOK', other_designations='bcl-2-related ovarian killer protein|BCL2 related ovarian killer|BOK, BCL2 family apoptosis regulator|bcl-2-like protein 9|bcl2-L-9|hBOK', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241558745, end_position_on_the_genomic_accession=241574131, orientation='plus', exon_count=7, OMIM=[605404], no_hdr0=''),
    667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=667, CurrentID=0, Status='live', Symbol='DST', Aliases=['BP240', 'BPA', 'BPAG1', 'CATX-15', 'CATX15', 'D6S1101', 'DMH', 'DT', 'EBSB2', 'HSAN6', 'MACF2'], description='dystonin', other_designations='dystonin|bullous pemphigoid antigen|bullous pemphigoid antigen 1|dystonia musculorum protein|hemidesmosomal plaque protein|trabeculin-beta', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=56457996, end_position_on_the_genomic_accession=56954830, orientation='minus', exon_count=112, OMIM=[113810], no_hdr0=''),
    668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=668, CurrentID=0, Status='live', Symbol='FOXL2', Aliases=['BPES', 'BPES1', 'PFRK', 'PINTO', 'POF3'], description='forkhead box L2', other_designations='forkhead box protein L2|forkhead transcription factor FOXL2', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138944224, end_position_on_the_genomic_accession=138947137, orientation='minus', exon_count=1, OMIM=[605597], no_hdr0=''),
    669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=669, CurrentID=0, Status='live', Symbol='BPGM', Aliases=['DPGM', 'ECYT8'], description='bisphosphoglycerate mutase', other_designations='bisphosphoglycerate mutase|2,3-bisphosphoglycerate mutase, erythrocyte|2,3-bisphosphoglycerate synthase|2,3-diphosphoglycerate mutase|BPG-dependent PGAM|erythrocyte 2,3-bisphosphoglycerate mutase|testis secretory sperm-binding protein Li 202a', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134646853, end_position_on_the_genomic_accession=134679816, orientation='plus', exon_count=6, OMIM=[613896], no_hdr0=''),
    670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=670, CurrentID=0, Status='live', Symbol='BPHL', Aliases=['BPH-RP', 'MCNAA', 'VACVASE'], description='biphenyl hydrolase like', other_designations='valacyclovir hydrolase|biphenyl hydrolase-like (serine hydrolase)|biphenyl hydrolase-related protein|breast epithelial mucin-associated antigen|valacyclovirase', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3118376, end_position_on_the_genomic_accession=3153599, orientation='plus', exon_count=10, OMIM=[603156], no_hdr0=''),
    671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=671, CurrentID=0, Status='live', Symbol='BPI', Aliases=['BPIFD1', 'rBPI'], description='bactericidal permeability increasing protein', other_designations='bactericidal permeability-increasing protein|BPI fold containing family D, member 1|CAP 57|recombinant BPI holoprotein, rBPI', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38304156, end_position_on_the_genomic_accession=38337505, orientation='plus', exon_count=16, OMIM=[109195], no_hdr0=''),
    672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=672, CurrentID=0, Status='live', Symbol='BRCA1', Aliases=['BRCAI', 'BRCC1', 'BROVCA1', 'FANCS', 'IRIS', 'PNCA4', 'PPP1R53', 'PSCP', 'RNF53'], description='BRCA1 DNA repair associated', other_designations='breast cancer type 1 susceptibility protein|BRCA1/BRCA2-containing complex, subunit 1|Fanconi anemia, complementation group S|RING finger protein 53|breast and ovarian cancer susceptibility protein 1|breast cancer 1, early onset|early onset breast cancer 1|protein phosphatase 1, regulatory subunit 53', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43044295, end_position_on_the_genomic_accession=43125364, orientation='minus', exon_count=24, OMIM=[113705], no_hdr0=''),
    673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=673, CurrentID=0, Status='live', Symbol='BRAF', Aliases=['B-RAF1', 'B-raf1', 'NS7', 'RAFB1', 'BRAF'], description='B-Raf proto-oncogene, serine/threonine kinase', other_designations='serine/threonine-protein kinase B-raf|94 kDa B-raf protein|B-Raf proto-oncogene serine/threonine-protein kinase (p94)|B-Raf serine/threonine-protein|murine sarcoma viral (v-raf) oncogene homolog B1|proto-oncogene B-Raf|v-raf murine sarcoma viral oncogene homolog B|v-raf murine sarcoma viral oncogene homolog B1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140713328, end_position_on_the_genomic_accession=140924929, orientation='minus', exon_count=23, OMIM=[164757], no_hdr0=''),
    675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=675, CurrentID=0, Status='live', Symbol='BRCA2', Aliases=['BRCC2', 'BROVCA2', 'FACD', 'FAD', 'FAD1', 'FANCD', 'FANCD1', 'GLM3', 'PNCA2', 'XRCC11'], description='BRCA2 DNA repair associated', other_designations='breast cancer type 2 susceptibility protein|BRCA1/BRCA2-containing complex, subunit 2|Fanconi anemia group D1 protein|breast and ovarian cancer susceptibility gene, early onset|breast and ovarian cancer susceptibility protein 2|breast cancer 2 tumor suppressor|breast cancer 2, early onset|mutant BRCA2|truncated BRCA2 DNA repair associated|truncated BRCA2 DNA repair-associated protein|truncated DNA repair-associated BRCA2|truncated DNA repair-associated protein|truncated breast cancer 2', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32315508, end_position_on_the_genomic_accession=32400268, orientation='plus', exon_count=27, OMIM=[600185], no_hdr0=''),
    676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=676, CurrentID=0, Status='live', Symbol='BRDT', Aliases=['BRD6', 'CT9', 'SPGF21'], description='bromodomain testis associated', other_designations='bromodomain testis-specific protein|RING3-like protein|bromodomain, testis-specific|cancer/testis antigen 9', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=91949371, end_position_on_the_genomic_accession=92014428, orientation='plus', exon_count=21, OMIM=[602144], no_hdr0=''),
    677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=677, CurrentID=0, Status='live', Symbol='ZFP36L1', Aliases=['BRF1', 'Berg36', 'ERF-1', 'ERF1', 'RNF162B', 'TIS11B', 'cMG1'], description='ZFP36 ring finger protein like 1', other_designations='mRNA decay activator protein ZFP36L1|EGF-response factor 1|TPA-induced sequence 11b|ZFP36-like 1|butyrate response factor 1|early response factor Berg36|zinc finger protein 36, C3H type-like 1|zinc finger protein 36, C3H1 type-like 1|zinc finger protein, C3H type, 36-like 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=68787655, end_position_on_the_genomic_accession=68796243, orientation='minus', exon_count=4, OMIM=[601064], no_hdr0=''),
    678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=678, CurrentID=0, Status='live', Symbol='ZFP36L2', Aliases=['BRF2', 'ERF-2', 'ERF2', 'RNF162C', 'TIS11D'], description='ZFP36 ring finger protein like 2', other_designations='mRNA decay activator protein ZFP36L2|EGF-response factor 2|TPA-induced sequence 11d|ZFP36-like 2|butyrate response factor 2 (EGF-response factor 2)|zinc finger protein 36, C3H type-like 1|zinc finger protein 36, C3H type-like 2|zinc finger protein 36, C3H1 type-like 2|zinc finger protein, C3H type, 36-like 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43222402, end_position_on_the_genomic_accession=43226606, orientation='minus', exon_count=2, OMIM=[612053], no_hdr0=''),
    680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=680, CurrentID=0, Status='live', Symbol='BRS3', Aliases=['BB3', 'BB3R', 'BBR3'], description='bombesin receptor subtype 3', other_designations='bombesin receptor subtype-3|BRS-3|G-protein coupled receptor|bombesin like receptor 3', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136487947, end_position_on_the_genomic_accession=136493780, orientation='plus', exon_count=3, OMIM=[300107], no_hdr0=''),
    682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=682, CurrentID=0, Status='live', Symbol='BSG', Aliases=['5F7', 'CD147', 'EMMPRIN', 'EMPRIN', 'HAb18G', 'OK', 'SLC7A11', 'TCSF'], description='basigin (Ok blood group)', other_designations='basigin|OK blood group antigen|collagenase stimulatory factor|extracellular matrix metalloproteinase inducer|hepatoma-associated antigen|leukocyte activation antigen M6|tumor cell-derived collagenase stimulatory factor', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=571283, end_position_on_the_genomic_accession=583493, orientation='plus', exon_count=10, OMIM=[109480], no_hdr0=''),
    683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=683, CurrentID=0, Status='live', Symbol='BST1', Aliases=['CD157'], description='bone marrow stromal cell antigen 1', other_designations='ADP-ribosyl cyclase/cyclic ADP-ribose hydrolase 2|ADP-ribosyl cyclase 2|NAD(+) nucleosidase|bone marrow stromal antigen 1|bone marrow stromal cell antigen 1 variant 2|cADPr hydrolase 2|cyclic ADP-ribose hydrolase 2', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15701866, end_position_on_the_genomic_accession=15774178, orientation='plus', exon_count=15, OMIM=[600387], no_hdr0=''),
    684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=684, CurrentID=0, Status='live', Symbol='BST2', Aliases=['CD317', 'HM1.24', 'TETHERIN'], description='bone marrow stromal cell antigen 2', other_designations='bone marrow stromal antigen 2|BST-2|HM1.24 antigen|NPC-A-7|antiviral factor tetherin', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17402939, end_position_on_the_genomic_accession=17405630, orientation='minus', exon_count=5, OMIM=[600534], no_hdr0=''),
    685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=685, CurrentID=0, Status='live', Symbol='BTC', Aliases=[], description='betacellulin', other_designations='probetacellulin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74744759, end_position_on_the_genomic_accession=74794718, orientation='minus', exon_count=8, OMIM=[600345], no_hdr0=''),
    686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=686, CurrentID=0, Status='live', Symbol='BTD', Aliases=[], description='biotinidase', other_designations='biotinidase|biotinase', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15601352, end_position_on_the_genomic_accession=15722516, orientation='plus', exon_count=11, OMIM=[609019], no_hdr0=''),
    687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=687, CurrentID=0, Status='live', Symbol='KLF9', Aliases=['BTEB', 'BTEB1'], description='Kruppel like factor 9', other_designations='Krueppel-like factor 9|BTE-binding protein 1|GC-box-binding protein 1|basic transcription element-binding protein 1|transcription factor BTEB1', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=70384604, end_position_on_the_genomic_accession=70414657, orientation='minus', exon_count=2, OMIM=[602902], no_hdr0=''),
    688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=688, CurrentID=0, Status='live', Symbol='KLF5', Aliases=['BTEB2', 'CKLF', 'IKLF'], description='Kruppel like factor 5', other_designations='Krueppel-like factor 5|(intestinal Kruppel-like factor|BTE-binding protein 2|GC box binding protein 2|Kruppel-like factor 5 (intestinal)|basic transcription element binding protein 2|colon krueppel-like factor|colon kruppel-like factor|epididymis secretory sperm binding protein|intestinal-enriched krueppel-like factor|intestinal-enriched kruppel-like factor|transcription factor BTEB2', map_location='13q22.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=73054976, end_position_on_the_genomic_accession=73077538, orientation='plus', exon_count=5, OMIM=[602903], no_hdr0=''),
    689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=689, CurrentID=0, Status='live', Symbol='BTF3', Aliases=['BETA-NACa', 'BTF3b', 'NACB', 'BTF3'], description='basic transcription factor 3', other_designations='transcription factor BTF3|NAC-beta|RNA polymerase B transcription factor 3|nascent polypeptide-associated complex subunit beta|nascent-polypeptide-associated complex beta polypeptide', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73498442, end_position_on_the_genomic_accession=73505667, orientation='plus', exon_count=6, OMIM=[602542], no_hdr0=''),
    694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=694, CurrentID=0, Status='live', Symbol='BTG1', Aliases=['APRO2'], description='BTG anti-proliferation factor 1', other_designations='protein BTG1|B-cell translocation gene 1 protein|B-cell translocation gene 1, anti-proliferative', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=92140278, end_position_on_the_genomic_accession=92145846, orientation='minus', exon_count=2, OMIM=[109580], no_hdr0=''),
    695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=695, CurrentID=0, Status='live', Symbol='BTK', Aliases=['AGMX1', 'AT', 'ATK', 'BPK', 'IGHD3', 'IMD1', 'PSCTK1', 'XLA'], description='Bruton tyrosine kinase', other_designations="tyrosine-protein kinase BTK|B-cell progenitor kinase|Bruton agammaglobulinemia tyrosine kinase|Bruton's tyrosine kinase|agammaglobulinaemia tyrosine kinase|dominant-negative kinase-deficient Brutons tyrosine kinase|truncated Bruton agammaglobulinemia tyrosine kinase", map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101349450, end_position_on_the_genomic_accession=101390796, orientation='minus', exon_count=21, OMIM=[300300], no_hdr0=''),
    696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=696, CurrentID=0, Status='live', Symbol='BTN1A1', Aliases=['BT', 'BTN', 'BTN1'], description='butyrophilin subfamily 1 member A1', other_designations='butyrophilin subfamily 1 member A1|bK14H9.2 (butyrophilin, subfamily 1, member A1)', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26500303, end_position_on_the_genomic_accession=26510425, orientation='plus', exon_count=8, OMIM=[601610], no_hdr0=''),
    699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=699, CurrentID=0, Status='live', Symbol='BUB1', Aliases=['BUB1AL', 'hBUB1', 'BUB1'], description='BUB1 mitotic checkpoint serine/threonine kinase', other_designations='mitotic checkpoint serine/threonine-protein kinase BUB1|BUB1 budding uninhibited by benzimidazoles 1 homolog|budding uninhibited by benzimidazoles 1 homolog|mitotic spindle checkpoint kinase|putative serine/threonine-protein kinase', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110637528, end_position_on_the_genomic_accession=110678063, orientation='minus', exon_count=25, OMIM=[602452], no_hdr0=''),
    701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=701, CurrentID=0, Status='live', Symbol='BUB1B', Aliases=['BUB1beta', 'BUBR1', 'Bub1A', 'MAD3L', 'MVA1', 'SSK1', 'hBUBR1'], description='BUB1 mitotic checkpoint serine/threonine kinase B', other_designations='mitotic checkpoint serine/threonine-protein kinase BUB1 beta|BUB1B, mitotic checkpoint serine/threonine kinase|MAD3/BUB1-related protein kinase|budding uninhibited by benzimidazoles 1 homolog beta|mitotic checkpoint kinase MAD3L', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40161069, end_position_on_the_genomic_accession=40221123, orientation='plus', exon_count=23, OMIM=[602860], no_hdr0=''),
    705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=705, CurrentID=0, Status='live', Symbol='BYSL', Aliases=['BYSTIN', 'Enp1'], description='bystin like', other_designations='bystin|by the ribosomal protein s6 gene, drosophila, homolog-like', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41921499, end_position_on_the_genomic_accession=41933046, orientation='plus', exon_count=7, OMIM=[603871], no_hdr0=''),
    706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=706, CurrentID=0, Status='live', Symbol='TSPO', Aliases=['BPBS', 'BZRP', 'DBI', 'IBP', 'MBR', 'PBR', 'PBS', 'PKBS', 'PTBR', 'mDRC', 'pk18'], description='translocator protein', other_designations='translocator protein|benzodiazepine peripheral binding site|mitochondrial benzodiazepine receptor|peripheral-type benzodiazepine receptor', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43151559, end_position_on_the_genomic_accession=43163242, orientation='plus', exon_count=5, OMIM=[109610], no_hdr0=''),
    708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=708, CurrentID=0, Status='live', Symbol='C1QBP', Aliases=['COXPD33', 'GC1QBP', 'HABP1', 'SF2AP32', 'SF2p32', 'gC1Q-R', 'gC1qR', 'p32'], description='complement C1q binding protein', other_designations='complement component 1 Q subcomponent-binding protein, mitochondrial|ASF/SF2-associated protein p32|C1q globular domain-binding protein|complement component 1, q subcomponent binding protein|glycoprotein gC1qBP|hyaluronan-binding protein 1|mitochondrial matrix protein p32|p33|splicing factor SF2-associated protein', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5432777, end_position_on_the_genomic_accession=5439155, orientation='minus', exon_count=6, OMIM=[601269], no_hdr0=''),
    710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=710, CurrentID=0, Status='live', Symbol='SERPING1', Aliases=['C1IN', 'C1INH', 'C1NH', 'HAE1', 'HAE2'], description='serpin family G member 1', other_designations='plasma protease C1 inhibitor|C1 esterase inhibitor|C1-inhibiting factor|C1-inhibitor|complement component 1 inhibitor|epididymis secretory sperm binding protein|serine/cysteine proteinase inhibitor clade G member 1|serpin G1|serpin peptidase inhibitor clade G member 1|serpin peptidase inhibitor, clade G (C1 inhibitor), member 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57597685, end_position_on_the_genomic_accession=57614848, orientation='plus', exon_count=8, OMIM=[606860], no_hdr0=''),
    712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=712, CurrentID=0, Status='live', Symbol='C1QA', Aliases=[], description='complement C1q A chain', other_designations='complement C1q subcomponent subunit A|complement C1q chain A|complement component 1, q subcomponent, A chain|complement component 1, q subcomponent, alpha polypeptide|complement component C1q, A chain', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22636463, end_position_on_the_genomic_accession=22639678, orientation='plus', exon_count=3, OMIM=[120550], no_hdr0=''),
    713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=713, CurrentID=0, Status='live', Symbol='C1QB', Aliases=[], description='complement C1q B chain', other_designations='complement C1q subcomponent subunit B|complement C1q chain B|complement component 1, q subcomponent, B chain|complement component 1, q subcomponent, beta polypeptide|complement component C1q, B chain|complement subcomponent C1q chain B', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22653236, end_position_on_the_genomic_accession=22661637, orientation='plus', exon_count=4, OMIM=[120570], no_hdr0=''),
    714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=714, CurrentID=0, Status='live', Symbol='C1QC', Aliases=['C1Q-C', 'C1QG'], description='complement C1q C chain', other_designations='complement C1q subcomponent subunit C|complement component 1, q subcomponent, C chain|complement component 1, q subcomponent, gamma polypeptide', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22643633, end_position_on_the_genomic_accession=22648108, orientation='plus', exon_count=3, OMIM=[120575], no_hdr0=''),
    715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=715, CurrentID=0, Status='live', Symbol='C1R', Aliases=['EDSPD1'], description='complement C1r', other_designations='complement C1r subcomponent|complement component 1, r subcomponent', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7080219, end_position_on_the_genomic_accession=7092445, orientation='minus', exon_count=12, OMIM=[613785], no_hdr0=''),
    716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=716, CurrentID=0, Status='live', Symbol='C1S', Aliases=['EDSPD2'], description='complement C1s', other_designations='complement C1s subcomponent|C1 esterase|basic proline-rich peptide IB-1|complement component 1 subcomponent s|complement component 1, s subcomponent', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7060718, end_position_on_the_genomic_accession=7071032, orientation='plus', exon_count=13, OMIM=[120580], no_hdr0=''),
    717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=717, CurrentID=0, Status='live', Symbol='C2', Aliases=['ARMD14', 'CO2'], description='complement C2', other_designations='complement C2|C3/C5 convertase|complement component 2|complement component C2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31897783, end_position_on_the_genomic_accession=31945672, orientation='plus', exon_count=20, OMIM=[613927], no_hdr0=''),
    718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=718, CurrentID=0, Status='live', Symbol='C3', Aliases=['AHUS5', 'ARMD9', 'ASPa', 'C3b', 'CPAMD1', 'HEL-S-62p', 'C3'], description='complement C3', other_designations='complement C3|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 1|C3a anaphylatoxin|acylation-stimulating protein cleavage product|complement component 3|complement component C3a|complement component C3b|epididymis secretory sperm binding protein Li 62p|prepro-C3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6677704, end_position_on_the_genomic_accession=6720650, orientation='minus', exon_count=41, OMIM=[120700], no_hdr0=''),
    719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=719, CurrentID=0, Status='live', Symbol='C3AR1', Aliases=['AZ3B', 'C3AR', 'HNFAG09'], description='complement C3a receptor 1', other_designations='C3a anaphylatoxin chemotactic receptor|complement component 3 receptor 1|complement component 3a receptor 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8056844, end_position_on_the_genomic_accession=8066359, orientation='minus', exon_count=2, OMIM=[605246], no_hdr0=''),
    720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=720, CurrentID=0, Status='live', Symbol='C4A', Aliases=['C42', 'C4A3', 'C4A4', 'C4A6', 'C4AD', 'C4S', 'CO4', 'CPAMD2', 'RG', 'C4A'], description='complement C4A (Rodgers blood group)', other_designations='complement C4-A|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 2|C4A anaphylatoxin|MHC class III region complement|Rodgers form of C4|acidic C4|acidic complement C4|complement component 4A (Rodgers blood group)', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31982057, end_position_on_the_genomic_accession=32002681, orientation='plus', exon_count=41, OMIM=[120810], no_hdr0=''),
    721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=721, CurrentID=0, Status='live', Symbol='C4B', Aliases=['C4B112', 'C4B2', 'C4B3', 'C4B5', 'C4BD', 'C4B_2', 'C4F', 'CH', 'CO4', 'CPAMD3', 'C4B'], description='complement C4B (Chido blood group)', other_designations='complement C4-B|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 3|Chido form of C4|basic complement C4|complement C4B1a|complement component 4B (Chido blood group)', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32014795, end_position_on_the_genomic_accession=32035418, orientation='plus', exon_count=41, OMIM=[120820], no_hdr0=''),
    722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=722, CurrentID=0, Status='live', Symbol='C4BPA', Aliases=['C4BP', 'PRP'], description='complement component 4 binding protein alpha', other_designations='C4b-binding protein alpha chain|proline-rich protein', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207104232, end_position_on_the_genomic_accession=207144972, orientation='plus', exon_count=12, OMIM=[120830], no_hdr0=''),
    725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=725, CurrentID=0, Status='live', Symbol='C4BPB', Aliases=['C4BP'], description='complement component 4 binding protein beta', other_designations='C4b-binding protein beta chain', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207088795, end_position_on_the_genomic_accession=207099993, orientation='plus', exon_count=9, OMIM=[120831], no_hdr0=''),
    726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=726, CurrentID=0, Status='live', Symbol='CAPN5', Aliases=['ADNIV', 'HTRA3', 'VRNI', 'nCL-3'], description='calpain 5', other_designations='calpain-5|calpain htra-3|new calpain 3|testis tissue sperm-binding protein Li 91mP', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77066971, end_position_on_the_genomic_accession=77126155, orientation='plus', exon_count=15, OMIM=[602537], no_hdr0=''),
    727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727, CurrentID=0, Status='live', Symbol='C5', Aliases=['C5Da', 'C5b', 'CPAMD4', 'ECLZB', 'C5'], description='complement C5', other_designations='complement C5|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 4|C5a anaphylatoxin|anaphylatoxin C5a analog|complement component 5|prepro-C5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120952335, end_position_on_the_genomic_accession=121074865, orientation='minus', exon_count=43, OMIM=[120900], no_hdr0=''),
    728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728, CurrentID=0, Status='live', Symbol='C5AR1', Aliases=['C5A', 'C5AR', 'C5R1', 'CD88'], description='complement C5a receptor 1', other_designations='C5a anaphylatoxin chemotactic receptor 1|C5a anaphylatoxin receptor|C5a ligand|C5a-R|complement component 5a receptor 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47309861, end_position_on_the_genomic_accession=47322066, orientation='plus', exon_count=3, OMIM=[113995], no_hdr0=''),
    729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729, CurrentID=0, Status='live', Symbol='C6', Aliases=[], description='complement C6', other_designations='complement component C6|complement component 6', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=41142116, end_position_on_the_genomic_accession=41261486, orientation='minus', exon_count=23, OMIM=[217050], no_hdr0=''),
    730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730, CurrentID=0, Status='live', Symbol='C7', Aliases=[], description='complement C7', other_designations='complement component C7|complement component 7', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40909497, end_position_on_the_genomic_accession=40984643, orientation='plus', exon_count=18, OMIM=[217070], no_hdr0=''),
    731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=731, CurrentID=0, Status='live', Symbol='C8A', Aliases=[], description='complement C8 alpha chain', other_designations='complement component C8 alpha chain|complement component 8 alpha subunit|complement component 8 subunit alpha|complement component 8, alpha polypeptide', map_location='1p32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56854796, end_position_on_the_genomic_accession=56918223, orientation='plus', exon_count=13, OMIM=[120950], no_hdr0=''),
    732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=732, CurrentID=0, Status='live', Symbol='C8B', Aliases=['C82'], description='complement C8 beta chain', other_designations='complement component C8 beta chain|complement component 8 subunit beta|complement component 8, beta polypeptide', map_location='1p32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56929207, end_position_on_the_genomic_accession=56974383, orientation='minus', exon_count=15, OMIM=[120960], no_hdr0=''),
    733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=733, CurrentID=0, Status='live', Symbol='C8G', Aliases=['C8C'], description='complement C8 gamma chain', other_designations='complement component C8 gamma chain|complement component 8, gamma polypeptide', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136944870, end_position_on_the_genomic_accession=136946981, orientation='plus', exon_count=7, OMIM=[120930], no_hdr0=''),
    734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=734, CurrentID=0, Status='live', Symbol='OSGIN2', Aliases=['C8orf1', 'hT41'], description='oxidative stress induced growth inhibitor family member 2', other_designations='oxidative stress-induced growth inhibitor 2', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=89901868, end_position_on_the_genomic_accession=89935614, orientation='plus', exon_count=9, OMIM=[604598], no_hdr0=''),
    735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=735, CurrentID=0, Status='live', Symbol='C9', Aliases=['ARMD15D', 'C9'], description='complement C9', other_designations='complement component C9|complement component 9', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=39284140, end_position_on_the_genomic_accession=39364495, orientation='minus', exon_count=11, OMIM=[120940], no_hdr0=''),
    738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=738, CurrentID=0, Status='live', Symbol='VPS51', Aliases=['ANG2', 'ANG3', 'C11orf2', 'C11orf3', 'FFR', 'PCH13'], description='VPS51 subunit of GARP complex', other_designations='vacuolar protein sorting-associated protein 51 homolog|VPS51, GARP complex subunit|another new gene 2 protein|protein fat-free homolog|vacuolar protein sorting 51 homolog', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65096214, end_position_on_the_genomic_accession=65111862, orientation='plus', exon_count=10, OMIM=[615738], no_hdr0=''),
    740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=740, CurrentID=0, Status='live', Symbol='MRPL49', Aliases=['C11orf4', 'L49mt', 'MRP-L49', 'NOF', 'NOF1'], description='mitochondrial ribosomal protein L49', other_designations='39S ribosomal protein L49, mitochondrial|mitochondrial large ribosomal subunit protein mL49|neighbor of FAU|next to FAU', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65122183, end_position_on_the_genomic_accession=65127371, orientation='plus', exon_count=4, OMIM=[606866], no_hdr0=''),
    741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=741, CurrentID=0, Status='live', Symbol='ZNHIT2', Aliases=['C11orf5', 'FON'], description='zinc finger HIT-type containing 2', other_designations='zinc finger HIT domain-containing protein 2|zinc finger, HIT domain containing 2|zinc finger, HIT type 2', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65116403, end_position_on_the_genomic_accession=65117701, orientation='minus', exon_count=1, OMIM=[604575], no_hdr0=''),
    744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=744, CurrentID=0, Status='live', Symbol='MPPED2', Aliases=['239FB', 'C11orf8'], description='metallophosphoesterase domain containing 2', other_designations='metallophosphoesterase MPPED2|fetal brain protein 239|metallophosphoesterase domain-containing protein 2', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=30384079, end_position_on_the_genomic_accession=30586995, orientation='minus', exon_count=19, OMIM=[600911], no_hdr0=''),
    745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=745, CurrentID=0, Status='live', Symbol='MYRF', Aliases=['11orf9', 'C11orf9', 'CUGS', 'MMERV', 'MRF', 'Ndt80', 'pqn-47'], description='myelin regulatory factor', other_designations='myelin regulatory factor|myelin gene regulatory factor', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61752617, end_position_on_the_genomic_accession=61788518, orientation='plus', exon_count=29, OMIM=[608329], no_hdr0=''),
    746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=746, CurrentID=0, Status='live', Symbol='TMEM258', Aliases=['C11orf10', 'Kud', 'Kuduk'], description='transmembrane protein 258', other_designations='transmembrane protein 258|UPF0197 transmembrane protein C11orf10|dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit TMEM258|oligosaccharyl transferase subunit TMEM258', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61788949, end_position_on_the_genomic_accession=61792599, orientation='minus', exon_count=4, OMIM=[617615], no_hdr0=''),
    747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=747, CurrentID=0, Status='live', Symbol='DAGLA', Aliases=['C11orf11', 'DAGL(ALPHA)LPHA', 'NSDDR', 'DAGLA'], description='diacylglycerol lipase alpha', other_designations='diacylglycerol lipase-alpha|DAGL-alpha|DGL-alpha|neural stem cell-derived dendrite regulator|sn1-specific diacylglycerol lipase alpha', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61680184, end_position_on_the_genomic_accession=61747002, orientation='plus', exon_count=23, OMIM=[614015], no_hdr0=''),
    752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=752, CurrentID=0, Status='live', Symbol='FMNL1', Aliases=['C17orf1', 'C17orf1B', 'FHOD4', 'FMNL', 'KW-13'], description='formin like 1', other_designations='formin-like protein 1|CLL-associated antigen KW-13|leukocyte formin', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45220268, end_position_on_the_genomic_accession=45247322, orientation='plus', exon_count=27, OMIM=[604656], no_hdr0=''),
    753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=753, CurrentID=0, Status='live', Symbol='LDLRAD4', Aliases=['C18orf1'], description='low density lipoprotein receptor class A domain containing 4', other_designations='low-density lipoprotein receptor class A domain-containing protein 4|clone 22', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=13217606, end_position_on_the_genomic_accession=13652754, orientation='plus', exon_count=33, OMIM=[606571], no_hdr0=''),
    754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=754, CurrentID=0, Status='live', Symbol='PTTG1IP', Aliases=['C21orf1', 'C21orf3', 'PBF'], description='PTTG1 interacting protein', other_designations='pituitary tumor-transforming gene 1 protein-interacting protein|PTTG-binding factor|pituitary tumor-transforming 1 interacting protein|pituitary tumor-transforming gene protein-binding factor', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44849598, end_position_on_the_genomic_accession=44873690, orientation='minus', exon_count=6, OMIM=[603784], no_hdr0=''),
    755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=755, CurrentID=0, Status='live', Symbol='CFAP410', Aliases=['C21orf2', 'LRRC76', 'RDMS', 'SMDAX', 'YF5/A2'], description='cilia and flagella associated protein 410', other_designations='cilia- and flagella-associated protein 410|nuclear encoded mitochondrial protein C21orf2|C21orf-HUMF09G8.5|leucine rich repeat containing 76|leucine-rich repeat-containing protein 76|protein C21orf2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44328944, end_position_on_the_genomic_accession=44339417, orientation='minus', exon_count=10, OMIM=[603191], no_hdr0=''),
    757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=757, CurrentID=0, Status='live', Symbol='TMEM50B', Aliases=['C21orf4', 'HCVP7TP3'], description='transmembrane protein 50B', other_designations='transmembrane protein 50B|HCV p7-trans-regulated protein 3|HCV p7-transregulated protein 3', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33432486, end_position_on_the_genomic_accession=33480004, orientation='minus', exon_count=10, OMIM=[617894], no_hdr0=''),
    758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=758, CurrentID=0, Status='live', Symbol='MPPED1', Aliases=['239AB', 'C22orf1', 'FAM1A'], description='metallophosphoesterase domain containing 1', other_designations='metallophosphoesterase domain-containing protein 1|adult brain protein 239', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43412014, end_position_on_the_genomic_accession=43507848, orientation='plus', exon_count=8, OMIM=[602112], no_hdr0=''),
    759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=759, CurrentID=0, Status='live', Symbol='CA1', Aliases=['CA-I', 'CAB', 'Car1', 'HEL-S-11'], description='carbonic anhydrase 1', other_designations='carbonic anhydrase 1|carbonate dehydratase I|carbonic anhydrase B|carbonic anhydrase I|epididymis secretory protein Li 11|epididymis secretory sperm binding protein', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85327608, end_position_on_the_genomic_accession=85378113, orientation='minus', exon_count=11, OMIM=[114800], no_hdr0=''),
    760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=760, CurrentID=0, Status='live', Symbol='CA2', Aliases=['CA-II', 'CAC', 'CAII', 'Car2', 'HEL-76', 'HEL-S-282'], description='carbonic anhydrase 2', other_designations='carbonic anhydrase 2|carbonate dehydratase II|carbonic anhydrase B|carbonic anhydrase C|carbonic anhydrase II|carbonic dehydratase|epididymis luminal protein 76|epididymis secretory protein Li 282', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85464007, end_position_on_the_genomic_accession=85481493, orientation='plus', exon_count=7, OMIM=[611492], no_hdr0=''),
    761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=761, CurrentID=0, Status='live', Symbol='CA3', Aliases=['CAIII', 'Car3'], description='carbonic anhydrase 3', other_designations='carbonic anhydrase 3|CA-III|HEL-S-167mP|carbonate dehydratase III|carbonic anhydrase III, muscle specific|carbonic anhydrase IIII|epididymis secretory sperm binding protein Li 167mP', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85438859, end_position_on_the_genomic_accession=85449040, orientation='plus', exon_count=7, OMIM=[114750], no_hdr0=''),
    762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=762, CurrentID=0, Status='live', Symbol='CA4', Aliases=['CAIV', 'Car4', 'RP17'], description='carbonic anhydrase 4', other_designations='carbonic anhydrase 4|CA-IV|carbonate dehydratase IV|carbonic anhydrase IV|carbonic dehydratase IV', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60149942, end_position_on_the_genomic_accession=60179021, orientation='plus', exon_count=13, OMIM=[114760], no_hdr0=''),
    763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=763, CurrentID=0, Status='live', Symbol='CA5A', Aliases=['CA5D', 'CAV', 'CAVA', 'GS1-21A4.1', 'CA5A'], description='carbonic anhydrase 5A', other_designations='carbonic anhydrase 5A, mitochondrial|CA-VA|carbonate dehydratase VA|carbonic anhydrase V, mitochondrial|carbonic anhydrase VA, mitochondrial|carbonic dehydratase', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87881549, end_position_on_the_genomic_accession=87936575, orientation='minus', exon_count=11, OMIM=[114761], no_hdr0=''),
    765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=765, CurrentID=0, Status='live', Symbol='CA6', Aliases=['CA-VI', 'GUSTIN'], description='carbonic anhydrase 6', other_designations='carbonic anhydrase 6|carbonate dehydratase VI|carbonic anhydrase VI nirs variant 2|salivary carbonic anhydrase|secreted carbonic anhydrase', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8945868, end_position_on_the_genomic_accession=8975092, orientation='plus', exon_count=10, OMIM=[114780], no_hdr0=''),
    766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=766, CurrentID=0, Status='live', Symbol='CA7', Aliases=['CA-VII', 'CAVII'], description='carbonic anhydrase 7', other_designations='carbonic anhydrase 7|carbonate dehydratase VII|carbonic anhydrase VII|carbonic dehydratase VII', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66844414, end_position_on_the_genomic_accession=66854149, orientation='plus', exon_count=9, OMIM=[114770], no_hdr0=''),
    767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=767, CurrentID=0, Status='live', Symbol='CA8', Aliases=['CA-RP', 'CA-VIII', 'CALS', 'CAMRQ3', 'CARP'], description='carbonic anhydrase 8', other_designations='carbonic anhydrase-related protein|CA-related protein|carbonate dehydratase|carbonic anhydrase VIII|carbonic anhydrase-like sequence', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=60185412, end_position_on_the_genomic_accession=60281400, orientation='minus', exon_count=14, OMIM=[114815], no_hdr0=''),
    768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=768, CurrentID=0, Status='live', Symbol='CA9', Aliases=['CAIX', 'MN'], description='carbonic anhydrase 9', other_designations='carbonic anhydrase 9|CA-IX|P54/58N|RCC-associated antigen G250|RCC-associated protein G250|carbonate dehydratase IX|carbonic anhydrase IX|carbonic dehydratase|membrane antigen MN|pMW1|renal cell carcinoma-associated antigen G250', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35673809, end_position_on_the_genomic_accession=35681159, orientation='plus', exon_count=11, OMIM=[603179], no_hdr0=''),
    770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=770, CurrentID=0, Status='live', Symbol='CA11', Aliases=['CA-RP', 'CA-RP II', 'CA-XI', 'CARP-2', 'CARPX1'], description='carbonic anhydrase 11', other_designations='carbonic anhydrase-related protein 11|carbonic anhydrase XI|carbonic anhydrase-related protein 2|carbonic anhydrase-related protein XI', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48637946, end_position_on_the_genomic_accession=48646187, orientation='minus', exon_count=6, OMIM=[604644], no_hdr0=''),
    771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=771, CurrentID=0, Status='live', Symbol='CA12', Aliases=['CA-XII', 'CAXII', 'HsT18816', 'T18816'], description='carbonic anhydrase 12', other_designations='carbonic anhydrase 12|carbonate dehydratase XII|carbonic anhydrase XII|carbonic dehydratase|tumor antigen HOM-RCC-3.1.3', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63321378, end_position_on_the_genomic_accession=63381846, orientation='minus', exon_count=11, OMIM=[603263], no_hdr0=''),
    773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=773, CurrentID=0, Status='live', Symbol='CACNA1A', Aliases=['APCA', 'BI', 'CACNL1A4', 'CAV2.1', 'DEE42', 'EA2', 'EIEE42', 'FHM', 'HPCA', 'MHP', 'MHP1', 'SCA6'], description='calcium voltage-gated channel subunit alpha1 A', other_designations='voltage-dependent P/Q-type calcium channel subunit alpha-1A|brain calcium channel 1|brain calcium channel I|calcium channel, L type, alpha-1 polypeptide|calcium channel, voltage-dependent, P/Q type, alpha 1A subunit|fetal brain Ca2+ voltage-gated channel alpha1A pore-forming subunit|voltage-gated calcium channel subunit alpha Cav2.1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13206442, end_position_on_the_genomic_accession=13506479, orientation='minus', exon_count=49, OMIM=[601011], no_hdr0=''),
    774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=774, CurrentID=0, Status='live', Symbol='CACNA1B', Aliases=['BIII', 'CACNL1A5', 'CACNN', 'Cav2.2', 'DYT23', 'NEDNEH'], description='calcium voltage-gated channel subunit alpha1 B', other_designations='voltage-dependent N-type calcium channel subunit alpha-1B|Cav2.2 voltage-gated Ca2+ channel|brain calcium channel III|calcium channel alpha12.2 subunit|calcium channel, L type, alpha-1 polypeptide|calcium channel, voltage-dependent, L type, alpha 1B subunit|calcium channel, voltage-dependent, N type, alpha 1B subunit|voltage-gated calcium channel alpha subunit Cav2.2|voltage-gated calcium channel subunit alpha Cav2.2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137877782, end_position_on_the_genomic_accession=138124619, orientation='plus', exon_count=47, OMIM=[601012], no_hdr0=''),
    775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=775, CurrentID=0, Status='live', Symbol='CACNA1C', Aliases=['CACH2', 'CACN2', 'CACNL1A1', 'CCHL1A1', 'CaV1.2', 'LQT8', 'TS', 'TS. LQT8'], description='calcium voltage-gated channel subunit alpha1 C', other_designations='voltage-dependent L-type calcium channel subunit alpha-1C|DHPR, alpha-1 subunit|calcium channel, cardic dihydropyridine-sensitive, alpha-1 subunit|calcium channel, voltage-dependent, L type, alpha 1C subunit|voltage-dependent L-type Ca2+ channel alpha 1 subunit|voltage-gated L-type calcium channel Cav1.2 alpha 1 subunit, splice variant 10*', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1969552, end_position_on_the_genomic_accession=2697950, orientation='plus', exon_count=56, OMIM=[114205], no_hdr0=''),
    776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=776, CurrentID=0, Status='live', Symbol='CACNA1D', Aliases=['CACH3', 'CACN4', 'CACNL1A2', 'CCHL1A2', 'Cav1.3', 'PASNA', 'SANDD'], description='calcium voltage-gated channel subunit alpha1 D', other_designations='voltage-dependent L-type calcium channel subunit alpha-1D|calcium channel, L type, alpha-1 polypeptide|calcium channel, neuroendocrine/brain-type, alpha 1 subunit|calcium channel, voltage-dependent, L type, alpha 1D subunit|voltage-gated calcium channel alpha 1 subunit|voltage-gated calcium channel alpha subunit Cav1.3', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53494611, end_position_on_the_genomic_accession=53813733, orientation='plus', exon_count=53, OMIM=[114206], no_hdr0=''),
    777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=777, CurrentID=0, Status='live', Symbol='CACNA1E', Aliases=['BII', 'CACH6', 'CACNL1A6', 'Cav2.3', 'DEE69', 'EIEE69', 'gm139'], description='calcium voltage-gated channel subunit alpha1 E', other_designations='voltage-dependent R-type calcium channel subunit alpha-1E|brain calcium channel II|calcium channel, L type, alpha-1 polypeptide|calcium channel, R type, alpha-1 polypeptide|voltage-dependent calcium channel alpha 1E subunit|voltage-gated calcium channel alpha subunit Cav2.3', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=181317712, end_position_on_the_genomic_accession=181808084, orientation='plus', exon_count=52, OMIM=[601013], no_hdr0=''),
    778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=778, CurrentID=0, Status='live', Symbol='CACNA1F', Aliases=['AIED', 'COD3', 'COD4', 'CORDX', 'CORDX3', 'CSNB2', 'CSNB2A', 'CSNBX2', 'Cav1.4', 'Cav1.4alpha1', 'JM8', 'JMC8', 'OA2'], description='calcium voltage-gated channel subunit alpha1 F', other_designations='voltage-dependent L-type calcium channel subunit alpha-1F|calcium channel, voltage-dependent, L type, alpha 1F subunit|voltage-gated calcium channel subunit alpha Cav1.4', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49205063, end_position_on_the_genomic_accession=49233404, orientation='minus', exon_count=48, OMIM=[300110], no_hdr0=''),
    779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=779, CurrentID=0, Status='live', Symbol='CACNA1S', Aliases=['CACNL1A3', 'CCHL1A3', 'Cav1.1', 'HOKPP', 'HOKPP1', 'MHS5', 'TTPP1', 'hypoPP'], description='calcium voltage-gated channel subunit alpha1 S', other_designations='voltage-dependent L-type calcium channel subunit alpha-1S|calcium channel, voltage-dependent, L type, alpha 1S subunit|dihydropyridine receptor alpha 1 subunit|dihydropyridine-sensitive L-type calcium channel alpha-1 subunit|voltage-gated calcium channel subunit alpha Cav1.1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201039509, end_position_on_the_genomic_accession=201112453, orientation='minus', exon_count=44, OMIM=[114208], no_hdr0=''),
    780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=780, CurrentID=0, Status='live', Symbol='DDR1', Aliases=['CAK', 'CD167', 'DDR', 'EDDR1', 'HGK2', 'MCK10', 'NEP', 'NTRK4', 'PTK3', 'PTK3A', 'RTK6', 'TRKE'], description='discoidin domain receptor tyrosine kinase 1', other_designations='epithelial discoidin domain-containing receptor 1|CD167 antigen-like family member A|PTK3A protein tyrosine kinase 3A|cell adhesion kinase|mammary carcinoma kinase 10|neuroepithelial tyrosine kinase|neurotrophic tyrosine kinase, receptor, type 4|protein-tyrosine kinase RTK-6|tyrosine kinase DDR|tyrosine-protein kinase CAK', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30880958, end_position_on_the_genomic_accession=30900156, orientation='plus', exon_count=26, OMIM=[600408], no_hdr0=''),
    781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=781, CurrentID=0, Status='live', Symbol='CACNA2D1', Aliases=['CACNA2', 'CACNL2A', 'CCHL2A', 'LINC01112', 'lncRNA-N3'], description='calcium voltage-gated channel auxiliary subunit alpha2delta 1', other_designations='voltage-dependent calcium channel subunit alpha-2/delta-1|calcium channel, L type, alpha 2 polypeptide|calcium channel, voltage-dependent, alpha 2/delta subunit 1|dihydropyridine-sensitive L-type, calcium channel alpha-2/delta subunit|voltage-gated calcium channel subunit alpha-2/delta-1', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=81946444, end_position_on_the_genomic_accession=82443956, orientation='minus', exon_count=45, OMIM=[114204], no_hdr0=''),
    782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=782, CurrentID=0, Status='live', Symbol='CACNB1', Aliases=['CAB1', 'CACNLB1', 'CCHLB1'], description='calcium voltage-gated channel auxiliary subunit beta 1', other_designations='voltage-dependent L-type calcium channel subunit beta-1|calcium channel voltage-dependent subunit beta 1|calcium channel, L type, beta 1 polypeptide|calcium channel, voltage-dependent, beta 1 subunit|dihydropyridine-sensitive L-type, calcium channel beta-1 subunit', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39173453, end_position_on_the_genomic_accession=39197669, orientation='minus', exon_count=19, OMIM=[114207], no_hdr0=''),
    783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=783, CurrentID=0, Status='live', Symbol='CACNB2', Aliases=['CAB2', 'CACNLB2', 'CAVB2', 'MYSB'], description='calcium voltage-gated channel auxiliary subunit beta 2', other_designations='voltage-dependent L-type calcium channel subunit beta-2|calcium channel voltage-dependent subunit beta 2|calcium channel, voltage-dependent, beta 2 subunit|lambert-Eaton myasthenic syndrome antigen B|myasthenic (Lambert-Eaton) syndrome antigen B', map_location='10p12.33-p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=18140424, end_position_on_the_genomic_accession=18545881, orientation='plus', exon_count=20, OMIM=[600003], no_hdr0=''),
    784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=784, CurrentID=0, Status='live', Symbol='CACNB3', Aliases=['CAB3', 'CACNLB3'], description='calcium voltage-gated channel auxiliary subunit beta 3', other_designations='voltage-dependent L-type calcium channel subunit beta-3|calcium channel, voltage-dependent, beta 3 subunit', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48814432, end_position_on_the_genomic_accession=48828941, orientation='plus', exon_count=17, OMIM=[601958], no_hdr0=''),
    785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=785, CurrentID=0, Status='live', Symbol='CACNB4', Aliases=['CAB4', 'CACNLB4', 'EA5', 'EIG9', 'EJM', 'EJM4', 'EJM6'], description='calcium voltage-gated channel auxiliary subunit beta 4', other_designations='voltage-dependent L-type calcium channel subunit beta-4|calcium channel voltage-dependent subunit beta 4|dihydropyridine-sensitive L-type, calcium channel beta-4 subunit', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151832771, end_position_on_the_genomic_accession=152099167, orientation='minus', exon_count=22, OMIM=[601949], no_hdr0=''),
    786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=786, CurrentID=0, Status='live', Symbol='CACNG1', Aliases=['CACNLG'], description='calcium voltage-gated channel auxiliary subunit gamma 1', other_designations='voltage-dependent calcium channel gamma-1 subunit|L-type calcium channel gamma polypeptide|calcium channel, voltage-dependent, gamma subunit 1|dihydropyridine-sensitive L-type, skeletal muscle calcium channel subunit gamma|neuronal dihydropyridine-sensitive calcium channel gamma subunit', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67044554, end_position_on_the_genomic_accession=67056797, orientation='plus', exon_count=4, OMIM=[114209], no_hdr0=''),
    788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=788, CurrentID=0, Status='live', Symbol='SLC25A20', Aliases=['CAC', 'CACT'], description='solute carrier family 25 member 20', other_designations='mitochondrial carnitine/acylcarnitine carrier protein|solute carrier family 25 (carnitine/acylcarnitine translocase), member 20', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48856926, end_position_on_the_genomic_accession=48898882, orientation='minus', exon_count=9, OMIM=[613698], no_hdr0=''),
    790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=790, CurrentID=0, Status='live', Symbol='CAD', Aliases=['CDG1Z', 'DEE50', 'EIEE50', 'GATD4'], description='carbamoyl-phosphate synthetase 2, aspartate transcarbamylase, and dihydroorotase', other_designations='CAD protein|CAD trifunctional protein|multifunctional protein CAD', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27217369, end_position_on_the_genomic_accession=27243943, orientation='plus', exon_count=45, OMIM=[114010], no_hdr0=''),
    793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=793, CurrentID=0, Status='live', Symbol='CALB1', Aliases=['CALB', 'D-28K'], description='calbindin 1', other_designations='calbindin|RTVL-H protein|calbindin 1, (28kD)|calbindin 1, 28kDa|calbindin 27|calbindin D28|vitamin D-dependent calcium-binding protein, avian-type', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90058608, end_position_on_the_genomic_accession=90082879, orientation='minus', exon_count=11, OMIM=[114050], no_hdr0=''),
    794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=794, CurrentID=0, Status='live', Symbol='CALB2', Aliases=['CAB29', 'CAL2', 'CR'], description='calbindin 2', other_designations='calretinin|29 kDa calbindin|calbindin 2, (29kD, calretinin)|calbindin D29K|testicular secretory protein Li 8', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71358723, end_position_on_the_genomic_accession=71390438, orientation='plus', exon_count=10, OMIM=[114051], no_hdr0=''),
    795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=795, CurrentID=0, Status='live', Symbol='S100G', Aliases=['CABP', 'CABP1', 'CABP9K', 'CALB3'], description='S100 calcium binding protein G', other_designations='protein S100-G|calbindin 3, (vitamin D-dependent calcium-binding protein)|calbindin D9K|calbindin-D9k|vitamin D-dependent calcium-binding protein, intestinal', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16649787, end_position_on_the_genomic_accession=16654674, orientation='plus', exon_count=3, OMIM=[302020], no_hdr0=''),
    796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=796, CurrentID=0, Status='live', Symbol='CALCA', Aliases=['CALC1', 'CGRP', 'CGRP-I', 'CGRP-alpha', 'CGRP1', 'CT', 'KC', 'PCT'], description='calcitonin related polypeptide alpha', other_designations='calcitonin|calcitonin gene-related peptide 1|alpha-type CGRP|calcitonin 1|calcitonin gene-related peptide I|calcitonin/calcitonin-related polypeptide, alpha|katacalcin', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14966668, end_position_on_the_genomic_accession=14972361, orientation='minus', exon_count=7, OMIM=[114130], no_hdr0=''),
    797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=797, CurrentID=0, Status='live', Symbol='CALCB', Aliases=['CALC2', 'CGRP-II', 'CGRP2'], description='calcitonin related polypeptide beta', other_designations='calcitonin gene-related peptide 2|beta-CGRP|beta-type CGRP|calcitonin 2|calcitonin gene-related peptide II', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=15073593, end_position_on_the_genomic_accession=15078637, orientation='plus', exon_count=5, OMIM=[114160], no_hdr0=''),
    799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=799, CurrentID=0, Status='live', Symbol='CALCR', Aliases=['CRT', 'CT-R', 'CTR', 'CTR1'], description='calcitonin receptor', other_designations='calcitonin receptor', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93424486, end_position_on_the_genomic_accession=93574724, orientation='minus', exon_count=17, OMIM=[114131], no_hdr0=''),
    800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=800, CurrentID=0, Status='live', Symbol='CALD1', Aliases=['CDM', 'H-CAD', 'HCAD', 'L-CAD', 'LCAD', 'NAG22'], description='caldesmon 1', other_designations='caldesmon|testis secretory sperm-binding protein Li 227n', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134779629, end_position_on_the_genomic_accession=134970729, orientation='plus', exon_count=18, OMIM=[114213], no_hdr0=''),
    801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=801, CurrentID=0, Status='live', Symbol='CALM1', Aliases=['CALML2', 'CAM2', 'CAM3', 'CAMB', 'CAMC', 'CAMI', 'CAMIII', 'CPVT4', 'DD132', 'LQT14', 'PHKD', 'caM'], description='calmodulin 1', other_designations='calmodulin-1|Calmodulin-2|Calmodulin-3|calmodulin 1 (phosphorylase kinase, delta)|phosphorylase kinase subunit delta|phosphorylase kinase, delta subunit|prepro-calmodulin 1', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90396502, end_position_on_the_genomic_accession=90408268, orientation='plus', exon_count=8, OMIM=[114180], no_hdr0=''),
    805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=805, CurrentID=0, Status='live', Symbol='CALM2', Aliases=['CALM', 'CALML2', 'CAM1', 'CAM3', 'CAMC', 'CAMII', 'CAMIII', 'LQT15', 'PHKD', 'PHKD2', 'caM'], description='calmodulin 2', other_designations='calmodulin-2|Calmodulin-1|Calmodulin-3|LP7057 protein|calmodulin 2 (phosphorylase kinase, delta)|phosphorylase kinase delta|phosphorylase kinase subunit delta|prepro-calmodulin 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47160082, end_position_on_the_genomic_accession=47176936, orientation='minus', exon_count=8, OMIM=[114182], no_hdr0=''),
    808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=808, CurrentID=0, Status='live', Symbol='CALM3', Aliases=['CALM', 'CAM1', 'CAM2', 'CAMB', 'CPVT6', 'CaM', 'CaMIII', 'HEL-S-72', 'LQT16', 'PHKD', 'PHKD3'], description='calmodulin 3', other_designations='calmodulin-3|Calmodulin-1|Calmodulin-2|epididymis secretory protein Li 72|phosphorylase kinase subunit delta|prepro-calmodulin 3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46601074, end_position_on_the_genomic_accession=46610782, orientation='plus', exon_count=9, OMIM=[114183], no_hdr0=''),
    810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=810, CurrentID=0, Status='live', Symbol='CALML3', Aliases=['CLP'], description='calmodulin like 3', other_designations='calmodulin-like protein 3|caM-like protein|calmodulin-related protein NB-1', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5524961, end_position_on_the_genomic_accession=5526771, orientation='plus', exon_count=1, OMIM=[114184], no_hdr0=''),
    811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=811, CurrentID=0, Status='live', Symbol='CALR', Aliases=['CRT', 'HEL-S-99n', 'RO', 'SSA', 'cC1qR'], description='calreticulin', other_designations='calreticulin|CRP55|ERp60|HACBP|Sicca syndrome antigen A (autoantigen Ro; calreticulin)|calregulin|endoplasmic reticulum resident protein 60|epididymis secretory sperm binding protein Li 99n|grp60', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12938609, end_position_on_the_genomic_accession=12944489, orientation='plus', exon_count=9, OMIM=[109091], no_hdr0=''),
    813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=813, CurrentID=0, Status='live', Symbol='CALU', Aliases=[], description='calumenin', other_designations='calumenin|IEF SSP 9302|crocalbin-like protein|multiple EF-hand protein', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128739359, end_position_on_the_genomic_accession=128773400, orientation='plus', exon_count=9, OMIM=[603420], no_hdr0=''),
    814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=814, CurrentID=0, Status='live', Symbol='CAMK4', Aliases=['CaMK IV', 'CaMK-GR', 'CaMKIV', 'caMK'], description='calcium/calmodulin dependent protein kinase IV', other_designations='calcium/calmodulin-dependent protein kinase type IV|CAM kinase IV|CAM kinase- GR|brain Ca(2+)-calmodulin-dependent protein kinase type IV|brain Ca++-calmodulin-dependent protein kinase type IV|calcium/calmodulin-dependent protein kinase type IV catalytic chain', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=111223583, end_position_on_the_genomic_accession=111498503, orientation='plus', exon_count=15, OMIM=[114080], no_hdr0=''),
    815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=815, CurrentID=0, Status='live', Symbol='CAMK2A', Aliases=['CAMKA', 'CaMKIINalpha', 'CaMKIIalpha', 'MRD53', 'MRT63'], description='calcium/calmodulin dependent protein kinase II alpha', other_designations='calcium/calmodulin-dependent protein kinase type II subunit alpha|CaM kinase II alpha subunit|CaM-kinase II alpha chain|CaMK-II alpha subunit|caM kinase II subunit alpha|caMK-II subunit alpha|calcium/calmodulin-dependent protein kinase (CaM kinase) II alpha|calcium/calmodulin-dependent protein kinase II alpha-B subunit|calcium/calmodulin-dependent protein kinase type II alpha chain', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150219491, end_position_on_the_genomic_accession=150290130, orientation='minus', exon_count=20, OMIM=[114078], no_hdr0=''),
    816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=816, CurrentID=0, Status='live', Symbol='CAMK2B', Aliases=['CAM2', 'CAMK2', 'CAMKB', 'CaMKIIbeta', 'MRD54'], description='calcium/calmodulin dependent protein kinase II beta', other_designations='calcium/calmodulin-dependent protein kinase type II subunit beta|CaM kinase II beta subunit|CaM-kinase II beta chain|caMK-II subunit beta|proline rich calmodulin-dependent protein kinase', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44217154, end_position_on_the_genomic_accession=44326167, orientation='minus', exon_count=28, OMIM=[607707], no_hdr0=''),
    817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=817, CurrentID=0, Status='live', Symbol='CAMK2D', Aliases=['CAMKD'], description='calcium/calmodulin dependent protein kinase II delta', other_designations='calcium/calmodulin-dependent protein kinase type II subunit delta|CaM kinase II delta subunit|CaM-kinase II delta chain|CaMK-II delta subunit|calcium/calmodulin-dependent protein kinase (CaM kinase) II delta|calcium/calmodulin-dependent protein kinase type II delta chain', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=113451032, end_position_on_the_genomic_accession=113762177, orientation='minus', exon_count=26, OMIM=[607708], no_hdr0=''),
    818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=818, CurrentID=0, Status='live', Symbol='CAMK2G', Aliases=['CAMK', 'CAMK-II', 'CAMKG', 'MRD59'], description='calcium/calmodulin dependent protein kinase II gamma', other_designations='calcium/calmodulin-dependent protein kinase type II subunit gamma|caMK-II subunit gamma|calcium/calmodulin-dependent protein kinase (CaM kinase) II gamma', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73812501, end_position_on_the_genomic_accession=73874582, orientation='minus', exon_count=25, OMIM=[602123], no_hdr0=''),
    819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=819, CurrentID=0, Status='live', Symbol='CAMLG', Aliases=['CAML', 'GET2'], description='calcium modulating ligand', other_designations='guided entry of tail-anchored proteins factor CAMLG|calcium signal-modulating cyclophilin ligand|calcium-modulating cyclophilin ligand|cyclophilin B-binding protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134738548, end_position_on_the_genomic_accession=134752157, orientation='plus', exon_count=4, OMIM=[601118], no_hdr0=''),
    820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=820, CurrentID=0, Status='live', Symbol='CAMP', Aliases=['CAP-18', 'CAP18', 'CRAMP', 'FALL-39', 'FALL39', 'HSD26', 'LL37'], description='cathelicidin antimicrobial peptide', other_designations='cathelicidin antimicrobial peptide|18 kDa cationic antimicrobial protein|epididymis secretory sperm binding protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48223495, end_position_on_the_genomic_accession=48225485, orientation='plus', exon_count=4, OMIM=[600474], no_hdr0=''),
    821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=821, CurrentID=0, Status='live', Symbol='CANX', Aliases=['CNX', 'IP90', 'P90'], description='calnexin', other_designations='calnexin|epididymis secretory sperm binding protein|major histocompatibility complex class I antigen-binding protein p88', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179678646, end_position_on_the_genomic_accession=179731641, orientation='plus', exon_count=20, OMIM=[114217], no_hdr0=''),
    822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=822, CurrentID=0, Status='live', Symbol='CAPG', Aliases=['AFCP', 'HEL-S-66', 'MCP'], description='capping actin protein, gelsolin like', other_designations='macrophage-capping protein|actin-regulatory protein CAP-G|capping protein (actin filament), gelsolin-like|epididymis secretory protein Li 66|gelsolin-like capping protein', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85394753, end_position_on_the_genomic_accession=85418467, orientation='minus', exon_count=15, OMIM=[153615], no_hdr0=''),
    823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=823, CurrentID=0, Status='live', Symbol='CAPN1', Aliases=['CANP', 'CANP1', 'CANPL1', 'SPG76', 'muCANP', 'muCL'], description='calpain 1', other_designations='calpain-1 catalytic subunit|CANP 1|calcium-activated neutral proteinase 1|calpain 1, (mu/I) large subunit|calpain mu-type|calpain, large polypeptide L1|calpain-1 large subunit|cell proliferation-inducing gene 30 protein|cell proliferation-inducing protein 30|micromolar-calpain', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65181373, end_position_on_the_genomic_accession=65212006, orientation='plus', exon_count=26, OMIM=[114220], no_hdr0=''),
    824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=824, CurrentID=0, Status='live', Symbol='CAPN2', Aliases=['CANP2', 'CANPL2', 'CANPml', 'mCANP'], description='calpain 2', other_designations='calpain-2 catalytic subunit|CANP 2|M-calpain|calcium-activated neutral proteinase 2|calpain 2, (m/II) large subunit|calpain 2, large [catalytic] subunit|calpain 2, large subunit|calpain M-type|calpain, large polypeptide L2|millimolar-calpain', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223701597, end_position_on_the_genomic_accession=223776018, orientation='plus', exon_count=22, OMIM=[114230], no_hdr0=''),
    825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=825, CurrentID=0, Status='live', Symbol='CAPN3', Aliases=['CANP3', 'CANPL3', 'LGMD2', 'LGMD2A', 'LGMDD4', 'LGMDR1', 'nCL-1', 'p94'], description='calpain 3', other_designations='calpain-3|calpain p94, large [catalytic] subunit|calpain, large polypeptide L3|muscle-specific calcium-activated neutral protease 3 large subunit|new calpain 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42359501, end_position_on_the_genomic_accession=42412317, orientation='plus', exon_count=26, OMIM=[114240], no_hdr0=''),
    826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=826, CurrentID=0, Status='live', Symbol='CAPNS1', Aliases=['CALPAIN4', 'CANP', 'CANPS', 'CAPN4', 'CDPS', 'CSS1'], description='calpain small subunit 1', other_designations='calpain small subunit 1|CANP small subunit|calcium-activated neutral proteinase small subunit|calcium-dependent protease small subunit 1|calcium-dependent protease, small subunit|calpain 4, small subunit (30K)|calpain regulatory subunit|calpain, small polypeptide|epididymis secretory sperm binding protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36140066, end_position_on_the_genomic_accession=36150353, orientation='plus', exon_count=13, OMIM=[114170], no_hdr0=''),
    827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=827, CurrentID=0, Status='live', Symbol='CAPN6', Aliases=['CANPX', 'CAPNX', 'CalpM', 'DJ914P14.1'], description='calpain 6', other_designations='calpain-6|calpain-like protease X-linked|calpamodulin', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111245099, end_position_on_the_genomic_accession=111270483, orientation='minus', exon_count=13, OMIM=[300146], no_hdr0=''),
    828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=828, CurrentID=0, Status='live', Symbol='CAPS', Aliases=['CAPS1'], description='calcyphosine', other_designations='calcyphosin|calcyphosine 1|epididymis secretory sperm binding protein|thyroid protein p24', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5914254, end_position_on_the_genomic_accession=5916211, orientation='plus', exon_count=5, OMIM=[114212], no_hdr0=''),
    829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=829, CurrentID=0, Status='live', Symbol='CAPZA1', Aliases=['CAPPA1', 'CAPZ', 'CAZ1'], description='capping actin protein of muscle Z-line subunit alpha 1', other_designations='F-actin-capping protein subunit alpha-1|Cap Z|capZ alpha-1|capping actin protein of muscle Z-line alpha subunit 1|capping protein (actin filament) muscle Z-line, alpha 1', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112619775, end_position_on_the_genomic_accession=112671616, orientation='plus', exon_count=11, OMIM=[601580], no_hdr0=''),
    830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=830, CurrentID=0, Status='live', Symbol='CAPZA2', Aliases=['CAPPA2', 'CAPZ'], description='capping actin protein of muscle Z-line subunit alpha 2', other_designations='F-actin-capping protein subunit alpha-2|F-actin capping protein alpha-2 subunit|capZ alpha-2|capping actin protein of muscle Z-line alpha subunit 2|capping protein (actin filament) muscle Z-line, alpha 2|epididymis secretory sperm binding protein', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116862587, end_position_on_the_genomic_accession=116922049, orientation='plus', exon_count=10, OMIM=[601571], no_hdr0=''),
    831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=831, CurrentID=0, Status='live', Symbol='CAST', Aliases=['BS-17', 'PLACK'], description='calpastatin', other_designations='calpastatin|calpain inhibitor|sperm BS-17 component', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=96662037, end_position_on_the_genomic_accession=96774683, orientation='plus', exon_count=36, OMIM=[114090], no_hdr0=''),
    832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=832, CurrentID=0, Status='live', Symbol='CAPZB', Aliases=['CAPB', 'CAPPB', 'CAPZ'], description='capping actin protein of muscle Z-line subunit beta', other_designations='F-actin-capping protein subunit beta|capZ beta|capping actin protein of muscle Z-line beta subunit|capping protein (actin filament) muscle Z-line, beta|epididymis secretory sperm binding protein', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19338775, end_position_on_the_genomic_accession=19485539, orientation='minus', exon_count=17, OMIM=[601572], no_hdr0=''),
    833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=833, CurrentID=0, Status='live', Symbol='CARS1', Aliases=['CARS', 'CYSRS', 'MCDDBH', 'MDBH', 'MGC:11246'], description='cysteinyl-tRNA synthetase 1', other_designations='cysteine--tRNA ligase, cytoplasmic|cysteine tRNA ligase 1, cytoplasmic|cysteine translase', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3000929, end_position_on_the_genomic_accession=3057423, orientation='minus', exon_count=25, OMIM=[123859], no_hdr0=''),
    834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=834, CurrentID=0, Status='live', Symbol='CASP1', Aliases=['ICE', 'IL1BC', 'P45'], description='caspase 1', other_designations='caspase-1|CASP1 nirs variant 1|IL-1 beta-converting enzyme|IL1B-convertase|caspase 1, apoptosis-related cysteine peptidase|caspase-1 isoform alpha|interleukin 1, beta, convertase|interleukin 1-B converting enzyme', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=105025443, end_position_on_the_genomic_accession=105035591, orientation='minus', exon_count=12, OMIM=[147678], no_hdr0=''),
    835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=835, CurrentID=0, Status='live', Symbol='CASP2', Aliases=['CASP-2', 'ICH1', 'NEDD-2', 'NEDD2', 'PPP1R57'], description='caspase 2', other_designations='caspase-2|caspase 2 apoptosis-related cysteine peptidase|neural precursor cell expressed developmentally down-regulated protein 2|protease ICH-1|protein phosphatase 1, regulatory subunit 57', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143288351, end_position_on_the_genomic_accession=143307696, orientation='plus', exon_count=13, OMIM=[600639], no_hdr0=''),
    836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=836, CurrentID=0, Status='live', Symbol='CASP3', Aliases=['CPP32', 'CPP32B', 'SCA-1'], description='caspase 3', other_designations='caspase-3|CASP-3|CPP-32|PARP cleavage protease|SREBP cleavage activity 1|apopain|caspase 3, apoptosis-related cysteine peptidase|caspase 3, apoptosis-related cysteine protease|cysteine protease CPP32|procaspase3|protein Yama', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184627696, end_position_on_the_genomic_accession=184649447, orientation='minus', exon_count=9, OMIM=[600636], no_hdr0=''),
    837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=837, CurrentID=0, Status='live', Symbol='CASP4', Aliases=['ICE(rel)II', 'ICEREL-II', 'ICH-2', 'Mih1', 'Mih1/TX', 'TX'], description='caspase 4', other_designations='caspase-4|CASP-4|ICE and Ced-3 homolog 2|ICE(rel)-II|apoptotic cysteine protease Mih1/TX|caspase 4, apoptosis-related cysteine peptidase|caspase 4, apoptosis-related cysteine protease|caspase-4 isoform alpha|protease ICH-2|protease TX', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=104942866, end_position_on_the_genomic_accession=104968596, orientation='minus', exon_count=10, OMIM=[602664], no_hdr0=''),
    838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=838, CurrentID=0, Status='live', Symbol='CASP5', Aliases=['ICE(rel)III', 'ICEREL-III', 'ICH-3'], description='caspase 5', other_designations='caspase-5|TY protease|caspase 5 variant X1|caspase 5, apoptosis-related cysteine peptidase|caspase 5, apoptosis-related cysteine protease|protease ICH-3|protease TY', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=104994243, end_position_on_the_genomic_accession=105023168, orientation='minus', exon_count=10, OMIM=[602665], no_hdr0=''),
    839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=839, CurrentID=0, Status='live', Symbol='CASP6', Aliases=['MCH2'], description='caspase 6', other_designations='caspase-6|apoptotic protease MCH-2|caspase 6, apoptosis-related cysteine peptidase|caspase 6, apoptosis-related cysteine protease', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109688628, end_position_on_the_genomic_accession=109703445, orientation='minus', exon_count=7, OMIM=[601532], no_hdr0=''),
    840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=840, CurrentID=0, Status='live', Symbol='CASP7', Aliases=['CASP-7', 'CMH-1', 'ICE-LAP3', 'LICE2', 'MCH3'], description='caspase 7', other_designations='caspase-7|ICE-like apoptotic protease 3|apoptotic protease MCH-3|caspase 7, apoptosis-related cysteine peptidase|caspase 7, apoptosis-related cysteine protease', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113679194, end_position_on_the_genomic_accession=113730909, orientation='plus', exon_count=13, OMIM=[601761], no_hdr0=''),
    841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=841, CurrentID=0, Status='live', Symbol='CASP8', Aliases=['ALPS2B', 'CAP4', 'Casp-8', 'FLICE', 'MACH', 'MCH5'], description='caspase 8', other_designations='caspase-8|FADD-homologous ICE/CED-3-like protease|FADD-like ICE|ICE-like apoptotic protease 5|MACH-alpha-1/2/3 protein|MACH-beta-1/2/3/4 protein|MORT1-associated ced-3 homolog|apoptotic cysteine protease|apoptotic protease Mch-5|caspase 8, apoptosis-related cysteine peptidase|caspase 8, apoptosis-related cysteine protease', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201233443, end_position_on_the_genomic_accession=201287711, orientation='plus', exon_count=15, OMIM=[601763], no_hdr0=''),
    842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=842, CurrentID=0, Status='live', Symbol='CASP9', Aliases=['APAF-3', 'APAF3', 'ICE-LAP6', 'MCH6', 'PPP1R56'], description='caspase 9', other_designations='caspase-9|ICE-like apoptotic protease 6|apoptotic protease MCH-6|apoptotic protease activating factor 3|caspase 9, apoptosis-related cysteine peptidase|protein phosphatase 1, regulatory subunit 56', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15491401, end_position_on_the_genomic_accession=15524912, orientation='minus', exon_count=11, OMIM=[602234], no_hdr0=''),
    843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=843, CurrentID=0, Status='live', Symbol='CASP10', Aliases=['ALPS2', 'FLICE-2', 'FLICE2', 'MCH4'], description='caspase 10', other_designations='caspase-10|CASP-10|FADD-like ICE2|FAS-associated death domain protein interleukin-1B-converting enzyme 2|ICE-like apoptotic protease 4|apoptotic protease MCH-4|caspase 10 apoptosis-related cysteine peptidase|caspase 10, apoptosis-related cysteine protease|interleukin-1B-converting enzyme 2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201182885, end_position_on_the_genomic_accession=201229406, orientation='plus', exon_count=13, OMIM=[601762], no_hdr0=''),
    844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=844, CurrentID=0, Status='live', Symbol='CASQ1', Aliases=['CASQ', 'PDIB1', 'VMCQA'], description='calsequestrin 1', other_designations='calsequestrin-1|calmitin|calmitine|calsequestrin 1 (fast-twitch, skeletal muscle)', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160190575, end_position_on_the_genomic_accession=160201886, orientation='plus', exon_count=11, OMIM=[114250], no_hdr0=''),
    845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=845, CurrentID=0, Status='live', Symbol='CASQ2', Aliases=['PDIB2'], description='calsequestrin 2', other_designations='calsequestrin-2|calsequestrin 2 (cardiac muscle)|calsequestrin 2, fast-twitch, cardiac muscle', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115700021, end_position_on_the_genomic_accession=115768714, orientation='minus', exon_count=11, OMIM=[114251], no_hdr0=''),
    846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=846, CurrentID=0, Status='live', Symbol='CASR', Aliases=['CAR', 'EIG8', 'FHH', 'FIH', 'GPRC2A', 'HHC', 'HHC1', 'HYPOC1', 'NSHPT', 'PCAR1', 'hCasR'], description='calcium sensing receptor', other_designations='extracellular calcium-sensing receptor|parathyroid Ca(2+)-sensing receptor 1|parathyroid cell calcium-sensing receptor 1', map_location='3q13.33-q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122183668, end_position_on_the_genomic_accession=122291629, orientation='plus', exon_count=11, OMIM=[601199], no_hdr0=''),
    847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=847, CurrentID=0, Status='live', Symbol='CAT', Aliases=[], description='catalase', other_designations='catalase|epididymis secretory sperm binding protein', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34438934, end_position_on_the_genomic_accession=34472060, orientation='plus', exon_count=13, OMIM=[115500], no_hdr0=''),
    857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=857, CurrentID=0, Status='live', Symbol='CAV1', Aliases=['BSCL3', 'CGL3', 'LCCNS', 'MSTP085', 'PPH3', 'VIP21'], description='caveolin 1', other_designations='caveolin-1|caveolin 1, caveolae protein, 22kDa|cell growth-inhibiting protein 32', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116525009, end_position_on_the_genomic_accession=116561185, orientation='plus', exon_count=4, OMIM=[601047], no_hdr0=''),
    858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=858, CurrentID=0, Status='live', Symbol='CAV2', Aliases=['CAV'], description='caveolin 2', other_designations='caveolin-2|caveolae protein, 20-kD', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116499738, end_position_on_the_genomic_accession=116508541, orientation='plus', exon_count=3, OMIM=[601048], no_hdr0=''),
    859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=859, CurrentID=0, Status='live', Symbol='CAV3', Aliases=['LGMD1C', 'LQT9', 'MPDT', 'RMD2', 'VIP-21', 'VIP21'], description='caveolin 3', other_designations='caveolin-3|M-caveolin|cavolin 3', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8733802, end_position_on_the_genomic_accession=8746758, orientation='plus', exon_count=2, OMIM=[601253], no_hdr0=''),
    860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=860, CurrentID=0, Status='live', Symbol='RUNX2', Aliases=['AML3', 'CBF-alpha-1', 'CBFA1', 'CCD', 'CCD1', 'CLCD', 'OSF-2', 'OSF2', 'PEA2aA', 'PEBP2aA'], description='RUNX family transcription factor 2', other_designations='runt-related transcription factor 2|PEA2-alpha A|PEBP2-alpha A|SL3-3 enhancer factor 1 alpha A subunit|SL3/AKV core-binding factor alpha A subunit|acute myeloid leukemia 3 protein|core-binding factor, runt domain, alpha subunit 1|oncogene AML-3|osteoblast-specific transcription factor 2|polyomavirus enhancer-binding protein 2 alpha A subunit|runt related transcription factor 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=45328330, end_position_on_the_genomic_accession=45551082, orientation='plus', exon_count=10, OMIM=[600211], no_hdr0=''),
    861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=861, CurrentID=0, Status='live', Symbol='RUNX1', Aliases=['AML1', 'AML1-EVI-1', 'AMLCR1', 'CBF2alpha', 'CBFA2', 'EVI-1', 'PEBP2aB', 'PEBP2alpha'], description='RUNX family transcription factor 1', other_designations='runt-related transcription factor 1|AML1-ETO fusion|AML1-ETO fusion protein|AML1-EVI-1 fusion protein|PEA2-alpha B|PEBP2-alpha B|SL3-3 enhancer factor 1 alpha B subunit|SL3/AKV core-binding factor alpha B subunit|acute myeloid leukemia 1 protein|core-binding factor, runt domain, alpha subunit 2|mutant RUNX1|oncogene AML-1|polyomavirus enhancer-binding protein 2 alpha B subunit|runt related transcription factor 1', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34787801, end_position_on_the_genomic_accession=35049334, orientation='minus', exon_count=13, OMIM=[151385], no_hdr0=''),
    862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=862, CurrentID=0, Status='live', Symbol='RUNX1T1', Aliases=['AML1-MTG8', 'AML1T1', 'CBFA2T1', 'CDR', 'ETO', 'MTG8', 'ZMYND2'], description='RUNX1 partner transcriptional co-repressor 1', other_designations='protein CBFA2T1|RUNX1 translocation partner 1|acute myelogenous leukemia 1 translocation 1, cyclin-D related|core-binding factor, runt domain, alpha subunit 2; translocated to, 1; cyclin D-related|eight twenty one protein|myeloid translocation gene on 8q22|runt related transcription factor 1; translocated to, 1 (cyclin D related)|zinc finger MYND domain-containing protein 2', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=91954967, end_position_on_the_genomic_accession=92103451, orientation='minus', exon_count=20, OMIM=[133435], no_hdr0=''),
    863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=863, CurrentID=0, Status='live', Symbol='CBFA2T3', Aliases=['ETO2', 'MTG16', 'MTGR2', 'RUNX1T3', 'ZMYND4'], description='CBFA2/RUNX1 partner transcriptional co-repressor 3', other_designations='protein CBFA2T3|CBFA2/RUNX1 translocation partner 3|MTG8-related gene 2|MTG8-related protein 2|core-binding factor, runt domain, alpha subunit 2; translocated to, 3|myeloid translocation gene 8 and 16b|myeloid translocation gene on chromosome 16 protein|zinc finger MYND domain-containing protein 4', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88874858, end_position_on_the_genomic_accession=88977207, orientation='minus', exon_count=14, OMIM=[603870], no_hdr0=''),
    864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=864, CurrentID=0, Status='live', Symbol='RUNX3', Aliases=['AML2', 'CBFA3', 'PEBP2aC'], description='RUNX family transcription factor 3', other_designations='runt-related transcription factor 3|CBF-alpha-3|PEA2 alpha C|PEBP2 alpha C|SL3-3 enhancer factor 1 alpha C subunit|SL3/AKV core-binding factor alpha C subunit|acute myeloid leukemia 2 protein|acute myeloid leukemia gene 2|core-binding factor subunit alpha-3|core-binding factor, runt domain, alpha subunit 3|oncogene AML-2|polyomavirus enhancer-binding protein 2 alpha C subunit|runt related transcription factor 3|transcription factor AML2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24899511, end_position_on_the_genomic_accession=24965158, orientation='minus', exon_count=7, OMIM=[600210], no_hdr0=''),
    865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=865, CurrentID=0, Status='live', Symbol='CBFB', Aliases=['PEBP2B'], description='core-binding factor subunit beta', other_designations='core-binding factor subunit beta|CBF-beta|PEA2-beta|PEBP2-beta|SL3-3 enhancer factor 1 beta subunit|SL3-3 enhancer factor 1 subunit beta|SL3/AKV core-binding factor beta subunit|core-binding factor beta subunit|polyomavirus enhancer binding protein 2, beta subunit', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67029149, end_position_on_the_genomic_accession=67101058, orientation='plus', exon_count=6, OMIM=[121360], no_hdr0=''),
    866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=866, CurrentID=0, Status='live', Symbol='SERPINA6', Aliases=['CBG'], description='serpin family A member 6', other_designations='corticosteroid-binding globulin|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 6|serpin A6|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 6|transcortin', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94304248, end_position_on_the_genomic_accession=94323336, orientation='minus', exon_count=5, OMIM=[122500], no_hdr0=''),
    867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=867, CurrentID=0, Status='live', Symbol='CBL', Aliases=['C-CBL2', 'FRA11B', 'NSLL', 'RNF55', 'CBL'], description='Cbl proto-oncogene', other_designations='E3 ubiquitin-protein ligase CBL|Cas-Br-M (murine) ecotropic retroviral transforming sequence|Cbl proto-oncogene, E3 ubiquitin protein ligase|RING finger protein 55|RING-type E3 ubiquitin transferase CBL|casitas B-lineage lymphoma proto-oncogene|fragile site, folic acid type, rare, fra(11)(q23.3)|oncogene CBL2|proto-oncogene c-Cbl|signal transduction protein CBL', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119206339, end_position_on_the_genomic_accession=119308149, orientation='plus', exon_count=16, OMIM=[165360], no_hdr0=''),
    868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=868, CurrentID=0, Status='live', Symbol='CBLB', Aliases=['Cbl-b', 'Nbla00127', 'RNF56'], description='Cbl proto-oncogene B', other_designations='E3 ubiquitin-protein ligase CBL-B|Cas-Br-M (murine) ecotropic retroviral transforming sequence b|Cbl proto-oncogene B, E3 ubiquitin protein ligase|Cbl proto-oncogene, E3 ubiquitin protein ligase B|RING finger protein 56|RING-type E3 ubiquitin transferase CBL-B|SH3-binding protein CBL-B|casitas B-lineage lymphoma proto-oncogene b|signal transduction protein CBL-B', map_location='3q13.11', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=105655461, end_position_on_the_genomic_accession=105869552, orientation='minus', exon_count=31, OMIM=[604491], no_hdr0=''),
    869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=869, CurrentID=0, Status='live', Symbol='CBLN1', Aliases=[], description='cerebellin 1 precursor', other_designations='cerebellin-1|precerebellin', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=49277917, end_position_on_the_genomic_accession=49281838, orientation='minus', exon_count=3, OMIM=[600432], no_hdr0=''),
    871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=871, CurrentID=0, Status='live', Symbol='SERPINH1', Aliases=['AsTP3', 'CBP1', 'CBP2', 'HSP47', 'OI10', 'PIG14', 'PPROM', 'RA-A47', 'SERPINH2', 'gp46'], description='serpin family H member 1', other_designations='serpin H1|47 kDa heat shock protein|arsenic-transactivated protein 3|cell proliferation-inducing gene 14 protein|collagen binding protein 1|colligin-1|colligin-2|rheumatoid arthritis antigen A-47|rheumatoid arthritis-related antigen RA-A47|serine (or cysteine) proteinase inhibitor, clade H (heat shock protein 47), member 1, (collagen binding protein 1)|serine (or cysteine) proteinase inhibitor, clade H (heat shock protein 47), member 2, (collagen-binding protein 2)|serpin peptidase inhibitor, clade H (heat shock protein 47), member 1, (collagen binding protein 1)', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75562253, end_position_on_the_genomic_accession=75572783, orientation='plus', exon_count=8, OMIM=[600943], no_hdr0=''),
    873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=873, CurrentID=0, Status='live', Symbol='CBR1', Aliases=['CBR', 'PG-9-KR', 'SDR21C1', 'hCBR1'], description='carbonyl reductase 1', other_designations='carbonyl reductase [NADPH] 1|15-hydroxyprostaglandin dehydrogenase|20-beta-hydroxysteroid dehydrogenase|NADPH-dependent carbonyl reductase 1|carbonyl reductase (NADPH) 1|epididymis secretory sperm binding protein|prostaglandin 9-ketoreductase|prostaglandin-E(2) 9-reductase|short chain dehydrogenase/reductase family 21C member 1', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36070024, end_position_on_the_genomic_accession=36073164, orientation='plus', exon_count=3, OMIM=[114830], no_hdr0=''),
    874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=874, CurrentID=0, Status='live', Symbol='CBR3', Aliases=['HEL-S-25', 'SDR21C2', 'hCBR3'], description='carbonyl reductase 3', other_designations='carbonyl reductase [NADPH] 3|NADPH-dependent carbonyl reductase 3|carbonyl reductase (NADPH) 3|epididymis secretory protein Li 25|short chain dehydrogenase/reductase family 21C member 2', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36134901, end_position_on_the_genomic_accession=36146562, orientation='plus', exon_count=4, OMIM=[603608], no_hdr0=''),
    875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=875, CurrentID=0, Status='live', Symbol='CBS', Aliases=['CBSL', 'HIP4'], description='cystathionine beta-synthase', other_designations='cystathionine beta-synthase-like protein|cystathionine beta-synthase|Cystathionine beta-synthase-like protein|beta-thionase|methylcysteine synthase|serine sulfhydrase', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43053190, end_position_on_the_genomic_accession=43076873, orientation='minus', exon_count=23, OMIM=[613381], no_hdr0=''),
    881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=881, CurrentID=0, Status='live', Symbol='CCIN', Aliases=['BTBD20', 'KBTBD14'], description='calicin', other_designations='calicin|testis tissue sperm-binding protein Li 65n', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36169388, end_position_on_the_genomic_accession=36171334, orientation='plus', exon_count=1, OMIM=[603960], no_hdr0=''),
    883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=883, CurrentID=0, Status='live', Symbol='KYAT1', Aliases=['CCBL1', 'GTK', 'KAT1', 'KATI'], description='kynurenine aminotransferase 1', other_designations='kynurenine--oxoglutarate transaminase 1|beta-lysase, kidney|cysteine conjugate beta lyase 1|cysteine conjugate-beta lyase, cytoplasmic|cysteine conjugate-beta lyase; cytoplasmic (glutamine transaminase K, kyneurenine aminotransferase)|cysteine-S-conjugate beta-lyase|glutamine transaminase K|glutamine--phenylpyruvate transaminase|glutamine-phenylpyruvate aminotransferase|kyneurenine aminotransferase|kynurenine aminotransferase I|kynurenine--oxoglutarate transaminase I', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128832942, end_position_on_the_genomic_accession=128882523, orientation='minus', exon_count=19, OMIM=[600547], no_hdr0=''),
    885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=885, CurrentID=0, Status='live', Symbol='CCK', Aliases=[], description='cholecystokinin', other_designations='cholecystokinin|cholecystokinin triacontatriapeptide|prepro-cholecystokinin', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42257826, end_position_on_the_genomic_accession=42266185, orientation='minus', exon_count=6, OMIM=[118440], no_hdr0=''),
    886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=886, CurrentID=0, Status='live', Symbol='CCKAR', Aliases=['CCK-A', 'CCK1-R', 'CCK1R', 'CCKRA'], description='cholecystokinin A receptor', other_designations='cholecystokinin receptor type A|CCK-A receptor|CCK-AR|cholecystokinin type-A receptor|cholecystokinin-1 receptor', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=26481396, end_position_on_the_genomic_accession=26490484, orientation='minus', exon_count=5, OMIM=[118444], no_hdr0=''),
    887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=887, CurrentID=0, Status='live', Symbol='CCKBR', Aliases=['CCK-B', 'CCK2R', 'GASR'], description='cholecystokinin B receptor', other_designations='gastrin/cholecystokinin type B receptor|CCK-B receptor|CCK2 receptor|cholecystokinin-2 receptor|gastrin receptor', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6259838, end_position_on_the_genomic_accession=6272127, orientation='plus', exon_count=5, OMIM=[118445], no_hdr0=''),
    889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=889, CurrentID=0, Status='live', Symbol='KRIT1', Aliases=['CAM', 'CCM1'], description='KRIT1 ankyrin repeat containing', other_designations='krev interaction trapped protein 1|ankyrin repeat-containing protein Krit1|cerebral cavernous malformations 1 protein|krev interaction trapped 1', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92198969, end_position_on_the_genomic_accession=92246100, orientation='minus', exon_count=20, OMIM=[604214], no_hdr0=''),
    890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=890, CurrentID=0, Status='live', Symbol='CCNA2', Aliases=['CCN1', 'CCNA'], description='cyclin A2', other_designations='cyclin-A2|cyclin-A', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121816444, end_position_on_the_genomic_accession=121823883, orientation='minus', exon_count=8, OMIM=[123835], no_hdr0=''),
    891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=891, CurrentID=0, Status='live', Symbol='CCNB1', Aliases=['CCNB'], description='cyclin B1', other_designations='G2/mitotic-specific cyclin-B1', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69167150, end_position_on_the_genomic_accession=69178245, orientation='plus', exon_count=9, OMIM=[123836], no_hdr0=''),
    892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=892, CurrentID=0, Status='live', Symbol='CCNC', Aliases=['CycC', 'SRB11', 'hSRB11'], description='cyclin C', other_designations='cyclin-C|SRB11 homolog', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99542387, end_position_on_the_genomic_accession=99568814, orientation='minus', exon_count=16, OMIM=[123838], no_hdr0=''),
    894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=894, CurrentID=0, Status='live', Symbol='CCND2', Aliases=['KIAK0002', 'MPPH3'], description='cyclin D2', other_designations='G1/S-specific cyclin-D2', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4273762, end_position_on_the_genomic_accession=4305353, orientation='plus', exon_count=5, OMIM=[123833], no_hdr0=''),
    896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=896, CurrentID=0, Status='live', Symbol='CCND3', Aliases=[], description='cyclin D3', other_designations='G1/S-specific cyclin-D3|D3-type cyclin', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41934933, end_position_on_the_genomic_accession=42048894, orientation='minus', exon_count=7, OMIM=[123834], no_hdr0=''),
    898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=898, CurrentID=0, Status='live', Symbol='CCNE1', Aliases=['CCNE', 'pCCNE1'], description='cyclin E1', other_designations='G1/S-specific cyclin-E1', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29811991, end_position_on_the_genomic_accession=29824312, orientation='plus', exon_count=12, OMIM=[123837], no_hdr0=''),
    899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=899, CurrentID=0, Status='live', Symbol='CCNF', Aliases=['FBX1', 'FBXO1', 'FTDALS5'], description='cyclin F', other_designations='cyclin-F|F-box only protein 1|G2/mitotic-specific cyclin-F', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2429447, end_position_on_the_genomic_accession=2458854, orientation='plus', exon_count=17, OMIM=[600227], no_hdr0=''),
    900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=900, CurrentID=0, Status='live', Symbol='CCNG1', Aliases=['CCNG'], description='cyclin G1', other_designations='cyclin-G1|cyclin-G', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=163437571, end_position_on_the_genomic_accession=163448199, orientation='plus', exon_count=11, OMIM=[601578], no_hdr0=''),
    901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=901, CurrentID=0, Status='live', Symbol='CCNG2', Aliases=[], description='cyclin G2', other_designations='cyclin-G2', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=77157207, end_position_on_the_genomic_accession=77170060, orientation='plus', exon_count=10, OMIM=[603203], no_hdr0=''),
    902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=902, CurrentID=0, Status='live', Symbol='CCNH', Aliases=['CAK', 'CycH', 'p34', 'p37'], description='cyclin H', other_designations='cyclin-H|CAK complex subunit|CDK-activating kinase complex subunit|MO15-associated protein|cyclin-dependent kinase-activating kinase complex subunit', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=87311471, end_position_on_the_genomic_accession=87412971, orientation='minus', exon_count=11, OMIM=[601953], no_hdr0=''),
    904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=904, CurrentID=0, Status='live', Symbol='CCNT1', Aliases=['CCNT', 'CYCT1', 'HIVE1'], description='cyclin T1', other_designations='cyclin-T1|CDK9-associated C-type protein|MLLT10/CCNT1 fusion|cyclin C-related protein|human immunodeficiency virus type 1 (HIV-1) expression (elevated) 1', map_location='12q13.11-q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48688458, end_position_on_the_genomic_accession=48716707, orientation='minus', exon_count=10, OMIM=[143055], no_hdr0=''),
    905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=905, CurrentID=0, Status='live', Symbol='CCNT2', Aliases=['CYCT2'], description='cyclin T2', other_designations='cyclin-T2|SDS-stable vimentin-bound DNA fragment HEF42VIM22|cyclin T2a|cyclin T2b|subunit of positive elongation transcription factor b', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=134918810, end_position_on_the_genomic_accession=134959342, orientation='plus', exon_count=10, OMIM=[603862], no_hdr0=''),
    908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=908, CurrentID=0, Status='live', Symbol='CCT6A', Aliases=['CCT-zeta', 'CCT-zeta-1', 'CCT6', 'Cctz', 'HTR3', 'MoDP-2', 'TCP-1-zeta', 'TCP20', 'TCPZ', 'TTCP20'], description='chaperonin containing TCP1 subunit 6A', other_designations='T-complex protein 1 subunit zeta|T-complex protein 1, zeta subunit|acute morphine dependence related protein 2|amino acid transport defect-complementing|chaperonin containing T-complex subunit 6|chaperonin containing TCP1, subunit 6A (zeta 1)|histidine transport regulator 3', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56051765, end_position_on_the_genomic_accession=56063989, orientation='plus', exon_count=14, OMIM=[104613], no_hdr0=''),
    909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=909, CurrentID=0, Status='live', Symbol='CD1A', Aliases=['CD1', 'FCB6', 'HTA1', 'R4', 'T6'], description='CD1a molecule', other_designations='T-cell surface glycoprotein CD1a|CD1A antigen, a polypeptide|T-cell surface antigen T6/Leu-6|cluster of differentiation 1 A|cortical thymocyte antigen CD1A|differentiation antigen CD1-alpha-3|epidermal dendritic cell marker CD1a|hTa1 thymocyte antigen', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158248336, end_position_on_the_genomic_accession=158258269, orientation='plus', exon_count=8, OMIM=[188370], no_hdr0=''),
    910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=910, CurrentID=0, Status='live', Symbol='CD1B', Aliases=['CD1', 'CD1A', 'R1'], description='CD1b molecule', other_designations='T-cell surface glycoprotein CD1b|CD1B antigen, b polypeptide|cortical thymocyte antigen CD1B|differentiation antigen CD1-alpha-3', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158285406, end_position_on_the_genomic_accession=158331531, orientation='minus', exon_count=8, OMIM=[188360], no_hdr0=''),
    911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=911, CurrentID=0, Status='live', Symbol='CD1C', Aliases=['BDCA1', 'CD1', 'CD1A', 'R7'], description='CD1c molecule', other_designations='T-cell surface glycoprotein CD1c|CD1C antigen, c polypeptide|cortical thymocyte antigen CD1C|differentiation antigen CD1-alpha-3', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158289887, end_position_on_the_genomic_accession=158294774, orientation='plus', exon_count=6, OMIM=[188340], no_hdr0=''),
    912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=912, CurrentID=0, Status='live', Symbol='CD1D', Aliases=['CD1A', 'R3', 'R3G1'], description='CD1d molecule', other_designations='antigen-presenting glycoprotein CD1d|CD1D antigen, d polypeptide|HMC class I antigen-like glycoprotein CD1D|T-cell surface glycoprotein CD1d|differentiation antigen CD1-alpha-3|thymocyte antigen CD1D', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158178030, end_position_on_the_genomic_accession=158186427, orientation='plus', exon_count=8, OMIM=[188410], no_hdr0=''),
    913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=913, CurrentID=0, Status='live', Symbol='CD1E', Aliases=['CD1A', 'R2'], description='CD1e molecule', other_designations='T-cell surface glycoprotein CD1e, membrane-associated|CD1E antigen, e polypeptide|R2G1|differentiation antigen CD1-alpha-3|hCD1e|leukocyte differentiation antigen|thymocyte antigen CD1E', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158353123, end_position_on_the_genomic_accession=158357554, orientation='plus', exon_count=6, OMIM=[188411], no_hdr0=''),
    914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=914, CurrentID=0, Status='live', Symbol='CD2', Aliases=['LFA-2', 'SRBC', 'T11'], description='CD2 molecule', other_designations='T-cell surface antigen CD2|CD2 antigen (p50), sheep red blood cell receptor|LFA-3 receptor|T-cell surface antigen T11/Leu-5|erythrocyte receptor|lymphocyte-function antigen-2|rosette receptor', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116754430, end_position_on_the_genomic_accession=116769229, orientation='plus', exon_count=5, OMIM=[186990], no_hdr0=''),
    915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=915, CurrentID=0, Status='live', Symbol='CD3D', Aliases=['CD3-DELTA', 'IMD19', 'T3D'], description='CD3d molecule', other_designations='T-cell surface glycoprotein CD3 delta chain|CD3 antigen, delta subunit|CD3 delta|CD3d antigen, delta polypeptide (TiT3 complex)|CD3d molecule, delta (CD3-TCR complex)|OKT3, delta chain|T-cell receptor T3 delta chain', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118338954, end_position_on_the_genomic_accession=118342705, orientation='minus', exon_count=5, OMIM=[186790], no_hdr0=''),
    916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=916, CurrentID=0, Status='live', Symbol='CD3E', Aliases=['IMD18', 'T3E', 'TCRE'], description='CD3e molecule', other_designations='T-cell surface glycoprotein CD3 epsilon chain|CD3-epsilon|CD3e antigen, epsilon polypeptide (TiT3 complex)|CD3e molecule, epsilon (CD3-TCR complex)|T-cell antigen receptor complex, epsilon subunit of T3|T-cell surface antigen T3/Leu-4 epsilon chain', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118304730, end_position_on_the_genomic_accession=118316173, orientation='plus', exon_count=9, OMIM=[186830], no_hdr0=''),
    917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=917, CurrentID=0, Status='live', Symbol='CD3G', Aliases=['CD3-GAMMA', 'IMD17', 'T3G'], description='CD3g molecule', other_designations='T-cell surface glycoprotein CD3 gamma chain|CD3g antigen, gamma polypeptide (TiT3 complex)|CD3g molecule, epsilon (CD3-TCR complex)|CD3g molecule, gamma (CD3-TCR complex)|T-cell antigen receptor complex, gamma subunit of T3|T-cell receptor T3 gamma chain', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118344344, end_position_on_the_genomic_accession=118355161, orientation='plus', exon_count=7, OMIM=[186740], no_hdr0=''),
    919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=919, CurrentID=0, Status='live', Symbol='CD247', Aliases=['CD3-ZETA', 'CD3H', 'CD3Q', 'CD3Z', 'IMD25', 'T3Z', 'TCRZ'], description='CD247 molecule', other_designations='T-cell surface glycoprotein CD3 zeta chain|CD247 antigen, zeta subunit|CD3Z antigen, zeta polypeptide (TiT3 complex)|CD3zeta chain|T-cell antigen receptor complex, zeta subunit of CD3|T-cell receptor T3 zeta chain|TCR zeta chain', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167430640, end_position_on_the_genomic_accession=167518542, orientation='minus', exon_count=10, OMIM=[186780], no_hdr0=''),
    920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=920, CurrentID=0, Status='live', Symbol='CD4', Aliases=['CD4mut', 'IMD79', 'OKT4D'], description='CD4 molecule', other_designations='T-cell surface glycoprotein CD4|CD4 antigen (p55)|CD4 receptor|T-cell surface antigen T4/Leu-3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6789528, end_position_on_the_genomic_accession=6820799, orientation='plus', exon_count=11, OMIM=[186940], no_hdr0=''),
    921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=921, CurrentID=0, Status='live', Symbol='CD5', Aliases=['LEU1', 'T1'], description='CD5 molecule', other_designations='T-cell surface glycoprotein CD5|CD5 antigen (p56-62)|epididymis secretory sperm binding protein|lymphocyte antigen T1/Leu-1', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61093963, end_position_on_the_genomic_accession=61127852, orientation='plus', exon_count=12, OMIM=[153340], no_hdr0=''),
    922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=922, CurrentID=0, Status='live', Symbol='CD5L', Aliases=['AIM', 'API6', 'CT-2', 'PRO229', 'SP-ALPHA', 'Spalpha', 'hAIM'], description='CD5 molecule like', other_designations='CD5 antigen-like|CD5 antigen-like (scavenger receptor cysteine rich family)|apoptosis inhibitor 6|apoptosis inhibitor expressed by macrophages|apoptosis inhibitor of macrophage|igM-associated peptide', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157827068, end_position_on_the_genomic_accession=157841844, orientation='minus', exon_count=7, OMIM=[602592], no_hdr0=''),
    923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=923, CurrentID=0, Status='live', Symbol='CD6', Aliases=['TP120'], description='CD6 molecule', other_designations='T-cell differentiation antigen CD6|CD6 antigen|T12', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60971678, end_position_on_the_genomic_accession=61020377, orientation='plus', exon_count=13, OMIM=[186720], no_hdr0=''),
    924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=924, CurrentID=0, Status='live', Symbol='CD7', Aliases=['GP40', 'LEU-9', 'TP41', 'Tp40'], description='CD7 molecule', other_designations='T-cell antigen CD7|CD7 antigen (p41)|T-cell leukemia antigen|T-cell surface antigen Leu-9|p41 protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82314865, end_position_on_the_genomic_accession=82320829, orientation='minus', exon_count=4, OMIM=[186820], no_hdr0=''),
    925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=925, CurrentID=0, Status='live', Symbol='CD8A', Aliases=['CD8', 'Leu2', 'p32'], description='CD8a molecule', other_designations='T-cell surface glycoprotein CD8 alpha chain|CD8 antigen, alpha polypeptide (p32)|Leu2 T-lymphocyte antigen|OKT8 T-cell antigen|T cell co-receptor|T-cell antigen Leu2|T-lymphocyte differentiation antigen T8/Leu-2|T8 T-cell antigen', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86784605, end_position_on_the_genomic_accession=86808396, orientation='minus', exon_count=10, OMIM=[186910], no_hdr0=''),
    926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=926, CurrentID=0, Status='live', Symbol='CD8B', Aliases=['CD8B1', 'LEU2', 'LY3', 'LYT3', 'P37'], description='CD8b molecule', other_designations='T-cell surface glycoprotein CD8 beta chain|CD8 antigen, beta polypeptide 1 (p37)|T lymphocyte surface glycoprotein beta chain', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86815369, end_position_on_the_genomic_accession=86861886, orientation='minus', exon_count=8, OMIM=[186730], no_hdr0=''),
    927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=927, CurrentID=0, Status='live', Symbol='CD8B2', Aliases=['CD8BP'], description='CD8b2 molecule', other_designations='T-cell surface glycoprotein CD8 beta-2 chain|CD8 antigen, beta polypeptide pseudogene|CD8b molecule pseudogene|CD8b pseudogene|putative T-cell surface glycoprotein CD8 beta-2 chain', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=106487335, end_position_on_the_genomic_accession=106544297, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=928, CurrentID=0, Status='live', Symbol='CD9', Aliases=['BTCC-1', 'DRAP-27', 'MIC3', 'MRP-1', 'TSPAN-29', 'TSPAN29'], description='CD9 molecule', other_designations='CD9 antigen|5H9 antigen|BA-2/p24 antigen|CD9 antigen (p24)|antigen CD9|cell growth-inhibiting gene 2 protein|leukocyte antigen MIC3|motility related protein-1|tetraspanin-29', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6199946, end_position_on_the_genomic_accession=6238266, orientation='plus', exon_count=9, OMIM=[143030], no_hdr0=''),
    929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=929, CurrentID=0, Status='live', Symbol='CD14', Aliases=[], description='CD14 molecule', other_designations='monocyte differentiation antigen CD14|myeloid cell-specific leucine-rich glycoprotein', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140631732, end_position_on_the_genomic_accession=140633701, orientation='minus', exon_count=3, OMIM=[158120], no_hdr0=''),
    930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=930, CurrentID=0, Status='live', Symbol='CD19', Aliases=['B4', 'CVID3'], description='CD19 molecule', other_designations='B-lymphocyte antigen CD19|B-lymphocyte surface antigen B4|T-cell surface antigen Leu-12|differentiation antigen CD19', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28931735, end_position_on_the_genomic_accession=28939347, orientation='plus', exon_count=15, OMIM=[107265], no_hdr0=''),
    931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=931, CurrentID=0, Status='live', Symbol='MS4A1', Aliases=['B1', 'Bp35', 'CD20', 'CVID5', 'FMC7', 'LEU-16', 'MS4A2', 'S7'], description='membrane spanning 4-domains A1', other_designations='B-lymphocyte antigen CD20|B-lymphocyte cell-surface antigen B1|CD20 antigen|CD20 receptor|leukocyte surface antigen Leu-16|membrane-spanning 4-domains, subfamily A, member 1', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60455847, end_position_on_the_genomic_accession=60470752, orientation='plus', exon_count=8, OMIM=[112210], no_hdr0=''),
    932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=932, CurrentID=0, Status='live', Symbol='MS4A3', Aliases=['CD20L', 'HTM4'], description='membrane spanning 4-domains A3', other_designations='membrane-spanning 4-domains subfamily A member 3|CD20 antigen homolog|CD20 antigen-like protein|IgE receptor beta chain|IgE receptor beta subunit|hematopoietic cell 4 transmembrane protein|hematopoietic-specific transmembrane protein 4|membrane-spanning 4-domains, subfamily A, member 3 (hematopoietic cell-specific)', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60056665, end_position_on_the_genomic_accession=60071116, orientation='plus', exon_count=8, OMIM=[606498], no_hdr0=''),
    933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=933, CurrentID=0, Status='live', Symbol='CD22', Aliases=['SIGLEC-2', 'SIGLEC2'], description='CD22 molecule', other_designations='B-cell receptor CD22|B-lymphocyte cell adhesion molecule|BL-CAM|CD22 antigen|T-cell surface antigen Leu-14|sialic acid-binding Ig-like lectin 2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35329187, end_position_on_the_genomic_accession=35347361, orientation='plus', exon_count=14, OMIM=[107266], no_hdr0=''),
    939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=939, CurrentID=0, Status='live', Symbol='CD27', Aliases=['S152', 'S152. LPFS2', 'T14', 'TNFRSF7', 'Tp55'], description='CD27 molecule', other_designations='CD27 antigen|CD27L receptor|T cell activation antigen S152|T-cell activation antigen CD27|tumor necrosis factor receptor superfamily, member 7', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6444867, end_position_on_the_genomic_accession=6451718, orientation='plus', exon_count=6, OMIM=[186711], no_hdr0=''),
    940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=940, CurrentID=0, Status='live', Symbol='CD28', Aliases=['Tp44'], description='CD28 molecule', other_designations='T-cell-specific surface glycoprotein CD28', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203706509, end_position_on_the_genomic_accession=203739756, orientation='plus', exon_count=5, OMIM=[186760], no_hdr0=''),
    941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=941, CurrentID=0, Status='live', Symbol='CD80', Aliases=['B7', 'B7-1', 'B7.1', 'BB1', 'CD28LG', 'CD28LG1', 'LAB7'], description='CD80 molecule', other_designations='T-lymphocyte activation antigen CD80|B-lymphocyte activation antigen B7|CD80 antigen (CD28 antigen ligand 1, B7-1 antigen)|CTLA-4 counter-receptor B7.1|activation B7-1 antigen|costimulatory factor CD80|costimulatory molecule variant IgV-CD80', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119524293, end_position_on_the_genomic_accession=119559614, orientation='minus', exon_count=7, OMIM=[112203], no_hdr0=''),
    942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=942, CurrentID=0, Status='live', Symbol='CD86', Aliases=['B7-2', 'B7.2', 'B70', 'CD28LG2', 'LAB72'], description='CD86 molecule', other_designations='T-lymphocyte activation antigen CD86|B-lymphocyte activation antigen B7-2|BU63|CD86 antigen (CD28 antigen ligand 2, B7-2 antigen)|CTLA-4 counter-receptor B7.2|FUN-1', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122055362, end_position_on_the_genomic_accession=122121136, orientation='plus', exon_count=8, OMIM=[601020], no_hdr0=''),
    943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=943, CurrentID=0, Status='live', Symbol='TNFRSF8', Aliases=['CD30', 'D1S166E', 'Ki-1'], description='TNF receptor superfamily member 8', other_designations='tumor necrosis factor receptor superfamily member 8|CD30L receptor|Ki-1 antigen|cytokine receptor CD30|lymphocyte activation antigen CD30', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12063303, end_position_on_the_genomic_accession=12144213, orientation='plus', exon_count=16, OMIM=[153243], no_hdr0=''),
    944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=944, CurrentID=0, Status='live', Symbol='TNFSF8', Aliases=['CD153', 'CD30L', 'CD30LG', 'TNLG3A'], description='TNF superfamily member 8', other_designations='tumor necrosis factor ligand superfamily member 8|CD153 antigen|CD30 antigen ligand|CD30 ligand|CD30-L|tumor necrosis factor (ligand) superfamily, member 8|tumor necrosis factor ligand 3A|tumor necrosis factor superfamily member 8', map_location='9q32-q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114893343, end_position_on_the_genomic_accession=114930674, orientation='minus', exon_count=6, OMIM=[603875], no_hdr0=''),
    945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=945, CurrentID=0, Status='live', Symbol='CD33', Aliases=['SIGLEC-3', 'SIGLEC3', 'p67'], description='CD33 molecule', other_designations='myeloid cell surface antigen CD33|CD33 antigen (gp67)|CD33 molecule transcript|gp67|sialic acid-binding Ig-like lectin 3', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51211054, end_position_on_the_genomic_accession=51240016, orientation='plus', exon_count=14, OMIM=[159590], no_hdr0=''),
    946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=946, CurrentID=0, Status='live', Symbol='SIGLEC6', Aliases=['CD327', 'CD33L', 'CD33L1', 'CD33L2', 'CDW327', 'OBBP1'], description='sialic acid binding Ig like lectin 6', other_designations='sialic acid-binding Ig-like lectin 6|CD33 antigen-like 1|obesity-binding protein 1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51517819, end_position_on_the_genomic_accession=51531803, orientation='minus', exon_count=11, OMIM=[604405], no_hdr0=''),
    947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=947, CurrentID=0, Status='live', Symbol='CD34', Aliases=[], description='CD34 molecule', other_designations='hematopoietic progenitor cell antigen CD34|CD34 antigen', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207880972, end_position_on_the_genomic_accession=207911125, orientation='minus', exon_count=8, OMIM=[142230], no_hdr0=''),
    948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=948, CurrentID=0, Status='live', Symbol='CD36', Aliases=['BDPLT10', 'CHDS7', 'FAT', 'GP3B', 'GP4', 'GPIV', 'PASIV', 'SCARB3'], description='CD36 molecule', other_designations='platelet glycoprotein 4|CD36 antigen (collagen type I receptor, thrombospondin receptor)|CD36 molecule (thrombospondin receptor)|GPIIIB|PAS IV|PAS-4 protein|cluster determinant 36|fatty acid translocase|glycoprotein IIIb|leukocyte differentiation antigen CD36|platelet glycoprotein IV|scavenger receptor class B, member 3', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=80602207, end_position_on_the_genomic_accession=80679277, orientation='plus', exon_count=19, OMIM=[173510], no_hdr0=''),
    949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=949, CurrentID=0, Status='live', Symbol='SCARB1', Aliases=['CD36L1', 'CLA-1', 'CLA1', 'HDLQTL6', 'SR-BI', 'SRB1'], description='scavenger receptor class B member 1', other_designations='scavenger receptor class B member 1|CD36 and LIMPII analogous 1|CD36 antigen (collagen type I receptor, thrombospondin receptor)-like 1|scavenger receptor class B type III', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124776856, end_position_on_the_genomic_accession=124863864, orientation='minus', exon_count=15, OMIM=[601040], no_hdr0=''),
    950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=950, CurrentID=0, Status='live', Symbol='SCARB2', Aliases=['AMRF', 'CD36L2', 'EPM4', 'HLGP85', 'LGP85', 'LIMP-2', 'LIMPII', 'SR-BII'], description='scavenger receptor class B member 2', other_designations='lysosome membrane protein 2|85 kDa lysosomal membrane sialoglycoprotein|85 kDa lysosomal sialoglycoprotein scavenger receptor class B, member 2|CD36 antigen (collagen type I receptor, thrombospondin receptor)-like 2 (lysosomal integral membrane protein II)|CD36 antigen-like 2|LIMP II|lysosome membrane protein II', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76158737, end_position_on_the_genomic_accession=76213824, orientation='minus', exon_count=12, OMIM=[602257], no_hdr0=''),
    951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=951, CurrentID=0, Status='live', Symbol='CD37', Aliases=['GP52-40', 'TSPAN26'], description='CD37 molecule', other_designations='leukocyte antigen CD37|cell differentiation antigen 37|leukocyte surface antigen CD37|tetraspanin-26|tspan-26', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49334961, end_position_on_the_genomic_accession=49340608, orientation='plus', exon_count=8, OMIM=[151523], no_hdr0=''),
    952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=952, CurrentID=0, Status='live', Symbol='CD38', Aliases=['ADPRC 1', 'ADPRC1'], description='CD38 molecule', other_designations="ADP-ribosyl cyclase/cyclic ADP-ribose hydrolase 1|2'-phospho-ADP-ribosyl cyclase|2'-phospho-cyclic-ADP-ribose transferase|ADP-ribosyl cyclase 1|CD38 antigen (p45)|NAD(+) nucleosidase|cluster of differentiation 38|cyclic ADP-ribose hydrolase 1|ecto-nicotinamide adenine dinucleotide glycohydrolase", map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15778328, end_position_on_the_genomic_accession=15853232, orientation='plus', exon_count=8, OMIM=[107270], no_hdr0=''),
    953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=953, CurrentID=0, Status='live', Symbol='ENTPD1', Aliases=['ATPDase', 'CD39', 'NTPDase-1', 'SPG64'], description='ectonucleoside triphosphate diphosphohydrolase 1', other_designations='ectonucleoside triphosphate diphosphohydrolase 1|CD39 antigen|ecto-ATP diphosphohydrolase 1|ecto-ATPDase 1|ecto-ATPase 1|ecto-apyrase|lymphoid cell activation antigen', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95710901, end_position_on_the_genomic_accession=95877266, orientation='plus', exon_count=18, OMIM=[601752], no_hdr0=''),
    954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=954, CurrentID=0, Status='live', Symbol='ENTPD2', Aliases=['CD39L1', 'NTPDase-2'], description='ectonucleoside triphosphate diphosphohydrolase 2', other_designations='ectonucleoside triphosphate diphosphohydrolase 2|CD39 antigen-like 1|NTPDase 2|ecto-ATP diphosphohydrolase 2|ecto-ATPDase 2|ecto-ATPase 2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137048107, end_position_on_the_genomic_accession=137054061, orientation='minus', exon_count=9, OMIM=[602012], no_hdr0=''),
    955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=955, CurrentID=0, Status='live', Symbol='ENTPD6', Aliases=['CD39L2', 'IL-6SAG', 'IL6ST2', 'NTPDase-6', 'dJ738P15.3'], description='ectonucleoside triphosphate diphosphohydrolase 6', other_designations='ectonucleoside triphosphate diphosphohydrolase 6|CD39 antigen-like 2|NTPDase 6|ectonucleoside triphosphate diphosphohydrolase 6 (putative)|interleukin 6 signal transducer-2', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25195703, end_position_on_the_genomic_accession=25228075, orientation='plus', exon_count=19, OMIM=[603160], no_hdr0=''),
    956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=956, CurrentID=0, Status='live', Symbol='ENTPD3', Aliases=['CD39L3', 'HB6', 'NTPDase-3'], description='ectonucleoside triphosphate diphosphohydrolase 3', other_designations='ectonucleoside triphosphate diphosphohydrolase 3|CD39 antigen-like 3|NTPDase 3|ecto-ATP diphosphohydrolase 3|ecto-ATPDase 3|ecto-ATPase 3|ecto-apyrase 3', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40387182, end_position_on_the_genomic_accession=40428744, orientation='plus', exon_count=13, OMIM=[603161], no_hdr0=''),
    957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=957, CurrentID=0, Status='live', Symbol='ENTPD5', Aliases=['CD39L4', 'NTPDase-5', 'PCPH'], description='ectonucleoside triphosphate diphosphohydrolase 5 (inactive)', other_designations='ectonucleoside triphosphate diphosphohydrolase 5|CD39 antigen-like 4|CD39-like 4|ER-UDPase|GDPase ENTPD5|NTPDase 5|Pcph proto-oncogene protein|UDPase ENTPD5|guanosine-diphosphatase ENTPD5|nucleoside diphosphatase|proto-oncogene CPH|uridine-diphosphatase ENTPD5', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73955329, end_position_on_the_genomic_accession=74019326, orientation='minus', exon_count=23, OMIM=[603162], no_hdr0=''),
    958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=958, CurrentID=0, Status='live', Symbol='CD40', Aliases=['Bp50', 'CDW40', 'TNFRSF5', 'p50'], description='CD40 molecule', other_designations='tumor necrosis factor receptor superfamily member 5|B cell surface antigen CD40|B cell-associated molecule|CD40 molecule, TNF receptor superfamily member 5|CD40L receptor', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46118242, end_position_on_the_genomic_accession=46129858, orientation='plus', exon_count=9, OMIM=[109535], no_hdr0=''),
    959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=959, CurrentID=0, Status='live', Symbol='CD40LG', Aliases=['CD154', 'CD40L', 'HIGM1', 'IGM', 'IMD3', 'T-BAM', 'TNFSF5', 'TRAP', 'gp39', 'hCD40L'], description='CD40 ligand', other_designations='CD40 ligand|CD40 antigen ligand|CD40-L|T-B cell-activating molecule|T-cell antigen Gp39|TNF-related activation protein|tumor necrosis factor (ligand) superfamily member 5', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136648158, end_position_on_the_genomic_accession=136660390, orientation='plus', exon_count=5, OMIM=[300386], no_hdr0=''),
    960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=960, CurrentID=0, Status='live', Symbol='CD44', Aliases=['CDW44', 'CSPG8', 'ECMR-III', 'HCELL', 'HUTCH-I', 'IN', 'LHR', 'MC56', 'MDU2', 'MDU3', 'MIC4', 'Pgp1'], description='CD44 molecule (Indian blood group)', other_designations='CD44 antigen|GP90 lymphocyte homing/adhesion receptor|Hermes antigen|Indian blood group antigen|cell surface glycoprotein CD44|chondroitin sulfate proteoglycan 8|epican|extracellular matrix receptor III|hematopoietic cell E- and L-selectin ligand|heparan sulfate proteoglycan|homing function and Indian blood group system|hyaluronate receptor|phagocytic glycoprotein 1|soluble CD44', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35139168, end_position_on_the_genomic_accession=35232402, orientation='plus', exon_count=21, OMIM=[107269], no_hdr0=''),
    961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=961, CurrentID=0, Status='live', Symbol='CD47', Aliases=['IAP', 'MER6', 'OA3'], description='CD47 molecule', other_designations='leukocyte surface antigen CD47|CD47 antigen (Rh-related antigen, integrin-associated signal transducer)|CD47 glycoprotein|Rh-related antigen|antigen identified by monoclonal antibody 1D8|antigenic surface determinant protein OA3|integrin associated protein|integrin-associated signal transducer', map_location='3q13.12', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108043091, end_position_on_the_genomic_accession=108094200, orientation='minus', exon_count=14, OMIM=[601028], no_hdr0=''),
    962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=962, CurrentID=0, Status='live', Symbol='CD48', Aliases=['BCM1', 'BLAST', 'BLAST1', 'MEM-102', 'SLAMF2', 'hCD48', 'mCD48'], description='CD48 molecule', other_designations='CD48 antigen|B-lymphocyte activation marker BLAST-1|BCM1 surface antigen|CD48 antigen (B-cell membrane protein)|SLAM family member 2|TCT.1|leukocyte antigen MEM-102|signaling lymphocytic activation molecule 2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160678746, end_position_on_the_genomic_accession=160711836, orientation='minus', exon_count=5, OMIM=[109530], no_hdr0=''),
    963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=963, CurrentID=0, Status='live', Symbol='CD53', Aliases=['MOX44', 'TSPAN25'], description='CD53 molecule', other_designations='leukocyte surface antigen CD53|CD53 antigen|CD53 glycoprotein|CD53 tetraspan antigen|antigen MOX44 identified by monoclonal antibody MRC-OX44|cell surface antigen|cell surface glycoprotein CD53|tetraspanin-25|transmembrane glycoprotein|tspan-25', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110871167, end_position_on_the_genomic_accession=110899928, orientation='plus', exon_count=9, OMIM=[151525], no_hdr0=''),
    965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=965, CurrentID=0, Status='live', Symbol='CD58', Aliases=['LFA-3', 'LFA3', 'ag3'], description='CD58 molecule', other_designations='lymphocyte function-associated antigen 3|CD58 antigen, (lymphocyte function-associated antigen 3)|surface glycoprotein LFA-3', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116500390, end_position_on_the_genomic_accession=116571037, orientation='minus', exon_count=7, OMIM=[153420], no_hdr0=''),
    966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=966, CurrentID=0, Status='live', Symbol='CD59', Aliases=['16.3A5', '1F5', 'EJ16', 'EJ30', 'EL32', 'G344', 'HRF-20', 'HRF20', 'MAC-IP', 'MACIF', 'MEM43', 'MIC11', 'MIN1', 'MIN2', 'MIN3', 'MIRL', 'MSK21', 'p18-20'], description='CD59 molecule (CD59 blood group)', other_designations='CD59 glycoprotein|1F5 antigen|20 kDa homologous restriction factor|CD59 antigen p18-20 (antigen identified by monoclonal antibodies 16.3A5, EJ16, EJ30, EL32 and G344)|CD59 blood group antigen|CD59 molecule, complement regulatory protein|Ly-6-like protein|MEM43 antigen|T cell-activating protein|human leukocyte antigen MIC11|lymphocytic antigen CD59/MEM43|membrane attack complex (MAC) inhibition factor|membrane attack complex inhibition factor|membrane inhibitor of reactive lysis|protectin|surface anitgen recognized by monoclonal antibody 16.3A5', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33703010, end_position_on_the_genomic_accession=33736479, orientation='minus', exon_count=8, OMIM=[107271], no_hdr0=''),
    967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=967, CurrentID=0, Status='live', Symbol='CD63', Aliases=['LAMP-3', 'ME491', 'MLA1', 'OMA81H', 'TSPAN30'], description='CD63 molecule', other_designations='CD63 antigen|CD63 antigen (melanoma 1 antigen)|granulophysin|lysosomal-associated membrane protein 3|lysosome-associated membrane glycoprotein 3|melanoma-associated antigen ME491|melanoma-associated antigen MLA1|ocular melanoma-associated antigen|tetraspanin-30|tspan-30', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55725323, end_position_on_the_genomic_accession=55729673, orientation='minus', exon_count=12, OMIM=[155740], no_hdr0=''),
    968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=968, CurrentID=0, Status='live', Symbol='CD68', Aliases=['GP110', 'LAMP4', 'SCARD1'], description='CD68 molecule', other_designations='macrosialin|CD68 antigen|macrophage antigen CD68|scavenger receptor class D, member 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7579638, end_position_on_the_genomic_accession=7582111, orientation='plus', exon_count=6, OMIM=[153634], no_hdr0=''),
    969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=969, CurrentID=0, Status='live', Symbol='CD69', Aliases=['AIM', 'BL-AC/P26', 'CLEC2C', 'EA1', 'GP32/28', 'MLR-3'], description='CD69 molecule', other_designations='early activation antigen CD69|C-type lectin domain family 2, member C|CD69 antigen (p60, early T-cell activation antigen)|activation inducer molecule (AIM/CD69)|early T-cell activation antigen p60|early lymphocyte activation antigen|leukocyte surface antigen Leu-23', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9752486, end_position_on_the_genomic_accession=9760901, orientation='minus', exon_count=5, OMIM=[107273], no_hdr0=''),
    970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=970, CurrentID=0, Status='live', Symbol='CD70', Aliases=['CD27-L', 'CD27L', 'CD27LG', 'LPFS3', 'TNFSF7', 'TNLG8A'], description='CD70 molecule', other_designations='CD70 antigen|CD27 ligand|Ki-24 antigen|surface antigen CD70|tumor necrosis factor ligand 8A|tumor necrosis factor ligand superfamily member 7', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6581648, end_position_on_the_genomic_accession=6591150, orientation='minus', exon_count=4, OMIM=[602840], no_hdr0=''),
    971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=971, CurrentID=0, Status='live', Symbol='CD72', Aliases=['CD72b', 'LYB2'], description='CD72 molecule', other_designations='B-cell differentiation antigen CD72|CD72 antigen|lyb-2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35609981, end_position_on_the_genomic_accession=35618427, orientation='minus', exon_count=9, OMIM=[107272], no_hdr0=''),
    972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=972, CurrentID=0, Status='live', Symbol='CD74', Aliases=['DHLAG', 'HLADG', 'II', 'Ia-GAMMA', 'p33'], description='CD74 molecule', other_designations='HLA class II histocompatibility antigen gamma chain|CD74 antigen (invariant polypeptide of major histocompatibility complex, class II antigen-associated)|CD74 molecule, major histocompatibility complex, class II invariant chain|HLA-DR antigens-associated invariant chain|HLA-DR-gamma|Ia-associated invariant chain|MHC HLA-DR gamma chain|gamma chain of class II antigens', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150401637, end_position_on_the_genomic_accession=150412910, orientation='minus', exon_count=8, OMIM=[142790], no_hdr0=''),
    973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=973, CurrentID=0, Status='live', Symbol='CD79A', Aliases=['IGA', 'MB-1'], description='CD79a molecule', other_designations='B-cell antigen receptor complex-associated protein alpha chain|CD79a antigen (immunoglobulin-associated alpha)|CD79a molecule, immunoglobulin-associated alpha|MB-1 membrane glycoprotein|ig-alpha|membrane-bound immunoglobulin-associated protein|surface IgM-associated protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41877279, end_position_on_the_genomic_accession=41881372, orientation='plus', exon_count=5, OMIM=[112205], no_hdr0=''),
    974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=974, CurrentID=0, Status='live', Symbol='CD79B', Aliases=['AGM6', 'B29', 'IGB'], description='CD79b molecule', other_designations='B-cell antigen receptor complex-associated protein beta chain|B-cell-specific glycoprotein B29|CD79b antigen (immunoglobulin-associated beta)|CD79b molecule, immunoglobulin-associated beta|Ig-beta|immunoglobulin-associated B29 protein', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63928740, end_position_on_the_genomic_accession=63932331, orientation='minus', exon_count=6, OMIM=[147245], no_hdr0=''),
    975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=975, CurrentID=0, Status='live', Symbol='CD81', Aliases=['CVID6', 'S5.7', 'TAPA1', 'TSPAN28'], description='CD81 molecule', other_designations='CD81 antigen|26 kDa cell surface protein TAPA-1|CD81 antigen (target of antiproliferative antibody 1)|tetraspanin-28|tspan-28', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2376180, end_position_on_the_genomic_accession=2397402, orientation='plus', exon_count=10, OMIM=[186845], no_hdr0=''),
    976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=976, CurrentID=0, Status='live', Symbol='ADGRE5', Aliases=['CD97', 'TM7LN1'], description='adhesion G protein-coupled receptor E5', other_designations='adhesion G protein-coupled receptor E5|CD97 molecule|leukocyte antigen CD97|seven transmembrane helix receptor|seven-span transmembrane protein|seven-transmembrane, heterodimeric receptor associated with inflammation', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14381144, end_position_on_the_genomic_accession=14408725, orientation='plus', exon_count=20, OMIM=[601211], no_hdr0=''),
    977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=977, CurrentID=0, Status='live', Symbol='CD151', Aliases=['GP27', 'MER2', 'PETA-3', 'RAPH', 'SFA1', 'TSPAN24'], description='CD151 molecule (Raph blood group)', other_designations='CD151 antigen|CD151 antigen (Raph blood group)|hemidesmosomal tetraspanin CD151|membrane glycoprotein SFA-1|platelet surface glycoprotein gp27|platelet-endothelial cell tetraspan antigen 3|platelet-endothelial tetraspan antigen 3|tetraspanin-24|tspan-24', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=832952, end_position_on_the_genomic_accession=838835, orientation='plus', exon_count=10, OMIM=[602243], no_hdr0=''),
    978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=978, CurrentID=0, Status='live', Symbol='CDA', Aliases=['CDD'], description='cytidine deaminase', other_designations='cytidine deaminase|cytidine aminohydrolase|cytosine nucleoside deaminase|small cytidine deaminase', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20589097, end_position_on_the_genomic_accession=20618903, orientation='plus', exon_count=4, OMIM=[123920], no_hdr0=''),
    983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=983, CurrentID=0, Status='live', Symbol='CDK1', Aliases=['CDC2', 'CDC28A', 'P34CDC2'], description='cyclin dependent kinase 1', other_designations='cyclin-dependent kinase 1|cell cycle controller CDC2|cell division control protein 2 homolog|cell division cycle 2, G1 to S and G2 to M|cell division protein kinase 1|p34 protein kinase', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=60778331, end_position_on_the_genomic_accession=60794852, orientation='plus', exon_count=9, OMIM=[116940], no_hdr0=''),
    984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=984, CurrentID=0, Status='live', Symbol='CDK11B', Aliases=['CDC2L1', 'CDK11', 'CDK11-p110', 'CDK11-p46', 'CDK11-p58', 'CLK-1', 'PITSLREA', 'PK58', 'p58', 'p58CDC2L1', 'p58CLK-1'], description='cyclin dependent kinase 11B', other_designations='cyclin-dependent kinase 11B|CDC-related protein kinase p58|PITSLRE serine/threonine-protein kinase CDC2L1|cell division cycle 2-like 1 (PITSLRE proteins)|cell division protein kinase 11B|galactosyltransferase-associated protein kinase p58/GTA|p58 CLK-1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1635225, end_position_on_the_genomic_accession=1659619, orientation='minus', exon_count=22, OMIM=[176873], no_hdr0=''),
    987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=987, CurrentID=0, Status='live', Symbol='LRBA', Aliases=['BGL', 'CDC4L', 'CVID8', 'LAB300', 'LBA'], description='LPS responsive beige-like anchor protein', other_designations='lipopolysaccharide-responsive and beige-like anchor protein|CDC4-like protein|LPS-responsive vesicle trafficking, beach and anchor containing|vesicle trafficking, beach and anchor containing', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=150264435, end_position_on_the_genomic_accession=151015727, orientation='minus', exon_count=61, OMIM=[606453], no_hdr0=''),
    988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=988, CurrentID=0, Status='live', Symbol='CDC5L', Aliases=['CDC5', 'CDC5-LIKE', 'CEF1', 'PCDC5RP', 'dJ319D22.1'], description='cell division cycle 5 like', other_designations='cell division cycle 5-like protein|CDC5 cell division cycle 5-like|Cdc5-related protein|dJ319D22.1 (CDC5-like protein)|pombe cdc5-related protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44387706, end_position_on_the_genomic_accession=44450425, orientation='plus', exon_count=16, OMIM=[602868], no_hdr0=''),
    989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=989, CurrentID=0, Status='live', Symbol='SEPTIN7', Aliases=['CDC10', 'CDC3', 'NBLA02942', 'SEPT7', 'SEPT7A'], description='septin 7', other_designations='septin-7|CDC10 (cell division cycle 10, S. cerevisiae, homolog)|CDC10 protein homolog|septin 7 variant 4', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=35800986, end_position_on_the_genomic_accession=35915763, orientation='plus', exon_count=19, OMIM=[603151], no_hdr0=''),
    990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=990, CurrentID=0, Status='live', Symbol='CDC6', Aliases=['CDC18L', 'HsCDC18', 'HsCDC6', 'MGORS5'], description='cell division cycle 6', other_designations='cell division control protein 6 homolog|CDC6 cell division cycle 6 homolog|CDC6-related protein|cdc18-related protein|cell division cycle 6 homolog|p62(cdc6)', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40287878, end_position_on_the_genomic_accession=40304657, orientation='plus', exon_count=13, OMIM=[602627], no_hdr0=''),
    991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=991, CurrentID=0, Status='live', Symbol='CDC20', Aliases=['CDC20A', 'bA276H19.3', 'p55CDC'], description='cell division cycle 20', other_designations='cell division cycle protein 20 homolog|CDC20 cell division cycle 20 homolog|cell division cycle 20 homolog|fizzy homolog', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43358981, end_position_on_the_genomic_accession=43363203, orientation='plus', exon_count=11, OMIM=[603618], no_hdr0=''),
    993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=993, CurrentID=0, Status='live', Symbol='CDC25A', Aliases=['CDC25A2'], description='cell division cycle 25A', other_designations='M-phase inducer phosphatase 1|CDC25 homolog A|dual specificity phosphatase CDC25A', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48157146, end_position_on_the_genomic_accession=48188417, orientation='minus', exon_count=15, OMIM=[116947], no_hdr0=''),
    994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=994, CurrentID=0, Status='live', Symbol='CDC25B', Aliases=[], description='cell division cycle 25B', other_designations='M-phase inducer phosphatase 2|CDC25 homolog B|dual specificity phosphatase Cdc25B', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3786951, end_position_on_the_genomic_accession=3806118, orientation='plus', exon_count=19, OMIM=[116949], no_hdr0=''),
    995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=995, CurrentID=0, Status='live', Symbol='CDC25C', Aliases=['CDC25', 'PPP1R60'], description='cell division cycle 25C', other_designations='M-phase inducer phosphatase 3|CDC25 homolog C|dual specificity phosphatase CDC25C|mitosis inducer CDC25|phosphotyrosine phosphatase|protein phosphatase 1, regulatory subunit 60', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138285265, end_position_on_the_genomic_accession=138338355, orientation='minus', exon_count=15, OMIM=[157680], no_hdr0=''),
    996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=996, CurrentID=0, Status='live', Symbol='CDC27', Aliases=['ANAPC3', 'APC3Hs', 'D0S1430E', 'D17S978E', 'H-NUC', 'HNUC', 'NUC2', 'CDC27'], description='cell division cycle 27', other_designations='cell division cycle protein 27 homolog|D0S1430E, D17S978E|anaphase promoting complex subunit 3|anaphase-promoting complex, protein 3|cell division cycle 27 homolog|nuc2 homolog', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47117703, end_position_on_the_genomic_accession=47189295, orientation='minus', exon_count=20, OMIM=[116946], no_hdr0=''),
    997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=997, CurrentID=0, Status='live', Symbol='CDC34', Aliases=['E2-CDC34', 'UBC3', 'UBCH3', 'UBE2R1'], description='cell division cycle 34, ubiqiutin conjugating enzyme', other_designations='ubiquitin-conjugating enzyme E2 R1|(E3-independent) E2 ubiquitin-conjugating enzyme R1|E2 ubiquitin-conjugating enzyme R1|cell division cycle 34 homolog|ubiquitin carrier protein|ubiquitin-conjugating enzyme E2-32 KDA complementing|ubiquitin-conjugating enzyme E2-CDC34|ubiquitin-protein ligase R1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=531720, end_position_on_the_genomic_accession=542088, orientation='plus', exon_count=6, OMIM=[116948], no_hdr0=''),
    998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=998, CurrentID=0, Status='live', Symbol='CDC42', Aliases=['CDC42Hs', 'G25K', 'TKS'], description='cell division cycle 42', other_designations='cell division control protein 42 homolog|G25K GTP-binding protein|GTP binding protein, 25kDa|dJ224A6.1.1 (cell division cycle 42 (GTP-binding protein, 25kD))|dJ224A6.1.2 (cell division cycle 42 (GTP-binding protein, 25kD))|growth-regulating protein|small GTP binding protein CDC42', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22052709, end_position_on_the_genomic_accession=22101360, orientation='plus', exon_count=8, OMIM=[116952], no_hdr0=''),
    999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=999, CurrentID=0, Status='live', Symbol='CDH1', Aliases=['Arc-1', 'BCDS1', 'CD324', 'CDHE', 'ECAD', 'LCAM', 'UVO'], description='cadherin 1', other_designations='cadherin-1|CAM 120/80|E-cadherin 1|cadherin 1, E-cadherin (epithelial)|cadherin 1, type 1, E-cadherin (epithelial)|calcium-dependent adhesion protein, epithelial|cell-CAM 120/80|epididymis secretory sperm binding protein|epithelial cadherin|uvomorulin', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68737292, end_position_on_the_genomic_accession=68835537, orientation='plus', exon_count=16, OMIM=[192090], no_hdr0=''),
    1000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1000, CurrentID=0, Status='live', Symbol='CDH2', Aliases=['ACOGS', 'ARVD14', 'CD325', 'CDHN', 'CDw325', 'NCAD'], description='cadherin 2', other_designations='cadherin-2|N-cadherin 1|cadherin 2, type 1, N-cadherin (neuronal)|calcium-dependent adhesion protein, neuronal|neural cadherin', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=27932878, end_position_on_the_genomic_accession=28177130, orientation='minus', exon_count=19, OMIM=[114020], no_hdr0=''),
    1001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1001, CurrentID=0, Status='live', Symbol='CDH3', Aliases=['CDHP', 'HJMD', 'PCAD'], description='cadherin 3', other_designations='cadherin-3|cadherin 3, type 1, P-cadherin (placental)|calcium-dependent adhesion protein, placental', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68644914, end_position_on_the_genomic_accession=68727573, orientation='plus', exon_count=18, OMIM=[114021], no_hdr0=''),
    1002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1002, CurrentID=0, Status='live', Symbol='CDH4', Aliases=['CAD4', 'R-CAD', 'RCAD'], description='cadherin 4', other_designations='cadherin-4|R-cadherin|cadherin 4, type 1, R-cadherin (retinal)|cadherin 4, type 1, preproprotein|retinal cadherin', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=61252261, end_position_on_the_genomic_accession=61940617, orientation='plus', exon_count=18, OMIM=[603006], no_hdr0=''),
    1003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1003, CurrentID=0, Status='live', Symbol='CDH5', Aliases=['7B4', 'CD144'], description='cadherin 5', other_designations='cadherin-5|7B4 antigen|VE-cadherin|cadherin 5, type 2 (vascular endothelium)|cadherin 5, type 2, VE-cadherin (vascular epithelium)|cd144 antigen|endothelial-specific cadherin|vascular endothelial cadherin', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66366657, end_position_on_the_genomic_accession=66404784, orientation='plus', exon_count=12, OMIM=[601120], no_hdr0=''),
    1004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1004, CurrentID=0, Status='live', Symbol='CDH6', Aliases=['CAD6', 'KCAD'], description='cadherin 6', other_designations='cadherin-6|cadherin 6, type 2, K-cadherin (fetal kidney)', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=31193686, end_position_on_the_genomic_accession=31329146, orientation='plus', exon_count=14, OMIM=[603007], no_hdr0=''),
    1005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1005, CurrentID=0, Status='live', Symbol='CDH7', Aliases=['CDH7L1'], description='cadherin 7', other_designations='cadherin-7|cadherin 7, type 2', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=65750252, end_position_on_the_genomic_accession=65890337, orientation='plus', exon_count=13, OMIM=[605806], no_hdr0=''),
    1006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1006, CurrentID=0, Status='live', Symbol='CDH8', Aliases=['Nbla04261'], description='cadherin 8', other_designations='cadherin-8|cadherin 8, type 2', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=61640398, end_position_on_the_genomic_accession=62036446, orientation='minus', exon_count=14, OMIM=[603008], no_hdr0=''),
    1007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1007, CurrentID=0, Status='live', Symbol='CDH9', Aliases=[], description='cadherin 9', other_designations='cadherin-9|T1-cadherin', map_location='5p14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=26880597, end_position_on_the_genomic_accession=27038586, orientation='minus', exon_count=12, OMIM=[609974], no_hdr0=''),
    1008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1008, CurrentID=0, Status='live', Symbol='CDH10', Aliases=[], description='cadherin 10', other_designations='cadherin-10|T2-cadherin|cadherin 10 type 2', map_location='5p14.2-p14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=24487100, end_position_on_the_genomic_accession=24644978, orientation='minus', exon_count=13, OMIM=[604555], no_hdr0=''),
    1009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1009, CurrentID=0, Status='live', Symbol='CDH11', Aliases=['CAD11', 'CDHOB', 'ESWS', 'OB', 'OSF-4'], description='cadherin 11', other_designations='cadherin-11|cadherin 11, type 2, OB-cadherin (osteoblast)', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=64943753, end_position_on_the_genomic_accession=65126112, orientation='minus', exon_count=18, OMIM=[600023], no_hdr0=''),
    1010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1010, CurrentID=0, Status='live', Symbol='CDH12', Aliases=['CDHB'], description='cadherin 12', other_designations='cadherin-12|Br-cadherin|N-cadherin 2|brain-cadherin|cadherin, neural type, 2|neural type cadherin 2|neuronal cadherin 2', map_location='5p14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=21750673, end_position_on_the_genomic_accession=22853344, orientation='minus', exon_count=18, OMIM=[600562], no_hdr0=''),
    1012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1012, CurrentID=0, Status='live', Symbol='CDH13', Aliases=['CDHH', 'P105'], description='cadherin 13', other_designations='cadherin-13|H-cadherin (heart)|T-cad|T-cadherin|cadherin 13, H-cadherin (heart)|heart cadherin', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=82626823, end_position_on_the_genomic_accession=83800640, orientation='plus', exon_count=20, OMIM=[601364], no_hdr0=''),
    1013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1013, CurrentID=0, Status='live', Symbol='CDH15', Aliases=['CDH14', 'CDH3', 'CDHM', 'MCAD', 'MRD3'], description='cadherin 15', other_designations='cadherin-15|cadherin 15, type 1, M-cadherin (myotubule)|cadherin-14|cadherin-3|muscle-cadherin', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89171748, end_position_on_the_genomic_accession=89195492, orientation='plus', exon_count=14, OMIM=[114019], no_hdr0=''),
    1014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1014, CurrentID=0, Status='live', Symbol='CDH16', Aliases=[], description='cadherin 16', other_designations='cadherin-16|KSP-cadherin|cadherin 16, KSP-cadherin|kidney-specific cadherin', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66908122, end_position_on_the_genomic_accession=66918885, orientation='minus', exon_count=18, OMIM=[603118], no_hdr0=''),
    1015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1015, CurrentID=0, Status='live', Symbol='CDH17', Aliases=['CDH16', 'HPT-1', 'HPT1'], description='cadherin 17', other_designations='cadherin-17|HPT-1 cadherin|LI cadherin|cadherin 17, LI cadherin (liver-intestine)|cadherin-16|human intestinal peptide-associated transporter HPT-1|human peptide transporter 1|intestinal peptide-associated transporter HPT-1|liver-intestine cadherin', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94127162, end_position_on_the_genomic_accession=94217278, orientation='minus', exon_count=19, OMIM=[603017], no_hdr0=''),
    1016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1016, CurrentID=0, Status='live', Symbol='CDH18', Aliases=['CDH14', 'CDH14L', 'CDH24'], description='cadherin 18', other_designations='cadherin-18|cadherin 18, type 2|cadherin-14|cadherin-like 24|ey-cadherin', map_location='5p14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=19471296, end_position_on_the_genomic_accession=20575886, orientation='minus', exon_count=25, OMIM=[603019], no_hdr0=''),
    1017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1017, CurrentID=0, Status='live', Symbol='CDK2', Aliases=['CDKN2', 'p33(CDK2)'], description='cyclin dependent kinase 2', other_designations='cyclin-dependent kinase 2|cdc2-related protein kinase|cell division protein kinase 2|p33 protein kinase', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55966830, end_position_on_the_genomic_accession=55972789, orientation='plus', exon_count=8, OMIM=[116953], no_hdr0=''),
    1018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1018, CurrentID=0, Status='live', Symbol='CDK3', Aliases=[], description='cyclin dependent kinase 3', other_designations='cyclin-dependent kinase 3|cell division protein kinase 3', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76000855, end_position_on_the_genomic_accession=76005998, orientation='plus', exon_count=8, OMIM=[123828], no_hdr0=''),
    1019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1019, CurrentID=0, Status='live', Symbol='CDK4', Aliases=['CMM3', 'PSK-J3'], description='cyclin dependent kinase 4', other_designations='cyclin-dependent kinase 4|cell division protein kinase 4', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57747727, end_position_on_the_genomic_accession=57752310, orientation='minus', exon_count=8, OMIM=[123829], no_hdr0=''),
    1020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1020, CurrentID=0, Status='live', Symbol='CDK5', Aliases=['LIS7', 'PSSALRE'], description='cyclin dependent kinase 5', other_designations='cyclin-dependent-like kinase 5|TPKII catalytic subunit|cell division protein kinase 5|epididymis secretory sperm binding protein|protein kinase CDK5 splicing|serine/threonine-protein kinase PSSALRE|tau protein kinase II catalytic subunit', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151053815, end_position_on_the_genomic_accession=151057897, orientation='minus', exon_count=12, OMIM=[123831], no_hdr0=''),
    1021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1021, CurrentID=0, Status='live', Symbol='CDK6', Aliases=['MCPH12', 'PLSTIRE'], description='cyclin dependent kinase 6', other_designations='cyclin-dependent kinase 6|cell division protein kinase 6|serine/threonine-protein kinase PLSTIRE', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92604921, end_position_on_the_genomic_accession=92836573, orientation='minus', exon_count=10, OMIM=[603368], no_hdr0=''),
    1022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1022, CurrentID=0, Status='live', Symbol='CDK7', Aliases=['CAK', 'CAK1', 'CDKN7', 'HCAK', 'MO15', 'STK1', 'p39MO15'], description='cyclin dependent kinase 7', other_designations='cyclin-dependent kinase 7|39 KDa protein kinase|CDK-activating kinase 1|TFIIH basal transcription factor complex kinase subunit|cell division protein kinase 7|cyclin-dependent kinase 7 (MO15 homolog, Xenopus laevis, cdk-activating kinase)|homolog of Xenopus MO15 Cdk-activating kinase|kinase subunit of CAK|serine/threonine kinase stk1|serine/threonine protein kinase 1|serine/threonine protein kinase MO15', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69234795, end_position_on_the_genomic_accession=69277430, orientation='plus', exon_count=13, OMIM=[601955], no_hdr0=''),
    1024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1024, CurrentID=0, Status='live', Symbol='CDK8', Aliases=['IDDHBA', 'K35'], description='cyclin dependent kinase 8', other_designations='cyclin-dependent kinase 8|CDK8 protein kinase|cell division protein kinase 8|mediator complex subunit CDK8|mediator of RNA polymerase II transcription subunit CDK8|protein kinase K35', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=26254125, end_position_on_the_genomic_accession=26405238, orientation='plus', exon_count=14, OMIM=[603184], no_hdr0=''),
    1025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1025, CurrentID=0, Status='live', Symbol='CDK9', Aliases=['C-2k', 'CDC2L4', 'CTK1', 'PITALRE', 'TAK'], description='cyclin dependent kinase 9', other_designations='cyclin-dependent kinase 9|CDC2-related kinase|cell division cycle 2-like protein kinase 4|cell division protein kinase 9|serine/threonine protein kinase PITALRE|tat-associated kinase complex catalytic subunit', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127786034, end_position_on_the_genomic_accession=127790792, orientation='plus', exon_count=7, OMIM=[603251], no_hdr0=''),
    1026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1026, CurrentID=0, Status='live', Symbol='CDKN1A', Aliases=['CAP20', 'CDKN1', 'CIP1', 'MDA-6', 'P21', 'SDI1', 'WAF1', 'p21CIP1'], description='cyclin dependent kinase inhibitor 1A', other_designations='cyclin-dependent kinase inhibitor 1|CDK-interacting protein 1|CDK-interaction protein 1|DNA synthesis inhibitor|cyclin-dependent kinase inhibitor 1A (p21, Cip1)|melanoma differentiation associated protein 6|wild-type p53-activated fragment 1', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36676463, end_position_on_the_genomic_accession=36687332, orientation='plus', exon_count=6, OMIM=[116899], no_hdr0=''),
    1027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1027, CurrentID=0, Status='live', Symbol='CDKN1B', Aliases=['CDKN4', 'KIP1', 'MEN1B', 'MEN4', 'P27KIP1'], description='cyclin dependent kinase inhibitor 1B', other_designations='cyclin-dependent kinase inhibitor 1B|cyclin-dependent kinase inhibitor 1B (p27, Kip1)', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12717368, end_position_on_the_genomic_accession=12722369, orientation='plus', exon_count=3, OMIM=[600778], no_hdr0=''),
    1028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1028, CurrentID=0, Status='live', Symbol='CDKN1C', Aliases=['BWCR', 'BWS', 'KIP2', 'WBS', 'p57', 'p57Kip2'], description='cyclin dependent kinase inhibitor 1C', other_designations='cyclin-dependent kinase inhibitor 1C|cyclin-dependent kinase inhibitor 1C (p57, Kip2)|cyclin-dependent kinase inhibitor p57', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2883218, end_position_on_the_genomic_accession=2885775, orientation='minus', exon_count=4, OMIM=[600856], no_hdr0=''),
    1029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1029, CurrentID=0, Status='live', Symbol='CDKN2A', Aliases=['ARF', 'CDK4I', 'CDKN2', 'CMM2', 'INK4', 'INK4A', 'MLM', 'MTS-1', 'MTS1', 'P14', 'P14ARF', 'P16', 'P16-INK4A', 'P16INK4', 'P16INK4A', 'P19', 'P19ARF', 'TP16'], description='cyclin dependent kinase inhibitor 2A', other_designations='cyclin-dependent kinase inhibitor 2A|CDK4 inhibitor p16-INK4|alternative reading frame|cell cycle negative regulator beta|cyclin-dependent kinase 4 inhibitor A|cyclin-dependent kinase inhibitor 2A (melanoma, p16, inhibits CDK4)|multiple tumor suppressor 1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21967752, end_position_on_the_genomic_accession=21995324, orientation='minus', exon_count=8, OMIM=[600160], no_hdr0=''),
    1030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1030, CurrentID=0, Status='live', Symbol='CDKN2B', Aliases=['CDK4I', 'INK4B', 'MTS2', 'P15', 'TP15', 'p15INK4b'], description='cyclin dependent kinase inhibitor 2B', other_designations='cyclin-dependent kinase 4 inhibitor B|CDK inhibitory protein|CDK4B inhibitor|MTS-2|cyclin-dependent kinase inhibitor 2B (p15, inhibits CDK4)|cyclin-dependent kinases 4 and 6 binding protein|multiple tumor suppressor 2|p14-INK4b|p14_CDK inhibitor|p14_INK4B|p15 CDK inhibitor|p15-INK4b|p15_INK4B', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=22002903, end_position_on_the_genomic_accession=22009313, orientation='minus', exon_count=2, OMIM=[600431], no_hdr0=''),
    1031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1031, CurrentID=0, Status='live', Symbol='CDKN2C', Aliases=['INK4C', 'p18', 'p18-INK4C'], description='cyclin dependent kinase inhibitor 2C', other_designations='cyclin-dependent kinase 4 inhibitor C|CDK6 inhibitor p18|cyclin-dependent inhibitor|cyclin-dependent kinase 6 inhibitor p18|cyclin-dependent kinase inhibitor 2C (p18, inhibits CDK4)|p18-INK6', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=50968706, end_position_on_the_genomic_accession=50974634, orientation='plus', exon_count=3, OMIM=[603369], no_hdr0=''),
    1032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1032, CurrentID=0, Status='live', Symbol='CDKN2D', Aliases=['INK4D', 'p19', 'p19-INK4D'], description='cyclin dependent kinase inhibitor 2D', other_designations='cyclin-dependent kinase 4 inhibitor D|CDK inhibitor p19INK4d|cell cycle inhibitor, Nur77 associating protein|cyclin-dependent kinase 4 inhibitor D p19|cyclin-dependent kinase inhibitor 2D (p19, inhibits CDK4)|inhibitor of cyclin-dependent kinase 4d', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10566460, end_position_on_the_genomic_accession=10568979, orientation='minus', exon_count=2, OMIM=[600927], no_hdr0=''),
    1033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1033, CurrentID=0, Status='live', Symbol='CDKN3', Aliases=['CDI1', 'CIP2', 'KAP', 'KAP1'], description='cyclin dependent kinase inhibitor 3', other_designations='cyclin-dependent kinase inhibitor 3|CDK2-associated dual specificity phosphatase|Cdk-associated protein phosphatase|cyclin-dependent kinase inhibitor|cyclin-dependent kinase interacting protein 2|cyclin-dependent kinase interactor 1|kinase-associated phosphatase', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54396873, end_position_on_the_genomic_accession=54420218, orientation='plus', exon_count=9, OMIM=[123832], no_hdr0=''),
    1036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1036, CurrentID=0, Status='live', Symbol='CDO1', Aliases=['CDO-I'], description='cysteine dioxygenase type 1', other_designations='cysteine dioxygenase type 1|cysteine dioxygenase, type I', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115804733, end_position_on_the_genomic_accession=115816659, orientation='minus', exon_count=8, OMIM=[603943], no_hdr0=''),
    1038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1038, CurrentID=0, Status='live', Symbol='CDR1', Aliases=['CDR', 'CDR34', 'CDR62A'], description='cerebellar degeneration related protein 1', other_designations='cerebellar degeneration-related antigen 1|cerebellar degeneration-related protein 1, 34kDa', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=140783260, end_position_on_the_genomic_accession=140784558, orientation='minus', exon_count=1, OMIM=[302650], no_hdr0=''),
    1039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1039, CurrentID=0, Status='live', Symbol='CDR2', Aliases=['CDR62', 'Yo'], description='cerebellar degeneration related protein 2', other_designations='cerebellar degeneration-related protein 2|Yo paraneoplastic antigen|cerebellar degeneration-related protein 2, 62kDa|major Yo paraneoplastic antigen|paraneoplastic cerebellar degeneration-associated antigen', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22345936, end_position_on_the_genomic_accession=22374619, orientation='minus', exon_count=5, OMIM=[117340], no_hdr0=''),
    1040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1040, CurrentID=0, Status='live', Symbol='CDS1', Aliases=['CDS 1'], description='CDP-diacylglycerol synthase 1', other_designations='phosphatidate cytidylyltransferase 1|CDP-DAG synthase 1|CDP-DG synthase 1|CDP-DG synthetase 1|CDP-diacylglycerol synthase (phosphatidate cytidylyltransferase) 1|CDP-diglyceride pyrophosphorylase 1|CDP-diglyceride synthase 1|CDP-diglyceride synthetase 1|CTP:phosphatidate cytidylyltransferase 1', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=84582931, end_position_on_the_genomic_accession=84651334, orientation='plus', exon_count=13, OMIM=[603548], no_hdr0=''),
    1041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1041, CurrentID=0, Status='live', Symbol='CDSN', Aliases=['HTSS', 'HTSS1', 'HYPT2', 'PSS', 'PSS1', 'S'], description='corneodesmosin', other_designations='corneodesmosin|differentiated keratinocyte S protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31115087, end_position_on_the_genomic_accession=31120446, orientation='minus', exon_count=2, OMIM=[602593], no_hdr0=''),
    1043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1043, CurrentID=0, Status='live', Symbol='CD52', Aliases=['CDW52', 'EDDM5', 'HE5'], description='CD52 molecule', other_designations='CAMPATH-1 antigen|CD52 antigen (CAMPATH-1 antigen)|CDW52 antigen (CAMPATH-1 antigen)|HEL-S-171mP|cambridge pathology 1 antigen|epididymal secretory protein E5|epididymis secretory sperm binding protein Li 171mP|human epididymis-specific protein 5', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26317958, end_position_on_the_genomic_accession=26320523, orientation='plus', exon_count=2, OMIM=[114280], no_hdr0=''),
    1044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1044, CurrentID=0, Status='live', Symbol='CDX1', Aliases=[], description='caudal type homeobox 1', other_designations='homeobox protein CDX-1|caudal type homeo box transcription factor 1|caudal type homeobox transcription factor 1|caudal-type homeobox protein 1|caudal-type homeobox protein CDX1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150166778, end_position_on_the_genomic_accession=150184558, orientation='plus', exon_count=3, OMIM=[600746], no_hdr0=''),
    1045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1045, CurrentID=0, Status='live', Symbol='CDX2', Aliases=['CDX-3/AS', 'CDX3', 'CDX2'], description='caudal type homeobox 2', other_designations='homeobox protein CDX-2|caudal type homeobox transcription factor 2|caudal-type homeobox protein 2|homeobox protein miniCDX2', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27960918, end_position_on_the_genomic_accession=27969337, orientation='minus', exon_count=4, OMIM=[600297], no_hdr0=''),
    1046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1046, CurrentID=0, Status='live', Symbol='CDX4', Aliases=[], description='caudal type homeobox 4', other_designations='homeobox protein CDX-4|caudal type homeobox transcription factor 4|caudal-type homeobox protein 4', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=73447053, end_position_on_the_genomic_accession=73455171, orientation='plus', exon_count=3, OMIM=[300025], no_hdr0=''),
    1047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1047, CurrentID=0, Status='live', Symbol='CLGN', Aliases=[], description='calmegin', other_designations='calmegin|testis tissue sperm-binding protein Li 79P', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140388453, end_position_on_the_genomic_accession=140427648, orientation='minus', exon_count=16, OMIM=[601858], no_hdr0=''),
    1048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1048, CurrentID=0, Status='live', Symbol='CEACAM5', Aliases=['CD66e', 'CEA'], description='CEA cell adhesion molecule 5', other_designations='carcinoembryonic antigen-related cell adhesion molecule 5|carcinoembryonic antigen related cell adhesion molecule 5|meconium antigen 100', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41708626, end_position_on_the_genomic_accession=41730433, orientation='plus', exon_count=10, OMIM=[114890], no_hdr0=''),
    1050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1050, CurrentID=0, Status='live', Symbol='CEBPA', Aliases=['C/EBP-alpha', 'CEBP'], description='CCAAT enhancer binding protein alpha', other_designations='CCAAT/enhancer-binding protein alpha|CCAAT/enhancer binding protein (C/EBP), alpha', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33299934, end_position_on_the_genomic_accession=33302564, orientation='minus', exon_count=1, OMIM=[116897], no_hdr0=''),
    1051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1051, CurrentID=0, Status='live', Symbol='CEBPB', Aliases=['C/EBP-beta', 'IL6DBP', 'NF-IL6', 'TCF5'], description='CCAAT enhancer binding protein beta', other_designations='CCAAT/enhancer-binding protein beta|CCAAT/enhancer binding protein (C/EBP), beta|interleukin 6-dependent DNA-binding protein|nuclear factor NF-IL6|nuclear factor of interleukin 6|transcription factor 5|transcription factor C/EBP beta', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50190583, end_position_on_the_genomic_accession=50192690, orientation='plus', exon_count=1, OMIM=[189965], no_hdr0=''),
    1052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1052, CurrentID=0, Status='live', Symbol='CEBPD', Aliases=['C/EBP-delta', 'CELF', 'CRP3', 'NF-IL6-beta'], description='CCAAT enhancer binding protein delta', other_designations='CCAAT/enhancer-binding protein delta|CCAAT/enhancer binding protein (C/EBP), delta|c/EBP delta|nuclear factor NF-IL6-beta', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47736913, end_position_on_the_genomic_accession=47738164, orientation='minus', exon_count=1, OMIM=[116898], no_hdr0=''),
    1053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1053, CurrentID=0, Status='live', Symbol='CEBPE', Aliases=['C/EBP-epsilon', 'CRP1', 'c/EBP epsilon'], description='CCAAT enhancer binding protein epsilon', other_designations='CCAAT/enhancer-binding protein epsilon|CCAAT/enhancer binding protein (C/EBP), epsilon', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23117306, end_position_on_the_genomic_accession=23119255, orientation='minus', exon_count=2, OMIM=[600749], no_hdr0=''),
    1054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1054, CurrentID=0, Status='live', Symbol='CEBPG', Aliases=['GPE1BP', 'IG/EBP-1'], description='CCAAT enhancer binding protein gamma', other_designations='CCAAT/enhancer-binding protein gamma|CCAAT/enhancer binding protein (C/EBP), gamma|c/EBP gamma', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33373709, end_position_on_the_genomic_accession=33382686, orientation='plus', exon_count=3, OMIM=[138972], no_hdr0=''),
    1056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1056, CurrentID=0, Status='live', Symbol='CEL', Aliases=['BAL', 'BSDL', 'BSSLL', 'CEase', 'FAP', 'FAPP', 'LIPA', 'MODY8', 'CEL'], description='carboxyl ester lipase', other_designations='bile salt-activated lipase|bucelipase|carboxyl ester hydrolase|carboxyl ester lipase (bile salt-stimulated lipase)|cholesterol esterase|fetoacinar pancreatic protein|lysophospholipase, pancreatic|sterol esterase', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133061981, end_position_on_the_genomic_accession=133071861, orientation='plus', exon_count=11, OMIM=[114840], no_hdr0=''),
    1058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1058, CurrentID=0, Status='live', Symbol='CENPA', Aliases=['CENP-A', 'CenH3'], description='centromere protein A', other_designations='histone H3-like centromeric protein A|centromere autoantigen A|centromere protein A, 17kDa|centromere-specific histone', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26786056, end_position_on_the_genomic_accession=26794589, orientation='plus', exon_count=5, OMIM=[117139], no_hdr0=''),
    1059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1059, CurrentID=0, Status='live', Symbol='CENPB', Aliases=[], description='centromere protein B', other_designations='major centromere autoantigen B|CENP-B|centromere autoantigen B|centromere protein B, 80kDa', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3783851, end_position_on_the_genomic_accession=3786740, orientation='minus', exon_count=1, OMIM=[117140], no_hdr0=''),
    1060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1060, CurrentID=0, Status='live', Symbol='CENPC', Aliases=['CENP-C1', 'MIF2', 'hcp-4', 'CENPC'], description='centromere protein C', other_designations='centromere protein C|CENP-C 1|centromere autoantigen C|centromere autoantigen C1|centromere protein C 1|interphase centromere complex protein 7', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67468762, end_position_on_the_genomic_accession=67545503, orientation='minus', exon_count=20, OMIM=[117141], no_hdr0=''),
    1062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1062, CurrentID=0, Status='live', Symbol='CENPE', Aliases=['CENP-E', 'KIF10', 'MCPH13', 'PPP1R61'], description='centromere protein E', other_designations='centromere-associated protein E|Centromere autoantigen E (312kD)|centromere protein E, 312kDa|kinesin family member 10|kinesin-7|kinesin-related protein CENPE|protein phosphatase 1, regulatory subunit 61', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=103105811, end_position_on_the_genomic_accession=103198408, orientation='minus', exon_count=49, OMIM=[117143], no_hdr0=''),
    1063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1063, CurrentID=0, Status='live', Symbol='CENPF', Aliases=['CENF', 'CILD31', 'PRO1779', 'STROMS', 'hcp-1'], description='centromere protein F', other_designations='centromere protein F|AH antigen|CENP-F kinetochore protein|cell-cycle-dependent 350K nuclear protein|centromere protein F, 350/400kDa|kinetochore protein CENPF|mitosin', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=214603195, end_position_on_the_genomic_accession=214664571, orientation='plus', exon_count=21, OMIM=[600236], no_hdr0=''),
    1066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1066, CurrentID=0, Status='live', Symbol='CES1', Aliases=['ACAT', 'CE-1', 'CEH', 'CES2', 'HMSE', 'HMSE1', 'PCE-1', 'REH', 'SES1', 'TGH', 'hCE-1'], description='carboxylesterase 1', other_designations='liver carboxylesterase 1|acyl coenzyme A:cholesterol acyltransferase|brain carboxylesterase hBr1|carboxylesterase 1 (monocyte/macrophage serine esterase 1)|carboxylesterase 2 (liver)|cholesteryl ester hydrolase|cocaine carboxylesterase|egasyn|human monocyte/macrophage serine esterase 1|methylumbelliferyl-acetate deacetylase 1|monocyte/macrophage serine esterase|retinyl ester hydrolase|serine esterase 1|triacylglycerol hydrolase', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55802851, end_position_on_the_genomic_accession=55833127, orientation='minus', exon_count=14, OMIM=[114835], no_hdr0=''),
    1068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1068, CurrentID=0, Status='live', Symbol='CETN1', Aliases=['CEN1', 'CETN'], description='centrin 1', other_designations='centrin-1|EF-hand protein|calcium binding protein|caltractin|centrin, EF-hand protein, 1|testicular tissue protein Li 37', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=580380, end_position_on_the_genomic_accession=582114, orientation='plus', exon_count=1, OMIM=[603187], no_hdr0=''),
    1069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1069, CurrentID=0, Status='live', Symbol='CETN2', Aliases=['CALT', 'CEN2'], description='centrin 2', other_designations='centrin-2|caltractin (20kD calcium-binding protein)|centrin, EF-hand protein, 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152826994, end_position_on_the_genomic_accession=152830757, orientation='minus', exon_count=5, OMIM=[300006], no_hdr0=''),
    1070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1070, CurrentID=0, Status='live', Symbol='CETN3', Aliases=['CDC31', 'CEN3'], description='centrin 3', other_designations='centrin-3|CDC31 yeast homolog|EF-hand superfamily member|centrin, EF-hand protein, 3 (CDC31 homolog, yeast)', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=90392257, end_position_on_the_genomic_accession=90409756, orientation='minus', exon_count=6, OMIM=[602907], no_hdr0=''),
    1071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1071, CurrentID=0, Status='live', Symbol='CETP', Aliases=['BPIFF', 'HDLCQ10'], description='cholesteryl ester transfer protein', other_designations='cholesteryl ester transfer protein|BPI fold containing family F|cholesteryl ester transfer protein plasma|lipid transfer protein I', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56961950, end_position_on_the_genomic_accession=56983845, orientation='plus', exon_count=17, OMIM=[118470], no_hdr0=''),
    1072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1072, CurrentID=0, Status='live', Symbol='CFL1', Aliases=['CFL', 'HEL-S-15', 'cofilin'], description='cofilin 1', other_designations='cofilin-1|18 kDa phosphoprotein|cofilin 1 (non-muscle)|epididymis secretory protein Li 15|p18', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65854673, end_position_on_the_genomic_accession=65858180, orientation='minus', exon_count=4, OMIM=[601442], no_hdr0=''),
    1073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1073, CurrentID=0, Status='live', Symbol='CFL2', Aliases=['NEM7'], description='cofilin 2', other_designations='cofilin-2|cofilin 2 (muscle)|nemaline myopathy type 7', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34709113, end_position_on_the_genomic_accession=34714593, orientation='minus', exon_count=6, OMIM=[601443], no_hdr0=''),
    1075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1075, CurrentID=0, Status='live', Symbol='CTSC', Aliases=['CPPI', 'DPP-I', 'DPP1', 'DPPI', 'HMS', 'JP', 'JPD', 'PALS', 'PDON1', 'PLS'], description='cathepsin C', other_designations='dipeptidyl peptidase 1|cathepsin J|dipeptidyl transferase|dipeptidyl-peptidase I', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=88293592, end_position_on_the_genomic_accession=88337736, orientation='minus', exon_count=9, OMIM=[602365], no_hdr0=''),
    1080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1080, CurrentID=0, Status='live', Symbol='CFTR', Aliases=['ABC35', 'ABCC7', 'CF/MRP', 'MRP7', 'TNR-CFTR', 'dJ760C5.1', 'CFTR'], description='CF transmembrane conductance regulator', other_designations='cystic fibrosis transmembrane conductance regulator|cAMP-dependent chloride channel|channel conductance-controlling ATPase|cystic fibrosis transmembrane conductance regulating|cystic fibrosis transmembrane conductance regulator (ATP-binding cassette sub-family C, member 7)', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=117480025, end_position_on_the_genomic_accession=117668665, orientation='plus', exon_count=27, OMIM=[602421], no_hdr0=''),
    1081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1081, CurrentID=0, Status='live', Symbol='CGA', Aliases=['CG-ALPHA', 'FSHA', 'GPA1', 'GPHA1', 'GPHa', 'HCG', 'LHA', 'TSHA'], description='glycoprotein hormones, alpha polypeptide', other_designations='glycoprotein hormones alpha chain|FSH-alpha|LSH-alpha|TSH-alpha|anterior pituitary glycoprotein hormones common subunit alpha|choriogonadotropin alpha chain|chorionic gonadotrophin subunit alpha|chorionic gonadotropin, alpha polypeptide|follicle-stimulating hormone alpha chain|follicle-stimulating hormone alpha subunit|follitropin alpha chain|luteinizing hormone alpha chain|lutropin alpha chain|thyroid-stimulating hormone alpha chain|thyrotropin alpha chain', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87085498, end_position_on_the_genomic_accession=87095106, orientation='minus', exon_count=5, OMIM=[118850], no_hdr0=''),
    1082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1082, CurrentID=0, Status='live', Symbol='CGB3', Aliases=['CGB', 'CGB5', 'CGB7', 'CGB8', 'LHB', 'hCGB'], description='chorionic gonadotropin subunit beta 3', other_designations='choriogonadotropin subunit beta 3|CG-beta|chorionic gonadotrophin chain beta|chorionic gonadotropin beta 3 subunit|chorionic gonadotropin beta chain|chorionic gonadotropin beta subunit 3|chorionic gonadotropin chain beta|chorionic gonadotropin, beta polypeptide|luteinizing hormone beta subunit', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49022869, end_position_on_the_genomic_accession=49024333, orientation='minus', exon_count=3, OMIM=[118860], no_hdr0=''),
    1084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1084, CurrentID=0, Status='live', Symbol='CEACAM3', Aliases=['CD66D', 'CEA', 'CGM1', 'W264', 'W282'], description='CEA cell adhesion molecule 3', other_designations='carcinoembryonic antigen-related cell adhesion molecule 3|CD66d antigen|carcinoembryonic antigen CGM1|carcinoembryonic antigen gene family member 1|carcinoembryonic antigen related cell adhesion molecule 3|nonspecific cross-reacting antigen', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41796587, end_position_on_the_genomic_accession=41811554, orientation='plus', exon_count=8, OMIM=[609142], no_hdr0=''),
    1087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1087, CurrentID=0, Status='live', Symbol='CEACAM7', Aliases=['CGM2'], description='CEA cell adhesion molecule 7', other_designations='carcinoembryonic antigen-related cell adhesion molecule 7|carcinoembryonic antigen CGM2|carcinoembryonic antigen gene family member 2|carcinoembryonic antigen related cell adhesion molecule 7', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41673303, end_position_on_the_genomic_accession=41688270, orientation='minus', exon_count=5, OMIM=[619160], no_hdr0=''),
    1088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1088, CurrentID=0, Status='live', Symbol='CEACAM8', Aliases=['CD66b', 'CD67', 'CGM6', 'NCA-95'], description='CEA cell adhesion molecule 8', other_designations='carcinoembryonic antigen-related cell adhesion molecule 8|CD67 antigen|carcinoembryonic antigen CGM6|carcinoembryonic antigen gene family member 6|carcinoembryonic antigen related cell adhesion molecule 8|non-specific cross-reacting antigen NCA-95', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42580243, end_position_on_the_genomic_accession=42595157, orientation='minus', exon_count=8, OMIM=[615747], no_hdr0=''),
    1089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1089, CurrentID=0, Status='live', Symbol='CEACAM4', Aliases=['CGM7', 'CGM7_HUMAN', 'NCA'], description='CEA cell adhesion molecule 4', other_designations='carcinoembryonic antigen-related cell adhesion molecule 4|Nonspecific cross-reacting antigen (NCA)|carcinoembryonic antigen CGM7|carcinoembryonic antigen gene family member 7|carcinoembryonic antigen related cell adhesion molecule 4|carcinoembryonic antigen-related cell adhesion molecule 4-sv1|carcinoembryonic antigen-related cell adhesion molecule 4-sv2|non-specific cross-reacting antigen W236|nonspecific cross-reacting antigen W236', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41616986, end_position_on_the_genomic_accession=41627087, orientation='minus', exon_count=11, OMIM=[619159], no_hdr0=''),
    1101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1101, CurrentID=0, Status='live', Symbol='CHAD', Aliases=['SLRR4A'], description='chondroadherin', other_designations='chondroadherin|cartilage leucine-rich protein|chondroadherin proteoglycan', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50464492, end_position_on_the_genomic_accession=50469881, orientation='minus', exon_count=4, OMIM=[602178], no_hdr0=''),
    1102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1102, CurrentID=0, Status='live', Symbol='RCBTB2', Aliases=['CHC1L', 'RLG'], description='RCC1 and BTB domain containing protein 2', other_designations='RCC1 and BTB domain-containing protein 2|RCC1-like G exchanging factor RLG|regulator of chromosome condensation (RCC1) and BTB (POZ) domain containing protein 2', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48488963, end_position_on_the_genomic_accession=48535997, orientation='minus', exon_count=18, OMIM=[603524], no_hdr0=''),
    1103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1103, CurrentID=0, Status='live', Symbol='CHAT', Aliases=['CHOACTASE', 'CMS1A', 'CMS1A2', 'CMS6'], description='choline O-acetyltransferase', other_designations='choline O-acetyltransferase|acetyl CoA:choline O-acetyltransferase|choline acetylase', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49609095, end_position_on_the_genomic_accession=49667942, orientation='plus', exon_count=18, OMIM=[118490], no_hdr0=''),
    1104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1104, CurrentID=0, Status='live', Symbol='RCC1', Aliases=['CHC1-I', 'SNHG3-RCC1', 'RCC1'], description='regulator of chromosome condensation 1', other_designations='regulator of chromosome condensation|SNHG3-RCC1 readthrough|cell cycle regulatory protein|guanine nucleotide-releasing protein', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28506043, end_position_on_the_genomic_accession=28538989, orientation='plus', exon_count=15, OMIM=[179710], no_hdr0=''),
    1105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1105, CurrentID=0, Status='live', Symbol='CHD1', Aliases=['CHD-1', 'PILBOS'], description='chromodomain helicase DNA binding protein 1', other_designations='chromodomain-helicase-DNA-binding protein 1|ATP-dependent helicase CHD1', map_location='5q15-q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=98853985, end_position_on_the_genomic_accession=98929772, orientation='minus', exon_count=40, OMIM=[602118], no_hdr0=''),
    1106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1106, CurrentID=0, Status='live', Symbol='CHD2', Aliases=['DEE94', 'EEOC'], description='chromodomain helicase DNA binding protein 2', other_designations='chromodomain-helicase-DNA-binding protein 2|ATP-dependent helicase CHD2|CHD-2', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=92900324, end_position_on_the_genomic_accession=93027996, orientation='plus', exon_count=39, OMIM=[602119], no_hdr0=''),
    1107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1107, CurrentID=0, Status='live', Symbol='CHD3', Aliases=['Mi-2a', 'Mi2-ALPHA', 'SNIBCPS', 'ZFH'], description='chromodomain helicase DNA binding protein 3', other_designations='chromodomain-helicase-DNA-binding protein 3|ATP-dependent helicase CHD3|CHD-3|hZFH|mi-2 autoantigen 240 kDa protein|zinc finger helicase|zinc-finger helicase (Snf2-like)', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7884764, end_position_on_the_genomic_accession=7912755, orientation='plus', exon_count=44, OMIM=[602120], no_hdr0=''),
    1108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1108, CurrentID=0, Status='live', Symbol='CHD4', Aliases=['CHD-4', 'Mi-2b', 'Mi2-BETA', 'SIHIWES'], description='chromodomain helicase DNA binding protein 4', other_designations='chromodomain-helicase-DNA-binding protein 4|ATP-dependent helicase CHD4|Mi-2 autoantigen 218 kDa protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6570082, end_position_on_the_genomic_accession=6607379, orientation='minus', exon_count=40, OMIM=[603277], no_hdr0=''),
    1109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1109, CurrentID=0, Status='live', Symbol='AKR1C4', Aliases=['3-alpha-HSD', 'C11', 'CDR', 'CHDR', 'DD-4', 'DD4', 'HAKRA'], description='aldo-keto reductase family 1 member C4', other_designations='aldo-keto reductase family 1 member C4|3-alpha-HSD1|3alpha-hydroxysteroid 3-dehydrogenase|chlordecone reductase; 3-alpha hydroxysteroid dehydrogenase, type I; dihydrodiol dehydrogenase 4|dihydrodiol dehydrogenase isozyme DD4|type I 3-alpha-hydroxysteroid dehydrogenase', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5196837, end_position_on_the_genomic_accession=5218949, orientation='plus', exon_count=9, OMIM=[600451], no_hdr0=''),
    1111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1111, CurrentID=0, Status='live', Symbol='CHEK1', Aliases=['CHK1'], description='checkpoint kinase 1', other_designations='serine/threonine-protein kinase Chk1|CHK1 checkpoint homolog|Checkpoint, S. pombe, homolog of, 1|Chk1-S|cell cycle checkpoint kinase', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125624910, end_position_on_the_genomic_accession=125676255, orientation='plus', exon_count=15, OMIM=[603078], no_hdr0=''),
    1112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1112, CurrentID=0, Status='live', Symbol='FOXN3', Aliases=['C14orf116', 'CHES1', 'PRO1635'], description='forkhead box N3', other_designations='forkhead box protein N3|checkpoint suppressor 1', map_location='14q31.3-q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=89156177, end_position_on_the_genomic_accession=89619165, orientation='minus', exon_count=8, OMIM=[602628], no_hdr0=''),
    1113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1113, CurrentID=0, Status='live', Symbol='CHGA', Aliases=['CGA'], description='chromogranin A', other_designations='chromogranin-A|SP-I|betagranin (N-terminal fragment of chromogranin A)|catestatin|chromofungin|parathyroid secretory protein 1|pituitary secretory protein I', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92922594, end_position_on_the_genomic_accession=92935293, orientation='plus', exon_count=9, OMIM=[118910], no_hdr0=''),
    1114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1114, CurrentID=0, Status='live', Symbol='CHGB', Aliases=['SCG1'], description='chromogranin B', other_designations='secretogranin-1|cgB|secretogranin B|secretogranin I|sgI', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5911510, end_position_on_the_genomic_accession=5925353, orientation='plus', exon_count=5, OMIM=[118920], no_hdr0=''),
    1116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1116, CurrentID=0, Status='live', Symbol='CHI3L1', Aliases=['ASRT7', 'CGP-39', 'GP-39', 'GP39', 'HC-gp39', 'HCGP-3P', 'YK-40', 'YKL-40', 'YKL40', 'YYL-40', 'hCGP-39'], description='chitinase 3 like 1', other_designations='chitinase-3-like protein 1|39 kDa synovial protein|cartilage glycoprotein 39|chitinase 3-like 1 (cartilage glycoprotein-39)', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203178931, end_position_on_the_genomic_accession=203186704, orientation='minus', exon_count=10, OMIM=[601525], no_hdr0=''),
    1117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1117, CurrentID=0, Status='live', Symbol='CHI3L2', Aliases=['CHIL2', 'YKL-39', 'YKL39'], description='chitinase 3 like 2', other_designations='chitinase-3-like protein 2|chondrocyte protein 39', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111227080, end_position_on_the_genomic_accession=111243440, orientation='plus', exon_count=12, OMIM=[601526], no_hdr0=''),
    1118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1118, CurrentID=0, Status='live', Symbol='CHIT1', Aliases=['CHI3', 'CHIT', 'CHITD'], description='chitinase 1', other_designations='chitotriosidase-1|chitinase 1 (chitotriosidase)|plasma methylumbelliferyl tetra-N-acetylchitotetraoside hydrolase', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203216079, end_position_on_the_genomic_accession=203229673, orientation='minus', exon_count=13, OMIM=[600031], no_hdr0=''),
    1119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1119, CurrentID=0, Status='live', Symbol='CHKA', Aliases=['CHK', 'CK', 'CKI', 'EK'], description='choline kinase alpha', other_designations='choline kinase alpha|CHETK-alpha|ethanolamine kinase', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68052859, end_position_on_the_genomic_accession=68121389, orientation='minus', exon_count=14, OMIM=[118491], no_hdr0=''),
    1120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1120, CurrentID=0, Status='live', Symbol='CHKB', Aliases=['CHETK', 'CHKL', 'CK', 'CKB', 'CKEKB', 'EK', 'EKB', 'MDCMC'], description='choline kinase beta', other_designations='choline/ethanolamine kinase|choline kinase-like protein|ethanolamine kinase beta', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50578963, end_position_on_the_genomic_accession=50582849, orientation='minus', exon_count=11, OMIM=[612395], no_hdr0=''),
    1121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1121, CurrentID=0, Status='live', Symbol='CHM', Aliases=['DXS540', 'GGTA', 'HSD-32', 'REP-1', 'TCD'], description='CHM Rab escort protein', other_designations='rab proteins geranylgeranyltransferase component A 1|CHM, Rab escort protein 1|choroideremia (Rab escort protein 1)', map_location='Xq21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=85861180, end_position_on_the_genomic_accession=86047558, orientation='minus', exon_count=19, OMIM=[300390], no_hdr0=''),
    1122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1122, CurrentID=0, Status='live', Symbol='CHML', Aliases=['REP2'], description='CHM like Rab escort protein', other_designations='rab proteins geranylgeranyltransferase component A 2|CHM like Rab escort protein 2|choroideraemia-like protein|choroideremia-like (Rab escort protein 2)|choroideremia-like protein', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241628851, end_position_on_the_genomic_accession=241640369, orientation='minus', exon_count=2, OMIM=[118825], no_hdr0=''),
    1123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1123, CurrentID=0, Status='live', Symbol='CHN1', Aliases=['ARHGAP2', 'CHN', 'DURS2', 'NC', 'RHOGAP2'], description='chimerin 1', other_designations='N-chimaerin|A-chimaerin|Rho GTPase-activating protein 2|a2-chimaerin|alpha-chimerin|chimaerin 1|chimerin (chimaerin) 1|n-chimerin', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174798809, end_position_on_the_genomic_accession=175005381, orientation='minus', exon_count=15, OMIM=[118423], no_hdr0=''),
    1124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1124, CurrentID=0, Status='live', Symbol='CHN2', Aliases=['ARHGAP3', 'BCH-3', 'RHOGAP3', 'CHN2'], description='chimerin 2', other_designations='beta-chimaerin|beta-chimerin|beta3-chimaerin|chimerin (chimaerin) 2|chimerin, beta-2|chimerin, testis-specific|rho-GTPase-activating protein 3', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=29146547, end_position_on_the_genomic_accession=29514335, orientation='plus', exon_count=21, OMIM=[602857], no_hdr0=''),
    1128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1128, CurrentID=0, Status='live', Symbol='CHRM1', Aliases=['HM1', 'M1', 'M1R'], description='cholinergic receptor muscarinic 1', other_designations='muscarinic acetylcholine receptor M1|acetylcholine receptor, muscarinic 1', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62908675, end_position_on_the_genomic_accession=62921861, orientation='minus', exon_count=3, OMIM=[118510], no_hdr0=''),
    1129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1129, CurrentID=0, Status='live', Symbol='CHRM2', Aliases=['HM2'], description='cholinergic receptor muscarinic 2', other_designations='muscarinic acetylcholine receptor M2|7TM receptor|acetylcholine receptor, muscarinic 2|muscarinic M2 receptor', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=136868652, end_position_on_the_genomic_accession=137020213, orientation='plus', exon_count=7, OMIM=[118493], no_hdr0=''),
    1130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1130, CurrentID=0, Status='live', Symbol='LYST', Aliases=['CHS', 'CHS1', 'Mauve'], description='lysosomal trafficking regulator', other_designations='lysosomal-trafficking regulator|Chediak-Higashi syndrome 1|beige homolog', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235661031, end_position_on_the_genomic_accession=235883713, orientation='minus', exon_count=61, OMIM=[606897], no_hdr0=''),
    1131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1131, CurrentID=0, Status='live', Symbol='CHRM3', Aliases=['EGBRS', 'HM3', 'PBS'], description='cholinergic receptor muscarinic 3', other_designations='muscarinic acetylcholine receptor M3|acetylcholine receptor, muscarinic 3|m3 muscarinic receptor', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=239386565, end_position_on_the_genomic_accession=239915450, orientation='plus', exon_count=17, OMIM=[118494], no_hdr0=''),
    1132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1132, CurrentID=0, Status='live', Symbol='CHRM4', Aliases=['HM4', 'M4R'], description='cholinergic receptor muscarinic 4', other_designations='muscarinic acetylcholine receptor M4|acetylcholine receptor, muscarinic 4', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46383789, end_position_on_the_genomic_accession=46391776, orientation='minus', exon_count=2, OMIM=[118495], no_hdr0=''),
    1133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1133, CurrentID=0, Status='live', Symbol='CHRM5', Aliases=['HM5'], description='cholinergic receptor muscarinic 5', other_designations='muscarinic acetylcholine receptor M5|acetylcholine receptor, muscarinic 5', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=33968497, end_position_on_the_genomic_accession=34067458, orientation='plus', exon_count=3, OMIM=[118496], no_hdr0=''),
    1134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1134, CurrentID=0, Status='live', Symbol='CHRNA1', Aliases=['ACHRA', 'ACHRD', 'CHRNA', 'CMS1A', 'CMS1B', 'CMS2A', 'FCCMS', 'SCCMS'], description='cholinergic receptor nicotinic alpha 1 subunit', other_designations='acetylcholine receptor subunit alpha|acetylcholine receptor, nicotinic, alpha 1 (muscle)|cholinergic receptor, nicotinic alpha 1|cholinergic receptor, nicotinic, alpha 1 (muscle)|cholinergic receptor, nicotinic, alpha polypeptide 1 (muscle)|muscle nicotinic acetylcholine receptor|nicotinic acetylcholine receptor alpha subunit|nicotinic cholinergic receptor alpha 1', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174747592, end_position_on_the_genomic_accession=174764472, orientation='minus', exon_count=10, OMIM=[100690], no_hdr0=''),
    1135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1135, CurrentID=0, Status='live', Symbol='CHRNA2', Aliases=[], description='cholinergic receptor nicotinic alpha 2 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-2|acetylcholine receptor, nicotinic, alpha 2 (neuronal)|cholinergic receptor, nicotinic alpha 2|cholinergic receptor, nicotinic, alpha 2 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 2 (neuronal)', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27459756, end_position_on_the_genomic_accession=27479285, orientation='minus', exon_count=8, OMIM=[118502], no_hdr0=''),
    1136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1136, CurrentID=0, Status='live', Symbol='CHRNA3', Aliases=['BAIPRCK', 'LNCR2', 'NACHRA3', 'PAOD2'], description='cholinergic receptor nicotinic alpha 3 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-3|cholinergic receptor, nicotinic alpha 3|cholinergic receptor, nicotinic, alpha 3 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 3|neuronal nicotinic acetylcholine receptor, alpha3 subunit', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78593052, end_position_on_the_genomic_accession=78620996, orientation='minus', exon_count=9, OMIM=[118503], no_hdr0=''),
    1137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1137, CurrentID=0, Status='live', Symbol='CHRNA4', Aliases=['BFNC', 'EBN', 'EBN1', 'NACHR', 'NACHRA4', 'NACRA4'], description='cholinergic receptor nicotinic alpha 4 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-4|cholinergic receptor, nicotinic alpha 4|cholinergic receptor, nicotinic, alpha 4 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 4|neuronal nicotinic acetylcholine receptor alpha-4 subunit', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63343223, end_position_on_the_genomic_accession=63375471, orientation='minus', exon_count=10, OMIM=[118504], no_hdr0=''),
    1138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1138, CurrentID=0, Status='live', Symbol='CHRNA5', Aliases=['LNCR2'], description='cholinergic receptor nicotinic alpha 5 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-5|Cholinergic receptor, neuronal nicotinic, alpha polypeptide-5|acetylcholine receptor, nicotinic, alpha 5 (neuronal)|cholinergic receptor, nicotinic alpha 5|cholinergic receptor, nicotinic, alpha 5 (neuronal)|neuronal nicotinic acetylcholine receptor, alpha5 subunit', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78565520, end_position_on_the_genomic_accession=78595269, orientation='plus', exon_count=6, OMIM=[118505], no_hdr0=''),
    1139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1139, CurrentID=0, Status='live', Symbol='CHRNA7', Aliases=['CHRNA7-2', 'NACHRA7'], description='cholinergic receptor nicotinic alpha 7 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-7|a7 nicotinic acetylcholine receptor|alpha 7 neuronal nicotinic acetylcholine receptor|alpha-7 nicotinic cholinergic receptor subunit|cholinergic receptor, nicotinic alpha 7|cholinergic receptor, nicotinic, alpha 7 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 7|neuronal acetylcholine receptor protein, alpha-7 chain', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32030462, end_position_on_the_genomic_accession=32173018, orientation='plus', exon_count=13, OMIM=[118511], no_hdr0=''),
    1140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1140, CurrentID=0, Status='live', Symbol='CHRNB1', Aliases=['ACHRB', 'CHRNB', 'CMS1D', 'CMS2A', 'CMS2C', 'SCCMS'], description='cholinergic receptor nicotinic beta 1 subunit', other_designations='acetylcholine receptor subunit beta|acetylcholine receptor, nicotinic, beta 1 (muscle)|cholinergic receptor, nicotinic beta 1|cholinergic receptor, nicotinic, beta 1 (muscle)|cholinergic receptor, nicotinic, beta polypeptide 1 (muscle)', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7445061, end_position_on_the_genomic_accession=7457710, orientation='plus', exon_count=11, OMIM=[100710], no_hdr0=''),
    1141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1141, CurrentID=0, Status='live', Symbol='CHRNB2', Aliases=['EFNL3', 'nAChRB2'], description='cholinergic receptor nicotinic beta 2 subunit', other_designations='neuronal acetylcholine receptor subunit beta-2|acetylcholine receptor, nicotinic, beta 2 (neuronal)|beta2 human neuronal nicotinic acetylcholine receptor|cholinergic receptor, nicotinic beta 2|cholinergic receptor, nicotinic, beta 2 (neuronal)|cholinergic receptor, nicotinic, beta polypeptide 2 (neuronal)|neuronal nicotinic acetylcholine receptor beta 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154567778, end_position_on_the_genomic_accession=154584708, orientation='plus', exon_count=7, OMIM=[118507], no_hdr0=''),
    1142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1142, CurrentID=0, Status='live', Symbol='CHRNB3', Aliases=[], description='cholinergic receptor nicotinic beta 3 subunit', other_designations='neuronal acetylcholine receptor subunit beta-3|acetylcholine receptor, neuronal nicotinic, beta-3 subunit|acetylcholine receptor, nicotinic, beta 3 (neuronal)|cholinergic receptor, nicotinic beta 3|cholinergic receptor, nicotinic, beta 3 (neuronal)|cholinergic receptor, nicotinic, beta polypeptide 3', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42697366, end_position_on_the_genomic_accession=42737407, orientation='plus', exon_count=8, OMIM=[118508], no_hdr0=''),
    1143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1143, CurrentID=0, Status='live', Symbol='CHRNB4', Aliases=[], description='cholinergic receptor nicotinic beta 4 subunit', other_designations='neuronal acetylcholine receptor subunit beta-4|acetylcholine receptor, nicotinic, beta 4 (neuronal)|cholinergic receptor, nicotinic, beta 4 (neuronal)|cholinergic receptor, nicotinic, beta polypeptide 4|neuronal nicotinic receptor beta 4 subunit', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78623282, end_position_on_the_genomic_accession=78655586, orientation='minus', exon_count=15, OMIM=[118509], no_hdr0=''),
    1144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1144, CurrentID=0, Status='live', Symbol='CHRND', Aliases=['ACHRD', 'CMS2A', 'CMS3A', 'CMS3B', 'CMS3C', 'FCCMS', 'SCCMS'], description='cholinergic receptor nicotinic delta subunit', other_designations='acetylcholine receptor subunit delta|acetylcholine receptor, nicotinic, delta (muscle)|cholinergic receptor, nicotinic delta|cholinergic receptor, nicotinic, delta (muscle)|cholinergic receptor, nicotinic, delta polypeptide', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232526160, end_position_on_the_genomic_accession=232537907, orientation='plus', exon_count=12, OMIM=[100720], no_hdr0=''),
    1145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1145, CurrentID=0, Status='live', Symbol='CHRNE', Aliases=['ACHRE', 'CMS1D', 'CMS1E', 'CMS2A', 'CMS4A', 'CMS4B', 'CMS4C', 'FCCMS', 'SCCMS'], description='cholinergic receptor nicotinic epsilon subunit', other_designations='acetylcholine receptor subunit epsilon|AchR epsilon subunit|acetylcholine receptor, nicotinic, epsilon (muscle)|cholinergic receptor, nicotinic epsilon|cholinergic receptor, nicotinic, epsilon (muscle)|cholinergic receptor, nicotinic, epsilon polypeptide', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4897771, end_position_on_the_genomic_accession=4905019, orientation='minus', exon_count=13, OMIM=[100725], no_hdr0=''),
    1146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1146, CurrentID=0, Status='live', Symbol='CHRNG', Aliases=['ACHRG'], description='cholinergic receptor nicotinic gamma subunit', other_designations='acetylcholine receptor subunit gamma|acetylcholine receptor, muscle, gamma subunit|acetylcholine receptor, nicotinic, gamma (muscle)|cholinergic receptor, nicotinic gamma|cholinergic receptor, nicotinic, gamma (muscle)|cholinergic receptor, nicotinic, gamma polypeptide', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232539692, end_position_on_the_genomic_accession=232548115, orientation='plus', exon_count=12, OMIM=[100730], no_hdr0=''),
    1147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1147, CurrentID=0, Status='live', Symbol='CHUK', Aliases=['BPS2', 'IKBKA', 'IKK-alpha', 'IKK1', 'IKKA', 'NFKBIKA', 'TCF16'], description='component of inhibitor of nuclear factor kappa B kinase complex', other_designations='inhibitor of nuclear factor kappa-B kinase subunit alpha|I-kappa-B kinase 1|I-kappa-B kinase-alpha|IKK-a kinase|IkB kinase alpha subunit|Nuclear factor NFkappaB inhibitor kinase alpha|TCF-16|conserved helix-loop-helix ubiquitous kinase|transcription factor 16', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100188300, end_position_on_the_genomic_accession=100229610, orientation='minus', exon_count=23, OMIM=[600664], no_hdr0=''),
    1149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1149, CurrentID=0, Status='live', Symbol='CIDEA', Aliases=['CIDE-A'], description='cell death inducing DFFA like effector a', other_designations='cell death activator CIDE-A', map_location='18', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12254361, end_position_on_the_genomic_accession=12277595, orientation='plus', exon_count=6, OMIM=[604440], no_hdr0=''),
    1152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1152, CurrentID=0, Status='live', Symbol='CKB', Aliases=['B-CK', 'BCKB', 'CPK-B', 'HEL-211', 'HEL-S-29', 'CKB'], description='creatine kinase B', other_designations='creatine kinase B-type|brain creatine kinase|creatine kinase B chain|creatine kinase brain|creatine kinase brain-type|creatine phosphokinase B-type|epididymis luminal protein 211|epididymis secretory protein Li 29', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103519667, end_position_on_the_genomic_accession=103522833, orientation='minus', exon_count=7, OMIM=[123280], no_hdr0=''),
    1153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1153, CurrentID=0, Status='live', Symbol='CIRBP', Aliases=['CIRP'], description='cold inducible RNA binding protein', other_designations='cold-inducible RNA-binding protein|A18 hnRNP|glycine-rich RNA binding protein|testicular tissue protein Li 39', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1269332, end_position_on_the_genomic_accession=1274880, orientation='plus', exon_count=7, OMIM=[602649], no_hdr0=''),
    1154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1154, CurrentID=0, Status='live', Symbol='CISH', Aliases=['BACTS2', 'CIS', 'CIS-1', 'G18', 'SOCS'], description='cytokine inducible SH2 containing protein', other_designations='cytokine-inducible SH2-containing protein|cytokine-inducible inhibitor of signaling type 1B|suppressor of cytokine signaling', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50606454, end_position_on_the_genomic_accession=50611774, orientation='minus', exon_count=3, OMIM=[602441], no_hdr0=''),
    1155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1155, CurrentID=0, Status='live', Symbol='TBCB', Aliases=['CG22', 'CKAP1', 'CKAPI'], description='tubulin folding cofactor B', other_designations='tubulin-folding cofactor B|cytoskeleton associated protein 1|cytoskeleton-associated protein CKAPI|tubulin-specific chaperone B', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36114967, end_position_on_the_genomic_accession=36125941, orientation='plus', exon_count=7, OMIM=[601303], no_hdr0=''),
    1158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1158, CurrentID=0, Status='live', Symbol='CKM', Aliases=['CKMM', 'CPK-M', 'M-CK'], description='creatine kinase, M-type', other_designations='creatine kinase M-type|creatine kinase M chain|creatine kinase, muscle|creatine phosphokinase M-type', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45306413, end_position_on_the_genomic_accession=45322875, orientation='minus', exon_count=8, OMIM=[123310], no_hdr0=''),
    1159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1159, CurrentID=0, Status='live', Symbol='CKMT1B', Aliases=['CKMT', 'CKMT1', 'UMTCK'], description='creatine kinase, mitochondrial 1B', other_designations='creatine kinase U-type, mitochondrial|U-MtCK|acidic-type mitochondrial creatine kinase|creatine kinase, mitochondrial 1 (ubiquitous)|mia-CK|ubiquitous mitochondrial creatine kinase', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43592857, end_position_on_the_genomic_accession=43599406, orientation='plus', exon_count=10, OMIM=[123290], no_hdr0=''),
    1160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1160, CurrentID=0, Status='live', Symbol='CKMT2', Aliases=['SMTCK'], description='creatine kinase, mitochondrial 2', other_designations='creatine kinase S-type, mitochondrial|S-MtCK|basic-type mitochondrial creatine kinase|creatine kinase, mitochondrial 2 (sarcomeric)|mib-CK|sarcomeric mitochondrial creatine kinase', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=81233322, end_position_on_the_genomic_accession=81266398, orientation='plus', exon_count=11, OMIM=[123295], no_hdr0=''),
    1161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1161, CurrentID=0, Status='live', Symbol='ERCC8', Aliases=['CKN1', 'CSA', 'UVSS2'], description='ERCC excision repair 8, CSA ubiquitin ligase complex subunit', other_designations='DNA excision repair protein ERCC-8|Cockayne syndrome WD-repeat protein CSA|cockayne syndrome WD repeat protein CSA|excision repair cross-complementation group 8|excision repair cross-complementing rodent repair deficiency, complementation group 8', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=60866454, end_position_on_the_genomic_accession=60945070, orientation='minus', exon_count=13, OMIM=[609412], no_hdr0=''),
    1163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1163, CurrentID=0, Status='live', Symbol='CKS1B', Aliases=['CKS1', 'PNAS-16', 'PNAS-18', 'ckshs1'], description='CDC28 protein kinase regulatory subunit 1B', other_designations='cyclin-dependent kinases regulatory subunit 1|CDC2-associated protein CKS1|CDC28 protein kinase 1B|NB4 apoptosis/differentiation related protein|cell division control protein CKS1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154974681, end_position_on_the_genomic_accession=154979251, orientation='plus', exon_count=3, OMIM=[116900], no_hdr0=''),
    1164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1164, CurrentID=0, Status='live', Symbol='CKS2', Aliases=['CKSHS2'], description='CDC28 protein kinase regulatory subunit 2', other_designations='cyclin-dependent kinases regulatory subunit 2|CDC28 protein kinase 2|CKS-2|CKS1(S. cerevisiae Cdc28/Cdc2 kinase subunit) homolog-2', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=89311195, end_position_on_the_genomic_accession=89316703, orientation='plus', exon_count=3, OMIM=[116901], no_hdr0=''),
    1173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1173, CurrentID=0, Status='live', Symbol='AP2M1', Aliases=['AP50', 'CLAPM1', 'MRD60', 'mu2'], description='adaptor related protein complex 2 subunit mu 1', other_designations='AP-2 complex subunit mu|AP-2 mu 2 chain|HA2 50 kDA subunit|adaptin-mu2|adaptor protein complex AP-2 subunit mu|adaptor related protein complex 2 mu 1 subunit|adaptor-related protein complex 2 subunit mu|clathrin adaptor complex AP2, mu subunit|clathrin assembly protein complex 2 medium chain|clathrin assembly protein complex 2 mu medium chain|clathrin coat adaptor protein AP50|clathrin coat assembly protein AP50|clathrin coat-associated protein AP50|clathrin-associated/assembly/adaptor protein, medium 1|plasma membrane adaptor AP-2 50 kDa protein|plasma membrane adaptor AP-2 50kDA protein', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184174855, end_position_on_the_genomic_accession=184184091, orientation='plus', exon_count=14, OMIM=[601024], no_hdr0=''),
    1174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1174, CurrentID=0, Status='live', Symbol='AP1S1', Aliases=['AP19', 'CLAPS1', 'EKV3', 'MEDNIK', 'SIGMA1A'], description='adaptor related protein complex 1 subunit sigma 1', other_designations='AP-1 complex subunit sigma-1A|HA1 19 kDa subunit|adapter-related protein complex 1 sigma-1A subunit|adaptor protein complex AP-1 subunit sigma-1A|adaptor related protein complex 1 sigma 1 subunit|adaptor-related protein complex 1 subunit sigma-1A|clathrin assembly protein complex 1 sigma-1A small chain|clathrin coat assembly protein AP19|clathrin-associated/assembly/adaptor protein, small 1 (19kD)|golgi adaptor HA1/AP1 adaptin sigma-1A subunit|sigma1A subunit of AP-1 clathrin adaptor complex|sigma1A-adaptin', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101154476, end_position_on_the_genomic_accession=101161276, orientation='plus', exon_count=5, OMIM=[603531], no_hdr0=''),
    1175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1175, CurrentID=0, Status='live', Symbol='AP2S1', Aliases=['AP17', 'CLAPS2', 'FBH3', 'FBHOk', 'HHC3'], description='adaptor related protein complex 2 subunit sigma 1', other_designations='AP-2 complex subunit sigma|HA2 17 kDa subunit|adaptor protein complex AP-2 subunit sigma|adaptor related protein complex 2 sigma 1 subunit|clathrin assembly protein 2 sigma small chain|clathrin coat assembly protein AP17|clathrin coat-associated protein AP17|clathrin-associated/assembly/adaptor protein, small 2 (17kD)|plasma membrane adaptor AP-2 17 kDa protein|sigma-2|sigma2-adaptin', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46838167, end_position_on_the_genomic_accession=46850846, orientation='minus', exon_count=7, OMIM=[602242], no_hdr0=''),
    1176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1176, CurrentID=0, Status='live', Symbol='AP3S1', Aliases=['CLAPS3', 'Sigma3A'], description='adaptor related protein complex 3 subunit sigma 1', other_designations='AP-3 complex subunit sigma-1|adapter-related protein complex 3 subunit sigma-1|adaptor related protein complex 3 sigma 1 subunit|clathrin adaptor complex AP3, sigma-3A subunit|clathrin-associated/assembly/adapter protein, small 3|clathrin-associated/assembly/adaptor protein, small 3 (22kD)|sigma-adaptin 3a', map_location='5q22.3-q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115841606, end_position_on_the_genomic_accession=115914081, orientation='plus', exon_count=11, OMIM=[601507], no_hdr0=''),
    1178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1178, CurrentID=0, Status='live', Symbol='CLC', Aliases=['GAL10', 'Gal-10', 'LGALS10', 'LGALS10A', 'LPPL_HUMAN'], description='Charcot-Leyden crystal galectin', other_designations='galectin-10|Charcot-Leyden crystal protein|eosinophil lysophospholipase|lectin, galactoside-binding, soluble, 10|lysolecithin acylhydrolase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39731255, end_position_on_the_genomic_accession=39738029, orientation='minus', exon_count=4, OMIM=[153310], no_hdr0=''),
    1179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1179, CurrentID=0, Status='live', Symbol='CLCA1', Aliases=['CACC', 'CACC1', 'CLCRG1', 'CaCC-1', 'GOB5', 'hCLCA1', 'hCaCC-1'], description='chloride channel accessory 1', other_designations='calcium-activated chloride channel regulator 1|CLCA family member 1, chloride channel regulator|calcium-activated chloride channel family member 1|calcium-activated chloride channel protein 1|calcium-dependent chloride channel-1|chloride channel regulator 1|chloride channel, calcium activated, family member 1', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86468927, end_position_on_the_genomic_accession=86500259, orientation='plus', exon_count=14, OMIM=[603906], no_hdr0=''),
    1180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1180, CurrentID=0, Status='live', Symbol='CLCN1', Aliases=['CLC1'], description='chloride voltage-gated channel 1', other_designations='chloride channel protein 1|chloride channel 1, skeletal muscle|chloride channel protein, skeletal muscle|chloride channel, voltage-sensitive 1|clC-1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143316111, end_position_on_the_genomic_accession=143352083, orientation='plus', exon_count=23, OMIM=[118425], no_hdr0=''),
    1181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1181, CurrentID=0, Status='live', Symbol='CLCN2', Aliases=['CIC-2', 'CLC2', 'ECA2', 'ECA3', 'EGI11', 'EGI3', 'EGMA', 'EJM6', 'EJM8', 'HALD2', 'LKPAT', 'clC-2'], description='chloride voltage-gated channel 2', other_designations='chloride channel protein 2|chloride channel 2|chloride channel, voltage-sensitive 2', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184346185, end_position_on_the_genomic_accession=184361605, orientation='minus', exon_count=25, OMIM=[600570], no_hdr0=''),
    1182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1182, CurrentID=0, Status='live', Symbol='CLCN3', Aliases=['CLC3', 'ClC-3'], description='chloride voltage-gated channel 3', other_designations='H(+)/Cl(-) exchange transporter 3|chloride channel 3|chloride channel protein 3|chloride channel, voltage-sensitive 3|chloride transporter ClC-3', map_location='4q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=169620578, end_position_on_the_genomic_accession=169723673, orientation='plus', exon_count=16, OMIM=[600580], no_hdr0=''),
    1183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1183, CurrentID=0, Status='live', Symbol='CLCN4', Aliases=['CLC4', 'ClC-4', 'ClC-4A', 'MRX15', 'MRX49', 'MRXSRC'], description='chloride voltage-gated channel 4', other_designations='H(+)/Cl(-) exchange transporter 4|chloride channel 4|chloride channel protein 4|chloride channel, voltage-sensitive 4|chloride transporter ClC-4', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=10156975, end_position_on_the_genomic_accession=10237660, orientation='plus', exon_count=13, OMIM=[302910], no_hdr0=''),
    1184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1184, CurrentID=0, Status='live', Symbol='CLCN5', Aliases=['CLC5', 'CLCK2', 'ClC-5', 'DENT1', 'DENTS', 'NPHL1', 'NPHL2', 'XLRH', 'XRN', 'hCIC-K2'], description='chloride voltage-gated channel 5', other_designations='H(+)/Cl(-) exchange transporter 5|chloride channel, voltage-sensitive 5|chloride transporter ClC-5|voltage-gated chloride ion channel CLCN5', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49922596, end_position_on_the_genomic_accession=50099231, orientation='plus', exon_count=17, OMIM=[300008], no_hdr0=''),
    1185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1185, CurrentID=0, Status='live', Symbol='CLCN6', Aliases=['CLC-6', 'CONRIBA'], description='chloride voltage-gated channel 6', other_designations='chloride transport protein 6|chloride channel, voltage-sensitive 6', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11806191, end_position_on_the_genomic_accession=11843130, orientation='plus', exon_count=23, OMIM=[602726], no_hdr0=''),
    1186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1186, CurrentID=0, Status='live', Symbol='CLCN7', Aliases=['CLC-7', 'CLC7', 'HOD', 'OPTA2', 'OPTB4', 'PPP1R63'], description='chloride voltage-gated channel 7', other_designations='H(+)/Cl(-) exchange transporter 7|chloride channel 7 alpha subunit|chloride channel protein 7|chloride channel, voltage-sensitive 7|protein phosphatase 1, regulatory subunit 63', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1444935, end_position_on_the_genomic_accession=1475028, orientation='minus', exon_count=26, OMIM=[602727], no_hdr0=''),
    1187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1187, CurrentID=0, Status='live', Symbol='CLCNKA', Aliases=['CLCK1', 'ClC-K1', 'hClC-Ka'], description='chloride voltage-gated channel Ka', other_designations='chloride channel protein ClC-Ka|chloride channel Ka|chloride channel, kidney, A|chloride channel, voltage-sensitive Ka', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16022036, end_position_on_the_genomic_accession=16034050, orientation='plus', exon_count=20, OMIM=[602024], no_hdr0=''),
    1188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1188, CurrentID=0, Status='live', Symbol='CLCNKB', Aliases=['CLCKB', 'ClC-K2', 'ClC-Kb'], description='chloride voltage-gated channel Kb', other_designations='chloride channel protein ClC-Kb|chloride channel, kidney, B|chloride channel, voltage-sensitive Kb', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16043782, end_position_on_the_genomic_accession=16057326, orientation='plus', exon_count=20, OMIM=[602023], no_hdr0=''),
    1191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1191, CurrentID=0, Status='live', Symbol='CLU', Aliases=['AAG4', 'APO-J', 'APOJ', 'CLI1', 'CLU2', 'KUB1', 'NA1/NA2', 'SGP-2', 'SGP2', 'SP-40', 'TRPM-2', 'TRPM2', 'CLU'], description='clusterin', other_designations='clusterin|aging-associated protein 4|apolipoprotein J|complement cytolysis inhibitor|complement lysis inhibitor|complement-associated protein SP-40,40|epididymis secretory sperm binding protein|ku70-binding protein 1|sulfated glycoprotein 2|testosterone-repressed prostate message 2', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27596917, end_position_on_the_genomic_accession=27614700, orientation='minus', exon_count=11, OMIM=[185430], no_hdr0=''),
    1192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1192, CurrentID=0, Status='live', Symbol='CLIC1', Aliases=['CL1C1', 'CLCNL1', 'G6', 'NCC27'], description='chloride intracellular channel 1', other_designations='chloride intracellular channel protein 1|RNCC protein|chloride channel ABP|hRNCC|nuclear chloride ion channel 27|nuclear chloride ion channel protein|p64CLCP|regulatory nuclear chloride ion channel protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31730581, end_position_on_the_genomic_accession=31737318, orientation='minus', exon_count=8, OMIM=[602872], no_hdr0=''),
    1193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1193, CurrentID=0, Status='live', Symbol='CLIC2', Aliases=['CLCNL2b', 'MRXS32', 'XAP121', 'CLIC2'], description='chloride intracellular channel 2', other_designations='chloride intracellular channel protein 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155276211, end_position_on_the_genomic_accession=155334614, orientation='minus', exon_count=6, OMIM=[300138], no_hdr0=''),
    1195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1195, CurrentID=0, Status='live', Symbol='CLK1', Aliases=['CLK', 'CLK/STY', 'STY'], description='CDC like kinase 1', other_designations='dual specificity protein kinase CLK1|CDC28/CDC2-like kinase|protein tyrosine kinase STY', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200853009, end_position_on_the_genomic_accession=200864658, orientation='minus', exon_count=14, OMIM=[601951], no_hdr0=''),
    1196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1196, CurrentID=0, Status='live', Symbol='CLK2', Aliases=[], description='CDC like kinase 2', other_designations='dual specificity protein kinase CLK2|CLK kinase', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155262868, end_position_on_the_genomic_accession=155273504, orientation='minus', exon_count=13, OMIM=[602989], no_hdr0=''),
    1198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1198, CurrentID=0, Status='live', Symbol='CLK3', Aliases=['PHCLK3', 'PHCLK3/152'], description='CDC like kinase 3', other_designations='dual specificity protein kinase CLK3', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74608372, end_position_on_the_genomic_accession=74630201, orientation='plus', exon_count=14, OMIM=[602990], no_hdr0=''),
    1200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1200, CurrentID=0, Status='live', Symbol='TPP1', Aliases=['CLN2', 'GIG1', 'LPIC', 'SCAR7', 'TPP-1'], description='tripeptidyl peptidase 1', other_designations='tripeptidyl-peptidase 1|cell growth-inhibiting gene 1 protein|growth-inhibiting protein 1|lysosomal pepstatin insensitive protease|lysosomal pepstatin-insensitive carboxypeptidase|tripeptidyl aminopeptidase|tripeptidyl peptidase I', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6612768, end_position_on_the_genomic_accession=6619422, orientation='minus', exon_count=13, OMIM=[607998], no_hdr0=''),
    1201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1201, CurrentID=0, Status='live', Symbol='CLN3', Aliases=['BTN1', 'BTS', 'JNCL'], description='CLN3 lysosomal/endosomal transmembrane protein, battenin', other_designations='battenin|CLN3, battenin|batten disease protein|ceroid-lipofuscinosis, neuronal 3', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28466653, end_position_on_the_genomic_accession=28492082, orientation='minus', exon_count=16, OMIM=[607042], no_hdr0=''),
    1203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1203, CurrentID=0, Status='live', Symbol='CLN5', Aliases=[], description='CLN5 intracellular trafficking protein', other_designations='ceroid-lipofuscinosis neuronal protein 5|ceroid-lipofuscinosis, neuronal 5', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=76992081, end_position_on_the_genomic_accession=77005117, orientation='plus', exon_count=5, OMIM=[608102], no_hdr0=''),
    1207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1207, CurrentID=0, Status='live', Symbol='CLNS1A', Aliases=['CLCI', 'CLNS1B', 'ICln'], description='chloride nucleotide-sensitive channel 1A', other_designations='methylosome subunit pICln|chloride channel regulatory protein|chloride channel, nucleotide sensitive 1A|chloride conductance regulatory protein ICln|chloride ion current inducer protein|i(Cln)|reticulocyte pICln|reticulocyte protein ICln', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77614530, end_position_on_the_genomic_accession=77637794, orientation='minus', exon_count=8, OMIM=[602158], no_hdr0=''),
    1208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1208, CurrentID=0, Status='live', Symbol='CLPS', Aliases=[], description='colipase', other_designations='colipase|colipase, pancreatic|pancreatic colipase preproprotein', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35794982, end_position_on_the_genomic_accession=35797323, orientation='minus', exon_count=4, OMIM=[120105], no_hdr0=''),
    1209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1209, CurrentID=0, Status='live', Symbol='CLPTM1', Aliases=[], description='CLPTM1 regulator of GABA type A receptor forward trafficking', other_designations='cleft lip and palate transmembrane protein 1|CLPTM1, transmembrane protein|cleft lip and palate associated transmembrane protein 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44954585, end_position_on_the_genomic_accession=44993341, orientation='plus', exon_count=16, OMIM=[604783], no_hdr0=''),
    1211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1211, CurrentID=0, Status='live', Symbol='CLTA', Aliases=['LCA'], description='clathrin light chain A', other_designations='clathrin light chain A|clathrin, light polypeptide (Lca)', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36190855, end_position_on_the_genomic_accession=36212059, orientation='plus', exon_count=8, OMIM=[118960], no_hdr0=''),
    1212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1212, CurrentID=0, Status='live', Symbol='CLTB', Aliases=['LCB'], description='clathrin light chain B', other_designations='clathrin light chain B|clathrin, light chain (Lcb)|clathrin, light polypeptide (Lcb)', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176392455, end_position_on_the_genomic_accession=176416569, orientation='minus', exon_count=9, OMIM=[118970], no_hdr0=''),
    1213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1213, CurrentID=0, Status='live', Symbol='CLTC', Aliases=['CHC', 'CHC17', 'CLH-17L2', 'Hc', 'MRD56', 'CLTC'], description='clathrin heavy chain', other_designations='clathrin heavy chain 1|clathrin heavy chain on chromosome 17|clathrin, heavy polypeptide (Hc)|clathrin, heavy polypeptide-like 2', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59619895, end_position_on_the_genomic_accession=59696956, orientation='plus', exon_count=32, OMIM=[118955], no_hdr0=''),
    1215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1215, CurrentID=0, Status='live', Symbol='CMA1', Aliases=['CYH', 'MCT1', 'chymase'], description='chymase 1', other_designations='chymase|alpha-chymase|chymase 1 preproprotein transcript E|chymase 1 preproprotein transcript I|chymase 1, mast cell|chymase, heart|chymase, mast cell|mast cell protease I', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24505353, end_position_on_the_genomic_accession=24508265, orientation='minus', exon_count=5, OMIM=[118938], no_hdr0=''),
    1230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1230, CurrentID=0, Status='live', Symbol='CCR1', Aliases=['CD191', 'CKR-1', 'CKR1', 'CMKBR1', 'HM145', 'MIP1aR', 'SCYAR1'], description='C-C motif chemokine receptor 1', other_designations='C-C chemokine receptor type 1|C-C CKR-1|CC-CKR-1|CCR-1|LD78 receptor|MIP-1alpha-R|RANTES receptor|RANTES-R|chemokine (C-C motif) receptor 1|macrophage inflammatory protein 1-alpha receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46201711, end_position_on_the_genomic_accession=46208313, orientation='minus', exon_count=2, OMIM=[601159], no_hdr0=''),
    1232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1232, CurrentID=0, Status='live', Symbol='CCR3', Aliases=['C C CKR3', 'CC-CKR-3', 'CD193', 'CKR 3', 'CKR3', 'CMKBR3'], description='C-C motif chemokine receptor 3', other_designations='C-C chemokine receptor type 3|C-C CKR-3|CC chemokine receptor 3|CCR-3|b-chemokine receptor|chemokine (C-C motif) receptor 3|eosinophil CC chemokine receptor 3|eosinophil eotaxin receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46210699, end_position_on_the_genomic_accession=46266706, orientation='plus', exon_count=6, OMIM=[601268], no_hdr0=''),
    1233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1233, CurrentID=0, Status='live', Symbol='CCR4', Aliases=['CC-CKR-4', 'CD194', 'CKR4', 'CMKBR4', 'ChemR13', 'HGCN:14099', 'K5-5'], description='C-C motif chemokine receptor 4', other_designations='C-C chemokine receptor type 4|C-C CKR-4|CCR-4|chemokine (C-C motif) receptor 4|chemokine (C-C) receptor 4', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32951555, end_position_on_the_genomic_accession=32956349, orientation='plus', exon_count=2, OMIM=[604836], no_hdr0=''),
    1234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1234, CurrentID=0, Status='live', Symbol='CCR5', Aliases=['CC-CKR-5', 'CCCKR5', 'CCR-5', 'CD195', 'CKR-5', 'CKR5', 'CMKBR5', 'IDDM22'], description='C-C motif chemokine receptor 5', other_designations='C-C chemokine receptor type 5|C-C motif chemokine receptor 5 A159A|HIV-1 fusion coreceptor|chemokine (C-C motif) receptor 5|chemokine receptor CCR5|chemokine recptor CCR5 Delta32|chemr13', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46370142, end_position_on_the_genomic_accession=46376206, orientation='plus', exon_count=3, OMIM=[601373], no_hdr0=''),
    1235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1235, CurrentID=0, Status='live', Symbol='CCR6', Aliases=['BN-1', 'C-C CKR-6', 'CC-CKR-6', 'CCR-6', 'CD196', 'CKR-L3', 'CKRL3', 'CMKBR6', 'DCR2', 'DRY6', 'GPR29', 'GPRCY4', 'STRL22'], description='C-C motif chemokine receptor 6', other_designations='C-C chemokine receptor type 6|G protein-coupled receptor 29|LARC receptor|chemokine (C-C motif) receptor 6|chemokine (C-C) receptor 6|chemokine receptor-like 3|seven-transmembrane receptor, lymphocyte, 22', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167111795, end_position_on_the_genomic_accession=167139141, orientation='plus', exon_count=5, OMIM=[601835], no_hdr0=''),
    1236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1236, CurrentID=0, Status='live', Symbol='CCR7', Aliases=['BLR2', 'CC-CKR-7', 'CCR-7', 'CD197', 'CDw197', 'CMKBR7', 'EBI1'], description='C-C motif chemokine receptor 7', other_designations="C-C chemokine receptor type 7|Bukitt's lymphoma receptor 2|CC chemokine receptor 7|EBV-induced G protein-coupled receptor 1|Epstein-Barr virus induced gene 1|Epstein-Barr virus-induced G-protein coupled receptor 1|MIP-3 beta receptor|chemokine (C-C motif) receptor 7|lymphocyte-specific G protein-coupled peptide receptor", map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40553769, end_position_on_the_genomic_accession=40565472, orientation='minus', exon_count=5, OMIM=[600242], no_hdr0=''),
    1237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1237, CurrentID=0, Status='live', Symbol='CCR8', Aliases=['CC-CKR-8', 'CCR-8', 'CDw198', 'CKRL1', 'CMKBR8', 'CMKBRL2', 'CY6', 'GPRCY6', 'TER1'], description='C-C motif chemokine receptor 8', other_designations='C-C chemokine receptor type 8|CC chemokine receptor 8|CC chemokine receptor CHEMR1|CC-chemokine receptor chemr1|chemokine (C-C motif) receptor 8|chemokine (C-C) receptor 8|chemokine (C-C) receptor-like 2|chemokine receptor-like 1', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39329709, end_position_on_the_genomic_accession=39333680, orientation='plus', exon_count=2, OMIM=[601834], no_hdr0=''),
    1238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1238, CurrentID=0, Status='live', Symbol='ACKR2', Aliases=['CCBP2', 'CCR10', 'CCR9', 'CMKBR9', 'D6', 'hD6'], description='atypical chemokine receptor 2', other_designations='atypical chemokine receptor 2|C-C chemokine receptor D6|CC-chemokine-binding receptor JAB61|chemokine (C-C motif) receptor 9|chemokine (C-C) receptor 9|chemokine receptor CCR-10|chemokine receptor CCR-9|chemokine receptor D6|chemokine-binding protein 2|chemokine-binding protein D6', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42809445, end_position_on_the_genomic_accession=42867286, orientation='plus', exon_count=3, OMIM=[602648], no_hdr0=''),
    1240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1240, CurrentID=0, Status='live', Symbol='CMKLR1', Aliases=['CHEMERINR', 'ChemR23', 'DEZ', 'RVER1'], description='chemerin chemokine-like receptor 1', other_designations='chemokine-like receptor 1|G-protein coupled receptor ChemR23|G-protein coupled receptor DEZ|chemerin receptor|chemokine receptor-like 1|orphan G-protein coupled receptor, Dez|resolvin E1 receptor', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108288044, end_position_on_the_genomic_accession=108339347, orientation='minus', exon_count=5, OMIM=[602351], no_hdr0=''),
    1241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1241, CurrentID=0, Status='live', Symbol='LTB4R', Aliases=['BLT1', 'BLTR', 'CMKRL1', 'GPR161', 'LTBR1', 'P2RY7', 'P2Y7', 'LTB4R'], description='leukotriene B4 receptor', other_designations='leukotriene B4 receptor 1|G protein-coupled receptor 16|LTB4-R 1|LTB4-R1|P2Y purinoceptor 7|chemoattractant receptor-like 1|chemokine receptor-like 1|purinergic receptor P2Y, G-protein coupled, 7', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24311502, end_position_on_the_genomic_accession=24318036, orientation='plus', exon_count=3, OMIM=[601531], no_hdr0=''),
    1244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1244, CurrentID=0, Status='live', Symbol='ABCC2', Aliases=['ABC30', 'CMOAT', 'DJS', 'MRP2', 'cMRP'], description='ATP binding cassette subfamily C member 2', other_designations='ATP-binding cassette sub-family C member 2|ATP-binding cassette, sub-family C (CFTR/MRP), member 2|canalicular multidrug resistance protein|canalicular multispecific organic anion transporter 1|multidrug resistance-associated protein 2', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99782602, end_position_on_the_genomic_accession=99853741, orientation='plus', exon_count=34, OMIM=[601107], no_hdr0=''),
    1258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1258, CurrentID=0, Status='live', Symbol='CNGB1', Aliases=['CNCG2', 'CNCG3L', 'CNCG4', 'CNG4B', 'GAR1', 'GARP', 'GARP2', 'RCNC2', 'RCNCb', 'RCNCbeta', 'RP45', 'CNGB1'], description='cyclic nucleotide gated channel subunit beta 1', other_designations='cyclic nucleotide-gated cation channel beta-1|CNG channel beta-1|CNG-4|cyclic nucleotide gated channel beta 1|cyclic nucleotide-gated cation channel 4|cyclic nucleotide-gated cation channel gamma|cyclic nucleotide-gated cation channel modulatory subunit|glutamic-acid-rich protein', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57882340, end_position_on_the_genomic_accession=57971128, orientation='minus', exon_count=36, OMIM=[600724], no_hdr0=''),
    1259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1259, CurrentID=0, Status='live', Symbol='CNGA1', Aliases=['CNCG', 'CNCG1', 'CNG-1', 'CNG1', 'RCNC1', 'RCNCa', 'RCNCalpha', 'RP49'], description='cyclic nucleotide gated channel subunit alpha 1', other_designations='cGMP-gated cation channel alpha-1|CNG channel alpha-1|cyclic nucleotide gated channel alpha 1|cyclic nucleotide-gated cation channel 1|cyclic nucleotide-gated channel, photoreceptor|interleukin-1 homologue|rod photoreceptor cGMP-gated channel subunit alpha', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=47935015, end_position_on_the_genomic_accession=48016718, orientation='minus', exon_count=13, OMIM=[123825], no_hdr0=''),
    1260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1260, CurrentID=0, Status='live', Symbol='CNGA2', Aliases=['CNCA', 'CNCA1', 'CNG2', 'OCNC1', 'OCNCALPHA', 'OCNCa'], description='cyclic nucleotide gated channel subunit alpha 2', other_designations='cyclic nucleotide-gated olfactory channel|CNG channel alpha-2|cyclic nucleotide gated channel alpha 2|cyclic-nucleotide-gated cation channel 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151734746, end_position_on_the_genomic_accession=151745564, orientation='plus', exon_count=7, OMIM=[300338], no_hdr0=''),
    1261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1261, CurrentID=0, Status='live', Symbol='CNGA3', Aliases=['ACHM2', 'CCNC1', 'CCNCa', 'CCNCalpha', 'CNCG3', 'CNG3'], description='cyclic nucleotide gated channel subunit alpha 3', other_designations='cyclic nucleotide-gated cation channel alpha-3|CNG channel alpha-3|CNG-3|cone photoreceptor cGMP-gated channel alpha subunit|cone photoreceptor cGMP-gated channel subunit alpha|cyclic nucleotide gated channel alpha 3', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98346181, end_position_on_the_genomic_accession=98399154, orientation='plus', exon_count=9, OMIM=[600053], no_hdr0=''),
    1262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1262, CurrentID=0, Status='live', Symbol='CNGA4', Aliases=['CNCA2', 'CNG-4', 'CNG4', 'CNG5', 'CNGB2', 'OCNC2', 'OCNCBETA', 'OCNCb'], description='cyclic nucleotide gated channel subunit alpha 4', other_designations='cyclic nucleotide-gated cation channel alpha-4|CNG channel alpha-4|cyclic nucleotide gated channel alpha 4|cyclic nucleotide gated channel beta 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6234713, end_position_on_the_genomic_accession=6245924, orientation='plus', exon_count=7, OMIM=[609472], no_hdr0=''),
    1263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1263, CurrentID=0, Status='live', Symbol='PLK3', Aliases=['CNK', 'FNK', 'PLK-3', 'PRK'], description='polo like kinase 3', other_designations='serine/threonine-protein kinase PLK3|FGF-inducible kinase|cytokine-inducible serine/threonine-protein kinase|proliferation-related kinase', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44799952, end_position_on_the_genomic_accession=44805995, orientation='plus', exon_count=15, OMIM=[602913], no_hdr0=''),
    1264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1264, CurrentID=0, Status='live', Symbol='CNN1', Aliases=['HEL-S-14', 'SMCC', 'Sm-Calp'], description='calponin 1', other_designations='calponin-1|basic calponin|calponin 1, basic, smooth muscle|calponin H1, smooth muscle|calponins, basic|epididymis secretory protein Li 14', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11538775, end_position_on_the_genomic_accession=11550323, orientation='plus', exon_count=10, OMIM=[600806], no_hdr0=''),
    1265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1265, CurrentID=0, Status='live', Symbol='CNN2', Aliases=[], description='calponin 2', other_designations='calponin-2|calponin H2, smooth muscle|neutral calponin', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1026608, end_position_on_the_genomic_accession=1039065, orientation='plus', exon_count=7, OMIM=[602373], no_hdr0=''),
    1266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1266, CurrentID=0, Status='live', Symbol='CNN3', Aliases=[], description='calponin 3', other_designations='calponin-3|calponin 3, acidic|dJ639P13.2.2 (acidic calponin 3)', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94896957, end_position_on_the_genomic_accession=94927110, orientation='minus', exon_count=10, OMIM=[602374], no_hdr0=''),
    1267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1267, CurrentID=0, Status='live', Symbol='CNP', Aliases=['CNP1', 'HLD20'], description="2',3'-cyclic nucleotide 3' phosphodiesterase", other_designations="2',3'-cyclic-nucleotide 3'-phosphodiesterase|2', 3' cyclic nucleotide 3' phosphohydrolase|CNPase", map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41966795, end_position_on_the_genomic_accession=41977740, orientation='plus', exon_count=5, OMIM=[123830], no_hdr0=''),
    1268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1268, CurrentID=0, Status='live', Symbol='CNR1', Aliases=['CANN6', 'CB-R', 'CB1', 'CB1A', 'CB1K5', 'CB1R', 'CNR'], description='cannabinoid receptor 1', other_designations='cannabinoid receptor 1|cannabinoid receptor 1 (brain)|central cannabinoid receptor', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=88139864, end_position_on_the_genomic_accession=88167349, orientation='minus', exon_count=8, OMIM=[114610], no_hdr0=''),
    1269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1269, CurrentID=0, Status='live', Symbol='CNR2', Aliases=['CB-2', 'CB2', 'CX5'], description='cannabinoid receptor 2', other_designations='cannabinoid receptor 2|cannabinoid receptor 2 (macrophage)', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23870515, end_position_on_the_genomic_accession=23913362, orientation='minus', exon_count=6, OMIM=[605051], no_hdr0=''),
    1270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1270, CurrentID=0, Status='live', Symbol='CNTF', Aliases=['HCNTF'], description='ciliary neurotrophic factor', other_designations='ciliary neurotrophic factor|Ciliary Neuronotrophic Factor', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58622665, end_position_on_the_genomic_accession=58625733, orientation='plus', exon_count=2, OMIM=[118945], no_hdr0=''),
    1271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1271, CurrentID=0, Status='live', Symbol='CNTFR', Aliases=[], description='ciliary neurotrophic factor receptor', other_designations='ciliary neurotrophic factor receptor subunit alpha|CNTF receptor subunit alpha|CNTFR-alpha', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34551432, end_position_on_the_genomic_accession=34590386, orientation='minus', exon_count=14, OMIM=[118946], no_hdr0=''),
    1272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1272, CurrentID=0, Status='live', Symbol='CNTN1', Aliases=['F3', 'GP135', 'MYPCN'], description='contactin 1', other_designations='contactin-1|glycoprotein gP135|neural cell surface protein F3', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=40692429, end_position_on_the_genomic_accession=41072415, orientation='plus', exon_count=29, OMIM=[600016], no_hdr0=''),
    1277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1277, CurrentID=0, Status='live', Symbol='COL1A1', Aliases=['CAFYD', 'EDSARTH1', 'EDSC', 'OI1', 'OI2', 'OI3', 'OI4'], description='collagen type I alpha 1 chain', other_designations='collagen alpha-1(I) chain|alpha-1 type I collagen|alpha1(I) procollagen|collagen alpha 1 chain type I|collagen alpha-1(I) chain preproprotein|collagen of skin, tendon and bone, alpha-1 chain|collagen, type I, alpha 1|pro-alpha-1 collagen type 1|type I proalpha 1|type I procollagen alpha 1 chain', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50184096, end_position_on_the_genomic_accession=50201649, orientation='minus', exon_count=51, OMIM=[120150], no_hdr0=''),
    1278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1278, CurrentID=0, Status='live', Symbol='COL1A2', Aliases=['EDSARTH2', 'EDSCV', 'OI4'], description='collagen type I alpha 2 chain', other_designations='collagen alpha-2(I) chain|alpha 2 type I procollagen|alpha 2(I) procollagen|alpha 2(I)-collagen|alpha-2 type I collagen|collagen I, alpha-2 polypeptide|collagen of skin, tendon and bone, alpha-2 chain|collagen, type I, alpha 2|epididymis secretory sperm binding protein|type I procollagen', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=94394895, end_position_on_the_genomic_accession=94431227, orientation='plus', exon_count=52, OMIM=[120160], no_hdr0=''),
    1280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1280, CurrentID=0, Status='live', Symbol='COL2A1', Aliases=['ANFH', 'AOM', 'COL11A3', 'SEDC', 'STL1'], description='collagen type II alpha 1 chain', other_designations='collagen alpha-1(II) chain|alpha-1 type II collagen|arthroophthalmopathy, progressive (Stickler syndrome)|cartilage collagen|chondrocalcin|collagen II, alpha-1 polypeptide|collagen, type II, alpha 1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47972967, end_position_on_the_genomic_accession=48006212, orientation='minus', exon_count=57, OMIM=[120140], no_hdr0=''),
    1281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1281, CurrentID=0, Status='live', Symbol='COL3A1', Aliases=['EDS4A', 'EDSVASC', 'PMGEDSV'], description='collagen type III alpha 1 chain', other_designations='collagen alpha-1(III) chain|Ehlers-Danlos syndrome type IV, autosomal dominant|alpha-1 type III collagen|alpha1 (III) collagen|collagen, fetal|collagen, type III, alpha 1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=188974373, end_position_on_the_genomic_accession=189012746, orientation='plus', exon_count=51, OMIM=[120180], no_hdr0=''),
    1282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1282, CurrentID=0, Status='live', Symbol='COL4A1', Aliases=['BSVD', 'BSVD1s', 'PADMAL', 'RATOR', 'COL4A1'], description='collagen type IV alpha 1 chain', other_designations='collagen alpha-1(IV) chain|COL4A1 NC1 domain|arresten|collagen IV, alpha-1 polypeptide|collagen of basement membrane, alpha-1 chain', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110148963, end_position_on_the_genomic_accession=110307157, orientation='minus', exon_count=54, OMIM=[120130], no_hdr0=''),
    1284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1284, CurrentID=0, Status='live', Symbol='COL4A2', Aliases=['BSVD2', 'ICH', 'POREN2'], description='collagen type IV alpha 2 chain', other_designations='collagen alpha-2(IV) chain|canstatin', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110307284, end_position_on_the_genomic_accession=110513209, orientation='plus', exon_count=48, OMIM=[120090], no_hdr0=''),
    1285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1285, CurrentID=0, Status='live', Symbol='COL4A3', Aliases=['ATS2', 'ATS3'], description='collagen type IV alpha 3 chain', other_designations='collagen alpha-3(IV) chain|collagen IV, alpha-3 polypeptide|collagen, type IV, alpha 3 (Goodpasture antigen)|tumstatin', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227164589, end_position_on_the_genomic_accession=227314792, orientation='plus', exon_count=54, OMIM=[120070], no_hdr0=''),
    1286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1286, CurrentID=0, Status='live', Symbol='COL4A4', Aliases=['ATS2', 'BFH', 'CA44'], description='collagen type IV alpha 4 chain', other_designations='collagen alpha-4(IV) chain|Collagen IV, alpha-4 polypeptide|collagen of basement membrane, alpha-4 chain|collagen, type IV, alpha 4', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=226970293, end_position_on_the_genomic_accession=227164482, orientation='minus', exon_count=54, OMIM=[120131], no_hdr0=''),
    1287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1287, CurrentID=0, Status='live', Symbol='COL4A5', Aliases=['ASLN', 'ATS', 'ATS1', 'CA54'], description='collagen type IV alpha 5 chain', other_designations='collagen alpha-5(IV) chain|collagen IV, alpha-5 polypeptide|collagen of basement membrane, alpha-5 chain|collagen, type IV, alpha 5|dA149D17.3|dA24A23.1', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108439838, end_position_on_the_genomic_accession=108697545, orientation='plus', exon_count=58, OMIM=[303630], no_hdr0=''),
    1288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1288, CurrentID=0, Status='live', Symbol='COL4A6', Aliases=['CXDELq22.3', 'DELXq22.3', 'DFNX6'], description='collagen type IV alpha 6 chain', other_designations='collagen alpha-6(IV) chain|collagen IV, alpha-6 polypeptide|collagen of basement membrane, alpha-6|collagen, type IV, alpha 6|dJ889N15.4 (Collagen Alpha 6(IV))', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108155607, end_position_on_the_genomic_accession=108439493, orientation='minus', exon_count=50, OMIM=[303631], no_hdr0=''),
    1289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1289, CurrentID=0, Status='live', Symbol='COL5A1', Aliases=['EDSC', 'EDSCL1', 'FMDMF'], description='collagen type V alpha 1 chain', other_designations='collagen alpha-1(V) chain|collagen, type V, alpha 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134641789, end_position_on_the_genomic_accession=134844843, orientation='plus', exon_count=67, OMIM=[120215], no_hdr0=''),
    1290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1290, CurrentID=0, Status='live', Symbol='COL5A2', Aliases=['EDSC', 'EDSCL2'], description='collagen type V alpha 2 chain', other_designations='collagen alpha-2(V) chain|AB collagen|collagen, fetal membrane, A polypeptide|type V preprocollagen alpha 2 chain', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189031898, end_position_on_the_genomic_accession=189225301, orientation='minus', exon_count=55, OMIM=[120190], no_hdr0=''),
    1291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1291, CurrentID=0, Status='live', Symbol='COL6A1', Aliases=['BTHLM1', 'OPLL', 'UCHMD1'], description='collagen type VI alpha 1 chain', other_designations='collagen alpha-1(VI) chain|alpha 1 (VI) chain (61 AA)|collagen VI, alpha-1 polypeptide|collagen, type VI, alpha 1|epididymis secretory sperm binding protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45981770, end_position_on_the_genomic_accession=46005048, orientation='plus', exon_count=35, OMIM=[120220], no_hdr0=''),
    1292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1292, CurrentID=0, Status='live', Symbol='COL6A2', Aliases=['BTHLM1', 'PP3610', 'UCMD1'], description='collagen type VI alpha 2 chain', other_designations='collagen alpha-2(VI) chain|collagen VI, alpha-2 polypeptide|collagen, type VI, alpha 2|epididymis secretory sperm binding protein|human mRNA for collagen VI alpha-2 C-terminal globular domain', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46098071, end_position_on_the_genomic_accession=46132849, orientation='plus', exon_count=30, OMIM=[120240], no_hdr0=''),
    1293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1293, CurrentID=0, Status='live', Symbol='COL6A3', Aliases=['BTHLM1', 'DYT27', 'UCMD1'], description='collagen type VI alpha 3 chain', other_designations='collagen alpha-3(VI) chain|collagen VI, alpha-3 polypeptide|collagen, type VI, alpha 3|epididymis secretory sperm binding protein', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237324018, end_position_on_the_genomic_accession=237434822, orientation='minus', exon_count=50, OMIM=[120250], no_hdr0=''),
    1294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1294, CurrentID=0, Status='live', Symbol='COL7A1', Aliases=['EBD1', 'EBDCT', 'EBR1', 'NDNC8'], description='collagen type VII alpha 1 chain', other_designations='collagen alpha-1(VII) chain|LC collagen|collagen VII, alpha-1 polypeptide|collagen, type VII, alpha 1|long-chain collagen', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48564073, end_position_on_the_genomic_accession=48595329, orientation='minus', exon_count=120, OMIM=[120120], no_hdr0=''),
    1295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1295, CurrentID=0, Status='live', Symbol='COL8A1', Aliases=['C3orf7'], description='collagen type VIII alpha 1 chain', other_designations='collagen alpha-1(VIII) chain|cell proliferation-inducing protein 41|collagen VIII, alpha-1 polypeptide|collagen, type VIII, alpha 1|endothelial collagen|smag-64|smooth muscle cell-expressed and macrophage conditioned medium-induced protein smag-64', map_location='3q12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=99638594, end_position_on_the_genomic_accession=99799217, orientation='plus', exon_count=5, OMIM=[120251], no_hdr0=''),
    1296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1296, CurrentID=0, Status='live', Symbol='COL8A2', Aliases=['FECD', 'FECD1', 'PPCD', 'PPCD2'], description='collagen type VIII alpha 2 chain', other_designations='collagen alpha-2(VIII) chain|collagen VIII, alpha-2 polypeptide|collagen, type VIII, alpha 2|endothelial collagen', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36095239, end_position_on_the_genomic_accession=36126207, orientation='minus', exon_count=5, OMIM=[120252], no_hdr0=''),
    1297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1297, CurrentID=0, Status='live', Symbol='COL9A1', Aliases=['DJ149L1.1.2', 'EDM6', 'MED', 'STL4'], description='collagen type IX alpha 1 chain', other_designations='collagen alpha-1(IX) chain|alpha-1(IX) collagen chain|cartilage-specific short collagen|collagen IX, alpha-1 polypeptide|collagen, type IX, alpha 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=70215061, end_position_on_the_genomic_accession=70303084, orientation='minus', exon_count=43, OMIM=[120210], no_hdr0=''),
    1298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1298, CurrentID=0, Status='live', Symbol='COL9A2', Aliases=['DJ39G22.4', 'EDM2', 'MED', 'STL5'], description='collagen type IX alpha 2 chain', other_designations='collagen alpha-2(IX) chain|alpha 2 type IX collagen|collagen IX, alpha-2 polypeptide|collagen, type IX, alpha 2', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40300487, end_position_on_the_genomic_accession=40317653, orientation='minus', exon_count=35, OMIM=[120260], no_hdr0=''),
    1299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1299, CurrentID=0, Status='live', Symbol='COL9A3', Aliases=['DJ885L7.4.1', 'EDM3', 'IDD', 'MED'], description='collagen type IX alpha 3 chain', other_designations='collagen alpha-3(IX) chain|collagen IX, alpha-3 polypeptide|collagen type IX proteoglycan|collagen, type IX, alpha 3', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62817050, end_position_on_the_genomic_accession=62841159, orientation='plus', exon_count=33, OMIM=[120270], no_hdr0=''),
    1300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1300, CurrentID=0, Status='live', Symbol='COL10A1', Aliases=[], description='collagen type X alpha 1 chain', other_designations='collagen alpha-1(X) chain|Schmid metaphyseal chondrodysplasia|collagen X, alpha-1 polypeptide|collagen, type X, alpha 1', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116118909, end_position_on_the_genomic_accession=116219937, orientation='minus', exon_count=6, OMIM=[120110], no_hdr0=''),
    1301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1301, CurrentID=0, Status='live', Symbol='COL11A1', Aliases=['CO11A1', 'COLL6', 'DFNA37', 'STL2'], description='collagen type XI alpha 1 chain', other_designations='collagen alpha-1(XI) chain|collagen XI, alpha-1 polypeptide|collagen, type XI, alpha 1|deafness, autosomal dominant 37', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=102876473, end_position_on_the_genomic_accession=103108580, orientation='minus', exon_count=71, OMIM=[120280], no_hdr0=''),
    1302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1302, CurrentID=0, Status='live', Symbol='COL11A2', Aliases=['DFNA13', 'DFNB53', 'FBCG2', 'HKE5', 'OSMEDA', 'OSMEDB', 'PARP', 'STL3'], description='collagen type XI alpha 2 chain', other_designations='collagen alpha-2(XI) chain|collagen, type XI, alpha 2|pro-a2 chain of collagen type XI', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33162692, end_position_on_the_genomic_accession=33193009, orientation='minus', exon_count=70, OMIM=[120290], no_hdr0=''),
    1303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1303, CurrentID=0, Status='live', Symbol='COL12A1', Aliases=['BA209D8.1', 'BTHLM2L', 'DJ234P15.1', 'EDSMYP', 'UCMD2', 'COL12A1'], description='collagen type XII alpha 1 chain', other_designations='collagen alpha-1(XII) chain|collagen type XII proteoglycan|collagen, type XII, alpha 1', map_location='6q13-q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75084326, end_position_on_the_genomic_accession=75206262, orientation='minus', exon_count=67, OMIM=[120320], no_hdr0=''),
    1305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1305, CurrentID=0, Status='live', Symbol='COL13A1', Aliases=['CMS19', 'COLXIIIA1'], description='collagen type XIII alpha 1 chain', other_designations='collagen alpha-1(XIII) chain|collagen, type XIII, alpha 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69801835, end_position_on_the_genomic_accession=69959144, orientation='plus', exon_count=43, OMIM=[120350], no_hdr0=''),
    1306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1306, CurrentID=0, Status='live', Symbol='COL15A1', Aliases=[], description='collagen type XV alpha 1 chain', other_designations='collagen alpha-1(XV) chain|collagen XV, alpha-1 polypeptide|collagen type XV proteoglycan|collagen, type XV, alpha 1|endostatin-XV|restin', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98943392, end_position_on_the_genomic_accession=99070787, orientation='plus', exon_count=43, OMIM=[120325], no_hdr0=''),
    1307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1307, CurrentID=0, Status='live', Symbol='COL16A1', Aliases=['447AA', 'FP1572'], description='collagen type XVI alpha 1 chain', other_designations='collagen alpha-1(XVI) chain|alpha 1 type XVI collagen|collagen XVI, alpha-1 polypeptide|collagen, type XVI, alpha 1', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31652263, end_position_on_the_genomic_accession=31704162, orientation='minus', exon_count=74, OMIM=[120326], no_hdr0=''),
    1308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1308, CurrentID=0, Status='live', Symbol='COL17A1', Aliases=['BA16H23.2', 'BP180', 'BPA-2', 'BPAG2', 'ERED', 'LAD-1'], description='collagen type XVII alpha 1 chain', other_designations='collagen alpha-1(XVII) chain|180 kDa bullous pemphigoid antigen 2|alpha 1 type XVII collagen|bA16H23.2 (collagen, type XVII, alpha 1 (BP180))|bullous pemphigoid antigen 2 (180kD)|collagen XVII, alpha-1 polypeptide|collagen, type XVII, alpha 1|type XVII collagen alpha-1', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104031286, end_position_on_the_genomic_accession=104085880, orientation='minus', exon_count=56, OMIM=[113811], no_hdr0=''),
    1310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1310, CurrentID=0, Status='live', Symbol='COL19A1', Aliases=['COL9A1L', 'D6S228E'], description='collagen type XIX alpha 1 chain', other_designations='collagen alpha-1(XIX) chain|a1 chain of type XIX collagen|collagen XIX, alpha-1 polypeptide|collagen alpha 1 (Y) chain|collagen, type XIX, alpha 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=69866556, end_position_on_the_genomic_accession=70215063, orientation='plus', exon_count=55, OMIM=[120165], no_hdr0=''),
    1311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1311, CurrentID=0, Status='live', Symbol='COMP', Aliases=['CTS2', 'EDM1', 'EPD1', 'MED', 'PSACH', 'THBS5', 'TSP5'], description='cartilage oligomeric matrix protein', other_designations='cartilage oligomeric matrix protein|cartilage oligomeric matrix protein (pseudoachondroplasia, epiphyseal dysplasia 1, multiple)|pseudoachondroplasia (epiphyseal dysplasia 1, multiple)|thrombospondin-5', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18782773, end_position_on_the_genomic_accession=18791305, orientation='minus', exon_count=19, OMIM=[600310], no_hdr0=''),
    1312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1312, CurrentID=0, Status='live', Symbol='COMT', Aliases=['HEL-S-98n'], description='catechol-O-methyltransferase', other_designations='catechol O-methyltransferase|epididymis secretory sperm binding protein Li 98n|testicular tissue protein Li 42', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19941772, end_position_on_the_genomic_accession=19969975, orientation='plus', exon_count=8, OMIM=[116790], no_hdr0=''),
    1314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1314, CurrentID=0, Status='live', Symbol='COPA', Aliases=['AILJK', 'HEP-COP', 'alpha-COP'], description='COPI coat complex subunit alpha', other_designations='coatomer subunit alpha|alpha coat protein|coatomer protein complex subunit alpha|proxenin|xenin', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160288594, end_position_on_the_genomic_accession=160343250, orientation='minus', exon_count=33, OMIM=[601924], no_hdr0=''),
    1315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1315, CurrentID=0, Status='live', Symbol='COPB1', Aliases=['BARMACS', 'COPB'], description='COPI coat complex subunit beta 1', other_designations='coatomer subunit beta|beta coat protein|beta-cop|coatomer protein complex subunit beta 1', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14457512, end_position_on_the_genomic_accession=14499811, orientation='minus', exon_count=22, OMIM=[600959], no_hdr0=''),
    1316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1316, CurrentID=0, Status='live', Symbol='KLF6', Aliases=['BCD1', 'CBA1', 'COPEB', 'CPBP', 'GBF', 'PAC1', 'ST12', 'ZF9'], description='Kruppel like factor 6', other_designations='Krueppel-like factor 6|B-cell-derived protein 1|GC-rich binding factor|GC-rich sites-binding factor GBF|Kruppel-like zinc finger protein Zf9|core promoter element binding protein|proto-oncogene BCD1|protooncogene B-cell derived 1|suppression of tumorigenicity 12 (prostate)|suppressor of tumorigenicity 12 protein|transcription factor Zf9', map_location='10p15.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=3775996, end_position_on_the_genomic_accession=3785209, orientation='minus', exon_count=4, OMIM=[602053], no_hdr0=''),
    1317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1317, CurrentID=0, Status='live', Symbol='SLC31A1', Aliases=['COPT1', 'CTR1'], description='solute carrier family 31 member 1', other_designations='high affinity copper uptake protein 1|copper transport 1 homolog|copper transporter 1|solute carrier family 31 (copper transporter), member 1|solute carrier family 31 (copper transporters), member 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113221544, end_position_on_the_genomic_accession=113264492, orientation='plus', exon_count=5, OMIM=[603085], no_hdr0=''),
    1318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1318, CurrentID=0, Status='live', Symbol='SLC31A2', Aliases=['COPT2', 'CTR2', 'hCTR2'], description='solute carrier family 31 member 2', other_designations='probable low affinity copper uptake protein 2|copper transporter 2|solute carrier family 31 (copper transporter), member 2|solute carrier family 31 (copper transporters), member 2', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113151007, end_position_on_the_genomic_accession=113164140, orientation='plus', exon_count=4, OMIM=[603088], no_hdr0=''),
    1325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1325, CurrentID=0, Status='live', Symbol='CORT', Aliases=['CST-14', 'CST-17', 'CST-29', 'SST2'], description='cortistatin', other_designations='cortistatin|cortistatin-14|cortistatin-17|cortistatin-29|prepro-cortistatin|preprocortistatin|somatostatin 2', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10450031, end_position_on_the_genomic_accession=10451998, orientation='plus', exon_count=2, OMIM=[602784], no_hdr0=''),
    1326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1326, CurrentID=0, Status='live', Symbol='MAP3K8', Aliases=['AURA2', 'COT', 'EST', 'ESTF', 'MEKK8', 'TPL2', 'Tpl-2', 'c-COT'], description='mitogen-activated protein kinase kinase kinase 8', other_designations='mitogen-activated protein kinase kinase kinase 8|Ewing sarcoma transformant|augmented in rheumatoid arthritis 2|cot (cancer Osaka thyroid) oncogene|proto-oncogene c-Cot|proto-oncogene serine/threoine protein kinase|tumor progression locus 2', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=30434021, end_position_on_the_genomic_accession=30461833, orientation='plus', exon_count=12, OMIM=[191195], no_hdr0=''),
    1327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1327, CurrentID=0, Status='live', Symbol='COX4I1', Aliases=['COX IV-1', 'COX4', 'COX4-1', 'COXIV', 'COXIV-1', 'MC4DN16'], description='cytochrome c oxidase subunit 4I1', other_designations='cytochrome c oxidase subunit 4 isoform 1, mitochondrial|cytochrome c oxidase polypeptide IV|cytochrome c oxidase subunit IV', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85799695, end_position_on_the_genomic_accession=85807068, orientation='plus', exon_count=6, OMIM=[123864], no_hdr0=''),
    1329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1329, CurrentID=0, Status='live', Symbol='COX5B', Aliases=['COXVB'], description='cytochrome c oxidase subunit 5B', other_designations='cytochrome c oxidase subunit 5B, mitochondrial|cytochrome c oxidase polypeptide VB, mitochondrial|cytochrome c oxidase subunit Vb|epididymis secretory sperm binding protein', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97646062, end_position_on_the_genomic_accession=97648383, orientation='plus', exon_count=4, OMIM=[123866], no_hdr0=''),
    1337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1337, CurrentID=0, Status='live', Symbol='COX6A1', Aliases=['CMTRID', 'COX6A', 'COX6AL'], description='cytochrome c oxidase subunit 6A1', other_designations='cytochrome c oxidase subunit 6A1, mitochondrial|COX VIa-L|cytochrome C oxidase subunit VIa homolog|cytochrome c oxidase polypeptide VIa-liver|cytochrome c oxidase subunit VIA-liver|cytochrome c oxidase subunit VIa polypeptide 1', map_location='12q24.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120438113, end_position_on_the_genomic_accession=120440730, orientation='plus', exon_count=3, OMIM=[602072], no_hdr0=''),
    1339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1339, CurrentID=0, Status='live', Symbol='COX6A2', Aliases=['COX6AH', 'COXVIAH', 'MC4DN18'], description='cytochrome c oxidase subunit 6A2', other_designations='cytochrome c oxidase subunit 6A2, mitochondrial|COX VIa-M|cytochrome c oxidase polypeptide VIa-heart|cytochrome c oxidase subunit VIA-muscle|cytochrome c oxidase subunit VIa polypeptide 2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31427731, end_position_on_the_genomic_accession=31428360, orientation='minus', exon_count=3, OMIM=[602009], no_hdr0=''),
    1340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1340, CurrentID=0, Status='live', Symbol='COX6B1', Aliases=['COX6B', 'COXG', 'COXVIb1', 'MC4DN7'], description='cytochrome c oxidase subunit 6B1', other_designations='cytochrome c oxidase subunit 6B1|COX VIb-1|cytochrome c oxidase subunit VIb polypeptide 1 (ubiquitous)', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35648323, end_position_on_the_genomic_accession=35658782, orientation='plus', exon_count=4, OMIM=[124089], no_hdr0=''),
    1345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1345, CurrentID=0, Status='live', Symbol='COX6C', Aliases=[], description='cytochrome c oxidase subunit 6C', other_designations='cytochrome c oxidase subunit 6C|cytochrome c oxidase polypeptide VIc|cytochrome c oxidase subunit VIc preprotein|epididymis secretory sperm binding protein', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=99877865, end_position_on_the_genomic_accession=99893707, orientation='minus', exon_count=5, OMIM=[124090], no_hdr0=''),
    1346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1346, CurrentID=0, Status='live', Symbol='COX7A1', Aliases=['COX7A', 'COX7AH', 'COX7AM'], description='cytochrome c oxidase subunit 7A1', other_designations='cytochrome c oxidase subunit 7A1, mitochondrial|cytochrome c oxidase subunit VIIa polypeptide 1 (muscle)|cytochrome c oxidase subunit VIIa-H|cytochrome c oxidase subunit VIIa-M|cytochrome c oxidase subunit VIIa-heart|cytochrome c oxidase subunit VIIa-muscle', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36150922, end_position_on_the_genomic_accession=36152447, orientation='minus', exon_count=4, OMIM=[123995], no_hdr0=''),
    1347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1347, CurrentID=0, Status='live', Symbol='COX7A2', Aliases=['COX7AL', 'COX7AL1', 'COXVIIAL', 'COXVIIa-L', 'VIIAL'], description='cytochrome c oxidase subunit 7A2', other_designations='cytochrome c oxidase subunit 7A2, mitochondrial|cytochrome c oxidase polypeptide 7A2, mitochondrial|cytochrome c oxidase polypeptide VIIa-liver/heart|cytochrome c oxidase subunit VIIa polypeptide 2 (liver)|cytochrome c oxidase subunit VIIa-L|cytochrome c oxidase subunit VIIa-liver/heart|cytochrome c oxidase subunit VIIaL|hepatic cytochrome-c oxidase chain VIIa', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75237675, end_position_on_the_genomic_accession=75250298, orientation='minus', exon_count=6, OMIM=[123996], no_hdr0=''),
    1349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1349, CurrentID=0, Status='live', Symbol='COX7B', Aliases=['APLCC', 'LSDMCA2'], description='cytochrome c oxidase subunit 7B', other_designations='cytochrome c oxidase subunit 7B, mitochondrial|cytochrome c oxidase polypeptide VIIb|cytochrome c oxidase subunit VIIb|cytochrome-c oxidase chain VIIb', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77899468, end_position_on_the_genomic_accession=77907376, orientation='plus', exon_count=3, OMIM=[300885], no_hdr0=''),
    1350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1350, CurrentID=0, Status='live', Symbol='COX7C', Aliases=[], description='cytochrome c oxidase subunit 7C', other_designations='cytochrome c oxidase subunit 7C, mitochondrial|cytochrome c oxidase polypeptide VIIc|cytochrome c oxidase subunit VIIc|cytochrome-c oxidase chain VIIc', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=86617941, end_position_on_the_genomic_accession=86620962, orientation='plus', exon_count=3, OMIM=[603774], no_hdr0=''),
    1351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1351, CurrentID=0, Status='live', Symbol='COX8A', Aliases=['COX', 'COX8', 'COX8-2', 'COX8L', 'MC4DN15', 'VIII', 'VIII-L'], description='cytochrome c oxidase subunit 8A', other_designations='cytochrome c oxidase subunit 8A, mitochondrial|cytochrome c oxidase polypeptide VIII-liver/heart|cytochrome c oxidase subunit 8-2|cytochrome c oxidase subunit 8A (ubiquitous)|cytochrome c oxidase subunit VIII|cytochrome c oxidase subunit VIIIA (ubiquitous)', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63974620, end_position_on_the_genomic_accession=63976543, orientation='plus', exon_count=2, OMIM=[123870], no_hdr0=''),
    1352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1352, CurrentID=0, Status='live', Symbol='COX10', Aliases=['MC4DN3'], description='cytochrome c oxidase assembly factor heme A:farnesyltransferase COX10', other_designations='protoheme IX farnesyltransferase, mitochondrial|COX10 homolog, cytochrome c oxidase assembly protein, heme A: farnesyltransferase|COX10, heme A:farnesyltransferase cytochrome c oxidase assembly factor|cytochrome c oxidase assembly homolog 10|cytochrome c oxidase assembly protein|cytochrome c oxidase subunit X|heme A: farnesyltransferase|heme O synthase', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=14069504, end_position_on_the_genomic_accession=14208677, orientation='plus', exon_count=7, OMIM=[602125], no_hdr0=''),
    1353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1353, CurrentID=0, Status='live', Symbol='COX11', Aliases=['COX11P'], description='cytochrome c oxidase copper chaperone COX11', other_designations='cytochrome c oxidase assembly protein COX11, mitochondrial|COX11 homolog, cytochrome c oxidase assembly protein|COX11, cytochrome c oxidase copper chaperone|cytochrome c oxidase subunit 11', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=54951898, end_position_on_the_genomic_accession=54968785, orientation='minus', exon_count=6, OMIM=[603648], no_hdr0=''),
    1355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1355, CurrentID=0, Status='live', Symbol='COX15', Aliases=['CEMCOX2', 'MC4DN6'], description='cytochrome c oxidase assembly homolog COX15', other_designations='cytochrome c oxidase assembly protein COX15 homolog|COX15 homolog, cytochrome c oxidase assembly protein|COX15, cytochrome c oxidase assembly homolog|cytochrome c oxidase assembly homolog 15|cytochrome c oxidase subunit 15', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99694293, end_position_on_the_genomic_accession=99732131, orientation='minus', exon_count=10, OMIM=[603646], no_hdr0=''),
    1356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1356, CurrentID=0, Status='live', Symbol='CP', Aliases=['CP-2'], description='ceruloplasmin', other_designations='ceruloplasmin|ceruloplasmin (ferroxidase)', map_location='3q24-q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149162410, end_position_on_the_genomic_accession=149222008, orientation='minus', exon_count=22, OMIM=[117700], no_hdr0=''),
    1357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1357, CurrentID=0, Status='live', Symbol='CPA1', Aliases=['CPA'], description='carboxypeptidase A1', other_designations='carboxypeptidase A1|carboxypeptidase A1 (pancreatic)|pancreatic carboxypeptidase A', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130380494, end_position_on_the_genomic_accession=130388108, orientation='plus', exon_count=10, OMIM=[114850], no_hdr0=''),
    1358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1358, CurrentID=0, Status='live', Symbol='CPA2', Aliases=[], description='carboxypeptidase A2', other_designations='carboxypeptidase A2|carboxypeptidase A2 (pancreatic)', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130266863, end_position_on_the_genomic_accession=130289798, orientation='plus', exon_count=11, OMIM=[600688], no_hdr0=''),
    1359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1359, CurrentID=0, Status='live', Symbol='CPA3', Aliases=['MC-CPA'], description='carboxypeptidase A3', other_designations='mast cell carboxypeptidase A|carboxypeptidase A3 (mast cell)|tissue carboxypeptidase A', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=148865296, end_position_on_the_genomic_accession=148897203, orientation='plus', exon_count=11, OMIM=[114851], no_hdr0=''),
    1360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1360, CurrentID=0, Status='live', Symbol='CPB1', Aliases=['CPB', 'PASP', 'PCPB'], description='carboxypeptidase B1', other_designations='carboxypeptidase B|carboxypeptidase B1 (tissue)|pancreas-specific protein|pancreatic carboxypeptidase B|procarboxypeptidase B|protaminase|tissue carboxypeptidase B', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=148827811, end_position_on_the_genomic_accession=148860187, orientation='plus', exon_count=11, OMIM=[114852], no_hdr0=''),
    1361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1361, CurrentID=0, Status='live', Symbol='CPB2', Aliases=['CPU', 'PCPB', 'TAFI'], description='carboxypeptidase B2', other_designations='carboxypeptidase B2|carboxypeptidase B-like protein|carboxypeptidase B2 (plasma)|carboxypeptidase B2 (plasma, carboxypeptidase U)|carboxypeptidase R|thrombin-activable fibrinolysis inhibitor|thrombin-activatable fibrinolysis inhibitor', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46053066, end_position_on_the_genomic_accession=46105033, orientation='minus', exon_count=12, OMIM=[603101], no_hdr0=''),
    1362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1362, CurrentID=0, Status='live', Symbol='CPD', Aliases=['GP180'], description='carboxypeptidase D', other_designations='carboxypeptidase D|metallocarboxypeptidase D', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30378927, end_position_on_the_genomic_accession=30469989, orientation='plus', exon_count=22, OMIM=[603102], no_hdr0=''),
    1363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1363, CurrentID=0, Status='live', Symbol='CPE', Aliases=['CPH', 'IDDHH'], description='carboxypeptidase E', other_designations='carboxypeptidase E|carbocypeptidase E|carboxypeptidase H|cobalt-stimulated chromaffin granule carboxypeptidase|enkephalin convertase|epididymis secretory sperm binding protein|insulin granule-associated carboxypeptidase|prohormone-processing carboxypeptidase', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165379008, end_position_on_the_genomic_accession=165498547, orientation='plus', exon_count=9, OMIM=[114855], no_hdr0=''),
    1364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1364, CurrentID=0, Status='live', Symbol='CLDN4', Aliases=['CPE-R', 'CPER', 'CPETR', 'CPETR1', 'WBSCR8', 'hCPE-R'], description='claudin 4', other_designations='claudin-4|CPE-receptor|Clostridium perfringens enterotoxin receptor 1|Williams-Beuren syndrome chromosomal region 8 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73830996, end_position_on_the_genomic_accession=73832690, orientation='plus', exon_count=1, OMIM=[602909], no_hdr0=''),
    1365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1365, CurrentID=0, Status='live', Symbol='CLDN3', Aliases=['C7orf1', 'CPE-R2', 'CPETR2', 'HRVP1', 'RVP1'], description='claudin 3', other_designations='claudin-3|CPE-R 2|CPE-receptor 2|Clostridium perfringens enterotoxin receptor 2|ventral prostate.1 protein homolog|ventral prostate.1-like protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73768997, end_position_on_the_genomic_accession=73770270, orientation='minus', exon_count=1, OMIM=[602910], no_hdr0=''),
    1366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1366, CurrentID=0, Status='live', Symbol='CLDN7', Aliases=['CEPTRL2', 'CLDN-7', 'CPETRL2', 'Hs.84359', 'claudin-1'], description='claudin 7', other_designations='claudin-7|clostridium perfringens enterotoxin receptor-like 2|epididymis secretory sperm binding protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7259903, end_position_on_the_genomic_accession=7263213, orientation='minus', exon_count=5, OMIM=[609131], no_hdr0=''),
    1368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1368, CurrentID=0, Status='live', Symbol='CPM', Aliases=[], description='carboxypeptidase M', other_designations='carboxypeptidase M|renal carboxypeptidase|urinary carboxypeptidase B', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68842193, end_position_on_the_genomic_accession=68963469, orientation='minus', exon_count=11, OMIM=[114860], no_hdr0=''),
    1369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1369, CurrentID=0, Status='live', Symbol='CPN1', Aliases=['CPN', 'SCPN'], description='carboxypeptidase N subunit 1', other_designations='carboxypeptidase N catalytic chain|anaphylatoxin inactivator|arginine carboxypeptidase|carboxypeptidase K|carboxypeptidase N catalytic subunit|carboxypeptidase N polypeptide 1 50 kD|carboxypeptidase N small subunit|carboxypeptidase N, polypeptide 1|kininase I|kininase-1|lysine carboxypeptidase|plasma carboxypeptidase B|serum carboxypeptidase N', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100042193, end_position_on_the_genomic_accession=100081869, orientation='minus', exon_count=9, OMIM=[603103], no_hdr0=''),
    1370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1370, CurrentID=0, Status='live', Symbol='CPN2', Aliases=['ACBP'], description='carboxypeptidase N subunit 2', other_designations='carboxypeptidase N subunit 2|carboxypeptidase N 83 kDa chain|carboxypeptidase N large subunit|carboxypeptidase N regulatory subunit|carboxypeptidase N, polypeptide 2, 83kD', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194339765, end_position_on_the_genomic_accession=194351387, orientation='minus', exon_count=3, OMIM=[603104], no_hdr0=''),
    1371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1371, CurrentID=0, Status='live', Symbol='CPOX', Aliases=['COX', 'CPO', 'CPX', 'HARPO', 'HCP'], description='coproporphyrinogen oxidase', other_designations='oxygen-dependent coproporphyrinogen-III oxidase, mitochondrial|coprogen oxidase|coproporphyrinogenase|homozygous coproporphyria', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98569837, end_position_on_the_genomic_accession=98593684, orientation='minus', exon_count=10, OMIM=[612732], no_hdr0=''),
    1373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1373, CurrentID=0, Status='live', Symbol='CPS1', Aliases=['CPSASE1', 'GATD6', 'PHN'], description='carbamoyl-phosphate synthase 1', other_designations='carbamoyl-phosphate synthase [ammonia], mitochondrial|carbamoyl-phosphate synthase (ammonia)|carbamoyl-phosphate synthase 1, mitochondrial|carbamoylphosphate synthetase I', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210477685, end_position_on_the_genomic_accession=210679107, orientation='plus', exon_count=43, OMIM=[608307], no_hdr0=''),
    1374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1374, CurrentID=0, Status='live', Symbol='CPT1A', Aliases=['CPT1', 'CPT1-L', 'L-CPT1'], description='carnitine palmitoyltransferase 1A', other_designations='carnitine O-palmitoyltransferase 1, liver isoform|CPT I|CPTI-L|carnitine palmitoyltransferase 1A (liver)|carnitine palmitoyltransferase I, liver', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68754620, end_position_on_the_genomic_accession=68844410, orientation='minus', exon_count=22, OMIM=[600528], no_hdr0=''),
    1375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1375, CurrentID=0, Status='live', Symbol='CPT1B', Aliases=['CPT1-M', 'CPT1M', 'CPTI', 'CPTI-M', 'M-CPT1', 'MCCPT1', 'MCPT1'], description='carnitine palmitoyltransferase 1B', other_designations='carnitine O-palmitoyltransferase 1, muscle isoform|carnitine O-palmitoyltransferase 1B|carnitine palmitoyltransferase 1B (muscle)|carnitine palmitoyltransferase I-like protein', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50568861, end_position_on_the_genomic_accession=50578612, orientation='minus', exon_count=21, OMIM=[601987], no_hdr0=''),
    1376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1376, CurrentID=0, Status='live', Symbol='CPT2', Aliases=['CPT1', 'CPTASE', 'IIAE4'], description='carnitine palmitoyltransferase 2', other_designations='carnitine O-palmitoyltransferase 2, mitochondrial|CPT II|carnitine palmitoyltransferase II|testicular secretory protein Li 13', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53196824, end_position_on_the_genomic_accession=53214197, orientation='plus', exon_count=5, OMIM=[600650], no_hdr0=''),
    1378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1378, CurrentID=0, Status='live', Symbol='CR1', Aliases=['C3BR', 'C4BR', 'CD35', 'KN'], description='complement C3b/C4b receptor 1 (Knops blood group)', other_designations='complement receptor type 1|C3-binding protein|C3b/C4b receptor|CD35 antigen|Knops blood group antigen|complement component (3b/4b) receptor 1 (Knops blood group)|complement receptor 1', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207496157, end_position_on_the_genomic_accession=207641765, orientation='plus', exon_count=47, OMIM=[120620], no_hdr0=''),
    1379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1379, CurrentID=0, Status='live', Symbol='CR1L', Aliases=[], description='complement C3b/C4b receptor 1 like', other_designations='complement component receptor 1-like protein|complement C4b-binding protein CR-1-like protein|complement component (3b/4b) receptor 1-like', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207645133, end_position_on_the_genomic_accession=207723703, orientation='plus', exon_count=12, OMIM=[605886], no_hdr0=''),
    1380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1380, CurrentID=0, Status='live', Symbol='CR2', Aliases=['C3DR', 'CD21', 'CR', 'CVID7', 'SLEB9'], description='complement C3d receptor 2', other_designations='complement receptor type 2|EBV receptor|complement component (3d/Epstein Barr virus) receptor 2|complement component 3d receptor 2', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207454328, end_position_on_the_genomic_accession=207489892, orientation='plus', exon_count=21, OMIM=[120650], no_hdr0=''),
    1381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1381, CurrentID=0, Status='live', Symbol='CRABP1', Aliases=['CRABP', 'CRABP-I', 'CRABPI', 'RBP5'], description='cellular retinoic acid binding protein 1', other_designations='cellular retinoic acid-binding protein 1|cellular retinoic acid-binding protein I', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78340353, end_position_on_the_genomic_accession=78348225, orientation='plus', exon_count=4, OMIM=[180230], no_hdr0=''),
    1382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1382, CurrentID=0, Status='live', Symbol='CRABP2', Aliases=['CRABP-II', 'RBP6'], description='cellular retinoic acid binding protein 2', other_designations='cellular retinoic acid-binding protein 2|cellular retinoic acid-binding protein II', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156699606, end_position_on_the_genomic_accession=156705784, orientation='minus', exon_count=5, OMIM=[180231], no_hdr0=''),
    1384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1384, CurrentID=0, Status='live', Symbol='CRAT', Aliases=['CAT', 'CAT1', 'NBIA8'], description='carnitine O-acetyltransferase', other_designations='carnitine O-acetyltransferase|carnitine acetylase', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129094794, end_position_on_the_genomic_accession=129110793, orientation='minus', exon_count=18, OMIM=[600184], no_hdr0=''),
    1385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1385, CurrentID=0, Status='live', Symbol='CREB1', Aliases=['CREB', 'CREB-1'], description='cAMP responsive element binding protein 1', other_designations="cyclic AMP-responsive element-binding protein 1|active transcription factor CREB|cAMP-response element-binding protein-1|cyclic adenosine 3',5'-monophosphate response element binding protein|cyclic adenosine 3',5'-monophosphate response element-binding protein CREB|transactivator protein", map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207529943, end_position_on_the_genomic_accession=207605988, orientation='plus', exon_count=13, OMIM=[123810], no_hdr0=''),
    1386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1386, CurrentID=0, Status='live', Symbol='ATF2', Aliases=['CRE-BP1', 'CREB-2', 'CREB2', 'HB16', 'TREB7'], description='activating transcription factor 2', other_designations='cyclic AMP-dependent transcription factor ATF-2|activating transcription factor 2 splice variant ATF2-var2|cAMP response element-binding protein CRE-BP1|cAMP responsive element binding protein 2, formerly|cAMP-dependent transcription factor ATF-2|cyclic AMP-responsive element-binding protein 2|histone acetyltransferase ATF2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=175072259, end_position_on_the_genomic_accession=175168203, orientation='minus', exon_count=17, OMIM=[123811], no_hdr0=''),
    1387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1387, CurrentID=0, Status='live', Symbol='CREBBP', Aliases=['CBP', 'KAT3A', 'MKHK1', 'RSTS', 'RSTS1'], description='CREB binding protein', other_designations='CREB-binding protein|histone lysine acetyltransferase CREBBP|protein-lysine acetyltransferase CREBBP', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3725054, end_position_on_the_genomic_accession=3880727, orientation='minus', exon_count=33, OMIM=[600140], no_hdr0=''),
    1388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1388, CurrentID=0, Status='live', Symbol='ATF6B', Aliases=['CREB-RP', 'CREBL1', 'G13'], description='activating transcription factor 6 beta', other_designations='cyclic AMP-dependent transcription factor ATF-6 beta|Creb-related protein|cAMP response element-binding protein-related protein|cAMP-dependent transcription factor ATF-6 beta|cAMP-responsive element-binding protein-like 1|protein G13', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32115264, end_position_on_the_genomic_accession=32128246, orientation='minus', exon_count=18, OMIM=[600984], no_hdr0=''),
    1389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1389, CurrentID=0, Status='live', Symbol='CREBL2', Aliases=[], description='cAMP responsive element binding protein like 2', other_designations='cAMP-responsive element-binding protein-like 2|MHBs-binding protein 1', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12611876, end_position_on_the_genomic_accession=12645108, orientation='plus', exon_count=4, OMIM=[603476], no_hdr0=''),
    1390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1390, CurrentID=0, Status='live', Symbol='CREM', Aliases=['CREM-2', 'ICER', 'hCREM-2'], description='cAMP responsive element modulator', other_designations='cAMP-responsive element modulator|CREM 2alpha-b protein|CREM 2beta-a protein|cAMP response element modulator|inducible cAMP early repressor ICER', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=35126841, end_position_on_the_genomic_accession=35212958, orientation='plus', exon_count=18, OMIM=[123812], no_hdr0=''),
    1392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1392, CurrentID=0, Status='live', Symbol='CRH', Aliases=['CRF1', 'CRH'], description='corticotropin releasing hormone', other_designations='corticoliberin|corticotropin-releasing factor', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66176376, end_position_on_the_genomic_accession=66178464, orientation='minus', exon_count=2, OMIM=[122560], no_hdr0=''),
    1393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1393, CurrentID=0, Status='live', Symbol='CRHBP', Aliases=['CRF-BP', 'CRFBP'], description='corticotropin releasing hormone binding protein', other_designations='corticotropin-releasing factor-binding protein|CRF-binding protein|CRH-BP', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76952855, end_position_on_the_genomic_accession=76981143, orientation='plus', exon_count=9, OMIM=[122559], no_hdr0=''),
    1394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1394, CurrentID=0, Status='live', Symbol='CRHR1', Aliases=['CRF-R', 'CRF-R-1', 'CRF-R1', 'CRF1', 'CRFR-1', 'CRFR1', 'CRH-R-1', 'CRH-R1', 'CRHRL', 'CRHR1'], description='corticotropin releasing hormone receptor 1', other_designations='corticotropin-releasing factor receptor 1|corticotropin-releasing factor type 1 receptor|seven transmembrane helix receptor', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45784320, end_position_on_the_genomic_accession=45835828, orientation='plus', exon_count=14, OMIM=[122561], no_hdr0=''),
    1395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1395, CurrentID=0, Status='live', Symbol='CRHR2', Aliases=['CRF-RB', 'CRF2', 'CRFR2', 'HM-CRF'], description='corticotropin releasing hormone receptor 2', other_designations='corticotropin-releasing factor receptor 2|CRH receptor 2 variant B|CRH-R2', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30649406, end_position_on_the_genomic_accession=30700103, orientation='minus', exon_count=16, OMIM=[602034], no_hdr0=''),
    1396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1396, CurrentID=0, Status='live', Symbol='CRIP1', Aliases=['CRHP', 'CRIP', 'CRP-1', 'CRP1'], description='cysteine rich protein 1', other_designations='cysteine-rich protein 1|cysteine-rich heart protein|cysteine-rich intestinal protein|cysteine-rich protein 1 (intestinal)', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105486886, end_position_on_the_genomic_accession=105488947, orientation='plus', exon_count=6, OMIM=[123875], no_hdr0=''),
    1397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1397, CurrentID=0, Status='live', Symbol='CRIP2', Aliases=['CRIP', 'CRP2', 'ESP1'], description='cysteine rich protein 2', other_designations='cysteine-rich protein 2|Cysteine-rich intestinal protein|LIM domain protein ESP1/CRP2', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105472945, end_position_on_the_genomic_accession=105480170, orientation='plus', exon_count=10, OMIM=[601183], no_hdr0=''),
    1398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1398, CurrentID=0, Status='live', Symbol='CRK', Aliases=['CRKII', 'p38'], description='CRK proto-oncogene, adaptor protein', other_designations='adapter molecule crk|proto-oncogene c-Crk|v-crk avian sarcoma virus CT10 oncogene homolog|v-crk sarcoma virus CT10 oncogene-like protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1420693, end_position_on_the_genomic_accession=1456232, orientation='minus', exon_count=3, OMIM=[164762], no_hdr0=''),
    1399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1399, CurrentID=0, Status='live', Symbol='CRKL', Aliases=[], description='CRK like proto-oncogene, adaptor protein', other_designations='crk-like protein|v-crk avian sarcoma virus CT10 oncogene homolog-like', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20917407, end_position_on_the_genomic_accession=20953747, orientation='plus', exon_count=4, OMIM=[602007], no_hdr0=''),
    1400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1400, CurrentID=0, Status='live', Symbol='CRMP1', Aliases=['CRMP-1', 'DPYSL1', 'DRP-1', 'DRP1', 'ULIP-3'], description='collapsin response mediator protein 1', other_designations='dihydropyrimidinase-related protein 1|dihydropyrimidinase-like 1|inactive dihydropyrimidinase|unc-33-like phosphoprotein 3', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5820764, end_position_on_the_genomic_accession=5893086, orientation='minus', exon_count=17, OMIM=[602462], no_hdr0=''),
    1401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1401, CurrentID=0, Status='live', Symbol='CRP', Aliases=['PTX1'], description='C-reactive protein', other_designations='C-reactive protein|C-reactive protein, pentraxin-related|pentraxin 1', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159712289, end_position_on_the_genomic_accession=159714589, orientation='minus', exon_count=3, OMIM=[123260], no_hdr0=''),
    1404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1404, CurrentID=0, Status='live', Symbol='HAPLN1', Aliases=['CRT1', 'CRTL1'], description='hyaluronan and proteoglycan link protein 1', other_designations='hyaluronan and proteoglycan link protein 1|Cartilage link protein|cartilage-link protein|cartilage-linking protein 1|proteoglycan link protein', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=83637805, end_position_on_the_genomic_accession=83721210, orientation='minus', exon_count=8, OMIM=[115435], no_hdr0=''),
    1406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1406, CurrentID=0, Status='live', Symbol='CRX', Aliases=['CORD2', 'CRD', 'LCA7', 'OTX3'], description='cone-rod homeobox', other_designations='cone-rod homeobox protein|orthodenticle homeobox 3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47821937, end_position_on_the_genomic_accession=47843324, orientation='plus', exon_count=4, OMIM=[602225], no_hdr0=''),
    1407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1407, CurrentID=0, Status='live', Symbol='CRY1', Aliases=['DSPD', 'PHLL1'], description='cryptochrome circadian regulator 1', other_designations='cryptochrome-1|cryptochrome 1 (photolyase-like)|cryptochrome circadian clock 1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106991364, end_position_on_the_genomic_accession=107093872, orientation='minus', exon_count=14, OMIM=[601933], no_hdr0=''),
    1408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1408, CurrentID=0, Status='live', Symbol='CRY2', Aliases=['HCRY2', 'PHLL2'], description='cryptochrome circadian regulator 2', other_designations='cryptochrome-2|cryptochrome 2 (photolyase-like)|cryptochrome circadian clock 2|growth-inhibiting protein 37', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45847118, end_position_on_the_genomic_accession=45883244, orientation='plus', exon_count=13, OMIM=[603732], no_hdr0=''),
    1409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1409, CurrentID=0, Status='live', Symbol='CRYAA', Aliases=['CRYA1', 'CTRCT9', 'HSPB4'], description='crystallin alpha A', other_designations='alpha-crystallin A chain|crystallin, alpha-1|heat shock protein beta-4|human alphaA-crystallin (CRYA1)', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43169008, end_position_on_the_genomic_accession=43172810, orientation='plus', exon_count=4, OMIM=[123580], no_hdr0=''),
    1410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1410, CurrentID=0, Status='live', Symbol='CRYAB', Aliases=['CMD1II', 'CRYA2', 'CTPP2', 'CTRCT16', 'HEL-S-101', 'HSPB5', 'MFM2'], description='crystallin alpha B', other_designations='alpha-crystallin B chain|epididymis secretory protein Li 101|heat shock protein beta-5|heat-shock 20 kD like-protein|renal carcinoma antigen NY-REN-27|rosenthal fiber component', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111908564, end_position_on_the_genomic_accession=111923740, orientation='minus', exon_count=6, OMIM=[123590], no_hdr0=''),
    1411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1411, CurrentID=0, Status='live', Symbol='CRYBA1', Aliases=['CRYB1', 'CTRCT10'], description='crystallin beta A1', other_designations='beta-crystallin A3|beta crystallin A3 chain transcript CN|beta crystallin A3 chain transcript LAM|beta crystallin A3 chain transcript PS|beta crystallin A3 chain transcript TC|crystallin beta A3/A1|crystallin, beta A3|eye lens structural protein|truncated beta crystallin A3/A1 chain|truncated beta-crystallin A3', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29246859, end_position_on_the_genomic_accession=29254494, orientation='plus', exon_count=7, OMIM=[123610], no_hdr0=''),
    1412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1412, CurrentID=0, Status='live', Symbol='CRYBA2', Aliases=['CTRCT42'], description='crystallin beta A2', other_designations='beta-crystallin A2|eye lens structural protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218990190, end_position_on_the_genomic_accession=218993422, orientation='minus', exon_count=5, OMIM=[600836], no_hdr0=''),
    1413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1413, CurrentID=0, Status='live', Symbol='CRYBA4', Aliases=['CTRCT23', 'CYRBA4', 'MCOPCT4'], description='crystallin beta A4', other_designations='beta-crystallin A4|beta crystallin A4 chain transcript PS|beta crystallin alpha 4 chain|beta-A4 crystallin|crystallin, beta polypeptide A4|eye lens structural protein', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26607982, end_position_on_the_genomic_accession=26630672, orientation='plus', exon_count=7, OMIM=[123631], no_hdr0=''),
    1414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1414, CurrentID=0, Status='live', Symbol='CRYBB1', Aliases=['CATCN3', 'CTRCT17'], description='crystallin beta B1', other_designations='beta-crystallin B1|beta-B1 crystallin|eye lens structural protein', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26599278, end_position_on_the_genomic_accession=26618104, orientation='minus', exon_count=6, OMIM=[600929], no_hdr0=''),
    1415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1415, CurrentID=0, Status='live', Symbol='CRYBB2', Aliases=['CCA2', 'CRYB2', 'CRYB2A', 'CTRCT3', 'D22S665'], description='crystallin beta B2', other_designations='beta-crystallin B2|CTA-221G9.7|beta-B2 crystallin|beta-crystallin Bp|eye lens structural protein', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=25211660, end_position_on_the_genomic_accession=25231869, orientation='plus', exon_count=7, OMIM=[123620], no_hdr0=''),
    1417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1417, CurrentID=0, Status='live', Symbol='CRYBB3', Aliases=['CATCN2', 'CRYB3', 'CTRCT22'], description='crystallin beta B3', other_designations='beta-crystallin B3|eye lens structural protein', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=25194244, end_position_on_the_genomic_accession=25207617, orientation='plus', exon_count=6, OMIM=[123630], no_hdr0=''),
    1418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1418, CurrentID=0, Status='live', Symbol='CRYGA', Aliases=['CRY-g-A', 'CRYG1', 'CRYG5'], description='crystallin gamma A', other_designations='gamma-crystallin A|crystallin, gamma 1|gamma-crystallin 5', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208160740, end_position_on_the_genomic_accession=208163589, orientation='minus', exon_count=3, OMIM=[123660], no_hdr0=''),
    1419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1419, CurrentID=0, Status='live', Symbol='CRYGB', Aliases=['CRYG2', 'CTRCT39'], description='crystallin gamma B', other_designations='gamma-crystallin B|crystallin, gamma 1-2', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208142573, end_position_on_the_genomic_accession=208146327, orientation='minus', exon_count=3, OMIM=[123670], no_hdr0=''),
    1420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1420, CurrentID=0, Status='live', Symbol='CRYGC', Aliases=['CCL', 'CRYG3', 'CTRCT2'], description='crystallin gamma C', other_designations='gamma-crystallin C|gamma-crystallin 2-1|gamma-crystallin 3', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208128137, end_position_on_the_genomic_accession=208139100, orientation='minus', exon_count=4, OMIM=[123680], no_hdr0=''),
    1421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1421, CurrentID=0, Status='live', Symbol='CRYGD', Aliases=['CACA', 'CCA3', 'CCP', 'CRYG4', 'CTRCT4', 'PCC', 'cry-g-D'], description='crystallin gamma D', other_designations='gamma-crystallin D|gamma crystallin 4|gamma-D-crystallin', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208121607, end_position_on_the_genomic_accession=208124524, orientation='minus', exon_count=3, OMIM=[123690], no_hdr0=''),
    1427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1427, CurrentID=0, Status='live', Symbol='CRYGS', Aliases=['CRYG8', 'CTRCT20'], description='crystallin gamma S', other_designations='gamma-crystallin S|beta-crystallin S|crystallin, gamma 8', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186538443, end_position_on_the_genomic_accession=186544380, orientation='minus', exon_count=3, OMIM=[123730], no_hdr0=''),
    1428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1428, CurrentID=0, Status='live', Symbol='CRYM', Aliases=['DFNA40', 'THBP'], description='crystallin mu', other_designations='ketimine reductase mu-crystallin|NADP-regulated thyroid-hormone binding protein|mu-crystallin homolog|thiomorpholine-carboxylate dehydrogenase', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21258521, end_position_on_the_genomic_accession=21303062, orientation='minus', exon_count=10, OMIM=[123740], no_hdr0=''),
    1429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1429, CurrentID=0, Status='live', Symbol='CRYZ', Aliases=[], description='crystallin zeta', other_designations='quinone oxidoreductase|NADPH:quinone reductase|crystallin, zeta (quinone reductase)|epididymis secretory sperm binding protein', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74705470, end_position_on_the_genomic_accession=74733115, orientation='minus', exon_count=11, OMIM=[123691], no_hdr0=''),
    1431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1431, CurrentID=0, Status='live', Symbol='CS', Aliases=[], description='citrate synthase', other_designations='citrate synthase, mitochondrial|citrate (Si)-synthase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56271699, end_position_on_the_genomic_accession=56300330, orientation='minus', exon_count=11, OMIM=[118950], no_hdr0=''),
    1432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1432, CurrentID=0, Status='live', Symbol='MAPK14', Aliases=['CSBP', 'CSBP1', 'CSBP2', 'CSPB1', 'EXIP', 'Mxi2', 'PRKM14', 'PRKM15', 'RK', 'SAPK2A', 'p38', 'p38ALPHA'], description='mitogen-activated protein kinase 14', other_designations='mitogen-activated protein kinase 14|CSAID-binding protein|MAP kinase 14|MAP kinase Mxi2|MAP kinase p38 alpha|MAX-interacting protein 2|cytokine suppressive anti-inflammatory drug binding protein|mitogen-activated protein kinase p38 alpha|p38 MAP kinase|p38 mitogen activated protein kinase|p38alpha Exip|stress-activated protein kinase 2A', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36027711, end_position_on_the_genomic_accession=36122964, orientation='plus', exon_count=22, OMIM=[600289], no_hdr0=''),
    1434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1434, CurrentID=0, Status='live', Symbol='CSE1L', Aliases=['CAS', 'CSE1', 'XPO2'], description='chromosome segregation 1 like', other_designations='exportin-2|CSE1 chromosome segregation 1-like|cellular apoptosis susceptibility protein|chromosome segregation 1-like protein|epididymis secretory sperm binding protein|exp2|importin-alpha re-exporter', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49046312, end_position_on_the_genomic_accession=49096949, orientation='plus', exon_count=25, OMIM=[601342], no_hdr0=''),
    1435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1435, CurrentID=0, Status='live', Symbol='CSF1', Aliases=['CSF-1', 'MCSF'], description='colony stimulating factor 1', other_designations='macrophage colony-stimulating factor 1|colony stimulating factor 1 (macrophage)|lanimostim|macrophage colony stimulating factor 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109910506, end_position_on_the_genomic_accession=109930992, orientation='plus', exon_count=11, OMIM=[120420], no_hdr0=''),
    1436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1436, CurrentID=0, Status='live', Symbol='CSF1R', Aliases=['BANDDOS', 'C-FMS', 'CD115', 'CSF-1R', 'CSFR', 'FIM2', 'FMS', 'HDLS', 'M-CSF-R'], description='colony stimulating factor 1 receptor', other_designations='macrophage colony-stimulating factor 1 receptor|CD115 antigen|CSF-1 receptor|FMS proto-oncogene|McDonough feline sarcoma viral (v-fms) oncogene homolog|macrophage colony stimulating factor I receptor|proto-oncogene c-Fms', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150053295, end_position_on_the_genomic_accession=150113365, orientation='minus', exon_count=24, OMIM=[164770], no_hdr0=''),
    1437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1437, CurrentID=0, Status='live', Symbol='CSF2', Aliases=['CSF', 'GMCSF'], description='colony stimulating factor 2', other_designations='granulocyte-macrophage colony-stimulating factor|colony stimulating factor 2 (granulocyte-macrophage)|granulocyte macrophage-colony stimulating factor|molgramostim|molgramostin|sargramostim', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132073789, end_position_on_the_genomic_accession=132076170, orientation='plus', exon_count=4, OMIM=[138960], no_hdr0=''),
    1438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1438, CurrentID=0, Status='live', Symbol='CSF2RA', Aliases=['CD116', 'CDw116', 'CSF2RX', 'CSF2RAY', 'CSF2RX', 'CSF2RY', 'GM-CSF-R-alpha', 'GMCSFR', 'GMCSFR-alpha', 'GMR', 'GMR-alpha', 'SMDP4', 'alphaGMR', 'CSF2RA'], description='colony stimulating factor 2 receptor subunit alpha', other_designations='granulocyte-macrophage colony-stimulating factor receptor subunit alpha|CD116 antigen|GM-CSF receptor alpha subunit|alpha-GM-CSF receptor|colony stimulating factor 2 receptor alpha subunit|colony stimulating factor 2 receptor, alpha, low-affinity (granulocyte-macrophage)|granulocyte-macrophage colony-stimulating factor receptor alpha chain', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1268814, end_position_on_the_genomic_accession=1325218, orientation='plus', exon_count=22, OMIM=[306250, 425000], no_hdr0=''),
    1439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1439, CurrentID=0, Status='live', Symbol='CSF2RB', Aliases=['CD131', 'CDw131', 'IL3RB', 'IL5RB', 'SMDP5', 'betaGMR'], description='colony stimulating factor 2 receptor subunit beta', other_designations='cytokine receptor common subunit beta|GM-CSF/IL-3/IL-5 receptor common beta subunit|GM-CSF/IL-3/IL-5 receptor common beta-chain|beta common cytokine receptor|beta-GM-CSF receptor|colony stimulating factor 2 receptor beta common subunit|colony stimulating factor 2 receptor, beta, low-affinity (granulocyte-macrophage)|colony-stimulating factor-2 receptor, beta, low-affinity|interleukin 3 receptor/granulocyte-macrophage colony stimulating factor 3 receptor, beta (high affinity)', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36913574, end_position_on_the_genomic_accession=36940449, orientation='plus', exon_count=14, OMIM=[138981], no_hdr0=''),
    1440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1440, CurrentID=0, Status='live', Symbol='CSF3', Aliases=['C17orf33OS', 'GCSF', 'CSF3'], description='colony stimulating factor 3', other_designations='granulocyte colony-stimulating factor|filgrastim|granulocyte-colony stimulating factor|lenograstim|pluripoietin', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40015440, end_position_on_the_genomic_accession=40017813, orientation='plus', exon_count=4, OMIM=[138970], no_hdr0=''),
    1441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1441, CurrentID=0, Status='live', Symbol='CSF3R', Aliases=['CD114', 'GCSFR', 'SCN7'], description='colony stimulating factor 3 receptor', other_designations='granulocyte colony-stimulating factor receptor|CD114 antigen|G-CSF receptor|G-CSF-R|colony stimulating factor 3 receptor (granulocyte)', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36466043, end_position_on_the_genomic_accession=36483314, orientation='minus', exon_count=19, OMIM=[138971], no_hdr0=''),
    1442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1442, CurrentID=0, Status='live', Symbol='CSH1', Aliases=['CS-1', 'CSA', 'CSMT', 'GHB3', 'PL', 'hCS-1', 'hCS-A'], description='chorionic somatomammotropin hormone 1', other_designations='chorionic somatomammotropin hormone 1|Chorionic somatomammotropin hormone 2|choriomammotropin|chorionic somatomammotropin A|chorionic somatomammotropin-1|growth hormone B3|placental lactogen', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63894918, end_position_on_the_genomic_accession=63896574, orientation='minus', exon_count=5, OMIM=[150200], no_hdr0=''),
    1443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1443, CurrentID=0, Status='live', Symbol='CSH2', Aliases=['CS-2', 'CSB', 'GHB1', 'PL', 'hCS-B'], description='chorionic somatomammotropin hormone 2', other_designations='chorionic somatomammotropin hormone 2|choriomammotropin|chorionic somatomammotropin B|growth hormone B1|lactogen|placental lactogen', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63872012, end_position_on_the_genomic_accession=63873729, orientation='minus', exon_count=4, OMIM=[118820], no_hdr0=''),
    1444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1444, CurrentID=0, Status='live', Symbol='CSHL1', Aliases=['CS-5', 'CSHP1', 'CSL', 'GHB4', 'hCS-L'], description='chorionic somatomammotropin hormone like 1', other_designations='chorionic somatomammotropin hormone-like 1|chorionic somatomammotropin CS-5|epididymis secretory sperm binding protein|growth hormone B4|growth hormone cluster', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63909602, end_position_on_the_genomic_accession=63911280, orientation='minus', exon_count=4, OMIM=[603515], no_hdr0=''),
    1445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1445, CurrentID=0, Status='live', Symbol='CSK', Aliases=[], description='C-terminal Src kinase', other_designations='tyrosine-protein kinase CSK|C-Src kinase|CSK, non-receptor tyrosine kinase|c-src tyrosine kinase|protein-tyrosine kinase CYL', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74782080, end_position_on_the_genomic_accession=74803197, orientation='plus', exon_count=17, OMIM=[124095], no_hdr0=''),
    1446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1446, CurrentID=0, Status='live', Symbol='CSN1S1', Aliases=['CASA', 'CSN1'], description='casein alpha s1', other_designations='alpha-S1-casein|casein, alpha', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69931062, end_position_on_the_genomic_accession=69946574, orientation='plus', exon_count=16, OMIM=[115450], no_hdr0=''),
    1447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1447, CurrentID=0, Status='live', Symbol='CSN2', Aliases=['CASB', 'PDC213'], description='casein beta', other_designations='beta-casein', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69955256, end_position_on_the_genomic_accession=69965728, orientation='minus', exon_count=8, OMIM=[115460], no_hdr0=''),
    1448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1448, CurrentID=0, Status='live', Symbol='CSN3', Aliases=['CNS10', 'CSN10', 'CSNK', 'KCA'], description='casein kappa', other_designations='kappa-casein', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70238381, end_position_on_the_genomic_accession=70251432, orientation='plus', exon_count=6, OMIM=[601695], no_hdr0=''),
    1452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1452, CurrentID=0, Status='live', Symbol='CSNK1A1', Aliases=['CK1', 'CK1a', 'CKIa', 'HEL-S-77p', 'HLCDGP1', 'PRO2975'], description='casein kinase 1 alpha 1', other_designations='casein kinase I isoform alpha|CKI-alpha|clock regulator kinase|down-regulated in lung cancer|epididymis secretory sperm binding protein Li 77p', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149492982, end_position_on_the_genomic_accession=149551439, orientation='minus', exon_count=11, OMIM=[600505], no_hdr0=''),
    1453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1453, CurrentID=0, Status='live', Symbol='CSNK1D', Aliases=['ASPS', 'CKI-delta', 'CKId', 'CKIdelta', 'FASPS2', 'HCKID'], description='casein kinase 1 delta', other_designations='casein kinase I isoform delta|casein kinase I|tau-protein kinase CSNK1D', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82239019, end_position_on_the_genomic_accession=82273750, orientation='minus', exon_count=13, OMIM=[600864], no_hdr0=''),
    1454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1454, CurrentID=0, Status='live', Symbol='CSNK1E', Aliases=['CKIe', 'CKIepsilon', 'HCKIE'], description='casein kinase 1 epsilon', other_designations='casein kinase I isoform epsilon', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38290691, end_position_on_the_genomic_accession=38318084, orientation='minus', exon_count=12, OMIM=[600863], no_hdr0=''),
    1455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1455, CurrentID=0, Status='live', Symbol='CSNK1G2', Aliases=['CK1g2'], description='casein kinase 1 gamma 2', other_designations='casein kinase I isoform gamma-2|casein kinase I|CKI-gamma 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1941149, end_position_on_the_genomic_accession=1981338, orientation='plus', exon_count=14, OMIM=[602214], no_hdr0=''),
    1456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1456, CurrentID=0, Status='live', Symbol='CSNK1G3', Aliases=['CKI-gamma 3L', 'CSNK1G3'], description='casein kinase 1 gamma 3', other_designations='casein kinase I isoform gamma-3|casein kinase I', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=123512116, end_position_on_the_genomic_accession=123617049, orientation='plus', exon_count=18, OMIM=[604253], no_hdr0=''),
    1457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1457, CurrentID=0, Status='live', Symbol='CSNK2A1', Aliases=['CK2A1', 'CKII', 'Cka1', 'Cka2', 'OCNDS'], description='casein kinase 2 alpha 1', other_designations='casein kinase II subunit alpha|CK2 catalytic subunit alpha|casein kinase 2, alpha 1 polypeptide|casein kinase II alpha 1 polypeptide pseudogene|casein kinase II alpha 1 subunit|protein kinase CK2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=472498, end_position_on_the_genomic_accession=543790, orientation='minus', exon_count=14, OMIM=[115440], no_hdr0=''),
    1459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1459, CurrentID=0, Status='live', Symbol='CSNK2A2', Aliases=['CK2A2', "CK2alpha'", 'CSNK2A1'], description='casein kinase 2 alpha 2', other_designations="casein kinase II subunit alpha'|CK II alpha'|casein kinase 2 alpha'|casein kinase 2, alpha prime polypeptide", map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58157907, end_position_on_the_genomic_accession=58198106, orientation='minus', exon_count=13, OMIM=[115442], no_hdr0=''),
    1460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1460, CurrentID=0, Status='live', Symbol='CSNK2B', Aliases=['CK2B', 'CK2N', 'CSK2B', 'Ckb1', 'Ckb2', 'G5A', 'POBINDS'], description='casein kinase 2 beta', other_designations='casein kinase II subunit beta|CK II beta|CSNK2B-LY6G5B-1072|CSNK2B-LY6G5B-1103|CSNK2B-LY6G5B-532|CSNK2B-LY6G5B-560|CSNK2B-LY6G5B-562|Casein kinase II beta subunit|alternative name: G5a, phosvitin|casein kinase 2, beta polypeptide|phosvitin|protein G5a', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31666080, end_position_on_the_genomic_accession=31670067, orientation='plus', exon_count=7, OMIM=[115441], no_hdr0=''),
    1462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1462, CurrentID=0, Status='live', Symbol='VCAN', Aliases=['CSPG2', 'ERVR', 'GHAP', 'PG-M', 'WGN', 'WGN1'], description='versican', other_designations='versican core protein|chondroitin sulfate proteoglycan core protein 2|glial hyaluronate-binding protein|large fibroblast proteoglycan|versican proteoglycan', map_location='5q14.2-q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=83471744, end_position_on_the_genomic_accession=83582302, orientation='plus', exon_count=15, OMIM=[118661], no_hdr0=''),
    1463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1463, CurrentID=0, Status='live', Symbol='NCAN', Aliases=['CSPG3'], description='neurocan', other_designations='neurocan core protein|chondroitin sulfate proteoglycan 3 (neurocan)|neurocan proteoglycan', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19211958, end_position_on_the_genomic_accession=19252233, orientation='plus', exon_count=15, OMIM=[600826], no_hdr0=''),
    1464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1464, CurrentID=0, Status='live', Symbol='CSPG4', Aliases=['CSPG4A', 'HMW-MAA', 'MCSP', 'MCSPG', 'MEL-CSPG', 'MSK16', 'NG2'], description='chondroitin sulfate proteoglycan 4', other_designations='chondroitin sulfate proteoglycan 4|chondroitin sulfate proteoglycan 4 (melanoma-associated)|chondroitin sulfate proteoglycan NG2|melanoma chondroitin sulfate proteoglycan|melanoma-associated chondroitin sulfate proteoglycan', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75674322, end_position_on_the_genomic_accession=75712848, orientation='minus', exon_count=10, OMIM=[601172], no_hdr0=''),
    1465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1465, CurrentID=0, Status='live', Symbol='CSRP1', Aliases=['CRP', 'CRP1', 'CSRP', 'CYRP', 'D1S181E', 'HEL-141', 'HEL-S-286'], description='cysteine and glycine rich protein 1', other_designations='cysteine and glycine-rich protein 1|LIM-domain protein|cysteine-rich protein 1|epididymis luminal protein 141|epididymis secretory protein Li 286|epididymis secretory sperm binding protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201483530, end_position_on_the_genomic_accession=201507123, orientation='minus', exon_count=8, OMIM=[123876], no_hdr0=''),
    1466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1466, CurrentID=0, Status='live', Symbol='CSRP2', Aliases=['CRP2', 'LMO5', 'SmLIM'], description='cysteine and glycine rich protein 2', other_designations='cysteine and glycine-rich protein 2|LIM domain only 5, smooth muscle|LIM domain only protein 5|LMO-5|cysteine-rich protein 2|epididymis secretory sperm binding protein|smooth muscle cell LIM protein', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76858709, end_position_on_the_genomic_accession=76879019, orientation='minus', exon_count=6, OMIM=[601871], no_hdr0=''),
    1468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1468, CurrentID=0, Status='live', Symbol='SLC25A10', Aliases=['DIC', 'MTDPS19'], description='solute carrier family 25 member 10', other_designations='mitochondrial dicarboxylate carrier|dicarboxylate ion carrier|solute carrier family 25 (mitochondrial carrier; dicarboxylate transporter), member 10', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81712284, end_position_on_the_genomic_accession=81721012, orientation='plus', exon_count=12, OMIM=[606794], no_hdr0=''),
    1469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1469, CurrentID=0, Status='live', Symbol='CST1', Aliases=[], description='cystatin SN', other_designations='cystatin-SN|cystain-SA-I|cystatin 1|cystatin SA-I|cysteine proteinase inhibitor, type 2 family|salivary cystatin-SA-1', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23747562, end_position_on_the_genomic_accession=23750935, orientation='minus', exon_count=3, OMIM=[123855], no_hdr0=''),
    1470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1470, CurrentID=0, Status='live', Symbol='CST2', Aliases=[], description='cystatin SA', other_designations='cystatin-SA|cystatin 2|cystatin S5|cysteine-proteinase inhibitor|salivary cysteine (thiol) protease inhibitor', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23823769, end_position_on_the_genomic_accession=23826729, orientation='minus', exon_count=3, OMIM=[123856], no_hdr0=''),
    1471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1471, CurrentID=0, Status='live', Symbol='CST3', Aliases=['ARMD11', 'HEL-S-2'], description='cystatin C', other_designations='cystatin-C|bA218C14.4 (cystatin C)|cystatin 3|epididymis secretory protein Li 2|gamma-trace|neuroendocrine basic polypeptide|post-gamma-globulin', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23626706, end_position_on_the_genomic_accession=23637955, orientation='minus', exon_count=4, OMIM=[604312], no_hdr0=''),
    1472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1472, CurrentID=0, Status='live', Symbol='CST4', Aliases=[], description='cystatin S', other_designations='cystatin-S|cystatin 4|cystatin-SA-III|salivary acidic protein 1', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23685640, end_position_on_the_genomic_accession=23689038, orientation='minus', exon_count=3, OMIM=[123857], no_hdr0=''),
    1473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1473, CurrentID=0, Status='live', Symbol='CST5', Aliases=[], description='cystatin D', other_designations='cystatin-D|cystatin 5|cysteine-proteinase inhibitor', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23875934, end_position_on_the_genomic_accession=23879748, orientation='minus', exon_count=3, OMIM=[123858], no_hdr0=''),
    1474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1474, CurrentID=0, Status='live', Symbol='CST6', Aliases=['ECTD15'], description='cystatin E/M', other_designations='cystatin-M|cystatin 6|cystatin M/E|cystatin-E|cysteine proteinase inhibitor', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66012008, end_position_on_the_genomic_accession=66013505, orientation='plus', exon_count=3, OMIM=[601891], no_hdr0=''),
    1475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1475, CurrentID=0, Status='live', Symbol='CSTA', Aliases=['AREI', 'PSS4', 'STF1', 'STFA'], description='cystatin A', other_designations='cystatin-A|cystatin A (stefin A)|cystatin AS', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122325248, end_position_on_the_genomic_accession=122341969, orientation='plus', exon_count=3, OMIM=[184600], no_hdr0=''),
    1476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1476, CurrentID=0, Status='live', Symbol='CSTB', Aliases=['CPI-B', 'CST6', 'EPM1', 'EPM1A', 'PME', 'STFB', 'ULD'], description='cystatin B', other_designations='cystatin-B|cystatin B (stefin B)|epididymis secretory sperm binding protein|liver thiol proteinase inhibitor', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43773950, end_position_on_the_genomic_accession=43776308, orientation='minus', exon_count=3, OMIM=[601145], no_hdr0=''),
    1477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1477, CurrentID=0, Status='live', Symbol='CSTF1', Aliases=['CstF-50', 'CstFp50'], description='cleavage stimulation factor subunit 1', other_designations="cleavage stimulation factor subunit 1|CF-1 50 kDa subunit|CSTF 50 kDa subunit|cleavage stimulation factor 50 kDa subunit|cleavage stimulation factor, 3' pre-RNA, subunit 1, 50kD|cleavage stimulation factor, 3' pre-RNA, subunit 1, 50kDa", map_location='20q13.2-q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56392379, end_position_on_the_genomic_accession=56406362, orientation='plus', exon_count=7, OMIM=[600369], no_hdr0=''),
    1478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1478, CurrentID=0, Status='live', Symbol='CSTF2', Aliases=['CstF-64'], description='cleavage stimulation factor subunit 2', other_designations="cleavage stimulation factor subunit 2|CF-1 64 kDa subunit|CSTF 64 kDa subunit|betaCstF-64 variant 2|cleavage stimulation factor 64 kDa subunit|cleavage stimulation factor, 3' pre-RNA, subunit 2, 64kD|cleavage stimulation factor, 3' pre-RNA, subunit 2, 64kDa", map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100820369, end_position_on_the_genomic_accession=100843534, orientation='plus', exon_count=14, OMIM=[300907], no_hdr0=''),
    1479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1479, CurrentID=0, Status='live', Symbol='CSTF3', Aliases=['CSTF-77'], description='cleavage stimulation factor subunit 3', other_designations="cleavage stimulation factor subunit 3|CF-1 77 kDa subunit|CSTF 77 kDa subunit|cleavage stimulation factor 77 kDa subunit|cleavage stimulation factor, 3' pre-RNA, subunit 3, 77kD|cleavage stimulation factor, 3' pre-RNA, subunit 3, 77kDa", map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33084584, end_position_on_the_genomic_accession=33161480, orientation='minus', exon_count=21, OMIM=[600367], no_hdr0=''),
    1482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1482, CurrentID=0, Status='live', Symbol='NKX2-5', Aliases=['CHNG5', 'CSX', 'CSX1', 'HLHS2', 'NKX2.5', 'NKX2E', 'NKX4-1', 'VSD3'], description='NK2 homeobox 5', other_designations='homeobox protein Nkx-2.5|NK2 transcription factor related, locus 5|NKX 2-5|cardiac-specific homeobox 1|homeobox protein CSX|homeobox protein NK-2 homolog E|homeobox protein NKX 2-5|tinman homolog|tinman paralog', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173232109, end_position_on_the_genomic_accession=173235321, orientation='minus', exon_count=3, OMIM=[600584], no_hdr0=''),
    1485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1485, CurrentID=0, Status='live', Symbol='CTAG1B', Aliases=['CT6.1', 'CTAG', 'CTAG1', 'ESO1', 'LAGE-2', 'LAGE2B', 'NY-ESO-1'], description='cancer/testis antigen 1B', other_designations='cancer/testis antigen 1|New York esophageal squamous cell carcinoma 1|autoimmunogenic cancer/testis antigen NY-ESO-1|cancer antigen 3|cancer/testis antigen 6.1|l antigen family member 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154617609, end_position_on_the_genomic_accession=154619282, orientation='minus', exon_count=3, OMIM=[300156], no_hdr0=''),
    1486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1486, CurrentID=0, Status='live', Symbol='CTBS', Aliases=['CTB'], description='chitobiase', other_designations='di-N-acetylchitobiase|chitobiase, di-N-acetyl-', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84549611, end_position_on_the_genomic_accession=84574440, orientation='minus', exon_count=7, OMIM=[600873], no_hdr0=''),
    1487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1487, CurrentID=0, Status='live', Symbol='CTBP1', Aliases=['BARS', 'HADDTS'], description='C-terminal binding protein 1', other_designations='C-terminal-binding protein 1|brefeldin A-ribosylated substrate', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1211444, end_position_on_the_genomic_accession=1250355, orientation='minus', exon_count=15, OMIM=[602618], no_hdr0=''),
    1488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1488, CurrentID=0, Status='live', Symbol='CTBP2', Aliases=[], description='C-terminal binding protein 2', other_designations='C-terminal-binding protein 2|ribeye', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124984317, end_position_on_the_genomic_accession=125161039, orientation='minus', exon_count=20, OMIM=[602619], no_hdr0=''),
    1489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1489, CurrentID=0, Status='live', Symbol='CTF1', Aliases=['CT-1', 'CT1'], description='cardiotrophin 1', other_designations='cardiotrophin-1|cardiophin 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30895824, end_position_on_the_genomic_accession=30903560, orientation='plus', exon_count=4, OMIM=[600435], no_hdr0=''),
    1490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1490, CurrentID=0, Status='live', Symbol='CCN2', Aliases=['CTGF', 'HCS24', 'IGFBP8', 'NOV2'], description='cellular communication network factor 2', other_designations='CCN family member 2|IBP-8|IGF-binding protein 8|IGFBP-8|connective tissue growth factor|hypertrophic chondrocyte-specific protein 24|insulin-like growth factor-binding protein 8', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131948176, end_position_on_the_genomic_accession=131951372, orientation='minus', exon_count=5, OMIM=[121009], no_hdr0=''),
    1491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1491, CurrentID=0, Status='live', Symbol='CTH', Aliases=[], description='cystathionine gamma-lyase', other_designations='cystathionine gamma-lyase|cystathionase (cystathionine gamma-lyase)|cysteine desulfhydrase|cysteine-protein sulfhydrase|gamma-cystathionase|homoserine deaminase|homoserine dehydratase', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=70411268, end_position_on_the_genomic_accession=70441949, orientation='plus', exon_count=13, OMIM=[607657], no_hdr0=''),
    1493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1493, CurrentID=0, Status='live', Symbol='CTLA4', Aliases=['ALPS5', 'CD', 'CD152', 'CELIAC3', 'CTLA-4', 'GRD4', 'GSE', 'IDDM12'], description='cytotoxic T-lymphocyte associated protein 4', other_designations='cytotoxic T-lymphocyte protein 4|celiac disease 3|cytotoxic T lymphocyte associated antigen 4 short spliced form|cytotoxic T-lymphocyte-associated serine esterase-4|insulin-dependent diabetes mellitus 12|ligand and transmembrane spliced cytotoxic T lymphocyte associated antigen 4', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203867771, end_position_on_the_genomic_accession=203873965, orientation='plus', exon_count=4, OMIM=[123890], no_hdr0=''),
    1495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1495, CurrentID=0, Status='live', Symbol='CTNNA1', Aliases=['CAP102', 'MDPT2'], description='catenin alpha 1', other_designations='catenin alpha-1|alpha-E-catenin|catenin (cadherin-associated protein), alpha 1, 102kDa|epididymis secretory sperm binding protein|renal carcinoma antigen NY-REN-13', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138753425, end_position_on_the_genomic_accession=138935034, orientation='plus', exon_count=27, OMIM=[116805], no_hdr0=''),
    1496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1496, CurrentID=0, Status='live', Symbol='CTNNA2', Aliases=['CAP-R', 'CAPR', 'CDCBM9', 'CT114', 'CTNR'], description='catenin alpha 2', other_designations='catenin alpha-2|alpha-N-catenin|alpha-catenin-related protein|cadherin-associated protein, related|cancer/testis antigen 114|catenin (cadherin-associated protein), alpha 2', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=79505054, end_position_on_the_genomic_accession=80648788, orientation='plus', exon_count=29, OMIM=[114025], no_hdr0=''),
    1497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1497, CurrentID=0, Status='live', Symbol='CTNS', Aliases=['CTNS-LSB', 'PQLC4', 'SLC66A4'], description='cystinosin, lysosomal cystine transporter', other_designations='cystinosin|cystinosis nephropathic', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3636459, end_position_on_the_genomic_accession=3663103, orientation='plus', exon_count=14, OMIM=[606272], no_hdr0=''),
    1499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1499, CurrentID=0, Status='live', Symbol='CTNNB1', Aliases=['CTNNB', 'EVR7', 'MRD19', 'NEDSDV', 'armadillo'], description='catenin beta 1', other_designations='catenin beta-1|catenin (cadherin-associated protein), beta 1, 88kDa', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=41199422, end_position_on_the_genomic_accession=41240445, orientation='plus', exon_count=19, OMIM=[116806], no_hdr0=''),
    1500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1500, CurrentID=0, Status='live', Symbol='CTNND1', Aliases=['BCDS2', 'CAS', 'CTNND', 'P120CAS', 'P120CTN', 'p120', 'p120(CAS)', 'p120(CTN)'], description='catenin delta 1', other_designations='catenin delta-1|cadherin-associated Src substrate|catenin (cadherin-associated protein), delta 1|p120 catenin', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57761802, end_position_on_the_genomic_accession=57819540, orientation='plus', exon_count=21, OMIM=[601045], no_hdr0=''),
    1501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1501, CurrentID=0, Status='live', Symbol='CTNND2', Aliases=['GT24', 'NPRAP'], description='catenin delta 2', other_designations='catenin delta-2|T-cell delta-catenin|catenin (cadherin-associated protein), delta 2 (neural plakophilin-related arm-repeat protein)|neurojungin', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10971836, end_position_on_the_genomic_accession=11904446, orientation='minus', exon_count=26, OMIM=[604275], no_hdr0=''),
    1503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1503, CurrentID=0, Status='live', Symbol='CTPS1', Aliases=['CTPS', 'GATD5', 'GATD5A', 'IMD24'], description='CTP synthase 1', other_designations="CTP synthase 1|CTP synthetase 1|UTP--ammonia ligase 1|cytidine 5'-triphosphate synthetase|cytidine 5-prime triphosphate synthetase", map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40979696, end_position_on_the_genomic_accession=41012565, orientation='plus', exon_count=22, OMIM=[123860], no_hdr0=''),
    1504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1504, CurrentID=0, Status='live', Symbol='CTRB1', Aliases=['CTRB'], description='chymotrypsinogen B1', other_designations='chymotrypsinogen B', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75218988, end_position_on_the_genomic_accession=75224924, orientation='plus', exon_count=7, OMIM=[118890], no_hdr0=''),
    1506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1506, CurrentID=0, Status='live', Symbol='CTRL', Aliases=['CTRL1'], description='chymotrypsin like', other_designations='chymotrypsin-like protease CTRL-1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67929574, end_position_on_the_genomic_accession=67931862, orientation='minus', exon_count=7, OMIM=[118888], no_hdr0=''),
    1508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1508, CurrentID=0, Status='live', Symbol='CTSB', Aliases=['APPS', 'CPSB', 'RECEUP'], description='cathepsin B', other_designations='cathepsin B|APP secretase|amyloid precursor protein secretase|cathepsin B1|cysteine protease|epididymis secretory sperm binding protein', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11842524, end_position_on_the_genomic_accession=11868087, orientation='minus', exon_count=14, OMIM=[116810], no_hdr0=''),
    1509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1509, CurrentID=0, Status='live', Symbol='CTSD', Aliases=['CLN10', 'CPSD', 'HEL-S-130P'], description='cathepsin D', other_designations='cathepsin D|ceroid-lipofuscinosis, neuronal 10|epididymis secretory sperm binding protein Li 130P|lysosomal aspartyl peptidase|lysosomal aspartyl protease', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1752755, end_position_on_the_genomic_accession=1763927, orientation='minus', exon_count=9, OMIM=[116840], no_hdr0=''),
    1510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1510, CurrentID=0, Status='live', Symbol='CTSE', Aliases=['CATE'], description='cathepsin E', other_designations='cathepsin E|erythrocyte membrane aspartic proteinase|slow-moving proteinase', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206009264, end_position_on_the_genomic_accession=206023899, orientation='minus', exon_count=9, OMIM=[116890], no_hdr0=''),
    1511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1511, CurrentID=0, Status='live', Symbol='CTSG', Aliases=['CATG', 'CG'], description='cathepsin G', other_designations='cathepsin G', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24573518, end_position_on_the_genomic_accession=24576250, orientation='minus', exon_count=5, OMIM=[116830], no_hdr0=''),
    1512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1512, CurrentID=0, Status='live', Symbol='CTSH', Aliases=['ACC-4', 'ACC-5', 'ACC4', 'ACC5', 'CPSB'], description='cathepsin H', other_designations='pro-cathepsin H|N-benzoylarginine-beta-naphthylamide hydrolase|aleurain|cathepsin B3|cathepsin BA', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78921058, end_position_on_the_genomic_accession=78945089, orientation='minus', exon_count=14, OMIM=[116820], no_hdr0=''),
    1513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1513, CurrentID=0, Status='live', Symbol='CTSK', Aliases=['CTS02', 'CTSO', 'CTSO1', 'CTSO2', 'PKND', 'PYCD'], description='cathepsin K', other_designations='cathepsin K|cathepsin O|cathepsin O1|cathepsin O2|cathepsin X', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150796208, end_position_on_the_genomic_accession=150808260, orientation='minus', exon_count=8, OMIM=[601105], no_hdr0=''),
    1514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1514, CurrentID=0, Status='live', Symbol='CTSL', Aliases=['CATL1', 'MEP', 'CTSL'], description='cathepsin L', other_designations='procathepsin L|cathepsin L1|major excreted protein', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=87726119, end_position_on_the_genomic_accession=87731469, orientation='plus', exon_count=9, OMIM=[116880], no_hdr0=''),
    1515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1515, CurrentID=0, Status='live', Symbol='CTSV', Aliases=['CATL2', 'CTSL2', 'CTSU'], description='cathepsin V', other_designations='cathepsin L2|cathepsin L2, preproprotein|cathepsin U', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97029677, end_position_on_the_genomic_accession=97039643, orientation='minus', exon_count=9, OMIM=[603308], no_hdr0=''),
    1519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1519, CurrentID=0, Status='live', Symbol='CTSO', Aliases=['CTSO1'], description='cathepsin O', other_designations='cathepsin O', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155924118, end_position_on_the_genomic_accession=155953866, orientation='minus', exon_count=8, OMIM=[600550], no_hdr0=''),
    1520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1520, CurrentID=0, Status='live', Symbol='CTSS', Aliases=[], description='cathepsin S', other_designations='cathepsin S', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150730188, end_position_on_the_genomic_accession=150765778, orientation='minus', exon_count=8, OMIM=[116845], no_hdr0=''),
    1521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1521, CurrentID=0, Status='live', Symbol='CTSW', Aliases=['LYPN'], description='cathepsin W', other_designations='cathepsin W|lymphopain', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65879837, end_position_on_the_genomic_accession=65883741, orientation='plus', exon_count=10, OMIM=[602364], no_hdr0=''),
    1522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1522, CurrentID=0, Status='live', Symbol='CTSZ', Aliases=['CTSX'], description='cathepsin Z', other_designations='cathepsin Z|carboxypeptidase LB|cathepsin B2|cathepsin IV|cathepsin P|cathepsin X|cathepsin Y|cathepsin Z1|cysteine-type carboxypeptidase|lysosomal carboxypeptidase B|preprocathepsin P', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58995185, end_position_on_the_genomic_accession=59007254, orientation='minus', exon_count=6, OMIM=[603169], no_hdr0=''),
    1523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1523, CurrentID=0, Status='live', Symbol='CUX1', Aliases=['CASP', 'CDP', 'CDP/Cut', 'CDP1', 'COY1', 'CUTL1', 'CUX', 'Clox', 'Cux/CDP', 'GDDI', 'GOLIM6', 'Nbla10317', 'p100', 'p110', 'p200', 'p75'], description='cut like homeobox 1', other_designations='protein CASP|Homeobox protein cut-like 1|CCAAT displacement protein|CDP/Cux p200|CUX1 gene Alternatively Spliced Product|cut homolog|golgi integral membrane protein 6|homeobox protein cux-1|mutant CUX1|putative protein product of Nbla10317', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101815991, end_position_on_the_genomic_accession=102283958, orientation='plus', exon_count=34, OMIM=[116896], no_hdr0=''),
    1524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1524, CurrentID=0, Status='live', Symbol='CX3CR1', Aliases=['CCRL1', 'CMKBRL1', 'CMKDR1', 'GPR13', 'GPRV28', 'V28'], description='C-X3-C motif chemokine receptor 1', other_designations='CX3C chemokine receptor 1|C-X3-C CKR-1|CMK-BRL-1|CMK-BRL1|G-protein coupled receptor 13|beta chemokine receptor-like 1|chemokine (C-C) receptor-like 1|chemokine (C-X3-C motif) receptor 1|chemokine (C-X3-C) receptor 1|fractalkine receptor', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39263494, end_position_on_the_genomic_accession=39281735, orientation='minus', exon_count=5, OMIM=[601470], no_hdr0=''),
    1525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1525, CurrentID=0, Status='live', Symbol='CXADR', Aliases=['CAR', 'CAR4/6', 'HCAR'], description='CXADR Ig-like cell adhesion molecule', other_designations='coxsackievirus and adenovirus receptor|46 kD coxsackievirus and adenovirus receptor (CAR) protein|CVB3-binding protein|HCVADR|coxsackie virus and adenovirus receptor|coxsackievirus B-adenovirus receptor', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=17513016, end_position_on_the_genomic_accession=17636213, orientation='plus', exon_count=10, OMIM=[602621], no_hdr0=''),
    1527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1527, CurrentID=0, Status='live', Symbol='TEX28', Aliases=['CXorf2', 'MRX99P1', 'TEX28P2', 'fTEX', 'TEX28'], description='testis expressed 28', other_designations='testis-specific protein TEX28', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154271265, end_position_on_the_genomic_accession=154295356, orientation='minus', exon_count=8, OMIM=[300092], no_hdr0=''),
    1528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1528, CurrentID=0, Status='live', Symbol='CYB5A', Aliases=['CYB5', 'MCB5', 'METAG'], description='cytochrome b5 type A', other_designations='cytochrome b5|cytochrome b5 type A (microsomal)|epididymis secretory sperm binding protein|type 1 cyt-b5', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74250846, end_position_on_the_genomic_accession=74291980, orientation='minus', exon_count=6, OMIM=[613218], no_hdr0=''),
    1534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1534, CurrentID=0, Status='live', Symbol='CYB561', Aliases=['CYB561A1', 'FRRS2', 'ORTHYP2'], description='cytochrome b561', other_designations='transmembrane ascorbate-dependent reductase CYB561|cytochrome b-561|cytochrome b561 family, member A1|ferric-chelate reductase 2', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63432304, end_position_on_the_genomic_accession=63446639, orientation='minus', exon_count=8, OMIM=[600019], no_hdr0=''),
    1535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1535, CurrentID=0, Status='live', Symbol='CYBA', Aliases=['CGD4', 'p22-PHOX'], description='cytochrome b-245 alpha chain', other_designations='cytochrome b-245 light chain|cytochrome b light chain|cytochrome b(558) alpha chain|cytochrome b(558) alpha-subunit|cytochrome b, alpha polypeptide|cytochrome b-245, alpha polypeptide|cytochrome b558 subunit alpha|flavocytochrome b-558 alpha polypeptide|neutrophil cytochrome b 22 kDa polypeptide|p22 phagocyte B-cytochrome|p22phox|superoxide-generating NADPH oxidase light chain subunit', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88643289, end_position_on_the_genomic_accession=88651079, orientation='minus', exon_count=7, OMIM=[608508], no_hdr0=''),
    1536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1536, CurrentID=0, Status='live', Symbol='CYBB', Aliases=['AMCBX2', 'CGD', 'CGDX', 'GP91-1', 'GP91-PHOX', 'GP91PHOX', 'IMD34', 'NOX2', 'p91-PHOX'], description='cytochrome b-245 beta chain', other_designations='cytochrome b-245 heavy chain|CGD91-phox|NADPH oxidase 2|cytochrome b(558) subunit beta|cytochrome b-245 beta polypeptide|cytochrome b558 subunit beta|heme-binding membrane glycoprotein gp91phox|neutrophil cytochrome b 91 kDa polypeptide|p22 phagocyte B-cytochrome|superoxide-generating NADPH oxidase heavy chain subunit', map_location='Xp21.1-p11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37780059, end_position_on_the_genomic_accession=37813461, orientation='plus', exon_count=13, OMIM=[300481], no_hdr0=''),
    1537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1537, CurrentID=0, Status='live', Symbol='CYC1', Aliases=['MC3DN6', 'UQCR4'], description='cytochrome c1', other_designations='cytochrome c1, heme protein, mitochondrial|complex III subunit 4|complex III subunit IV|cytochrome b-c1 complex subunit 4|cytochrome c-1|ubiquinol-cytochrome-c reductase complex cytochrome c1 subunit', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144095076, end_position_on_the_genomic_accession=144097525, orientation='plus', exon_count=8, OMIM=[123980], no_hdr0=''),
    1538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1538, CurrentID=0, Status='live', Symbol='CYLC1', Aliases=['CYCL1'], description='cylicin 1', other_designations='cylicin-1|cylicin I|cylicin, basic protein of sperm head cytoskeleton 1|multiple-band polypeptide I', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=83861135, end_position_on_the_genomic_accession=83886700, orientation='plus', exon_count=5, OMIM=[300768], no_hdr0=''),
    1539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1539, CurrentID=0, Status='live', Symbol='CYLC2', Aliases=[], description='cylicin 2', other_designations='cylicin-2|cylicin II|cylicin, basic protein of sperm head cytoskeleton 2|multiple-band polypeptide II', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=102995333, end_position_on_the_genomic_accession=103018488, orientation='plus', exon_count=8, OMIM=[604035], no_hdr0=''),
    1540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1540, CurrentID=0, Status='live', Symbol='CYLD', Aliases=['BRSS', 'CDMT1', 'CYLDI', 'EAC', 'FTDALS8', 'MFT', 'MFT1', 'SBS', 'TEM', 'USPL2', 'CYLD'], description='CYLD lysine 63 deubiquitinase', other_designations='ubiquitin carboxyl-terminal hydrolase CYLD|cylindromatosis (turban tumor syndrome)|deubiquitinating enzyme CYLD|probable ubiquitin carboxyl-terminal hydrolase CYLD|ubiquitin specific peptidase like 2|ubiquitin thioesterase CYLD|ubiquitin thiolesterase CYLD|ubiquitin-specific-processing protease CYLD', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50742086, end_position_on_the_genomic_accession=50801935, orientation='plus', exon_count=23, OMIM=[605018], no_hdr0=''),
    1543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1543, CurrentID=0, Status='live', Symbol='CYP1A1', Aliases=['AHH', 'AHRR', 'CP11', 'CYP1', 'CYPIA1', 'P1-450', 'P450-C', 'P450DX'], description='cytochrome P450 family 1 subfamily A member 1', other_designations='cytochrome P450 1A1|aryl hydrocarbon hydroxylase|cytochrome P1-450, dioxin-inducible|cytochrome P450 form 6|cytochrome P450, family 1, subfamily A, polypeptide 1|cytochrome P450, subfamily I (aromatic compound-inducible), polypeptide 1|cytochrome P450-C|cytochrome P450-P1|flavoprotein-linked monooxygenase|hydroperoxy icosatetraenoate dehydratase|xenobiotic monooxygenase', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74719542, end_position_on_the_genomic_accession=74725528, orientation='minus', exon_count=7, OMIM=[108330], no_hdr0=''),
    1544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1544, CurrentID=0, Status='live', Symbol='CYP1A2', Aliases=['CP12', 'CYPIA2', 'P3-450', 'P450(PA)'], description='cytochrome P450 family 1 subfamily A member 2', other_designations='cytochrome P450 1A2|P450 form 4|aryl hydrocarbon hydroxylase|cholesterol 25-hydroxylase|cytochrome P(3)450|cytochrome P450 4|cytochrome P450, family 1, subfamily A, polypeptide 2|cytochrome P450, subfamily I (aromatic compound-inducible), polypeptide 2|cytochrome P450-P3|dioxin-inducible P3-450|flavoprotein-linked monooxygenase|hydroperoxy icosatetraenoate dehydratase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74748845, end_position_on_the_genomic_accession=74756607, orientation='plus', exon_count=7, OMIM=[124060], no_hdr0=''),
    1545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1545, CurrentID=0, Status='live', Symbol='CYP1B1', Aliases=['ASGD6', 'CP1B', 'CYPIB1', 'GLC3A', 'P4501B1'], description='cytochrome P450 family 1 subfamily B member 1', other_designations='cytochrome P450 1B1|aryl hydrocarbon hydroxylase|cytochrome P450, family 1, subfamily B, polypeptide 1|cytochrome P450, subfamily I (dioxin-inducible), polypeptide 1 (glaucoma 3, primary infantile)|dioxin-inducible cytochrome p450|flavoprotein-linked monooxygenase|hydroperoxy icosatetraenoate dehydratase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38067509, end_position_on_the_genomic_accession=38076151, orientation='minus', exon_count=3, OMIM=[601771], no_hdr0=''),
    1548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1548, CurrentID=0, Status='live', Symbol='CYP2A6', Aliases=['CPA6', 'CYP2A', 'CYP2A3', 'CYPIIA6', 'P450C2A', 'P450PB'], description='cytochrome P450 family 2 subfamily A member 6', other_designations='cytochrome P450 2A6|1,4-cineole 2-exo-monooxygenase|coumarin 7-hydroxylase|cytochrome P450 IIA3|cytochrome P450(I)|cytochrome P450, family 2, subfamily A, polypeptide 6|cytochrome P450, subfamily IIA (phenobarbital-inducible), polypeptide 6|flavoprotein-linked monooxygenase|xenobiotic monooxygenase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40843541, end_position_on_the_genomic_accession=40850447, orientation='minus', exon_count=9, OMIM=[122720], no_hdr0=''),
    1549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1549, CurrentID=0, Status='live', Symbol='CYP2A7', Aliases=['CPA7', 'CPAD', 'CYP2A', 'CYPIIA7', 'P450-IIA4'], description='cytochrome P450 family 2 subfamily A member 7', other_designations='cytochrome P450 2A7|cytochrome P450 IIA4|cytochrome P450, family 2, subfamily A, polypeptide 7|cytochrome P450, subfamily IIA (phenobarbital-inducible), polypeptide 7|cytochrome P450IIA4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40875439, end_position_on_the_genomic_accession=40885951, orientation='minus', exon_count=8, OMIM=[608054], no_hdr0=''),
    1551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1551, CurrentID=0, Status='live', Symbol='CYP3A7', Aliases=['CP37', 'CYPIIIA7', 'P-450(HFL33)', 'P-450111A7', 'P450-HFLA', 'P450HLp2'], description='cytochrome P450 family 3 subfamily A member 7', other_designations='cytochrome P450 3A7|aryl hydrocarbon hydroxylase|cytochrome P450, family 3, subfamily A, polypeptide 7|cytochrome P450, subfamily IIIA, polypeptide 7|cytochrome P450-HFLA|flavoprotein-linked monooxygenase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99705036, end_position_on_the_genomic_accession=99735196, orientation='minus', exon_count=13, OMIM=[605340], no_hdr0=''),
    1553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1553, CurrentID=0, Status='live', Symbol='CYP2A13', Aliases=['CPAD', 'CYP2A', 'CYPIIA13'], description='cytochrome P450 family 2 subfamily A member 13', other_designations='cytochrome P450 2A13|cytochrome P450, family 2, subfamily A, polypeptide 13|cytochrome P450, subfamily IIA (phenobarbital-inducible), polypeptide 13', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41088451, end_position_on_the_genomic_accession=41096195, orientation='plus', exon_count=9, OMIM=[608055], no_hdr0=''),
    1555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1555, CurrentID=0, Status='live', Symbol='CYP2B6', Aliases=['CPB6', 'CYP2B', 'CYP2B7', 'CYP2B7P', 'CYPIIB6', 'EFVM', 'IIB1', 'P450'], description='cytochrome P450 family 2 subfamily B member 6', other_designations='cytochrome P450 2B6|1,4-cineole 2-exo-monooxygenase|cytochrome P450 IIB1|cytochrome P450, family 2, subfamily B, polypeptide 6|cytochrome P450, subfamily IIB (phenobarbital-inducible), polypeptide 6', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40991282, end_position_on_the_genomic_accession=41018398, orientation='plus', exon_count=9, OMIM=[123930], no_hdr0=''),
    1557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1557, CurrentID=0, Status='live', Symbol='CYP2C19', Aliases=['CPCJ', 'CYP2C', 'CYPIIC17', 'CYPIIC19', 'P450C2C', 'P450IIC19'], description='cytochrome P450 family 2 subfamily C member 19', other_designations="cytochrome P450 2C19|(R)-limonene 6-monooxygenase|(S)-limonene 6-monooxygenase|(S)-limonene 7-monooxygenase|S-mephenytoin 4-hydroxylase|cytochrome P-450 II C|cytochrome P450, family 2, subfamily C, polypeptide 19|cytochrome P450, subfamily IIC (mephenytoin 4-hydroxylase), polypeptide 19|cytochrome P450-11A|cytochrome P450-254C|fenbendazole monooxygenase (4'-hydroxylating)|flavoprotein-linked monooxygenase|mephenytoin 4'-hydroxylase|mephenytoin 4-hydroxylase|microsomal monooxygenase|xenobiotic monooxygenase", map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94762681, end_position_on_the_genomic_accession=94855547, orientation='plus', exon_count=9, OMIM=[124020], no_hdr0=''),
    1558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1558, CurrentID=0, Status='live', Symbol='CYP2C8', Aliases=['CPC8DM', 'CYPIIC8', 'MP-12/MP-20', 'CYP2C8'], description='cytochrome P450 family 2 subfamily C member 8', other_designations='cytochrome P450 2C8|P450 form 1|cytochrome P450 IIC2|cytochrome P450 MP-12|cytochrome P450 MP-20|cytochrome P450 form 1|cytochrome P450, family 2, subfamily C, polypeptide 8|cytochrome P450, subfamily IIC (mephenytoin 4-hydroxylase), polypeptide 8|flavoprotein-linked monooxygenase|microsomal monooxygenase|s-mephenytoin 4-hydroxylase|xenobiotic monooxygenase', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95036772, end_position_on_the_genomic_accession=95069497, orientation='minus', exon_count=10, OMIM=[601129], no_hdr0=''),
    1559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1559, CurrentID=0, Status='live', Symbol='CYP2C9', Aliases=['CPC9', 'CYP2C', 'CYP2C10', 'CYPIIC9', 'P450IIC9'], description='cytochrome P450 family 2 subfamily C member 9', other_designations='cytochrome P450 2C9|cytochrome P-450 S-mephenytoin 4-hydroxylase|cytochrome P-450MP|cytochrome P450 PB-1|cytochrome P450, family 2, subfamily C, polypeptide 9|flavoprotein-linked monooxygenase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94938658, end_position_on_the_genomic_accession=94990091, orientation='plus', exon_count=9, OMIM=[601130], no_hdr0=''),
    1562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1562, CurrentID=0, Status='live', Symbol='CYP2C18', Aliases=['CPCI', 'CYP2C', 'CYP2C17', 'P450-6B/29C', 'P450IIC17'], description='cytochrome P450 family 2 subfamily C member 18', other_designations='cytochrome P450 2C18|(S)-mephenytoin hydroxylase associated cytochrome P450|CYPIIC18|cytochrome P450, family 2, subfamily C, polypeptide 18|cytochrome P450, subfamily IIC (mephenytoin 4-hydroxylase), polypeptide 17|cytochrome P450, subfamily IIC (mephenytoin 4-hydroxylase), polypeptide 18|cytochrome P450-6B/29C|flavoprotein-linked monooxygenase|microsomal monooxygenase|unspecific monooxygenase', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94683729, end_position_on_the_genomic_accession=94736190, orientation='plus', exon_count=9, OMIM=[601131], no_hdr0=''),
    1564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1564, CurrentID=0, Status='live', Symbol='CYP2D7', Aliases=['CYP2D', 'CYP2D6AP', 'CYP2D7P', 'CYP2D7P1', 'CYP2D@', 'P450C2D', 'P450DB1', 'RNA40057', 'CYP2D7'], description='cytochrome P450 family 2 subfamily D member 7 (gene/pseudogene)', other_designations='putative cytochrome P450 2D7|Putative cytochrome P450 2D7|cytochrome P450, family 2, subfamily D, polypeptide 7 pseudogene 1|cytochrome P450, subfamily II (debrisoquine, sparteine, etc., -metabolising), polypeptide 7 pseudogene 1|cytochrome P450, subfamily IID (debrisoquine, sparteine, etc., -metabolizing) cluster|cytochrome P4502D6|nonfunctional cytochrome P450 family 2 subfamily D polypeptide 6', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42139576, end_position_on_the_genomic_accession=42144483, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    1565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1565, CurrentID=0, Status='live', Symbol='CYP2D6', Aliases=['CPD6', 'CYP2D', 'CYP2D7AP', 'CYP2D7BP', 'CYP2D7P2', 'CYP2D8P2', 'CYP2DL1', 'CYPIID6', 'P450-DB1', 'P450C2D', 'P450DB1'], description='cytochrome P450 family 2 subfamily D member 6', other_designations='cytochrome P450 2D6|cholesterol 25-hydroxylase|cytochrome P450, family 2, subfamily D, polypeptide 6|cytochrome P450, family 2, subfamily D, polypeptide 7 pseudogene 2|cytochrome P450, family 2, subfamily D, polypeptide 8 pseudogene 2|cytochrome P450, subfamily II (debrisoquine, sparteine, etc., -metabolising), polypeptide 7 pseudogene 2|cytochrome P450, subfamily IID (debrisoquine, sparteine, etc., -metabolising), polypeptide 8 pseudogene 2|cytochrome P450, subfamily IID (debrisoquine, sparteine, etc., -metabolizing), polypeptide 6|cytochrome P450, subfamily IID (debrisoquine, sparteine, etc., -metabolizing)-like 1|cytochrome P450-DB1|debrisoquine 4-hydroxylase|flavoprotein-linked monooxygenase|microsomal monooxygenase|nonfunctional cytochrome P450 2D6|xenobiotic monooxygenase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42126499, end_position_on_the_genomic_accession=42130810, orientation='minus', exon_count=9, OMIM=[124030], no_hdr0=''),
    1571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1571, CurrentID=0, Status='live', Symbol='CYP2E1', Aliases=['CPE1', 'CYP2E', 'P450-J', 'P450C2E'], description='cytochrome P450 family 2 subfamily E member 1', other_designations='cytochrome P450 2E1|4-nitrophenol 2-hydroxylase|CYPIIE1|cytochrome P450, family 2, subfamily E, polypeptide 1|cytochrome P450, subfamily IIE (ethanol-inducible), polypeptide 1|cytochrome P450-J|flavoprotein-linked monooxygenase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133527363, end_position_on_the_genomic_accession=133539123, orientation='plus', exon_count=9, OMIM=[124040], no_hdr0=''),
    1572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1572, CurrentID=0, Status='live', Symbol='CYP2F1', Aliases=['C2F1', 'CYP2F', 'CYPIIF1'], description='cytochrome P450 family 2 subfamily F member 1', other_designations='cytochrome P450 2F1|cytochrome P450, family 2, subfamily F, polypeptide 1|cytochrome P450, subfamily IIF, polypeptide 1|flavoprotein-linked monooxygenase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41114292, end_position_on_the_genomic_accession=41128381, orientation='plus', exon_count=10, OMIM=[124070], no_hdr0=''),
    1573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1573, CurrentID=0, Status='live', Symbol='CYP2J2', Aliases=['CPJ2', 'CYPIIJ2'], description='cytochrome P450 family 2 subfamily J member 2', other_designations='cytochrome P450 2J2|albendazole monooxygenase (hydroxylating)|albendazole monooxygenase (sulfoxide-forming)|arachidonic acid epoxygenase|cytochrome P450, family 2, subfamily J, polypeptide 2|cytochrome P450, subfamily IIJ (arachidonic acid epoxygenase) polypeptide 2|flavoprotein-linked monooxygenase|hydroperoxy icosatetraenoate isomerase|microsomal monooxygenase', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=59893308, end_position_on_the_genomic_accession=59926773, orientation='minus', exon_count=10, OMIM=[601258], no_hdr0=''),
    1576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1576, CurrentID=0, Status='live', Symbol='CYP3A4', Aliases=['CP33', 'CP34', 'CYP3A', 'CYP3A3', 'CYPIIIA3', 'CYPIIIA4', 'HLP', 'NF-25', 'P450C3', 'P450PCN1', 'VDDR3'], description='cytochrome P450 family 3 subfamily A member 4', other_designations='cytochrome P450 3A4|1,4-cineole 2-exo-monooxygenase|1,8-cineole 2-exo-monooxygenase|P450-III, steroid inducible|albendazole monooxygenase (sulfoxide-forming)|albendazole sulfoxidase|cholesterol 25-hydroxylase|cytochrome P450 3A3|cytochrome P450 HLp|cytochrome P450 NF-25|cytochrome P450, family 3, subfamily A, polypeptide 4|cytochrome P450, subfamily IIIA (niphedipine oxidase), polypeptide 3|cytochrome P450, subfamily IIIA (niphedipine oxidase), polypeptide 4|cytochrome P450-PCN1|glucocorticoid-inducible P450|nifedipine oxidase|quinine 3-monooxygenase|taurochenodeoxycholate 6-alpha-hydroxylase', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99756967, end_position_on_the_genomic_accession=99784184, orientation='minus', exon_count=13, OMIM=[124010], no_hdr0=''),
    1577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1577, CurrentID=0, Status='live', Symbol='CYP3A5', Aliases=['CP35', 'CYPIIIA5', 'P450PCN3', 'PCN3'], description='cytochrome P450 family 3 subfamily A member 5', other_designations='cytochrome P450 3A5|aryl hydrocarbon hydroxylase|cytochrome P450 HLp2|cytochrome P450, family 3, subfamily A, polypeptide 5|cytochrome P450, subfamily IIIA (niphedipine oxidase), polypeptide 5|cytochrome P450-PCN3|flavoprotein-linked monooxygenase|microsomal monooxygenase|xenobiotic monooxygenase', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99648194, end_position_on_the_genomic_accession=99679996, orientation='minus', exon_count=14, OMIM=[605325], no_hdr0=''),
    1579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1579, CurrentID=0, Status='live', Symbol='CYP4A11', Aliases=['CP4Y', 'CYP4A2', 'CYP4AII', 'CYPIVA11'], description='cytochrome P450 family 4 subfamily A member 11', other_designations='cytochrome P450 4A11|20-HETE synthase|20-hydroxyeicosatetraenoic acid synthase|P450HL-omega|alkane-1 monooxygenase|cytochrome P-450HK-omega|cytochrome P450, family 4, subfamily A, polypeptide 11|cytochrome P450, subfamily IVA, polypeptide 11|cytochrome P450HL-omega|fatty acid omega-hydroxylase|lauric acid omega-hydroxylase|long-chain fatty acid omega-monooxygenase', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46929177, end_position_on_the_genomic_accession=46941476, orientation='minus', exon_count=13, OMIM=[601310], no_hdr0=''),
    1580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1580, CurrentID=0, Status='live', Symbol='CYP4B1', Aliases=['CYPIVB1', 'P-450HP'], description='cytochrome P450 family 4 subfamily B member 1', other_designations='cytochrome P450 4B1|cytochrome P450, family 4, subfamily B, polypeptide 1|cytochrome P450, subfamily IVB, polypeptide 1|cytochrome P450-HP|microsomal monooxygenase', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46799046, end_position_on_the_genomic_accession=46819413, orientation='plus', exon_count=12, OMIM=[124075], no_hdr0=''),
    1581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1581, CurrentID=0, Status='live', Symbol='CYP7A1', Aliases=['CP7A', 'CYP7', 'CYPVII'], description='cytochrome P450 family 7 subfamily A member 1', other_designations='cytochrome P450 7A1|24-hydroxycholesterol 7-alpha-hydroxylase|cholesterol 7-alpha-hydroxylase|cholesterol 7-alpha-monooxygenase|cholesterol 7alpha-hydroxylase|cytochrome P450, family 7, subfamily A, polypeptide 1|cytochrome P450, subfamily VIIA polypeptide 1', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=58490178, end_position_on_the_genomic_accession=58500163, orientation='minus', exon_count=6, OMIM=[118455], no_hdr0=''),
    1582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1582, CurrentID=0, Status='live', Symbol='CYP8B1', Aliases=['CP8B', 'CYP12'], description='cytochrome P450 family 8 subfamily B member 1', other_designations='7-alpha-hydroxycholest-4-en-3-one 12-alpha-hydroxylase|7 alpha-hydroxy-4-cholesten-3-one 12-alpha-hydroxylase|CYPVIIIB1|cytochrome P450 8B1|cytochrome P450, family 8, subfamily B, polypeptide 1|cytochrome P450, subfamily VIIIB (sterol 12-alpha-hydroxylase), polypeptide 1|sterol 12-alpha-hydroxylase', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42872192, end_position_on_the_genomic_accession=42875879, orientation='minus', exon_count=1, OMIM=[602172], no_hdr0=''),
    1583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1583, CurrentID=0, Status='live', Symbol='CYP11A1', Aliases=['CYP11A', 'CYPXIA1', 'P450SCC'], description='cytochrome P450 family 11 subfamily A member 1', other_designations='cholesterol side-chain cleavage enzyme, mitochondrial|cholesterol 20-22 desmolase|cholesterol monooxygenase (side-chain cleaving)|cytochrome P450 11A1|cytochrome P450 family 11 subfamily A polypeptide 1|cytochrome P450(scc)|cytochrome P450, subfamily XIA (cholesterol side chain cleavage)|steroid 20-22-lyase', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74337762, end_position_on_the_genomic_accession=74367646, orientation='minus', exon_count=10, OMIM=[118485], no_hdr0=''),
    1584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1584, CurrentID=0, Status='live', Symbol='CYP11B1', Aliases=['CPN1', 'CYP11B', 'FHI', 'P450C11'], description='cytochrome P450 family 11 subfamily B member 1', other_designations='cytochrome P450 11B1, mitochondrial|cytochrome P-450c11|cytochrome P450, family 11, subfamily B, polypeptide 1|cytochrome P450, subfamily XIB (steroid 11-beta-hydroxylase), polypeptide 1|cytochrome P450C11|cytochrome p450 XIB1|steroid 11-beta-hydroxylase, CYP11B1|steroid 11-beta-monooxygenase', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142872357, end_position_on_the_genomic_accession=142879825, orientation='minus', exon_count=9, OMIM=[610613], no_hdr0=''),
    1585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1585, CurrentID=0, Status='live', Symbol='CYP11B2', Aliases=['ALDOS', 'CPN2', 'CYP11B', 'CYP11BL', 'CYPXIB2', 'P-450C18', 'P450C18', 'P450aldo'], description='cytochrome P450 family 11 subfamily B member 2', other_designations='cytochrome P450 11B2, mitochondrial|aldosterone synthase|aldosterone-synthesizing enzyme|corticosterone 18-monooxygenase, CYP11B2|cytochrome P-450Aldo|cytochrome P-450C18|cytochrome P450, family 11, subfamily B, polypeptide 2|cytochrome P450, subfamily XIB (steroid 11-beta-hydroxylase), polypeptide 2|mitochondrial cytochrome P450, family 11, subfamily B, polypeptide 2|steroid 11-beta-hydroxylase, CYP11B2|steroid 11-beta-monooxygenase|steroid 11-beta/18-hydroxylase|steroid 18-hydroxylase, aldosterone synthase, P450C18, P450aldo', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142910559, end_position_on_the_genomic_accession=142917843, orientation='minus', exon_count=9, OMIM=[124080], no_hdr0=''),
    1586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1586, CurrentID=0, Status='live', Symbol='CYP17A1', Aliases=['CPT7', 'CYP17', 'P450C17', 'S17AH'], description='cytochrome P450 family 17 subfamily A member 1', other_designations='steroid 17-alpha-hydroxylase/17,20 lyase|17-alpha-hydroxyprogesterone aldolase|CYPXVII|cytochrome P450 17A1|cytochrome P450, family 17, subfamily A, polypeptide 1|cytochrome P450, subfamily XVII (steroid 17-alpha-hydroxylase), adrenal hyperplasia|cytochrome P450-C17|cytochrome P450c17|cytochrome p450 XVIIA1|steroid 17-alpha-monooxygenase', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102830531, end_position_on_the_genomic_accession=102837413, orientation='minus', exon_count=8, OMIM=[609300], no_hdr0=''),
    1588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1588, CurrentID=0, Status='live', Symbol='CYP19A1', Aliases=['ARO', 'ARO1', 'CPV1', 'CYAR', 'CYP19', 'CYPXIX', 'P-450AROM'], description='cytochrome P450 family 19 subfamily A member 1', other_designations='aromatase|cytochrome P-450AROM|cytochrome P450 19A1|cytochrome P450, family 19, subfamily A, polypeptide 1|cytochrome P450, subfamily XIX (aromatization of androgens)|estrogen synthase|estrogen synthetase|flavoprotein-linked monooxygenase|microsomal monooxygenase', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51208057, end_position_on_the_genomic_accession=51338596, orientation='minus', exon_count=18, OMIM=[107910], no_hdr0=''),
    1589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1589, CurrentID=0, Status='live', Symbol='CYP21A2', Aliases=['CA21H', 'CAH1', 'CPS1', 'CYP21', 'CYP21B', 'P450c21B'], description='cytochrome P450 family 21 subfamily A member 2', other_designations='steroid 21-hydroxylase|21-OHase|cytochrome P450 XXI|cytochrome P450, family 21, subfamily A, polypeptide 2|cytochrome P450, subfamily XXIA (steroid 21-hydroxylase, congenital adrenal hyperplasia), polypeptide 2|cytochrome P450-C21B|steroid 21 hydroxylase|steroid 21-monooxygenase', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32038415, end_position_on_the_genomic_accession=32041644, orientation='plus', exon_count=10, OMIM=[613815], no_hdr0=''),
    1591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1591, CurrentID=0, Status='live', Symbol='CYP24A1', Aliases=['CP24', 'CYP24', 'HCAI', 'HCINF1', 'P450-CC24'], description='cytochrome P450 family 24 subfamily A member 1', other_designations='1,25-dihydroxyvitamin D(3) 24-hydroxylase, mitochondrial|1,25-@dihydroxyvitamin D3 24-hydroxylase|24-OHase|cytochrome P450 24A1|cytochrome P450, family 24, subfamily A, polypeptide 1|cytochrome P450, subfamily XXIV (vitamin D 24-hydroxylase)|cytochrome P450-CC24|exo-mitochondrial protein|vitamin D 24-hydroxylase|vitamin D(3) 24-hydroxylase', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=54145731, end_position_on_the_genomic_accession=54174032, orientation='minus', exon_count=13, OMIM=[126065], no_hdr0=''),
    1592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1592, CurrentID=0, Status='live', Symbol='CYP26A1', Aliases=['CP26', 'CYP26', 'P450RAI', 'P450RAI1'], description='cytochrome P450 family 26 subfamily A member 1', other_designations='cytochrome P450 26A1|P450, retinoic acid-inactivating, 1|cytochrome P450 retinoic acid-inactivating 1|cytochrome P450, family 26, subfamily A, polypeptide 1|cytochrome P450, subfamily XXVIA, polypeptide 1|cytochrome P450RAI|hP450RAI|retinoic acid 4-hydroxylase|retinoic acid-metabolizing cytochrome', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93073475, end_position_on_the_genomic_accession=93077885, orientation='plus', exon_count=8, OMIM=[602239], no_hdr0=''),
    1593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1593, CurrentID=0, Status='live', Symbol='CYP27A1', Aliases=['CP27', 'CTX', 'CYP27'], description='cytochrome P450 family 27 subfamily A member 1', other_designations='sterol 26-hydroxylase, mitochondrial|5-beta-cholestane-3-alpha, 7-alpha, 12-alpha-triol 26-hydroxylase|5-beta-cholestane-3-alpha, 7-alpha, 12-alpha-triol 27-hydroxylase|cholestanetriol 26-monooxygenase|cytochrome P-450C27/25|cytochrome P450 27|cytochrome P450, family 27, subfamily A, polypeptide 1|cytochrome P450, subfamily XXVIIA (steroid 27-hydroxylase, cerebrotendinous xanthomatosis), polypeptide 1|sterol 27-hydroxylase|vitamin D(3) 25-hydroxylase', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218781733, end_position_on_the_genomic_accession=218815293, orientation='plus', exon_count=9, OMIM=[606530], no_hdr0=''),
    1594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1594, CurrentID=0, Status='live', Symbol='CYP27B1', Aliases=['CP2B', 'CYP1', 'CYP1alpha', 'CYP27B', 'P450c1', 'PDDR', 'VDD1', 'VDDR', 'VDDRI', 'VDR'], description='cytochrome P450 family 27 subfamily B member 1', other_designations='25-hydroxyvitamin D-1 alpha hydroxylase, mitochondrial|1alpha(OH)ase|25 hydroxyvitamin D3-1-alpha hydroxylase|25-OHD-1 alpha-hydroxylase|VD3 1A hydroxylase|calcidiol 1-monooxygenase|cytochrome P450 subfamily XXVIIB polypeptide 1|cytochrome P450, family 27, subfamily B, polypeptide 1|cytochrome P450C1 alpha|cytochrome P450VD1-alpha|cytochrome p450 27B1', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57762334, end_position_on_the_genomic_accession=57767078, orientation='minus', exon_count=9, OMIM=[609506], no_hdr0=''),
    1595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1595, CurrentID=0, Status='live', Symbol='CYP51A1', Aliases=['CP51', 'CYP51', 'CYPL1', 'LDM', 'P450-14DM', 'P450L1'], description='cytochrome P450 family 51 subfamily A member 1', other_designations='lanosterol 14-alpha demethylase|CYPLI|cytochrome P450 51A1|cytochrome P450, 51 (lanosterol 14-alpha-demethylase)|cytochrome P450, family 51, subfamily A, polypeptide 1|cytochrome P450-14DM|cytochrome P45014DM|cytochrome P450LI|sterol 14-alpha demethylase', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92112153, end_position_on_the_genomic_accession=92134803, orientation='minus', exon_count=11, OMIM=[601637], no_hdr0=''),
    1600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1600, CurrentID=0, Status='live', Symbol='DAB1', Aliases=['SCA37'], description='DAB adaptor protein 1', other_designations='disabled homolog 1|DAB1, reelin adaptor protein|Dab reelin signal transducer 1|Dab, reelin signal transducer, homolog 1', map_location='1p32.2-p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56994778, end_position_on_the_genomic_accession=58546726, orientation='minus', exon_count=27, OMIM=[603448], no_hdr0=''),
    1601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1601, CurrentID=0, Status='live', Symbol='DAB2', Aliases=['DOC-2', 'DOC2'], description='DAB adaptor protein 2', other_designations='disabled homolog 2|DAB2, clathrin adaptor protein|Dab, mitogen-responsive phosphoprotein, homolog 2|adaptor molecule disabled-2|differentially expressed in ovarian carcinoma 2|differentially-expressed protein 2|disabled homolog 2, mitogen-responsive phosphoprotein', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=39371677, end_position_on_the_genomic_accession=39424980, orientation='minus', exon_count=15, OMIM=[601236], no_hdr0=''),
    1602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1602, CurrentID=0, Status='live', Symbol='DACH1', Aliases=['DACH'], description='dachshund family transcription factor 1', other_designations='dachshund homolog 1|dac homolog', map_location='13q21.33', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=71437966, end_position_on_the_genomic_accession=71868068, orientation='minus', exon_count=15, OMIM=[603803], no_hdr0=''),
    1603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1603, CurrentID=0, Status='live', Symbol='DAD1', Aliases=['OST2'], description='defender against cell death 1', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit DAD1|DAD-1|oligosaccharyl transferase subunit DAD1|oligosaccharyltransferase 2 homolog|oligosaccharyltransferase subunit 2 (non-catalytic)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22564907, end_position_on_the_genomic_accession=22589224, orientation='minus', exon_count=3, OMIM=[600243], no_hdr0=''),
    1604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1604, CurrentID=0, Status='live', Symbol='CD55', Aliases=['CHAPLE', 'CR', 'CROM', 'DAF', 'TC'], description='CD55 molecule (Cromer blood group)', other_designations='complement decay-accelerating factor|CD55 antigen|CD55 molecule, decay accelerating factor for complement (Cromer blood group)|Cromer blood group antigen|Rh blood group D antigen', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207321674, end_position_on_the_genomic_accession=207360966, orientation='plus', exon_count=15, OMIM=[125240], no_hdr0=''),
    1605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1605, CurrentID=0, Status='live', Symbol='DAG1', Aliases=['156DAG', 'A3a', 'AGRNR', 'DAG', 'LGMDR16', 'MDDGA9', 'MDDGC7', 'MDDGC9'], description='dystroglycan 1', other_designations='dystroglycan|dystroglycan 1 (dystrophin-associated glycoprotein 1)', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49468703, end_position_on_the_genomic_accession=49535618, orientation='plus', exon_count=9, OMIM=[128239], no_hdr0=''),
    1606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1606, CurrentID=0, Status='live', Symbol='DGKA', Aliases=['DAGK', 'DAGK1', 'DGK-alpha'], description='diacylglycerol kinase alpha', other_designations='diacylglycerol kinase alpha|80 kDa diacylglycerol kinase|DAG kinase alpha|diacylglycerol kinase, alpha 80kDa|diglyceride kinase alpha', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55931091, end_position_on_the_genomic_accession=55954023, orientation='plus', exon_count=32, OMIM=[125855], no_hdr0=''),
    1607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1607, CurrentID=0, Status='live', Symbol='DGKB', Aliases=['DAGK2', 'DGK', 'DGK-BETA'], description='diacylglycerol kinase beta', other_designations='diacylglycerol kinase beta|90 kDa diacylglycerol kinase|DAG kinase beta|diacylglycerol kinase, beta 90kDa|diglyceride kinase beta', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=14145049, end_position_on_the_genomic_accession=14974858, orientation='minus', exon_count=32, OMIM=[604070], no_hdr0=''),
    1608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1608, CurrentID=0, Status='live', Symbol='DGKG', Aliases=['DAGK3', 'DGK-GAMMA'], description='diacylglycerol kinase gamma', other_designations='diacylglycerol kinase gamma|DAG kinase gamma|diacylglycerol kinase, gamma 90kDa|diacylglyerol kinase gamma|diglyceride kinase gamma', map_location='3q27.2-q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186147201, end_position_on_the_genomic_accession=186362234, orientation='minus', exon_count=25, OMIM=[601854], no_hdr0=''),
    1609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1609, CurrentID=0, Status='live', Symbol='DGKQ', Aliases=['DAGK', 'DAGK4', 'DAGK7'], description='diacylglycerol kinase theta', other_designations='diacylglycerol kinase theta|DAG kinase theta|DGK-theta|DGKtheta|diacylglycerol kinase, theta 110kDa|diglyceride kinase theta|testis tissue sperm-binding protein Li 38a', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=958887, end_position_on_the_genomic_accession=973569, orientation='minus', exon_count=25, OMIM=[601207], no_hdr0=''),
    1610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1610, CurrentID=0, Status='live', Symbol='DAO', Aliases=['DAAO', 'DAMOX', 'OXDA'], description='D-amino acid oxidase', other_designations='D-amino-acid oxidase', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108880030, end_position_on_the_genomic_accession=108901043, orientation='plus', exon_count=12, OMIM=[124050], no_hdr0=''),
    1611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1611, CurrentID=0, Status='live', Symbol='DAP', Aliases=[], description='death associated protein', other_designations='death-associated protein 1|DAP-1', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10679230, end_position_on_the_genomic_accession=10761234, orientation='minus', exon_count=4, OMIM=[600954], no_hdr0=''),
    1612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1612, CurrentID=0, Status='live', Symbol='DAPK1', Aliases=['DAPK', 'ROCO3'], description='death associated protein kinase 1', other_designations='death-associated protein kinase 1|DAP kinase 1', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=87497228, end_position_on_the_genomic_accession=87708634, orientation='plus', exon_count=31, OMIM=[600831], no_hdr0=''),
    1613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1613, CurrentID=0, Status='live', Symbol='DAPK3', Aliases=['DLK', 'ZIP', 'ZIPK'], description='death associated protein kinase 3', other_designations='death-associated protein kinase 3|DAP kinase 3|DAP-like kinase|MYPT1 kinase|ZIP-kinase|zipper-interacting protein kinase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3958453, end_position_on_the_genomic_accession=3971099, orientation='minus', exon_count=9, OMIM=[603289], no_hdr0=''),
    1615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1615, CurrentID=0, Status='live', Symbol='DARS1', Aliases=['DARS', 'HBSL', 'aspRS'], description='aspartyl-tRNA synthetase 1', other_designations='aspartate--tRNA ligase, cytoplasmic|aspartate tRNA ligase 1, cytoplasmic|aspartyl-tRNA synthetase, cytoplasmic|cell proliferation-inducing gene 40 protein|testicular tissue protein Li 192', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135905881, end_position_on_the_genomic_accession=135985684, orientation='minus', exon_count=16, OMIM=[603084], no_hdr0=''),
    1616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1616, CurrentID=0, Status='live', Symbol='DAXX', Aliases=['BING2', 'DAP6', 'EAP1', 'SMIM40'], description='death domain associated protein', other_designations='death domain-associated protein 6|CENP-C binding protein|ETS1-associated protein 1|Fas-binding protein|death-associated protein 6|fas death domain-associated protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33318558, end_position_on_the_genomic_accession=33322959, orientation='minus', exon_count=8, OMIM=[603186], no_hdr0=''),
    1617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1617, CurrentID=0, Status='live', Symbol='DAZ1', Aliases=['DAZ', 'SPGY'], description='deleted in azoospermia 1', other_designations='deleted in azoospermia protein 1|testicular tissue protein Li 49', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=23129355, end_position_on_the_genomic_accession=23199117, orientation='minus', exon_count=28, OMIM=[400003], no_hdr0=''),
    1618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1618, CurrentID=0, Status='live', Symbol='DAZL', Aliases=['DAZH1', 'DAZLA', 'SPGYLA', 'DAZL'], description='deleted in azoospermia like', other_designations='deleted in azoospermia-like|DAZ homolog|DAZ-like autosomal|SPGY-like-autosomal|deleted in azoospermia-like 1|germline specific RNA binding protein|spermatogenesis gene on the Y-like autosomal|testis secretory sperm-binding protein Li 204a', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16586792, end_position_on_the_genomic_accession=16605423, orientation='minus', exon_count=12, OMIM=[601486], no_hdr0=''),
    1620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1620, CurrentID=0, Status='live', Symbol='BRINP1', Aliases=['DBC1', 'DBCCR1', 'FAM5A'], description='BMP/retinoic acid inducible neural specific 1', other_designations='BMP/retinoic acid-inducible neural-specific protein 1|bA574M5.1 (deleted in bladder cancer chromosome region candidate 1 (IB3089A))|bone morphogenetic protein/retinoic acid inducible neural-specific 1|bone morphogenic protein/retinoic acid inducible neural-specific 1|deleted in bladder cancer 1|deleted in bladder cancer chromosome region candidate 1|deleted in bladder cancer protein 1', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=119166629, end_position_on_the_genomic_accession=119369435, orientation='minus', exon_count=8, OMIM=[602865], no_hdr0=''),
    1621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1621, CurrentID=0, Status='live', Symbol='DBH', Aliases=['DBM', 'ORTHYP1'], description='dopamine beta-hydroxylase', other_designations='dopamine beta-hydroxylase|dopamine beta-hydroxylase (dopamine beta-monooxygenase)', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133636363, end_position_on_the_genomic_accession=133659329, orientation='plus', exon_count=12, OMIM=[609312], no_hdr0=''),
    1622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1622, CurrentID=0, Status='live', Symbol='DBI', Aliases=['ACBD1', 'ACBP', 'CCK-RP', 'EP'], description='diazepam binding inhibitor, acyl-CoA binding protein', other_designations='acyl-CoA-binding protein|GABA receptor modulator|acyl coenzyme A binding protein|acyl-Coenzyme A binding domain containing 1|cholecystokinin-releasing peptide, trypsin-sensitive|diazepam binding inhibitor (GABA receptor modulator, acyl-CoA binding protein)|diazepam binding inhibitor (GABA receptor modulator, acyl-Coenzyme A binding protein)|diazepam-binding inhibitor|endozepine|epididymis secretory sperm binding protein', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119366977, end_position_on_the_genomic_accession=119372543, orientation='plus', exon_count=7, OMIM=[125950], no_hdr0=''),
    1627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1627, CurrentID=0, Status='live', Symbol='DBN1', Aliases=['D0S117E'], description='drebrin 1', other_designations='drebrin|developmentally-regulated brain protein|drebrin A|drebrin E|drebrin E2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177456610, end_position_on_the_genomic_accession=177480368, orientation='minus', exon_count=19, OMIM=[126660], no_hdr0=''),
    1628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1628, CurrentID=0, Status='live', Symbol='DBP', Aliases=['DABP', 'taxREB302'], description='D-box binding PAR bZIP transcription factor', other_designations='D site-binding protein|D site of albumin promoter (albumin D-box) binding protein|albumin D box-binding protein|albumin D-element-binding protein|tax-responsive enhancer element-binding protein 302', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48630030, end_position_on_the_genomic_accession=48637379, orientation='minus', exon_count=4, OMIM=[124097], no_hdr0=''),
    1629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1629, CurrentID=0, Status='live', Symbol='DBT', Aliases=['BCATE2', 'BCKAD-E2', 'BCKADE2', 'BCKDH-E2', 'BCOADC-E2', 'E2', 'E2B'], description='dihydrolipoamide branched chain transacylase E2', other_designations='lipoamide acyltransferase component of branched-chain alpha-keto acid dehydrogenase complex, mitochondrial|52 kDa mitochondrial autoantigen of primary biliary cirrhosis|BCKAD E2 subunit|E2 component of branched chain alpha-keto acid dehydrogenase complex|branched chain 2-oxo-acid dehydrogenase complex component E2|branched chain acyltransferase, E2 component|branched-chain alpha-keto acid dehydrogenase complex component E2|dihydrolipoamide acetyltransferase component of branched-chain alpha-keto acid dehydrogenase complex|dihydrolipoyl transacylase|dihydrolipoyllysine-residue (2-methylpropanoyl)transferase|lipoamide acyltransferase component of mitochondrial branched-chain alpha-keto acid dehydrogenase complex|mitochondrial branched chain alpha-keto acid dehydrogenase transacylase subunit (E2b)', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100186919, end_position_on_the_genomic_accession=100249864, orientation='minus', exon_count=14, OMIM=[248610], no_hdr0=''),
    1630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1630, CurrentID=0, Status='live', Symbol='DCC', Aliases=['CRC18', 'CRCR1', 'HGPPS2', 'IGDCC1', 'MRMV1', 'NTN1R1'], description='DCC netrin 1 receptor', other_designations='netrin receptor DCC|colorectal cancer suppressor|deleted in colorectal carcinoma|immunoglobulin superfamily DCC subclass member 1|putative colorectal tumor suppressor|tumor suppressor protein DCC', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=52340172, end_position_on_the_genomic_accession=53535899, orientation='plus', exon_count=32, OMIM=[120470], no_hdr0=''),
    1632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1632, CurrentID=0, Status='live', Symbol='ECI1', Aliases=['DCI'], description='enoyl-CoA delta isomerase 1', other_designations='enoyl-CoA delta isomerase 1, mitochondrial|3,2 trans-enoyl-Coenzyme A isomerase|3,2-trans-enoyl-CoA isomerase, mitochondrial|D3,D2-enoyl-CoA isomerase|acetylene-allene isomerase|delta(3),Delta(2)-enoyl-CoA isomerase|dodecenoyl-CoA delta isomerase (3,2 trans-enoyl-CoA isomerase)|dodecenoyl-Coenzyme A delta isomerase (3,2 trans-enoyl-Coenzyme A isomerase)|epididymis secretory sperm binding protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2239402, end_position_on_the_genomic_accession=2251587, orientation='minus', exon_count=7, OMIM=[600305], no_hdr0=''),
    1633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1633, CurrentID=0, Status='live', Symbol='DCK', Aliases=[], description='deoxycytidine kinase', other_designations='deoxycytidine kinase|deoxyadenosine kinase|deoxyguanosine kinase|deoxynucleoside kinase', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70993649, end_position_on_the_genomic_accession=71030914, orientation='plus', exon_count=7, OMIM=[125450], no_hdr0=''),
    1634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1634, CurrentID=0, Status='live', Symbol='DCN', Aliases=['CSCD', 'DSPG2', 'PG40', 'PGII', 'PGS2', 'SLRR1B'], description='decorin', other_designations='decorin|bone proteoglycan II|dermatan sulphate proteoglycans II|proteoglycan core protein|small leucine-rich protein 1B', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=91140484, end_position_on_the_genomic_accession=91182817, orientation='minus', exon_count=9, OMIM=[125255], no_hdr0=''),
    1635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1635, CurrentID=0, Status='live', Symbol='DCTD', Aliases=[], description='dCMP deaminase', other_designations='deoxycytidylate deaminase', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=182890091, end_position_on_the_genomic_accession=182917611, orientation='minus', exon_count=9, OMIM=[607638], no_hdr0=''),
    1636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1636, CurrentID=0, Status='live', Symbol='ACE', Aliases=['ACE1', 'CD143', 'DCP', 'DCP1'], description='angiotensin I converting enzyme', other_designations='angiotensin-converting enzyme|CD143 antigen|angiotensin I converting enzyme (peptidyl-dipeptidase A) 1|carboxycathepsin|dipeptidyl carboxypeptidase 1|dipeptidyl carboxypeptidase I|kininase II|peptidase P', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63477061, end_position_on_the_genomic_accession=63498373, orientation='plus', exon_count=26, OMIM=[106180], no_hdr0=''),
    1638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1638, CurrentID=0, Status='live', Symbol='DCT', Aliases=['OCA8', 'TRP-2', 'TYRP2'], description='dopachrome tautomerase', other_designations='L-dopachrome tautomerase|DT|L-dopachrome Delta-isomerase|L-dopachrome isomerase|TRP2|dopachrome delta-isomerase|dopachrome tautomerase (dopachrome delta-isomerase, tyrosine-related protein 2)|tyrosinase related protein-2|tyrosine-related protein 2', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=94436811, end_position_on_the_genomic_accession=94549406, orientation='minus', exon_count=14, OMIM=[191275], no_hdr0=''),
    1639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1639, CurrentID=0, Status='live', Symbol='DCTN1', Aliases=['DAP-150', 'DP-150', 'P135'], description='dynactin subunit 1', other_designations='dynactin subunit 1|150 kDa dynein-associated polypeptide|dynactin 1 (p150, glued homolog, Drosophila)', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74361155, end_position_on_the_genomic_accession=74391866, orientation='minus', exon_count=32, OMIM=[601143], no_hdr0=''),
    1641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1641, CurrentID=0, Status='live', Symbol='DCX', Aliases=['DBCN', 'DC', 'LISX', 'SCLH', 'XLIS'], description='doublecortin', other_designations='neuronal migration protein doublecortin|doublecortex|doublin|lis-X|lissencephalin-X', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111293779, end_position_on_the_genomic_accession=111412205, orientation='minus', exon_count=9, OMIM=[300121], no_hdr0=''),
    1642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1642, CurrentID=0, Status='live', Symbol='DDB1', Aliases=['DDBA', 'UV-DDB1', 'XAP1', 'XPCE', 'XPE', 'XPE-BF'], description='damage specific DNA binding protein 1', other_designations='DNA damage-binding protein 1|DDB p127 subunit|DNA damage-binding protein a|HBV X-associated protein 1|UV-DDB 1|UV-damaged DNA-binding factor|UV-damaged DNA-binding protein 1|XAP-1|XPE-binding factor|damage-specific DNA binding protein 1, 127kDa|xeroderma pigmentosum group E-complementing protein', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61299451, end_position_on_the_genomic_accession=61333105, orientation='minus', exon_count=27, OMIM=[600045], no_hdr0=''),
    1643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1643, CurrentID=0, Status='live', Symbol='DDB2', Aliases=['DDBB', 'UV-DDB2', 'XPE'], description='damage specific DNA binding protein 2', other_designations='DNA damage-binding protein 2|DDB p48 subunit|UV-DDB 2|UV-damaged DNA-binding protein 2|damage-specific DNA binding protein 2, 48kDa|xeroderma pigmentosum group E protein', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47214969, end_position_on_the_genomic_accession=47239218, orientation='plus', exon_count=10, OMIM=[600811], no_hdr0=''),
    1644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1644, CurrentID=0, Status='live', Symbol='DDC', Aliases=['AADC'], description='dopa decarboxylase', other_designations='aromatic-L-amino-acid decarboxylase|dopa decarboxylase (aromatic L-amino acid decarboxylase)', map_location='7p12.2-p12.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=50458436, end_position_on_the_genomic_accession=50565460, orientation='minus', exon_count=18, OMIM=[107930], no_hdr0=''),
    1645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1645, CurrentID=0, Status='live', Symbol='AKR1C1', Aliases=['2-ALPHA-HSD', '20-ALPHA-HSD', 'C9', 'DD1', 'DD1/DD2', 'DDH', 'DDH1', 'H-37', 'HAKRC', 'HBAB', 'MBAB'], description='aldo-keto reductase family 1 member C1', other_designations='aldo-keto reductase family 1 member C1|20 alpha-hydroxysteroid dehydrogenase|aldo-keto reductase C|chlordecone reductase homolog HAKRC|dihydrodiol dehydrogenase 1|dihydrodiol dehydrogenase 1/2|dihydrodiol dehydrogenase 1; 20-alpha (3-alpha)-hydroxysteroid dehydrogenase|hepatic dihydrodiol dehydrogenase|high-affinity hepatic bile acid-binding protein|indanol dehydrogenase|trans-1,2-dihydrobenzene-1,2-diol dehydrogenase|type II 3-alpha-hydroxysteroid dehydrogenase', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=4963415, end_position_on_the_genomic_accession=4983283, orientation='plus', exon_count=9, OMIM=[600449], no_hdr0=''),
    1646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1646, CurrentID=0, Status='live', Symbol='AKR1C2', Aliases=['AKR1C-pseudo', 'BABP', 'DD', 'DD-2', 'DD/BABP', 'DD2', 'DDH2', 'HAKRD', 'HBAB', 'MCDR2', 'SRXY8', 'TDD'], description='aldo-keto reductase family 1 member C2', other_designations='aldo-keto reductase family 1 member C2|3-alpha-HSD3|chlordecone reductase homolog HAKRD|dihydrodiol dehydrogenase 2; bile acid binding protein; 3-alpha hydroxysteroid dehydrogenase, type III|pseudo-chlordecone reductase|testicular 17,20-desmolase deficiency|trans-1,2-dihydrobenzene-1,2-diol dehydrogenase|type II dihydrodiol dehydrogenase', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=4987775, end_position_on_the_genomic_accession=5018000, orientation='minus', exon_count=12, OMIM=[600450], no_hdr0=''),
    1647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1647, CurrentID=0, Status='live', Symbol='GADD45A', Aliases=['DDIT1', 'GADD45'], description='growth arrest and DNA damage inducible alpha', other_designations='growth arrest and DNA damage-inducible protein GADD45 alpha|DDIT-1|DNA damage-inducible transcript 1 protein|DNA damage-inducible transcript-1|growth arrest and DNA-damage-inducible 45 alpha', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67685201, end_position_on_the_genomic_accession=67688334, orientation='plus', exon_count=4, OMIM=[126335], no_hdr0=''),
    1649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1649, CurrentID=0, Status='live', Symbol='DDIT3', Aliases=['AltDDIT3', 'C/EBPzeta', 'CEBPZ', 'CHOP', 'CHOP-10', 'CHOP10', 'GADD153'], description='DNA damage inducible transcript 3', other_designations='DNA damage-inducible transcript 3 protein|C/EBP zeta|CCAAT/enhancer-binding protein homologous protein|alternative DDIT3 protein|c/EBP-homologous protein 10|growth arrest and DNA damage-inducible protein GADD153', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57516588, end_position_on_the_genomic_accession=57520517, orientation='minus', exon_count=4, OMIM=[126337], no_hdr0=''),
    1650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1650, CurrentID=0, Status='live', Symbol='DDOST', Aliases=['AGER1', 'CDG1R', 'GATD6', 'OKSWcl45', 'OST', 'OST48', 'WBP1'], description='dolichyl-diphosphooligosaccharide--protein glycosyltransferase non-catalytic subunit', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase 48 kDa subunit|advanced glycation end-product receptor 1|advanced glycation endproduct receptor 1|dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit (non-catalytic)|dolichyl-diphosphooligosaccharide-protein glycotransferase|oligosaccharyl transferase 48 kDa subunit|oligosaccharyltransferase 48 kDa subunit|oligosaccharyltransferase subunit 48', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20651777, end_position_on_the_genomic_accession=20661369, orientation='minus', exon_count=11, OMIM=[602202], no_hdr0=''),
    1652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1652, CurrentID=0, Status='live', Symbol='DDT', Aliases=['D-DT', 'DDCT', 'MIF-2', 'MIF2'], description='D-dopachrome tautomerase', other_designations='D-dopachrome decarboxylase|phenylpyruvate tautomerase II', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23971370, end_position_on_the_genomic_accession=23979828, orientation='minus', exon_count=5, OMIM=[602750], no_hdr0=''),
    1653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1653, CurrentID=0, Status='live', Symbol='DDX1', Aliases=['DBP-RB', 'UKVH5d'], description='DEAD-box helicase 1', other_designations='ATP-dependent RNA helicase DDX1|DEAD (Asp-Glu-Ala-Asp) box helicase 1|DEAD (Asp-Glu-Ala-Asp) box polypeptide 1|DEAD box polypeptide 1|DEAD box protein 1|DEAD box protein retinoblastoma|DEAD box-1|DEAD-box RNA helicase DDX1|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 1|DEAD/H-box helicase 1', map_location='2p24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=15591868, end_position_on_the_genomic_accession=15631101, orientation='plus', exon_count=26, OMIM=[601257], no_hdr0=''),
    1654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1654, CurrentID=0, Status='live', Symbol='DDX3X', Aliases=['CAP-Rf', 'DBX', 'DDX14', 'DDX3', 'HLP2', 'MRX102', 'MRXSSB'], description='DEAD-box helicase 3 X-linked', other_designations='ATP-dependent RNA helicase DDX3X|DEAD (Asp-Glu-Ala-Asp) box helicase 3, X-linked|DEAD (Asp-Glu-Ala-Asp) box polypeptide 3, X-linked|DEAD box protein 3, X-chromosomal|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 3|DEAD/H box-3|helicase-like protein 2', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41333308, end_position_on_the_genomic_accession=41364472, orientation='plus', exon_count=20, OMIM=[300160], no_hdr0=''),
    1655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1655, CurrentID=0, Status='live', Symbol='DDX5', Aliases=['G17P1', 'HLR1', 'HUMP68', 'p68'], description='DEAD-box helicase 5', other_designations='probable ATP-dependent RNA helicase DDX5|ATP-dependent RNA helicase DDX5|DEAD (Asp-Glu-Ala-Asp) box helicase 5|DEAD (Asp-Glu-Ala-Asp) box polypeptide 5|DEAD box protein 5|DEAD box-5|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 5 (RNA helicase, 68kD)|RNA helicase p68', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64498254, end_position_on_the_genomic_accession=64506866, orientation='minus', exon_count=16, OMIM=[180630], no_hdr0=''),
    1656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1656, CurrentID=0, Status='live', Symbol='DDX6', Aliases=['HLR2', 'IDDILF', 'P54', 'RCK', 'Rck/p54'], description='DEAD-box helicase 6', other_designations='probable ATP-dependent RNA helicase DDX6|ATP-dependent RNA helicase p54|DEAD (Asp-Glu-Ala-Asp) box helicase 6|DEAD (Asp-Glu-Ala-Asp) box polypeptide 6|DEAD box protein 6|DEAD box-6|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 6 (RNA helicase, 54kD)|oncogene RCK', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118747763, end_position_on_the_genomic_accession=118791696, orientation='minus', exon_count=16, OMIM=[600326], no_hdr0=''),
    1657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1657, CurrentID=0, Status='live', Symbol='DMXL1', Aliases=[], description='Dmx like 1', other_designations='dmX-like protein 1', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=119071002, end_position_on_the_genomic_accession=119249432, orientation='plus', exon_count=47, OMIM=[605671], no_hdr0=''),
    1659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1659, CurrentID=0, Status='live', Symbol='DHX8', Aliases=['DDX8', 'Dhr2', 'HRH1', 'PRP22', 'PRPF22'], description='DEAH-box helicase 8', other_designations='ATP-dependent RNA helicase DHX8|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 8 (RNA helicase)|DEAH (Asp-Glu-Ala-His) box polypeptide 8|DEAH box protein 8|RNA helicase HRH1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43483975, end_position_on_the_genomic_accession=43544799, orientation='plus', exon_count=27, OMIM=[600396], no_hdr0=''),
    1660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1660, CurrentID=0, Status='live', Symbol='DHX9', Aliases=['DDX9', 'LKP', 'NDH2', 'NDHII', 'RHA'], description='DExH-box helicase 9', other_designations='ATP-dependent RNA helicase A|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 9|DEAH (Asp-Glu-Ala-His) box helicase 9|DEAH (Asp-Glu-Ala-His) box polypeptide 9|DEAH box protein 9|DEAH-box helicase 9|RNA helicase A|leukophysin|nuclear DNA helicase II', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182839347, end_position_on_the_genomic_accession=182887982, orientation='plus', exon_count=29, OMIM=[603115], no_hdr0=''),
    1662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1662, CurrentID=0, Status='live', Symbol='DDX10', Aliases=['Dbp4', 'HRH-J8'], description='DEAD-box helicase 10', other_designations='probable ATP-dependent RNA helicase DDX10|DDX10-NUP98 fusion protein type 2|DEAD (Asp-Glu-Ala-Asp) box polypeptide 10|DEAD box protein 10|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 10 (RNA helicase)', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108665069, end_position_on_the_genomic_accession=108940927, orientation='plus', exon_count=18, OMIM=[601235], no_hdr0=''),
    1663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1663, CurrentID=0, Status='live', Symbol='DDX11', Aliases=['CHL1', 'CHLR1', 'KRG2', 'WABS'], description='DEAD/H-box helicase 11', other_designations='ATP-dependent DNA helicase DDX11|CHL1-like helicase homolog|CHL1-related helicase gene-1|CHL1-related protein 1|DEAD/H (Asp-Glu-Ala-Asp/His) box helicase 11|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 11 (CHL1-like helicase homolog, S. cerevisiae)|DEAD/H box protein 11|KRG-2|hCHLR1|keratinocyte growth factor-regulated gene 2 protein|probable ATP-dependent DNA helicase DDX11|probable ATP-dependent RNA helicase DDX11', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31073860, end_position_on_the_genomic_accession=31104799, orientation='plus', exon_count=33, OMIM=[601150], no_hdr0=''),
    1665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1665, CurrentID=0, Status='live', Symbol='DHX15', Aliases=['DBP1', 'DDX15', 'PRP43', 'PRPF43', 'PrPp43p'], description='DEAH-box helicase 15', other_designations='pre-mRNA-splicing factor ATP-dependent RNA helicase DHX15|ATP-dependent RNA helicase #46|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 15|DEAD/H box-15|DEAH (Asp-Glu-Ala-His) box helicase 15|DEAH (Asp-Glu-Ala-His) box polypeptide 15|DEAH box protein 15|RNA helicase 2|putative pre-mRNA-splicing factor ATP-dependent RNA helicase DHX15', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=24527475, end_position_on_the_genomic_accession=24584554, orientation='minus', exon_count=14, OMIM=[603403], no_hdr0=''),
    1666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1666, CurrentID=0, Status='live', Symbol='DECR1', Aliases=['DECR', 'NADPH', 'SDR18C1'], description='2,4-dienoyl-CoA reductase 1', other_designations='2,4-dienoyl-CoA reductase [(3E)-enoyl-CoA-producing], mitochondrial|2,4-dienoyl-CoA reductase 1, mitochondrial|2,4-dienoyl-CoA reductase, mitochondrial|4-enoyl-CoA reductase|short chain dehydrogenase/reductase family 18C member 1', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90001437, end_position_on_the_genomic_accession=90053633, orientation='plus', exon_count=13, OMIM=[222745], no_hdr0=''),
    1667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1667, CurrentID=0, Status='live', Symbol='DEFA1', Aliases=['DEF1', 'DEFA2', 'HNP-1', 'HP-1', 'HP1', 'MRS'], description='defensin alpha 1', other_designations='neutrophil defensin 1|defensin, alpha 1, myeloid-related sequence|defensin, alpha 2|myeloid-related sequence', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6977649, end_position_on_the_genomic_accession=6980120, orientation='minus', exon_count=4, OMIM=[125220], no_hdr0=''),
    1668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1668, CurrentID=0, Status='live', Symbol='DEFA3', Aliases=['DEF3', 'HNP-3', 'HNP3', 'HP-3', 'HP3'], description='defensin alpha 3', other_designations='neutrophil defensin 3|defensin 3, neutrophil-specific|defensin, alpha 3, neutrophil-specific|neutrophil peptide 3', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7015869, end_position_on_the_genomic_accession=7018336, orientation='minus', exon_count=4, OMIM=[604522], no_hdr0=''),
    1669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1669, CurrentID=0, Status='live', Symbol='DEFA4', Aliases=['DEF4', 'HNP-4', 'HP-4', 'HP4'], description='defensin alpha 4', other_designations='neutrophil defensin 4|corticostatin|defensin, alpha 4, corticostatin|defensin, alpha 4, preproprotein', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6935820, end_position_on_the_genomic_accession=6938306, orientation='minus', exon_count=3, OMIM=[601157], no_hdr0=''),
    1670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1670, CurrentID=0, Status='live', Symbol='DEFA5', Aliases=['DEF5', 'HD-5'], description='defensin alpha 5', other_designations='defensin-5|HD5(20-94)|defensin, alpha 5, Paneth cell-specific|defensin, alpha 5, preproprotein', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7055304, end_position_on_the_genomic_accession=7056739, orientation='minus', exon_count=2, OMIM=[600472], no_hdr0=''),
    1671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1671, CurrentID=0, Status='live', Symbol='DEFA6', Aliases=['DEF6', 'HD-6'], description='defensin alpha 6', other_designations='defensin-6|defensin, alpha 6, Paneth cell-specific', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6924697, end_position_on_the_genomic_accession=6926076, orientation='minus', exon_count=2, OMIM=[600471], no_hdr0=''),
    1672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1672, CurrentID=0, Status='live', Symbol='DEFB1', Aliases=['BD1', 'DEFB-101', 'HBD1', 'DEFB1'], description='defensin beta 1', other_designations='beta-defensin 1|BD-1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6870592, end_position_on_the_genomic_accession=6877936, orientation='minus', exon_count=2, OMIM=[602056], no_hdr0=''),
    1673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1673, CurrentID=0, Status='live', Symbol='DEFB4A', Aliases=['BD-2', 'DEFB-2', 'DEFB102', 'DEFB2', 'DEFB4', 'HBD-2', 'SAP1'], description='defensin beta 4A', other_designations='beta-defensin 4A|beta defensin-2|defensin, beta 2|defensin, beta 4|skin-antimicrobial peptide 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7894677, end_position_on_the_genomic_accession=7896716, orientation='plus', exon_count=2, OMIM=[602215], no_hdr0=''),
    1674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1674, CurrentID=0, Status='live', Symbol='DES', Aliases=['CDCD3', 'CSM1', 'CSM2', 'LGMD1D', 'LGMD1E', 'LGMD2R'], description='desmin', other_designations='desmin|cardiomyopathy, dilated 1F (autosomal dominant)|epididymis secretory sperm binding protein|intermediate filament protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219418377, end_position_on_the_genomic_accession=219426734, orientation='plus', exon_count=9, OMIM=[125660], no_hdr0=''),
    1675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1675, CurrentID=0, Status='live', Symbol='CFD', Aliases=['ADIPSIN', 'ADN', 'DF', 'PFD'], description='complement factor D', other_designations='complement factor D|C3 convertase activator|D component of complement (adipsin)|complement factor D preproprotein|properdin factor D', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=859664, end_position_on_the_genomic_accession=863641, orientation='plus', exon_count=5, OMIM=[134350], no_hdr0=''),
    1676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1676, CurrentID=0, Status='live', Symbol='DFFA', Aliases=['DFF-45', 'DFF1', 'ICAD'], description='DNA fragmentation factor subunit alpha', other_designations='DNA fragmentation factor subunit alpha|DFF45|DNA fragmentation factor 45 kDa subunit|DNA fragmentation factor, 45kDa, alpha polypeptide|inhibitor of CAD', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10456522, end_position_on_the_genomic_accession=10472529, orientation='minus', exon_count=6, OMIM=[601882], no_hdr0=''),
    1677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1677, CurrentID=0, Status='live', Symbol='DFFB', Aliases=['CAD', 'CPAN', 'DFF-40', 'DFF2', 'DFF40'], description='DNA fragmentation factor subunit beta', other_designations='DNA fragmentation factor subunit beta|DNA fragmentation factor 40 kDa subunit|DNA fragmentation factor, 40kDa, beta polypeptide (caspase-activated DNase)|caspase-activated DNase|caspase-activated deoxyribonuclease|caspase-activated nuclease', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3857286, end_position_on_the_genomic_accession=3885429, orientation='plus', exon_count=11, OMIM=[601883], no_hdr0=''),
    1678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1678, CurrentID=0, Status='live', Symbol='TIMM8A', Aliases=['DDP', 'DDP1', 'DFN1', 'MTS', 'TIM8'], description='translocase of inner mitochondrial membrane 8A', other_designations='mitochondrial import inner membrane translocase subunit Tim8 A|X-linked deafness dystonia protein|deafness dystonia protein 1|deafness/dystonia peptide|translocase of inner mitochondrial membrane 8 homolog A', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101345661, end_position_on_the_genomic_accession=101348742, orientation='minus', exon_count=2, OMIM=[300356], no_hdr0=''),
    1687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1687, CurrentID=0, Status='live', Symbol='GSDME', Aliases=['DFNA5', 'ICERE-1'], description='gasdermin E', other_designations='gasdermin-E|DFNA5, deafness associated tumor suppressor|inversely correlated with estrogen receptor expression 1|non-syndromic hearing impairment protein 5|nonsyndromic hearing impairment protein', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=24698355, end_position_on_the_genomic_accession=24762235, orientation='minus', exon_count=13, OMIM=[608798], no_hdr0=''),
    1690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1690, CurrentID=0, Status='live', Symbol='COCH', Aliases=['COCH-5B25B2', 'DFNA9', 'DFNB110', 'COCH'], description='cochlin', other_designations='cochlin|coagulation factor C homolog, cochlin (Limulus polyphemus)', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=30874496, end_position_on_the_genomic_accession=30890618, orientation='plus', exon_count=13, OMIM=[603196], no_hdr0=''),
    1716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1716, CurrentID=0, Status='live', Symbol='DGUOK', Aliases=['MTDPS3', 'NCPH', 'PEOB4', 'dGK'], description='deoxyguanosine kinase', other_designations='deoxyguanosine kinase, mitochondrial|deoxyadenosine kinase, mitochondrial', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73926827, end_position_on_the_genomic_accession=73958961, orientation='plus', exon_count=8, OMIM=[601465], no_hdr0=''),
    1717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1717, CurrentID=0, Status='live', Symbol='DHCR7', Aliases=['SLOS'], description='7-dehydrocholesterol reductase', other_designations='7-dehydrocholesterol reductase|7-DHC reductase|delta-7-dehydrocholesterol reductase|delta7-sterol reductase|putative sterol reductase SR-2|sterol delta-7-reductase|sterol reductase SR-2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71434411, end_position_on_the_genomic_accession=71448393, orientation='minus', exon_count=9, OMIM=[602858], no_hdr0=''),
    1718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1718, CurrentID=0, Status='live', Symbol='DHCR24', Aliases=['DCE', 'Nbla03646', 'SELADIN1', 'seladin-1'], description='24-dehydrocholesterol reductase', other_designations='delta(24)-sterol reductase|3 beta-hydroxysterol delta 24-reductase|desmosterol-to-cholesterol enzyme|diminuto/dwarf1 homolog|seladin 1|selective AD indicator 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54849627, end_position_on_the_genomic_accession=54887195, orientation='minus', exon_count=9, OMIM=[606418], no_hdr0=''),
    1719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1719, CurrentID=0, Status='live', Symbol='DHFR', Aliases=['DHFRP1', 'DYR'], description='dihydrofolate reductase', other_designations='dihydrofolate reductase', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80626226, end_position_on_the_genomic_accession=80654983, orientation='minus', exon_count=6, OMIM=[126060], no_hdr0=''),
    1723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1723, CurrentID=0, Status='live', Symbol='DHODH', Aliases=['DHOdehase', 'POADS', 'URA1'], description='dihydroorotate dehydrogenase (quinone)', other_designations='dihydroorotate dehydrogenase (quinone), mitochondrial|dihydroorotate oxidase|human complement of yeast URA1', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72008744, end_position_on_the_genomic_accession=72027659, orientation='plus', exon_count=11, OMIM=[126064], no_hdr0=''),
    1725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1725, CurrentID=0, Status='live', Symbol='DHPS', Aliases=['DHS', 'DS', 'MIG13', 'NEDSSWI'], description='deoxyhypusine synthase', other_designations='deoxyhypusine synthase|migration-inducing gene 13', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12672470, end_position_on_the_genomic_accession=12681880, orientation='minus', exon_count=12, OMIM=[600944], no_hdr0=''),
    1727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1727, CurrentID=0, Status='live', Symbol='CYB5R3', Aliases=['B5R', 'DIA1'], description='cytochrome b5 reductase 3', other_designations='NADH-cytochrome b5 reductase 3|NADH-cytochrome b5 reductase 3 membrane-bound form|NADH-cytochrome b5 reductase 3 soluble form|diaphorase-1|mutant NADH-cytochrome b5 reductase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42617840, end_position_on_the_genomic_accession=42649392, orientation='minus', exon_count=12, OMIM=[613213], no_hdr0=''),
    1728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1728, CurrentID=0, Status='live', Symbol='NQO1', Aliases=['DHQU', 'DIA4', 'DTD', 'NMOR1', 'NMORI', 'QR1'], description='NAD(P)H quinone dehydrogenase 1', other_designations='NAD(P)H dehydrogenase [quinone] 1|DT-diaphorase|NAD(P)H dehydrogenase, quinone 1|NAD(P)H:Quinone acceptor oxidoreductase type 1|NAD(P)H:menadione oxidoreductase 1|NAD(P)H:quinone oxidoreductase 1|NAD(P)H:quinone oxireductase|azoreductase|diaphorase (NADH/NADPH) (cytochrome b-5 reductase)|diaphorase-4|dioxin-inducible 1|menadione reductase|phylloquinone reductase|quinone reductase 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69709401, end_position_on_the_genomic_accession=69726560, orientation='minus', exon_count=6, OMIM=[125860], no_hdr0=''),
    1729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1729, CurrentID=0, Status='live', Symbol='DIAPH1', Aliases=['DFNA1', 'DIA1', 'DRF1', 'LFHL1', 'SCBMS', 'hDIA1'], description='diaphanous related formin 1', other_designations='protein diaphanous homolog 1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141515016, end_position_on_the_genomic_accession=141619055, orientation='minus', exon_count=30, OMIM=[602121], no_hdr0=''),
    1730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1730, CurrentID=0, Status='live', Symbol='DIAPH2', Aliases=['DIA', 'DIA2', 'DRF2', 'POF', 'POF2', 'POF2A'], description='diaphanous related formin 2', other_designations='protein diaphanous homolog 2|diaphanous homolog 2|diaphorase-2', map_location='Xq21.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=96684842, end_position_on_the_genomic_accession=97604997, orientation='plus', exon_count=28, OMIM=[300108], no_hdr0=''),
    1731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1731, CurrentID=0, Status='live', Symbol='SEPTIN1', Aliases=['DIFF6', 'LARP', 'PNUTL3', 'SEP1', 'SEPT1'], description='septin 1', other_designations='septin-1|differentiation 6 (deoxyguanosine triphosphate triphosphohydrolase)|peanut-like protein 3|serologically defined breast cancer antigen NY-BR-24', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30378135, end_position_on_the_genomic_accession=30382830, orientation='minus', exon_count=10, OMIM=[612897], no_hdr0=''),
    1733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1733, CurrentID=0, Status='live', Symbol='DIO1', Aliases=['5DI', 'TXDI1'], description='iodothyronine deiodinase 1', other_designations="type I iodothyronine deiodinase|DIOI|deiodinase, iodothyronine type I|iodothyronine deiodinase type 1|selenoprotein DIO1|thyroxine 5'-deiodinase|thyroxine deiodinase type I (selenoprotein)|type 1 DI|type-I 5'-deiodinase", map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53894187, end_position_on_the_genomic_accession=53911086, orientation='plus', exon_count=5, OMIM=[147892], no_hdr0=''),
    1734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1734, CurrentID=0, Status='live', Symbol='DIO2', Aliases=['5DII', 'D2', 'DIOII', 'SELENOY', 'SelY', 'TXDI2'], description='iodothyronine deiodinase 2', other_designations="type II iodothyronine deiodinase|deiodinase, iodothyronine type II|deiodinase-2|deiodonase-2|selenoprotein Y|thyroxine deiodinase, type II|type 2 DI|type 2 iodothyronine deiodinase|type-II 5'-deiodinase|type-II 5'deiodinase", map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=80197526, end_position_on_the_genomic_accession=80231057, orientation='minus', exon_count=7, OMIM=[601413], no_hdr0=''),
    1735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1735, CurrentID=0, Status='live', Symbol='DIO3', Aliases=['5DIII', 'D3', 'DIOIII', 'TXDI3'], description='iodothyronine deiodinase 3', other_designations="thyroxine 5-deiodinase|deiodinase, iodothyronine type III|iodothyronine deiodinase, placental type|selenoprotein DIO3|thyroxine deiodinase type III (selenoprotein)|type 3 DI|type 3 iodothyronine selenodeiodinase|type-III 5' deiodinase", map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=101561351, end_position_on_the_genomic_accession=101563452, orientation='plus', exon_count=1, OMIM=[601038], no_hdr0=''),
    1736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1736, CurrentID=0, Status='live', Symbol='DKC1', Aliases=['CBF5', 'DKC', 'DKCX', 'NAP57', 'NOLA4', 'XAP101'], description='dyskerin pseudouridine synthase 1', other_designations='H/ACA ribonucleoprotein complex subunit DKC1|CBF5 homolog|H/ACA ribonucleoprotein complex subunit 4|dyskeratosis congenita 1, dyskerin|nopp140-associated protein of 57 kDa|nucleolar protein NAP57|nucleolar protein family A member 4|snoRNP protein DKC1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154762864, end_position_on_the_genomic_accession=154777689, orientation='plus', exon_count=14, OMIM=[300126], no_hdr0=''),
    1737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1737, CurrentID=0, Status='live', Symbol='DLAT', Aliases=['DLTA', 'E2', 'PBC', 'PDC-E2', 'PDCE2'], description='dihydrolipoamide S-acetyltransferase', other_designations='dihydrolipoyllysine-residue acetyltransferase component of pyruvate dehydrogenase complex, mitochondrial|70 kDa mitochondrial autoantigen of primary biliary cirrhosis|E2 component of pyruvate dehydrogenase complex|M2 antigen complex 70 kDa subunit|dihydrolipoamide acetyltransferase component of pyruvate dehydrogenase complex|pyruvate dehydrogenase complex component E2', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112025408, end_position_on_the_genomic_accession=112064404, orientation='plus', exon_count=14, OMIM=[608770], no_hdr0=''),
    1738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1738, CurrentID=0, Status='live', Symbol='DLD', Aliases=['DLDDH', 'E3', 'GCSL', 'LAD', 'OGDC-E3', 'PHE3', 'DLD'], description='dihydrolipoamide dehydrogenase', other_designations='dihydrolipoyl dehydrogenase, mitochondrial|E3 component of pyruvate dehydrogenase complex, 2-oxo-glutarate complex, branched chain keto acid dehydrogenase complex|diaphorase|epididymis secretory sperm binding protein|glycine cleavage system L protein|glycine cleavage system protein L|lipoamide dehydrogenase|lipoamide reductase|lipoyl dehydrogenase', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107891107, end_position_on_the_genomic_accession=107921198, orientation='plus', exon_count=14, OMIM=[238331], no_hdr0=''),
    1739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1739, CurrentID=0, Status='live', Symbol='DLG1', Aliases=['DLGH1', 'SAP-97', 'SAP97', 'hdlg'], description='discs large MAGUK scaffold protein 1', other_designations='disks large homolog 1|dJ1061C18.1.1|discs large homolog 1, scribble cell polarity complex component|presynaptic protein SAP97|synapse-associated protein 97', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197042560, end_position_on_the_genomic_accession=197299321, orientation='minus', exon_count=35, OMIM=[601014], no_hdr0=''),
    1740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1740, CurrentID=0, Status='live', Symbol='DLG2', Aliases=['PPP1R58', 'PSD-93', 'PSD93', 'chapsyn-110'], description='discs large MAGUK scaffold protein 2', other_designations='disks large homolog 2|channel-associated protein of synapse-110|channel-associated protein of synapses, 110kDa|discs, large homolog 2, chapsyn-110|postsynaptic density protein PSD-93|protein phosphatase 1, regulatory subunit 58', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=83455009, end_position_on_the_genomic_accession=85628535, orientation='minus', exon_count=47, OMIM=[603583], no_hdr0=''),
    1741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1741, CurrentID=0, Status='live', Symbol='DLG3', Aliases=['MRX', 'MRX90', 'NEDLG', 'PPP1R82', 'SAP102', 'XLMR'], description='discs large MAGUK scaffold protein 3', other_designations='disks large homolog 3|discs, large homolog 3|neuroendocrine-DLG|protein phosphatase 1, regulatory subunit 82|synapse-associated protein 102', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70444835, end_position_on_the_genomic_accession=70505490, orientation='plus', exon_count=26, OMIM=[300189], no_hdr0=''),
    1742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1742, CurrentID=0, Status='live', Symbol='DLG4', Aliases=['MRD62', 'PSD95', 'SAP-90', 'SAP90'], description='discs large MAGUK scaffold protein 4', other_designations='disks large homolog 4|Tax interaction protein 15|discs large homolog 4|post-synaptic density protein 95|synapse-associated protein 90', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7187187, end_position_on_the_genomic_accession=7220050, orientation='minus', exon_count=27, OMIM=[602887], no_hdr0=''),
    1743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1743, CurrentID=0, Status='live', Symbol='DLST', Aliases=['DLTS', 'KGD2', 'PGL7'], description='dihydrolipoamide S-succinyltransferase', other_designations='dihydrolipoyllysine-residue succinyltransferase component of 2-oxoglutarate dehydrogenase complex, mitochondrial|E2K|OGDC-E2|dihydrolipoamide S-succinyltransferase (E2 component of 2-oxo-glutarate complex)', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74881913, end_position_on_the_genomic_accession=74903743, orientation='plus', exon_count=15, OMIM=[126063], no_hdr0=''),
    1745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1745, CurrentID=0, Status='live', Symbol='DLX1', Aliases=[], description='distal-less homeobox 1', other_designations='homeobox protein DLX-1|distal-less homeo box 1', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=172085507, end_position_on_the_genomic_accession=172089674, orientation='plus', exon_count=3, OMIM=[600029], no_hdr0=''),
    1746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1746, CurrentID=0, Status='live', Symbol='DLX2', Aliases=['TES-1', 'TES1'], description='distal-less homeobox 2', other_designations='homeobox protein DLX-2|distal-less homeo box 2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=172099438, end_position_on_the_genomic_accession=172102900, orientation='minus', exon_count=3, OMIM=[126255], no_hdr0=''),
    1747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1747, CurrentID=0, Status='live', Symbol='DLX3', Aliases=['AI4', 'TDO'], description='distal-less homeobox 3', other_designations='homeobox protein DLX-3', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49990005, end_position_on_the_genomic_accession=49995224, orientation='minus', exon_count=3, OMIM=[600525], no_hdr0=''),
    1748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1748, CurrentID=0, Status='live', Symbol='DLX4', Aliases=['BP1', 'DLX7', 'DLX8', 'DLX9', 'OFC15'], description='distal-less homeobox 4', other_designations='homeobox protein DLX-4|beta protein 1|distal-less homeo box 7|distal-less homeo box 9|homeobox protein DLX-7|homeobox protein DLX-8', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49968970, end_position_on_the_genomic_accession=49974959, orientation='plus', exon_count=4, OMIM=[601911], no_hdr0=''),
    1749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1749, CurrentID=0, Status='live', Symbol='DLX5', Aliases=['SHFM1', 'SHFM1D'], description='distal-less homeobox 5', other_designations='homeobox protein DLX-5|distal-less homeo box 5|split hand/foot malformation type 1 with sensorineural hearing loss', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97020396, end_position_on_the_genomic_accession=97024831, orientation='minus', exon_count=5, OMIM=[600028], no_hdr0=''),
    1750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1750, CurrentID=0, Status='live', Symbol='DLX6', Aliases=[], description='distal-less homeobox 6', other_designations='homeobox protein DLX-6|distal-less homeo box 6', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97005553, end_position_on_the_genomic_accession=97011040, orientation='plus', exon_count=3, OMIM=[600030], no_hdr0=''),
    1755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1755, CurrentID=0, Status='live', Symbol='DMBT1', Aliases=['GP340', 'SAG', 'SALSA', 'muclin'], description='deleted in malignant brain tumors 1', other_designations='deleted in malignant brain tumors 1 protein|glycoprotein 340|hensin|salivary agglutinin|salivary scavenger and agglutinin|surfactant pulmonary-associated D-binding protein|vomeroglandin', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122560677, end_position_on_the_genomic_accession=122643736, orientation='plus', exon_count=57, OMIM=[601969], no_hdr0=''),
    1756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1756, CurrentID=0, Status='live', Symbol='DMD', Aliases=['BMD', 'CMD3B', 'DXS142', 'DXS164', 'DXS206', 'DXS230', 'DXS239', 'DXS268', 'DXS269', 'DXS270', 'DXS272', 'MRX85'], description='dystrophin', other_designations='dystrophin|truncated dystrophin', map_location='Xp21.2-p21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=31119219, end_position_on_the_genomic_accession=33339460, orientation='minus', exon_count=89, OMIM=[300377], no_hdr0=''),
    1757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1757, CurrentID=0, Status='live', Symbol='SARDH', Aliases=['BPR-2', 'DMGDHL1', 'SAR', 'SARD', 'SDH'], description='sarcosine dehydrogenase', other_designations='sarcosine dehydrogenase, mitochondrial|dimethylglycine dehydrogenase-like 1', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133663074, end_position_on_the_genomic_accession=133739958, orientation='minus', exon_count=26, OMIM=[604455], no_hdr0=''),
    1758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1758, CurrentID=0, Status='live', Symbol='DMP1', Aliases=['ARHP', 'ARHR', 'DMP-1'], description='dentin matrix acidic phosphoprotein 1', other_designations='dentin matrix acidic phosphoprotein 1|dentin matrix protein 1', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87650280, end_position_on_the_genomic_accession=87664357, orientation='plus', exon_count=7, OMIM=[600980], no_hdr0=''),
    1759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1759, CurrentID=0, Status='live', Symbol='DNM1', Aliases=['DEE31', 'DNM', 'EIEE31'], description='dynamin 1', other_designations='dynamin-1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128203379, end_position_on_the_genomic_accession=128255244, orientation='plus', exon_count=24, OMIM=[602377], no_hdr0=''),
    1760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1760, CurrentID=0, Status='live', Symbol='DMPK', Aliases=['DM', 'DM1', 'DM1PK', 'DMK', 'MDPK', 'MT-PK'], description='DM1 protein kinase', other_designations='myotonin-protein kinase|DM protein kinase|dystrophia myotonica protein kinase|myotonic dystrophy associated protein kinase|myotonin protein kinase A|thymopoietin homolog', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45769709, end_position_on_the_genomic_accession=45782490, orientation='minus', exon_count=15, OMIM=[605377], no_hdr0=''),
    1761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1761, CurrentID=0, Status='live', Symbol='DMRT1', Aliases=['CT154', 'DMT1'], description='doublesex and mab-3 related transcription factor 1', other_designations='doublesex- and mab-3-related transcription factor 1|DM domain expressed in testis 1|DM domain expressed in testis protein 1', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=841647, end_position_on_the_genomic_accession=969090, orientation='plus', exon_count=8, OMIM=[602424], no_hdr0=''),
    1762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1762, CurrentID=0, Status='live', Symbol='DMWD', Aliases=['D19S593E', 'DMR-N9', 'DMRN9', 'gene59'], description='DM1 locus, WD repeat containing', other_designations='dystrophia myotonica WD repeat-containing protein|dystrophia myotonica, WD repeat containing|dystrophia myotonica-containing WD repeat motif protein|protein 59', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45782947, end_position_on_the_genomic_accession=45792845, orientation='minus', exon_count=5, OMIM=[609857], no_hdr0=''),
    1763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1763, CurrentID=0, Status='live', Symbol='DNA2', Aliases=['DNA2L', 'hDNA2'], description='DNA replication helicase/nuclease 2', other_designations='DNA replication ATP-dependent helicase/nuclease DNA2|DNA replication ATP-dependent helicase-like homolog|DNA replication helicase 2 homolog|DNA2 DNA replication helicase 2-like|DNA2-like helicase', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68414064, end_position_on_the_genomic_accession=68472521, orientation='minus', exon_count=22, OMIM=[601810], no_hdr0=''),
    1767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1767, CurrentID=0, Status='live', Symbol='DNAH5', Aliases=['CILD3', 'DNAHC5', 'HL1', 'KTGNR', 'PCD'], description='dynein axonemal heavy chain 5', other_designations='dynein axonemal heavy chain 5|dynein heavy chain 5, axonemal|axonemal beta dynein heavy chain 5|ciliary dynein heavy chain 5|dynein, axonemal, heavy polypeptide 5', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=13690328, end_position_on_the_genomic_accession=14011829, orientation='minus', exon_count=86, OMIM=[603335], no_hdr0=''),
    1768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1768, CurrentID=0, Status='live', Symbol='DNAH6', Aliases=['DNHL1', 'Dnahc6', 'HL-2', 'HL2'], description='dynein axonemal heavy chain 6', other_designations='dynein axonemal heavy chain 6|dynein heavy chain 6, axonemal|axonemal beta dynein heavy chain 6|ciliary dynein heavy chain 6|dynein heavy chain-like 1|dynein, axonemal, heavy polypeptide 6', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=84459572, end_position_on_the_genomic_accession=84819589, orientation='plus', exon_count=81, OMIM=[603336], no_hdr0=''),
    1769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1769, CurrentID=0, Status='live', Symbol='DNAH8', Aliases=['ATPase', 'SPGF46', 'hdhc9'], description='dynein axonemal heavy chain 8', other_designations='dynein axonemal heavy chain 8|dynein heavy chain 8, axonemal|axonemal beta dynein heavy chain 8|ciliary dynein heavy chain 8|dynein, axonemal, heavy polypeptide 8', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=38715311, end_position_on_the_genomic_accession=39030798, orientation='plus', exon_count=97, OMIM=[603337], no_hdr0=''),
    1770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1770, CurrentID=0, Status='live', Symbol='DNAH9', Aliases=['CILD40', 'DNAH17L', 'DNEL1', 'DYH9', 'Dnahc9', 'HL-20', 'HL20'], description='dynein axonemal heavy chain 9', other_designations='dynein axonemal heavy chain 9|dynein heavy chain 9, axonemal|DNAH9 variant protein|axonemal beta dynein heavy chain 9|ciliary dynein heavy chain 9|dynein, axonemal, heavy polypeptide 9', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=11598470, end_position_on_the_genomic_accession=11970168, orientation='plus', exon_count=73, OMIM=[603330], no_hdr0=''),
    1773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1773, CurrentID=0, Status='live', Symbol='DNASE1', Aliases=['DNL1', 'DRNI'], description='deoxyribonuclease 1', other_designations='deoxyribonuclease-1|DNase I, lysosomal|Dornase alfa|deoxyribonuclease I|human urine deoxyribonuclease I', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3611737, end_position_on_the_genomic_accession=3665472, orientation='plus', exon_count=15, OMIM=[125505], no_hdr0=''),
    1774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1774, CurrentID=0, Status='live', Symbol='DNASE1L1', Aliases=['DNAS1L1', 'DNASEX', 'DNL1L', 'G4.8', 'XIB'], description='deoxyribonuclease 1 like 1', other_designations='deoxyribonuclease-1-like 1|DNase I, lysosomal-like|DNase I-like 1|DNase I-like, muscle-specific|deoxyribonuclease I-like 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154401236, end_position_on_the_genomic_accession=154412101, orientation='minus', exon_count=10, OMIM=[300081], no_hdr0=''),
    1775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1775, CurrentID=0, Status='live', Symbol='DNASE1L2', Aliases=['DNAS1L2'], description='deoxyribonuclease 1 like 2', other_designations='deoxyribonuclease-1-like 2|DNase I homolog protein DHP1|DNase I-like 2|deoxyribonuclease I like 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2236444, end_position_on_the_genomic_accession=2238711, orientation='plus', exon_count=7, OMIM=[602622], no_hdr0=''),
    1776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1776, CurrentID=0, Status='live', Symbol='DNASE1L3', Aliases=['DHP2', 'DNAS1L3', 'LSD', 'SLEB16'], description='deoxyribonuclease 1 like 3', other_designations='deoxyribonuclease gamma|DNase I homolog protein 2|DNase I homolog protein DHP2|DNase I-like 3|DNase gamma|LS-DNase|Liver and spleen DNase|deoxyribonuclease I-like 3|deoxyribonuclease I-like III', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58192257, end_position_on_the_genomic_accession=58210972, orientation='minus', exon_count=8, OMIM=[602244], no_hdr0=''),
    1777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1777, CurrentID=0, Status='live', Symbol='DNASE2', Aliases=['DNASE2A', 'DNL', 'DNL2'], description='deoxyribonuclease 2, lysosomal', other_designations='deoxyribonuclease-2-alpha|DNase II alpha|DNase II, lysosomal|R31240_2|acid DNase|deoxyribonuclease II alpha|deoxyribonuclease II, lysosomal|lysosomal DNase II', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12875209, end_position_on_the_genomic_accession=12881449, orientation='minus', exon_count=6, OMIM=[126350], no_hdr0=''),
    1778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1778, CurrentID=0, Status='live', Symbol='DYNC1H1', Aliases=['CMT2O', 'DHC1', 'DHC1a', 'DNCH1', 'DNCL', 'DNECL', 'DYHC', 'Dnchc1', 'HL-3', 'SMALED1', 'p22'], description='dynein cytoplasmic 1 heavy chain 1', other_designations='cytoplasmic dynein 1 heavy chain 1|dynein heavy chain, cytosolic|dynein, cytoplasmic, heavy polypeptide 1', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=101964573, end_position_on_the_genomic_accession=102056443, orientation='plus', exon_count=78, OMIM=[600112], no_hdr0=''),
    1780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1780, CurrentID=0, Status='live', Symbol='DYNC1I1', Aliases=['DNCI1', 'DNCIC1'], description='dynein cytoplasmic 1 intermediate chain 1', other_designations='cytoplasmic dynein 1 intermediate chain 1|DH IC-1|cytoplasmic dynein intermediate chain 1|dynein intermediate chain 1, cytosolic|dynein, cytoplasmic, intermediate polypeptide 1', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95772554, end_position_on_the_genomic_accession=96110322, orientation='plus', exon_count=18, OMIM=[603772], no_hdr0=''),
    1781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1781, CurrentID=0, Status='live', Symbol='DYNC1I2', Aliases=['DIC74', 'DNCI2', 'IC2', 'NEDMIBA'], description='dynein cytoplasmic 1 intermediate chain 2', other_designations='cytoplasmic dynein 1 intermediate chain 2|DH IC-2|dynein intermediate chain 2, cytosolic|dynein, cytoplasmic, intermediate polypeptide 2|testis tissue sperm-binding protein Li 66n', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171687469, end_position_on_the_genomic_accession=171750158, orientation='plus', exon_count=19, OMIM=[603331], no_hdr0=''),
    1783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1783, CurrentID=0, Status='live', Symbol='DYNC1LI2', Aliases=['DNCLI2', 'LIC2'], description='dynein cytoplasmic 1 light intermediate chain 2', other_designations='cytoplasmic dynein 1 light intermediate chain 2|LIC-2|LIC53/55|dynein light intermediate chain 2, cytosolic|dynein, cytoplasmic, light intermediate polypeptide 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66720893, end_position_on_the_genomic_accession=66751609, orientation='minus', exon_count=14, OMIM=[611406], no_hdr0=''),
    1785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1785, CurrentID=0, Status='live', Symbol='DNM2', Aliases=['CMT2M', 'CMTDI1', 'CMTDIB', 'DI-CMTB', 'DYN2', 'DYNII', 'LCCS5'], description='dynamin 2', other_designations='dynamin-2|dynamin II', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10718079, end_position_on_the_genomic_accession=10831903, orientation='plus', exon_count=22, OMIM=[602378], no_hdr0=''),
    1786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1786, CurrentID=0, Status='live', Symbol='DNMT1', Aliases=['ADCADN', 'AIM', 'CXXC9', 'DNMT', 'HSN1E', 'MCMT', 'm.HsaI'], description='DNA methyltransferase 1', other_designations='DNA (cytosine-5)-methyltransferase 1|CXXC-type zinc finger protein 9|DNA (cytosine-5-)-methyltransferase 1|DNA MTase HsaI|DNA methyltransferase HsaI', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10133346, end_position_on_the_genomic_accession=10194953, orientation='minus', exon_count=41, OMIM=[126375], no_hdr0=''),
    1787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1787, CurrentID=0, Status='live', Symbol='TRDMT1', Aliases=['DMNT2', 'DNMT2', 'MHSAIIP', 'PUMET', 'RNMT1'], description='tRNA aspartic acid methyltransferase 1', other_designations='tRNA (cytosine(38)-C(5))-methyltransferase|DNA (cytosine-5)-methyltransferase-like protein 2|DNA MTase homolog HsaIIP|DNA cytosine-5 methyltransferase 2|DNA methyltransferase-2|tRNA (cytosine-5-)-methyltransferase', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17137336, end_position_on_the_genomic_accession=17202066, orientation='minus', exon_count=15, OMIM=[602478], no_hdr0=''),
    1788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1788, CurrentID=0, Status='live', Symbol='DNMT3A', Aliases=['DNMT3A2', 'HESJAS', 'M.HsaIIIA', 'TBRS'], description='DNA methyltransferase 3 alpha', other_designations='DNA (cytosine-5)-methyltransferase 3A|DNA (cytosine-5-)-methyltransferase 3 alpha|DNA MTase HsaIIIA|DNA cytosine methyltransferase 3A2|cysteine methyltransferase DNMT3A', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25227874, end_position_on_the_genomic_accession=25342590, orientation='minus', exon_count=34, OMIM=[602769], no_hdr0=''),
    1789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1789, CurrentID=0, Status='live', Symbol='DNMT3B', Aliases=['ICF', 'ICF1', 'M.HsaIIIB'], description='DNA methyltransferase 3 beta', other_designations='DNA (cytosine-5)-methyltransferase 3B|DNA (cytosine-5-)-methyltransferase 3 beta|DNA MTase HsaIIIB|DNA cytosine-5--methyltransferase 3 beta|DNA methyltransferase HsaIIIB', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32762385, end_position_on_the_genomic_accession=32809356, orientation='plus', exon_count=24, OMIM=[602900], no_hdr0=''),
    1791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1791, CurrentID=0, Status='live', Symbol='DNTT', Aliases=['TDT'], description='DNA nucleotidylexotransferase', other_designations='DNA nucleotidylexotransferase|nucleosidetriphosphate:DNA deoxynucleotidylexotransferase|terminal addition enzyme|terminal deoxynucleotidyltransferase|terminal deoxyribonucleotidyltransferase|terminal transferase', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96304434, end_position_on_the_genomic_accession=96338564, orientation='plus', exon_count=11, OMIM=[187410], no_hdr0=''),
    1793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1793, CurrentID=0, Status='live', Symbol='DOCK1', Aliases=['DOCK180', 'ced5'], description='dedicator of cytokinesis 1', other_designations='dedicator of cytokinesis protein 1|180 kDa protein downstream of CRK|DOwnstream of CrK', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=126905428, end_position_on_the_genomic_accession=127452517, orientation='plus', exon_count=59, OMIM=[601403], no_hdr0=''),
    1794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1794, CurrentID=0, Status='live', Symbol='DOCK2', Aliases=['IMD40'], description='dedicator of cytokinesis 2', other_designations='dedicator of cytokinesis protein 2|dedicator of cyto-kinesis 2', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=169637247, end_position_on_the_genomic_accession=170083382, orientation='plus', exon_count=60, OMIM=[603122], no_hdr0=''),
    1795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1795, CurrentID=0, Status='live', Symbol='DOCK3', Aliases=['MOCA', 'NEDIDHA', 'PBP'], description='dedicator of cytokinesis 3', other_designations='dedicator of cytokinesis protein 3|modifier of cell adhesion|presenilin-binding protein', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50674927, end_position_on_the_genomic_accession=51384198, orientation='plus', exon_count=59, OMIM=[603123], no_hdr0=''),
    1796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1796, CurrentID=0, Status='live', Symbol='DOK1', Aliases=['P62DOK', 'pp62'], description='docking protein 1', other_designations='docking protein 1|Downstream of tyrosine kinase 1', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74549105, end_position_on_the_genomic_accession=74557551, orientation='plus', exon_count=6, OMIM=[602919], no_hdr0=''),
    1797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1797, CurrentID=0, Status='live', Symbol='DXO', Aliases=['DOM3L', 'DOM3Z', 'NG6', 'RAI1'], description='decapping exoribonuclease', other_designations="decapping and exoribonuclease protein|5'-3' exoribonuclease DXO|NAD-capped RNA hydrolase DXO|deNADding enzyme DXO|protein Dom3Z", map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31969811, end_position_on_the_genomic_accession=31972290, orientation='minus', exon_count=6, OMIM=[605996], no_hdr0=''),
    1798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1798, CurrentID=0, Status='live', Symbol='DPAGT1', Aliases=['ALG7', 'CDG-Ij', 'CDG1J', 'CMS13', 'CMSTA2', 'D11S366', 'DGPT', 'DPAGT', 'DPAGT2', 'G1PT', 'GPT', 'UAGT', 'UGAT'], description='dolichyl-phosphate N-acetylglucosaminephosphotransferase 1', other_designations='UDP-N-acetylglucosamine--dolichyl-phosphate N-acetylglucosaminephosphotransferase|GlcNAc-1-P transferase 1|N-acetylglucosamine-1-phosphate transferase|UDP-GlcNAc:dolichyl-phosphate N-acetylglucosaminephosphotransferase|UDP-N-acetylglucosamine--dolichyl-phosphate N-acetylglucosaminephosphotransferase 1|dolichyl-phosphate (UDP-N-acetylglucosamine) N-acetylglucosaminephosphotransferase 1 (GlcNAc-1-P tra|dolichyl-phosphate (UDP-N-acetylglucosamine) N-acetylglucosaminephosphotransferase 1 (GlcNAc-1-P transferase)|dolichyl-phosphate alpha-N-acetylglucosaminyltransferase', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119096505, end_position_on_the_genomic_accession=119101884, orientation='minus', exon_count=9, OMIM=[191350], no_hdr0=''),
    1800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1800, CurrentID=0, Status='live', Symbol='DPEP1', Aliases=['MBD1', 'MDP', 'RDP'], description='dipeptidase 1', other_designations='dipeptidase 1|beta-lactamase|dehydropeptidase-I|dipeptidase 1 (renal)|hRDP|microsomal dipeptidase|renal dipeptidase|testicular tissue protein Li 57', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89613308, end_position_on_the_genomic_accession=89641540, orientation='plus', exon_count=17, OMIM=[179780], no_hdr0=''),
    1801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1801, CurrentID=0, Status='live', Symbol='DPH1', Aliases=['DEDSSH', 'DPH2L', 'DPH2L1', 'OVCA1'], description='diphthamide biosynthesis 1', other_designations='2-(3-amino-3-carboxypropyl)histidine synthase subunit 1|DPH-like 1|DPH1 homolog|DPH2-like 1|S-adenosyl-L-methionine:L-histidine 3-amino-3-carboxypropyltransferase 1|candidate tumor suppressor in ovarian cancer 1|diphthamide biosynthesis protein 1|diphthamide biosynthesis protein 2 homolog-like 1|diphtheria toxin resistance protein 1|diptheria toxin resistance protein required for diphthamide biosynthesis (Saccharomyces)-like 1|ovarian cancer-associated gene 1 protein|ovarian tumor suppressor candidate 1', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2030112, end_position_on_the_genomic_accession=2043898, orientation='plus', exon_count=13, OMIM=[603527], no_hdr0=''),
    1802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1802, CurrentID=0, Status='live', Symbol='DPH2', Aliases=['DPH2L2'], description='diphthamide biosynthesis 2', other_designations='2-(3-amino-3-carboxypropyl)histidine synthase subunit 2|DPH2 homolog|DPH2-like 2|S-adenosyl-L-methionine:L-histidine 3-amino-3-carboxypropyltransferase 2|diphthamide biosynthesis protein 2 homolog-like 2|diphthamide biosynthesis-like protein 2|diphtheria toxin resistance protein 2|diptheria toxin resistance protein required for diphthamide biosynthesis-like 2', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43969997, end_position_on_the_genomic_accession=43973369, orientation='plus', exon_count=5, OMIM=[603456], no_hdr0=''),
    1803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1803, CurrentID=0, Status='live', Symbol='DPP4', Aliases=['ADABP', 'ADCP2', 'CD26', 'DPPIV', 'TP103'], description='dipeptidyl peptidase 4', other_designations='dipeptidyl peptidase 4|ADCP-2|DPP IV|Gly-Pro naphthylamidase|Post-proline dipeptidyl aminopeptidase IV|T-cell activation antigen CD26|Xaa-Pro-dipeptidylaminopeptidase|adenosine deaminase complexing protein 2|dipeptidyl peptidase IV|dipeptidylpeptidase 4|dipeptidylpeptidase IV (CD26, adenosine deaminase complexing protein 2)', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=161992245, end_position_on_the_genomic_accession=162074215, orientation='minus', exon_count=28, OMIM=[102720], no_hdr0=''),
    1804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1804, CurrentID=0, Status='live', Symbol='DPP6', Aliases=['DPL1', 'DPPX', 'MRD33', 'VF2'], description='dipeptidyl peptidase like 6', other_designations='dipeptidyl aminopeptidase-like protein 6|DPP VI|dipeptidyl aminopeptidase IV-related protein|dipeptidyl peptidase IV-related protein|dipeptidyl peptidase VI|dipeptidyl-peptidase 6', map_location='7q36.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=153748133, end_position_on_the_genomic_accession=154894285, orientation='plus', exon_count=32, OMIM=[126141], no_hdr0=''),
    1805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1805, CurrentID=0, Status='live', Symbol='DPT', Aliases=['TRAMP'], description='dermatopontin', other_designations='dermatopontin|tyrosine-rich acidic matrix protein', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168695468, end_position_on_the_genomic_accession=168729206, orientation='minus', exon_count=4, OMIM=[125597], no_hdr0=''),
    1806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1806, CurrentID=0, Status='live', Symbol='DPYD', Aliases=['DHP', 'DHPDHASE', 'DPD'], description='dihydropyrimidine dehydrogenase', other_designations='dihydropyrimidine dehydrogenase [NADP(+)]|dihydrothymine dehydrogenase|dihydrouracil dehydrogenase', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=97077743, end_position_on_the_genomic_accession=97921059, orientation='minus', exon_count=26, OMIM=[612779], no_hdr0=''),
    1807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1807, CurrentID=0, Status='live', Symbol='DPYS', Aliases=['DHP', 'DHPase'], description='dihydropyrimidinase', other_designations='dihydropyrimidinase|dihydropyrimidine amidohydrolase|hydantoinase', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=104379429, end_position_on_the_genomic_accession=104467074, orientation='minus', exon_count=13, OMIM=[613326], no_hdr0=''),
    1808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1808, CurrentID=0, Status='live', Symbol='DPYSL2', Aliases=['CRMP-2', 'CRMP2', 'DHPRP2', 'DRP-2', 'DRP2', 'N2A3', 'ULIP-2', 'ULIP2'], description='dihydropyrimidinase like 2', other_designations='dihydropyrimidinase-related protein 2|collapsin response mediator protein hCRMP-2|unc-33-like phosphoprotein 2', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=26514031, end_position_on_the_genomic_accession=26658175, orientation='plus', exon_count=16, OMIM=[602463], no_hdr0=''),
    1809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1809, CurrentID=0, Status='live', Symbol='DPYSL3', Aliases=['CRMP-4', 'CRMP4', 'DRP-3', 'DRP3', 'LCRMP', 'ULIP', 'ULIP-1'], description='dihydropyrimidinase like 3', other_designations='dihydropyrimidinase-related protein 3|collapsin response mediator protein 4 long|testicular secretory protein Li 7|unc-33-like phosphoprotein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147390808, end_position_on_the_genomic_accession=147510068, orientation='minus', exon_count=16, OMIM=[601168], no_hdr0=''),
    1810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1810, CurrentID=0, Status='live', Symbol='DR1', Aliases=['NC2', 'NC2-BETA', 'NC2B', 'NCB2'], description='down-regulator of transcription 1', other_designations='protein Dr1|TATA-binding protein-associated phosphoprotein|negative cofactor 2|negative cofactor 2-beta', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93345907, end_position_on_the_genomic_accession=93369493, orientation='plus', exon_count=3, OMIM=[601482], no_hdr0=''),
    1811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1811, CurrentID=0, Status='live', Symbol='SLC26A3', Aliases=['CLD', 'DRA'], description='solute carrier family 26 member 3', other_designations='chloride anion exchanger|down-regulated in adenoma protein|solute carrier family 26 (anion exchanger), member 3', map_location='7q22.3-q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107765469, end_position_on_the_genomic_accession=107803223, orientation='minus', exon_count=21, OMIM=[126650], no_hdr0=''),
    1812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1812, CurrentID=0, Status='live', Symbol='DRD1', Aliases=['DADRA', 'DRD1'], description='dopamine receptor D1', other_designations='D(1A) dopamine receptor|dopamine D1 receptor', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=175440036, end_position_on_the_genomic_accession=175444182, orientation='minus', exon_count=2, OMIM=[126449], no_hdr0=''),
    1813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1813, CurrentID=0, Status='live', Symbol='DRD2', Aliases=['D2DR', 'D2R'], description='dopamine receptor D2', other_designations='D(2) dopamine receptor|dopamine D2 receptor|seven transmembrane helix receptor', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113409605, end_position_on_the_genomic_accession=113475398, orientation='minus', exon_count=9, OMIM=[126450], no_hdr0=''),
    1814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1814, CurrentID=0, Status='live', Symbol='DRD3', Aliases=['D3DR', 'ETM1', 'FET1'], description='dopamine receptor D3', other_designations='D(3) dopamine receptor|essential tremor 1', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=114127580, end_position_on_the_genomic_accession=114199407, orientation='minus', exon_count=11, OMIM=[126451], no_hdr0=''),
    1815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1815, CurrentID=0, Status='live', Symbol='DRD4', Aliases=['D4DR'], description='dopamine receptor D4', other_designations='D(4) dopamine receptor|D(2C) dopamine receptor|dopamine D4 receptor|seven transmembrane helix receptor', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=637269, end_position_on_the_genomic_accession=640706, orientation='plus', exon_count=4, OMIM=[126452], no_hdr0=''),
    1816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1816, CurrentID=0, Status='live', Symbol='DRD5', Aliases=['DBDR', 'DRD1B', 'DRD1L2'], description='dopamine receptor D5', other_designations='D(1B) dopamine receptor|D1beta dopamine receptor|d(5) dopamine receptor|dopamine D5 receptor|dopamine receptor D1B', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9781634, end_position_on_the_genomic_accession=9784009, orientation='plus', exon_count=1, OMIM=[126453], no_hdr0=''),
    1819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1819, CurrentID=0, Status='live', Symbol='DRG2', Aliases=[], description='developmentally regulated GTP binding protein 2', other_designations='developmentally-regulated GTP-binding protein 2|TRAFAC GTPase DRG2|translation factor GTPase DRG2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18087885, end_position_on_the_genomic_accession=18107970, orientation='plus', exon_count=13, OMIM=[602986], no_hdr0=''),
    1820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1820, CurrentID=0, Status='live', Symbol='ARID3A', Aliases=['BRIGHT', 'DRIL1', 'DRIL3', 'E2FBP1'], description='AT-rich interaction domain 3A', other_designations='AT-rich interactive domain-containing protein 3A|ARID domain-containing 3A|ARID domain-containing protein 3A|AT rich interactive domain 3A (BRIGHT- like) protein|AT rich interactive domain 3A (BRIGHT-like)|B-cell regulator of IgH transcription|E2F-binding protein 1|dead ringer-like 1|dead ringer-like protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=925733, end_position_on_the_genomic_accession=975939, orientation='plus', exon_count=12, OMIM=[603265], no_hdr0=''),
    1821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1821, CurrentID=0, Status='live', Symbol='DRP2', Aliases=['DRP-2'], description='dystrophin related protein 2', other_designations='dystrophin-related protein 2', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101219786, end_position_on_the_genomic_accession=101264502, orientation='plus', exon_count=24, OMIM=[300052], no_hdr0=''),
    1822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1822, CurrentID=0, Status='live', Symbol='ATN1', Aliases=['B37', 'CHEDDA', 'D12S755E', 'DRPLA', 'HRS', 'NOD'], description='atrophin 1', other_designations='atrophin-1|dentatorubral-pallidoluysian atrophy protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6924459, end_position_on_the_genomic_accession=6942321, orientation='plus', exon_count=11, OMIM=[607462], no_hdr0=''),
    1823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1823, CurrentID=0, Status='live', Symbol='DSC1', Aliases=['CDHF1', 'DG2/DG3'], description='desmocollin 1', other_designations='desmocollin-1|cadherin family member 1|desmosomal glycoprotein 2/3', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31129236, end_position_on_the_genomic_accession=31162856, orientation='minus', exon_count=17, OMIM=[125643], no_hdr0=''),
    1824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1824, CurrentID=0, Status='live', Symbol='DSC2', Aliases=['ARVD11', 'CDHF2', 'DG2', 'DGII/III', 'DSC3'], description='desmocollin 2', other_designations='desmocollin-2|cadherin family member 2|desmosomal glycoprotein II/III', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31058840, end_position_on_the_genomic_accession=31102421, orientation='minus', exon_count=18, OMIM=[125645], no_hdr0=''),
    1825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1825, CurrentID=0, Status='live', Symbol='DSC3', Aliases=['CDHF3', 'DSC', 'DSC1', 'DSC2', 'DSC4', 'HT-CP'], description='desmocollin 3', other_designations='desmocollin-3|cadherin family member 3|desmocollin-4', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=30989365, end_position_on_the_genomic_accession=31042742, orientation='minus', exon_count=17, OMIM=[600271], no_hdr0=''),
    1826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1826, CurrentID=0, Status='live', Symbol='DSCAM', Aliases=['CHD2', 'CHD2-42', 'CHD2-52'], description='DS cell adhesion molecule', other_designations='Down syndrome cell adhesion molecule', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=40010999, end_position_on_the_genomic_accession=40847158, orientation='minus', exon_count=33, OMIM=[602523], no_hdr0=''),
    1827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1827, CurrentID=0, Status='live', Symbol='RCAN1', Aliases=['ADAPT78', 'CSP1', 'DSC1', 'DSCR1', 'MCIP1', 'RCN1'], description='regulator of calcineurin 1', other_designations='calcipressin-1|Down syndrome candidate region 1|Down syndrome critical region gene 1|calcium and oxidant-inducible mRNA|modulatory calcineurin-interacting protein 1|myocyte-enriched calcineurin-interacting protein 1|near DSCR proline-rich protein', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34516442, end_position_on_the_genomic_accession=34615123, orientation='minus', exon_count=9, OMIM=[602917], no_hdr0=''),
    1828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1828, CurrentID=0, Status='live', Symbol='DSG1', Aliases=['CDHF4', 'DG1', 'DSG', 'EPKHE', 'EPKHIA', 'PPKS1', 'SPPK1'], description='desmoglein 1', other_designations='desmoglein-1|cadherin family member 4|desmosomal glycoprotein 1|pemphigus foliaceus antigen', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31318160, end_position_on_the_genomic_accession=31359246, orientation='plus', exon_count=15, OMIM=[125670], no_hdr0=''),
    1829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1829, CurrentID=0, Status='live', Symbol='DSG2', Aliases=['CDHF5', 'HDGC'], description='desmoglein 2', other_designations='desmoglein-2|cadherin family member 5', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31498177, end_position_on_the_genomic_accession=31549008, orientation='plus', exon_count=16, OMIM=[125671], no_hdr0=''),
    1830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1830, CurrentID=0, Status='live', Symbol='DSG3', Aliases=['ABOLM', 'CDHF6', 'PVA'], description='desmoglein 3', other_designations='desmoglein-3|130 kDa pemphigus vulgaris antigen|cadherin family member 6', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31447741, end_position_on_the_genomic_accession=31478712, orientation='plus', exon_count=16, OMIM=[169615], no_hdr0=''),
    1831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1831, CurrentID=0, Status='live', Symbol='TSC22D3', Aliases=['DIP', 'DSIPI', 'GILZ', 'TSC-22R'], description='TSC22 domain family member 3', other_designations='TSC22 domain family protein 3|DSIP-immunoreactive leucine zipper protein|DSIP-immunoreactive peptide|TSC-22 related protein|TSC-22-like protein|delta sleep-inducing peptide immunoreactor|glucocorticoid-induced leucine zipper protein', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107713221, end_position_on_the_genomic_accession=107777329, orientation='minus', exon_count=8, OMIM=[300506], no_hdr0=''),
    1832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1832, CurrentID=0, Status='live', Symbol='DSP', Aliases=['DCWHKTA', 'DP'], description='desmoplakin', other_designations='desmoplakin|250/210 kDa paraneoplastic pemphigus antigen', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7541671, end_position_on_the_genomic_accession=7586714, orientation='plus', exon_count=24, OMIM=[125647], no_hdr0=''),
    1833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1833, CurrentID=0, Status='live', Symbol='EPYC', Aliases=['DSPG3', 'PGLB', 'Pg-Lb', 'SLRR3B'], description='epiphycan', other_designations='epiphycan|dermatan sulfate proteoglycan 3|epiphycan proteoglycan|proteoglycan-lb|small chondroitin/dermatan sulfate proteoglycan', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=90963679, end_position_on_the_genomic_accession=91004972, orientation='minus', exon_count=8, OMIM=[601657], no_hdr0=''),
    1834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1834, CurrentID=0, Status='live', Symbol='DSPP', Aliases=['DFNA39', 'DGI1', 'DMP3', 'DPP', 'DSP'], description='dentin sialophosphoprotein', other_designations='dentin sialophosphoprotein|deafness, autosomal dominant 39|dentin phosphophoryn|dentin phosphoprotein|dentin phosphoryn|dentin sialoprotein', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87608529, end_position_on_the_genomic_accession=87616873, orientation='plus', exon_count=5, OMIM=[125485], no_hdr0=''),
    1836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1836, CurrentID=0, Status='live', Symbol='SLC26A2', Aliases=['D5S1708', 'DTD', 'DTDST', 'EDM4', 'MST153', 'MSTP157'], description='solute carrier family 26 member 2', other_designations='sulfate transporter|diastrophic dysplasia protein|solute carrier family 26 (anion exchanger), member 2|solute carrier family 26 (sulfate transporter), member 2|sulfate anion transporter 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149960758, end_position_on_the_genomic_accession=149987400, orientation='plus', exon_count=3, OMIM=[606718], no_hdr0=''),
    1837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1837, CurrentID=0, Status='live', Symbol='DTNA', Aliases=['D18S892E', 'DRP3', 'DTN', 'DTN-A', 'LVNC1'], description='dystrobrevin alpha', other_designations='dystrobrevin alpha|dystrophin-related protein 3', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=34493298, end_position_on_the_genomic_accession=34891844, orientation='plus', exon_count=30, OMIM=[601239], no_hdr0=''),
    1838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1838, CurrentID=0, Status='live', Symbol='DTNB', Aliases=[], description='dystrobrevin beta', other_designations='dystrobrevin beta|DTN-B|beta-dystrobrevin', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25377243, end_position_on_the_genomic_accession=25673577, orientation='minus', exon_count=28, OMIM=[602415], no_hdr0=''),
    1839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1839, CurrentID=0, Status='live', Symbol='HBEGF', Aliases=['DTR', 'DTS', 'DTSF', 'HEGFL'], description='heparin binding EGF like growth factor', other_designations='proheparin-binding EGF-like growth factor|diphtheria toxin receptor (heparin-binding EGF-like growth factor)|diphtheria toxin receptor (heparin-binding epidermal growth factor-like growth factor)|heparin-binding epidermal growth factor', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140332843, end_position_on_the_genomic_accession=140346603, orientation='minus', exon_count=6, OMIM=[126150], no_hdr0=''),
    1840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1840, CurrentID=0, Status='live', Symbol='DTX1', Aliases=['RNF140', 'hDx-1'], description='deltex E3 ubiquitin ligase 1', other_designations='E3 ubiquitin-protein ligase DTX1|RING-type E3 ubiquitin transferase DTX1|deltex 1, E3 ubiquitin ligase|deltex homolog 1|protein deltex-1', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113056730, end_position_on_the_genomic_accession=113098025, orientation='plus', exon_count=10, OMIM=[602582], no_hdr0=''),
    1841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1841, CurrentID=0, Status='live', Symbol='DTYMK', Aliases=['CDC8', 'PP3731', 'TMPK', 'TYMK'], description='deoxythymidylate kinase', other_designations='thymidylate kinase|dTMP kinase|deoxythymidylate kinase (thymidylate kinase)', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241675747, end_position_on_the_genomic_accession=241686815, orientation='minus', exon_count=7, OMIM=[188345], no_hdr0=''),
    1842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1842, CurrentID=0, Status='live', Symbol='ECM2', Aliases=[], description='extracellular matrix protein 2', other_designations='extracellular matrix protein 2|extracellular matrix protein 2, female organ and adipocyte specific|matrix glycoprotein SC1/ECM2', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92493547, end_position_on_the_genomic_accession=92536841, orientation='minus', exon_count=13, OMIM=[603479], no_hdr0=''),
    1843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1843, CurrentID=0, Status='live', Symbol='DUSP1', Aliases=['CL100', 'HVH1', 'MKP-1', 'MKP1', 'PTPN10'], description='dual specificity phosphatase 1', other_designations='dual specificity protein phosphatase 1|CL 100|MAP kinase phosphatase 1|dual specificity protein phosphatase hVH1|mitogen-activated protein kinase phosphatase 1|protein-tyrosine phosphatase CL100|serine/threonine specific protein phosphatase', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172768096, end_position_on_the_genomic_accession=172771195, orientation='minus', exon_count=4, OMIM=[600714], no_hdr0=''),
    1844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1844, CurrentID=0, Status='live', Symbol='DUSP2', Aliases=['PAC-1', 'PAC1'], description='dual specificity phosphatase 2', other_designations='dual specificity protein phosphatase 2|dual specificity protein phosphatase PAC-1|serine/threonine specific protein phosphatase', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96143166, end_position_on_the_genomic_accession=96145468, orientation='minus', exon_count=3, OMIM=[603068], no_hdr0=''),
    1845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1845, CurrentID=0, Status='live', Symbol='DUSP3', Aliases=['VHR'], description='dual specificity phosphatase 3', other_designations='dual specificity protein phosphatase 3|dual specificity protein phosphatase VHR|serine/threonine specific protein phosphatase|vaccinia H1-related phosphatase|vaccinia virus phosphatase VH1-related', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43766125, end_position_on_the_genomic_accession=43778977, orientation='minus', exon_count=3, OMIM=[600183], no_hdr0=''),
    1846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1846, CurrentID=0, Status='live', Symbol='DUSP4', Aliases=['HVH2', 'MKP-2', 'MKP2', 'TYP'], description='dual specificity phosphatase 4', other_designations='dual specificity protein phosphatase 4|MAP kinase phosphatase 2|VH1 homologous phosphatase 2|dual specificity protein phosphatase hVH2|mitogen-activated protein kinase phosphatase 2|serine/threonine specific protein phosphatase', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=29333064, end_position_on_the_genomic_accession=29350684, orientation='minus', exon_count=6, OMIM=[602747], no_hdr0=''),
    1847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1847, CurrentID=0, Status='live', Symbol='DUSP5', Aliases=['DUSP', 'HVH3'], description='dual specificity phosphatase 5', other_designations='dual specificity protein phosphatase 5|VH1-like phosphatase 3|dual specificity protein phosphatase hVH3|serine/threonine specific protein phosphatase', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110497907, end_position_on_the_genomic_accession=110511533, orientation='plus', exon_count=4, OMIM=[603069], no_hdr0=''),
    1848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1848, CurrentID=0, Status='live', Symbol='DUSP6', Aliases=['HH19', 'MKP3', 'PYST1'], description='dual specificity phosphatase 6', other_designations='dual specificity protein phosphatase 6|MAP kinase phosphatase 3|dual specificity protein phosphatase PYST1|mitogen-activated protein kinase phosphatase 3|serine/threonine specific protein phosphatase', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=89347235, end_position_on_the_genomic_accession=89352501, orientation='minus', exon_count=3, OMIM=[602748], no_hdr0=''),
    1849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1849, CurrentID=0, Status='live', Symbol='DUSP7', Aliases=['MKPX', 'PYST2'], description='dual specificity phosphatase 7', other_designations='dual specificity protein phosphatase 7|dual specificity protein phosphatase PYST2', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52048919, end_position_on_the_genomic_accession=52056571, orientation='minus', exon_count=3, OMIM=[602749], no_hdr0=''),
    1850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1850, CurrentID=0, Status='live', Symbol='DUSP8', Aliases=['C11orf81', 'HB5', 'HVH-5', 'HVH8'], description='dual specificity phosphatase 8', other_designations='dual specificity protein phosphatase 8|H1 phosphatase, vaccinia virus homolog|dual specificity protein phosphatase hVH-5|serine/threonine specific protein phosphatase', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1554051, end_position_on_the_genomic_accession=1572839, orientation='minus', exon_count=9, OMIM=[602038], no_hdr0=''),
    1852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1852, CurrentID=0, Status='live', Symbol='DUSP9', Aliases=['MKP-4', 'MKP4'], description='dual specificity phosphatase 9', other_designations='dual specificity protein phosphatase 9|map kinase phosphatase 4|mitogen-activated protein kinase phosphatase 4|serine/threonine specific protein phosphatase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153642441, end_position_on_the_genomic_accession=153651326, orientation='plus', exon_count=7, OMIM=[300134], no_hdr0=''),
    1854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1854, CurrentID=0, Status='live', Symbol='DUT', Aliases=['dUTPase'], description='deoxyuridine triphosphatase', other_designations="deoxyuridine 5'-triphosphate nucleotidohydrolase, mitochondrial|dUTP diphosphatase|dUTP nucleotidohydrolase|dUTP pyrophosphatase", map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48329991, end_position_on_the_genomic_accession=48343373, orientation='plus', exon_count=9, OMIM=[601266], no_hdr0=''),
    1855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1855, CurrentID=0, Status='live', Symbol='DVL1', Aliases=['DRS2', 'DVLL1', 'DVL1P1', 'DVL1'], description='dishevelled segment polarity protein 1', other_designations='segment polarity protein dishevelled homolog DVL-1|DSH homolog 1|dishevelled 1 (homologous to Drosophila dsh)|dishevelled, dsh homolog 1|dishevelled-1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1335278, end_position_on_the_genomic_accession=1349418, orientation='minus', exon_count=16, OMIM=[601365], no_hdr0=''),
    1856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1856, CurrentID=0, Status='live', Symbol='DVL2', Aliases=[], description='dishevelled segment polarity protein 2', other_designations='segment polarity protein dishevelled homolog DVL-2|dishevelled 2 (homologous to Drosophila dsh)|dishevelled, dsh homolog 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7225341, end_position_on_the_genomic_accession=7234544, orientation='minus', exon_count=16, OMIM=[602151], no_hdr0=''),
    1857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1857, CurrentID=0, Status='live', Symbol='DVL3', Aliases=['DRS3'], description='dishevelled segment polarity protein 3', other_designations='segment polarity protein dishevelled homolog DVL-3|dishevelled 3 (homologous to Drosophila dsh)|dishevelled, dsh homolog 3', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184155377, end_position_on_the_genomic_accession=184173614, orientation='plus', exon_count=15, OMIM=[601368], no_hdr0=''),
    1859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1859, CurrentID=0, Status='live', Symbol='DYRK1A', Aliases=['DYRK', 'DYRK1', 'HP86', 'MNB', 'MNBH', 'MRD7'], description='dual specificity tyrosine phosphorylation regulated kinase 1A', other_designations='dual specificity tyrosine-phosphorylation-regulated kinase 1A|MNB/DYRK protein kinase|dual specificity YAK1-related kinase|dual specificity tyrosine-(Y)-phosphorylation regulated kinase 1A|mnb protein kinase homolog hp86|protein kinase minibrain homolog|serine/threonine kinase MNB|serine/threonine-specific protein kinase', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37365573, end_position_on_the_genomic_accession=37526358, orientation='plus', exon_count=21, OMIM=[600855], no_hdr0=''),
    1861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1861, CurrentID=0, Status='live', Symbol='TOR1A', Aliases=['AMC5', 'DQ2', 'DYT1'], description='torsin family 1 member A', other_designations='torsin-1A|dystonia 1 protein|dystonia 1, torsion (autosomal dominant; torsin A)|torsin A|torsin ATPase 1|torsin ATPase-1A', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129812942, end_position_on_the_genomic_accession=129824136, orientation='minus', exon_count=5, OMIM=[605204], no_hdr0=''),
    1869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1869, CurrentID=0, Status='live', Symbol='E2F1', Aliases=['E2F-1', 'RBAP1', 'RBBP3', 'RBP3'], description='E2F transcription factor 1', other_designations='transcription factor E2F1|PBR3|PRB-binding protein E2F-1|RBAP-1|RBBP-3|retinoblastoma-associated protein 1|retinoblastoma-binding protein 3', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33675477, end_position_on_the_genomic_accession=33686385, orientation='minus', exon_count=7, OMIM=[189971], no_hdr0=''),
    1870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1870, CurrentID=0, Status='live', Symbol='E2F2', Aliases=['E2F-2'], description='E2F transcription factor 2', other_designations='transcription factor E2F2', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23505696, end_position_on_the_genomic_accession=23531250, orientation='minus', exon_count=10, OMIM=[600426], no_hdr0=''),
    1871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1871, CurrentID=0, Status='live', Symbol='E2F3', Aliases=['E2F-3'], description='E2F transcription factor 3', other_designations='transcription factor E2F3', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=20401879, end_position_on_the_genomic_accession=20493714, orientation='plus', exon_count=11, OMIM=[600427], no_hdr0=''),
    1874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1874, CurrentID=0, Status='live', Symbol='E2F4', Aliases=['E2F-4'], description='E2F transcription factor 4', other_designations='transcription factor E2F4|E2F transcription factor 4, p107/p130-binding|p107/p130-binding protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67192155, end_position_on_the_genomic_accession=67198918, orientation='plus', exon_count=10, OMIM=[600659], no_hdr0=''),
    1875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1875, CurrentID=0, Status='live', Symbol='E2F5', Aliases=['E2F-5'], description='E2F transcription factor 5', other_designations='transcription factor E2F5|E2F transcription factor 5, p130-binding', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85177154, end_position_on_the_genomic_accession=85214518, orientation='plus', exon_count=9, OMIM=[600967], no_hdr0=''),
    1876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1876, CurrentID=0, Status='live', Symbol='E2F6', Aliases=['E2F-6'], description='E2F transcription factor 6', other_designations='transcription factor E2F6', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11444375, end_position_on_the_genomic_accession=11466177, orientation='minus', exon_count=10, OMIM=[602944], no_hdr0=''),
    1877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1877, CurrentID=0, Status='live', Symbol='E4F1', Aliases=['E4F'], description='E4F transcription factor 1', other_designations='transcription factor E4F1|RING-type E3 ubiquitin transferase E4F1|p120E4F|p50E4F|putative E3 ubiquitin-protein ligase E4F1|transcription factor E4F', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2223498, end_position_on_the_genomic_accession=2235742, orientation='plus', exon_count=14, OMIM=[603022], no_hdr0=''),
    1879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1879, CurrentID=0, Status='live', Symbol='EBF1', Aliases=['COE1', 'EBF', 'O/E-1', 'OLF1'], description='EBF transcription factor 1', other_designations='transcription factor COE1|Collier, Olf and EBF transcription factor 1|early B cell factor 1|olfactory neuronal transcription factor 1', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=158695918, end_position_on_the_genomic_accession=159099916, orientation='minus', exon_count=22, OMIM=[164343], no_hdr0=''),
    1880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1880, CurrentID=0, Status='live', Symbol='GPR183', Aliases=['EBI2', 'hEBI2'], description='G protein-coupled receptor 183', other_designations='G-protein coupled receptor 183|EBV-induced G-protein coupled receptor 2|Epstein-Barr virus induced gene 2 (lymphocyte-specific G protein-coupled receptor)|epstein-Barr virus-induced G-protein coupled receptor 2', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99294273, end_position_on_the_genomic_accession=99307399, orientation='minus', exon_count=3, OMIM=[605741], no_hdr0=''),
    1889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1889, CurrentID=0, Status='live', Symbol='ECE1', Aliases=['ECE'], description='endothelin converting enzyme 1', other_designations='endothelin-converting enzyme 1|ECE-1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21217250, end_position_on_the_genomic_accession=21345504, orientation='minus', exon_count=23, OMIM=[600423], no_hdr0=''),
    1890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1890, CurrentID=0, Status='live', Symbol='TYMP', Aliases=['ECGF', 'ECGF1', 'MEDPS1', 'MNGIE', 'MTDPS1', 'PDECGF', 'TP', 'hPD-ECGF'], description='thymidine phosphorylase', other_designations='thymidine phosphorylase|gliostatin|tdRPase', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50525752, end_position_on_the_genomic_accession=50530085, orientation='minus', exon_count=10, OMIM=[131222], no_hdr0=''),
    1891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1891, CurrentID=0, Status='live', Symbol='ECH1', Aliases=['HPXEL'], description='enoyl-CoA hydratase 1', other_designations='delta(3,5)-Delta(2,4)-dienoyl-CoA isomerase, mitochondrial|delta3,5-delta2,4-dienoyl-CoA isomerase|delta3,5-delta2,4-dienoyl-coenzyme A isomerase|dienoyl-CoA isomerase|enoyl Coenzyme A hydratase 1, peroxisomal|enoyl-CoA hydratase 1, peroxisomal|epididymis secretory sperm binding protein|peroxisomal enoyl-CoA hydratase 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38815422, end_position_on_the_genomic_accession=38831794, orientation='minus', exon_count=9, OMIM=[600696], no_hdr0=''),
    1892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1892, CurrentID=0, Status='live', Symbol='ECHS1', Aliases=['ECHS1D', 'SCEH'], description='enoyl-CoA hydratase, short chain 1', other_designations='enoyl-CoA hydratase, mitochondrial|enoyl Coenzyme A hydratase, short chain, 1, mitochondrial|enoyl-CoA hydratase, short chain, 1, mitochondrial|epididymis secretory sperm binding protein|short chain enoyl-CoA hydratase', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133362480, end_position_on_the_genomic_accession=133373396, orientation='minus', exon_count=7, OMIM=[602292], no_hdr0=''),
    1893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1893, CurrentID=0, Status='live', Symbol='ECM1', Aliases=['URBWD'], description='extracellular matrix protein 1', other_designations='extracellular matrix protein 1|secretory component p85|testicular tissue protein Li 61', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150508109, end_position_on_the_genomic_accession=150513789, orientation='plus', exon_count=10, OMIM=[602201], no_hdr0=''),
    1894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1894, CurrentID=0, Status='live', Symbol='ECT2', Aliases=['ARHGEF31'], description='epithelial cell transforming 2', other_designations='protein ECT2|epithelial cell-transforming sequence 2 oncogene', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172750694, end_position_on_the_genomic_accession=172829273, orientation='plus', exon_count=29, OMIM=[600586], no_hdr0=''),
    1896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1896, CurrentID=0, Status='live', Symbol='EDA', Aliases=['ECTD1', 'ED1', 'ED1-A1', 'ED1-A2-A1', 'EDA-A2', 'EDA1', 'EDA2', 'HED', 'HED1', 'ODT1', 'STHAGX1', 'TNLG7C', 'XHED', 'XLHED', 'EDA'], description='ectodysplasin A', other_designations='ectodysplasin-A|X-linked anhidroitic ectodermal dysplasia protein|oligodontia 1|tumor necrosis factor ligand 7C', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=69616086, end_position_on_the_genomic_accession=70039472, orientation='plus', exon_count=13, OMIM=[300451], no_hdr0=''),
    1901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1901, CurrentID=0, Status='live', Symbol='S1PR1', Aliases=['CD363', 'CHEDG1', 'D1S3362', 'ECGF1', 'EDG-1', 'EDG1', 'S1P1'], description='sphingosine-1-phosphate receptor 1', other_designations='sphingosine 1-phosphate receptor 1|S1P receptor 1|S1P receptor Edg-1|endothelial differentiation G-protein coupled receptor 1|endothelial differentiation, sphingolipid G-protein-coupled receptor, 1|sphingosine 1-phosphate receptor EDG1|sphingosine 1-phosphate receptor Edg-1', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=101236899, end_position_on_the_genomic_accession=101241518, orientation='plus', exon_count=3, OMIM=[601974], no_hdr0=''),
    1902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1902, CurrentID=0, Status='live', Symbol='LPAR1', Aliases=['EDG2', 'Gpcr26', 'LPA1', 'Mrec1.3', 'VZG1', 'edg-2', 'rec.1.3', 'vzg-1'], description='lysophosphatidic acid receptor 1', other_designations='lysophosphatidic acid receptor 1|LPA receptor 1|LPA-1|endothelial differentiation, lysophosphatidic acid G-protein-coupled receptor, 2|lysophosphatidic acid receptor Edg-2|ventricular zone gene 1', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110873252, end_position_on_the_genomic_accession=111038998, orientation='minus', exon_count=16, OMIM=[602282], no_hdr0=''),
    1903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1903, CurrentID=0, Status='live', Symbol='S1PR3', Aliases=['EDG-3', 'EDG3', 'LPB3', 'S1P3'], description='sphingosine-1-phosphate receptor 3', other_designations='sphingosine 1-phosphate receptor 3|G protein-coupled receptor, endothelial differentiation gene-3|S1P receptor 3|S1P receptor EDG3|S1P receptor Edg-3|endothelial differentiation G-protein coupled receptor 3|endothelial differentiation, sphingolipid G-protein-coupled receptor, 3|sphingosine 1-phosphate receptor Edg-3', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=88991468, end_position_on_the_genomic_accession=89005155, orientation='plus', exon_count=2, OMIM=[601965], no_hdr0=''),
    1906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1906, CurrentID=0, Status='live', Symbol='EDN1', Aliases=['ARCND3', 'ET1', 'HDLCQ7', 'PPET1', 'QME'], description='endothelin 1', other_designations='endothelin-1|preproendothelin-1', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=12256463, end_position_on_the_genomic_accession=12297194, orientation='plus', exon_count=9, OMIM=[131240], no_hdr0=''),
    1907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1907, CurrentID=0, Status='live', Symbol='EDN2', Aliases=['ET-2', 'ET2', 'PPET2'], description='endothelin 2', other_designations='endothelin-2|preproendothelin 2', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=41478775, end_position_on_the_genomic_accession=41484699, orientation='minus', exon_count=6, OMIM=[131241], no_hdr0=''),
    1908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1908, CurrentID=0, Status='live', Symbol='EDN3', Aliases=['ET-3', 'ET3', 'HSCR4', 'PPET3', 'WS4B'], description='endothelin 3', other_designations='endothelin-3|preproendothelin-3', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59300415, end_position_on_the_genomic_accession=59325992, orientation='plus', exon_count=6, OMIM=[131242], no_hdr0=''),
    1909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1909, CurrentID=0, Status='live', Symbol='EDNRA', Aliases=['ET-A', 'ETA', 'ETA-R', 'ETAR', 'ETRA', 'MFDA', 'hET-AR'], description='endothelin receptor type A', other_designations='endothelin-1 receptor|G protein-coupled receptor|endothelin receptor subtype A|endothelin-1-specific receptor', map_location='4q31.22-q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=147481097, end_position_on_the_genomic_accession=147544954, orientation='plus', exon_count=9, OMIM=[131243], no_hdr0=''),
    1910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1910, CurrentID=0, Status='live', Symbol='EDNRB', Aliases=['ABCDS', 'ET-B', 'ET-BR', 'ETB', 'ETB1', 'ETBR', 'ETRB', 'HSCR', 'HSCR2', 'WS4A'], description='endothelin receptor type B', other_designations='endothelin receptor type B|Hirschsprung disease 2|endothelin receptor non-selective type|endothelin receptor subtype B1', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=77895481, end_position_on_the_genomic_accession=77975527, orientation='minus', exon_count=9, OMIM=[131244], no_hdr0=''),
    1911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1911, CurrentID=0, Status='live', Symbol='PHC1', Aliases=['EDR1', 'HPH1', 'MCPH11', 'RAE28'], description='polyhomeotic homolog 1', other_designations='polyhomeotic-like protein 1|early development regulator 1 (homolog of polyhomeotic 1)|early development regulatory protein 1|polyhomeotic-like 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8914509, end_position_on_the_genomic_accession=8941467, orientation='plus', exon_count=16, OMIM=[602978], no_hdr0=''),
    1912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1912, CurrentID=0, Status='live', Symbol='PHC2', Aliases=['EDR2', 'HPH2', 'PH2'], description='polyhomeotic homolog 2', other_designations='polyhomeotic-like protein 2|early development regulator 2 (homolog of polyhomeotic 2)|early development regulatory protein 2|polyhomeotic 2|polyhomeotic-like 2', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33323626, end_position_on_the_genomic_accession=33431095, orientation='minus', exon_count=18, OMIM=[602979], no_hdr0=''),
    1915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1915, CurrentID=0, Status='live', Symbol='EEF1A1', Aliases=['CCS-3', 'CCS3', 'EE1A1', 'EEF-1', 'EEF1A', 'EF-Tu', 'EF1A', 'GRAF-1EF', 'LENG7', 'PTI1', 'eEF1A-1'], description='eukaryotic translation elongation factor 1 alpha 1', other_designations='elongation factor 1-alpha 1|CTCL tumor antigen|EF-1-alpha-1|EF1a-like protein|cervical cancer suppressor 3|elongation factor 1 alpha subunit|elongation factor Tu|epididymis secretory sperm binding protein|eukaryotic elongation factor 1 A-1|eukaryotic translation elongation factor 1 alpha 1-like 14|glucocorticoid receptor AF-1 specific elongation factor|leukocyte receptor cluster (LRC) member 7|leukocyte receptor cluster member 7|prostate tumor-inducing protein 1|translation elongation factor 1 alpha 1-like 14', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73515750, end_position_on_the_genomic_accession=73521032, orientation='minus', exon_count=8, OMIM=[130590], no_hdr0=''),
    1917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1917, CurrentID=0, Status='live', Symbol='EEF1A2', Aliases=['DEE33', 'EEF1AL', 'EF-1-alpha-2', 'EF1A', 'EIEE33', 'HS1', 'MRD38', 'STN', 'STNL'], description='eukaryotic translation elongation factor 1 alpha 2', other_designations='elongation factor 1-alpha 2|eukaryotic elongation factor 1 A-2|statin-S1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63488014, end_position_on_the_genomic_accession=63499083, orientation='minus', exon_count=8, OMIM=[602959], no_hdr0=''),
    1933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1933, CurrentID=0, Status='live', Symbol='EEF1B2', Aliases=['EEF1B', 'EEF1B1', 'EF1B'], description='eukaryotic translation elongation factor 1 beta 2', other_designations='elongation factor 1-beta|EF-1-beta|eukaryotic translation elongation factor 1 beta 1', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206159609, end_position_on_the_genomic_accession=206162928, orientation='plus', exon_count=7, OMIM=[600655], no_hdr0=''),
    1936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1936, CurrentID=0, Status='live', Symbol='EEF1D', Aliases=['EF-1D', 'EF1D', 'FP1047'], description='eukaryotic translation elongation factor 1 delta', other_designations='elongation factor 1-delta|EF-1-delta|antigen NY-CO-4|eukaryotic translation elongation factor 1 delta (guanine nucleotide exchange protein)', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143579728, end_position_on_the_genomic_accession=143597422, orientation='minus', exon_count=11, OMIM=[130592], no_hdr0=''),
    1937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1937, CurrentID=0, Status='live', Symbol='EEF1G', Aliases=['EF1G', 'GIG35'], description='eukaryotic translation elongation factor 1 gamma', other_designations='elongation factor 1-gamma|EF-1-gamma|PRO1608|eEF-1B gamma|pancreatic tumor-related protein|translation elongation factor eEF-1 gamma chain', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62559596, end_position_on_the_genomic_accession=62573891, orientation='minus', exon_count=10, OMIM=[130593], no_hdr0=''),
    1938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1938, CurrentID=0, Status='live', Symbol='EEF2', Aliases=['EEF-2', 'EF-2', 'EF2', 'SCA26'], description='eukaryotic translation elongation factor 2', other_designations='elongation factor 2|epididymis secretory sperm binding protein|polypeptidyl-tRNA translocase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3976056, end_position_on_the_genomic_accession=3985463, orientation='minus', exon_count=15, OMIM=[130610], no_hdr0=''),
    1939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1939, CurrentID=0, Status='live', Symbol='EIF2D', Aliases=['HCA56', 'LGTN'], description='eukaryotic translation initiation factor 2D', other_designations='eukaryotic translation initiation factor 2D|hepatocellular carcinoma-associated antigen 56|ligatin', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206572484, end_position_on_the_genomic_accession=206612466, orientation='minus', exon_count=18, OMIM=[613709], no_hdr0=''),
    1942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1942, CurrentID=0, Status='live', Symbol='EFNA1', Aliases=['B61', 'ECKLG', 'EFL1', 'EPLG1', 'GMAN', 'LERK-1', 'LERK1', 'TNFAIP4'], description='ephrin A1', other_designations='ephrin-A1|TNF alpha-induced protein 4|eph-related receptor tyrosine kinase ligand 1|epididymis secretory sperm binding protein|gastric cancer metastasis associated long noncoding RNA|immediate early response protein B61|ligand of eph-related kinase 1|tumor necrosis factor, alpha-induced protein 4', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155127876, end_position_on_the_genomic_accession=155134899, orientation='plus', exon_count=5, OMIM=[191164], no_hdr0=''),
    1943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1943, CurrentID=0, Status='live', Symbol='EFNA2', Aliases=['ELF-1', 'EPLG6', 'HEK7-L', 'LERK-6', 'LERK6'], description='ephrin A2', other_designations='ephrin-A2|HEK7 ligand|eph-related receptor tyrosine kinase ligand 6', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1282817, end_position_on_the_genomic_accession=1301431, orientation='plus', exon_count=6, OMIM=[602756], no_hdr0=''),
    1944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1944, CurrentID=0, Status='live', Symbol='EFNA3', Aliases=['EFL2', 'EPLG3', 'Ehk1-L', 'LERK3'], description='ephrin A3', other_designations='ephrin-A3|EFL-2|EHK1 ligand|LERK-3|eph-related receptor tyrosine kinase ligand 3|ligand of eph-related kinase 3', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155078837, end_position_on_the_genomic_accession=155087538, orientation='plus', exon_count=5, OMIM=[601381], no_hdr0=''),
    1945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1945, CurrentID=0, Status='live', Symbol='EFNA4', Aliases=['EFL4', 'EPLG4', 'LERK4'], description='ephrin A4', other_designations='ephrin-A4|LERK-4|eph-related receptor tyrosine kinase ligand 4|ligand of eph-related kinase 4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155063740, end_position_on_the_genomic_accession=155069553, orientation='plus', exon_count=4, OMIM=[601380], no_hdr0=''),
    1946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1946, CurrentID=0, Status='live', Symbol='EFNA5', Aliases=['AF1', 'EFL5', 'EPLG7', 'GLC1M', 'LERK7', 'RAGS'], description='ephrin A5', other_designations='ephrin-A5|AL-1|LERK-7|eph-related receptor tyrosine kinase ligand 7', map_location='5q21.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=107376889, end_position_on_the_genomic_accession=107670937, orientation='minus', exon_count=8, OMIM=[601535], no_hdr0=''),
    1947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1947, CurrentID=0, Status='live', Symbol='EFNB1', Aliases=['CFND', 'CFNS', 'EFB1', 'EFL3', 'EPLG2', 'Elk-L', 'LERK2'], description='ephrin B1', other_designations='ephrin-B1|ELK ligand|eph-related receptor tyrosine kinase ligand 2', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=68829021, end_position_on_the_genomic_accession=68842160, orientation='plus', exon_count=5, OMIM=[300035], no_hdr0=''),
    1948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1948, CurrentID=0, Status='live', Symbol='EFNB2', Aliases=['EPLG5', 'HTKL', 'Htk-L', 'LERK5'], description='ephrin B2', other_designations='ephrin-B2|HTK ligand|eph-related receptor tyrosine kinase ligand 5|ligand of eph-related kinase 5', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=106489745, end_position_on_the_genomic_accession=106535662, orientation='minus', exon_count=7, OMIM=[600527], no_hdr0=''),
    1949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1949, CurrentID=0, Status='live', Symbol='EFNB3', Aliases=['EFL6', 'EPLG8', 'LERK8'], description='ephrin B3', other_designations='ephrin-B3|EPH-related receptor transmembrane ligand ELK-L3|eph-related receptor tyrosine kinase ligand 8', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7705202, end_position_on_the_genomic_accession=7711372, orientation='plus', exon_count=5, OMIM=[602297], no_hdr0=''),
    1950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1950, CurrentID=0, Status='live', Symbol='EGF', Aliases=['HOMG4', 'URG'], description='epidermal growth factor', other_designations='pro-epidermal growth factor|beta-urogastrone', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109912883, end_position_on_the_genomic_accession=110013766, orientation='plus', exon_count=26, OMIM=[131530], no_hdr0=''),
    1951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1951, CurrentID=0, Status='live', Symbol='CELSR3', Aliases=['ADGRC3', 'CDHF11', 'EGFL1', 'FMI1', 'HFMI1', 'MEGF2', 'RESDA1'], description='cadherin EGF LAG seven-pass G-type receptor 3', other_designations='cadherin EGF LAG seven-pass G-type receptor 3|EGF-like protein 1|EGF-like-domain, multiple 1|adhesion G protein-coupled receptor C3|anchor protein|cadherin family member 11|cadherin, EGF LAG seven-pass G-type receptor 3 (flamingo homolog, Drosophila)|epidermal growth factor-like protein 1|flamingo homolog 1|multiple EGF-like domains protein 2|multiple epidermal growth factor-like domains protein 2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48636463, end_position_on_the_genomic_accession=48662886, orientation='minus', exon_count=35, OMIM=[604264], no_hdr0=''),
    1952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1952, CurrentID=0, Status='live', Symbol='CELSR2', Aliases=['ADGRC2', 'CDHF10', 'EGFL2', 'Flamingo1', 'MEGF3'], description='cadherin EGF LAG seven-pass G-type receptor 2', other_designations='cadherin EGF LAG seven-pass G-type receptor 2|EGF-like protein 2|EGF-like-domain, multiple 2|adhesion G protein-coupled receptor C2|cadherin family member 10|cadherin, EGF LAG seven-pass G-type receptor 2 (flamingo homolog, Drosophila)|epidermal growth factor-like 2|epidermal growth factor-like protein 2|flamingo homolog 3|multiple EGF-like domains protein 3|multiple epidermal growth factor-like domains 3|multiple epidermal growth factor-like domains protein 3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109249539, end_position_on_the_genomic_accession=109275751, orientation='plus', exon_count=34, OMIM=[604265], no_hdr0=''),
    1953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1953, CurrentID=0, Status='live', Symbol='MEGF6', Aliases=['EGFL3'], description='multiple EGF like domains 6', other_designations='multiple epidermal growth factor-like domains protein 6|EGF-like protein 3|EGF-like-domain, multiple 3|epidermal growth factor-like protein 3|multiple EGF-like domains protein 6', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3487951, end_position_on_the_genomic_accession=3624770, orientation='minus', exon_count=41, OMIM=[604266], no_hdr0=''),
    1954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1954, CurrentID=0, Status='live', Symbol='MEGF8', Aliases=['C19orf49', 'CRPT2', 'EGFL4', 'SBP1'], description='multiple EGF like domains 8', other_designations='multiple epidermal growth factor-like domains protein 8|EGF-like domain-containing protein 4|EGF-like-domain, multiple 4|HBV pre-S2-binding protein 1|HBV pre-s2 binding protein 1|epidermal growth factor-like protein 4|hepatitis B virus pre-S2-binding protein 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42325635, end_position_on_the_genomic_accession=42378765, orientation='plus', exon_count=42, OMIM=[604267], no_hdr0=''),
    1955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1955, CurrentID=0, Status='live', Symbol='MEGF9', Aliases=['EGFL5'], description='multiple EGF like domains 9', other_designations='multiple epidermal growth factor-like domains protein 9|EGF-like-domain, multiple 5|epidermal growth factor-like protein 5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120600811, end_position_on_the_genomic_accession=120714470, orientation='minus', exon_count=6, OMIM=[604268], no_hdr0=''),
    1956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1956, CurrentID=0, Status='live', Symbol='EGFR', Aliases=['ERBB', 'ERBB1', 'ERRP', 'HER1', 'NISBD2', 'PIG61', 'mENA'], description='epidermal growth factor receptor', other_designations='epidermal growth factor receptor|avian erythroblastic leukemia viral (v-erb-b) oncogene homolog|cell growth inhibiting protein 40|cell proliferation-inducing protein 61|epidermal growth factor receptor tyrosine kinase domain|erb-b2 receptor tyrosine kinase 1|proto-oncogene c-ErbB-1|receptor tyrosine-protein kinase erbB-1', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55019017, end_position_on_the_genomic_accession=55211628, orientation='plus', exon_count=31, OMIM=[131550], no_hdr0=''),
    1958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1958, CurrentID=0, Status='live', Symbol='EGR1', Aliases=['AT225', 'G0S30', 'KROX-24', 'NGFI-A', 'TIS8', 'ZIF-268', 'ZNF225'], description='early growth response 1', other_designations='early growth response protein 1|EGR-1|nerve growth factor-induced protein A|transcription factor ETR103|transcription factor Zif268|zinc finger protein 225|zinc finger protein Krox-24', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138465479, end_position_on_the_genomic_accession=138469303, orientation='plus', exon_count=2, OMIM=[128990], no_hdr0=''),
    1959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1959, CurrentID=0, Status='live', Symbol='EGR2', Aliases=['AT591', 'CHN1', 'CMT1D', 'CMT4E', 'KROX20'], description='early growth response 2', other_designations='E3 SUMO-protein ligase EGR2|E3 SUMO-protein transferase ERG2|KROX-20, Drosophila, homolog (early growth response-2)|early growth response protein 2|zinc finger protein Krox-20', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=62811996, end_position_on_the_genomic_accession=62819167, orientation='minus', exon_count=5, OMIM=[129010], no_hdr0=''),
    1960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1960, CurrentID=0, Status='live', Symbol='EGR3', Aliases=['EGR-3', 'PILOT'], description='early growth response 3', other_designations='early growth response protein 3|zinc finger protein pilot', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22687659, end_position_on_the_genomic_accession=22693480, orientation='minus', exon_count=5, OMIM=[602419], no_hdr0=''),
    1961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1961, CurrentID=0, Status='live', Symbol='EGR4', Aliases=['AT133', 'NGFI-C', 'NGFIC', 'PAT133'], description='early growth response 4', other_designations='early growth response protein 4', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73290929, end_position_on_the_genomic_accession=73293548, orientation='minus', exon_count=2, OMIM=[128992], no_hdr0=''),
    1962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1962, CurrentID=0, Status='live', Symbol='EHHADH', Aliases=['ECHD', 'FRTS3', 'L-PBE', 'LBFP', 'LBP', 'MFE1', 'PBFE'], description='enoyl-CoA hydratase and 3-hydroxyacyl CoA dehydrogenase', other_designations='peroxisomal bifunctional enzyme|3,2-trans-enoyl-CoA isomerase|L-3-hydroxyacyl-CoA dehydrogenase|L-bifunctional protein, peroxisomal|PBE|enoyl-CoA, hydratase/3-hydroxyacyl CoA dehydrogenase|enoyl-Coenzyme A, hydratase/3-hydroxyacyl Coenzyme A dehydrogenase|multifunctional enzyme 1|peroxisomal enoyl-CoA hydratase', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185190624, end_position_on_the_genomic_accession=185254049, orientation='minus', exon_count=8, OMIM=[607037], no_hdr0=''),
    1964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1964, CurrentID=0, Status='live', Symbol='EIF1AX', Aliases=['EIF1A', 'EIF1AP1', 'EIF4C', 'eIF-1A', 'eIF-4C'], description='eukaryotic translation initiation factor 1A X-linked', other_designations='eukaryotic translation initiation factor 1A, X-chromosomal|Putative eukaryotic translation initiation factor 1A|eukaryotic translation initiation factor 1A, X chromosome|eukaryotic translation initiation factor 4C', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=20124525, end_position_on_the_genomic_accession=20141838, orientation='minus', exon_count=7, OMIM=[300186], no_hdr0=''),
    1965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1965, CurrentID=0, Status='live', Symbol='EIF2S1', Aliases=['EIF-2', 'EIF-2A', 'EIF-2alpha', 'EIF2', 'EIF2A'], description='eukaryotic translation initiation factor 2 subunit alpha', other_designations='eukaryotic translation initiation factor 2 subunit 1|eIF-2-alpha|eukaryotic translation initiation factor 2, subunit 1 alpha, 35kDa', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67360328, end_position_on_the_genomic_accession=67386516, orientation='plus', exon_count=8, OMIM=[603907], no_hdr0=''),
    1967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1967, CurrentID=0, Status='live', Symbol='EIF2B1', Aliases=['EIF2B', 'EIF2BA'], description='eukaryotic translation initiation factor 2B subunit alpha', other_designations='translation initiation factor eIF-2B subunit alpha|eIF-2B GDP-GTP exchange factor subunit alpha|eukaryotic translation initiation factor 2B, subunit 1 alpha, 26kDa', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123620406, end_position_on_the_genomic_accession=123633686, orientation='minus', exon_count=9, OMIM=[606686], no_hdr0=''),
    1968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1968, CurrentID=0, Status='live', Symbol='EIF2S3', Aliases=['EIF2', 'EIF2G', 'EIF2gamma', 'MEHMO', 'MRXSBRK', 'eIF-2gA'], description='eukaryotic translation initiation factor 2 subunit gamma', other_designations='eukaryotic translation initiation factor 2 subunit 3|eIF-2-gamma X|eIF-2gX|eukaryotic translation initiation factor 2 subunit gamma X|eukaryotic translation initiation factor 2, subunit 3 gamma, 52kDa|eukaryotic translation initiation factor 2G', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24054956, end_position_on_the_genomic_accession=24078810, orientation='plus', exon_count=12, OMIM=[300161], no_hdr0=''),
    1969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1969, CurrentID=0, Status='live', Symbol='EPHA2', Aliases=['ARCC2', 'CTPA', 'CTPP1', 'CTRCT6', 'ECK'], description='EPH receptor A2', other_designations='ephrin type-A receptor 2|epithelial cell receptor protein tyrosine kinase|soluble EPHA2 variant 1|tyrosine-protein kinase receptor ECK', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16124337, end_position_on_the_genomic_accession=16156104, orientation='minus', exon_count=18, OMIM=[176946], no_hdr0=''),
    1973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1973, CurrentID=0, Status='live', Symbol='EIF4A1', Aliases=['DDX2A', 'EIF-4A', 'EIF4A', 'eIF-4A-I', 'eIF4A-I'], description='eukaryotic translation initiation factor 4A1', other_designations='eukaryotic initiation factor 4A-I|ATP-dependent RNA helicase eIF4A-1|eukaryotic initiation factor 4AI|eukaryotic translation initiation factor 4A', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7572825, end_position_on_the_genomic_accession=7579006, orientation='plus', exon_count=11, OMIM=[602641], no_hdr0=''),
    1974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1974, CurrentID=0, Status='live', Symbol='EIF4A2', Aliases=['BM-010', 'DDX2B', 'EIF4A', 'EIF4F', 'eIF-4A-II', 'eIF4A-II'], description='eukaryotic translation initiation factor 4A2', other_designations='eukaryotic initiation factor 4A-II|ATP-dependent RNA helicase eIF4A-2', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186783577, end_position_on_the_genomic_accession=186789897, orientation='plus', exon_count=11, OMIM=[601102], no_hdr0=''),
    1975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1975, CurrentID=0, Status='live', Symbol='EIF4B', Aliases=['EIF-4B', 'PRO1843'], description='eukaryotic translation initiation factor 4B', other_designations='eukaryotic translation initiation factor 4B', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53006456, end_position_on_the_genomic_accession=53042215, orientation='plus', exon_count=15, OMIM=[603928], no_hdr0=''),
    1977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1977, CurrentID=0, Status='live', Symbol='EIF4E', Aliases=['AUTS19', 'CBP1', 'EIF4EL1', 'EIF4F', 'eIF-4E', 'EIF4E'], description='eukaryotic translation initiation factor 4E', other_designations='eukaryotic translation initiation factor 4E|eIF-4F 25 kDa subunit|eukaryotic translation initiation factor 4E-like 1|mRNA cap-binding protein', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=98879276, end_position_on_the_genomic_accession=98929133, orientation='minus', exon_count=9, OMIM=[133440], no_hdr0=''),
    1978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1978, CurrentID=0, Status='live', Symbol='EIF4EBP1', Aliases=['4E-BP1', '4EBP1', 'BP-1', 'PHAS-I'], description='eukaryotic translation initiation factor 4E binding protein 1', other_designations='eukaryotic translation initiation factor 4E-binding protein 1|eIF4E-binding protein 1|phosphorylated heat- and acid-stable protein regulated by insulin 1', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38030534, end_position_on_the_genomic_accession=38060365, orientation='plus', exon_count=3, OMIM=[602223], no_hdr0=''),
    1979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1979, CurrentID=0, Status='live', Symbol='EIF4EBP2', Aliases=['4EBP2', 'PHASII'], description='eukaryotic translation initiation factor 4E binding protein 2', other_designations='eukaryotic translation initiation factor 4E-binding protein 2|4E-BP2|eIF4E-binding protein 2|phosphorylated, heat and acid stable regulated by insulin protein II', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70404145, end_position_on_the_genomic_accession=70428618, orientation='plus', exon_count=3, OMIM=[602224], no_hdr0=''),
    1981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1981, CurrentID=0, Status='live', Symbol='EIF4G1', Aliases=['EIF-4G1', 'EIF4F', 'EIF4G', 'EIF4GI', 'P220', 'PARK18'], description='eukaryotic translation initiation factor 4 gamma 1', other_designations='eukaryotic translation initiation factor 4 gamma 1|EIF4-gamma|eIF-4-gamma 1|eucaryotic translation initiation factor 4G', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184314606, end_position_on_the_genomic_accession=184335358, orientation='plus', exon_count=34, OMIM=[600495], no_hdr0=''),
    1982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1982, CurrentID=0, Status='live', Symbol='EIF4G2', Aliases=['AAG1', 'DAP5', 'NAT1', 'P97'], description='eukaryotic translation initiation factor 4 gamma 2', other_designations='eukaryotic translation initiation factor 4 gamma 2|DAP-5|aging-associated protein 1|death-associated protein 5|eIF-4-gamma 2|eIF-4G 2|eIF4G 2|eukaryotic translation initiation factor 4G-like 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10797046, end_position_on_the_genomic_accession=10808926, orientation='minus', exon_count=23, OMIM=[602325], no_hdr0=''),
    1983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1983, CurrentID=0, Status='live', Symbol='EIF5', Aliases=['EIF-5', 'EIF-5A'], description='eukaryotic translation initiation factor 5', other_designations='eukaryotic translation initiation factor 5', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103334237, end_position_on_the_genomic_accession=103345025, orientation='plus', exon_count=13, OMIM=[601710], no_hdr0=''),
    1984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1984, CurrentID=0, Status='live', Symbol='EIF5A', Aliases=['EIF-5A1', 'FABAS', 'eIF-4D', 'eIF5AI', 'EIF5A'], description='eukaryotic translation initiation factor 5A', other_designations='eukaryotic translation initiation factor 5A-1|eukaryotic initiation factor 5A|rev-binding factor', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7306999, end_position_on_the_genomic_accession=7312463, orientation='plus', exon_count=10, OMIM=[600187], no_hdr0=''),
    1990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1990, CurrentID=0, Status='live', Symbol='CELA1', Aliases=['ELA1'], description='chymotrypsin like elastase 1', other_designations='chymotrypsin-like elastase family member 1|chymotrypsin like elastase family member 1|elastase 1, pancreatic|elastase-1|pancreatic elastase 1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51328442, end_position_on_the_genomic_accession=51346679, orientation='minus', exon_count=8, OMIM=[130120], no_hdr0=''),
    1991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1991, CurrentID=0, Status='live', Symbol='ELANE', Aliases=['ELA2', 'GE', 'HLE', 'HNE', 'NE', 'PMN-E', 'SCN1'], description='elastase, neutrophil expressed', other_designations='neutrophil elastase|PMN elastase|bone marrow serine protease|elastase 2, neutrophil|elastase-2|granulocyte-derived elastase|leukocyte elastase|medullasin|polymorphonuclear elastase|polymorphonuclear leukocyte elastase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=850997, end_position_on_the_genomic_accession=856250, orientation='plus', exon_count=6, OMIM=[130130], no_hdr0=''),
    1992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1992, CurrentID=0, Status='live', Symbol='SERPINB1', Aliases=['EI', 'ELANH2', 'HEL-S-27', 'HEL57', 'LEI', 'M/NEI', 'MNEI', 'PI-2', 'PI2'], description='serpin family B member 1', other_designations='leukocyte elastase inhibitor|epididymis luminal protein 57|epididymis secretory protein Li 27|peptidase inhibitor 2|protease inhibitor 2 (anti-elastase), monocyte/neutrophil derived|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 1|serpin peptidase inhibitor, clade B (ovalbumin), member 1', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2832332, end_position_on_the_genomic_accession=2842012, orientation='minus', exon_count=9, OMIM=[130135], no_hdr0=''),
    1993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1993, CurrentID=0, Status='live', Symbol='ELAVL2', Aliases=['HEL-N1', 'HELN1', 'HUB'], description='ELAV like RNA binding protein 2', other_designations='ELAV-like protein 2|ELAV (embryonic lethal, abnormal vision, Drosophila)-like 2 (Hu antigen B)|ELAV like neuron-specific RNA binding protein 2|hu-antigen B|nervous system-specific RNA-binding protein Hel-N1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=23690099, end_position_on_the_genomic_accession=23850601, orientation='minus', exon_count=20, OMIM=[601673], no_hdr0=''),
    1994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1994, CurrentID=0, Status='live', Symbol='ELAVL1', Aliases=['ELAV1', 'HUR', 'Hua', 'MelG'], description='ELAV like RNA binding protein 1', other_designations='ELAV-like protein 1|ELAV (embryonic lethal, abnormal vision, Drosophila)-like 1 (Hu antigen R)|Hu antigen R|embryonic lethal, abnormal vision, drosophila, homolog-like 1|hu-antigen R', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7958573, end_position_on_the_genomic_accession=8005641, orientation='minus', exon_count=7, OMIM=[603466], no_hdr0=''),
    1995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1995, CurrentID=0, Status='live', Symbol='ELAVL3', Aliases=['HUC', 'HUCL', 'PLE21'], description='ELAV like RNA binding protein 3', other_designations='ELAV-like protein 3|ELAV (embryonic lethal, abnormal vision, Drosophila)-like 3 (Hu antigen C)|ELAV like neuron-specific RNA binding protein 3|Hu antigen C|hu-antigen C|paraneoplastic cerebellar degeneration-associated antigen|paraneoplastic limbic encephalitis antigen 21', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11451326, end_position_on_the_genomic_accession=11481046, orientation='minus', exon_count=7, OMIM=[603458], no_hdr0=''),
    1996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1996, CurrentID=0, Status='live', Symbol='ELAVL4', Aliases=['HUD', 'PNEM'], description='ELAV like RNA binding protein 4', other_designations='ELAV-like protein 4|ELAV (embryonic lethal, abnormal vision, Drosophila)-like 4 (Hu antigen D)|ELAV like neuron-specific RNA binding protein 4|Hu antigen D|paraneoplastic encephalomyelitis antigen HuD', map_location='1p33-p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=50048055, end_position_on_the_genomic_accession=50203772, orientation='plus', exon_count=17, OMIM=[168360], no_hdr0=''),
    1997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1997, CurrentID=0, Status='live', Symbol='ELF1', Aliases=['EFTUD1', 'RIA1'], description='E74 like ETS transcription factor 1', other_designations='ETS-related transcription factor Elf-1|E74-like factor 1 (ets domain transcription factor)', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=40931919, end_position_on_the_genomic_accession=41061386, orientation='minus', exon_count=14, OMIM=[189973], no_hdr0=''),
    1998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1998, CurrentID=0, Status='live', Symbol='ELF2', Aliases=['EU32', 'NERF', 'NERF-1A', 'NERF-1B', 'NERF-1a', 'b', 'NERF-2'], description='E74 like ETS transcription factor 2', other_designations='ETS-related transcription factor Elf-2|E74-like factor 2 (ets domain transcription factor)|ets family transcription factor ELF2C|new Ets-related factor', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139057220, end_position_on_the_genomic_accession=139177218, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    1999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=1999, CurrentID=0, Status='live', Symbol='ELF3', Aliases=['EPR-1', 'ERT', 'ESE-1', 'ESX'], description='E74 like ETS transcription factor 3', other_designations='ETS-related transcription factor Elf-3|E74-like factor 3 (ETS domain transcription factor, serine box, epithelial-specific)|E74-like factor 3 (ets domain transcription factor)|E74-like factor 3 (ets domain transcription factor, epithelial-specific )|epithelial-restricted with serine box|epithelium-restricted Ets protein ESX|epithelium-specific Ets transcription factor 1|ets domain transcription factor, serine box (epithelial-specific)', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202010583, end_position_on_the_genomic_accession=202017183, orientation='plus', exon_count=9, OMIM=[602191], no_hdr0=''),
    2000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2000, CurrentID=0, Status='live', Symbol='ELF4', Aliases=['ELFR', 'MEF'], description='E74 like ETS transcription factor 4', other_designations='ETS-related transcription factor Elf-4|E74-like factor 4 (ets domain transcription factor)|myeloid Elf-1-like factor', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130063955, end_position_on_the_genomic_accession=130110891, orientation='minus', exon_count=11, OMIM=[300775], no_hdr0=''),
    2001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2001, CurrentID=0, Status='live', Symbol='ELF5', Aliases=['ESE2'], description='E74 like ETS transcription factor 5', other_designations='ETS-related transcription factor Elf-5|E74-like factor 5 (ets domain transcription factor)|epithelium-restricted ESE-1-related Ets factor|epithelium-specific Ets transcription factor 2', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34478791, end_position_on_the_genomic_accession=34513794, orientation='minus', exon_count=8, OMIM=[605169], no_hdr0=''),
    2002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2002, CurrentID=0, Status='live', Symbol='ELK1', Aliases=[], description='ETS transcription factor ELK1', other_designations='ETS domain-containing protein Elk-1|ELK1, ETS transcription factor|ELK1, member of ETS oncogene family|ETS-like gene 1|tyrosine kinase (ELK1) oncogene', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47635520, end_position_on_the_genomic_accession=47650604, orientation='minus', exon_count=7, OMIM=[311040], no_hdr0=''),
    2004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2004, CurrentID=0, Status='live', Symbol='ELK3', Aliases=['ERP', 'NET', 'SAP-2', 'SAP2'], description='ETS transcription factor ELK3', other_designations='ETS domain-containing protein Elk-3|ELK3, ETS transcription factor|ELK3, ETS-domain protein (SRF accessory protein 2)|ETS-related protein ERP|ETS-related protein NET|SRF accessory protein 2|serum response factor accessory protein 2', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=96194375, end_position_on_the_genomic_accession=96269824, orientation='plus', exon_count=7, OMIM=[600247], no_hdr0=''),
    2005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2005, CurrentID=0, Status='live', Symbol='ELK4', Aliases=['SAP1'], description='ETS transcription factor ELK4', other_designations='ETS domain-containing protein Elk-4|ELK4, ETS transcription factor|ELK4, ETS-domain protein (SRF accessory protein 1)|SAP-1|serum response factor accessory protein 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205607943, end_position_on_the_genomic_accession=205632872, orientation='minus', exon_count=5, OMIM=[600246], no_hdr0=''),
    2006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2006, CurrentID=0, Status='live', Symbol='ELN', Aliases=['ADCL1', 'SVAS', 'WBS', 'WS'], description='elastin', other_designations='elastin|tropoelastin', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74027772, end_position_on_the_genomic_accession=74069907, orientation='plus', exon_count=34, OMIM=[130160], no_hdr0=''),
    2009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2009, CurrentID=0, Status='live', Symbol='EML1', Aliases=['BH', 'ELP79', 'EMAP', 'EMAP-1', 'EMAPL'], description='EMAP like 1', other_designations='echinoderm microtubule-associated protein-like 1|echinoderm microtubule associated protein like 1', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99737722, end_position_on_the_genomic_accession=99942060, orientation='plus', exon_count=27, OMIM=[602033], no_hdr0=''),
    2010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2010, CurrentID=0, Status='live', Symbol='EMD', Aliases=['EDMD', 'LEMD5', 'STA'], description='emerin', other_designations='emerin|LEM domain containing 5', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154379236, end_position_on_the_genomic_accession=154381523, orientation='plus', exon_count=5, OMIM=[300384], no_hdr0=''),
    2011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2011, CurrentID=0, Status='live', Symbol='MARK2', Aliases=['EMK-1', 'EMK1', 'PAR-1', 'Par-1b', 'Par1b'], description='microtubule affinity regulating kinase 2', other_designations='serine/threonine-protein kinase MARK2|ELKL motif kinase 1|MAP/microtubule affinity-regulating kinase 2|PAR1 homolog b|Ser/Thr protein kinase PAR-1B|serine/threonine protein kinase EMK|testicular tissue protein Li 117', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63838955, end_position_on_the_genomic_accession=63911020, orientation='plus', exon_count=22, OMIM=[600526], no_hdr0=''),
    2012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2012, CurrentID=0, Status='live', Symbol='EMP1', Aliases=['CL-20', 'EMP-1', 'TMP'], description='epithelial membrane protein 1', other_designations='epithelial membrane protein 1|tumor-associated membrane protein', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=13196726, end_position_on_the_genomic_accession=13219941, orientation='plus', exon_count=4, OMIM=[602333], no_hdr0=''),
    2013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2013, CurrentID=0, Status='live', Symbol='EMP2', Aliases=['XMP'], description='epithelial membrane protein 2', other_designations='epithelial membrane protein 2', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10528422, end_position_on_the_genomic_accession=10580598, orientation='minus', exon_count=6, OMIM=[602334], no_hdr0=''),
    2014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2014, CurrentID=0, Status='live', Symbol='EMP3', Aliases=['YMP'], description='epithelial membrane protein 3', other_designations='epithelial membrane protein 3|EMP-3|HNMP-1|hematopoietic neural membrane protein 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48325504, end_position_on_the_genomic_accession=48330554, orientation='plus', exon_count=6, OMIM=[602335], no_hdr0=''),
    2015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2015, CurrentID=0, Status='live', Symbol='ADGRE1', Aliases=['EMR1', 'TM7LN3'], description='adhesion G protein-coupled receptor E1', other_designations='adhesion G protein-coupled receptor E1|EGF-like module receptor 1|EGF-like module-containing mucin-like hormone receptor-like 1|EMR1 hormone receptor|egf-like module containing, mucin-like, hormone receptor-like 1|egf-like module containing, mucin-like, hormone receptor-like sequence 1', map_location='19p13.3-p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6887549, end_position_on_the_genomic_accession=6940450, orientation='plus', exon_count=23, OMIM=[600493], no_hdr0=''),
    2016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2016, CurrentID=0, Status='live', Symbol='EMX1', Aliases=[], description='empty spiracles homeobox 1', other_designations='homeobox protein EMX1|empty spiracles homolog 1|empty spiracles-like protein 1', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=72910949, end_position_on_the_genomic_accession=72936691, orientation='plus', exon_count=5, OMIM=[600034], no_hdr0=''),
    2017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2017, CurrentID=0, Status='live', Symbol='CTTN', Aliases=['EMS1'], description='cortactin', other_designations='src substrate cortactin|1110020L01Rik|amplaxin|ems1 sequence (mammary tumor and squamous cell carcinoma-associated (p80/85 src substrate)|epididymis secretory sperm binding protein|oncogene EMS1', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=70398529, end_position_on_the_genomic_accession=70436579, orientation='plus', exon_count=20, OMIM=[164765], no_hdr0=''),
    2018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2018, CurrentID=0, Status='live', Symbol='EMX2', Aliases=[], description='empty spiracles homeobox 2', other_designations='homeobox protein EMX2|empty spiracles homolog 2|empty spiracles-like protein 2', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=117542746, end_position_on_the_genomic_accession=117549546, orientation='plus', exon_count=3, OMIM=[600035], no_hdr0=''),
    2019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2019, CurrentID=0, Status='live', Symbol='EN1', Aliases=['ENDOVESLB'], description='engrailed homeobox 1', other_designations='homeobox protein engrailed-1|engrailed homolog 1|homeobox protein en-1|hu-En-1', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=118842171, end_position_on_the_genomic_accession=118847648, orientation='minus', exon_count=2, OMIM=[131290], no_hdr0=''),
    2020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2020, CurrentID=0, Status='live', Symbol='EN2', Aliases=[], description='engrailed homeobox 2', other_designations='homeobox protein engrailed-2|engrailed homolog 2|engrailed-2|homeobox protein en-2|hu-En-2', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155458129, end_position_on_the_genomic_accession=155464831, orientation='plus', exon_count=2, OMIM=[131310], no_hdr0=''),
    2021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2021, CurrentID=0, Status='live', Symbol='ENDOG', Aliases=[], description='endonuclease G', other_designations='endonuclease G, mitochondrial|endo G|mitochondrial endonuclease G', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128818402, end_position_on_the_genomic_accession=128822676, orientation='plus', exon_count=4, OMIM=[600440], no_hdr0=''),
    2022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2022, CurrentID=0, Status='live', Symbol='ENG', Aliases=['END', 'HHT1', 'ORW1'], description='endoglin', other_designations='endoglin|CD105 antigen', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127815012, end_position_on_the_genomic_accession=127854773, orientation='minus', exon_count=15, OMIM=[131195], no_hdr0=''),
    2023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2023, CurrentID=0, Status='live', Symbol='ENO1', Aliases=['ENO1L1', 'HEL-S-17', 'MPB1', 'NNE', 'PPH'], description='enolase 1', other_designations='alpha-enolase|c-myc promoter-binding protein-1|2-phospho-D-glycerate hydro-lyase|MYC promoter-binding protein 1|alpha enolase like 1|enolase 1, (alpha)|enolase-alpha|epididymis secretory protein Li 17|non-neural enolase|phosphopyruvate hydratase|plasminogen-binding protein|tau-crystallin', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8861000, end_position_on_the_genomic_accession=8878686, orientation='minus', exon_count=13, OMIM=[172430], no_hdr0=''),
    2026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2026, CurrentID=0, Status='live', Symbol='ENO2', Aliases=['HEL-S-279', 'NSE'], description='enolase 2', other_designations='gamma-enolase|2-phospho-D-glycerate hydro-lyase|2-phospho-D-glycerate hydrolyase|enolase 2 (gamma, neuronal)|epididymis secretory protein Li 279|neural enolase|neuron specific gamma enolase|neuron-specific enolase|neuronal enriched enolase|neurone-specific enolase', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6914580, end_position_on_the_genomic_accession=6923697, orientation='plus', exon_count=12, OMIM=[131360], no_hdr0=''),
    2027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2027, CurrentID=0, Status='live', Symbol='ENO3', Aliases=['GSD13', 'MSE'], description='enolase 3', other_designations='beta-enolase|2-phospho-D-glycerate hydrolyase|enolase 3 (beta, muscle)|muscle enriched enolase|muscle-specific enolase|skeletal muscle enolase', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4949182, end_position_on_the_genomic_accession=4957131, orientation='plus', exon_count=14, OMIM=[131370], no_hdr0=''),
    2028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2028, CurrentID=0, Status='live', Symbol='ENPEP', Aliases=['APA', 'CD249', 'gp160'], description='glutamyl aminopeptidase', other_designations='glutamyl aminopeptidase|AP-A|EAP|aminopeptidase A|differentiation antigen gp160', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=110476155, end_position_on_the_genomic_accession=110565285, orientation='plus', exon_count=24, OMIM=[138297], no_hdr0=''),
    2029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2029, CurrentID=0, Status='live', Symbol='ENSA', Aliases=['ARPP-19e'], description='endosulfine alpha', other_designations='alpha-endosulfine', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150621246, end_position_on_the_genomic_accession=150629612, orientation='minus', exon_count=6, OMIM=[603061], no_hdr0=''),
    2030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2030, CurrentID=0, Status='live', Symbol='SLC29A1', Aliases=['ENT1'], description='solute carrier family 29 member 1 (Augustine blood group)', other_designations='equilibrative nucleoside transporter 1|equilibrative nitrobenzylmercaptopurine riboside (NBMPR)-sensitive nucleoside transporter|nucleoside transporter, es-type|solute carrier family 29 (equilibrative nucleoside transporter), member 1|solute carrier family 29 (nucleoside transporters), member 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44219587, end_position_on_the_genomic_accession=44234144, orientation='plus', exon_count=17, OMIM=[602193], no_hdr0=''),
    2033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2033, CurrentID=0, Status='live', Symbol='EP300', Aliases=['KAT3B', 'MKHK2', 'RSTS2', 'p300'], description='E1A binding protein p300', other_designations='histone acetyltransferase p300|E1A-associated protein p300|E1A-binding protein, 300kD|histone butyryltransferase p300|histone crotonyltransferase p300|p300 HAT|protein 2-hydroxyisobutyryltransferase p300|protein lactyltransferas p300|protein propionyltransferase p300', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41092592, end_position_on_the_genomic_accession=41180077, orientation='plus', exon_count=31, OMIM=[602700], no_hdr0=''),
    2034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2034, CurrentID=0, Status='live', Symbol='EPAS1', Aliases=['ECYT4', 'HIF2A', 'HLF', 'MOP2', 'PASD2', 'bHLHe73'], description='endothelial PAS domain protein 1', other_designations='endothelial PAS domain-containing protein 1|EPAS-1|HIF-1-alpha-like factor|HIF-1alpha-like factor|HIF-2-alpha|HIF2-alpha|PAS domain-containing protein 2|basic-helix-loop-helix-PAS protein MOP2|class E basic helix-loop-helix protein 73|hypoxia-inducible factor 2 alpha|member of PAS protein 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46297407, end_position_on_the_genomic_accession=46386697, orientation='plus', exon_count=17, OMIM=[603349], no_hdr0=''),
    2035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2035, CurrentID=0, Status='live', Symbol='EPB41', Aliases=['4.1R', 'EL1', 'HE'], description='erythrocyte membrane protein band 4.1', other_designations='protein 4.1|EPB4.1|P4.1|band 4.1|elliptocytosis 1, RH-linked|erythrocyte surface protein band 4.1', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28887100, end_position_on_the_genomic_accession=29120041, orientation='plus', exon_count=28, OMIM=[130500], no_hdr0=''),
    2036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2036, CurrentID=0, Status='live', Symbol='EPB41L1', Aliases=['4.1N', 'MRD11'], description='erythrocyte membrane protein band 4.1 like 1', other_designations='band 4.1-like protein 1|neuron-type nonerythroid protein 4.1|neuronal protein 4.1', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36064891, end_position_on_the_genomic_accession=36232799, orientation='plus', exon_count=36, OMIM=[602879], no_hdr0=''),
    2037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2037, CurrentID=0, Status='live', Symbol='EPB41L2', Aliases=['4.1-G', '4.1G'], description='erythrocyte membrane protein band 4.1 like 2', other_designations='band 4.1-like protein 2|erythrocyte membrane protein band 4.1 like-protein 2|generally expressed protein 4.1', map_location='6q23.1-q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=130827955, end_position_on_the_genomic_accession=131063251, orientation='minus', exon_count=31, OMIM=[603237], no_hdr0=''),
    2038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2038, CurrentID=0, Status='live', Symbol='EPB42', Aliases=['PA', 'SPH5'], description='erythrocyte membrane protein band 4.2', other_designations='protein 4.2|P4.2|erythrocyte protein 4.2|erythrocyte surface protein band 4.2', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43197227, end_position_on_the_genomic_accession=43225856, orientation='minus', exon_count=16, OMIM=[177070], no_hdr0=''),
    2039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2039, CurrentID=0, Status='live', Symbol='DMTN', Aliases=['DMT', 'EPB49'], description='dematin actin binding protein', other_designations='dematin|erythrocyte membrane protein band 4.9 (dematin)', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22048931, end_position_on_the_genomic_accession=22082525, orientation='plus', exon_count=21, OMIM=[125305], no_hdr0=''),
    2040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2040, CurrentID=0, Status='live', Symbol='STOM', Aliases=['BND7', 'EPB7', 'EPB72'], description='stomatin', other_designations='stomatin|erythrocyte band 7 integral membrane protein|erythrocyte membrane protein band 7.2 (stomatin)|erythrocyte surface protein band 7.2|protein 7.2b', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121338987, end_position_on_the_genomic_accession=121370250, orientation='minus', exon_count=8, OMIM=[133090], no_hdr0=''),
    2041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2041, CurrentID=0, Status='live', Symbol='EPHA1', Aliases=['EPH', 'EPHT', 'EPHT1'], description='EPH receptor A1', other_designations='ephrin type-A receptor 1|eph tyrosine kinase 1|erythropoietin-producing hepatoma amplified sequence|erythropoietin-producing hepatoma receptor|hEpha1|oncogene EPH|soluble EPHA1 variant 1|soluble EPHA1 variant 2|tyrosine-protein kinase receptor EPH', map_location='7q34-q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143391129, end_position_on_the_genomic_accession=143408856, orientation='minus', exon_count=18, OMIM=[179610], no_hdr0=''),
    2042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2042, CurrentID=0, Status='live', Symbol='EPHA3', Aliases=['EK4', 'ETK', 'ETK1', 'HEK', 'HEK4', 'TYRO4'], description='EPH receptor A3', other_designations='ephrin type-A receptor 3|EPH-like kinase 4|TYRO4 protein tyrosine kinase|eph-like tyrosine kinase 1|human embryo kinase 1|testicular tissue protein Li 64|tyrosine-protein kinase receptor ETK1', map_location='3p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=89107621, end_position_on_the_genomic_accession=89482134, orientation='plus', exon_count=17, OMIM=[179611], no_hdr0=''),
    2043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2043, CurrentID=0, Status='live', Symbol='EPHA4', Aliases=['EK8', 'HEK8', 'SEK', 'TYRO1'], description='EPH receptor A4', other_designations='ephrin type-A receptor 4|EPH-like kinase 8|TYRO1 protein tyrosine kinase|receptor protein-tyrosine kinase HEK8|tyrosine-protein kinase TYRO1|tyrosine-protein kinase receptor SEK', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=221418027, end_position_on_the_genomic_accession=221574202, orientation='minus', exon_count=19, OMIM=[602188], no_hdr0=''),
    2044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2044, CurrentID=0, Status='live', Symbol='EPHA5', Aliases=['CEK7', 'EHK-1', 'EHK1', 'EK7', 'HEK7', 'TYRO4'], description='EPH receptor A5', other_designations='ephrin type-A receptor 5|EPH homology kinase 1|EPH-like kinase 7|brain-specific kinase|epididymis secretory sperm binding protein|receptor protein-tyrosine kinase HEK7|tyrosine-protein kinase receptor EHK-1', map_location='4q13.1-q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=65319567, end_position_on_the_genomic_accession=65670489, orientation='minus', exon_count=19, OMIM=[600004], no_hdr0=''),
    2045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2045, CurrentID=0, Status='live', Symbol='EPHA7', Aliases=['EHK-3', 'EHK3', 'EK11', 'HEK11'], description='EPH receptor A7', other_designations='ephrin type-A receptor 7|EPH homology kinase 3|EPH-like kinase 11|Eph homology kinase-3|receptor protein-tyrosine kinase HEK11|tyrosine-protein kinase receptor EHK-3', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=93240020, end_position_on_the_genomic_accession=93419584, orientation='minus', exon_count=21, OMIM=[602190], no_hdr0=''),
    2046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2046, CurrentID=0, Status='live', Symbol='EPHA8', Aliases=['EEK', 'EK3', 'HEK3'], description='EPH receptor A8', other_designations='ephrin type-A receptor 8|EPH- and ELK-related kinase|EPH- and ELK-related tyrosine kinase|EPH-like kinase 3|hydroxyaryl-protein kinase|protein-tyrosine kinase|tyrosine-protein kinase receptor EEK|tyrosylprotein kinase', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22563489, end_position_on_the_genomic_accession=22603595, orientation='plus', exon_count=24, OMIM=[176945], no_hdr0=''),
    2047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2047, CurrentID=0, Status='live', Symbol='EPHB1', Aliases=['ELK', 'EPHT2', 'Hek6', 'NET'], description='EPH receptor B1', other_designations='ephrin type-B receptor 1|EK6|EPH-like kinase 6|eph tyrosine kinase 2|neuronally-expressed EPH-related tyrosine kinase|soluble EPHB1 variant 1|tyrosine-protein kinase receptor EPH-2', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134795260, end_position_on_the_genomic_accession=135260467, orientation='plus', exon_count=16, OMIM=[600600], no_hdr0=''),
    2048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2048, CurrentID=0, Status='live', Symbol='EPHB2', Aliases=['BDPLT22', 'CAPB', 'DRT', 'EK5', 'EPHT3', 'ERK', 'Hek5', 'PCBC', 'Tyro5'], description='EPH receptor B2', other_designations='ephrin type-B receptor 2|EPH-like kinase 5|developmentally-regulated Eph-related tyrosine kinase|elk-related tyrosine kinase|eph tyrosine kinase 3|protein-tyrosine kinase HEK5|renal carcinoma antigen NY-REN-47|tyrosine-protein kinase TYRO5|tyrosine-protein kinase receptor EPH-3', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22710770, end_position_on_the_genomic_accession=22921500, orientation='plus', exon_count=17, OMIM=[600997], no_hdr0=''),
    2049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2049, CurrentID=0, Status='live', Symbol='EPHB3', Aliases=['EK2', 'ETK2', 'HEK2', 'TYRO6'], description='EPH receptor B3', other_designations='ephrin type-B receptor 3|EPH-like tyrosine kinase 2|embryonic kinase 2|human embryo kinase 2|tyrosine-protein kinase TYRO6', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184561785, end_position_on_the_genomic_accession=184582408, orientation='plus', exon_count=16, OMIM=[601839], no_hdr0=''),
    2050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2050, CurrentID=0, Status='live', Symbol='EPHB4', Aliases=['CMAVM2', 'HFASD', 'HTK', 'LMPHM7', 'MYK1', 'TYRO11'], description='EPH receptor B4', other_designations='ephrin type-B receptor 4|ephrin receptor EphB4|hepatoma transmembrane kinase|soluble EPHB4 variant 1|soluble EPHB4 variant 2|soluble EPHB4 variant 3|tyrosine-protein kinase TYRO11|tyrosine-protein kinase receptor HTK', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100802565, end_position_on_the_genomic_accession=100827523, orientation='minus', exon_count=17, OMIM=[600011], no_hdr0=''),
    2051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2051, CurrentID=0, Status='live', Symbol='EPHB6', Aliases=['HEP'], description='EPH receptor B6', other_designations='ephrin type-B receptor 6|human kinase-defective Eph-family receptor protein|tyrosine-protein kinase-defective receptor EPH-6', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142854639, end_position_on_the_genomic_accession=142871093, orientation='plus', exon_count=21, OMIM=[602757], no_hdr0=''),
    2052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2052, CurrentID=0, Status='live', Symbol='EPHX1', Aliases=['EPHX', 'EPOX', 'HYL1', 'MEH'], description='epoxide hydrolase 1', other_designations='epoxide hydrolase 1|epoxide hydratase|epoxide hydrolase 1 microsomal|epoxide hydrolase 1, microsomal (xenobiotic)', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225810124, end_position_on_the_genomic_accession=225845563, orientation='plus', exon_count=11, OMIM=[132810], no_hdr0=''),
    2053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2053, CurrentID=0, Status='live', Symbol='EPHX2', Aliases=['ABHD20', 'CEH', 'SEH'], description='epoxide hydrolase 2', other_designations='bifunctional epoxide hydrolase 2|epoxide hydratase|epoxide hydrolase 2, cytoplasmic|epoxide hydrolase 2, cytosolic|epoxide hydrolase, soluble', map_location='8p21.2-p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27491143, end_position_on_the_genomic_accession=27597559, orientation='plus', exon_count=22, OMIM=[132811], no_hdr0=''),
    2054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2054, CurrentID=0, Status='live', Symbol='STX2', Aliases=['EPIM', 'EPMA', 'STX2B', 'STX2C', 'STX2'], description='syntaxin 2', other_designations='syntaxin-2|epimorphin', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130789600, end_position_on_the_genomic_accession=130839274, orientation='minus', exon_count=17, OMIM=[132350], no_hdr0=''),
    2055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2055, CurrentID=0, Status='live', Symbol='CLN8', Aliases=['C8orf61', 'EPMR', 'TLCD6'], description='CLN8 transmembrane ER and ERGIC protein', other_designations='protein CLN8|ceroid-lipofuscinosis, neuronal 8', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=1755778, end_position_on_the_genomic_accession=1786570, orientation='plus', exon_count=7, OMIM=[607837], no_hdr0=''),
    2056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2056, CurrentID=0, Status='live', Symbol='EPO', Aliases=['DBAL', 'ECYT5', 'EP', 'MVCD2'], description='erythropoietin', other_designations='erythropoietin|epoetin', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100720468, end_position_on_the_genomic_accession=100723700, orientation='plus', exon_count=5, OMIM=[133170], no_hdr0=''),
    2057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2057, CurrentID=0, Status='live', Symbol='EPOR', Aliases=['EPO-R'], description='erythropoietin receptor', other_designations='erythropoietin receptor|truncated erythropoietin receptor', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11377207, end_position_on_the_genomic_accession=11384314, orientation='minus', exon_count=8, OMIM=[133171], no_hdr0=''),
    2058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2058, CurrentID=0, Status='live', Symbol='EPRS1', Aliases=['EARS', 'EPRS', 'GLUPRORS', 'HLD15', 'PARS', 'PIG32', 'QARS', 'QPRS'], description='glutamyl-prolyl-tRNA synthetase 1', other_designations='bifunctional glutamate/proline--tRNA ligase|bifunctional aminoacyl-tRNA synthetase|cell proliferation-inducing gene 32 protein|glutamate tRNA ligase|glutamatyl-prolyl-tRNA synthetase|glutaminyl-tRNA synthetase|proliferation-inducing gene 32 protein|proliferation-inducing protein 32|proline-tRNA ligase|prolyl-tRNA synthetase', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=219968600, end_position_on_the_genomic_accession=220046505, orientation='minus', exon_count=33, OMIM=[138295], no_hdr0=''),
    2059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2059, CurrentID=0, Status='live', Symbol='EPS8', Aliases=['DFNB102'], description='epidermal growth factor receptor pathway substrate 8', other_designations='epidermal growth factor receptor kinase substrate 8', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=15620134, end_position_on_the_genomic_accession=15789388, orientation='minus', exon_count=26, OMIM=[600206], no_hdr0=''),
    2060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2060, CurrentID=0, Status='live', Symbol='EPS15', Aliases=['AF-1P', 'AF1P', 'MLLT5'], description='epidermal growth factor receptor pathway substrate 15', other_designations='epidermal growth factor receptor substrate 15|ALL1 fused gene from chromosome 1|protein AF-1p', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51354263, end_position_on_the_genomic_accession=51519275, orientation='minus', exon_count=26, OMIM=[600051], no_hdr0=''),
    2063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2063, CurrentID=0, Status='live', Symbol='NR2F6', Aliases=['EAR-2', 'EAR2', 'ERBAL2'], description='nuclear receptor subfamily 2 group F member 6', other_designations='nuclear receptor subfamily 2 group F member 6|ERBA-related gene-2|V-erbA-related protein 2|nuclear receptor V-erbA-related|v-erb-a avian erythroblastic leukemia viral oncogene homolog-like 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17231883, end_position_on_the_genomic_accession=17245919, orientation='minus', exon_count=4, OMIM=[132880], no_hdr0=''),
    2064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2064, CurrentID=0, Status='live', Symbol='ERBB2', Aliases=['CD340', 'HER-2', 'HER-2/neu', 'HER2', 'MLN 19', 'NEU', 'NGL', 'TKR1'], description='erb-b2 receptor tyrosine kinase 2', other_designations='receptor tyrosine-protein kinase erbB-2|c-erb B2/neu protein|herstatin|human epidermal growth factor receptor 2|metastatic lymph node gene 19 protein|neuro/glioblastoma derived oncogene homolog|neuroblastoma/glioblastoma derived oncogene homolog|proto-oncogene Neu|proto-oncogene c-ErbB-2|tyrosine kinase-type cell surface receptor HER2|v-erb-b2 avian erythroblastic leukemia viral oncogene homolog 2|v-erb-b2 avian erythroblastic leukemia viral oncoprotein 2|v-erb-b2 erythroblastic leukemia viral oncogene homolog 2, neuro/glioblastoma derived oncogene homolog', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39688094, end_position_on_the_genomic_accession=39728660, orientation='plus', exon_count=35, OMIM=[164870], no_hdr0=''),
    2065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2065, CurrentID=0, Status='live', Symbol='ERBB3', Aliases=['ErbB-3', 'FERLK', 'HER3', 'LCCS2', 'MDA-BF-1', 'c-erbB-3', 'c-erbB3', 'erbB3-S', 'p180-ErbB3', 'p45-sErbB3', 'p85-sErbB3'], description='erb-b2 receptor tyrosine kinase 3', other_designations='receptor tyrosine-protein kinase erbB-3|human epidermal growth factor receptor 3|proto-oncogene-like protein c-ErbB-3|tyrosine kinase-type cell surface receptor HER3|v-erb-b2 avian erythroblastic leukemia viral oncogene homolog 3', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56080108, end_position_on_the_genomic_accession=56103505, orientation='plus', exon_count=28, OMIM=[190151], no_hdr0=''),
    2066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2066, CurrentID=0, Status='live', Symbol='ERBB4', Aliases=['ALS19', 'HER4', 'p180erbB4'], description='erb-b2 receptor tyrosine kinase 4', other_designations='receptor tyrosine-protein kinase erbB-4|avian erythroblastic leukemia viral (v-erb-b2) oncogene homolog 4|human epidermal growth factor receptor 4|proto-oncogene-like protein c-ErbB-4|tyrosine kinase-type cell surface receptor HER4|v-erb-a erythroblastic leukemia viral oncogene homolog 4|v-erb-b2 avian erythroblastic leukemia viral oncogene homolog 4', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=211375717, end_position_on_the_genomic_accession=212538802, orientation='minus', exon_count=31, OMIM=[600543], no_hdr0=''),
    2067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2067, CurrentID=0, Status='live', Symbol='ERCC1', Aliases=['COFS4', 'RAD10', 'UV20'], description='ERCC excision repair 1, endonuclease non-catalytic subunit', other_designations='DNA excision repair protein ERCC-1|excision repair cross-complementation group 1|excision repair cross-complementing rodent repair deficiency, complementation group 1 (includes overlapping antisense sequence)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45407334, end_position_on_the_genomic_accession=45451547, orientation='minus', exon_count=13, OMIM=[126380], no_hdr0=''),
    2068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2068, CurrentID=0, Status='live', Symbol='ERCC2', Aliases=['COFS2', 'EM9', 'TFIIH', 'TTD', 'TTD1', 'XPD'], description='ERCC excision repair 2, TFIIH core complex helicase subunit', other_designations='general transcription and DNA repair factor IIH helicase subunit XPD|BTF2 p80|CXPD|DNA excision repair protein ERCC-2|DNA repair protein complementing XP-D cells|TFIIH 80 kDa subunit|TFIIH basal transcription factor complex 80 kDa subunit|TFIIH basal transcription factor complex helicase XPB subunit|TFIIH basal transcription factor complex helicase XPD subunit|TFIIH basal transcription factor complex helicase subunit|TFIIH p80|TFIIH subunit XPD|basic transcription factor 2 80 kDa subunit|excision repair cross-complementation group 2|excision repair cross-complementing rodent repair deficiency, complementation group 2|xeroderma pigmentosum complementary group D|xeroderma pigmentosum group D-complementing protein', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45349837, end_position_on_the_genomic_accession=45370647, orientation='minus', exon_count=25, OMIM=[126340], no_hdr0=''),
    2069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2069, CurrentID=0, Status='live', Symbol='EREG', Aliases=['EPR', 'ER', 'Ep'], description='epiregulin', other_designations='proepiregulin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74365145, end_position_on_the_genomic_accession=74388749, orientation='plus', exon_count=5, OMIM=[602061], no_hdr0=''),
    2070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2070, CurrentID=0, Status='live', Symbol='EYA4', Aliases=['CMD1J', 'DFNA10'], description='EYA transcriptional coactivator and phosphatase 4', other_designations='eyes absent homolog 4|dJ78N10.1 (eyes absent)|eyes absent-like protein 4', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=133240340, end_position_on_the_genomic_accession=133532128, orientation='plus', exon_count=22, OMIM=[603550], no_hdr0=''),
    2071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2071, CurrentID=0, Status='live', Symbol='ERCC3', Aliases=['BTF2', 'GTF2H', 'RAD25', 'Ssl2', 'TFIIH', 'TTD2', 'XPB'], description='ERCC excision repair 3, TFIIH core complex helicase subunit', other_designations='general transcription and DNA repair factor IIH helicase subunit XPB|BTF2 p89|DNA excision repair protein ERCC-3|DNA repair helicase|DNA repair protein complementing XP-B cells|TFIIH 89 kDa subunit|TFIIH basal transcription factor complex 89 kDa subunit|TFIIH basal transcription factor complex helicase XPB subunit|TFIIH p89|TFIIH subunit XPB|basic transcription factor 2 89 kDa subunit|excision repair cross-complementation group 3|excision repair cross-complementing rodent repair deficiency, complementation group 3|xeroderma pigmentosum group B-complementing protein|xeroderma pigmentosum, complementation group B', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127257290, end_position_on_the_genomic_accession=127294166, orientation='minus', exon_count=15, OMIM=[133510], no_hdr0=''),
    2072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2072, CurrentID=0, Status='live', Symbol='ERCC4', Aliases=['ERCC11', 'FANCQ', 'RAD1', 'XFEPS', 'XPF'], description='ERCC excision repair 4, endonuclease catalytic subunit', other_designations='DNA repair endonuclease XPF|DNA excision repair protein ERCC-4|DNA repair protein complementing XP-F cells|excision repair cross-complementation group 4|excision repair cross-complementing rodent repair deficiency, complementation group 4|excision-repair, complementing defective, in Chinese hamster|xeroderma pigmentosum group F-complementing protein|xeroderma pigmentosum, complementation group F', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=13920137, end_position_on_the_genomic_accession=13952348, orientation='plus', exon_count=13, OMIM=[133520], no_hdr0=''),
    2073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2073, CurrentID=0, Status='live', Symbol='ERCC5', Aliases=['COFS3-201', 'ERCM2', 'UVDR', 'XPG', 'XPGC', 'ERCC5'], description='ERCC excision repair 5, endonuclease', other_designations='DNA excision repair protein ERCC-5|DNA repair protein complementing XP-G cells|XPG-complementing protein|excision repair cross-complementation group 5|excision repair cross-complementing rodent repair deficiency, complementation group 5|xeroderma pigmentosum, complementation group G', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102846032, end_position_on_the_genomic_accession=102875995, orientation='plus', exon_count=15, OMIM=[133530], no_hdr0=''),
    2074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2074, CurrentID=0, Status='live', Symbol='ERCC6', Aliases=['ARMD5', 'CKN2', 'COFS', 'COFS1', 'CSB', 'CSB-PGBD3', 'POF11', 'RAD26', 'UVSS1'], description='ERCC excision repair 6, chromatin remodeling factor', other_designations='DNA excision repair protein ERCC-6|ERCC6-PGBD3 fusion protein|ATP-dependent helicase ERCC6|Chimeric CSB-PGBD3 protein|Chimeric ERCC6-PGBD3 protein|Cockayne syndrome group B protein|cockayne syndrome protein CSB|excision repair cross-complementation group 6|excision repair cross-complementing rodent repair deficiency, complementation group 6', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49434881, end_position_on_the_genomic_accession=49539538, orientation='minus', exon_count=23, OMIM=[609413], no_hdr0=''),
    2077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2077, CurrentID=0, Status='live', Symbol='ERF', Aliases=['CHYTS', 'CRS4', 'PE-2', 'PE2'], description='ETS2 repressor factor', other_designations='ETS domain-containing transcription factor ERF', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42247569, end_position_on_the_genomic_accession=42255128, orientation='minus', exon_count=8, OMIM=[611888], no_hdr0=''),
    2078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2078, CurrentID=0, Status='live', Symbol='ERG', Aliases=['erg-3', 'p55'], description='ETS transcription factor ERG', other_designations='transcriptional regulator ERG|ERG, ETS transcription factor|FUS/ERG fusion protein|TMPRSS2/ERG fusion|erythroblast transformation-specific transcription factor ERG variant 10|ets-related|transcriptional regulator ERG (transforming protein ERG)|v-ets avian erythroblastosis virus E26 oncogene homolog|v-ets avian erythroblastosis virus E26 oncogene related|v-ets erythroblastosis virus E26 oncogene homolog|v-ets erythroblastosis virus E26 oncogene like', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=38367261, end_position_on_the_genomic_accession=38661783, orientation='minus', exon_count=17, OMIM=[165080], no_hdr0=''),
    2079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2079, CurrentID=0, Status='live', Symbol='ERH', Aliases=['DROER'], description='ERH mRNA splicing and mitosis factor', other_designations='enhancer of rudimentary homolog', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69380128, end_position_on_the_genomic_accession=69398299, orientation='minus', exon_count=4, OMIM=[601191], no_hdr0=''),
    2081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2081, CurrentID=0, Status='live', Symbol='ERN1', Aliases=['IRE1', 'IRE1P', 'IRE1a', 'hIRE1p'], description='endoplasmic reticulum to nucleus signaling 1', other_designations='serine/threonine-protein kinase/endoribonuclease IRE1|ER to nucleus signalling 1|inositol-requiring 1|inositol-requiring enzyme 1|inositol-requiring protein 1|ire1-alpha|protein kinase/endoribonuclease', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64039142, end_position_on_the_genomic_accession=64132469, orientation='minus', exon_count=22, OMIM=[604033], no_hdr0=''),
    2086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2086, CurrentID=0, Status='live', Symbol='ERV3-1', Aliases=['ERV-R', 'ERV3', 'ERVR', 'HERV-R', 'HERVR', 'envR'], description='endogenous retrovirus group 3 member 1, envelope', other_designations='endogenous retrovirus group 3 member 1 Env polyprotein|ERV-R envelope protein|ERV3-1 envelope protein|HERV-R envelope protein|HERV-R_7q21.2 provirus ancestral Env polyprotein|endogenous retroviral sequence 3|endogenous retrovirus group 3, member 1', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64990356, end_position_on_the_genomic_accession=65006687, orientation='minus', exon_count=4, OMIM=[131170], no_hdr0=''),
    2090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2090, CurrentID=0, Status='live', Symbol='ESA4', Aliases=[], description='esterase A4', other_designations='esterase A4', map_location='11q13-q22', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[133220], no_hdr0=''),
    2091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2091, CurrentID=0, Status='live', Symbol='FBL', Aliases=['FIB', 'FLRN', 'Nop1', 'RNU3IP1'], description='fibrillarin', other_designations="rRNA 2'-O-methyltransferase fibrillarin|34 kDa nucleolar scleroderma antigen|34-kD nucleolar scleroderma antigen|RNA, U3 small nucleolar interacting protein 1|U6 snRNA 2'-O-methyltransferase fibrillarin|histone-glutamine methyltransferase", map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39834458, end_position_on_the_genomic_accession=39846395, orientation='minus', exon_count=9, OMIM=[134795], no_hdr0=''),
    2097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2097, CurrentID=0, Status='live', Symbol='ESB3', Aliases=[], description='esterase B3', other_designations='esterase B3', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[133290], no_hdr0=''),
    2098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2098, CurrentID=0, Status='live', Symbol='ESD', Aliases=['FGH'], description='esterase D', other_designations='S-formylglutathione hydrolase|esterase 10|esterase D/formylglutathione hydrolase|methylumbelliferyl-acetate deacetylase|testicular tissue protein Li 66', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46771256, end_position_on_the_genomic_accession=46797700, orientation='minus', exon_count=11, OMIM=[133280], no_hdr0=''),
    2099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2099, CurrentID=0, Status='live', Symbol='ESR1', Aliases=['ER', 'ESR', 'ESRA', 'ESTRR', 'Era', 'NR3A1'], description='estrogen receptor 1', other_designations='estrogen receptor|E2 receptor alpha|ER-alpha|estradiol receptor|estrogen nuclear receptor alpha|estrogen receptor alpha E1-E2-1-2|estrogen receptor alpha E1-N2-E2-1-2|nuclear receptor subfamily 3 group A member 1|oestrogen receptor alpha', map_location='6q25.1-q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151654148, end_position_on_the_genomic_accession=152129619, orientation='plus', exon_count=23, OMIM=[133430], no_hdr0=''),
    2100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2100, CurrentID=0, Status='live', Symbol='ESR2', Aliases=['ER-BETA', 'ESR-BETA', 'ESRB', 'ESTRB', 'Erb', 'NR3A2', 'ODG8'], description='estrogen receptor 2', other_designations='estrogen receptor beta|estrogen receptor beta 4|estrogen receptor beta splice variant, ERbeta2delta7|estrogen receptor beta splice variant, ERbeta4delta7|estrogen receptor beta splice variant, ERbeta6|estrogen receptor beta splice variant, ERbeta6delta7|estrogen receptor beta splice variant, ERbeta7|estrogen receptor beta splice variant, ERbeta7delta7|estrogen receptor beta splice variant, ERbetaEx. 4L|estrogen receptor beta splice variant, ERbetaEx. 6L|nuclear receptor subfamily 3 group A member 2|oestrogen receptor beta', map_location='14q23.2-q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64226707, end_position_on_the_genomic_accession=64338631, orientation='minus', exon_count=17, OMIM=[601663], no_hdr0=''),
    2101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2101, CurrentID=0, Status='live', Symbol='ESRRA', Aliases=['ERR1', 'ERRa', 'ERRalpha', 'ESRL1', 'NR3B1'], description='estrogen related receptor alpha', other_designations='steroid hormone receptor ERR1|ERR-alpha|estrogen receptor-like 1|estrogen-related nuclear receptor alpha|nuclear receptor subfamily 3 group B member 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64305524, end_position_on_the_genomic_accession=64316743, orientation='plus', exon_count=8, OMIM=[601998], no_hdr0=''),
    2103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2103, CurrentID=0, Status='live', Symbol='ESRRB', Aliases=['DFNB35', 'ERR beta-2', 'ERR2', 'ERRb', 'ERRbeta2', 'ESRL2', 'NR3B2'], description='estrogen related receptor beta', other_designations='steroid hormone receptor ERR2|estrogen receptor-like 2|estrogen-related nuclear receptor beta|nuclear receptor ERRB2|nuclear receptor subfamily 3 group B member 2|orphan nuclear receptor', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=76371271, end_position_on_the_genomic_accession=76501839, orientation='plus', exon_count=14, OMIM=[602167], no_hdr0=''),
    2104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2104, CurrentID=0, Status='live', Symbol='ESRRG', Aliases=['ERR-gamma', 'ERR3', 'ERRg', 'ERRgamma', 'NR3B3'], description='estrogen related receptor gamma', other_designations='estrogen-related receptor gamma|ERR gamma-2|estrogen receptor-related protein 3|nuclear receptor subfamily 3 group B member 3', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=216503246, end_position_on_the_genomic_accession=217137702, orientation='minus', exon_count=28, OMIM=[602969], no_hdr0=''),
    2107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2107, CurrentID=0, Status='live', Symbol='ETF1', Aliases=['D5S1995', 'ERF', 'ERF1', 'RF1', 'SUP45L1', 'TB3-1'], description='eukaryotic translation termination factor 1', other_designations='eukaryotic peptide chain release factor subunit 1|polypeptide chain release factor 1|protein Cl1|sup45 (yeast omnipotent suppressor 45) homolog-like 1', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138506095, end_position_on_the_genomic_accession=138543236, orientation='minus', exon_count=13, OMIM=[600285], no_hdr0=''),
    2108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2108, CurrentID=0, Status='live', Symbol='ETFA', Aliases=['EMA', 'GA2', 'MADD'], description='electron transfer flavoprotein subunit alpha', other_designations='electron transfer flavoprotein subunit alpha, mitochondrial|alpha-ETF|electron transfer flavoprotein alpha subunit|electron transfer flavoprotein, alpha polypeptide|epididymis secretory sperm binding protein|glutaric aciduria II', map_location='15q24.2-q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76215353, end_position_on_the_genomic_accession=76311469, orientation='minus', exon_count=13, OMIM=[608053], no_hdr0=''),
    2109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2109, CurrentID=0, Status='live', Symbol='ETFB', Aliases=['FP585', 'MADD'], description='electron transfer flavoprotein subunit beta', other_designations='electron transfer flavoprotein subunit beta|beta-ETF|electron transfer flavoprotein beta subunit|electron transfer flavoprotein, beta polypeptide|electron-transferring-flavoprotein, beta polypeptide', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51345155, end_position_on_the_genomic_accession=51366388, orientation='minus', exon_count=7, OMIM=[130410], no_hdr0=''),
    2110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2110, CurrentID=0, Status='live', Symbol='ETFDH', Aliases=['ETFQO', 'MADD'], description='electron transfer flavoprotein dehydrogenase', other_designations='electron transfer flavoprotein-ubiquinone oxidoreductase, mitochondrial|ETF dehydrogenase|ETF-QO|ETF-ubiquinone oxidoreductase|electron-transferring-flavoprotein dehydrogenase|mutant electron transfer flavoprotein dehydrogenase', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158672296, end_position_on_the_genomic_accession=158709623, orientation='plus', exon_count=14, OMIM=[231675], no_hdr0=''),
    2113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2113, CurrentID=0, Status='live', Symbol='ETS1', Aliases=['ETS-1', 'EWSR2', 'c-ets-1', 'p54'], description='ETS proto-oncogene 1, transcription factor', other_designations='protein C-ets-1|Avian erythroblastosis virus E26 (v-ets) oncogene homolog-1|v-ets avian erythroblastosis virus E2 oncogene homolog 1|v-ets avian erythroblastosis virus E26 oncogene homolog 1', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128458765, end_position_on_the_genomic_accession=128587593, orientation='minus', exon_count=12, OMIM=[164720], no_hdr0=''),
    2114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2114, CurrentID=0, Status='live', Symbol='ETS2', Aliases=['ETS2IT1'], description='ETS proto-oncogene 2, transcription factor', other_designations='protein C-ets-2|oncogene ETS-2|v-ets avian erythroblastosis virus E2 oncogene homolog 2|v-ets avian erythroblastosis virus E26 oncogene homolog 2|v-ets erythroblastosis virus E26 oncogene homolog 2', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=38805183, end_position_on_the_genomic_accession=38824955, orientation='plus', exon_count=13, OMIM=[164740], no_hdr0=''),
    2115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2115, CurrentID=0, Status='live', Symbol='ETV1', Aliases=['ER81'], description='ETS variant transcription factor 1', other_designations='ETS translocation variant 1|ETS variant 1|ets variant gene 1|ets-related protein 81', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=13891229, end_position_on_the_genomic_accession=13991425, orientation='minus', exon_count=21, OMIM=[600541], no_hdr0=''),
    2116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2116, CurrentID=0, Status='live', Symbol='ETV2', Aliases=['ER71', 'ETSRP71'], description='ETS variant transcription factor 2', other_designations='ETS translocation variant 2|ETS variant 2|ets variant gene 2|ets-related protein 71', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35641175, end_position_on_the_genomic_accession=35644871, orientation='plus', exon_count=7, OMIM=[609358], no_hdr0=''),
    2117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2117, CurrentID=0, Status='live', Symbol='ETV3', Aliases=['METS', 'PE-1', 'PE1'], description='ETS variant transcription factor 3', other_designations='ETS translocation variant 3|ETS domain transcriptional repressor PE1|ETS variant 3|ets variant gene 3, ETS family transcriptional repressor|mitogenic Ets transcriptional suppressor', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157121191, end_position_on_the_genomic_accession=157138575, orientation='minus', exon_count=5, OMIM=[164873], no_hdr0=''),
    2118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2118, CurrentID=0, Status='live', Symbol='ETV4', Aliases=['E1A-F', 'E1AF', 'PEA3', 'PEAS3'], description='ETS variant transcription factor 4', other_designations='ETS translocation variant 4|ETS variant 4|EWS protein/E1A enhancer binding protein chimera|adenovirus E1A enhancer-binding protein|ets variant gene 4 (E1A enhancer-binding protein, E1AF)|polyomavirus enhancer activator 3 homolog', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43527843, end_position_on_the_genomic_accession=43546340, orientation='minus', exon_count=14, OMIM=[600711], no_hdr0=''),
    2119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2119, CurrentID=0, Status='live', Symbol='ETV5', Aliases=['ERM'], description='ETS variant transcription factor 5', other_designations='ETS translocation variant 5|ETS variant 5|ets-related molecule|ets-related protein ERM', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186046314, end_position_on_the_genomic_accession=186109089, orientation='minus', exon_count=13, OMIM=[601600], no_hdr0=''),
    2120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2120, CurrentID=0, Status='live', Symbol='ETV6', Aliases=['TEL', 'TEL/ABL', 'THC5'], description='ETS variant transcription factor 6', other_designations='transcription factor ETV6|ETS translocation variant 6|ETS variant 6|ETS-related protein Tel1|TEL1 oncogene|ets variant gene 6 (TEL oncogene)', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11649601, end_position_on_the_genomic_accession=11895386, orientation='plus', exon_count=14, OMIM=[600618], no_hdr0=''),
    2121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2121, CurrentID=0, Status='live', Symbol='EVC', Aliases=['DWF-11', 'EVCL', 'EVC'], description='EvC ciliary complex subunit 1', other_designations='ellis-van Creveld syndrome protein|Ellis van Creveld protein|Ellis van Creveld syndrome', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5711199, end_position_on_the_genomic_accession=5829043, orientation='plus', exon_count=30, OMIM=[604831], no_hdr0=''),
    2122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2122, CurrentID=0, Status='live', Symbol='MECOM', Aliases=['AML1-EVI-1', 'EVI1', 'KMT8E', 'MDS1', 'MDS1-EVI1', 'PRDM3', 'RUSAT2'], description='MDS1 and EVI1 complex locus', other_designations='histone-lysine N-methyltransferase MECOM|AML1-EVI-1 fusion protein|MDS1 and EVI1 complex locus protein EVI1|MDS1 and EVI1 complex locus protein MDS1|PR domain 3|ecotropic virus integration site 1 protein homolog|myelodysplasia syndrome-associated protein 1|oncogene EVI1|zinc finger protein Evi1', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169083506, end_position_on_the_genomic_accession=169663781, orientation='minus', exon_count=23, OMIM=[165215], no_hdr0=''),
    2123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2123, CurrentID=0, Status='live', Symbol='EVI2A', Aliases=['EVDA', 'EVI-2A', 'EVI2'], description='ecotropic viral integration site 2A', other_designations='protein EVI2A|ecotropic viral integration site 2A protein homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31316410, end_position_on_the_genomic_accession=31321622, orientation='minus', exon_count=3, OMIM=[158380], no_hdr0=''),
    2124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2124, CurrentID=0, Status='live', Symbol='EVI2B', Aliases=['CD361', 'D17S376', 'EVDB'], description='ecotropic viral integration site 2B', other_designations='protein EVI2B|EVI-2B|ecotropic viral integration site 2B protein homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31303770, end_position_on_the_genomic_accession=31314149, orientation='minus', exon_count=3, OMIM=[158381], no_hdr0=''),
    2125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2125, CurrentID=0, Status='live', Symbol='EVPL', Aliases=['EVPK'], description='envoplakin', other_designations='envoplakin|210 kDa cornified envelope precursor protein|210 kDa paraneoplastic pemphigus antigen', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76006845, end_position_on_the_genomic_accession=76027306, orientation='minus', exon_count=22, OMIM=[601590], no_hdr0=''),
    2128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2128, CurrentID=0, Status='live', Symbol='EVX1', Aliases=['EVX-1'], description='even-skipped homeobox 1', other_designations='homeobox even-skipped homolog protein 1|eve, even-skipped homeo box homolog 1|eve, even-skipped homeobox homolog 1|even-skipped homeo box 1 (homolog of Drosophila)', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27242802, end_position_on_the_genomic_accession=27247830, orientation='plus', exon_count=4, OMIM=[142996], no_hdr0=''),
    2130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2130, CurrentID=0, Status='live', Symbol='EWSR1', Aliases=['EWS', 'EWS-FLI1', 'bK984G1.4'], description='EWS RNA binding protein 1', other_designations='RNA-binding protein EWS|EWS RNA-binding protein variant 6|Ewing sarcoma breakpoint region 1|Ewings sarcoma EWS-Fli1 (type 1) oncogene', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29268254, end_position_on_the_genomic_accession=29300523, orientation='plus', exon_count=19, OMIM=[133450], no_hdr0=''),
    2131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2131, CurrentID=0, Status='live', Symbol='EXT1', Aliases=['EXT', 'LGCR', 'LGS', 'TRPS2', 'TTV'], description='exostosin glycosyltransferase 1', other_designations='exostosin-1|Glucuronosyl-N-acetylglucosaminyl-proteoglycan 4-alpha-N- acetylglucosaminyltransferase|Langer-Giedion syndrome chromosome region|N-acetylglucosaminyl-proteoglycan 4-beta-glucuronosyltransferase|exostoses (multiple) 1|glucuronosyl-N-acetylglucosaminyl-proteoglycan/N-acetylglucosaminyl-proteoglycan 4-alpha-N-acetylglucosaminyltransferase|multiple exostoses protein 1|putative tumor suppressor protein EXT1', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=117794490, end_position_on_the_genomic_accession=118111826, orientation='minus', exon_count=11, OMIM=[608177], no_hdr0=''),
    2132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2132, CurrentID=0, Status='live', Symbol='EXT2', Aliases=['SOTV', 'SSMS'], description='exostosin glycosyltransferase 2', other_designations='exostosin-2|N-acetylglucosaminyl-proteoglycan 4-beta-glucuronosyltransferase|glucuronosyl-N-acetylglucosaminyl-proteoglycan/N-acetylglucosaminyl-proteoglycan 4-alpha-N-acetylglucosaminyltransferase|multiple exostoses protein 2|multiple exostosis 2|putative tumor suppressor protein EXT2', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44095678, end_position_on_the_genomic_accession=44251962, orientation='plus', exon_count=18, OMIM=[608210], no_hdr0=''),
    2134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2134, CurrentID=0, Status='live', Symbol='EXTL1', Aliases=['EXTL'], description='exostosin like glycosyltransferase 1', other_designations='exostosin-like 1|alpha-N-acetylglucosaminyltransferase II|exostoses (multiple)-like 1|exostosin-L|glucuronosyl-N-acetylglucosaminyl-proteoglycan 4-alpha-N- acetylglucosaminyltransferase|glucuronyl-N-acetylglucosaminylproteoglycan alpha-1,4-N- acetylglucosaminyltransferase|multiple exostosis-like protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26021775, end_position_on_the_genomic_accession=26036464, orientation='plus', exon_count=12, OMIM=[601738], no_hdr0=''),
    2135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2135, CurrentID=0, Status='live', Symbol='EXTL2', Aliases=['EXTR2'], description='exostosin like glycosyltransferase 2', other_designations='exostosin-like 2|EXT-related protein 2|alpha-1,4-N-acetylhexosaminyltransferase EXTL2|alpha-GalNAcT EXTL2|exostoses (multiple)-like 2|glucuronyl-galactosyl-proteoglycan 4-alpha-N-acetylglucosaminyltransferase|processed exostosin-like 2', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100872372, end_position_on_the_genomic_accession=100895411, orientation='minus', exon_count=9, OMIM=[602411], no_hdr0=''),
    2137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2137, CurrentID=0, Status='live', Symbol='EXTL3', Aliases=['BOTV', 'EXTL1L', 'EXTR1', 'ISDNA', 'REGR', 'RPR'], description='exostosin like glycosyltransferase 3', other_designations='exostosin-like 3|EXT-related 1|epididymis secretory sperm binding protein|exostoses (multiple)-like 3|exostosin tumor-like 3|glucuronyl-galactosyl-proteoglycan 4-alpha-N-acetylglucosaminyltransferase|hereditary multiple exostoses gene isolog|putative tumor suppressor protein EXTL3|reg receptor', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28607736, end_position_on_the_genomic_accession=28755599, orientation='plus', exon_count=10, OMIM=[605744], no_hdr0=''),
    2138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2138, CurrentID=0, Status='live', Symbol='EYA1', Aliases=['BOP', 'BOR', 'BOS1', 'OFC1'], description='EYA transcriptional coactivator and phosphatase 1', other_designations='eyes absent homolog 1', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=71197433, end_position_on_the_genomic_accession=71548104, orientation='minus', exon_count=25, OMIM=[601653], no_hdr0=''),
    2139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2139, CurrentID=0, Status='live', Symbol='EYA2', Aliases=['EAB1'], description='EYA transcriptional coactivator and phosphatase 2', other_designations='eyes absent homolog 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46894843, end_position_on_the_genomic_accession=47188844, orientation='plus', exon_count=16, OMIM=[601654], no_hdr0=''),
    2140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2140, CurrentID=0, Status='live', Symbol='EYA3', Aliases=[], description='EYA transcriptional coactivator and phosphatase 3', other_designations='eyes absent homolog 3|eyes absent 3', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27970344, end_position_on_the_genomic_accession=28088671, orientation='minus', exon_count=22, OMIM=[601655], no_hdr0=''),
    2145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2145, CurrentID=0, Status='live', Symbol='EZH1', Aliases=['KMT6B'], description='enhancer of zeste 1 polycomb repressive complex 2 subunit', other_designations='histone-lysine N-methyltransferase EZH1|ENX-2|enhancer of zeste homolog 1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42700275, end_position_on_the_genomic_accession=42745078, orientation='minus', exon_count=21, OMIM=[601674], no_hdr0=''),
    2146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2146, CurrentID=0, Status='live', Symbol='EZH2', Aliases=['ENX-1', 'ENX1b', 'KMT6', 'KMT6A', 'WVS', 'WVS2', 'EZH2'], description='enhancer of zeste 2 polycomb repressive complex 2 subunit', other_designations='histone-lysine N-methyltransferase EZH2|enhancer of zeste homolog 2|lysine N-methyltransferase 6', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=148807374, end_position_on_the_genomic_accession=148884344, orientation='minus', exon_count=25, OMIM=[601573], no_hdr0=''),
    2147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2147, CurrentID=0, Status='live', Symbol='F2', Aliases=['PT', 'RPRGL2', 'THPH1'], description='coagulation factor II, thrombin', other_designations='prothrombin|prepro-coagulation factor II|prothrombin B-chain|thrombin factor II', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46719213, end_position_on_the_genomic_accession=46739506, orientation='plus', exon_count=14, OMIM=[176930], no_hdr0=''),
    2149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2149, CurrentID=0, Status='live', Symbol='F2R', Aliases=['CF2R', 'HTR', 'PAR-1', 'PAR1', 'TR'], description='coagulation factor II thrombin receptor', other_designations='proteinase-activated receptor 1|protease-activated receptor 1', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76716126, end_position_on_the_genomic_accession=76735770, orientation='plus', exon_count=3, OMIM=[187930], no_hdr0=''),
    2150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2150, CurrentID=0, Status='live', Symbol='F2RL1', Aliases=['GPR11', 'PAR2'], description='F2R like trypsin receptor 1', other_designations='proteinase-activated receptor 2|G-protein coupled receptor 11|coagulation factor II (thrombin) receptor-like 1|protease-activated receptor 2|thrombin receptor-like 1', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76819030, end_position_on_the_genomic_accession=76835315, orientation='plus', exon_count=3, OMIM=[600933], no_hdr0=''),
    2151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2151, CurrentID=0, Status='live', Symbol='F2RL2', Aliases=['PAR-3', 'PAR3'], description='coagulation factor II thrombin receptor like 2', other_designations='proteinase-activated receptor 3|Coagulation factor II receptor-like 2 (protease-actovated receptor 3)|protease-activated receptor 3|thrombin receptor-like 2', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76615482, end_position_on_the_genomic_accession=76623403, orientation='minus', exon_count=2, OMIM=[601919], no_hdr0=''),
    2152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2152, CurrentID=0, Status='live', Symbol='F3', Aliases=['CD142', 'TF', 'TFA'], description='coagulation factor III, tissue factor', other_designations='tissue factor|coagulation factor III (thromboplastin, tissue factor)', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94529173, end_position_on_the_genomic_accession=94541759, orientation='minus', exon_count=6, OMIM=[134390], no_hdr0=''),
    2153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2153, CurrentID=0, Status='live', Symbol='F5', Aliases=['FVL', 'PCCF', 'RPRGL1', 'THPH2'], description='coagulation factor V', other_designations='coagulation factor V|activated protein c cofactor|coagulation factor V (proaccelerin, labile factor)|coagulation factor V jinjiang A2 domain|factor V Leiden', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169511951, end_position_on_the_genomic_accession=169586630, orientation='minus', exon_count=25, OMIM=[612309], no_hdr0=''),
    2155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2155, CurrentID=0, Status='live', Symbol='F7', Aliases=['SPCA'], description='coagulation factor VII', other_designations='coagulation factor VII|FVII coagulation protein|coagulation factor VII (serum prothrombin conversion accelerator)|eptacog alfa|proconvertin', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113105773, end_position_on_the_genomic_accession=113120685, orientation='plus', exon_count=10, OMIM=[613878], no_hdr0=''),
    2157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2157, CurrentID=0, Status='live', Symbol='F8', Aliases=['AHF', 'DXS1253EB', 'F8C', 'FVIII', 'HEMA', 'F8'], description='coagulation factor VIII', other_designations='coagulation factor VIII|antihemophilic factor|coagulation factor VIII A1 domain|coagulation factor VIII C2 domain|coagulation factor VIII, procoagulant component|coagulation factor VIIIc|factor VIII F8B', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154835792, end_position_on_the_genomic_accession=155022723, orientation='minus', exon_count=27, OMIM=[300841], no_hdr0=''),
    2158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2158, CurrentID=0, Status='live', Symbol='F9', Aliases=['F9 p22', 'FIX', 'HEMB', 'P19', 'PTC', 'THPH8'], description='coagulation factor IX', other_designations='coagulation factor IX|Christmas factor|factor 9|factor IX F9|plasma thromboplastic component|plasma thromboplastin component', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=139530720, end_position_on_the_genomic_accession=139563459, orientation='plus', exon_count=8, OMIM=[300746], no_hdr0=''),
    2159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2159, CurrentID=0, Status='live', Symbol='F10', Aliases=['FX', 'FXA'], description='coagulation factor X', other_designations='coagulation factor X|Stuart-Prower factor|factor X|factor Xa|prothrombinase', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113122799, end_position_on_the_genomic_accession=113149529, orientation='plus', exon_count=8, OMIM=[613872], no_hdr0=''),
    2160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2160, CurrentID=0, Status='live', Symbol='F11', Aliases=['FXI', 'PTA'], description='coagulation factor XI', other_designations='coagulation factor XI|coagualtion factor XI|plasma thromboplastin antecedent', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186265964, end_position_on_the_genomic_accession=186290727, orientation='plus', exon_count=15, OMIM=[264900], no_hdr0=''),
    2161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2161, CurrentID=0, Status='live', Symbol='F12', Aliases=['HAE3', 'HAEX', 'HAF'], description='coagulation factor XII', other_designations='coagulation factor XII|Hageman factor|beta-factor XIIa part 1|beta-factor XIIa part 2|coagulation factor XIIa heavy chain|coagulation factor XIIa light chain', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177402138, end_position_on_the_genomic_accession=177409564, orientation='minus', exon_count=15, OMIM=[610619], no_hdr0=''),
    2162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2162, CurrentID=0, Status='live', Symbol='F13A1', Aliases=['F13A'], description='coagulation factor XIII A chain', other_designations='coagulation factor XIII A chain|FSF, A subunit|TGase|bA525O21.1 (coagulation factor XIII, A1 polypeptide)|coagulation factor XIII, A polypeptide|coagulation factor XIII, A1 polypeptide|coagulation factor XIIIa|factor XIIIa|fibrin stabilizing factor, A subunit|fibrinoligase|protein-glutamine gamma-glutamyltransferase A chain|transglutaminase A chain|transglutaminase. plasma', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=6144084, end_position_on_the_genomic_accession=6320662, orientation='minus', exon_count=15, OMIM=[134570], no_hdr0=''),
    2165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2165, CurrentID=0, Status='live', Symbol='F13B', Aliases=['FXIIIB'], description='coagulation factor XIII B chain', other_designations='coagulation factor XIII B chain|TGase|coagulation factor XIII, B polypeptide|fibrin-stabilizing factor B subunit|protein-glutamine gamma-glutamyltransferase B chain|transglutaminase B chain', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197038741, end_position_on_the_genomic_accession=197067264, orientation='minus', exon_count=12, OMIM=[134580], no_hdr0=''),
    2166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2166, CurrentID=0, Status='live', Symbol='FAAH', Aliases=['FAAH-1', 'PSAB'], description='fatty acid amide hydrolase', other_designations='fatty-acid amide hydrolase 1|anandamide amidohydrolase 1|fatty acid ester hydrolase|oleamide hydrolase 1', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46394317, end_position_on_the_genomic_accession=46413845, orientation='plus', exon_count=15, OMIM=[602935], no_hdr0=''),
    2167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2167, CurrentID=0, Status='live', Symbol='FABP4', Aliases=['A-FABP', 'AFABP', 'ALBP', 'HEL-S-104', 'aP2'], description='fatty acid binding protein 4', other_designations='fatty acid-binding protein, adipocyte|adipocyte fatty acid binding protein|adipocyte lipid-binding protein|adipocyte-type fatty acid-binding protein|epididymis secretory protein Li 104|fatty acid binding protein 4, adipocyte', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81478419, end_position_on_the_genomic_accession=81483233, orientation='minus', exon_count=4, OMIM=[600434], no_hdr0=''),
    2168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2168, CurrentID=0, Status='live', Symbol='FABP1', Aliases=['FABPL', 'L-FABP'], description='fatty acid binding protein 1', other_designations='fatty acid-binding protein, liver|fatty acid binding protein 1, liver|liver-type fatty acid-binding protein', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88122982, end_position_on_the_genomic_accession=88128062, orientation='minus', exon_count=4, OMIM=[134650], no_hdr0=''),
    2169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2169, CurrentID=0, Status='live', Symbol='FABP2', Aliases=['FABPI', 'I-FABP'], description='fatty acid binding protein 2', other_designations='fatty acid-binding protein, intestinal|fatty acid binding protein 2, intestinal|intestinal-type fatty acid-binding protein', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=119317250, end_position_on_the_genomic_accession=119322138, orientation='minus', exon_count=4, OMIM=[134640], no_hdr0=''),
    2170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2170, CurrentID=0, Status='live', Symbol='FABP3', Aliases=['FABP11', 'H-FABP', 'M-FABP', 'MDGI', 'O-FABP'], description='fatty acid binding protein 3', other_designations='fatty acid-binding protein, heart|epididymis secretory sperm binding protein|fatty acid binding protein 11|fatty acid binding protein 3, muscle and heart|heart-type fatty acid-binding protein|mammary-derived growth inhibitor|muscle fatty acid-binding protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31359595, end_position_on_the_genomic_accession=31373618, orientation='minus', exon_count=5, OMIM=[134651], no_hdr0=''),
    2171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2171, CurrentID=0, Status='live', Symbol='FABP5', Aliases=['E-FABP', 'EFABP', 'KFABP', 'PA-FABP', 'PAFABP'], description='fatty acid binding protein 5', other_designations='fatty acid-binding protein 5|epidermal-type fatty acid-binding protein|fatty acid binding protein 5 (psoriasis-associated)|psoriasis-associated fatty acid-binding protein homolog', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81280536, end_position_on_the_genomic_accession=81284775, orientation='plus', exon_count=4, OMIM=[605168], no_hdr0=''),
    2172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2172, CurrentID=0, Status='live', Symbol='FABP6', Aliases=['I-15P', 'I-BABP', 'I-BALB', 'I-BAP', 'ILBP', 'ILBP3', 'ILLBP'], description='fatty acid binding protein 6', other_designations='gastrotropin|GT|fatty acid binding protein 6, ileal|ileal bile acid binding protein|ileal lipid-binding protein|illeal lipid-binding protein|intestinal 15 kDa protein', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160187381, end_position_on_the_genomic_accession=160238722, orientation='plus', exon_count=7, OMIM=[600422], no_hdr0=''),
    2173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2173, CurrentID=0, Status='live', Symbol='FABP7', Aliases=['B-FABP', 'BLBP', 'FABPB', 'MRG'], description='fatty acid binding protein 7', other_designations='fatty acid-binding protein, brain|brain lipid-binding protein|brain-type fatty acid-binding protein|hypothetical protein DKFZp547J2313|mammary-derived growth inhibitor-related', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122749201, end_position_on_the_genomic_accession=122784074, orientation='plus', exon_count=5, OMIM=[602965], no_hdr0=''),
    2175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2175, CurrentID=0, Status='live', Symbol='FANCA', Aliases=['FA', 'FA-H', 'FA1', 'FAA', 'FACA', 'FAH', 'FANCH'], description='FA complementation group A', other_designations='Fanconi anemia group A protein|Fanconi anemia complementation group A|Fanconi anemia, complementation group H|Fanconi anemia, type 1', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89737549, end_position_on_the_genomic_accession=89816647, orientation='minus', exon_count=44, OMIM=[607139], no_hdr0=''),
    2176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2176, CurrentID=0, Status='live', Symbol='FANCC', Aliases=['FA3', 'FAC', 'FACC'], description='FA complementation group C', other_designations='Fanconi anemia group C protein|Fanconi anemia complementation group C', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=95099054, end_position_on_the_genomic_accession=95317730, orientation='minus', exon_count=22, OMIM=[613899], no_hdr0=''),
    2177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2177, CurrentID=0, Status='live', Symbol='FANCD2', Aliases=['FA-D2', 'FA4', 'FACD', 'FAD', 'FAD2', 'FANCD'], description='FA complementation group D2', other_designations='Fanconi anemia group D2 protein|Fanconi anemia complementation group D2', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10026437, end_position_on_the_genomic_accession=10101932, orientation='plus', exon_count=45, OMIM=[613984], no_hdr0=''),
    2178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2178, CurrentID=0, Status='live', Symbol='FANCE', Aliases=['FACE', 'FAE'], description='FA complementation group E', other_designations='Fanconi anemia group E protein|Fanconi anemia complementation group E', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35452338, end_position_on_the_genomic_accession=35467106, orientation='plus', exon_count=10, OMIM=[613976], no_hdr0=''),
    2180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2180, CurrentID=0, Status='live', Symbol='ACSL1', Aliases=['ACS1', 'FACL1', 'FACL2', 'LACS', 'LACS1', 'LACS2'], description='acyl-CoA synthetase long chain family member 1', other_designations='long-chain-fatty-acid--CoA ligase 1|LACS 1|LACS 2|acyl-CoA synthetase 1|arachidonate--CoA ligase|fatty-acid-Coenzyme A ligase, long-chain 1|fatty-acid-Coenzyme A ligase, long-chain 2|lignoceroyl-CoA synthase|long-chain acyl-CoA synthetase 1|long-chain acyl-CoA synthetase 2|long-chain fatty acid-CoA ligase 2|long-chain fatty-acid-coenzyme A ligase 1|palmitoyl-CoA ligase 1|palmitoyl-CoA ligase 2|paltimoyl-CoA ligase 1|phytanate--CoA ligase', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184755595, end_position_on_the_genomic_accession=184826593, orientation='minus', exon_count=31, OMIM=[152425], no_hdr0=''),
    2181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2181, CurrentID=0, Status='live', Symbol='ACSL3', Aliases=['ACS3', 'FACL3', 'LACS 3', 'LACS3', 'PRO2194'], description='acyl-CoA synthetase long chain family member 3', other_designations='long-chain-fatty-acid--CoA ligase 3|arachidonate--CoA ligase|fatty-acid-Coenzyme A ligase, long-chain 3|lignoceroyl-CoA synthase|long-chain acyl-CoA synthetase 3', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=222861036, end_position_on_the_genomic_accession=222944639, orientation='plus', exon_count=17, OMIM=[602371], no_hdr0=''),
    2182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2182, CurrentID=0, Status='live', Symbol='ACSL4', Aliases=['ACS4', 'FACL4', 'LACS4', 'MRX63', 'MRX68'], description='acyl-CoA synthetase long chain family member 4', other_designations='long-chain-fatty-acid--CoA ligase 4|acyl-CoA synthetase 4|arachidonate--CoA ligase|fatty-acid-Coenzyme A ligase, long-chain 4|lignoceroyl-CoA synthase|long-chain acyl-CoA synthetase 4|long-chain fatty-acid-Coenzyme A ligase 4', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=109641335, end_position_on_the_genomic_accession=109733325, orientation='minus', exon_count=18, OMIM=[300157], no_hdr0=''),
    2184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2184, CurrentID=0, Status='live', Symbol='FAH', Aliases=[], description='fumarylacetoacetate hydrolase', other_designations='fumarylacetoacetase|FAA|beta-diketonase|epididymis secretory sperm binding protein|fumarylacetoacetate hydrolase (fumarylacetoacetase)', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80152789, end_position_on_the_genomic_accession=80186949, orientation='plus', exon_count=15, OMIM=[613871], no_hdr0=''),
    2185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2185, CurrentID=0, Status='live', Symbol='PTK2B', Aliases=['CADTK', 'CAKB', 'FADK2', 'FAK2', 'PKB', 'PTK', 'PYK2', 'RAFTK'], description='protein tyrosine kinase 2 beta', other_designations='protein-tyrosine kinase 2-beta|CAK-beta|FADK 2|PTK2B protein tyrosine kinase 2 beta|calcium-dependent tyrosine kinase|calcium-regulated non-receptor proline-rich tyrosine kinase|cell adhesion kinase beta|focal adhesion kinase 2|proline-rich tyrosine kinase 2|protein kinase B|related adhesion focal tyrosine kinase', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27311478, end_position_on_the_genomic_accession=27459391, orientation='plus', exon_count=39, OMIM=[601212], no_hdr0=''),
    2186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2186, CurrentID=0, Status='live', Symbol='BPTF', Aliases=['FAC1', 'FALZ', 'NEDDFL', 'NURF301'], description='bromodomain PHD finger transcription factor', other_designations='nucleosome-remodeling factor subunit BPTF|bromodomain and PHD domain transcription factor|bromodomain and PHD finger-containing transcription factor|fetal Alz-50 clone 1 protein|fetal Alz-50 reactive clone 1|fetal Alzheimer antigen|nucleosome remodeling factor, large subunit', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67825503, end_position_on_the_genomic_accession=67984378, orientation='plus', exon_count=34, OMIM=[601819], no_hdr0=''),
    2187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2187, CurrentID=0, Status='live', Symbol='FANCB', Aliases=['FA2', 'FAAP90', 'FAAP95', 'FAB', 'FACB'], description='FA complementation group B', other_designations='Fanconi anemia group B protein|Fanconi anemia complementation group B|Fanconi anemia-associated polypeptide of 95 kDa', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=14690863, end_position_on_the_genomic_accession=14873255, orientation='minus', exon_count=17, OMIM=[300515], no_hdr0=''),
    2188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2188, CurrentID=0, Status='live', Symbol='FANCF', Aliases=['FAF'], description='FA complementation group F', other_designations='Fanconi anemia group F protein|Fanconi anemia complementation group F', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22622533, end_position_on_the_genomic_accession=22625823, orientation='minus', exon_count=1, OMIM=[613897], no_hdr0=''),
    2189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2189, CurrentID=0, Status='live', Symbol='FANCG', Aliases=['FAG', 'XRCC9'], description='FA complementation group G', other_designations='Fanconi anemia group G protein|DNA repair protein XRCC9|Fanconi anemia complementation group G|X-ray repair complementing defective repair in Chinese hamster cells 9|X-ray repair, complementing defective, in Chinese hamster, 9|truncated Fanconi anemia group G protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35073839, end_position_on_the_genomic_accession=35079942, orientation='minus', exon_count=14, OMIM=[602956], no_hdr0=''),
    2191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2191, CurrentID=0, Status='live', Symbol='FAP', Aliases=['DPPIVA', 'FAPalpha', 'SIMP', 'FAP'], description='fibroblast activation protein alpha', other_designations='prolyl endopeptidase FAP|170 kDa melanoma membrane-bound gelatinase|dipeptidyl peptidase FAP|gelatine degradation protease FAP|integral membrane serine protease|post-proline cleaving enzyme|seprase|surface-expressed protease', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=162170684, end_position_on_the_genomic_accession=162243472, orientation='minus', exon_count=30, OMIM=[600403], no_hdr0=''),
    2192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2192, CurrentID=0, Status='live', Symbol='FBLN1', Aliases=['FBLN', 'FIBL1'], description='fibulin 1', other_designations='fibulin-1', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45502883, end_position_on_the_genomic_accession=45601135, orientation='plus', exon_count=20, OMIM=[135820], no_hdr0=''),
    2193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2193, CurrentID=0, Status='live', Symbol='FARSA', Aliases=['CML33', 'FARSL', 'FARSLA', 'FRSA', 'PheHA', 'RILDBC2'], description='phenylalanyl-tRNA synthetase subunit alpha', other_designations='phenylalanine--tRNA ligase alpha subunit|pheRS|phenylalanine tRNA ligase 1, alpha, cytoplasmic|phenylalanine--tRNA ligase alpha chain|phenylalanine-tRNA synthetase alpha-subunit|phenylalanine-tRNA synthetase-like, alpha subunit|phenylalanyl-tRNA synthetase alpha chain|phenylalanyl-tRNA synthetase alpha subunit|phenylalanyl-tRNA synthetase-like, alpha subunit', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12922479, end_position_on_the_genomic_accession=12933711, orientation='minus', exon_count=13, OMIM=[602918], no_hdr0=''),
    2194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2194, CurrentID=0, Status='live', Symbol='FASN', Aliases=['FAS', 'OA-519', 'SDR27X1'], description='fatty acid synthase', other_designations='fatty acid synthase|short chain dehydrogenase/reductase family 27X, member 1|type I fatty acid synthase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82078338, end_position_on_the_genomic_accession=82098303, orientation='minus', exon_count=43, OMIM=[600212], no_hdr0=''),
    2195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2195, CurrentID=0, Status='live', Symbol='FAT1', Aliases=['CDHF7', 'CDHR8', 'FAT', 'ME5', 'hFat1'], description='FAT atypical cadherin 1', other_designations='protocadherin Fat 1|FAT tumor suppressor 1|cadherin ME5|cadherin family member 7|cadherin-related family member 8|cadherin-related tumor suppressor homolog|protein fat homolog', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186587789, end_position_on_the_genomic_accession=186726696, orientation='minus', exon_count=29, OMIM=[600976], no_hdr0=''),
    2196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2196, CurrentID=0, Status='live', Symbol='FAT2', Aliases=['CDHF8', 'CDHR9', 'HFAT2', 'MEGF1', 'SCA45'], description='FAT atypical cadherin 2', other_designations='protocadherin Fat 2|FAT tumor suppressor homolog 2|cadherin family member 8|cadherin-related family member 9|multiple EGF-like domains protein 1|multiple epidermal growth factor-like domains 1|multiple epidermal growth factor-like domains protein 1|protocadherin FAT2', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151504092, end_position_on_the_genomic_accession=151594822, orientation='minus', exon_count=30, OMIM=[604269], no_hdr0=''),
    2197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2197, CurrentID=0, Status='live', Symbol='FAU', Aliases=['FAU1', 'Fub1', 'Fubi', 'MNSFbeta', 'RPS30', 'S30', 'asr1'], description='FAU ubiquitin like and ribosomal protein S30 fusion', other_designations='ubiquitin-like protein fubi and ribosomal protein S30|40S ribosomal protein S30|FAU-encoded ubiquitin-like protein|FBR-MuSV-associated ubiquitously expressed|Finkel-Biskis-Reilly murine sarcoma virus (FBR-MuSV) ubiquitously expressed (fox derived)|monoclonal nonspecific suppressor factor beta|ribosomal protein S30|small ribosomal subunit protein eS30|ubiquitin-like-S30 fusion protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65120630, end_position_on_the_genomic_accession=65122134, orientation='minus', exon_count=5, OMIM=[134690], no_hdr0=''),
    2199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2199, CurrentID=0, Status='live', Symbol='FBLN2', Aliases=[], description='fibulin 2', other_designations='fibulin-2|FIBL-2', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=13549125, end_position_on_the_genomic_accession=13638404, orientation='plus', exon_count=19, OMIM=[135821], no_hdr0=''),
    2200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2200, CurrentID=0, Status='live', Symbol='FBN1', Aliases=['ACMICD', 'ECTOL1', 'FBN', 'GPHYSD2', 'MASS', 'MFLS', 'MFS1', 'OCTD', 'SGS', 'SSKS', 'WMS', 'WMS2'], description='fibrillin 1', other_designations='fibrillin-1|asprosin|epididymis secretory sperm binding protein|fibrillin 15|fibrillin-1 preproprotein', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48408313, end_position_on_the_genomic_accession=48645709, orientation='minus', exon_count=66, OMIM=[134797], no_hdr0=''),
    2201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2201, CurrentID=0, Status='live', Symbol='FBN2', Aliases=['CCA', 'DA9', 'EOMD'], description='fibrillin 2', other_designations='fibrillin-2|fibrillin 5', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=128257909, end_position_on_the_genomic_accession=128538245, orientation='minus', exon_count=65, OMIM=[612570], no_hdr0=''),
    2202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2202, CurrentID=0, Status='live', Symbol='EFEMP1', Aliases=['DHRD', 'DRAD', 'FBLN3', 'FBNL', 'FIBL-3', 'MLVT', 'MTLV', 'S1-5'], description='EGF containing fibulin extracellular matrix protein 1', other_designations='EGF-containing fibulin-like extracellular matrix protein 1|EGF containing fibulin like extracellular matrix protein 1|extracellular protein S1-5|fibulin-3', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55865967, end_position_on_the_genomic_accession=55924163, orientation='minus', exon_count=12, OMIM=[601548], no_hdr0=''),
    2203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2203, CurrentID=0, Status='live', Symbol='FBP1', Aliases=['FBP'], description='fructose-bisphosphatase 1', other_designations='fructose-1,6-bisphosphatase 1|D-fructose-1,6-bisphosphate 1-phosphohydrolase 1|FBPase 1|growth-inhibiting protein 17|liver FBPase', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94603133, end_position_on_the_genomic_accession=94640263, orientation='minus', exon_count=8, OMIM=[611570], no_hdr0=''),
    2204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2204, CurrentID=0, Status='live', Symbol='FCAR', Aliases=['CD89', 'CTB-61M7.2', 'FcalphaRI'], description='Fc fragment of IgA receptor', other_designations='immunoglobulin alpha Fc receptor|FCAR variant 14|Fc alpha receptor|Fc fragment of IgA, receptor for', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54874231, end_position_on_the_genomic_accession=54891420, orientation='plus', exon_count=7, OMIM=[147045], no_hdr0=''),
    2205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2205, CurrentID=0, Status='live', Symbol='FCER1A', Aliases=['FCE1A', 'FcERI'], description='Fc fragment of IgE receptor Ia', other_designations='high affinity immunoglobulin epsilon receptor subunit alpha|Fc IgE receptor, alpha polypeptide|Fc epsilon RI alpha-chain|Fc epsilon receptor Ia|Fc fragment of IgE, high affinity I, receptor for; alpha polypeptide|Fc-epsilon RI-alpha|high affinity immunoglobulin epsilon receptor alpha-subunit|igE Fc receptor subunit alpha|immunoglobulin E receptor, high-affinity, of mast cells, alpha polypeptide', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159283575, end_position_on_the_genomic_accession=159308202, orientation='plus', exon_count=7, OMIM=[147140], no_hdr0=''),
    2206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2206, CurrentID=0, Status='live', Symbol='MS4A2', Aliases=['APY', 'ATOPY', 'FCER1B', 'FCERI', 'IGEL', 'IGER', 'IGHER', 'MS4A1'], description='membrane spanning 4-domains A2', other_designations='high affinity immunoglobulin epsilon receptor subunit beta|Fc fragment of IgE, high affinity I, receptor for; beta polypeptide|High affinity immunoglobulin epsilon receptor beta-subunit (FcERI) (IgE Fc receptor, beta-subunit) (Fc epsilon receptor I beta-chain)|high affinity IgE receptor beta subunit|igE Fc receptor subunit beta|immunoglobulin E receptor, high affinity, beta polypeptide|membrane-spanning 4-domains subfamily A member 2', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60088261, end_position_on_the_genomic_accession=60098467, orientation='plus', exon_count=8, OMIM=[147138], no_hdr0=''),
    2207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2207, CurrentID=0, Status='live', Symbol='FCER1G', Aliases=['FCRG'], description='Fc fragment of IgE receptor Ig', other_designations='high affinity immunoglobulin epsilon receptor subunit gamma|Fc epsilon receptor Ig|Fc fragment of IgE, high affinity I, receptor for; gamma polypeptide|Fc receptor gamma-chain|fc-epsilon RI-gamma|fcRgamma|fceRI gamma|immunoglobulin E receptor, high affinity, gamma chain', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161215295, end_position_on_the_genomic_accession=161219245, orientation='plus', exon_count=5, OMIM=[147139], no_hdr0=''),
    2208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2208, CurrentID=0, Status='live', Symbol='FCER2', Aliases=['BLAST-2', 'CD23', 'CD23A', 'CLEC4J', 'FCE2', 'IGEBF'], description='Fc fragment of IgE receptor II', other_designations='low affinity immunoglobulin epsilon Fc receptor|C-type lectin domain family 4, member J|CD23 antigen|Fc epsilon receptor II|Fc fragment of IgE, low affinity II, receptor for (CD23)|fc-epsilon-RII|immunoglobulin E-binding factor|immunoglobulin epsilon-chain|lymphocyte IgE receptor', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7688759, end_position_on_the_genomic_accession=7702755, orientation='minus', exon_count=12, OMIM=[151445], no_hdr0=''),
    2209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2209, CurrentID=0, Status='live', Symbol='FCGR1A', Aliases=['CD64', 'CD64A', 'FCRI', 'IGFR1'], description='Fc fragment of IgG receptor Ia', other_designations='high affinity immunoglobulin gamma Fc receptor I|Fc fragment of IgG, high affinity Ia, receptor (CD64)|Fc fragment of IgG, high affinity Ia, receptor for (CD64)|Fc gamma receptor Ia|Fc-gamma RI|Fc-gamma receptor I A1|IgG Fc receptor I|fc-gamma RIA|fcgammaRIa', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149782694, end_position_on_the_genomic_accession=149800609, orientation='plus', exon_count=8, OMIM=[146760], no_hdr0=''),
    2212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2212, CurrentID=0, Status='live', Symbol='FCGR2A', Aliases=['CD32', 'CD32A', 'CDw32', 'FCG2', 'FCGR21', 'FcGR', 'IGFR2', 'FCGR2A'], description='Fc fragment of IgG receptor IIa', other_designations='low affinity immunoglobulin gamma Fc region receptor II-a|Fc fragment of IgG, low affinity IIa, receptor (CD32)|Fc gamma receptor RIIa3|Immunoglobulin G Fc receptor II|fc-gamma-RIIa|fcRII-a|igG Fc receptor II-a', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161505430, end_position_on_the_genomic_accession=161524048, orientation='plus', exon_count=12, OMIM=[146790], no_hdr0=''),
    2213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2213, CurrentID=0, Status='live', Symbol='FCGR2B', Aliases=['CD32', 'CD32B', 'FCG2', 'FCGR2', 'FCGR2C', 'FcRII-c', 'IGFR2'], description='Fc fragment of IgG receptor IIb', other_designations='low affinity immunoglobulin gamma Fc region receptor II-b|CDw32|Fc fragment of IgG, low affinity II, receptor for (CD32)|Fc fragment of IgG, low affinity IIb, receptor (CD32)|Fc fragment of IgG, low affinity IIb, receptor for (CD32)|Fc gamma RIIb|Fc gamma receptor IIb|Fc-gamma RII-c|Fc-gamma-RIIc|IgG Fc receptor II-c|Low affinity immunoglobulin gamma Fc region receptor II-c|fc-gamma RII-b|fc-gamma-RIIb|fcRII-b|igG Fc receptor II-b', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161647243, end_position_on_the_genomic_accession=161678654, orientation='plus', exon_count=11, OMIM=[604590], no_hdr0=''),
    2214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2214, CurrentID=0, Status='live', Symbol='FCGR3A', Aliases=['CD16', 'CD16A', 'FCG3', 'FCGR3', 'FCGRIII', 'FCR-10', 'FCRIII', 'FCRIIIA', 'IGFR3', 'IMD20'], description='Fc fragment of IgG receptor IIIa', other_designations='low affinity immunoglobulin gamma Fc region receptor III-A|CD16a antigen|Fc fragment of IgG, low affinity III, receptor for (CD16)|Fc fragment of IgG, low affinity IIIa, receptor (CD16a)|Fc gamma receptor III-A|Fc-gamma RIII-alpha|Fc-gamma receptor III-2 (CD 16)|Fc-gamma receptor IIIb (CD16)|FcgammaRIIIA|igG Fc receptor III-2|immunoglobulin G Fc receptor III|low affinity immunoglobulin gamma receptor III-a Fc fragment|neutrophil-specific antigen NA', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161541759, end_position_on_the_genomic_accession=161550737, orientation='minus', exon_count=7, OMIM=[146740], no_hdr0=''),
    2215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2215, CurrentID=0, Status='live', Symbol='FCGR3B', Aliases=['CD16', 'CD16A', 'CD16b', 'FCG3', 'FCGR3', 'FCGR3A', 'FCR-10', 'FCRIII', 'FCRIIIb'], description='Fc fragment of IgG receptor IIIb', other_designations='low affinity immunoglobulin gamma Fc region receptor III-B|Fc fragment of IgG, low affinity IIIb, receptor (CD16b)|Fc gamma receptor III-B|Fc gamma receptor IIIb|Fc-gamma receptor IIIb (CD 16)|fc-gamma RIII-beta|fc-gamma RIIIb|igG Fc receptor III-1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161623196, end_position_on_the_genomic_accession=161631963, orientation='minus', exon_count=7, OMIM=[610665], no_hdr0=''),
    2217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2217, CurrentID=0, Status='live', Symbol='FCGRT', Aliases=['FCRN', 'alpha-chain'], description='Fc fragment of IgG receptor and transporter', other_designations='IgG receptor FcRn large subunit p51|Fc fragment of IgG, receptor, transporter, alpha|FcRn alpha chain|IgG Fc fragment receptor transporter alpha chain|heavy chain of the major histocompatibility complex class I-like Fc receptor|immunoglobulin receptor, intestinal, heavy chain|major histocompatibility complex class I-like Fc receptor|neonatal Fc receptor|neonatal Fc-receptor for Ig|transmembrane alpha chain of the neonatal receptor', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49512661, end_position_on_the_genomic_accession=49526428, orientation='plus', exon_count=7, OMIM=[601437], no_hdr0=''),
    2218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2218, CurrentID=0, Status='live', Symbol='FKTN', Aliases=['CMD1X', 'FCMD', 'LGMD2M', 'LGMDR13', 'MDDGA4', 'MDDGB4', 'MDDGC4'], description='fukutin', other_designations='fukutin|Fukuyama type congenital muscular dystrophy protein|patient fukutin|ribitol-5-phosphate transferase', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=105558117, end_position_on_the_genomic_accession=105655950, orientation='plus', exon_count=27, OMIM=[607440], no_hdr0=''),
    2219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2219, CurrentID=0, Status='live', Symbol='FCN1', Aliases=['FCNM'], description='ficolin 1', other_designations='ficolin-1|M-ficolin|ficolin (collagen/fibrinogen domain-containing) 1|ficolin-A|ficolin-alpha', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134903232, end_position_on_the_genomic_accession=134917912, orientation='minus', exon_count=9, OMIM=[601252], no_hdr0=''),
    2220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2220, CurrentID=0, Status='live', Symbol='FCN2', Aliases=['EBP-37', 'FCNL', 'P35', 'ficolin-2'], description='ficolin 2', other_designations='ficolin-2|37 kDa elastin-binding protein|L-ficolin|collagen/fibrinogen domain-containing protein 2|ficolin (collagen/fibrinogen domain containing lectin) 2 (hucolin)|ficolin B|ficolin-beta|serum lectin p35', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134864062, end_position_on_the_genomic_accession=134890506, orientation='plus', exon_count=9, OMIM=[601624], no_hdr0=''),
    2222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2222, CurrentID=0, Status='live', Symbol='FDFT1', Aliases=['DGPT', 'ERG9', 'SQS', 'SQSD', 'SS'], description='farnesyl-diphosphate farnesyltransferase 1', other_designations='squalene synthase|FPP:FPP farnesyltransferase|presqualene-di-diphosphate synthase|squalene synthetase', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11795582, end_position_on_the_genomic_accession=11839309, orientation='plus', exon_count=14, OMIM=[184420], no_hdr0=''),
    2224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2224, CurrentID=0, Status='live', Symbol='FDPS', Aliases=['FPPS', 'FPS', 'POROK9'], description='farnesyl diphosphate synthase', other_designations='farnesyl pyrophosphate synthase|(2E,6E)-farnesyl diphosphate synthase|FPP synthase|FPP synthetase|farnesyl pyrophosphate synthetase, dimethylallyltranstransferase, geranyltranstransferase', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155308801, end_position_on_the_genomic_accession=155320665, orientation='plus', exon_count=10, OMIM=[134629], no_hdr0=''),
    2230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2230, CurrentID=0, Status='live', Symbol='FDX1', Aliases=['ADX', 'FDX', 'LOH11CR1D'], description='ferredoxin 1', other_designations='adrenodoxin, mitochondrial|adrenal ferredoxin|hepatoredoxin|mitochondrial adrenodoxin', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=110429948, end_position_on_the_genomic_accession=110464884, orientation='plus', exon_count=4, OMIM=[103260], no_hdr0=''),
    2232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2232, CurrentID=0, Status='live', Symbol='FDXR', Aliases=['ADR', 'ADXR', 'ANOA'], description='ferredoxin reductase', other_designations='NADPH:adrenodoxin oxidoreductase, mitochondrial|AR|adrenodoxin reductase|adrenodoxin-NADP(+) reductase|epididymis secretory sperm binding protein|ferredoxin--NADP(+) reductase', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74862497, end_position_on_the_genomic_accession=74872994, orientation='minus', exon_count=14, OMIM=[103270], no_hdr0=''),
    2235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2235, CurrentID=0, Status='live', Symbol='FECH', Aliases=['EPP', 'EPP1', 'FCE'], description='ferrochelatase', other_designations='ferrochelatase, mitochondrial|heme synthase|heme synthetase|protoheme ferro-lyase|protoporphyria', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57544377, end_position_on_the_genomic_accession=57586708, orientation='minus', exon_count=12, OMIM=[612386], no_hdr0=''),
    2237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2237, CurrentID=0, Status='live', Symbol='FEN1', Aliases=['FEN-1', 'MF1', 'RAD2'], description='flap structure-specific endonuclease 1', other_designations='flap endonuclease 1|DNase IV|maturation factor-1', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61792911, end_position_on_the_genomic_accession=61797238, orientation='plus', exon_count=2, OMIM=[600393], no_hdr0=''),
    2239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2239, CurrentID=0, Status='live', Symbol='GPC4', Aliases=['K-glypican', 'KPTS'], description='glypican 4', other_designations='glypican-4|dJ900E8.1 (glypican 4)|glypican proteoglycan 4', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=133300103, end_position_on_the_genomic_accession=133415489, orientation='minus', exon_count=9, OMIM=[300168], no_hdr0=''),
    2241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2241, CurrentID=0, Status='live', Symbol='FER', Aliases=['PPP1R74', 'TYK3', 'p94-Fer'], description='FER tyrosine kinase', other_designations='tyrosine-protein kinase Fer|feline encephalitis virus-related kinase FER|fer (fps/fes related) tyrosine kinase|fujinami poultry sarcoma/Feline sarcoma-related protein Fer|phosphoprotein NCP94|protein phosphatase 1, regulatory subunit 74|proto-oncogene c-Fer|tyrosine kinase 3', map_location='5q21.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=108746085, end_position_on_the_genomic_accession=109196841, orientation='plus', exon_count=30, OMIM=[176942], no_hdr0=''),
    2242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2242, CurrentID=0, Status='live', Symbol='FES', Aliases=['FPS'], description='FES proto-oncogene, tyrosine kinase', other_designations='tyrosine-protein kinase Fes/Fps|Oncogene FES, feline sarcoma virus|feline sarcoma (Snyder-Theilen) viral (v-fes)/Fujinami avian sarcoma (PRCII) viral (v-fps) oncogene homolog|feline sarcoma oncogene|feline sarcoma/Fujinami avian sarcoma oncogene homolog|p93c-fes|proto-oncogene c-Fes|proto-oncogene c-Fps|proto-oncogene tyrosine-protein kinase Fes/Fps', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90884421, end_position_on_the_genomic_accession=90895776, orientation='plus', exon_count=19, OMIM=[190030], no_hdr0=''),
    2243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2243, CurrentID=0, Status='live', Symbol='FGA', Aliases=['Fib2'], description='fibrinogen alpha chain', other_designations='fibrinogen alpha chain|fibrinogen, A alpha polypeptide', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154583126, end_position_on_the_genomic_accession=154590742, orientation='minus', exon_count=6, OMIM=[134820], no_hdr0=''),
    2244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2244, CurrentID=0, Status='live', Symbol='FGB', Aliases=['HEL-S-78p'], description='fibrinogen beta chain', other_designations='fibrinogen beta chain|beta-fibrinogen|epididymis secretory sperm binding protein Li 78p|fibrinogen, B beta polypeptide', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154562980, end_position_on_the_genomic_accession=154572807, orientation='plus', exon_count=8, OMIM=[134830], no_hdr0=''),
    2245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2245, CurrentID=0, Status='live', Symbol='FGD1', Aliases=['AAS', 'FGDY', 'MRXS16', 'ZFYVE3'], description='FYVE, RhoGEF and PH domain containing 1', other_designations='FYVE, RhoGEF and PH domain-containing protein 1|faciogenital dysplasia 1 protein|rho/Rac GEF|rho/Rac guanine nucleotide exchange factor FGD1|zinc finger FYVE domain-containing protein 3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54445454, end_position_on_the_genomic_accession=54496234, orientation='minus', exon_count=18, OMIM=[300546], no_hdr0=''),
    2246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2246, CurrentID=0, Status='live', Symbol='FGF1', Aliases=['AFGF', 'ECGF', 'ECGF-beta', 'ECGFA', 'ECGFB', 'FGF-1', 'FGF-alpha', 'FGFA', 'GLIO703', 'HBGF-1', 'HBGF1'], description='fibroblast growth factor 1', other_designations='fibroblast growth factor 1|beta-endothelial cell growth factor|endothelial cell growth factor, alpha|endothelial cell growth factor, beta|fibroblast growth factor 1 (acidic)|heparin-binding growth factor 1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=142592178, end_position_on_the_genomic_accession=142698070, orientation='minus', exon_count=11, OMIM=[131220], no_hdr0=''),
    2247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2247, CurrentID=0, Status='live', Symbol='FGF2', Aliases=['BFGF', 'FGF-2', 'FGFB', 'HBGF-2'], description='fibroblast growth factor 2', other_designations='fibroblast growth factor 2|basic fibroblast growth factor bFGF|fibroblast growth factor 2 (basic)|heparin-binding growth factor 2|prostatropin', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122826708, end_position_on_the_genomic_accession=122898236, orientation='plus', exon_count=3, OMIM=[134920], no_hdr0=''),
    2248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2248, CurrentID=0, Status='live', Symbol='FGF3', Aliases=['HBGF-3', 'INT2'], description='fibroblast growth factor 3', other_designations='fibroblast growth factor 3|FGF-3|INT-2 proto-oncogene protein|V-INT2 murine mammary tumor virus integration site oncogene homolog|fibroblast growth factor 3 (murine mammary tumor virus integration site (v-int-2) oncogene homolog)|heparin-binding growth factor 3|murine mammary tumor virus integration site 2, mouse|oncogene INT2|proto-oncogene Int-2', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69809968, end_position_on_the_genomic_accession=69819416, orientation='minus', exon_count=3, OMIM=[164950], no_hdr0=''),
    2249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2249, CurrentID=0, Status='live', Symbol='FGF4', Aliases=['FGF-4', 'HBGF-4', 'HST', 'HST-1', 'HSTF-1', 'HSTF1', 'K-FGF', 'KFGF'], description='fibroblast growth factor 4', other_designations='fibroblast growth factor 4|heparin secretory transforming protein 1|heparin-binding growth factor 4|human stomach cancer, transforming factor from FGF-related oncogene|kaposi sarcoma oncogene|oncogene HST|transforming protein KS3', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69771022, end_position_on_the_genomic_accession=69775341, orientation='minus', exon_count=3, OMIM=[164980], no_hdr0=''),
    2250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2250, CurrentID=0, Status='live', Symbol='FGF5', Aliases=['HBGF-5', 'Smag-82', 'TCMGLY'], description='fibroblast growth factor 5', other_designations='fibroblast growth factor 5|heparin-binding growth factor 5', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=80266588, end_position_on_the_genomic_accession=80291017, orientation='plus', exon_count=4, OMIM=[165190], no_hdr0=''),
    2251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2251, CurrentID=0, Status='live', Symbol='FGF6', Aliases=['HBGF-6', 'HST2'], description='fibroblast growth factor 6', other_designations='fibroblast growth factor 6|FGF-6|HST-2|HSTF-2|heparin secretory-transforming protein 2|heparin-binding growth factor 6', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4434142, end_position_on_the_genomic_accession=4445815, orientation='minus', exon_count=5, OMIM=[134921], no_hdr0=''),
    2252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2252, CurrentID=0, Status='live', Symbol='FGF7', Aliases=['HBGF-7', 'KGF'], description='fibroblast growth factor 7', other_designations='fibroblast growth factor 7|FGF-7|heparin-binding growth factor 7|keratinocyte growth factor', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49423242, end_position_on_the_genomic_accession=49488775, orientation='plus', exon_count=4, OMIM=[148180], no_hdr0=''),
    2253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2253, CurrentID=0, Status='live', Symbol='FGF8', Aliases=['AIGF', 'FGF-8', 'HBGF-8', 'HH6', 'KAL6'], description='fibroblast growth factor 8', other_designations='fibroblast growth factor 8|androgen-induced growth factor|fibroblast growth factor 8 (androgen-induced)|heparin-binding growth factor 8', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101770109, end_position_on_the_genomic_accession=101780369, orientation='minus', exon_count=7, OMIM=[600483], no_hdr0=''),
    2254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2254, CurrentID=0, Status='live', Symbol='FGF9', Aliases=['FGF-9', 'GAF', 'HBFG-9', 'HBGF-9', 'SYNS3'], description='fibroblast growth factor 9', other_designations='fibroblast growth factor 9|fibroblast growth factor 9 (glia-activating factor)|heparin-binding growth factor 9', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21671073, end_position_on_the_genomic_accession=21704501, orientation='plus', exon_count=4, OMIM=[600921], no_hdr0=''),
    2255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2255, CurrentID=0, Status='live', Symbol='FGF10', Aliases=[], description='fibroblast growth factor 10', other_designations='fibroblast growth factor 10|FGF-10|keratinocyte growth factor 2|produced by fibroblasts of urinary bladder lamina propria', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=44300247, end_position_on_the_genomic_accession=44389706, orientation='minus', exon_count=3, OMIM=[602115], no_hdr0=''),
    2256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2256, CurrentID=0, Status='live', Symbol='FGF11', Aliases=['FGF-11', 'FHF-3', 'FHF3'], description='fibroblast growth factor 11', other_designations='fibroblast growth factor 11|fibroblast growth factor homologous factor 3', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7438298, end_position_on_the_genomic_accession=7444937, orientation='plus', exon_count=7, OMIM=[601514], no_hdr0=''),
    2257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2257, CurrentID=0, Status='live', Symbol='FGF12', Aliases=['DEE47', 'EIEE47B', 'FHF1', 'FGF12'], description='fibroblast growth factor 12', other_designations='fibroblast growth factor 12|fibroblast growth factor 12B|fibroblast growth factor FGF-12b|fibroblast growth factor homologous factor 1|myocyte-activating factor', map_location='3q28-q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=192139390, end_position_on_the_genomic_accession=192727541, orientation='minus', exon_count=10, OMIM=[601513], no_hdr0=''),
    2258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2258, CurrentID=0, Status='live', Symbol='FGF13', Aliases=['DEE90', 'FGF-13', 'FGF2', 'FHF-2', 'FHF2', 'LINC00889'], description='fibroblast growth factor 13', other_designations='fibroblast growth factor 13|fibroblast growth factor homologous factor 2', map_location='Xq26.3-q27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=138614727, end_position_on_the_genomic_accession=139222889, orientation='minus', exon_count=13, OMIM=[300070], no_hdr0=''),
    2259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2259, CurrentID=0, Status='live', Symbol='FGF14', Aliases=['FGF-14', 'FHF-4', 'FHF4', 'SCA27'], description='fibroblast growth factor 14', other_designations='fibroblast growth factor 14|fibroblast growth factor homologous factor 4', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=101710804, end_position_on_the_genomic_accession=102402443, orientation='minus', exon_count=16, OMIM=[601515], no_hdr0=''),
    2260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2260, CurrentID=0, Status='live', Symbol='FGFR1', Aliases=['BFGFR', 'CD331', 'CEK', 'ECCL', 'FGFBR', 'FGFR-1', 'FLG', 'FLT-2', 'FLT2', 'HBGFR', 'HH2', 'HRTFDS', 'KAL2', 'N-SAM', 'OGD', 'bFGF-R-1'], description='fibroblast growth factor receptor 1', other_designations='fibroblast growth factor receptor 1|FGFR1/PLAG1 fusion|FMS-like tyrosine kinase 2|basic fibroblast growth factor receptor 1|fms-related tyrosine kinase 2|heparin-binding growth factor receptor|hydroxyaryl-protein kinase|proto-oncogene c-Fgr', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38411143, end_position_on_the_genomic_accession=38468635, orientation='minus', exon_count=24, OMIM=[136350], no_hdr0=''),
    2261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2261, CurrentID=0, Status='live', Symbol='FGFR3', Aliases=['ACH', 'CD333', 'CEK2', 'HSFGFR3EX', 'JTK4'], description='fibroblast growth factor receptor 3', other_designations='fibroblast growth factor receptor 3|FGFR-3|fibroblast growth factor receptor 3 variant 4|fibroblast growth factor receptor 3-S|hydroxyaryl-protein kinase|tyrosine kinase JTK4', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1793293, end_position_on_the_genomic_accession=1808872, orientation='plus', exon_count=19, OMIM=[134934], no_hdr0=''),
    2262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2262, CurrentID=0, Status='live', Symbol='GPC5', Aliases=[], description='glypican 5', other_designations='glypican-5|bA93M14.1|glypican proteoglycan 5', map_location='13q31.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=91398621, end_position_on_the_genomic_accession=92867237, orientation='plus', exon_count=14, OMIM=[602446], no_hdr0=''),
    2263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2263, CurrentID=0, Status='live', Symbol='FGFR2', Aliases=['BBDS', 'BEK', 'BFR-1', 'CD332', 'CEK3', 'CFD1', 'ECT1', 'JWS', 'K-SAM', 'KGFR', 'TK14', 'TK25'], description='fibroblast growth factor receptor 2', other_designations='fibroblast growth factor receptor 2|BEK fibroblast growth factor receptor|bacteria-expressed kinase|keratinocyte growth factor receptor|protein tyrosine kinase, receptor like 14', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=121478330, end_position_on_the_genomic_accession=121598458, orientation='minus', exon_count=24, OMIM=[176943], no_hdr0=''),
    2264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2264, CurrentID=0, Status='live', Symbol='FGFR4', Aliases=['CD334', 'JTK2', 'TKF'], description='fibroblast growth factor receptor 4', other_designations='fibroblast growth factor receptor 4|hydroxyaryl-protein kinase|protein-tyrosine kinase|tyrosine kinase related to fibroblast growth factor receptor|tyrosylprotein kinase', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177086915, end_position_on_the_genomic_accession=177098144, orientation='plus', exon_count=18, OMIM=[134935], no_hdr0=''),
    2266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2266, CurrentID=0, Status='live', Symbol='FGG', Aliases=[], description='fibrinogen gamma chain', other_designations='fibrinogen gamma chain|fibrinogen, gamma polypeptide|testicular tissue protein Li 70', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154604136, end_position_on_the_genomic_accession=154612656, orientation='minus', exon_count=10, OMIM=[134850], no_hdr0=''),
    2267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2267, CurrentID=0, Status='live', Symbol='FGL1', Aliases=['HFREP1', 'HP-041', 'HPS', 'LFIRE-1', 'LFIRE1'], description='fibrinogen like 1', other_designations='fibrinogen-like protein 1|hepassocin|hepatocellular carcinoma-related sequence|hepatocyte-derived fibrinogen-related protein 1|liver fibrinogen-related protein 1', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17864380, end_position_on_the_genomic_accession=17909983, orientation='minus', exon_count=11, OMIM=[605776], no_hdr0=''),
    2268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2268, CurrentID=0, Status='live', Symbol='FGR', Aliases=['SRC2', 'c-fgr', 'c-src2', 'p55-Fgr', 'p55c-fgr', 'p58-Fgr', 'p58c-fgr'], description='FGR proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Fgr|Gardner-Rasheed feline sarcoma viral (v-fgr) oncogene homolog|c-fgr protooncogene|c-src-2 proto-oncogene|feline Gardner-Rasheed sarcoma viral oncogene homolog|p55-c-fgr protein|proto-oncogene c-Fgr|proto-oncogene tyrosine-protein kinase FGR|v-fgr feline Gardner-Rasheed sarcoma viral oncogene homolog', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27612064, end_position_on_the_genomic_accession=27635561, orientation='minus', exon_count=18, OMIM=[164940], no_hdr0=''),
    2271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2271, CurrentID=0, Status='live', Symbol='FH', Aliases=['FMRD', 'HLRCC', 'HsFH', 'LRCC', 'MCL', 'MCUL1'], description='fumarate hydratase', other_designations='fumarate hydratase, mitochondrial|epididymis secretory sperm binding protein|fumarase', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241497603, end_position_on_the_genomic_accession=241519755, orientation='minus', exon_count=10, OMIM=[136850], no_hdr0=''),
    2272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2272, CurrentID=0, Status='live', Symbol='FHIT', Aliases=['AP3Aase', 'FRA3B'], description='fragile histidine triad diadenosine triphosphatase', other_designations="bis(5'-adenosyl)-triphosphatase|AP3A hydrolase|diadenosine 5',5'''-P1,P3-triphosphate hydrolase|dinucleosidetriphosphatase", map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=59747277, end_position_on_the_genomic_accession=61251452, orientation='minus', exon_count=17, OMIM=[601153], no_hdr0=''),
    2273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2273, CurrentID=0, Status='live', Symbol='FHL1', Aliases=['FCMSU', 'FHL-1A', 'FHL1B', 'FLH1A', 'KYOT', 'RBMX1A', 'RBMX1B', 'SLIM', 'SLIM-1', 'SLIM1', 'SLIMMER', 'XMPMA', 'FHL1'], description='four and a half LIM domains 1', other_designations='four and a half LIM domains protein 1|LIM protein SLIMMER|four-and-a-half Lin11, Isl-1 and Mec-3 domains 1|skeletal muscle LIM-protein 1', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136146702, end_position_on_the_genomic_accession=136211359, orientation='plus', exon_count=17, OMIM=[300163], no_hdr0=''),
    2274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2274, CurrentID=0, Status='live', Symbol='FHL2', Aliases=['AAG11', 'DRAL', 'FHL-2', 'SLIM-3', 'SLIM3'], description='four and a half LIM domains 2', other_designations='four and a half LIM domains protein 2|LIM domain protein DRAL|aging-associated gene 11|down-regulated in rhabdomyosarcoma LIM protein|skeletal muscle LIM-protein 3', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105357712, end_position_on_the_genomic_accession=105438529, orientation='minus', exon_count=11, OMIM=[602633], no_hdr0=''),
    2275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2275, CurrentID=0, Status='live', Symbol='FHL3', Aliases=['SLIM2'], description='four and a half LIM domains 3', other_designations='four and a half LIM domains protein 3|FHL-3|LIM-only protein FHL3|SLIM-2|skeletal muscle LIM-protein 2', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37996765, end_position_on_the_genomic_accession=38005691, orientation='minus', exon_count=8, OMIM=[602790], no_hdr0=''),
    2277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2277, CurrentID=0, Status='live', Symbol='VEGFD', Aliases=['FIGF', 'VEGF-D'], description='vascular endothelial growth factor D', other_designations='vascular endothelial growth factor D|c-fos induced growth factor (vascular endothelial growth factor D)', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15345596, end_position_on_the_genomic_accession=15384413, orientation='minus', exon_count=7, OMIM=[300091], no_hdr0=''),
    2280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2280, CurrentID=0, Status='live', Symbol='FKBP1A', Aliases=['FKBP-12', 'FKBP-1A', 'FKBP1', 'FKBP12', 'PKC12', 'PKCI2', 'PPIASE'], description='FKBP prolyl isomerase 1A', other_designations='peptidyl-prolyl cis-trans isomerase FKBP1A|12 kDa FK506-binding protein|12 kDa FKBP|FK506 binding protein 1A, 12kDa|FK506 binding protein12|FK506-binding protein 1|FK506-binding protein 12|FK506-binding protein 1A|FK506-binding protein, T-cell, 12-kD|FKBP12-Exip3|PPIase FKBP1A|calstabin-1|immunophilin FKBP12|protein kinase C inhibitor 2|rotamase', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1368977, end_position_on_the_genomic_accession=1393172, orientation='minus', exon_count=5, OMIM=[186945], no_hdr0=''),
    2281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2281, CurrentID=0, Status='live', Symbol='FKBP1B', Aliases=['FKBP12.6', 'FKBP1L', 'OTK4', 'PKBP1L', 'PPIase'], description='FKBP prolyl isomerase 1B', other_designations='peptidyl-prolyl cis-trans isomerase FKBP1B|12.6 kDa FK506-binding protein|12.6 kDa FKBP|FK506 binding protein 1B, 12.6 kDa|FK506-binding protein 12.6|FK506-binding protein 1B|FKBP-12.6|FKBP-1B|PPIase FKBP1B|calstabin 2|h-FKBP-12|immunophilin FKBP12.6|rotamase', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24033205, end_position_on_the_genomic_accession=24067743, orientation='plus', exon_count=9, OMIM=[600620], no_hdr0=''),
    2286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2286, CurrentID=0, Status='live', Symbol='FKBP2', Aliases=['FKBP-13', 'FKBP13', 'PPIase'], description='FKBP prolyl isomerase 2', other_designations='peptidyl-prolyl cis-trans isomerase FKBP2|13 kDa FK506-binding protein|13 kDa FKBP|FK506 binding protein 2, 13kDa|FK506-binding protein 2|PPIase FKBP2|epididymis secretory sperm binding protein|immunophilin FKBP13|proline isomerase|rapamycin-binding protein|rotamase', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64241095, end_position_on_the_genomic_accession=64244135, orientation='plus', exon_count=9, OMIM=[186946], no_hdr0=''),
    2287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2287, CurrentID=0, Status='live', Symbol='FKBP3', Aliases=['FKBP-25', 'FKBP-3', 'FKBP25', 'PPIase'], description='FKBP prolyl isomerase 3', other_designations='peptidyl-prolyl cis-trans isomerase FKBP3|25 kDa FK506-binding protein|25 kDa FKBP|FK506 binding protein 3, 25kDa|FK506-binding protein 25, T-cell|FK506-binding protein 3|PPIase FKBP3|immunophilin FKBP25|rapamycin binding protein|rapamycin-selective 25 kDa immunophilin|rotamase', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=45115292, end_position_on_the_genomic_accession=45134481, orientation='minus', exon_count=7, OMIM=[186947], no_hdr0=''),
    2288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2288, CurrentID=0, Status='live', Symbol='FKBP4', Aliases=['FKBP51', 'FKBP52', 'FKBP59', 'HBI', 'Hsp56', 'PPIase', 'p52'], description='FKBP prolyl isomerase 4', other_designations='peptidyl-prolyl cis-trans isomerase FKBP4|FK506 binding protein 4, 59kDa|HSP binding immunophilin|T-cell FK506-binding protein, 59kD|peptidylprolyl cis-trans isomerase|rotamase', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2794970, end_position_on_the_genomic_accession=2805423, orientation='plus', exon_count=11, OMIM=[600611], no_hdr0=''),
    2289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2289, CurrentID=0, Status='live', Symbol='FKBP5', Aliases=['AIG61', 'FKBP54', 'P54', 'PPIase', 'Ptg-10', 'FKBP5'], description='FKBP prolyl isomerase 5', other_designations='peptidyl-prolyl cis-trans isomerase FKBP5|51 kDa FK506-binding protein|51 kDa FKBP|54 kDa progesterone receptor-associated immunophilin|FF1 antigen|FK506 binding protein 5|FKBP-51|HSP90-binding immunophilin|PPIase FKBP5|T-cell FK506-binding protein|androgen-regulated protein 6|peptidylprolyl cis-trans isomerase|rotamase', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35573590, end_position_on_the_genomic_accession=35728583, orientation='minus', exon_count=13, OMIM=[602623], no_hdr0=''),
    2290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2290, CurrentID=0, Status='live', Symbol='FOXG1', Aliases=['BF1', 'BF2', 'FHKL3', 'FKH2', 'FKHL1', 'FKHL2', 'FKHL3', 'FKHL4A', 'FOXG1B', 'FOXG1C', 'HBF-1', 'HBF-2', 'HBF-3', 'HBF-G2', 'HBF2', 'HFK1', 'HFK2', 'HFK3', 'KHL2', 'QIN', 'FOXG1'], description='forkhead box G1', other_designations='forkhead box protein G1|brain factor 1|brain factor 2|forkhead-like 1|forkhead-like 2|forkhead-like 3|forkhead-like 4|oncogene QIN', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=28766787, end_position_on_the_genomic_accession=28770277, orientation='plus', exon_count=1, OMIM=[164874], no_hdr0=''),
    2294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2294, CurrentID=0, Status='live', Symbol='FOXF1', Aliases=['ACDMPV', 'FKHL5', 'FREAC1'], description='forkhead box F1', other_designations='forkhead box protein F1|FREAC-1|Forkhead, drosophila, homolog-like 5|forkhead-related activator 1|forkhead-related protein FKHL5|forkhead-related transcription factor 1', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=86510527, end_position_on_the_genomic_accession=86515422, orientation='plus', exon_count=2, OMIM=[601089], no_hdr0=''),
    2295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2295, CurrentID=0, Status='live', Symbol='FOXF2', Aliases=['FKHL6', 'FREAC-2', 'FREAC2'], description='forkhead box F2', other_designations='forkhead box protein F2|forkhead-like 6|forkhead-related activator 2|forkhead-related protein FKHL6|forkhead-related transcription factor 2', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=1389576, end_position_on_the_genomic_accession=1395603, orientation='plus', exon_count=2, OMIM=[603250], no_hdr0=''),
    2296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2296, CurrentID=0, Status='live', Symbol='FOXC1', Aliases=['ARA', 'ASGD3', 'FKHL7', 'FREAC-3', 'FREAC3', 'IGDA', 'IHG1', 'IRID1', 'RIEG3'], description='forkhead box C1', other_designations='forkhead box protein C1|forkhead box C1 protein|forkhead, drosophila, homolog-like 7|forkhead-related activator 3|forkhead-related protein FKHL7|forkhead-related transcription factor 3|forkhead/winged helix-like transcription factor 7|myeloid factor-delta', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=1609915, end_position_on_the_genomic_accession=1613897, orientation='plus', exon_count=1, OMIM=[601090], no_hdr0=''),
    2297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2297, CurrentID=0, Status='live', Symbol='FOXD1', Aliases=['FKHL8', 'FREAC-4', 'FREAC4'], description='forkhead box D1', other_designations='forkhead box protein D1|Forkhead, drosophila, homolog-like 8|forkhead-like 8|forkhead-related activator 4|forkhead-related protein FKHL8|forkhead-related transcription factor 4', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73446266, end_position_on_the_genomic_accession=73448777, orientation='minus', exon_count=1, OMIM=[601091], no_hdr0=''),
    2298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2298, CurrentID=0, Status='live', Symbol='FOXD4', Aliases=['FKHL9A', 'FREAC-5', 'FREAC5', 'FOXD4'], description='forkhead box D4', other_designations='forkhead box protein D4|forkhead, Drosophila, homolog-like 9|forkhead-related activator 5|forkhead-related protein FKHL9|forkhead-related transcription factor 5|myeloid factor-alpha', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=116231, end_position_on_the_genomic_accession=118417, orientation='minus', exon_count=1, OMIM=[601092], no_hdr0=''),
    2299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2299, CurrentID=0, Status='live', Symbol='FOXI1', Aliases=['FKH10', 'FKHL10', 'FREAC-6', 'FREAC6', 'HFH-3', 'HFH3'], description='forkhead box I1', other_designations='forkhead box protein I1|HNF-3/fork-head homolog-3|forkhead-like 10|forkhead-related activator 6|forkhead-related protein FKHL10|forkhead-related transcription factor 6|hepatocyte nuclear factor 3 forkhead homolog 3', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170105897, end_position_on_the_genomic_accession=170109737, orientation='plus', exon_count=4, OMIM=[601093], no_hdr0=''),
    2300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2300, CurrentID=0, Status='live', Symbol='FOXL1', Aliases=['FKH6', 'FKHL11', 'FREAC7'], description='forkhead box L1', other_designations='forkhead box protein L1|forkhead-like 11|forkhead-related protein FKHL11|forkhead-related transcription factor 7', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=86578549, end_position_on_the_genomic_accession=86583478, orientation='plus', exon_count=1, OMIM=[603252], no_hdr0=''),
    2301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2301, CurrentID=0, Status='live', Symbol='FOXE3', Aliases=['AAT11', 'ASGD2', 'CTRCT34', 'FKHL12', 'FREAC8'], description='forkhead box E3', other_designations='forkhead box protein E3|FREAC-8|forkhead, drosophila, homolog-like 12|forkhead-related protein FKHL12|forkhead-related transcription factor 8', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47416285, end_position_on_the_genomic_accession=47418052, orientation='plus', exon_count=1, OMIM=[601094], no_hdr0=''),
    2302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2302, CurrentID=0, Status='live', Symbol='FOXJ1', Aliases=['CILD43', 'FKHL13', 'HFH-4', 'HFH4'], description='forkhead box J1', other_designations='forkhead box protein J1|fork head homologue 4|forkhead transcription factor HFH-4|forkhead-like 13|forkhead-related protein FKHL13|hepatocyte nuclear factor 3 forkhead homolog 4', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76136333, end_position_on_the_genomic_accession=76141245, orientation='minus', exon_count=3, OMIM=[602291], no_hdr0=''),
    2303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2303, CurrentID=0, Status='live', Symbol='FOXC2', Aliases=['FKHL14', 'LD', 'MFH-1', 'MFH1'], description='forkhead box C2', other_designations='forkhead box protein C2|MFH-1,mesenchyme forkhead 1|forkhead box C2 (MFH-1, mesenchyme forkhead 1)|forkhead, Drosophila, homolog-like 14|forkhead-related protein FKHL14|mesenchyme fork head protein 1|mesenchyme forkhead 1|transcription factor FKH-14', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=86566829, end_position_on_the_genomic_accession=86569728, orientation='plus', exon_count=1, OMIM=[602402], no_hdr0=''),
    2304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2304, CurrentID=0, Status='live', Symbol='FOXE1', Aliases=['FKHL15', 'FOXE2', 'HFKH4', 'HFKL5', 'NMTC4', 'TITF2', 'TTF-2', 'TTF2'], description='forkhead box E1', other_designations='forkhead box protein E1|HNF-3/fork head-like protein 5|forkhead box protein E2|forkhead, drosophila, homolog-like 15|forkhead-related protein FKHL15|thyroid transcription factor 2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97853226, end_position_on_the_genomic_accession=97856717, orientation='plus', exon_count=1, OMIM=[602617], no_hdr0=''),
    2305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2305, CurrentID=0, Status='live', Symbol='FOXM1', Aliases=['FKHL16A', 'FOXM1B', 'FOXM1C', 'HFH-11', 'HFH11', 'HNF-3', 'INS-1', 'MPHOSPH2', 'MPP-2', 'MPP2', 'PIG29', 'TRIDENT', 'FOXM1'], description='forkhead box M1', other_designations='forkhead box protein M1|Forkhead, drosophila, homolog-like 16|HNF-3/fork-head homolog 11|M-phase phosphoprotein 2|MPM-2 reactive phosphoprotein 2|forkhead box M1-D|forkhead-related protein FKHL16|hepatocyte nuclear factor 3 forkhead homolog 11|transcription factor Trident|winged-helix factor from INS-1 cells', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2857680, end_position_on_the_genomic_accession=2877174, orientation='minus', exon_count=11, OMIM=[602341], no_hdr0=''),
    2306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2306, CurrentID=0, Status='live', Symbol='FOXD2', Aliases=['FKHL17', 'FREAC-9', 'FREAC9'], description='forkhead box D2', other_designations='forkhead box protein D2|forkhead, drosophila, homolog-like 17|forkhead-like 17|forkhead-related activator 9|forkhead-related protein FKHL17|forkhead-related transcription factor 9', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47438044, end_position_on_the_genomic_accession=47440691, orientation='plus', exon_count=1, OMIM=[602211], no_hdr0=''),
    2307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2307, CurrentID=0, Status='live', Symbol='FOXS1', Aliases=['FKHL18', 'FREAC10'], description='forkhead box S1', other_designations='forkhead box protein S1|FREAC-10|forkhead-like 18 protein|forkhead-related activator 10|forkhead-related transcription factor 10|forkhead-related transcription factor FREAC-10', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31844303, end_position_on_the_genomic_accession=31845604, orientation='minus', exon_count=1, OMIM=[602939], no_hdr0=''),
    2308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2308, CurrentID=0, Status='live', Symbol='FOXO1', Aliases=['FKH1', 'FKHRA', 'FOXO1'], description='forkhead box O1', other_designations='forkhead box protein O1|forkhead box protein O1A|forkhead, Drosophila, homolog of, in rhabdomyosarcoma', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=40555667, end_position_on_the_genomic_accession=40666641, orientation='minus', exon_count=5, OMIM=[136533], no_hdr0=''),
    2309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2309, CurrentID=0, Status='live', Symbol='FOXO3', Aliases=['AF6q21', 'FKHRL1', 'FKHRL1P2', 'FOXO2A', 'FOXO3'], description='forkhead box O3', other_designations='forkhead box protein O3|FOXO3A-|forkhead box O3A|forkhead homolog (rhabdomyosarcoma) like 1|forkhead in rhabdomyosarcoma-like 1|forkhead, Drosophila, homolog of, in rhabdomyosarcoma-like 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108559825, end_position_on_the_genomic_accession=108684774, orientation='plus', exon_count=9, OMIM=[602681], no_hdr0=''),
    2310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2310, CurrentID=0, Status='live', Symbol='FOXO3B', Aliases=['FKHRL1P1', 'ZNF286C'], description='forkhead box O3B', other_designations='forkhead box protein O3B|forkhead box O3B (pseudogene)|forkhead(Drosophila) homolog (rhabdomyosarcoma) 1 like pseudogene 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18667629, end_position_on_the_genomic_accession=18682314, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    2312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2312, CurrentID=0, Status='live', Symbol='FLG', Aliases=['ATOD2'], description='filaggrin', other_designations='filaggrin|epidermal filaggrin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152302165, end_position_on_the_genomic_accession=152325239, orientation='minus', exon_count=3, OMIM=[135940], no_hdr0=''),
    2313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2313, CurrentID=0, Status='live', Symbol='FLI1', Aliases=['BDPLT21', 'EWSR2', 'SIC-1'], description='Fli-1 proto-oncogene, ETS transcription factor', other_designations='Friend leukemia integration 1 transcription factor|Ewing sarcoma breakpoint region 2|Friend leukemia virus integration 1|transcription factor ERGB', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128685263, end_position_on_the_genomic_accession=128813267, orientation='plus', exon_count=15, OMIM=[193067], no_hdr0=''),
    2314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2314, CurrentID=0, Status='live', Symbol='FLII', Aliases=['FLI', 'FLIL', 'Fli1'], description='FLII actin remodeling protein', other_designations='protein flightless-1 homolog|flightless I actin binding protein|flightless I homolog', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18244815, end_position_on_the_genomic_accession=18259022, orientation='minus', exon_count=30, OMIM=[600362], no_hdr0=''),
    2315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2315, CurrentID=0, Status='live', Symbol='MLANA', Aliases=['MART-1', 'MART1'], description='melan-A', other_designations='melanoma antigen recognized by T-cells 1|antigen LB39-AA|antigen SK29-AA|epididymis secretory sperm binding protein|protein Melan-A', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5890889, end_position_on_the_genomic_accession=5910606, orientation='plus', exon_count=5, OMIM=[605513], no_hdr0=''),
    2316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2316, CurrentID=0, Status='live', Symbol='FLNA', Aliases=['ABP-280', 'ABPX', 'CSBS', 'CVD1', 'FGS2', 'FLN', 'FLN-A', 'FLN1', 'FMD', 'MNS', 'NHBP', 'OPD', 'OPD1', 'OPD2', 'XLVD', 'XMVD'], description='filamin A', other_designations='filamin-A|actin binding protein 280|alpha-filamin|endothelial actin-binding protein|epididymis secretory sperm binding protein|filamin A, alpha|filamin-1|non-muscle filamin', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154348531, end_position_on_the_genomic_accession=154374634, orientation='minus', exon_count=48, OMIM=[300017], no_hdr0=''),
    2317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2317, CurrentID=0, Status='live', Symbol='FLNB', Aliases=['ABP-278', 'ABP-280', 'AOI', 'FH1', 'FLN-B', 'FLN1L', 'LRS1', 'SCT', 'TABP', 'TAP'], description='filamin B', other_designations='filamin-B|ABP-280 homolog|Larsen syndrome 1 (autosomal dominant)|actin binding protein 278|actin-binding-like protein|beta-filamin|filamin B, beta|filamin homolog 1|filamin-3|thyroid autoantigen', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58008422, end_position_on_the_genomic_accession=58172251, orientation='plus', exon_count=47, OMIM=[603381], no_hdr0=''),
    2318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2318, CurrentID=0, Status='live', Symbol='FLNC', Aliases=['ABP-280', 'ABP280A', 'ABPA', 'ABPL', 'CMH26', 'FLN2', 'MFM5', 'MPD4', 'RCM5'], description='filamin C', other_designations='filamin-C|ABP-280-like protein|ABP-L, gamma filamin|actin binding protein 280|filamin C, gamma|filamin-2|gamma filamin', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128830406, end_position_on_the_genomic_accession=128859272, orientation='plus', exon_count=48, OMIM=[102565], no_hdr0=''),
    2319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2319, CurrentID=0, Status='live', Symbol='FLOT2', Aliases=['ECS-1', 'ECS1', 'ESA', 'ESA1', 'M17S1'], description='flotillin 2', other_designations='flotillin-2|Flotillin 2 (epidermal surface antigen 1)|epidermal surface antigen|membrane component chromosome 17 surface marker 1|membrane component, chromosome 17, surface marker 1 (35kD protein identified by monoclonal antibody ECS-1)', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28879339, end_position_on_the_genomic_accession=28897733, orientation='minus', exon_count=13, OMIM=[131560], no_hdr0=''),
    2321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2321, CurrentID=0, Status='live', Symbol='FLT1', Aliases=['FLT', 'FLT-1', 'VEGFR-1', 'VEGFR1'], description='fms related receptor tyrosine kinase 1', other_designations='vascular endothelial growth factor receptor 1|fms related tyrosine kinase 1|fms-like tyrosine kinase 1|fms-related tyrosine kinase 1 (vascular endothelial growth factor/vascular permeability factor receptor)|tyrosine-protein kinase FRT|tyrosine-protein kinase receptor FLT|vascular permeability factor receptor', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28300346, end_position_on_the_genomic_accession=28495128, orientation='minus', exon_count=33, OMIM=[165070], no_hdr0=''),
    2322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2322, CurrentID=0, Status='live', Symbol='FLT3', Aliases=['CD135', 'FLK-2', 'FLK2', 'STK1'], description='fms related receptor tyrosine kinase 3', other_designations='receptor-type tyrosine-protein kinase FLT3|CD135 antigen|FL cytokine receptor|fetal liver kinase 2|fms related tyrosine kinase 3|fms-like tyrosine kinase 3|growth factor receptor tyrosine kinase type III|stem cell tyrosine kinase 1', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28003274, end_position_on_the_genomic_accession=28100587, orientation='minus', exon_count=27, OMIM=[136351], no_hdr0=''),
    2323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2323, CurrentID=0, Status='live', Symbol='FLT3LG', Aliases=['FL', 'FLG3L', 'FLT3L'], description='fms related receptor tyrosine kinase 3 ligand', other_designations='fms-related tyrosine kinase 3 ligand|flt3 ligand|fms related tyrosine kinase 3 ligand', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49474172, end_position_on_the_genomic_accession=49487037, orientation='plus', exon_count=12, OMIM=[600007], no_hdr0=''),
    2324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2324, CurrentID=0, Status='live', Symbol='FLT4', Aliases=['CHTD7', 'FLT-41', 'LMPH1A', 'LMPHM1', 'PCL', 'VEGFR-3', 'VEGFR3', 'FLT4'], description='fms related receptor tyrosine kinase 4', other_designations='vascular endothelial growth factor receptor 3|Feline McDonough Sarcoma (FMS)-like tyrosine kinase 4|VEGF receptor-3|fms related tyrosine kinase 4|fms-like tyrosine kinase 4|primary congenital lymphedema|tyrosine-protein kinase receptor FLT4', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180601506, end_position_on_the_genomic_accession=180650298, orientation='minus', exon_count=35, OMIM=[136352], no_hdr0=''),
    2326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2326, CurrentID=0, Status='live', Symbol='FMO1', Aliases=[], description='flavin containing dimethylaniline monoxygenase 1', other_designations='dimethylaniline monooxygenase [N-oxide-forming] 1|FMO 1|Flavin-containing monooxygenase 1 (fetal liver)|dimethylaniline oxidase 1|fetal hepatic flavin-containing monooxygenase 1|flavin containing monooxygenase 1', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171248473, end_position_on_the_genomic_accession=171285978, orientation='plus', exon_count=12, OMIM=[136130], no_hdr0=''),
    2327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2327, CurrentID=0, Status='live', Symbol='FMO2', Aliases=['FMO1B1'], description='flavin containing dimethylaniline monoxygenase 2', other_designations='dimethylaniline monooxygenase [N-oxide-forming] 2|FMO, pulmonary|dimethylaniline oxidase 2|flavin containing monooxygenase 2 (non-functional)|pulmonary flavin-containing monooxygenase 2', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171185208, end_position_on_the_genomic_accession=171212686, orientation='plus', exon_count=10, OMIM=[603955], no_hdr0=''),
    2328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2328, CurrentID=0, Status='live', Symbol='FMO3', Aliases=['FMOII', 'TMAU', 'dJ127D3.1'], description='flavin containing dimethylaniline monoxygenase 3', other_designations='dimethylaniline monooxygenase [N-oxide-forming] 3|FMO form 2|dimethylaniline oxidase 3|flavin containing monooxygenase 3|hepatic flavin-containing monooxygenase-3|trimethylamine monooxygenase', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171090873, end_position_on_the_genomic_accession=171117819, orientation='plus', exon_count=10, OMIM=[136132], no_hdr0=''),
    2329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2329, CurrentID=0, Status='live', Symbol='FMO4', Aliases=['FMO2'], description='flavin containing dimethylaniline monoxygenase 4', other_designations='dimethylaniline monooxygenase [N-oxide-forming] 4|FMO 4|dimethylaniline oxidase 4|flavin containing monooxygenase 4|hepatic flavin-containing monooxygenase 4', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171314131, end_position_on_the_genomic_accession=171342084, orientation='plus', exon_count=11, OMIM=[136131], no_hdr0=''),
    2330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2330, CurrentID=0, Status='live', Symbol='FMO5', Aliases=['hBVMO1'], description='flavin containing dimethylaniline monoxygenase 5', other_designations='flavin-containing monooxygenase 5|FMO 5|NAPDH oxidase|baeyer-Villiger monooxygenase 1|dimethylaniline monooxygenase [N-oxide-forming] 5|dimethylaniline oxidase 5|flavin containing monooxygenase 5|hepatic flavin-containing monooxygenase 5', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147183963, end_position_on_the_genomic_accession=147225798, orientation='minus', exon_count=11, OMIM=[603957], no_hdr0=''),
    2331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2331, CurrentID=0, Status='live', Symbol='FMOD', Aliases=['FM', 'SLRR2E'], description='fibromodulin', other_designations='fibromodulin|KSPG fibromodulin|collagen-binding 59 kDa protein|epididymis secretory sperm binding protein|keratan sulfate proteoglycan fibromodulin', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203340628, end_position_on_the_genomic_accession=203351122, orientation='minus', exon_count=3, OMIM=[600245], no_hdr0=''),
    2332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2332, CurrentID=0, Status='live', Symbol='FMR1', Aliases=['FMRP', 'FRAXA', 'POF', 'POF1'], description='FMRP translational regulator 1', other_designations='synaptic functional regulator FMR1|fragile X mental retardation 1|fragile X mental retardation protein 1|truncated FMRP', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=147911919, end_position_on_the_genomic_accession=147951125, orientation='plus', exon_count=17, OMIM=[309550], no_hdr0=''),
    2334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2334, CurrentID=0, Status='live', Symbol='AFF2', Aliases=['FMR2', 'FMR2P', 'FRAXE', 'MRX2', 'OX19', 'XLID109'], description='AF4/FMR2 family member 2', other_designations='AF4/FMR2 family member 2|fragile X E mental retardation syndrome protein|fragile X mental retardation 2 protein|protein FMR-2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=148500617, end_position_on_the_genomic_accession=149000663, orientation='plus', exon_count=22, OMIM=[300806], no_hdr0=''),
    2335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2335, CurrentID=0, Status='live', Symbol='FN1', Aliases=['CIG', 'ED-B', 'FINC', 'FN', 'FNZ', 'GFND', 'GFND2', 'LETS', 'MSF', 'SMDCF'], description='fibronectin 1', other_designations='fibronectin|cold-insoluble globulin|epididymis secretory sperm binding protein|migration-stimulating factor', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=215360862, end_position_on_the_genomic_accession=215436167, orientation='minus', exon_count=46, OMIM=[135600], no_hdr0=''),
    2339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2339, CurrentID=0, Status='live', Symbol='FNTA', Aliases=['FPTA', 'PGGT1A', 'PTAR2'], description='farnesyltransferase, CAAX box, alpha', other_designations='protein farnesyltransferase/geranylgeranyltransferase type-1 subunit alpha|FTase-alpha|GGTase-I-alpha|farnesyl-protein transferase alpha-subunit|protein prenyltransferase alpha subunit repeat containing 2|ras proteins prenyltransferase subunit alpha|type I protein geranyl-geranyltransferase alpha subunit', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=43056323, end_position_on_the_genomic_accession=43085785, orientation='plus', exon_count=9, OMIM=[134635], no_hdr0=''),
    2342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2342, CurrentID=0, Status='live', Symbol='FNTB', Aliases=['FPTB'], description='farnesyltransferase, CAAX box, beta', other_designations='protein farnesyltransferase subunit beta|CAAX farnesyltransferase subunit beta|FTase-beta|epididymis secretory sperm binding protein|ras proteins prenyltransferase subunit beta', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64986895, end_position_on_the_genomic_accession=65062650, orientation='plus', exon_count=12, OMIM=[134636], no_hdr0=''),
    2346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2346, CurrentID=0, Status='live', Symbol='FOLH1', Aliases=['FGCP', 'FOLH', 'GCP2', 'GCPII', 'NAALAD1', 'NAALAdase', 'PSM', 'PSMA', 'mGCP'], description='folate hydrolase 1', other_designations='glutamate carboxypeptidase 2|N-acetylated alpha-linked acidic dipeptidase 1|N-acetylated-alpha-linked acidic dipeptidase I|NAALADase I|cell growth-inhibiting gene 27 protein|folylpoly-gamma-glutamate carboxypeptidase|glutamate carboxylase II|glutamate carboxypeptidase II|membrane glutamate carboxypeptidase|prostate specific membrane antigen variant F|pteroylpoly-gamma-glutamate carboxypeptidase', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=49145092, end_position_on_the_genomic_accession=49208642, orientation='minus', exon_count=21, OMIM=[600934], no_hdr0=''),
    2348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2348, CurrentID=0, Status='live', Symbol='FOLR1', Aliases=['FBP', 'FOLR', 'FRalpha', 'NCFTD'], description='folate receptor alpha', other_designations='folate receptor alpha|FR-alpha|KB cells FBP|adult folate-binding protein|folate binding protein|folate receptor 1 (adult)|folate receptor, adult|ovarian tumor-associated antigen MOv18', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72189709, end_position_on_the_genomic_accession=72196323, orientation='plus', exon_count=7, OMIM=[136430], no_hdr0=''),
    2350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2350, CurrentID=0, Status='live', Symbol='FOLR2', Aliases=['BETA-HFR', 'FBP', 'FBP/PL-1', 'FOLR1', 'FR-BETA', 'FR-P3', 'FRbeta'], description='folate receptor beta', other_designations='folate receptor beta|folate receptor 2 (fetal)|folate receptor alpha|folate receptor, fetal/placental|folate-binding protein, fetal/placental|placental folate-binding protein', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72216794, end_position_on_the_genomic_accession=72221950, orientation='plus', exon_count=6, OMIM=[136425], no_hdr0=''),
    2352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2352, CurrentID=0, Status='live', Symbol='FOLR3', Aliases=['FR-G', 'FR-gamma', 'FRgamma', 'gamma-hFR'], description='folate receptor gamma', other_designations='folate receptor gamma|folate receptor 3 (gamma)', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72135725, end_position_on_the_genomic_accession=72139892, orientation='plus', exon_count=5, OMIM=[602469], no_hdr0=''),
    2353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2353, CurrentID=0, Status='live', Symbol='FOS', Aliases=['AP-1', 'C-FOS', 'p55'], description='Fos proto-oncogene, AP-1 transcription factor subunit', other_designations='proto-oncogene c-Fos|FBJ murine osteosarcoma viral (v-fos) oncogene homolog (oncogene FOS)|FBJ murine osteosarcoma viral oncogene homolog|Fos proto-oncogene, AP-1 trancription factor subunit|G0/G1 switch regulatory protein 7|activator protein 1|cellular oncogene c-fos', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75278828, end_position_on_the_genomic_accession=75282230, orientation='plus', exon_count=4, OMIM=[164810], no_hdr0=''),
    2354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2354, CurrentID=0, Status='live', Symbol='FOSB', Aliases=['AP-1', 'G0S3', 'GOS3', 'GOSB'], description='FosB proto-oncogene, AP-1 transcription factor subunit', other_designations='protein fosB|FBJ murine osteosarcoma viral oncogene homolog B|FosB proto-oncogene, AP-1 trancription factor subunit|G0/G1 switch regulatory protein 3|activator protein 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45467996, end_position_on_the_genomic_accession=45475179, orientation='plus', exon_count=4, OMIM=[164772], no_hdr0=''),
    2355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2355, CurrentID=0, Status='live', Symbol='FOSL2', Aliases=['FRA2'], description='FOS like 2, AP-1 transcription factor subunit', other_designations='fos-related antigen 2|FOS like 2, AP-1 trancription factor subunit|FOS like antigen 2|FRA-2', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28392855, end_position_on_the_genomic_accession=28417317, orientation='plus', exon_count=6, OMIM=[601575], no_hdr0=''),
    2356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2356, CurrentID=0, Status='live', Symbol='FPGS', Aliases=[], description='folylpolyglutamate synthase', other_designations='folylpolyglutamate synthase, mitochondrial|folylpoly-gamma-glutamate synthetase|tetrahydrofolate synthase|tetrahydrofolylpolyglutamate synthase', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127802858, end_position_on_the_genomic_accession=127814520, orientation='plus', exon_count=17, OMIM=[136510], no_hdr0=''),
    2357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2357, CurrentID=0, Status='live', Symbol='FPR1', Aliases=['FMLP', 'FPR'], description='formyl peptide receptor 1', other_designations='fMet-Leu-Phe receptor|N-formylpeptide chemoattractant receptor|fMLP receptor', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51745172, end_position_on_the_genomic_accession=51751878, orientation='minus', exon_count=3, OMIM=[136537], no_hdr0=''),
    2358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2358, CurrentID=0, Status='live', Symbol='FPR2', Aliases=['ALX', 'ALXR', 'FMLP-R-II', 'FMLPXA', 'FPRH1', 'FPRH2', 'FPRL1', 'HM63', 'LXA4R', 'FPR2'], description='formyl peptide receptor 2', other_designations='N-formyl peptide receptor 2|FMLP-R-I|FMLP-related receptor I|LXA4 receptor|RFP|formyl peptide receptor-like 1|lipoxin A4 receptor (formyl peptide receptor related)', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51752026, end_position_on_the_genomic_accession=51770531, orientation='plus', exon_count=5, OMIM=[136538], no_hdr0=''),
    2359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2359, CurrentID=0, Status='live', Symbol='FPR3', Aliases=['FML2_HUMAN', 'FMLP-R-II', 'FMLPY', 'FPRH1', 'FPRH2', 'FPRL2', 'RMLP-R-I'], description='formyl peptide receptor 3', other_designations='N-formyl peptide receptor 3|FMLP-related receptor II|formyl peptide receptor-like 2', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51795157, end_position_on_the_genomic_accession=51826207, orientation='plus', exon_count=3, OMIM=[136539], no_hdr0=''),
    2395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2395, CurrentID=0, Status='live', Symbol='FXN', Aliases=['CyaY', 'FA', 'FARR', 'FRDA', 'X25'], description='frataxin', other_designations='frataxin, mitochondrial|Friedreich ataxia protein', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69035752, end_position_on_the_genomic_accession=69079076, orientation='plus', exon_count=5, OMIM=[606829], no_hdr0=''),
    2444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2444, CurrentID=0, Status='live', Symbol='FRK', Aliases=['GTK', 'PTK5', 'RAK'], description='fyn related Src family tyrosine kinase', other_designations='tyrosine-protein kinase FRK|PTK5 protein tyrosine kinase 5|fyn-related kinase|nuclear tyrosine protein kinase RAK|protein-tyrosine kinase 5', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=115931149, end_position_on_the_genomic_accession=116100739, orientation='minus', exon_count=12, OMIM=[606573], no_hdr0=''),
    2475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2475, CurrentID=0, Status='live', Symbol='MTOR', Aliases=['FRAP', 'FRAP1', 'FRAP2', 'RAFT1', 'RAPT1', 'SKS'], description='mechanistic target of rapamycin kinase', other_designations='serine/threonine-protein kinase mTOR|FK506 binding protein 12-rapamycin associated protein 2|FK506-binding protein 12-rapamycin complex-associated protein 1|FKBP-rapamycin associated protein|FKBP12-rapamycin complex-associated protein 1|mammalian target of rapamycin|mechanistic target of rapamycin (serine/threonine kinase)|rapamycin and FKBP12 target 1|rapamycin associated protein FRAP2|rapamycin target protein 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11106535, end_position_on_the_genomic_accession=11273497, orientation='minus', exon_count=60, OMIM=[601231], no_hdr0=''),
    2483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2483, CurrentID=0, Status='live', Symbol='FRG1', Aliases=['FRG1A', 'FSG1'], description='FSHD region gene 1', other_designations='protein FRG1|FSHD region gene 1 protein|facioscapulohumeral muscular dystrophy region gene-1', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=189940846, end_position_on_the_genomic_accession=189963204, orientation='plus', exon_count=8, OMIM=[601278], no_hdr0=''),
    2487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2487, CurrentID=0, Status='live', Symbol='FRZB', Aliases=['FRE', 'FRITZ', 'FRP-3-1', 'FRZB-PEN', 'FRZB1', 'FZRB', 'OS1', 'SFRP3', 'SRFP3', 'hFIZ', 'FRZB'], description='frizzled related protein', other_designations='secreted frizzled-related protein 3|frezzled|frizzled homolog-related|frizzled-related protein 1|sFRP-3', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=182833275, end_position_on_the_genomic_accession=182866637, orientation='minus', exon_count=6, OMIM=[605083], no_hdr0=''),
    2488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2488, CurrentID=0, Status='live', Symbol='FSHB', Aliases=['HH24'], description='follicle stimulating hormone subunit beta', other_designations='follitropin subunit beta|FSH-B|FSH-beta|follicle stimulating hormone beta subunit|follicle stimulating hormone, beta polypeptide|follitropin, beta chain', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=30231014, end_position_on_the_genomic_accession=30235194, orientation='plus', exon_count=3, OMIM=[136530], no_hdr0=''),
    2491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2491, CurrentID=0, Status='live', Symbol='CENPI', Aliases=['CENP-I', 'FSHPRH1', 'LRPR1'], description='centromere protein I', other_designations='centromere protein I|FSH primary response 1|follicle-stimulating hormone primary response protein|interphase centromere complex protein 19|leucine-rich primary response protein 1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101098159, end_position_on_the_genomic_accession=101181847, orientation='plus', exon_count=25, OMIM=[300065], no_hdr0=''),
    2492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2492, CurrentID=0, Status='live', Symbol='FSHR', Aliases=['FSHR1O', 'LGR1', 'ODG1', 'FSHR'], description='follicle stimulating hormone receptor', other_designations='follicle-stimulating hormone receptor|FSH receptor|follitropin receptor', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48953161, end_position_on_the_genomic_accession=49154527, orientation='minus', exon_count=14, OMIM=[136435], no_hdr0=''),
    2494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2494, CurrentID=0, Status='live', Symbol='NR5A2', Aliases=['B1F', 'B1F2', 'CPF', 'FTF', 'FTZ-F1', 'FTZ-F1beta', 'LRH-1', 'LRH1', 'hB1F-2'], description='nuclear receptor subfamily 5 group A member 2', other_designations='nuclear receptor subfamily 5 group A member 2|CYP7A promoter-binding factor|b1-binding factor, hepatocyte transcription factor which activates enhancer II of hepatitis B virus|fetoprotein-alpha 1 (AFP) transcription factor|hepatocytic transcription factor hB1F-3|liver nuclear receptor homolog-1 variant 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200027710, end_position_on_the_genomic_accession=200177415, orientation='plus', exon_count=13, OMIM=[604453], no_hdr0=''),
    2495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2495, CurrentID=0, Status='live', Symbol='FTH1', Aliases=['FHC', 'FTH', 'FTHL6', 'HFE5', 'PIG15', 'PLIF'], description='ferritin heavy chain 1', other_designations='ferritin heavy chain|apoferritin|cell proliferation-inducing gene 15 protein|ferritin H subunit|ferritin, heavy polypeptide 1|placenta immunoregulatory factor|proliferation-inducing protein 15', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61964285, end_position_on_the_genomic_accession=61967634, orientation='minus', exon_count=4, OMIM=[134770], no_hdr0=''),
    2512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2512, CurrentID=0, Status='live', Symbol='FTL', Aliases=['LFTD', 'NBIA3'], description='ferritin light chain', other_designations='ferritin light chain|epididymis secretory sperm binding protein|ferritin L subunit|ferritin L-chain|ferritin light polypeptide-like 3|ferritin, light polypeptide', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48965309, end_position_on_the_genomic_accession=48966879, orientation='plus', exon_count=4, OMIM=[134790], no_hdr0=''),
    2515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2515, CurrentID=0, Status='live', Symbol='ADAM2', Aliases=['CRYN1', 'CRYN2', 'CT15', 'FTNB', 'PH-30b', 'PH30', 'PH30-beta'], description='ADAM metallopeptidase domain 2', other_designations='disintegrin and metalloproteinase domain-containing protein 2|cancer/testis antigen 15|fertilin subunit beta', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=39743735, end_position_on_the_genomic_accession=39838227, orientation='minus', exon_count=21, OMIM=[601533], no_hdr0=''),
    2516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2516, CurrentID=0, Status='live', Symbol='NR5A1', Aliases=['AD4BP', 'ELP', 'FTZ1', 'FTZF1', 'POF7', 'SF-1', 'SF1', 'SPGF8', 'SRXX4', 'SRXY3', 'hSF-1'], description='nuclear receptor subfamily 5 group A member 1', other_designations='steroidogenic factor 1|STF-1|adrenal 4 binding protein|fushi tarazu factor homolog 1|nuclear receptor AdBP4|steroid hormone receptor Ad4BP|steroidogenic factor 1 nuclear receptor|steroidogenic factor-1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124481236, end_position_on_the_genomic_accession=124507399, orientation='minus', exon_count=7, OMIM=[184757], no_hdr0=''),
    2517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2517, CurrentID=0, Status='live', Symbol='FUCA1', Aliases=['FUCA'], description='alpha-L-fucosidase 1', other_designations='tissue alpha-L-fucosidase|I+/--L-fucosidase 1|a-L-fucosidase 1|alpha-L-fucosidase I|alpha-L-fucoside fucohydrolase 1|fucosidase, alpha-L- 1, tissue|tissue fucosidase', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23845077, end_position_on_the_genomic_accession=23868332, orientation='minus', exon_count=10, OMIM=[612280], no_hdr0=''),
    2519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2519, CurrentID=0, Status='live', Symbol='FUCA2', Aliases=['dJ20N2.5'], description='alpha-L-fucosidase 2', other_designations='plasma alpha-L-fucosidase|I+/--L-fucosidase 2|a-L-fucosidase 2|alpha-L-fucoside fucohydrolase 2|fucosidase, alpha-L- 2, plasma|plasma fucosidase', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143494812, end_position_on_the_genomic_accession=143511720, orientation='minus', exon_count=7, OMIM=[136820], no_hdr0=''),
    2520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2520, CurrentID=0, Status='live', Symbol='GAST', Aliases=['GAS'], description='gastrin', other_designations='gastrin|preprogastrin', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41712331, end_position_on_the_genomic_accession=41715969, orientation='plus', exon_count=3, OMIM=[137250], no_hdr0=''),
    2521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2521, CurrentID=0, Status='live', Symbol='FUS', Aliases=['ALS6', 'ETM41', 'HNRNPP2', 'POMP75', 'TLS', 'altFUS', 'FUS'], description='FUS RNA binding protein', other_designations='RNA-binding protein FUS|75 kDa DNA-pairing protein|fus-like protein|fused in sarcoma|fusion gene in myxoid liposarcoma|heterogeneous nuclear ribonucleoprotein P2|oncogene FUS|oncogene TLS|translocated in liposarcoma protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31180110, end_position_on_the_genomic_accession=31194871, orientation='plus', exon_count=15, OMIM=[137070], no_hdr0=''),
    2523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2523, CurrentID=0, Status='live', Symbol='FUT1', Aliases=['H', 'HH', 'HSC'], description='fucosyltransferase 1 (H blood group)', other_designations='galactoside alpha-(1,2)-fucosyltransferase 1|GDP-L-fucose:beta-D-galactoside 2-alpha-L-fucosyltransferase 1|H glycosyltransferase|H glycosytransferase|alpha(1,2) fucosyltransferase 1|alpha(1,2)FT 1|blood group H alpha 2-fucosyltransferase|galactoside 2-L-fucosyltransferase enzyme|galactoside 2-alpha-L-fucosyltransferase|nonfunctional fucosyltransferase 1|truncated FUT1|truncated alpha(1,2)fucosyltransferase|truncated fucosyltransferase 1|type 1 galactoside alpha-(1,2)-fucosyltransferase FUT1|type 2 galactoside alpha-(1,2)-fucosyltransferase FUT1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48748011, end_position_on_the_genomic_accession=48755358, orientation='minus', exon_count=5, OMIM=[211100], no_hdr0=''),
    2524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2524, CurrentID=0, Status='live', Symbol='FUT2', Aliases=['B12QTL1', 'SE', 'SEC2', 'Se2', 'sej'], description='fucosyltransferase 2', other_designations='galactoside alpha-(1,2)-fucosyltransferase 2|GDP-L-fucose:beta-D-galactoside 2-alpha-L-fucosyltransferase 2|alpha (1,2) fucosyltransferase|alpha(1,2)FT 2|alpha(1,2)FT2|fucosyltransferase 2 (secretor status included)|galactoside 2-L-fucosyltransferase|galactoside 2-alpha-L-fucosyltransferase 2|secretor blood group alpha-2-fucosyltransferase|secretor factor|truncated fucosyltransferase 2|type 1 galactoside alpha-(1,2)-fucosyltransferase FUT2|type 2 galactoside alpha-(1,2)-fucosyltransferase FUT2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48695971, end_position_on_the_genomic_accession=48705951, orientation='plus', exon_count=2, OMIM=[182100], no_hdr0=''),
    2525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2525, CurrentID=0, Status='live', Symbol='FUT3', Aliases=['CD174', 'FT3B', 'FucT-III', 'LE', 'Les'], description='fucosyltransferase 3 (Lewis blood group)', other_designations='3-galactosyl-N-acetylglucosaminide 4-alpha-L-fucosyltransferase FUT3|Lewis FT|alpha-(1,3/1,4)-fucosyltransferase|alpha-3-fucosyltransferase FUT3|blood group Lewis alpha-4-fucosyltransferase|fucosyltransferase 3 (galactoside 3(4)-L-fucosyltransferase, Lewis blood group)|fucosyltransferase III|galactoside 3(4)-L-fucosyltransferase|truncated fucosyltransferase 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5842888, end_position_on_the_genomic_accession=5857122, orientation='minus', exon_count=5, OMIM=[111100], no_hdr0=''),
    2526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2526, CurrentID=0, Status='live', Symbol='FUT4', Aliases=['CD15', 'ELFT', 'FCT3A', 'FUC-TIV', 'FUTIV', 'LeX', 'SSEA-1'], description='fucosyltransferase 4', other_designations='alpha-(1,3)-fucosyltransferase 4|ELAM ligand fucosyltransferase|ELAM-1 ligand fucosyltransferase|Lewis X|alpha (1,3) fucosyltransferase, myeloid-specific|fucT-IV|fucosyltransferase IV|galactoside 3-L-fucosyltransferase|stage-specific embryonic antigen 1', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94543921, end_position_on_the_genomic_accession=94549895, orientation='plus', exon_count=1, OMIM=[104230], no_hdr0=''),
    2527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2527, CurrentID=0, Status='live', Symbol='FUT5', Aliases=['FUC-TV'], description='fucosyltransferase 5', other_designations='4-galactosyl-N-acetylglucosaminide 3-alpha-L-fucosyltransferase FUT5|3-galactosyl-N-acetylglucosaminide 4-alpha-L-fucosyltransferase FUT5|alpha (1,3) fucosyltransferase|alpha-(1,3)-fucosyltransferase 5|fucT-V|fucosyltransferase V|galactoside 3-L-fucosyltransferase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5865826, end_position_on_the_genomic_accession=5870540, orientation='minus', exon_count=2, OMIM=[136835], no_hdr0=''),
    2528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2528, CurrentID=0, Status='live', Symbol='FUT6', Aliases=['FCT3A', 'FT1A', 'Fuc-TVI', 'FucT-VI'], description='fucosyltransferase 6', other_designations='4-galactosyl-N-acetylglucosaminide 3-alpha-L-fucosyltransferase FUT6|alpha-(1,3)-fucosyltransferase 6|fucosyltransferase 6 (alpha (1,3) fucosyltransferase)|fucosyltransferase VI|galactoside 3-L-fucosyltransferase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5830408, end_position_on_the_genomic_accession=5840019, orientation='minus', exon_count=8, OMIM=[136836], no_hdr0=''),
    2529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2529, CurrentID=0, Status='live', Symbol='FUT7', Aliases=['FucT-VII'], description='fucosyltransferase 7', other_designations='alpha-(1,3)-fucosyltransferase 7|fuc-TVII|fucosyltransferase 7 (alpha (1,3) fucosyltransferase)|fucosyltransferase VII|galactoside 3-L-fucosyltransferase|selectin-ligand synthase', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137030174, end_position_on_the_genomic_accession=137032088, orientation='minus', exon_count=2, OMIM=[602030], no_hdr0=''),
    2530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2530, CurrentID=0, Status='live', Symbol='FUT8', Aliases=['CDGF', 'CDGF1'], description='fucosyltransferase 8', other_designations='alpha-(1,6)-fucosyltransferase|GDP-L-Fuc:N-acetyl-beta-D-glucosaminide alpha1,6-fucosyltransferase|GDP-fucose--glycoprotein fucosyltransferase|alpha1-6FucT|fucosyltransferase 8 (alpha (1,6) fucosyltransferase)|glycoprotein 6-alpha-L-fucosyltransferase', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=65410592, end_position_on_the_genomic_accession=65744122, orientation='plus', exon_count=16, OMIM=[602589], no_hdr0=''),
    2531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2531, CurrentID=0, Status='live', Symbol='KDSR', Aliases=['DHSR', 'EKVP4', 'FVT1', 'SDR35C1'], description='3-ketodihydrosphingosine reductase', other_designations='3-ketodihydrosphingosine reductase|3-dehydrosphinganine reductase|FVT-1|KDS reductase|follicular lymphoma variant translocation 1|follicular variant translocation protein 1|short chain dehydrogenase/reductase family 35C member 1', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63327726, end_position_on_the_genomic_accession=63367234, orientation='minus', exon_count=11, OMIM=[136440], no_hdr0=''),
    2532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2532, CurrentID=0, Status='live', Symbol='ACKR1', Aliases=['CCBP1', 'CD234', 'DARC', 'DARC/ACKR1', 'Dfy', 'FY', 'GPD', 'GpFy', 'WBCQ1'], description='atypical chemokine receptor 1 (Duffy blood group)', other_designations='atypical chemokine receptor 1|Duffy antigen chemokine receptor|Duffy blood group antigen|Duffy blood group system protein|Duffy blood group, chemokine receptor|Fy glycoprotein|glycoprotein D|plasmodium vivax receptor', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159204875, end_position_on_the_genomic_accession=159206500, orientation='plus', exon_count=2, OMIM=[613665], no_hdr0=''),
    2533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2533, CurrentID=0, Status='live', Symbol='FYB1', Aliases=['ADAP', 'FYB', 'PRO0823', 'SLAP-130', 'SLAP130', 'THC3'], description='FYN binding protein 1', other_designations='FYN-binding protein 1|FYB-120/130|FYN-T-binding protein|SLP-76-associated phosphoprotein|adhesion and degranulation-promoting adaptor protein|p120/p130', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=39105252, end_position_on_the_genomic_accession=39274500, orientation='minus', exon_count=26, OMIM=[602731], no_hdr0=''),
    2534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2534, CurrentID=0, Status='live', Symbol='FYN', Aliases=['SLK', 'SYN', 'p59-FYN'], description='FYN proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Fyn|FYN oncogene related to SRC, FGR, YES|OKT3-induced calcium influx regulator|c-syn protooncogene|proto-oncogene Syn|proto-oncogene c-Fyn|src-like kinase|src/yes-related novel|tyrosine kinase p59fyn(T)', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=111660332, end_position_on_the_genomic_accession=111873452, orientation='minus', exon_count=19, OMIM=[137025], no_hdr0=''),
    2535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2535, CurrentID=0, Status='live', Symbol='FZD2', Aliases=['Fz2', 'OMOD2', 'fz-2', 'fzE2', 'hFz2'], description='frizzled class receptor 2', other_designations='frizzled-2|frizzled 2, seven transmembrane spanning receptor|frizzled family receptor 2|frizzled homolog 2', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44557484, end_position_on_the_genomic_accession=44561262, orientation='plus', exon_count=1, OMIM=[600667], no_hdr0=''),
    2537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2537, CurrentID=0, Status='live', Symbol='IFI6', Aliases=['6-16', 'FAM14C', 'G1P3', 'IFI-6-1616', 'IFI6'], description='interferon alpha inducible protein 6', other_designations='interferon alpha-inducible protein 6|interferon, alpha-inducible protein clone IFI-6-16|interferon-induced protein 6-16', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27666061, end_position_on_the_genomic_accession=27672229, orientation='minus', exon_count=5, OMIM=[147572], no_hdr0=''),
    2538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2538, CurrentID=0, Status='live', Symbol='G6PC1', Aliases=['G6PC', 'G6PT', 'G6Pase', 'GSD1', 'GSD1a'], description='glucose-6-phosphatase catalytic subunit 1', other_designations='glucose-6-phosphatase catalytic subunit 1|G-6-Pase|G6Pase-alpha|glucose-6-phosphatase alpha', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42900799, end_position_on_the_genomic_accession=42914438, orientation='plus', exon_count=5, OMIM=[613742], no_hdr0=''),
    2539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2539, CurrentID=0, Status='live', Symbol='G6PD', Aliases=['G6PD1'], description='glucose-6-phosphate dehydrogenase', other_designations='glucose-6-phosphate 1-dehydrogenase|epididymis secretory sperm binding protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154531390, end_position_on_the_genomic_accession=154547569, orientation='minus', exon_count=14, OMIM=[305900], no_hdr0=''),
    2541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2541, CurrentID=0, Status='live', Symbol='G6PR', Aliases=['GSD1aSP'], description='glucose-6-phosphatase regulator', other_designations='glucose-6-phosphatase regulator|glucose-6-phosphatase, regulatory', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    2542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2542, CurrentID=0, Status='live', Symbol='SLC37A4', Aliases=['G6PT1', 'G6PT2', 'G6PT3', 'GSD1b', 'GSD1c', 'GSD1d', 'PRO0685', 'TRG-19', 'TRG19'], description='solute carrier family 37 member 4', other_designations='glucose-6-phosphate exchanger SLC37A4|glucose-5-phosphate transporter|glucose-6-phosphatase, transport (glucose) protein 3|glucose-6-phosphatase, transport (glucose-6-phosphate) protein 1|glucose-6-phosphatase, transport (phosphate/pyrophosphate) protein 2|glucose-6-phosphate translocase|microsomal glucose-6-phosphate transporter|solute carrier family 37 (glucose-6-phosphate transporter), member 4|transformation-related gene 19 protein', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119024112, end_position_on_the_genomic_accession=119030877, orientation='minus', exon_count=12, OMIM=[602671], no_hdr0=''),
    2543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2543, CurrentID=0, Status='live', Symbol='GAGE1', Aliases=['CT4.1', 'CT4.4', 'GAGE-1', 'GAGE-4', 'GAGE4'], description='G antigen 1', other_designations='G antigen 1|Cancer/testis antigen 4.4|G antigen 4|MZ2-F antigen|cancer/testis antigen 4.1|cancer/testis antigen family 4, member 1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49598992, end_position_on_the_genomic_accession=49608538, orientation='plus', exon_count=7, OMIM=[300594], no_hdr0=''),
    2547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2547, CurrentID=0, Status='live', Symbol='XRCC6', Aliases=['CTC75', 'CTCBF', 'G22P1', 'KU70', 'ML8', 'TLAA'], description='X-ray repair cross complementing 6', other_designations="X-ray repair cross-complementing protein 6|5'-dRP lyase Ku70|5'-deoxyribose-5-phosphate lyase Ku70|70 kDa subunit of Ku antigen|ATP-dependent DNA helicase 2 subunit 1|ATP-dependent DNA helicase II, 70 kDa subunit|CTC box binding factor 75 kDa subunit|DNA repair protein XRCC6|Ku autoantigen p70 subunit|Ku autoantigen, 70kDa|X-ray repair complementing defective repair in Chinese hamster cells 6|lupus Ku autoantigen protein p70|thyroid autoantigen 70kD (Ku antigen)|thyroid autoantigen 70kDa (Ku antigen)|thyroid-lupus autoantigen p70", map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41621295, end_position_on_the_genomic_accession=41664041, orientation='plus', exon_count=13, OMIM=[152690], no_hdr0=''),
    2548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2548, CurrentID=0, Status='live', Symbol='GAA', Aliases=['LYAG'], description='alpha glucosidase', other_designations='lysosomal alpha-glucosidase|acid maltase|aglucosidase alfa|glucosidase alpha, acid', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80101535, end_position_on_the_genomic_accession=80119881, orientation='plus', exon_count=22, OMIM=[606800], no_hdr0=''),
    2549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2549, CurrentID=0, Status='live', Symbol='GAB1', Aliases=['DFNB26'], description='GRB2 associated binding protein 1', other_designations='GRB2-associated-binding protein 1|GRB2-associated binder 1|deafness, autosomal recessive 26|growth factor receptor bound protein 2-associated protein 1|symbol withdrawn, see GAB1', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143336876, end_position_on_the_genomic_accession=143474565, orientation='plus', exon_count=19, OMIM=[604439], no_hdr0=''),
    2550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2550, CurrentID=0, Status='live', Symbol='GABBR1', Aliases=['GABABR1-3', 'GB1', 'GPRC3A', 'GABBR1'], description='gamma-aminobutyric acid type B receptor subunit 1', other_designations='gamma-aminobutyric acid type B receptor subunit 1|GABA-B receptor, R1 subunit|gamma-aminobutyric acid (GABA) B receptor, 1|seven transmembrane helix receptor', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29602230, end_position_on_the_genomic_accession=29633183, orientation='minus', exon_count=25, OMIM=[603540], no_hdr0=''),
    2551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2551, CurrentID=0, Status='live', Symbol='GABPA', Aliases=['E4TF1-60', 'E4TF1A', 'NFT2', 'NRF2', 'NRF2A', 'RCH04A07'], description='GA binding protein transcription factor subunit alpha', other_designations='GA-binding protein alpha chain|GA binding protein transcription factor alpha subunit 60kDa|GABP subunit alpha|human nuclear respiratory factor-2 subunit alpha|nuclear respiratory factor 2 alpha subunit|nuclear respiratory factor 2 subunit alpha|transcription factor E4TF1-60', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=25734972, end_position_on_the_genomic_accession=25772460, orientation='plus', exon_count=13, OMIM=[600609], no_hdr0=''),
    2553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2553, CurrentID=0, Status='live', Symbol='GABPB1', Aliases=['BABPB2', 'E4TF1', 'E4TF1-47', 'E4TF1-53', 'E4TF1B', 'GABPB', 'GABPB-1', 'GABPB2', 'NRF2B1', 'NRF2B2'], description='GA binding protein transcription factor subunit beta 1', other_designations='GA-binding protein subunit beta-1|GA binding protein transcription factor beta subunit 1 transcript variant gamma-2|GABP subunit beta-2|nuclear respiratory factor 2|transcription factor E4TF1-47|transcription factor E4TF1-53', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50275389, end_position_on_the_genomic_accession=50359306, orientation='minus', exon_count=13, OMIM=[600610], no_hdr0=''),
    2554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2554, CurrentID=0, Status='live', Symbol='GABRA1', Aliases=['DEE19', 'ECA4', 'EIEE19', 'EJM', 'EJM5'], description='gamma-aminobutyric acid type A receptor subunit alpha1', other_designations='gamma-aminobutyric acid receptor subunit alpha-1|GABA(A) receptor subunit alpha-1|GABA(A) receptor, alpha 1|gamma-aminobutyric acid (GABA) A receptor, alpha 1|gamma-aminobutyric acid type A receptor alpha1 subunit', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=161847191, end_position_on_the_genomic_accession=161899971, orientation='plus', exon_count=13, OMIM=[137160], no_hdr0=''),
    2555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2555, CurrentID=0, Status='live', Symbol='GABRA2', Aliases=['DEE78', 'EIEE78'], description='gamma-aminobutyric acid type A receptor subunit alpha2', other_designations='gamma-aminobutyric acid receptor subunit alpha-2|GABA(A) receptor subunit alpha-2|gamma-aminobutyric acid type A receptor alpha2 subunit', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=46243548, end_position_on_the_genomic_accession=46390300, orientation='minus', exon_count=14, OMIM=[137140], no_hdr0=''),
    2556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2556, CurrentID=0, Status='live', Symbol='GABRA3', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit alpha3', other_designations='gamma-aminobutyric acid receptor subunit alpha-3|GABA(A) receptor subunit alpha-3|GABA(A) receptor, alpha 3|gamma-aminobutyric acid (GABA) A receptor, alpha 3|gamma-aminobutyric acid type A receptor alpha3 subunit|gamma-animobutyric acid (GABA) A receptor, alpha 3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152166234, end_position_on_the_genomic_accession=152451341, orientation='minus', exon_count=10, OMIM=[305660], no_hdr0=''),
    2557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2557, CurrentID=0, Status='live', Symbol='GABRA4', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit alpha4', other_designations='gamma-aminobutyric acid receptor subunit alpha-4|GABA(A) receptor, alpha 4|gamma-aminobutyric acid (GABA) A receptor, alpha 4|gamma-aminobutyric acid A receptor alpha 4|gamma-aminobutyric acid type A receptor alpha4 subunit', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=46918900, end_position_on_the_genomic_accession=46993581, orientation='minus', exon_count=9, OMIM=[137141], no_hdr0=''),
    2558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2558, CurrentID=0, Status='live', Symbol='GABRA5', Aliases=['DEE79', 'EIEE79'], description='gamma-aminobutyric acid type A receptor subunit alpha5', other_designations='gamma-aminobutyric acid receptor subunit alpha-5|GABA(A) receptor subunit alpha-5|gamma-aminobutyric acid (GABA) A receptor, alpha 5|gamma-aminobutyric acid type A receptor alpha5 subunit', map_location='15q12', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=26866719, end_position_on_the_genomic_accession=26949208, orientation='plus', exon_count=13, OMIM=[137142], no_hdr0=''),
    2559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2559, CurrentID=0, Status='live', Symbol='GABRA6', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit alpha6', other_designations='gamma-aminobutyric acid receptor subunit alpha-6|GABA subunit A receptor alpha 6|GABA(A) receptor subunit alpha-6|GABA(A) receptor, alpha 6|gamma-aminobutyric acid (GABA) A receptor, alpha 6|gamma-aminobutyric acid type A receptor alpha6 subunit', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=161685721, end_position_on_the_genomic_accession=161702592, orientation='plus', exon_count=9, OMIM=[137143], no_hdr0=''),
    2560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2560, CurrentID=0, Status='live', Symbol='GABRB1', Aliases=['DEE45', 'EIEE45'], description='gamma-aminobutyric acid type A receptor subunit beta1', other_designations='gamma-aminobutyric acid receptor subunit beta-1|gamma-aminobutyric acid (GABA) A receptor, beta 1|gamma-aminobutyric acid type A receptor beta1 subunit', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=46993560, end_position_on_the_genomic_accession=47438409, orientation='plus', exon_count=13, OMIM=[137190], no_hdr0=''),
    2561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2561, CurrentID=0, Status='live', Symbol='GABRB2', Aliases=['DEE92', 'ICEE2'], description='gamma-aminobutyric acid type A receptor subunit beta2', other_designations='gamma-aminobutyric acid receptor subunit beta-2|GABA(A) receptor subunit beta-2|gamma-aminobutyric acid A receptor beta 2|gamma-aminobutyric acid type A receptor beta2 subunit', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=161288436, end_position_on_the_genomic_accession=161548404, orientation='minus', exon_count=11, OMIM=[600232], no_hdr0=''),
    2562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2562, CurrentID=0, Status='live', Symbol='GABRB3', Aliases=['DEE43', 'ECA5', 'EIEE43'], description='gamma-aminobutyric acid type A receptor subunit beta3', other_designations='gamma-aminobutyric acid receptor subunit beta-3|GABA-alpha receptor beta-2 subunit|GABAA receptor beta-3 subunit|gamma-aminobutyric acid (GABA) A receptor, beta 3|gamma-aminobutyric acid A receptor beta 3|gamma-aminobutyric acid type A receptor beta3 subunit', map_location='15q12', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=26543552, end_position_on_the_genomic_accession=26773763, orientation='minus', exon_count=18, OMIM=[137192], no_hdr0=''),
    2563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2563, CurrentID=0, Status='live', Symbol='GABRD', Aliases=['EIG10', 'EJM7', 'GEFSP5'], description='gamma-aminobutyric acid type A receptor subunit delta', other_designations='gamma-aminobutyric acid receptor subunit delta|GABA(A) receptor subunit delta|GABA(A) receptor, delta|GABA-A receptor, delta polypeptide|gamma-aminobutyric acid (GABA) A receptor, delta|gamma-aminobutyric acid type A receptor delta subunit', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2019345, end_position_on_the_genomic_accession=2030758, orientation='plus', exon_count=10, OMIM=[137163], no_hdr0=''),
    2564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2564, CurrentID=0, Status='live', Symbol='GABRE', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit epsilon', other_designations='gamma-aminobutyric acid receptor subunit epsilon|GABA(A) receptor subunit epsilon|GABA(A) receptor, epsilon|gamma-aminobutyric acid (GABA) A receptor, epsilon|gamma-aminobutyric acid type A receptor epsilon subunit', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151953124, end_position_on_the_genomic_accession=151974692, orientation='minus', exon_count=11, OMIM=[300093], no_hdr0=''),
    2565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2565, CurrentID=0, Status='live', Symbol='GABRG1', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit gamma1', other_designations='gamma-aminobutyric acid receptor subunit gamma-1|GABA(A) receptor subunit gamma-1|GABA(A) receptor, gamma|gamma-1 polypeptide|gamma-aminobutyric acid (GABA) A receptor, gamma 1|gamma-aminobutyric acid type A receptor gamma1 subunit', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=46035769, end_position_on_the_genomic_accession=46124054, orientation='minus', exon_count=10, OMIM=[137166], no_hdr0=''),
    2566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2566, CurrentID=0, Status='live', Symbol='GABRG2', Aliases=['CAE2', 'DEE74', 'ECA2', 'EIEE74', 'FEB8', 'GEFSP3'], description='gamma-aminobutyric acid type A receptor subunit gamma2', other_designations='gamma-aminobutyric acid receptor subunit gamma-2|GABA(A) receptor subunit gamma-2|GABA(A) receptor, gamma 2|gamma-aminobutyric acid (GABA) A receptor, gamma 2|gamma-aminobutyric acid type A receptor gamma2 subunit', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=162067465, end_position_on_the_genomic_accession=162155539, orientation='plus', exon_count=13, OMIM=[137164], no_hdr0=''),
    2567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2567, CurrentID=0, Status='live', Symbol='GABRG3', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit gamma3', other_designations='gamma-aminobutyric acid receptor subunit gamma-3|GABA(A) receptor subunit gamma-3|GABA(G) receptor, gamma 3|gamma-aminobutyric acid (GABA) A receptor, gamma 3|gamma-aminobutyric acid type A receptor gamma3 subunit', map_location='15q12', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=26971181, end_position_on_the_genomic_accession=27541984, orientation='plus', exon_count=14, OMIM=[600233], no_hdr0=''),
    2568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2568, CurrentID=0, Status='live', Symbol='GABRP', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit pi', other_designations='gamma-aminobutyric acid receptor subunit pi|GABA(A) receptor subunit pi|GABA(A) receptor, pi|gamma-aminobutyric acid (GABA) A receptor, pi|gamma-aminobutyric acid type A receptor pi subunit', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170782841, end_position_on_the_genomic_accession=170814047, orientation='plus', exon_count=11, OMIM=[602729], no_hdr0=''),
    2569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2569, CurrentID=0, Status='live', Symbol='GABRR1', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit rho1', other_designations='gamma-aminobutyric acid receptor subunit rho-1|GABA(A) receptor subunit rho-1|GABA(A) receptor, rho 1|GABA(C) receptor|bA135P14.1 (gamma-aminobutyric acid (GABA) receptor, rho 1)|gamma-aminobutyric acid (GABA) A receptor, rho-1|gamma-aminobutyric acid (GABA) receptor, rho 1|gamma-aminobutyric acid type A receptor rho1 subunit', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89177504, end_position_on_the_genomic_accession=89231288, orientation='minus', exon_count=13, OMIM=[137161], no_hdr0=''),
    2570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2570, CurrentID=0, Status='live', Symbol='GABRR2', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit rho2', other_designations='gamma-aminobutyric acid receptor subunit rho-2|GABA-C receptor, rho-2 subunit|gamma-aminobutyric acid (GABA) A receptor, rho 2|gamma-aminobutyric acid type A receptor rho2 subunit', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89254464, end_position_on_the_genomic_accession=89315299, orientation='minus', exon_count=10, OMIM=[137162], no_hdr0=''),
    2571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2571, CurrentID=0, Status='live', Symbol='GAD1', Aliases=['CPSQ1', 'DEE89', 'GAD', 'SCP'], description='glutamate decarboxylase 1', other_designations='glutamate decarboxylase 1|67 kDa glutamic acid decarboxylase|GAD-67|glutamate decarboxylase 1 (brain, 67kDa)', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170813210, end_position_on_the_genomic_accession=170861151, orientation='plus', exon_count=21, OMIM=[605363], no_hdr0=''),
    2572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2572, CurrentID=0, Status='live', Symbol='GAD2', Aliases=['GAD65'], description='glutamate decarboxylase 2', other_designations='glutamate decarboxylase 2|65 kDa glutamic acid decarboxylase|GAD-65|Glutamate decarboxylase-2 (pancreas)|glutamate decarboxylase 2 (pancreatic islets and brain, 65kDa)', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=26216372, end_position_on_the_genomic_accession=26304558, orientation='plus', exon_count=16, OMIM=[138275], no_hdr0=''),
    2574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2574, CurrentID=0, Status='live', Symbol='GAGE2C', Aliases=['CT4.2', 'GAGE-2', 'GAGE-2C', 'GAGE2'], description='G antigen 2C', other_designations='G antigen 2B/2C|G antigen 2|cancer/testis antigen 4.2', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300595], no_hdr0=''),
    2576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2576, CurrentID=0, Status='live', Symbol='GAGE4', Aliases=['CT4.4'], description='G antigen 4', other_designations='G antigen 4|GAGE-4|cancer/testis antigen 4.4|cancer/testis antigen family 4, member 4', map_location='Xp11.4-p11.2', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300597], no_hdr0=''),
    2577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2577, CurrentID=0, Status='live', Symbol='GAGE5', Aliases=['CT4.5'], description='G antigen 5', other_designations='G antigen 5|GAGE-5|cancer/testis antigen 4.5|cancer/testis antigen family 4, member 5', map_location='Xp11.4-p11.2', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300598], no_hdr0=''),
    2578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2578, CurrentID=0, Status='live', Symbol='GAGE6', Aliases=['CT4.6'], description='G antigen 6', other_designations='G antigen 6|GAGE-6|cancer/testis antigen 4.6|cancer/testis antigen family 4, member 6', map_location='Xp11.4-p11.2', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300599], no_hdr0=''),
    2579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2579, CurrentID=0, Status='live', Symbol='GAGE7', Aliases=['AL4', 'CT4.7', 'GAGE-7'], description='G antigen 7', other_designations='G antigen 12G|cancer/testis antigen 4.7|cancer/testis antigen family 4, member 7', map_location='Xp11.4-p11.2', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300601], no_hdr0=''),
    2580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2580, CurrentID=0, Status='live', Symbol='GAK', Aliases=['DNAJ26', 'DNAJC26'], description='cyclin G associated kinase', other_designations='cyclin-G-associated kinase|auxilin-2', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=849276, end_position_on_the_genomic_accession=932330, orientation='minus', exon_count=31, OMIM=[602052], no_hdr0=''),
    2581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2581, CurrentID=0, Status='live', Symbol='GALC', Aliases=[], description='galactosylceramidase', other_designations='galactocerebrosidase|GALCERase|galactocerebroside beta-galactosidase|galactosylceramide beta-galactosidase|galactosylceraminidase|testis tissue sperm-binding protein Li 88E|testis tissue sperm-binding protein Li 89A', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=87933014, end_position_on_the_genomic_accession=87993665, orientation='minus', exon_count=19, OMIM=[606890], no_hdr0=''),
    2582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2582, CurrentID=0, Status='live', Symbol='GALE', Aliases=['SDR1E1'], description='UDP-galactose-4-epimerase', other_designations="UDP-glucose 4-epimerase|UDP galactose-4'-epimerase|UDP-GalNAc 4-epimerase|UDP-GlcNAc 4-epimerase|UDP-N-acetylgalactosamine 4-epimerase|UDP-N-acetylglucosamine 4-epimerase|epididymis secretory sperm binding protein|galactose-4-epimerase, UDP-|galactowaldenase|short chain dehydrogenase/reductase family 1E, member 1", map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23795599, end_position_on_the_genomic_accession=23800754, orientation='minus', exon_count=13, OMIM=[606953], no_hdr0=''),
    2583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2583, CurrentID=0, Status='live', Symbol='B4GALNT1', Aliases=['GALGT', 'GALNACT', 'GalNAc-T', 'SPG26'], description='beta-1,4-N-acetyl-galactosaminyltransferase 1', other_designations='beta-1,4 N-acetylgalactosaminyltransferase 1|GD2 synthase, GM2 synthase|GM2/GD2 synthase|UDP-Gal:betaGlcNAc beta-1,4-N-acetylgalactosaminyltransferase transferase 1|UDP-N-acetyl-alpha-D-galactosamine:(N-acetylneuraminyl)-galactosylglucosylceramide N-acetylgalactosaminyltransferase (GalNAc-T)|beta-1,4-N-acetyl-galactosaminyl transferase 1|beta1,4GalNAc-T', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57623409, end_position_on_the_genomic_accession=57633201, orientation='minus', exon_count=12, OMIM=[601873], no_hdr0=''),
    2584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2584, CurrentID=0, Status='live', Symbol='GALK1', Aliases=['GALK', 'GK1', 'HEL-S-19'], description='galactokinase 1', other_designations='galactokinase|epididymis secretory protein Li 19|galactose kinase', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75751469, end_position_on_the_genomic_accession=75765192, orientation='minus', exon_count=9, OMIM=[604313], no_hdr0=''),
    2585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2585, CurrentID=0, Status='live', Symbol='GALK2', Aliases=['GK2'], description='galactokinase 2', other_designations='N-acetylgalactosamine kinase|galNAc kinase', map_location='15q21.1-q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49155774, end_position_on_the_genomic_accession=49367883, orientation='plus', exon_count=19, OMIM=[137028], no_hdr0=''),
    2587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2587, CurrentID=0, Status='live', Symbol='GALR1', Aliases=['GALNR', 'GALNR1'], description='galanin receptor 1', other_designations='galanin receptor type 1|GAL1-R|GALR-1', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=77249848, end_position_on_the_genomic_accession=77277900, orientation='plus', exon_count=4, OMIM=[600377], no_hdr0=''),
    2588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2588, CurrentID=0, Status='live', Symbol='GALNS', Aliases=['GALNAC6S', 'GAS', 'GalN6S', 'MPS4A'], description='galactosamine (N-acetyl)-6-sulfatase', other_designations='N-acetylgalactosamine-6-sulfatase|N-acetylgalactosamine-6-sulfate sulfatase|chondroitinase|chondroitinsulfatase|galNAc6S sulfatase|galactosamine (N-acetyl)-6-sulfate sulfatase|galactose-6-sulfate sulfatase', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88813734, end_position_on_the_genomic_accession=88856966, orientation='minus', exon_count=16, OMIM=[612222], no_hdr0=''),
    2589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2589, CurrentID=0, Status='live', Symbol='GALNT1', Aliases=['GALNAC-T1'], description='polypeptide N-acetylgalactosaminyltransferase 1', other_designations='polypeptide N-acetylgalactosaminyltransferase 1|GalNAc transferase 1|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 1|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 1 (GalNAc-T1)|polypeptide GalNAc transferase 1|pp-GaNTase 1|protein-UDP acetylgalactosaminyltransferase 1', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35580922, end_position_on_the_genomic_accession=35711834, orientation='plus', exon_count=16, OMIM=[602273], no_hdr0=''),
    2590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2590, CurrentID=0, Status='live', Symbol='GALNT2', Aliases=['CDG2T', 'GalNAc-T2'], description='polypeptide N-acetylgalactosaminyltransferase 2', other_designations='polypeptide N-acetylgalactosaminyltransferase 2|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 2|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 2 (GalNAc-T2)|polypeptide GalNAc transferase 2|pp-GaNTase 2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230057789, end_position_on_the_genomic_accession=230282122, orientation='plus', exon_count=20, OMIM=[602274], no_hdr0=''),
    2591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2591, CurrentID=0, Status='live', Symbol='GALNT3', Aliases=['GalNAc-T3', 'HFTC', 'HFTC1', 'HHS'], description='polypeptide N-acetylgalactosaminyltransferase 3', other_designations='polypeptide N-acetylgalactosaminyltransferase 3|GalNAc transferase 3|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 3|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 3 (GalNAc-T3)|polypeptide GalNAc transferase 3|polypeptide GalNAc-transferase T3|pp-GaNTase 3|protein-UDP acetylgalactosaminyltransferase 3', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165747588, end_position_on_the_genomic_accession=165796352, orientation='minus', exon_count=13, OMIM=[601756], no_hdr0=''),
    2592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2592, CurrentID=0, Status='live', Symbol='GALT', Aliases=[], description='galactose-1-phosphate uridylyltransferase', other_designations='galactose-1-phosphate uridylyltransferase|UDP-glucose--hexose-1-phosphate uridylyltransferase|gal-1-P uridylyltransferase|galactose-1-phosphate uridyl transferase', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34646675, end_position_on_the_genomic_accession=34651035, orientation='plus', exon_count=11, OMIM=[606999], no_hdr0=''),
    2593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2593, CurrentID=0, Status='live', Symbol='GAMT', Aliases=['CCDS2', 'HEL-S-20', 'PIG2', 'TP53I2'], description='guanidinoacetate N-methyltransferase', other_designations='guanidinoacetate N-methyltransferase|epididymis secretory protein Li 20', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1397026, end_position_on_the_genomic_accession=1401542, orientation='minus', exon_count=6, OMIM=[601240], no_hdr0=''),
    2595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2595, CurrentID=0, Status='live', Symbol='GANC', Aliases=[], description='glucosidase alpha, neutral C', other_designations='neutral alpha-glucosidase C', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42273201, end_position_on_the_genomic_accession=42353666, orientation='plus', exon_count=28, OMIM=[104180], no_hdr0=''),
    2596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2596, CurrentID=0, Status='live', Symbol='GAP43', Aliases=['B-50', 'GAP-43', 'PP46'], description='growth associated protein 43', other_designations='neuromodulin|axonal membrane protein GAP-43|calmodulin-binding protein P-57|nerve growth-related peptide GAP43|neural phosphoprotein B-50|neuron growth-associated protein 43|protein F1', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=115623510, end_position_on_the_genomic_accession=115721485, orientation='plus', exon_count=4, OMIM=[162060], no_hdr0=''),
    2597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2597, CurrentID=0, Status='live', Symbol='GAPDH', Aliases=['G3PD', 'GAPD', 'HEL-S-162eP'], description='glyceraldehyde-3-phosphate dehydrogenase', other_designations='glyceraldehyde-3-phosphate dehydrogenase|OCAS, p38 component|Oct1 coactivator in S phase, 38 Kd component|aging-associated gene 9 protein|epididymis secretory sperm binding protein Li 162eP|peptidyl-cysteine S-nitrosylase GAPDH', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6534517, end_position_on_the_genomic_accession=6538371, orientation='plus', exon_count=10, OMIM=[138400], no_hdr0=''),
    2615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2615, CurrentID=0, Status='live', Symbol='LRRC32', Aliases=['CPPRDD', 'D11S833E', 'GARP'], description='leucine rich repeat containing 32', other_designations='transforming growth factor beta activator LRRC32|garpin|glycoprotein A repetitions predominant|leucine-rich repeat-containing protein 32', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76657524, end_position_on_the_genomic_accession=76670747, orientation='minus', exon_count=5, OMIM=[137207], no_hdr0=''),
    2617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2617, CurrentID=0, Status='live', Symbol='GARS1', Aliases=['CMT2D', 'DSMAV', 'GARS', 'GlyRS', 'HMN5', 'HMN5A', 'SMAD1', 'SMAJI'], description='glycyl-tRNA synthetase 1', other_designations='glycine--tRNA ligase|AP-4-A synthetase|Charcot-Marie-Tooth neuropathy 2D|Charcot-Marie-Tooth neuropathy, neuronal type, D|ap4A synthetase|diadenosine tetraphosphate synthetase', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30594735, end_position_on_the_genomic_accession=30634033, orientation='plus', exon_count=18, OMIM=[600287], no_hdr0=''),
    2618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2618, CurrentID=0, Status='live', Symbol='GART', Aliases=['AIRS', 'GARSF', 'PAIS', 'PGFT', 'PRGS', 'GART'], description='phosphoribosylglycinamide formyltransferase, phosphoribosylglycinamide synthetase, phosphoribosylaminoimidazole synthetase', other_designations='trifunctional purine biosynthetic protein adenosine-3|GAR transformylase|GARS-AIRS-GART|glycinamide ribonucleotide formyltransferase|glycinamide ribonucleotide synthetase-aminoimidazole ribonucleotide synthetase-glycinamide ribonucleotide transformylase', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33503931, end_position_on_the_genomic_accession=33542892, orientation='minus', exon_count=23, OMIM=[138440], no_hdr0=''),
    2619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2619, CurrentID=0, Status='live', Symbol='GAS1', Aliases=[], description='growth arrest specific 1', other_designations='growth arrest-specific protein 1|GAS-1|Growth arrest-specific gene-1', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=86944362, end_position_on_the_genomic_accession=86947506, orientation='minus', exon_count=1, OMIM=[139185], no_hdr0=''),
    2620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2620, CurrentID=0, Status='live', Symbol='GAS2', Aliases=['GAS-2'], description='growth arrest specific 2', other_designations='growth arrest-specific protein 2', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22627758, end_position_on_the_genomic_accession=22885930, orientation='plus', exon_count=20, OMIM=[602835], no_hdr0=''),
    2621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2621, CurrentID=0, Status='live', Symbol='GAS6', Aliases=['AXLLG', 'AXSF'], description='growth arrest specific 6', other_designations='growth arrest-specific protein 6|AXL receptor tyrosine kinase ligand|AXL stimulatory factor', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113820549, end_position_on_the_genomic_accession=113864076, orientation='minus', exon_count=15, OMIM=[600441], no_hdr0=''),
    2622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2622, CurrentID=0, Status='live', Symbol='GAS8', Aliases=['CILD33', 'DRC4', 'GAS11'], description='growth arrest specific 8', other_designations='dynein regulatory complex subunit 4|GAS-11|epididymis secretory sperm binding protein|growth arrest-specific protein 11|growth arrest-specific protein 8', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=90019629, end_position_on_the_genomic_accession=90044960, orientation='plus', exon_count=15, OMIM=[605178], no_hdr0=''),
    2623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2623, CurrentID=0, Status='live', Symbol='GATA1', Aliases=['ERYF1', 'GATA-1', 'GF-1', 'GF1', 'NF-E1', 'NFE1', 'XLANP', 'XLTDA', 'XLTT'], description='GATA binding protein 1', other_designations='erythroid transcription factor|GATA-binding factor 1|NF-E1 DNA-binding protein|erythroid transcription factor 1|globin transcription factor 1|nuclear factor, erythroid 1|transcription factor GATA1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48786590, end_position_on_the_genomic_accession=48794311, orientation='plus', exon_count=6, OMIM=[305371], no_hdr0=''),
    2624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2624, CurrentID=0, Status='live', Symbol='GATA2', Aliases=['DCML', 'IMD21', 'MONOMAC', 'NFE1B'], description='GATA binding protein 2', other_designations='endothelial transcription factor GATA-2', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128479422, end_position_on_the_genomic_accession=128493201, orientation='minus', exon_count=8, OMIM=[137295], no_hdr0=''),
    2625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2625, CurrentID=0, Status='live', Symbol='GATA3', Aliases=['HDR', 'HDRS'], description='GATA binding protein 3', other_designations='trans-acting T-cell-specific transcription factor GATA-3|GATA-binding factor 3', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=8045420, end_position_on_the_genomic_accession=8075198, orientation='plus', exon_count=8, OMIM=[131320], no_hdr0=''),
    2626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2626, CurrentID=0, Status='live', Symbol='GATA4', Aliases=['ASD2', 'TACHD', 'TOF', 'VSD1'], description='GATA binding protein 4', other_designations='transcription factor GATA-4|GATA-binding factor 4', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11676935, end_position_on_the_genomic_accession=11760002, orientation='plus', exon_count=9, OMIM=[600576], no_hdr0=''),
    2627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2627, CurrentID=0, Status='live', Symbol='GATA6', Aliases=[], description='GATA binding protein 6', other_designations='transcription factor GATA-6|GATA-binding factor 6', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=22169589, end_position_on_the_genomic_accession=22202528, orientation='plus', exon_count=7, OMIM=[601656], no_hdr0=''),
    2628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2628, CurrentID=0, Status='live', Symbol='GATM', Aliases=['AGAT', 'AT', 'CCDS3', 'FRTS1'], description='glycine amidinotransferase', other_designations='glycine amidinotransferase, mitochondrial|glycine amidinotransferase (L-arginine:glycine amidinotransferase)|testicular secretory protein Li 19|transamidinase', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45361124, end_position_on_the_genomic_accession=45402227, orientation='minus', exon_count=13, OMIM=[602360], no_hdr0=''),
    2629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2629, CurrentID=0, Status='live', Symbol='GBA', Aliases=['GBA1', 'GCB', 'GLUC'], description='glucosylceramidase beta', other_designations='lysosomal acid glucosylceramidase|D-glucosyl-N-acylsphingosine glucohydrolase|SGTase|acid beta-glucosidase|alglucerase|beta-GC|beta-glucocerebrosidase|cholesterol glucosyltransferase|cholesteryl-beta-glucosidase|glucosidase, beta, acid|glucosylceramidase-like protein|imiglucerase|lysosomal acid GCase|lysosomal glucocerebrosidase', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155234452, end_position_on_the_genomic_accession=155244627, orientation='minus', exon_count=12, OMIM=[606463], no_hdr0=''),
    2631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2631, CurrentID=0, Status='live', Symbol='NIPSNAP2', Aliases=['GBAS'], description='nipsnap homolog 2', other_designations='protein NipSnap homolog 2|4-nitrophenylphosphatase domain and non-neuronal SNAP25-like 2|glioblastoma amplified sequence', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55964585, end_position_on_the_genomic_accession=56000179, orientation='plus', exon_count=10, OMIM=[603004], no_hdr0=''),
    2632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2632, CurrentID=0, Status='live', Symbol='GBE1', Aliases=['APBD', 'GBE', 'GSD4'], description='1,4-alpha-glucan branching enzyme 1', other_designations='1,4-alpha-glucan-branching enzyme|amylo-(1,4 to 1,6) transglucosidase|amylo-(1,4 to 1,6) transglycosylase|brancher enzyme|glucan (1,4-alpha-), branching enzyme 1|glycogen branching enzyme', map_location='3p12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=81489703, end_position_on_the_genomic_accession=81761645, orientation='minus', exon_count=16, OMIM=[607839], no_hdr0=''),
    2633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2633, CurrentID=0, Status='live', Symbol='GBP1', Aliases=[], description='guanylate binding protein 1', other_designations='guanylate-binding protein 1|GBP-1|GTP-binding protein 1|guanine nucleotide-binding protein 1|guanylate binding protein 1, interferon-inducible, 67kDa|huGBP-1|interferon-induced guanylate-binding protein 1', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89052319, end_position_on_the_genomic_accession=89065208, orientation='minus', exon_count=11, OMIM=[600411], no_hdr0=''),
    2634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2634, CurrentID=0, Status='live', Symbol='GBP2', Aliases=[], description='guanylate binding protein 2', other_designations='guanylate-binding protein 2|GTP-binding protein 2|guanine nucleotide-binding protein 2|guanylate binding protein 2, interferon-inducible|interferon-induced guanylate-binding protein 2', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89106132, end_position_on_the_genomic_accession=89126114, orientation='minus', exon_count=11, OMIM=[600412], no_hdr0=''),
    2635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2635, CurrentID=0, Status='live', Symbol='GBP3', Aliases=[], description='guanylate binding protein 3', other_designations='guanylate-binding protein 3|GTP-binding protein 3|guanine nucleotide-binding protein 3|guanylate-binding protein 3 delta C', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89006677, end_position_on_the_genomic_accession=89022870, orientation='minus', exon_count=12, OMIM=[600413], no_hdr0=''),
    2636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2636, CurrentID=0, Status='live', Symbol='GBX1', Aliases=['Huh-17'], description='gastrulation brain homeobox 1', other_designations='homeobox protein GBX-1|gastrulation and brain-specific homeobox protein 1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151148009, end_position_on_the_genomic_accession=151167694, orientation='minus', exon_count=2, OMIM=[603354], no_hdr0=''),
    2637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2637, CurrentID=0, Status='live', Symbol='GBX2', Aliases=[], description='gastrulation brain homeobox 2', other_designations='homeobox protein GBX-2|gastrulation and brain-specific homeobox protein 2', map_location='2q37.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=236165236, end_position_on_the_genomic_accession=236168386, orientation='minus', exon_count=3, OMIM=[601135], no_hdr0=''),
    2638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2638, CurrentID=0, Status='live', Symbol='GC', Aliases=['DBP', 'DBP-maf', 'DBP/GC', 'GRD3', 'Gc-MAF', 'GcMAF', 'HEL-S-51', 'VDB', 'VDBG', 'VDBP'], description='GC vitamin D binding protein', other_designations='vitamin D-binding protein|epididymis secretory protein Li 51|gc protein-derived macrophage activating factor|gc-globulin|group-specific component (vitamin D binding protein)|vitamin D-binding alpha-globulin|vitamin D-binding protein-macrophage activating factor', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=71741693, end_position_on_the_genomic_accession=71805520, orientation='minus', exon_count=15, OMIM=[139200], no_hdr0=''),
    2639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2639, CurrentID=0, Status='live', Symbol='GCDH', Aliases=['ACAD5', 'GCD'], description='glutaryl-CoA dehydrogenase', other_designations='glutaryl-CoA dehydrogenase, mitochondrial|glutaryl-Coenzyme A dehydrogenase|truncated GCDH|truncated glutaryl-CoA dehydrogenase', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12891129, end_position_on_the_genomic_accession=12899999, orientation='plus', exon_count=12, OMIM=[608801], no_hdr0=''),
    2641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2641, CurrentID=0, Status='live', Symbol='GCG', Aliases=['GLP-1', 'GLP1', 'GLP2', 'GRPP'], description='glucagon', other_designations='pro-glucagon|glicentin-related polypeptide|glucagon-like peptide 1|glucagon-like peptide 2|preproglucagon', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=162142882, end_position_on_the_genomic_accession=162152247, orientation='minus', exon_count=6, OMIM=[138030], no_hdr0=''),
    2642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2642, CurrentID=0, Status='live', Symbol='GCGR', Aliases=['GGR', 'GL-R', 'MVAH'], description='glucagon receptor', other_designations='glucagon receptor', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81804078, end_position_on_the_genomic_accession=81814008, orientation='plus', exon_count=15, OMIM=[138033], no_hdr0=''),
    2643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2643, CurrentID=0, Status='live', Symbol='GCH1', Aliases=['DYT14', 'DYT5', 'DYT5a', 'GCH', 'GTP-CH-1', 'GTPCH1', 'HPABH4B'], description='GTP cyclohydrolase 1', other_designations="GTP cyclohydrolase 1|GTP cyclohydrolase I|GTP-CH-I|dystonia 14|guanosine 5'-triphosphate cyclohydrolase I", map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54842016, end_position_on_the_genomic_accession=54902826, orientation='minus', exon_count=7, OMIM=[600225], no_hdr0=''),
    2644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2644, CurrentID=0, Status='live', Symbol='GCHFR', Aliases=['GFRP', 'HsT16933', 'P35'], description='GTP cyclohydrolase I feedback regulator', other_designations='GTP cyclohydrolase 1 feedback regulatory protein|GTP cyclohydrolase I feedback regulatory protein', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40764068, end_position_on_the_genomic_accession=40767708, orientation='plus', exon_count=3, OMIM=[602437], no_hdr0=''),
    2645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2645, CurrentID=0, Status='live', Symbol='GCK', Aliases=['FGQTL3', 'GK', 'GLK', 'HHF3', 'HK4', 'HKIV', 'HXKP', 'LGLK', 'MODY2', 'PNDM1'], description='glucokinase', other_designations='hexokinase-4|ATP:D-hexose 6-phosphotransferase|HK IV|glucokinase (hexokinase 4)|hexokinase D, pancreatic isozyme|hexokinase type IV', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44143213, end_position_on_the_genomic_accession=44189439, orientation='minus', exon_count=15, OMIM=[138079], no_hdr0=''),
    2646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2646, CurrentID=0, Status='live', Symbol='GCKR', Aliases=['FGQTL5', 'GKRP'], description='glucokinase regulator', other_designations='glucokinase regulatory protein|glucokinase (hexokinase 4) regulator|hexokinase 4 regulator', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27496839, end_position_on_the_genomic_accession=27523689, orientation='plus', exon_count=20, OMIM=[600842], no_hdr0=''),
    2647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2647, CurrentID=0, Status='live', Symbol='BLOC1S1', Aliases=['BLOS1', 'BORCS1', 'GCN5L1', 'MICoA', 'RT14'], description='biogenesis of lysosomal organelles complex 1 subunit 1', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 1|BLOC-1 subunit 1|GCN5 (general control of amino-acid synthesis, yeast, homolog)-like 1|GCN5 general control of amino-acid synthesis 5-like 1|GCN5-like protein 1|MTA1-interacting coactivator', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55716046, end_position_on_the_genomic_accession=55719703, orientation='plus', exon_count=5, OMIM=[601444], no_hdr0=''),
    2648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2648, CurrentID=0, Status='live', Symbol='KAT2A', Aliases=['GCN5', 'GCN5L2', 'PCAF-b', 'hGCN5'], description='lysine acetyltransferase 2A', other_designations='histone acetyltransferase KAT2A|GCN5 (general control of amino-acid synthesis, yeast, homolog)-like 2|General control of amino acid synthesis, yeast, homolog-like 2|K(lysine) acetyltransferase 2A|STAF97|general control of amino acid synthesis protein 5-like 2|histone acetyltransferase GCN5|histone glutaryltransferase KAT2A|histone succinyltransferase KAT2A|hsGCN5', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42113111, end_position_on_the_genomic_accession=42121367, orientation='minus', exon_count=18, OMIM=[602301], no_hdr0=''),
    2649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2649, CurrentID=0, Status='live', Symbol='NR6A1', Aliases=['CT150', 'GCNF', 'GCNF1', 'NR61', 'RTR', 'hGCNF', 'hRTR'], description='nuclear receptor subfamily 6 group A member 1', other_designations='nuclear receptor subfamily 6 group A member 1|germ cell nuclear factor variant 1|retinoic acid receptor-related testis-associated receptor|retinoid receptor-related testis-specific receptor', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124517275, end_position_on_the_genomic_accession=124771311, orientation='minus', exon_count=11, OMIM=[602778], no_hdr0=''),
    2650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2650, CurrentID=0, Status='live', Symbol='GCNT1', Aliases=['C2GNT', 'C2GNT-L', 'C2GNT1', 'G6NT', 'NACGT2', 'NAGCT2'], description='glucosaminyl (N-acetyl) transferase 1', other_designations='beta-1,3-galactosyl-O-glycosyl-glycoprotein beta-1,6-N-acetylglucosaminyltransferase|beta-1,6-N-acetylglucosaminyltransferase|core 2 GnT|core 2 beta-1,6-N-acetylglucosaminyltransferase I|core 2 beta1,6 N-acetylglucosaminyltransferase-I|core 2 branching enzyme|core2-GlcNAc-transferase|glucosaminyl (N-acetyl) transferase 1, core 2 (beta-1,6-N-acetylglucosaminyltransferase)', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=76441666, end_position_on_the_genomic_accession=76507416, orientation='plus', exon_count=6, OMIM=[600391], no_hdr0=''),
    2651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2651, CurrentID=0, Status='live', Symbol='GCNT2', Aliases=['CCAT', 'CTRCT13C', 'GCNT5', 'IGNT', 'II', 'NACGT1', 'NAGCT1', 'ULG3', 'bA360O19.2', 'bA421M1.1', 'GCNT2'], description='glucosaminyl (N-acetyl) transferase 2 (I blood group)', other_designations='N-acetyllactosaminide beta-1,6-N-acetylglucosaminyl-transferase|I beta-1,6-N-acetylglucosaminyltransferase|Ii blood group|beta-1,6-N-acetylglucosaminyltransferase 2|glucosaminyl (N-acetyl) transferase 2, I-branching enzyme (I blood group)', map_location='6p24.3-p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10521283, end_position_on_the_genomic_accession=10629368, orientation='plus', exon_count=12, OMIM=[600429], no_hdr0=''),
    2652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2652, CurrentID=0, Status='live', Symbol='OPN1MW', Aliases=['CBBM', 'CBD', 'COD5', 'GCP', 'GOP1', 'OPN1MW'], description='opsin 1, medium wave sensitive', other_designations='medium-wave-sensitive opsin 1|cone dystrophy 5 (X-linked)|green cone photoreceptor pigment|green cone pigment|green-sensitive opsin|opsin 1 (cone pigments), medium-wave-sensitive|photopigment apoprotein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154182596, end_position_on_the_genomic_accession=154196861, orientation='plus', exon_count=6, OMIM=[300821], no_hdr0=''),
    2653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2653, CurrentID=0, Status='live', Symbol='GCSH', Aliases=['GCE', 'NKH'], description='glycine cleavage system protein H', other_designations='glycine cleavage system H protein, mitochondrial|glycine cleavage system protein H (aminomethyl carrier)|lipoic acid-containing protein|mitochondrial glycine cleavage system H-protein', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81081945, end_position_on_the_genomic_accession=81096395, orientation='minus', exon_count=6, OMIM=[238330], no_hdr0=''),
    2657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2657, CurrentID=0, Status='live', Symbol='GDF1', Aliases=['CERS1', 'CHTD6', 'DORV', 'DTGA3', 'LAG1', 'LASS1', 'RAI', 'UOG1'], description='growth differentiation factor 1', other_designations='embryonic growth/differentiation factor 1|Ceramide synthase 1|LAG1 longevity assurance homolog 1|Longevity assurance gene 1 protein homolog 1|Protein UOG-1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18868545, end_position_on_the_genomic_accession=18896158, orientation='minus', exon_count=8, OMIM=[602880], no_hdr0=''),
    2658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2658, CurrentID=0, Status='live', Symbol='GDF2', Aliases=['BMP-9', 'BMP9', 'HHT5'], description='growth differentiation factor 2', other_designations='growth/differentiation factor 2|bone morphogenetic protein 9', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47322454, end_position_on_the_genomic_accession=47327588, orientation='plus', exon_count=2, OMIM=[605120], no_hdr0=''),
    2660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2660, CurrentID=0, Status='live', Symbol='MSTN', Aliases=['GDF8', 'MSLHP'], description='myostatin', other_designations='growth/differentiation factor 8', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190055700, end_position_on_the_genomic_accession=190062729, orientation='minus', exon_count=3, OMIM=[601788], no_hdr0=''),
    2661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2661, CurrentID=0, Status='live', Symbol='GDF9', Aliases=['POF14'], description='growth differentiation factor 9', other_designations='growth/differentiation factor 9', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132861181, end_position_on_the_genomic_accession=132866651, orientation='minus', exon_count=6, OMIM=[601918], no_hdr0=''),
    2662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2662, CurrentID=0, Status='live', Symbol='GDF10', Aliases=['BIP', 'BMP-3b', 'BMP3B'], description='growth differentiation factor 10', other_designations='growth/differentiation factor 10|bone morphogenetic protein 3B|bone-inducing protein', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47300197, end_position_on_the_genomic_accession=47313577, orientation='plus', exon_count=3, OMIM=[601361], no_hdr0=''),
    2664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2664, CurrentID=0, Status='live', Symbol='GDI1', Aliases=['1A', 'GDIL', 'MRX41', 'MRX48', 'OPHN2', 'RABGD1A', 'RABGDIA', 'XAP-4'], description='GDP dissociation inhibitor 1', other_designations='rab GDP dissociation inhibitor alpha|GDI-1|guanosine diphosphate dissociation inhibitor 1|mental retardation, X-linked 48|oligophrenin-2|protein XAP-4|rab GDI alpha|rab GDP-dissociation inhibitor, alpha|testis secretory sperm-binding protein Li 208a', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154437154, end_position_on_the_genomic_accession=154443467, orientation='plus', exon_count=11, OMIM=[300104], no_hdr0=''),
    2665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2665, CurrentID=0, Status='live', Symbol='GDI2', Aliases=['HEL-S-46e', 'RABGDIB'], description='GDP dissociation inhibitor 2', other_designations='rab GDP dissociation inhibitor beta|GDI-2|epididymis secretory sperm binding protein Li 46e|guanosine diphosphate dissociation inhibitor 2|rab GDI beta|rab GDP-dissociation inhibitor, beta', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5765222, end_position_on_the_genomic_accession=5813434, orientation='minus', exon_count=12, OMIM=[600767], no_hdr0=''),
    2668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2668, CurrentID=0, Status='live', Symbol='GDNF', Aliases=['ATF', 'ATF1', 'ATF2', 'HFB1-GDNF', 'HSCR3'], description='glial cell derived neurotrophic factor', other_designations='glial cell line-derived neurotrophic factor|astrocyte-derived trophic factor', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=37812677, end_position_on_the_genomic_accession=37840044, orientation='minus', exon_count=6, OMIM=[600837], no_hdr0=''),
    2669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2669, CurrentID=0, Status='live', Symbol='GEM', Aliases=['KIR'], description='GTP binding protein overexpressed in skeletal muscle', other_designations='GTP-binding protein GEM|GTP-binding mitogen-induced T-cell protein|RAS-like protein KIR|kinase-inducible Ras-like protein', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94249249, end_position_on_the_genomic_accession=94262345, orientation='minus', exon_count=5, OMIM=[600164], no_hdr0=''),
    2670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2670, CurrentID=0, Status='live', Symbol='GFAP', Aliases=['ALXDRD'], description='glial fibrillary acidic protein', other_designations='glial fibrillary acidic protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44903159, end_position_on_the_genomic_accession=44915552, orientation='minus', exon_count=10, OMIM=[137780], no_hdr0=''),
    2671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2671, CurrentID=0, Status='live', Symbol='GFER', Aliases=['ALR', 'ERV1', 'HERV1', 'HPO', 'HPO1', 'HPO2', 'HSS', 'MMCHD', 'MPMCD'], description='growth factor, augmenter of liver regeneration', other_designations='FAD-linked sulfhydryl oxidase ALR|ERV1 homolog|erv1-like growth factor|hepatic regenerative stimulation substance|hepatopoietin protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1984193, end_position_on_the_genomic_accession=1987749, orientation='plus', exon_count=3, OMIM=[600924], no_hdr0=''),
    2672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2672, CurrentID=0, Status='live', Symbol='GFI1', Aliases=['GFI-1A', 'SCN2', 'ZNF163', 'GFI1'], description='growth factor independent 1 transcriptional repressor', other_designations='zinc finger protein Gfi-1|growth factor independence-1|growth factor independent 1 transcription repressor|growth factor independent protein 1|zinc finger protein 163', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92473043, end_position_on_the_genomic_accession=92486925, orientation='minus', exon_count=11, OMIM=[600871], no_hdr0=''),
    2673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2673, CurrentID=0, Status='live', Symbol='GFPT1', Aliases=['CMS12', 'CMSTA1', 'GFA', 'GFAT', 'GFAT 1', 'GFAT1', 'GFAT1m', 'GFPTL', 'MSLG', 'GFPT1'], description='glutamine--fructose-6-phosphate transaminase 1', other_designations='glutamine--fructose-6-phosphate aminotransferase [isomerizing] 1|D-fructose-6-phosphate amidotransferase 1|glucosamine--fructose-6-phosphate aminotransferase [isomerizing] 1|glutamine:fructose-6-phosphate amidotransferase 1|hexosephosphate aminotransferase 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69319780, end_position_on_the_genomic_accession=69387227, orientation='minus', exon_count=21, OMIM=[138292], no_hdr0=''),
    2674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2674, CurrentID=0, Status='live', Symbol='GFRA1', Aliases=['GDNFR', 'GDNFRA', 'GFR-ALPHA-1', 'GFRalpha-1', 'RET1L', 'RETL1', 'TRNR1'], description='GDNF family receptor alpha 1', other_designations='GDNF family receptor alpha-1|GDNF receptor alpha 1d|GDNF receptor alpha 1e|GDNFR-alpha-1|GPI-linked anchor protein|Glial cell line-derived neurotrophic factor receptor alpha|PI-linked cell-surface accessory protein|RET ligand 1|TGF-beta-related neurotrophic factor receptor 1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116056925, end_position_on_the_genomic_accession=116274705, orientation='minus', exon_count=16, OMIM=[601496], no_hdr0=''),
    2675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2675, CurrentID=0, Status='live', Symbol='GFRA2', Aliases=['GDNFRB', 'NRTNR-ALPHA', 'NTNRA', 'RETL2', 'TRNR2'], description='GDNF family receptor alpha 2', other_designations='GDNF family receptor alpha-2|GDNF receptor beta|GDNFR-alpha-2|GDNFR-beta|GFR-alpha 2|NTNR-alpha|PI-linked cell-surface accessory protein|RET ligand 2|TGF-beta-related neurotrophic factor receptor 2|TRN receptor, GPI-anchored|glial cell line derived neurotrophic factor receptor, beta|neurturin receptor alpha', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=21690398, end_position_on_the_genomic_accession=21789296, orientation='minus', exon_count=11, OMIM=[601956], no_hdr0=''),
    2676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2676, CurrentID=0, Status='live', Symbol='GFRA3', Aliases=['GDNFR3'], description='GDNF family receptor alpha 3', other_designations='GDNF family receptor alpha-3|GDNF receptor alpha-3|GDNFR-alpha-3|GFR-alpha-3|GPI-linked receptor|glial cell line-derived neurotrophic factor receptor alpha-3', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138252380, end_position_on_the_genomic_accession=138274621, orientation='minus', exon_count=8, OMIM=[605710], no_hdr0=''),
    2677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2677, CurrentID=0, Status='live', Symbol='GGCX', Aliases=['VKCFD1'], description='gamma-glutamyl carboxylase', other_designations='vitamin K-dependent gamma-carboxylase|peptidyl-glutamate 4-carboxylase', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85544720, end_position_on_the_genomic_accession=85561527, orientation='minus', exon_count=15, OMIM=[137167], no_hdr0=''),
    2678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2678, CurrentID=0, Status='live', Symbol='GGT1', Aliases=['CD224', 'D22S672', 'D22S732', 'GGT', 'GGT 1', 'GGTD', 'GTG'], description='gamma-glutamyltransferase 1', other_designations='glutathione hydrolase 1 proenzyme|gamma-glutamyltranspeptidase 1|leukotriene-C4 hydrolase|testicular tissue protein Li 73', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24583750, end_position_on_the_genomic_accession=24628996, orientation='plus', exon_count=18, OMIM=[612346], no_hdr0=''),
    2681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2681, CurrentID=0, Status='live', Symbol='GGTA1', Aliases=['GGTAP', 'GLYT2', 'a1/3GTP', 'GGTA1'], description='glycoprotein alpha-galactosyltransferase 1 (inactive)', other_designations='inactive N-acetyllactosaminide alpha-1,3-galactosyltransferase|glycoprotein alpha-galactosyltransferase 1, pseudogene|glycoprotein, alpha-galactosyltransferase 1|truncated alpha-1,3-galactosyltransferase', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121444990, end_position_on_the_genomic_accession=121499844, orientation='minus', exon_count=11, OMIM=[104175], no_hdr0=''),
    2683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2683, CurrentID=0, Status='live', Symbol='B4GALT1', Aliases=['B4GAL-T1', 'CDG2D', 'GGTB2', 'GT1', 'GTB', 'beta4Gal-T1'], description='beta-1,4-galactosyltransferase 1', other_designations='beta-1,4-galactosyltransferase 1|N-acetyllactosamine synthase|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 1|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase, polypeptide 1|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 1|beta-1,4-GalTase 1|beta-N-acetylglucosaminyl-glycolipid beta-1,4-galactosyltransferase|beta-N-acetylglucosaminylglycopeptide beta-1,4-galactosyltransferase|glycoprotein-4-beta-galactosyltransferase 2|lactose synthase A protein|nal synthase|neolactotriaosylceramide beta-1,4-galactosyltransferase', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33104077, end_position_on_the_genomic_accession=33167336, orientation='minus', exon_count=7, OMIM=[137060], no_hdr0=''),
    2686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2686, CurrentID=0, Status='live', Symbol='GGT7', Aliases=['D20S101', 'GGT4', 'GGTL3', 'GGTL5'], description='gamma-glutamyltransferase 7', other_designations='glutathione hydrolase 7|GGT 7|gamma-glutamyltransferase 4|gamma-glutamyltransferase-like 3|gamma-glutamyltransferase-like 5|gamma-glutamyltranspeptidase 7|gamma-glutamyltranspeptidase-like 3', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34844720, end_position_on_the_genomic_accession=34872857, orientation='minus', exon_count=18, OMIM=[612342], no_hdr0=''),
    2687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2687, CurrentID=0, Status='live', Symbol='GGT5', Aliases=['GGL', 'GGT 5', 'GGT-REL', 'GGTLA1'], description='gamma-glutamyltransferase 5', other_designations='glutathione hydrolase 5 proenzyme|gamma-glutamyl cleaving enzyme|gamma-glutamyl transpeptidase-related enzyme|gamma-glutamyl transpeptidase-related protein|gamma-glutamyltransferase-like activity 1|gamma-glutamyltranspeptidase 5|leukotriene-C4 hydrolase', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24219654, end_position_on_the_genomic_accession=24245142, orientation='minus', exon_count=14, OMIM=[137168], no_hdr0=''),
    2688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2688, CurrentID=0, Status='live', Symbol='GH1', Aliases=['GH', 'GH-N', 'GHB5', 'GHN', 'IGHD1A', 'IGHD1B', 'IGHD2', 'hGH-N'], description='growth hormone 1', other_designations='somatotropin|growth hormone B5|pituitary growth hormone', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63917203, end_position_on_the_genomic_accession=63918839, orientation='minus', exon_count=5, OMIM=[139250], no_hdr0=''),
    2689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2689, CurrentID=0, Status='live', Symbol='GH2', Aliases=['GH-V', 'GHB2', 'GHL', 'GHV', 'hGH-V'], description='growth hormone 2', other_designations='growth hormone variant|growth hormone B2|placenta-specific growth hormone|placental-specific growth hormone', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63880215, end_position_on_the_genomic_accession=63881944, orientation='minus', exon_count=5, OMIM=[139240], no_hdr0=''),
    2690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2690, CurrentID=0, Status='live', Symbol='GHR', Aliases=['GHBP', 'GHIP'], description='growth hormone receptor', other_designations='growth hormone receptor|GH receptor|growth hormone binding protein|mutant growth hormone receptor|serum binding protein|somatotropin receptor|truncated growth hormone receptor', map_location='5p13.1-p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=42423439, end_position_on_the_genomic_accession=42721878, orientation='plus', exon_count=18, OMIM=[600946], no_hdr0=''),
    2691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2691, CurrentID=0, Status='live', Symbol='GHRH', Aliases=['GHRF', 'GRF', 'INN'], description='growth hormone releasing hormone', other_designations='somatoliberin|growth hormone releasing factor|sermorelin|somatocrinin|somatorelin', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37251086, end_position_on_the_genomic_accession=37261814, orientation='minus', exon_count=5, OMIM=[139190], no_hdr0=''),
    2692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2692, CurrentID=0, Status='live', Symbol='GHRHR', Aliases=['GHRFR', 'GRFR', 'IGHD1B', 'IGHD4'], description='growth hormone releasing hormone receptor', other_designations='growth hormone-releasing hormone receptor|GHRH receptor|GRF receptor', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30963953, end_position_on_the_genomic_accession=30979528, orientation='plus', exon_count=13, OMIM=[139191], no_hdr0=''),
    2693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2693, CurrentID=0, Status='live', Symbol='GHSR', Aliases=['GHDP'], description='growth hormone secretagogue receptor', other_designations='growth hormone secretagogue receptor type 1|GH-releasing peptide receptor|GHRP|GHS-R|ghrelin receptor', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172443291, end_position_on_the_genomic_accession=172448456, orientation='minus', exon_count=2, OMIM=[601898], no_hdr0=''),
    2694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2694, CurrentID=0, Status='live', Symbol='CBLIF', Aliases=['GIF', 'IF', 'IFMH', 'INF', 'TCN3'], description='cobalamin binding intrinsic factor', other_designations='cobalamin binding intrinsic factor|gastric intrinsic factor (vitamin B synthesis)|intrinsic factor', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59829268, end_position_on_the_genomic_accession=59845501, orientation='minus', exon_count=9, OMIM=[609342], no_hdr0=''),
    2695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2695, CurrentID=0, Status='live', Symbol='GIP', Aliases=[], description='gastric inhibitory polypeptide', other_designations='gastric inhibitory polypeptide|glucose-dependent insulinotropic polypeptide|incretin hormone', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48958554, end_position_on_the_genomic_accession=48968596, orientation='minus', exon_count=6, OMIM=[137240], no_hdr0=''),
    2696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2696, CurrentID=0, Status='live', Symbol='GIPR', Aliases=['PGQTL2'], description='gastric inhibitory polypeptide receptor', other_designations='gastric inhibitory polypeptide receptor|GIP-R|glucose-dependent insulinotropic polypeptide receptor', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45668187, end_position_on_the_genomic_accession=45683722, orientation='plus', exon_count=16, OMIM=[137241], no_hdr0=''),
    2697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2697, CurrentID=0, Status='live', Symbol='GJA1', Aliases=['AVSD3', 'CMDR', 'CX43', 'EKVP', 'EKVP3', 'GJAL', 'HLHS1', 'HSS', 'ODDD', 'PPKCA'], description='gap junction protein alpha 1', other_designations='gap junction alpha-1 protein|connexin-43|gap junction 43 kDa heart protein|gap junction protein, alpha 1, 43kDa', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=121435646, end_position_on_the_genomic_accession=121449727, orientation='plus', exon_count=2, OMIM=[121014], no_hdr0=''),
    2700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2700, CurrentID=0, Status='live', Symbol='GJA3', Aliases=['CTRCT14', 'CX46', 'CZP3'], description='gap junction protein alpha 3', other_designations='gap junction alpha-3 protein|connexin-46|gap junction alpha 3|gap junction protein, alpha 3, 46kDa', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20138252, end_position_on_the_genomic_accession=20161327, orientation='minus', exon_count=3, OMIM=[121015], no_hdr0=''),
    2701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2701, CurrentID=0, Status='live', Symbol='GJA4', Aliases=['CX37'], description='gap junction protein alpha 4', other_designations='gap junction alpha-4 protein|connexin-37|gap junction protein, alpha 4, 37kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34792958, end_position_on_the_genomic_accession=34795747, orientation='plus', exon_count=3, OMIM=[121012], no_hdr0=''),
    2702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2702, CurrentID=0, Status='live', Symbol='GJA5', Aliases=['ATFB11', 'CX40'], description='gap junction protein alpha 5', other_designations='gap junction alpha-5 protein|connexin 40|gap junction protein alpha 5 40kDa', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147756199, end_position_on_the_genomic_accession=147781127, orientation='minus', exon_count=4, OMIM=[121013], no_hdr0=''),
    2703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2703, CurrentID=0, Status='live', Symbol='GJA8', Aliases=['CAE', 'CAE1', 'CTRCT1', 'CX50', 'CZP1', 'MP70'], description='gap junction protein alpha 8', other_designations='gap junction alpha-8 protein|cell surface glycoprotein|connexin 50|gap junction alpha 8|gap junction membrane channel protein alpha-8|gap junction protein alpha 8 50kDa|lens fiber protein MP70|lens intrinsic membrane protein MP70', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147902795, end_position_on_the_genomic_accession=147915287, orientation='plus', exon_count=3, OMIM=[600897], no_hdr0=''),
    2705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2705, CurrentID=0, Status='live', Symbol='GJB1', Aliases=['CMTX', 'CMTX1', 'CX32'], description='gap junction protein beta 1', other_designations='gap junction beta-1 protein|GAP junction 28 kDa liver protein|connexin-32|gap junction protein, beta 1, 32kDa', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71215239, end_position_on_the_genomic_accession=71225516, orientation='plus', exon_count=4, OMIM=[304040], no_hdr0=''),
    2706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2706, CurrentID=0, Status='live', Symbol='GJB2', Aliases=['BAPS', 'CX26', 'DFNA3', 'DFNA3A', 'DFNB1', 'DFNB1A', 'HID', 'KID', 'NSRD1', 'PPK'], description='gap junction protein beta 2', other_designations='gap junction beta-2 protein|connexin 26|gap junction beta 2 proteinc|gap junction protein, beta 2, 26kDa|mutant gap junction beta 2 protein|mutant gap junction protein beta 2', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20187470, end_position_on_the_genomic_accession=20192938, orientation='minus', exon_count=3, OMIM=[121011], no_hdr0=''),
    2707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2707, CurrentID=0, Status='live', Symbol='GJB3', Aliases=['CX31', 'DFNA2', 'DFNA2B', 'EKV', 'EKVP1'], description='gap junction protein beta 3', other_designations='gap junction beta-3 protein|connexin 31|gap junction protein, beta 3, 31kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34781214, end_position_on_the_genomic_accession=34786364, orientation='plus', exon_count=3, OMIM=[603324], no_hdr0=''),
    2709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2709, CurrentID=0, Status='live', Symbol='GJB5', Aliases=['CX31.1'], description='gap junction protein beta 5', other_designations='gap junction beta-5 protein|gap junction protein, beta 5 (connexin 31.1)|gap junction protein, beta 5, 31.1kDa|gap junctional protein cx31.1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34754777, end_position_on_the_genomic_accession=34758513, orientation='plus', exon_count=2, OMIM=[604493], no_hdr0=''),
    2710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2710, CurrentID=0, Status='live', Symbol='GK', Aliases=['GK1D', 'GK'], description='glycerol kinase', other_designations='glycerol kinase|ATP:glycerol 3-phosphotransferase|glycerokinase', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30653348, end_position_on_the_genomic_accession=30731462, orientation='plus', exon_count=24, OMIM=[300474], no_hdr0=''),
    2712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2712, CurrentID=0, Status='live', Symbol='GK2', Aliases=['GKP2', 'GKTA'], description='glycerol kinase 2', other_designations='glycerol kinase 2|ATP:glycerol 3-phosphotransferase 2|glycerokinase 2|glycerol kinase pseudogene 2|glycerol kinase testis specific 2|testis tissue sperm-binding protein Li 77m', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=79406361, end_position_on_the_genomic_accession=79408228, orientation='minus', exon_count=1, OMIM=[600148], no_hdr0=''),
    2717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2717, CurrentID=0, Status='live', Symbol='GLA', Aliases=['GALA'], description='galactosidase alpha', other_designations='alpha-galactosidase A|agalsidase alfa|alpha-D-galactosidase A|alpha-D-galactoside galactohydrolase 1|alpha-gal A|galactosylgalactosylglucosylceramidase GLA|melibiase', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101397803, end_position_on_the_genomic_accession=101407925, orientation='minus', exon_count=8, OMIM=[300644], no_hdr0=''),
    2719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2719, CurrentID=0, Status='live', Symbol='GPC3', Aliases=['DGSX', 'GTR2-2', 'MXR7', 'OCI-5', 'SDYS', 'SGB', 'SGBS', 'SGBS1'], description='glypican 3', other_designations='glypican-3|glypican proteoglycan 3|heparan sulphate proteoglycan|intestinal protein OCI-5|secreted glypican-3', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=133535745, end_position_on_the_genomic_accession=133985616, orientation='minus', exon_count=11, OMIM=[300037], no_hdr0=''),
    2720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2720, CurrentID=0, Status='live', Symbol='GLB1', Aliases=['EBP', 'ELNR1', 'MPS4B'], description='galactosidase beta 1', other_designations='beta-galactosidase|acid beta-galactosidase|elastin binding protein|elastin receptor 1, 67kDa|lactase', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32961108, end_position_on_the_genomic_accession=33097146, orientation='minus', exon_count=19, OMIM=[611458], no_hdr0=''),
    2729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2729, CurrentID=0, Status='live', Symbol='GCLC', Aliases=['GCL', 'GCS', 'GLCL', 'GLCLC'], description='glutamate-cysteine ligase catalytic subunit', other_designations='glutamate--cysteine ligase catalytic subunit|GCS heavy chain|gamma-ECS|gamma-glutamylcysteine synthetase', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53497341, end_position_on_the_genomic_accession=53545101, orientation='minus', exon_count=16, OMIM=[606857], no_hdr0=''),
    2730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2730, CurrentID=0, Status='live', Symbol='GCLM', Aliases=['GLCLR'], description='glutamate-cysteine ligase modifier subunit', other_designations='glutamate--cysteine ligase regulatory subunit|GCS light chain|GSC light chain|gamma-ECS regulatory subunit|gamma-glutamylcysteine synthetase regulatory subunit|glutamate-cysteine ligase (gamma-glutamylcysteine synthetase), regulatory (30.8kD)|glutamate-cysteine ligase modifier subunit delta2 alternative splicing|glutamate-cysteine ligase regulatory protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93885199, end_position_on_the_genomic_accession=93910370, orientation='minus', exon_count=9, OMIM=[601176], no_hdr0=''),
    2731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2731, CurrentID=0, Status='live', Symbol='GLDC', Aliases=['GCE', 'GCSP', 'HYGN1'], description='glycine decarboxylase', other_designations='glycine dehydrogenase (decarboxylating), mitochondrial|glycine cleavage system protein P|glycine decarboxylase P-protein|glycine dehydrogenase (aminomethyl-transferring)|glycine dehydrogenase [decarboxylating], mitochondrial|nonketotic hyperglycinemia', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6532467, end_position_on_the_genomic_accession=6645729, orientation='minus', exon_count=25, OMIM=[238300], no_hdr0=''),
    2733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2733, CurrentID=0, Status='live', Symbol='GLE1', Aliases=['CAAHC', 'CAAHDL', 'LCCS', 'LCCS1', 'hGLE1', 'GLE1'], description='GLE1 RNA export mediator', other_designations='nucleoporin GLE1|GLE1 RNA export mediator homolog|GLE1-like protein|GLE1-like, RNA export mediator', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128504692, end_position_on_the_genomic_accession=128542292, orientation='plus', exon_count=19, OMIM=[603371], no_hdr0=''),
    2734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2734, CurrentID=0, Status='live', Symbol='GLG1', Aliases=['CFR-1', 'ESL-1', 'MG-160', 'MG160'], description='golgi glycoprotein 1', other_designations='Golgi apparatus protein 1|E-selectin ligand 1|cysteine-rich fibroblast growth factor receptor|golgi sialoglycoprotein MG-160', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74447440, end_position_on_the_genomic_accession=74607114, orientation='minus', exon_count=27, OMIM=[600753], no_hdr0=''),
    2735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2735, CurrentID=0, Status='live', Symbol='GLI1', Aliases=['GLI', 'PAPA8', 'PPD1'], description='GLI family zinc finger 1', other_designations='zinc finger protein GLI1|GLI-Kruppel family member GLI1|glioma-associated oncogene 1|glioma-associated oncogene homolog 1 (zinc finger protein)|oncogene GLI', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57459785, end_position_on_the_genomic_accession=57472451, orientation='plus', exon_count=13, OMIM=[165220], no_hdr0=''),
    2736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2736, CurrentID=0, Status='live', Symbol='GLI2', Aliases=['CJS', 'HPE9', 'PHS2', 'THP1', 'THP2'], description='GLI family zinc finger 2', other_designations='zinc finger protein GLI2|GLI family zinc finger protein 2|GLI-Kruppel family member GLI2|glioma-associated oncogene family zinc finger 2|oncogene GLI2|tax helper protein 1|tax helper protein 2|tax-responsive element-2 holding protein|tax-responsive element-25-bp sequence binding protein', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120735868, end_position_on_the_genomic_accession=120992653, orientation='plus', exon_count=19, OMIM=[165230], no_hdr0=''),
    2737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2737, CurrentID=0, Status='live', Symbol='GLI3', Aliases=['ACLS', 'GCPS-190', 'GLI3FL', 'PAP-A', 'PAPA', 'PAPA1', 'PAPB', 'PHS', 'PPDIV', 'GLI3'], description='GLI family zinc finger 3', other_designations='transcriptional activator GLI3|GLI-Kruppel family member GLI3|glioma-associated oncogene family zinc finger 3|oncogene GLI3|zinc finger protein GLI3', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=41960949, end_position_on_the_genomic_accession=42237209, orientation='minus', exon_count=17, OMIM=[165240], no_hdr0=''),
    2738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2738, CurrentID=0, Status='live', Symbol='GLI4', Aliases=['HKR4', 'ZNF928'], description='GLI family zinc finger 4', other_designations='zinc finger protein GLI4|GLI-Kruppel family member GLI4 (oncogene HKR4)|glioma-associated oncogene family zinc finger 4|krueppel-related zinc finger protein 4', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143267445, end_position_on_the_genomic_accession=143276931, orientation='plus', exon_count=4, OMIM=[165280], no_hdr0=''),
    2739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2739, CurrentID=0, Status='live', Symbol='GLO1', Aliases=['GLOD1', 'GLYI', 'HEL-S-74'], description='glyoxalase I', other_designations='lactoylglutathione lyase|S-D-lactoylglutathione methylglyoxal lyase|aldoketomutase|epididymis secretory protein Li 74|glx I|glyoxalase domain containing 1|ketone-aldehyde mutase|lactoyl glutathione lyase|methylglyoxalase', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=38675925, end_position_on_the_genomic_accession=38703145, orientation='minus', exon_count=6, OMIM=[138750], no_hdr0=''),
    2740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2740, CurrentID=0, Status='live', Symbol='GLP1R', Aliases=['GLP-1', 'GLP-1-R', 'GLP-1R'], description='glucagon like peptide 1 receptor', other_designations='glucagon-like peptide 1 receptor|GLP-1 receptor|GLP1 receptor|seven transmembrane helix receptor', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39048781, end_position_on_the_genomic_accession=39091303, orientation='plus', exon_count=14, OMIM=[138032], no_hdr0=''),
    2741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2741, CurrentID=0, Status='live', Symbol='GLRA1', Aliases=['HKPX1', 'STHE'], description='glycine receptor alpha 1', other_designations='glycine receptor subunit alpha-1|glycine receptor 48 kDa subunit|glycine receptor strychnine-binding subunit', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151822513, end_position_on_the_genomic_accession=151924851, orientation='minus', exon_count=9, OMIM=[138491], no_hdr0=''),
    2742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2742, CurrentID=0, Status='live', Symbol='GLRA2', Aliases=['GLR'], description='glycine receptor alpha 2', other_designations='glycine receptor subunit alpha-2|glycine receptor alpha 2 subunit|glycine receptor, alpha-2 polypeptide', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=14529298, end_position_on_the_genomic_accession=14731812, orientation='plus', exon_count=12, OMIM=[305990], no_hdr0=''),
    2743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2743, CurrentID=0, Status='live', Symbol='GLRB', Aliases=['HKPX2'], description='glycine receptor beta', other_designations='glycine receptor subunit beta|glycine receptor 58 kDa subunit|glycine receptor, beta subunit', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=157076146, end_position_on_the_genomic_accession=157172090, orientation='plus', exon_count=12, OMIM=[138492], no_hdr0=''),
    2744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2744, CurrentID=0, Status='live', Symbol='GLS', Aliases=['AAD20', 'CASGID', 'DEE71', 'EIEE71', 'GAC', 'GAM', 'GDPAG1', 'KGA', 'GLS'], description='glutaminase', other_designations='glutaminase kidney isoform, mitochondrial|K-glutaminase|L-glutamine amidohydrolase|glutaminase C|glutaminase, phosphate-activated', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190880821, end_position_on_the_genomic_accession=190965552, orientation='plus', exon_count=20, OMIM=[138280], no_hdr0=''),
    2745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2745, CurrentID=0, Status='live', Symbol='GLRX', Aliases=['GRX', 'GRX1'], description='glutaredoxin', other_designations='glutaredoxin-1|TTase-1|thioltransferase|thioltransferase-1', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95813849, end_position_on_the_genomic_accession=95822726, orientation='minus', exon_count=3, OMIM=[600443], no_hdr0=''),
    2746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2746, CurrentID=0, Status='live', Symbol='GLUD1', Aliases=['GDH', 'GDH1', 'GLUD'], description='glutamate dehydrogenase 1', other_designations='glutamate dehydrogenase 1, mitochondrial|epididymis secretory sperm binding protein|epididymis tissue sperm binding protein Li 18mP|glutamate dehydrogenase (NAD(P)+)', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87050202, end_position_on_the_genomic_accession=87094843, orientation='minus', exon_count=18, OMIM=[138130], no_hdr0=''),
    2747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2747, CurrentID=0, Status='live', Symbol='GLUD2', Aliases=['GDH2', 'GLUDP1'], description='glutamate dehydrogenase 2', other_designations='glutamate dehydrogenase 2, mitochondrial|GDH 2|glutamate dehydrogenase pseudogene 1|testicular secretory protein Li 14', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=121047610, end_position_on_the_genomic_accession=121050094, orientation='plus', exon_count=1, OMIM=[300144], no_hdr0=''),
    2752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2752, CurrentID=0, Status='live', Symbol='GLUL', Aliases=['GLNS', 'GS', 'PIG43', 'PIG59'], description='glutamate-ammonia ligase', other_designations='glutamine synthetase|cell proliferation-inducing protein 59|glutamate decarboxylase|glutamine synthase|palmitoyltransferase GLUL|proliferation-inducing protein 43', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182378098, end_position_on_the_genomic_accession=182391790, orientation='minus', exon_count=9, OMIM=[138290], no_hdr0=''),
    2760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2760, CurrentID=0, Status='live', Symbol='GM2A', Aliases=['GM2-AP', 'SAP-3'], description='GM2 ganglioside activator', other_designations='ganglioside GM2 activator|cerebroside sulfate activator protein|shingolipid activator protein 3|sphingolipid activator protein 3', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151253185, end_position_on_the_genomic_accession=151270440, orientation='plus', exon_count=4, OMIM=[613109], no_hdr0=''),
    2762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2762, CurrentID=0, Status='live', Symbol='GMDS', Aliases=['GMD', 'SDR3E1'], description='GDP-mannose 4,6-dehydratase', other_designations='GDP-mannose 4,6 dehydratase|GDP-D-mannose dehydratase|short chain dehydrogenase/reductase family 3E, member 1', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=1623806, end_position_on_the_genomic_accession=2245605, orientation='minus', exon_count=21, OMIM=[602884], no_hdr0=''),
    2764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2764, CurrentID=0, Status='live', Symbol='GMFB', Aliases=['GMF'], description='glia maturation factor beta', other_designations='glia maturation factor beta|GMF-beta', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54474485, end_position_on_the_genomic_accession=54488980, orientation='minus', exon_count=7, OMIM=[601713], no_hdr0=''),
    2765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2765, CurrentID=0, Status='live', Symbol='GML', Aliases=['LY6DL'], description='glycosylphosphatidylinositol anchored molecule like', other_designations='glycosyl-phosphatidylinositol-anchored molecule-like protein|GPI anchored molecule like protein|Glycosylphosphatidylinositol-anchored molecule-like protein|glycosylphosphatidylinositol anchored molecule like protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142834801, end_position_on_the_genomic_accession=142846851, orientation='plus', exon_count=4, OMIM=[602370], no_hdr0=''),
    2766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2766, CurrentID=0, Status='live', Symbol='GMPR', Aliases=['GMPR 11', 'GMPR'], description='guanosine monophosphate reductase', other_designations="GMP reductase 1|guanine monophosphate reductase|guanosine 5'-monophosphate oxidoreductase 1|guanosine monophosphate reductase 1", map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=16238587, end_position_on_the_genomic_accession=16295549, orientation='plus', exon_count=10, OMIM=[139265], no_hdr0=''),
    2767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2767, CurrentID=0, Status='live', Symbol='GNA11', Aliases=['FBH', 'FBH2', 'FHH2', 'GNA-11', 'HHC2', 'HYPOC2'], description='G protein subunit alpha 11', other_designations='guanine nucleotide-binding protein subunit alpha-11|g alpha-11|guanine nucleotide binding protein (G protein), alpha 11 (Gq class)|guanine nucleotide-binding protein G(y) subunit alpha', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3094362, end_position_on_the_genomic_accession=3123999, orientation='plus', exon_count=7, OMIM=[139313], no_hdr0=''),
    2768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2768, CurrentID=0, Status='live', Symbol='GNA12', Aliases=['NNX3', 'RMP', 'gep'], description='G protein subunit alpha 12', other_designations='guanine nucleotide-binding protein subunit alpha-12|WUGSC:H_GS165O14.2|g alpha-12|guanine nucleotide binding protein (G protein) alpha 12', map_location='7p22.3-p22.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2728105, end_position_on_the_genomic_accession=2844308, orientation='minus', exon_count=7, OMIM=[604394], no_hdr0=''),
    2769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2769, CurrentID=0, Status='live', Symbol='GNA15', Aliases=['GNA16'], description='G protein subunit alpha 15', other_designations='guanine nucleotide-binding protein subunit alpha-15|G-protein subunit alpha-16|epididymis secretory sperm binding protein|epididymis tissue protein Li 17E|g alpha-15|g alpha-16|guanine nucleotide binding protein (G protein), alpha 15 (Gq class)|guanine nucleotide-binding protein subunit alpha-16', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3136033, end_position_on_the_genomic_accession=3163749, orientation='plus', exon_count=7, OMIM=[139314], no_hdr0=''),
    2770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2770, CurrentID=0, Status='live', Symbol='GNAI1', Aliases=['Gi'], description='G protein subunit alpha i1', other_designations='guanine nucleotide-binding protein G(i) subunit alpha-1|Gi1 protein alpha subunit|adenylate cyclase-inhibiting G alpha protein|guanine nucleotide binding protein (G protein), alpha inhibiting activity polypeptide 1', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=80134831, end_position_on_the_genomic_accession=80226181, orientation='plus', exon_count=9, OMIM=[139310], no_hdr0=''),
    2771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2771, CurrentID=0, Status='live', Symbol='GNAI2', Aliases=['GIPB', 'H_LUCA15.1', 'H_LUCA16.1', 'GNAI2'], description='G protein subunit alpha i2', other_designations='guanine nucleotide-binding protein G(i) subunit alpha-2|GTP-binding regulatory protein Gi alpha-2 chain|adenylate cyclase-inhibiting G alpha protein|guanine nucleotide binding protein (G protein), alpha inhibiting activity polypeptide 2|guanine nucleotide-binding protein G(i), alpha-2 subunit', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50227068, end_position_on_the_genomic_accession=50259362, orientation='plus', exon_count=13, OMIM=[139360], no_hdr0=''),
    2773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2773, CurrentID=0, Status='live', Symbol='GNAI3', Aliases=['87U6', 'ARCND1'], description='G protein subunit alpha i3', other_designations='guanine nucleotide-binding protein G(i) subunit alpha-3|g(i) alpha-3|guanine nucleotide binding protein (G protein), alpha inhibiting activity polypeptide 3|guanine nucleotide-binding protein G(i) subunit alpha|guanine nucleotide-binding protein G(k) subunit alpha', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109548615, end_position_on_the_genomic_accession=109600195, orientation='plus', exon_count=9, OMIM=[139370], no_hdr0=''),
    2774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2774, CurrentID=0, Status='live', Symbol='GNAL', Aliases=['DYT25'], description='G protein subunit alpha L', other_designations='guanine nucleotide-binding protein G(olf) subunit alpha|adenylate cyclase-stimulating G alpha protein, olfactory type|guanine nucleotide binding protein (G protein), alpha activating activity polypeptide, olfactory type|guanine nucleotide binding protein (G protein), alpha stimulating activity polypeptide, olfactory type', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=11689015, end_position_on_the_genomic_accession=11885685, orientation='plus', exon_count=17, OMIM=[139312], no_hdr0=''),
    2775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2775, CurrentID=0, Status='live', Symbol='GNAO1', Aliases=['DEE17', 'EIEE17', 'G-ALPHA-o', 'GNAO', 'HLA-DQB1', 'NEDIM'], description='G protein subunit alpha o1', other_designations='guanine nucleotide-binding protein G(o) subunit alpha|GO2-q chimeric G-protein|guanine nucleotide binding protein (G protein), alpha activating activity polypeptide O|guanine nucleotide-binding regulatory protein 2', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56191489, end_position_on_the_genomic_accession=56357444, orientation='plus', exon_count=12, OMIM=[139311], no_hdr0=''),
    2776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2776, CurrentID=0, Status='live', Symbol='GNAQ', Aliases=['CMC1', 'G-ALPHA-q', 'GAQ', 'SWS'], description='G protein subunit alpha q', other_designations='guanine nucleotide-binding protein G(q) subunit alpha|epididymis secretory sperm binding protein|guanine nucleotide binding protein (G protein), q polypeptide|guanine nucleotide-binding protein alpha-q', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=77716097, end_position_on_the_genomic_accession=78031811, orientation='minus', exon_count=8, OMIM=[600998], no_hdr0=''),
    2778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2778, CurrentID=0, Status='live', Symbol='GNAS', Aliases=['AHO', 'C20orf451', 'GPSA', 'GSA', 'GSP', 'NESP', 'PITA3', 'POH', 'SCG6', 'SgVI', 'GNAS'], description='GNAS complex locus', other_designations='protein ALEX|protein GNAS|protein SCG6 (secretogranin VI)|G protein subunit alpha S|adenylate cyclase-stimulating G alpha protein|alternative gene product encoded by XL-exon|extra large alphas protein|guanine nucleotide binding protein (G protein), alpha stimulating activity polypeptide 1|guanine nucleotide regulatory protein|secretogranin VI', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58839681, end_position_on_the_genomic_accession=58911192, orientation='plus', exon_count=23, OMIM=[139320], no_hdr0=''),
    2779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2779, CurrentID=0, Status='live', Symbol='GNAT1', Aliases=['CSNB1G', 'CSNBAD3', 'GBT1', 'GNATR'], description='G protein subunit alpha transducin 1', other_designations='guanine nucleotide-binding protein G(t) subunit alpha-1|guanine nucleotide binding protein (G protein), alpha transducing activity polypeptide 1|guanine nucleotide-binding protein G(T), alpha-1 subunit|rod-type transducin alpha subunit|transducin alpha-1 chain|transducin, rod-specific', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50191610, end_position_on_the_genomic_accession=50197696, orientation='plus', exon_count=9, OMIM=[139330], no_hdr0=''),
    2780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2780, CurrentID=0, Status='live', Symbol='GNAT2', Aliases=['ACHM4', 'GNATC'], description='G protein subunit alpha transducin 2', other_designations='guanine nucleotide-binding protein G(t) subunit alpha-2|cone-type transducin alpha subunit|guanine nucleotide binding protein (G protein), alpha transducing activity polypeptide 2|transducin alpha-2 chain|transducin, cone-specific, alpha polypeptide', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109603091, end_position_on_the_genomic_accession=109619616, orientation='minus', exon_count=9, OMIM=[139340], no_hdr0=''),
    2781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2781, CurrentID=0, Status='live', Symbol='GNAZ', Aliases=['gz-alpha'], description='G protein subunit alpha z', other_designations='guanine nucleotide-binding protein G(z) subunit alpha|g(x) alpha chain|guanine nucleotide binding protein (G protein), alpha z polypeptide|transducin alpha', map_location='22q11.22-q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23070519, end_position_on_the_genomic_accession=23125037, orientation='plus', exon_count=5, OMIM=[139160], no_hdr0=''),
    2782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2782, CurrentID=0, Status='live', Symbol='GNB1', Aliases=['MDS', 'MRD42'], description='G protein subunit beta 1', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(T) subunit beta-1|beta subunit, signal-transducing proteins GS/GI|guanine nucleotide binding protein (G protein), beta polypeptide 1|testicular tissue protein Li 72|transducin beta chain 1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1785286, end_position_on_the_genomic_accession=1891087, orientation='minus', exon_count=14, OMIM=[139380], no_hdr0=''),
    2783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2783, CurrentID=0, Status='live', Symbol='GNB2', Aliases=[], description='G protein subunit beta 2', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(T) subunit beta-2|G protein, beta-2 subunit|epididymis secretory sperm binding protein|g protein subunit beta-2|guanine nucleotide binding protein (G protein), beta polypeptide 2|guanine nucleotide-binding protein G(I)/G(S)/G(T) beta subunit 2|signal-transducing guanine nucleotide-binding regulatory protein beta subunit|transducin beta chain 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100673740, end_position_on_the_genomic_accession=100679169, orientation='plus', exon_count=10, OMIM=[139390], no_hdr0=''),
    2784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2784, CurrentID=0, Status='live', Symbol='GNB3', Aliases=['CSNB1H'], description='G protein subunit beta 3', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(T) subunit beta-3|G protein, beta-3 subunit|GTP-binding regulatory protein beta-3 chain|guanine nucleotide binding protein (G protein), beta polypeptide 3|guanine nucleotide-binding protein G(I)/G(S)/G(T) beta subunit 3|hypertension associated protein|transducin beta chain 3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6840922, end_position_on_the_genomic_accession=6847393, orientation='plus', exon_count=10, OMIM=[139130], no_hdr0=''),
    2785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2785, CurrentID=0, Status='live', Symbol='GNG3', Aliases=[], description='G protein subunit gamma 3', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-3|NBP gamma-3|guanine nucleotide binding protein (G protein), gamma 3|guanine nucleotide-binding protein gamma-3 subunit', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62707255, end_position_on_the_genomic_accession=62709206, orientation='plus', exon_count=4, OMIM=[608941], no_hdr0=''),
    2786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2786, CurrentID=0, Status='live', Symbol='GNG4', Aliases=[], description='G protein subunit gamma 4', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-4|guanine nucleotide binding protein (G protein), gamma 4|guanine nucleotide binding protein 4', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235547685, end_position_on_the_genomic_accession=235650608, orientation='minus', exon_count=7, OMIM=[604388], no_hdr0=''),
    2787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2787, CurrentID=0, Status='live', Symbol='GNG5', Aliases=[], description='G protein subunit gamma 5', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-5|guanine nucleotide binding protein (G protein), gamma 5', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84498325, end_position_on_the_genomic_accession=84506581, orientation='minus', exon_count=4, OMIM=[600874], no_hdr0=''),
    2788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2788, CurrentID=0, Status='live', Symbol='GNG7', Aliases=[], description='G protein subunit gamma 7', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-7|guanine nucleotide binding protein (G protein), gamma 7', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2511219, end_position_on_the_genomic_accession=2702694, orientation='minus', exon_count=6, OMIM=[604430], no_hdr0=''),
    2790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2790, CurrentID=0, Status='live', Symbol='GNG10', Aliases=[], description='G protein subunit gamma 10', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-10|guanine nucleotide binding protein (G protein), gamma 10|guanine nucleotide binding protein 10', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111661605, end_position_on_the_genomic_accession=111670226, orientation='plus', exon_count=3, OMIM=[604389], no_hdr0=''),
    2791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2791, CurrentID=0, Status='live', Symbol='GNG11', Aliases=['GNGT11'], description='G protein subunit gamma 11', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-11|G protein gamma-11 subunit|guanine nucleotide binding protein (G protein), gamma 11|guanine nucleotide-binding protein G(I)/G(S)/G(O) gamma-11 subunit', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93921735, end_position_on_the_genomic_accession=93928610, orientation='plus', exon_count=2, OMIM=[604390], no_hdr0=''),
    2792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2792, CurrentID=0, Status='live', Symbol='GNGT1', Aliases=['GNG1'], description='G protein subunit gamma transducin 1', other_designations='guanine nucleotide-binding protein G(T) subunit gamma-T1|guanine nucleotide binding protein (G protein), gamma transducing activity polypeptide 1|transducin gamma chain', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93906567, end_position_on_the_genomic_accession=93911265, orientation='plus', exon_count=3, OMIM=[189970], no_hdr0=''),
    2793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2793, CurrentID=0, Status='live', Symbol='GNGT2', Aliases=['G-GAMMA-8', 'G-GAMMA-C', 'GNG9', 'GNGT8'], description='G protein subunit gamma transducin 2', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-T2|G protein cone gamma 8 subunit|G-gamma-9|g gamma-C|gamma-T2 subunit|guanine nucleotide binding protein (G protein), gamma transducing activity polypeptide 2|guanine nucleotide binding protein gamma 9|guanine nucleotide binding protein gamma transducing activity polypeptide 2', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49206234, end_position_on_the_genomic_accession=49210574, orientation='minus', exon_count=5, OMIM=[139391], no_hdr0=''),
    2794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2794, CurrentID=0, Status='live', Symbol='GNL1', Aliases=['HSR1'], description='G protein nucleolar 1 (putative)', other_designations='guanine nucleotide-binding protein-like 1|GTP-binding protein HSR1|HSR1 GTP-binding protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30541381, end_position_on_the_genomic_accession=30557199, orientation='minus', exon_count=13, OMIM=[143024], no_hdr0=''),
    2796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2796, CurrentID=0, Status='live', Symbol='GNRH1', Aliases=['GNRH', 'GRH', 'LHRH', 'LNRH'], description='gonadotropin releasing hormone 1', other_designations='progonadoliberin-1|GnRH-associated peptide 1|gonadotropin-releasing hormone 1 (luteinizing-releasing hormone)|leuteinizing-releasing hormone|luliberin I|prolactin release-inhibiting factor', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=25419258, end_position_on_the_genomic_accession=25425040, orientation='minus', exon_count=3, OMIM=[152760], no_hdr0=''),
    2797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2797, CurrentID=0, Status='live', Symbol='GNRH2', Aliases=['GnRH-II', 'LH-RHII'], description='gonadotropin releasing hormone 2', other_designations='progonadoliberin-2|GnRH-associated peptide 2|GnRH-associated peptide II|Gonadoliberin II|Gonadoliberin-2|luliberin II|luteinizing hormone-releasing hormone II|progonadoliberin II', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3039061, end_position_on_the_genomic_accession=3045896, orientation='plus', exon_count=5, OMIM=[602352], no_hdr0=''),
    2798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2798, CurrentID=0, Status='live', Symbol='GNRHR', Aliases=['GNRHR1', 'GRHR', 'HH7', 'LHRHR', 'LRHR'], description='gonadotropin releasing hormone receptor', other_designations='gonadotropin-releasing hormone receptor|gnRH receptor|gnRH-R|gonadotropin-releasing hormone (type 1) receptor 1|leutinizing hormone releasing horomone receptor|leutinizing-releasing hormone receptor|luliberin receptor|type I GnRH receptor', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67737118, end_position_on_the_genomic_accession=67754388, orientation='minus', exon_count=3, OMIM=[138850], no_hdr0=''),
    2799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2799, CurrentID=0, Status='live', Symbol='GNS', Aliases=['G6S'], description='glucosamine (N-acetyl)-6-sulfatase', other_designations='N-acetylglucosamine-6-sulfatase|glucosamine -6-sulfatase', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64713449, end_position_on_the_genomic_accession=64759406, orientation='minus', exon_count=14, OMIM=[607664], no_hdr0=''),
    2800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2800, CurrentID=0, Status='live', Symbol='GOLGA1', Aliases=['golgin-97'], description='golgin A1', other_designations='golgin subfamily A member 1|gap junction protein, alpha 4, 37kD|golgi autoantigen, golgin subfamily a, 1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124878275, end_position_on_the_genomic_accession=124941407, orientation='minus', exon_count=23, OMIM=[602502], no_hdr0=''),
    2801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2801, CurrentID=0, Status='live', Symbol='GOLGA2', Aliases=['GM130'], description='golgin A2', other_designations='golgin subfamily A member 2|130 kDa cis-Golgi matrix protein|GM130 autoantigen|Golgi matrix protein GM130|SY11 protein|golgi autoantigen, golgin subfamily a, 2|golgin-95', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128255829, end_position_on_the_genomic_accession=128276007, orientation='minus', exon_count=27, OMIM=[602580], no_hdr0=''),
    2802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2802, CurrentID=0, Status='live', Symbol='GOLGA3', Aliases=['GCP170', 'MEA-2'], description='golgin A3', other_designations='golgin subfamily A member 3|Golgi membrane associated protein|Golgi peripheral membrane protein|SY2/SY10 protein|golgi autoantigen, golgin subfamily a, 3|golgi complex-associated protein of 170 kDa|golgin-160|golgin-165|male enhanced antigen-2', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132768913, end_position_on_the_genomic_accession=132829131, orientation='minus', exon_count=30, OMIM=[602581], no_hdr0=''),
    2803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2803, CurrentID=0, Status='live', Symbol='GOLGA4', Aliases=['CRPF46', 'GCP2', 'GOLG', 'MU-RMS-40.18', 'p230'], description='golgin A4', other_designations='golgin subfamily A member 4|256 kDa golgin|72.1 protein|centrosome-related protein F46|golgi autoantigen, golgin subfamily a, 4|golgin-240|golgin-245|protein 72.1|trans-Golgi p230', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37243269, end_position_on_the_genomic_accession=37366879, orientation='plus', exon_count=29, OMIM=[602509], no_hdr0=''),
    2804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2804, CurrentID=0, Status='live', Symbol='GOLGB1', Aliases=['GCP', 'GCP372', 'GOLIM1'], description='golgin B1', other_designations='golgin subfamily B member 1|372 kDa Golgi complex-associated protein|giantin|golgi autoantigen, golgin subfamily b, macrogolgin (with transmembrane signal), 1|golgi integral membrane protein 1|golgin B1, golgi integral membrane protein', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121663201, end_position_on_the_genomic_accession=121751169, orientation='minus', exon_count=27, OMIM=[602500], no_hdr0=''),
    2805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2805, CurrentID=0, Status='live', Symbol='GOT1', Aliases=['AST1', 'ASTQTL1', 'GIG18', 'cAspAT', 'cCAT'], description='glutamic-oxaloacetic transaminase 1', other_designations='aspartate aminotransferase, cytoplasmic|aspartate aminotransferase 1|aspartate transaminase 1|cysteine aminotransferase, cytoplasmic|cysteine transaminase, cytoplasmic|glutamate oxaloacetate transaminase 1|glutamic-oxaloacetic transaminase 1, soluble|growth-inhibiting protein 18|testis secretory sperm-binding protein Li 196a|transaminase A', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99396870, end_position_on_the_genomic_accession=99430624, orientation='minus', exon_count=9, OMIM=[138180], no_hdr0=''),
    2806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2806, CurrentID=0, Status='live', Symbol='GOT2', Aliases=['DEE82', 'KAT4', 'KATIV', 'KYAT4', 'mitAAT'], description='glutamic-oxaloacetic transaminase 2', other_designations='aspartate aminotransferase, mitochondrial|FABP-1|FABPpm|aspartate aminotransferase 2|aspartate transaminase 2|fatty acid-binding protein|glutamate oxaloacetate transaminase 2|glutamic-oxaloacetic transaminase 2, mitochondrial|kynurenine aminotransferase 4|kynurenine aminotransferase IV|kynurenine--oxoglutarate transaminase 4|kynurenine--oxoglutarate transaminase IV|mAspAT|plasma membrane-associated fatty acid-binding protein|transaminase A', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58707131, end_position_on_the_genomic_accession=58734316, orientation='minus', exon_count=10, OMIM=[138150], no_hdr0=''),
    2810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2810, CurrentID=0, Status='live', Symbol='SFN', Aliases=['YWHAS'], description='stratifin', other_designations='14-3-3 protein sigma|epithelial cell marker protein 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26863149, end_position_on_the_genomic_accession=26864456, orientation='plus', exon_count=1, OMIM=[601290], no_hdr0=''),
    2811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2811, CurrentID=0, Status='live', Symbol='GP1BA', Aliases=['BDPLT1', 'BDPLT3', 'BSS', 'CD42B', 'CD42b-alpha', 'DBPLT3', 'GP1B', 'GPIbA', 'GPIbalpha', 'VWDP'], description='glycoprotein Ib platelet subunit alpha', other_designations='platelet glycoprotein Ib alpha chain|GP-Ib alpha|antigen CD42b-alpha|glycoprotein Ib (platelet), alpha polypeptide|glycoprotein Ib platelet alpha subunit|mutant platelet membrane glycoprotein Ib-alpha|platelet membrane glycoprotein 1b-alpha subunit|platelet membrane glycoprotein Ib-alpha', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4932277, end_position_on_the_genomic_accession=4935023, orientation='plus', exon_count=2, OMIM=[606672], no_hdr0=''),
    2812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2812, CurrentID=0, Status='live', Symbol='GP1BB', Aliases=['BDPLT1', 'BS', 'CD42C', 'GPIBB', 'GPIbbeta'], description='glycoprotein Ib platelet subunit beta', other_designations='platelet glycoprotein Ib beta chain|GP-Ib beta|antigen CD42b-beta|glycoprotein Ib (platelet), beta polypeptide|glycoprotein Ib platelet beta subunit|nuclear localization signal deleted in velocardiofacial syndrome|platelet membrane glycoprotein Ib beta|truncated platelet membrane glycoprotein Ib beta', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19723539, end_position_on_the_genomic_accession=19724771, orientation='plus', exon_count=2, OMIM=[138720], no_hdr0=''),
    2813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2813, CurrentID=0, Status='live', Symbol='GP2', Aliases=['ZAP75'], description='glycoprotein 2', other_designations='pancreatic secretory granule membrane major glycoprotein GP2|glycoprotein 2 (zymogen granule membrane)|pancreatic zymogen granule membrane associated protein GP2', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20309574, end_position_on_the_genomic_accession=20327513, orientation='minus', exon_count=12, OMIM=[602977], no_hdr0=''),
    2814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2814, CurrentID=0, Status='live', Symbol='GP5', Aliases=['CD42d', 'GPV'], description='glycoprotein V platelet', other_designations='platelet glycoprotein V|glycoprotein 5', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194394821, end_position_on_the_genomic_accession=194399266, orientation='minus', exon_count=2, OMIM=[173511], no_hdr0=''),
    2815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2815, CurrentID=0, Status='live', Symbol='GP9', Aliases=['CD42a', 'GPIX'], description='glycoprotein IX platelet', other_designations='platelet glycoprotein IX|glycoprotein 9', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129055449, end_position_on_the_genomic_accession=129062411, orientation='plus', exon_count=6, OMIM=[173515], no_hdr0=''),
    2817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2817, CurrentID=0, Status='live', Symbol='GPC1', Aliases=['glypican'], description='glypican 1', other_designations='glypican-1|epididymis secretory sperm binding protein|glypican proteoglycan 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240435663, end_position_on_the_genomic_accession=240468076, orientation='plus', exon_count=10, OMIM=[600395], no_hdr0=''),
    2819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2819, CurrentID=0, Status='live', Symbol='GPD1', Aliases=['GPD-C', 'GPDH-C', 'HTGTI'], description='glycerol-3-phosphate dehydrogenase 1', other_designations='glycerol-3-phosphate dehydrogenase [NAD(+)], cytoplasmic|epididymis secretory sperm binding protein|glycerol-3-phosphate dehydrogenase 1 (soluble)|glycerol-3-phosphate dehydrogenase [NAD+], cytoplasmic|glycerophosphate dehydrogenase', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50104008, end_position_on_the_genomic_accession=50111313, orientation='plus', exon_count=8, OMIM=[138420], no_hdr0=''),
    2820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2820, CurrentID=0, Status='live', Symbol='GPD2', Aliases=['GDH2', 'GPDM', 'mGDH', 'mGPDH'], description='glycerol-3-phosphate dehydrogenase 2', other_designations='glycerol-3-phosphate dehydrogenase, mitochondrial|GPD-M|GPDH-M|glycerol-3-phosphate dehydrogenase 2 (mitochondrial)|mitochondrial glycerophosphate dehydrogenase|mitohondrial glycerophosphate dehydrogenase|mtGPD|testicular tissue protein Li 76', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=156435290, end_position_on_the_genomic_accession=156586403, orientation='plus', exon_count=22, OMIM=[138430], no_hdr0=''),
    2821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2821, CurrentID=0, Status='live', Symbol='GPI', Aliases=['AMF', 'GNPI', 'NLK', 'PGI', 'PHI', 'SA-36', 'SA36'], description='glucose-6-phosphate isomerase', other_designations='glucose-6-phosphate isomerase|autocrine motility factor|hexose monophosphate isomerase|hexosephosphate isomerase|neuroleukin|oxoisomerase|phosphoglucose isomerase|phosphohexomutase|phosphohexose isomerase|phosphosaccharomutase|sperm antigen-36', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34353330, end_position_on_the_genomic_accession=34402413, orientation='plus', exon_count=20, OMIM=[172400], no_hdr0=''),
    2822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2822, CurrentID=0, Status='live', Symbol='GPLD1', Aliases=['GPIPLD', 'GPIPLDM', 'PIGPLD', 'PIGPLD1', 'PLD'], description='glycosylphosphatidylinositol specific phospholipase D1', other_designations='phosphatidylinositol-glycan-specific phospholipase D|GPI-PLD|GPI-specific phospholipase D|PI-G PLD|glycoprotein phospholipase D', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24423969, end_position_on_the_genomic_accession=24495232, orientation='minus', exon_count=26, OMIM=[602515], no_hdr0=''),
    2823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2823, CurrentID=0, Status='live', Symbol='GPM6A', Aliases=['GPM6', 'M6A'], description='glycoprotein M6A', other_designations='neuronal membrane glycoprotein M6-a', map_location='4q34.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=175632937, end_position_on_the_genomic_accession=176002691, orientation='minus', exon_count=11, OMIM=[601275], no_hdr0=''),
    2824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2824, CurrentID=0, Status='live', Symbol='GPM6B', Aliases=['M6B'], description='glycoprotein M6B', other_designations='neuronal membrane glycoprotein M6-b|protolipid M6B', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13770922, end_position_on_the_genomic_accession=13938713, orientation='minus', exon_count=9, OMIM=[300051], no_hdr0=''),
    2825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2825, CurrentID=0, Status='live', Symbol='CMKLR2', Aliases=['GPR1'], description='chemerin chemokine-like receptor 2', other_designations='G-protein coupled receptor 1|G protein-coupled receptor 1|probable G-protein coupled receptor 1', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206175316, end_position_on_the_genomic_accession=206217912, orientation='minus', exon_count=6, OMIM=[600239], no_hdr0=''),
    2826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2826, CurrentID=0, Status='live', Symbol='CCR10', Aliases=['GPR2'], description='C-C motif chemokine receptor 10', other_designations='C-C chemokine receptor type 10|C-C CKR-10|CC chemokine receptor 10|CC-CKR-10|CCR-10|G-protein coupled receptor 2|chemokine (C-C motif) receptor 10', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42678889, end_position_on_the_genomic_accession=42681843, orientation='minus', exon_count=2, OMIM=[600240], no_hdr0=''),
    2827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2827, CurrentID=0, Status='live', Symbol='GPR3', Aliases=['ACCA'], description='G protein-coupled receptor 3', other_designations='G-protein coupled receptor 3|ACCA orphan receptor|adenylate cyclase constitutive activator', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27392622, end_position_on_the_genomic_accession=27395814, orientation='plus', exon_count=2, OMIM=[600241], no_hdr0=''),
    2828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2828, CurrentID=0, Status='live', Symbol='GPR4', Aliases=['GPR6C.l'], description='G protein-coupled receptor 4', other_designations='G-protein coupled receptor 4|G-protein coupled receptor 19|G-protein coupled receptor 6C.l', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45589764, end_position_on_the_genomic_accession=45602212, orientation='minus', exon_count=4, OMIM=[600551], no_hdr0=''),
    2829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2829, CurrentID=0, Status='live', Symbol='XCR1', Aliases=['CCXCR1', 'GPR5'], description='X-C motif chemokine receptor 1', other_designations='chemokine XC receptor 1|G protein-coupled receptor 5|XC chemokine receptor 1|chemokine (C motif) XC receptor 1|chemokine (C motif) receptor 1|lymphotactin receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46016990, end_position_on_the_genomic_accession=46086773, orientation='minus', exon_count=10, OMIM=[600552], no_hdr0=''),
    2830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2830, CurrentID=0, Status='live', Symbol='GPR6', Aliases=[], description='G protein-coupled receptor 6', other_designations='G-protein coupled receptor 6|sphingosine 1-phosphate receptor GPR6', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109978311, end_position_on_the_genomic_accession=109980720, orientation='plus', exon_count=3, OMIM=[600553], no_hdr0=''),
    2831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2831, CurrentID=0, Status='live', Symbol='NPBWR1', Aliases=['GPR7'], description='neuropeptides B and W receptor 1', other_designations='neuropeptides B/W receptor type 1|G-protein coupled receptor 7|neuropeptide B/W receptor 1|neuropeptides B/W receptor 1|opioid-somatostatin-like receptor 7', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=52939182, end_position_on_the_genomic_accession=52943734, orientation='plus', exon_count=2, OMIM=[600730], no_hdr0=''),
    2832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2832, CurrentID=0, Status='live', Symbol='NPBWR2', Aliases=['GPR8'], description='neuropeptides B and W receptor 2', other_designations='neuropeptides B/W receptor type 2|G-protein coupled receptor 8|neuropeptides B/W receptor 2|opioid-somatostatin-like receptor 8', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64103802, end_position_on_the_genomic_accession=64107565, orientation='minus', exon_count=2, OMIM=[600731], no_hdr0=''),
    2833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2833, CurrentID=0, Status='live', Symbol='CXCR3', Aliases=['CD182', 'CD183', 'CKR-L2', 'CMKAR3', 'GPR9', 'IP10-R', 'Mig-R', 'MigR'], description='C-X-C motif chemokine receptor 3', other_designations='C-X-C chemokine receptor type 3|G protein-coupled receptor 9|IP-10 receptor|Mig receptor|chemokine (C-X-C motif) receptor 3|chemokine receptor 3|interferon-inducible protein 10 receptor', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71615913, end_position_on_the_genomic_accession=71618515, orientation='minus', exon_count=4, OMIM=[300574], no_hdr0=''),
    2834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2834, CurrentID=0, Status='live', Symbol='PRLHR', Aliases=['GPR10', 'GR3', 'PrRPR'], description='prolactin releasing hormone receptor', other_designations='prolactin-releasing peptide receptor|G-protein coupled receptor 10|hGR3|prRP receptor', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=118589997, end_position_on_the_genomic_accession=118595648, orientation='minus', exon_count=2, OMIM=[600895], no_hdr0=''),
    2835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2835, CurrentID=0, Status='live', Symbol='GPR12', Aliases=['GPCR12', 'GPCR21', 'PPP1R84'], description='G protein-coupled receptor 12', other_designations='G-protein coupled receptor 12|protein phosphatase 1, regulatory subunit 84', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=26755200, end_position_on_the_genomic_accession=26760786, orientation='minus', exon_count=2, OMIM=[600752], no_hdr0=''),
    2837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2837, CurrentID=0, Status='live', Symbol='UTS2R', Aliases=['GPR14', 'UR-2-R', 'UTR', 'UTR2'], description='urotensin 2 receptor', other_designations='urotensin-2 receptor|G-protein coupled receptor 14|UR-II-R|urotensin II receptor', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82371765, end_position_on_the_genomic_accession=82377458, orientation='plus', exon_count=3, OMIM=[600896], no_hdr0=''),
    2838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2838, CurrentID=0, Status='live', Symbol='GPR15', Aliases=['BOB'], description='G protein-coupled receptor 15', other_designations='G-protein coupled receptor 15|brother of Bonzo', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98531978, end_position_on_the_genomic_accession=98534681, orientation='plus', exon_count=1, OMIM=[601166], no_hdr0=''),
    2840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2840, CurrentID=0, Status='live', Symbol='GPR17', Aliases=[], description='G protein-coupled receptor 17', other_designations='uracil nucleotide/cysteinyl leukotriene receptor|P2Y-like receptor|R12|UDP/CysLT receptor', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127646153, end_position_on_the_genomic_accession=127652639, orientation='plus', exon_count=4, OMIM=[603071], no_hdr0=''),
    2841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2841, CurrentID=0, Status='live', Symbol='GPR18', Aliases=[], description='G protein-coupled receptor 18', other_designations='N-arachidonyl glycine receptor|NAGly receptor', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99254713, end_position_on_the_genomic_accession=99262498, orientation='minus', exon_count=4, OMIM=[602042], no_hdr0=''),
    2842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2842, CurrentID=0, Status='live', Symbol='GPR19', Aliases=[], description='G protein-coupled receptor 19', other_designations='probable G-protein coupled receptor 19|GPR-NGA', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12659691, end_position_on_the_genomic_accession=12717786, orientation='minus', exon_count=8, OMIM=[602927], no_hdr0=''),
    2843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2843, CurrentID=0, Status='live', Symbol='GPR20', Aliases=[], description='G protein-coupled receptor 20', other_designations='G-protein coupled receptor 20|CTD-3064M3.3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=141356470, end_position_on_the_genomic_accession=141367286, orientation='minus', exon_count=2, OMIM=[601908], no_hdr0=''),
    2844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2844, CurrentID=0, Status='live', Symbol='GPR21', Aliases=[], description='G protein-coupled receptor 21', other_designations='probable G-protein coupled receptor 21', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=123033635, end_position_on_the_genomic_accession=123042751, orientation='plus', exon_count=2, OMIM=[601909], no_hdr0=''),
    2845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2845, CurrentID=0, Status='live', Symbol='GPR22', Aliases=[], description='G protein-coupled receptor 22', other_designations='G-protein coupled receptor 22|probable G-protein coupled receptor 22', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107470057, end_position_on_the_genomic_accession=107476207, orientation='plus', exon_count=3, OMIM=[601910], no_hdr0=''),
    2846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2846, CurrentID=0, Status='live', Symbol='LPAR4', Aliases=['GPR23', 'LPA4', 'P2RY9', 'P2Y5-LIKE', 'P2Y9'], description='lysophosphatidic acid receptor 4', other_designations='lysophosphatidic acid receptor 4|G-protein coupled receptor 23|LPA receptor 4|LPA-4|P2Y purinoceptor 9|P2Y5-like receptor|purinergic receptor 9', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78747658, end_position_on_the_genomic_accession=78758714, orientation='plus', exon_count=5, OMIM=[300086], no_hdr0=''),
    2847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2847, CurrentID=0, Status='live', Symbol='MCHR1', Aliases=['GPR24', 'MCH-1R', 'MCH1R', 'SLC-1', 'SLC1'], description='melanin concentrating hormone receptor 1', other_designations='melanin-concentrating hormone receptor 1|G protein-coupled receptor 24|MCH receptor 1|somatostatin receptor-like protein', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40679484, end_position_on_the_genomic_accession=40682812, orientation='plus', exon_count=2, OMIM=[601751], no_hdr0=''),
    2848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2848, CurrentID=0, Status='live', Symbol='GPR25', Aliases=[], description='G protein-coupled receptor 25', other_designations='probable G-protein coupled receptor 25', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200872981, end_position_on_the_genomic_accession=200874178, orientation='plus', exon_count=1, OMIM=[602174], no_hdr0=''),
    2849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2849, CurrentID=0, Status='live', Symbol='GPR26', Aliases=[], description='G protein-coupled receptor 26', other_designations='G-protein coupled receptor 26', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123666355, end_position_on_the_genomic_accession=123697399, orientation='plus', exon_count=3, OMIM=[604847], no_hdr0=''),
    2850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2850, CurrentID=0, Status='live', Symbol='GPR27', Aliases=['SREB1'], description='G protein-coupled receptor 27', other_designations='probable G-protein coupled receptor 27|super conserved receptor expressed in brain 1', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=71753855, end_position_on_the_genomic_accession=71756496, orientation='plus', exon_count=1, OMIM=[605187], no_hdr0=''),
    2852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2852, CurrentID=0, Status='live', Symbol='GPER1', Aliases=['CEPR', 'CMKRL2', 'DRY12', 'FEG-1', 'GPCR-Br', 'GPER', 'GPR30', 'LERGU', 'LERGU2', 'LyGPR', 'mER'], description='G protein-coupled estrogen receptor 1', other_designations='G-protein coupled estrogen receptor 1|G protein-coupled receptor 30|IL8-related receptor DRY12|chemoattractant receptor-like 2|chemokine receptor-like 2|constitutively expressed peptide-like receptor|flow-induced endothelial G-protein coupled receptor 1|heptahelix receptor|lymphocyte-derived G-protein coupled receptor|membrane estrogen receptor', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1087118, end_position_on_the_genomic_accession=1093810, orientation='plus', exon_count=3, OMIM=[601805], no_hdr0=''),
    2853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2853, CurrentID=0, Status='live', Symbol='GPR31', Aliases=['12-HETER', 'HETER', 'HETER1'], description='G protein-coupled receptor 31', other_designations='12-(S)-hydroxy-5,8,10,14-eicosatetraenoic acid receptor|12-(S)-HETE acid receptor|12-(S)-HETE receptor|12-(S)-hydroxy-5,8,10,14-eicosatetraenoic acid (HETE) receptor|GPR31/12-HETER|bA517H2.2 (G protein-coupled receptor 31)|hydroxyeicosatetraenoic (HETE) acid receptor 1|probable G-protein coupled receptor 31', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167155247, end_position_on_the_genomic_accession=167157980, orientation='minus', exon_count=1, OMIM=[602043], no_hdr0=''),
    2854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2854, CurrentID=0, Status='live', Symbol='GPR32', Aliases=['RVDR1'], description='G protein-coupled receptor 32', other_designations='probable G-protein coupled receptor 32|resolvin D1 receptor', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50770464, end_position_on_the_genomic_accession=50771732, orientation='plus', exon_count=1, OMIM=[603195], no_hdr0=''),
    2856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2856, CurrentID=0, Status='live', Symbol='GPR33', Aliases=[], description='G protein-coupled receptor 33', other_designations='probable G-protein coupled receptor 33|G protein-coupled receptor 33 pseudogene', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31482875, end_position_on_the_genomic_accession=31488039, orientation='minus', exon_count=2, OMIM=[610118], no_hdr0=''),
    2857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2857, CurrentID=0, Status='live', Symbol='GPR34', Aliases=['LYPSR1'], description='G protein-coupled receptor 34', other_designations='probable G-protein coupled receptor 34', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41686397, end_position_on_the_genomic_accession=41697275, orientation='plus', exon_count=3, OMIM=[300241], no_hdr0=''),
    2859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2859, CurrentID=0, Status='live', Symbol='GPR35', Aliases=[], description='G protein-coupled receptor 35', other_designations='G-protein coupled receptor 35|KYNA receptor|kynurenic acid receptor', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240605430, end_position_on_the_genomic_accession=240633159, orientation='plus', exon_count=7, OMIM=[602646], no_hdr0=''),
    2860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2860, CurrentID=0, Status='live', Symbol='GPR36', Aliases=[], description='G protein-coupled receptor 36', other_designations='G protein-coupled receptor 36', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    2861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2861, CurrentID=0, Status='live', Symbol='GPR37', Aliases=['EDNRBL', 'PAELR', 'hET(B)R-LP'], description='G protein-coupled receptor 37', other_designations='prosaposin receptor GPR37|ETBR-LP-1|G protein-coupled receptor 37 (endothelin receptor type B-like)|Parkin-associated endothelin receptor-like receptor|endothelin B receptor-like protein 1|probable G-protein coupled receptor 37', map_location='7q31.33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=124743885, end_position_on_the_genomic_accession=124765792, orientation='minus', exon_count=2, OMIM=[602583], no_hdr0=''),
    2862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2862, CurrentID=0, Status='live', Symbol='MLNR', Aliases=['GPR38', 'MTLR1'], description='motilin receptor', other_designations='motilin receptor|G protein-coupled receptor 38', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49220338, end_position_on_the_genomic_accession=49222377, orientation='plus', exon_count=2, OMIM=[602885], no_hdr0=''),
    2863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2863, CurrentID=0, Status='live', Symbol='GPR39', Aliases=[], description='G protein-coupled receptor 39', other_designations='G-protein coupled receptor 39', map_location='2q21.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=132416805, end_position_on_the_genomic_accession=132646582, orientation='plus', exon_count=2, OMIM=[602886], no_hdr0=''),
    2864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2864, CurrentID=0, Status='live', Symbol='FFAR1', Aliases=['FFA1R', 'GPCR40', 'GPR40'], description='free fatty acid receptor 1', other_designations='free fatty acid receptor 1|G-protein coupled receptor 40', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35351542, end_position_on_the_genomic_accession=35352464, orientation='plus', exon_count=1, OMIM=[603820], no_hdr0=''),
    2865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2865, CurrentID=0, Status='live', Symbol='FFAR3', Aliases=['FFA3R', 'GPR41', 'GPR42'], description='free fatty acid receptor 3', other_designations='free fatty acid receptor 3|G-protein coupled receptor 41', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35358106, end_position_on_the_genomic_accession=35360491, orientation='plus', exon_count=2, OMIM=[603821], no_hdr0=''),
    2866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2866, CurrentID=0, Status='live', Symbol='GPR42', Aliases=['FFAR1L', 'FFAR3L', 'GPR41LP', 'GPR42'], description='G protein-coupled receptor 42', other_designations='G-protein coupled receptor 42|G protein-coupled receptor 42 pseudogene|G-protein coupled receptor', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35371068, end_position_on_the_genomic_accession=35372962, orientation='plus', exon_count=2, OMIM=[603822], no_hdr0=''),
    2867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2867, CurrentID=0, Status='live', Symbol='FFAR2', Aliases=['FFA2R', 'GPR43'], description='free fatty acid receptor 2', other_designations='free fatty acid receptor 2|G-protein coupled receptor 43|fatty acid receptor 2|free fatty acid activated receptor 2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35448257, end_position_on_the_genomic_accession=35451767, orientation='plus', exon_count=4, OMIM=[603823], no_hdr0=''),
    2868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2868, CurrentID=0, Status='live', Symbol='GRK4', Aliases=['GPRK2L', 'GPRK4a', 'IT11', 'GRK4'], description='G protein-coupled receptor kinase 4', other_designations='G protein-coupled receptor kinase 4|G protein-coupled receptor kinase 2-like', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2963504, end_position_on_the_genomic_accession=3040760, orientation='plus', exon_count=23, OMIM=[137026], no_hdr0=''),
    2869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2869, CurrentID=0, Status='live', Symbol='GRK5', Aliases=['FP2025', 'GPRK5'], description='G protein-coupled receptor kinase 5', other_designations='G protein-coupled receptor kinase 5|g protein-coupled receptor kinase GRK5', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119207571, end_position_on_the_genomic_accession=119459745, orientation='plus', exon_count=16, OMIM=[600870], no_hdr0=''),
    2870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2870, CurrentID=0, Status='live', Symbol='GRK6', Aliases=['GPRK6'], description='G protein-coupled receptor kinase 6', other_designations='G protein-coupled receptor kinase 6', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177426496, end_position_on_the_genomic_accession=177442891, orientation='plus', exon_count=18, OMIM=[600869], no_hdr0=''),
    2872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2872, CurrentID=0, Status='live', Symbol='MKNK2', Aliases=['GPRK7', 'MNK2'], description='MAPK interacting serine/threonine kinase 2', other_designations='MAP kinase-interacting serine/threonine-protein kinase 2|G protein-coupled receptor kinase 7|MAP kinase interacting serine/threonine kinase 2|MAP kinase signal-integrating kinase 2|MAPK signal-integrating kinase 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2037471, end_position_on_the_genomic_accession=2051278, orientation='minus', exon_count=13, OMIM=[605069], no_hdr0=''),
    2873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2873, CurrentID=0, Status='live', Symbol='GPS1', Aliases=['COPS1', 'CSN1', 'SGN1'], description='G protein pathway suppressor 1', other_designations='COP9 signalosome complex subunit 1|JAB1-containing signalosome subunit 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82050932, end_position_on_the_genomic_accession=82057470, orientation='plus', exon_count=16, OMIM=[601934], no_hdr0=''),
    2874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2874, CurrentID=0, Status='live', Symbol='GPS2', Aliases=['AMF-1'], description='G protein pathway suppressor 2', other_designations='G protein pathway suppressor 2|GPS-2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7312661, end_position_on_the_genomic_accession=7315360, orientation='minus', exon_count=11, OMIM=[601935], no_hdr0=''),
    2875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2875, CurrentID=0, Status='live', Symbol='GPT', Aliases=['AAT1', 'ALT11', 'GPT'], description='glutamic--pyruvic transaminase', other_designations='alanine aminotransferase 1|alanine aminotransferase|alanine transaminase|glutamate pyruvate transaminase 1|glutamic--pyruvic transaminase 1|glutamic-alanine transaminase 1|glutamic-pyruvate transaminase (alanine aminotransferase)', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144503068, end_position_on_the_genomic_accession=144507172, orientation='plus', exon_count=12, OMIM=[138200], no_hdr0=''),
    2876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2876, CurrentID=0, Status='live', Symbol='GPX1', Aliases=['GPXD', 'GSHPX1'], description='glutathione peroxidase 1', other_designations='glutathione peroxidase 1|GSHPx-1|cellular glutathione peroxidase|selenoprotein GPX1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49357176, end_position_on_the_genomic_accession=49358353, orientation='minus', exon_count=2, OMIM=[138320], no_hdr0=''),
    2877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2877, CurrentID=0, Status='live', Symbol='GPX2', Aliases=['GI-GPx', 'GPRP', 'GPRP-2', 'GPx-2', 'GPx-GI', 'GSHPX-GI', 'GSHPx-2'], description='glutathione peroxidase 2', other_designations='glutathione peroxidase 2|gastrointestinal glutathione peroxidase|glutathione peroxidase 2 (gastrointestinal)|glutathione peroxidase-related protein 2|selenoprotein GPX2', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64939158, end_position_on_the_genomic_accession=64942745, orientation='minus', exon_count=4, OMIM=[138319], no_hdr0=''),
    2878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2878, CurrentID=0, Status='live', Symbol='GPX3', Aliases=['GPx-P', 'GSHPx-3', 'GSHPx-P'], description='glutathione peroxidase 3', other_designations='glutathione peroxidase 3|GPx-3|extracellular glutathione peroxidase|glutathione peroxidase 3 (plasma)|plasma glutathione peroxidase|selenoprotein GPX3', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151020591, end_position_on_the_genomic_accession=151028988, orientation='plus', exon_count=6, OMIM=[138321], no_hdr0=''),
    2879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2879, CurrentID=0, Status='live', Symbol='GPX4', Aliases=['GPx-4', 'GSHPx-4', 'MCSP', 'PHGPx', 'SMDS', 'snGPx', 'snPHGPx'], description='glutathione peroxidase 4', other_designations='phospholipid hydroperoxide glutathione peroxidase|epididymis secretory sperm binding protein|phospholipid hydroperoxidase|phospholipid hydroperoxide glutathione peroxidase, mitochondrial|selenoprotein GPX4|sperm nucleus glutathione peroxidase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1103994, end_position_on_the_genomic_accession=1106779, orientation='plus', exon_count=8, OMIM=[138322], no_hdr0=''),
    2880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2880, CurrentID=0, Status='live', Symbol='GPX5', Aliases=['EGLP', 'GPx-5', 'GSHPx-5', 'HEL-S-75p'], description='glutathione peroxidase 5', other_designations='epididymal secretory glutathione peroxidase|epididymal androgen-related protein|epididymis secretory sperm binding protein Li 75p|epididymis-specific glutathione peroxidase-like protein', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28525881, end_position_on_the_genomic_accession=28534955, orientation='plus', exon_count=6, OMIM=[603435], no_hdr0=''),
    2882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2882, CurrentID=0, Status='live', Symbol='GPX7', Aliases=['CL683', 'GPX6', 'GPx-7', 'GSHPx-7', 'NPGPx'], description='glutathione peroxidase 7', other_designations='glutathione peroxidase 7|glutathione peroxidase 6|non-selenocysteine containing phospholipid hydroperoxide glutathione peroxidase', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52602371, end_position_on_the_genomic_accession=52609051, orientation='plus', exon_count=3, OMIM=[615784], no_hdr0=''),
    2885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2885, CurrentID=0, Status='live', Symbol='GRB2', Aliases=['ASH', 'EGFRBP-GRB2', 'Grb3-3', 'MST084', 'MSTP084', 'NCKAP2'], description='growth factor receptor bound protein 2', other_designations='growth factor receptor-bound protein 2|HT027|SH2/SH3 adapter GRB2|abundant SRC homology|epidermal growth factor receptor-binding protein GRB2|epididymis secretory sperm binding protein|growth factor receptor-bound protein 3|protein Ash', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75318076, end_position_on_the_genomic_accession=75405678, orientation='minus', exon_count=6, OMIM=[108355], no_hdr0=''),
    2886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2886, CurrentID=0, Status='live', Symbol='GRB7', Aliases=[], description='growth factor receptor bound protein 7', other_designations='growth factor receptor-bound protein 7|B47|GRB7 adapter protein|epidermal growth factor receptor GRB-7', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39737938, end_position_on_the_genomic_accession=39747285, orientation='plus', exon_count=18, OMIM=[601522], no_hdr0=''),
    2887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2887, CurrentID=0, Status='live', Symbol='GRB10', Aliases=['GRB-IR', 'Grb-10', 'IRBP', 'MEG1', 'RSS'], description='growth factor receptor bound protein 10', other_designations='growth factor receptor-bound protein 10|GRB10 adapter protein|GRB10 adaptor protein|insulin receptor-binding protein Grb-IR|maternally expressed gene 1', map_location='7p12.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=50590068, end_position_on_the_genomic_accession=50793453, orientation='minus', exon_count=34, OMIM=[601523], no_hdr0=''),
    2888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2888, CurrentID=0, Status='live', Symbol='GRB14', Aliases=[], description='growth factor receptor bound protein 14', other_designations='growth factor receptor-bound protein 14|GRB14 adapter protein', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=164492417, end_position_on_the_genomic_accession=164622959, orientation='minus', exon_count=18, OMIM=[601524], no_hdr0=''),
    2889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2889, CurrentID=0, Status='live', Symbol='RAPGEF1', Aliases=['C3G', 'GRF2'], description='Rap guanine nucleotide exchange factor 1', other_designations='rap guanine nucleotide exchange factor 1|CRK SH3-binding GNRP|Rap guanine nucleotide exchange factor (GEF) 1|guanine nucleotide-releasing factor 2 (specific for crk proto-oncogene)', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131576770, end_position_on_the_genomic_accession=131740076, orientation='minus', exon_count=37, OMIM=[600303], no_hdr0=''),
    2890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2890, CurrentID=0, Status='live', Symbol='GRIA1', Aliases=['GLUH1', 'GLUR1', 'GLURA', 'GluA1', 'HBGR1'], description='glutamate ionotropic receptor AMPA type subunit 1', other_designations='glutamate receptor 1|AMPA 1|AMPA-selective glutamate receptor 1|gluR-1|gluR-A|gluR-K1|glutamate receptor, ionotropic, AMPA 1', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=153490670, end_position_on_the_genomic_accession=153813873, orientation='plus', exon_count=20, OMIM=[138248], no_hdr0=''),
    2891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2891, CurrentID=0, Status='live', Symbol='GRIA2', Aliases=['GLUR2', 'GLURB', 'GluA2', 'GluR-K2', 'HBGR2', 'NEDLIB', 'gluR-2', 'gluR-B'], description='glutamate ionotropic receptor AMPA type subunit 2', other_designations='glutamate receptor 2|AMPA-selective glutamate receptor 2|glutamate receptor, ionotropic, AMPA 2', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=157220120, end_position_on_the_genomic_accession=157370583, orientation='plus', exon_count=19, OMIM=[138247], no_hdr0=''),
    2892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2892, CurrentID=0, Status='live', Symbol='GRIA3', Aliases=['GLUR-C', 'GLUR-K3', 'GLUR3', 'GLURC', 'GluA3', 'MRX94', 'MRXSW'], description='glutamate ionotropic receptor AMPA type subunit 3', other_designations='glutamate receptor 3|AMPA-selective glutamate receptor 3|dJ1171F9.1|gluR-3|glutamate receptor C|glutamate receptor subunit 3|glutamate receptor, ionotrophic, AMPA 3|glutamate receptor, ionotropic, AMPA 3', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=123184278, end_position_on_the_genomic_accession=123490915, orientation='plus', exon_count=19, OMIM=[305915], no_hdr0=''),
    2893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2893, CurrentID=0, Status='live', Symbol='GRIA4', Aliases=['GLUR4', 'GLUR4C', 'GLURD', 'GluA4', 'GluA4-ATD', 'NEDSGA'], description='glutamate ionotropic receptor AMPA type subunit 4', other_designations='glutamate receptor 4|AMPA-selective glutamate receptor 4|gluR-4|gluR-D|glutamate receptor, ionotrophic, AMPA 4|glutamate receptor, ionotropic, AMPA 4', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=105609540, end_position_on_the_genomic_accession=105982090, orientation='plus', exon_count=24, OMIM=[138246], no_hdr0=''),
    2894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2894, CurrentID=0, Status='live', Symbol='GRID1', Aliases=['GluD1', 'GluD1-b'], description='glutamate ionotropic receptor delta type subunit 1', other_designations='glutamate receptor ionotropic, delta-1|gluR delta-1 subunit|glutamate receptor delta-1 subunit', map_location='10q23.1-q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=85599552, end_position_on_the_genomic_accession=86366795, orientation='minus', exon_count=17, OMIM=[610659], no_hdr0=''),
    2895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2895, CurrentID=0, Status='live', Symbol='GRID2', Aliases=['GluD2', 'SCAR18'], description='glutamate ionotropic receptor delta type subunit 2', other_designations='glutamate receptor ionotropic, delta-2|gluR delta-2 subunit|glutamate receptor delta-2 subunit|glutamate receptor, ionotropic, delta 2', map_location='4q22.1-q22.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=92303622, end_position_on_the_genomic_accession=93810415, orientation='plus', exon_count=27, OMIM=[602368], no_hdr0=''),
    2896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2896, CurrentID=0, Status='live', Symbol='GRN', Aliases=['CLN11', 'GEP', 'GP88', 'PCDGF', 'PEPI', 'PGRN'], description='granulin precursor', other_designations='progranulin|PC cell-derived growth factor|acrogranin|epithelin|glycoprotein 88|glycoprotein of 88 Kda|granulin-epithelin|granulins|proepithelin', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44345302, end_position_on_the_genomic_accession=44353106, orientation='plus', exon_count=14, OMIM=[138945], no_hdr0=''),
    2897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2897, CurrentID=0, Status='live', Symbol='GRIK1', Aliases=['EAA3', 'EEA3', 'GLR5', 'GLUR5', 'GluK1', 'gluR-5'], description='glutamate ionotropic receptor kainate type subunit 1', other_designations='glutamate receptor ionotropic, kainate 1|GluK1(del_e2)|excitatory amino acid receptor 3|glutamate receptor 5', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29536933, end_position_on_the_genomic_accession=29939996, orientation='minus', exon_count=19, OMIM=[138245], no_hdr0=''),
    2898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2898, CurrentID=0, Status='live', Symbol='GRIK2', Aliases=['EAA4', 'GLR6', 'GLUK6', 'GLUR6', 'GluK2', 'MRT6'], description='glutamate ionotropic receptor kainate type subunit 2', other_designations="glutamate receptor ionotropic, kainate 2|GluK2(alt_5'UTR)|bA487F5.1|excitatory amino acid receptor 4|gluR-6|glutamate receptor 6|glutamate receptor form A|glutamate receptor form B|glutamate receptor form C|glutamate receptor form D|glutamate receptor form E|putative NMDtranscript(cassette_171nt)", map_location='6q16.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=101393708, end_position_on_the_genomic_accession=102070083, orientation='plus', exon_count=22, OMIM=[138244], no_hdr0=''),
    2899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2899, CurrentID=0, Status='live', Symbol='GRIK3', Aliases=['EAA5', 'GLR7', 'GLUR7', 'GluK3', 'GluR7a'], description='glutamate ionotropic receptor kainate type subunit 3', other_designations='glutamate receptor ionotropic, kainate 3|dJ1090M5.1 (glutamate receptor, ionotropic, kainate 3 (GLUR7))|excitatory amino acid receptor 5|gluR-7|glutamate receptor 7', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36795527, end_position_on_the_genomic_accession=37034515, orientation='minus', exon_count=16, OMIM=[138243], no_hdr0=''),
    2900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2900, CurrentID=0, Status='live', Symbol='GRIK4', Aliases=['EAA1', 'GRIK', 'GluK4', 'GluK4-2', 'KA1'], description='glutamate ionotropic receptor kainate type subunit 4', other_designations="glutamate receptor ionotropic, kainate 4|GluK4(alt_5'UTR)|excitatory amino acid receptor 1|glutamate receptor KA1|glutamate receptor, ionotropic, kainate 4|putative NMDtranscript(altAcc_e11)", map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120511748, end_position_on_the_genomic_accession=120988906, orientation='plus', exon_count=24, OMIM=[600282], no_hdr0=''),
    2901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2901, CurrentID=0, Status='live', Symbol='GRIK5', Aliases=['EAA2', 'GRIK2', 'GluK5', 'KA2'], description='glutamate ionotropic receptor kainate type subunit 5', other_designations='glutamate receptor ionotropic, kainate 5|excitatory amino acid receptor 2|glutamate receptor KA2|putative NMDtranscript(altDon_e2)|putative NMDtranscript(del_e13-e15)', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41998316, end_position_on_the_genomic_accession=42071804, orientation='minus', exon_count=26, OMIM=[600283], no_hdr0=''),
    2902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2902, CurrentID=0, Status='live', Symbol='GRIN1', Aliases=['GluN1', 'MRD8', 'NDHMSD', 'NDHMSR', 'NMD-R1', 'NMDA1', 'NMDAR1', 'NR1'], description='glutamate ionotropic receptor NMDA type subunit 1', other_designations='glutamate receptor ionotropic, NMDA 1|N-methyl-D-aspartate receptor channel, subunit zeta-1|N-methyl-D-aspartate receptor subunit NR1|glutamate [NMDA] receptor subunit zeta-1|glutamate receptor, ionotropic, N-methyl D-aspartate 1|putative NMDtranscript(altAcc_e2)', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137139092, end_position_on_the_genomic_accession=137168759, orientation='plus', exon_count=22, OMIM=[138249], no_hdr0=''),
    2903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2903, CurrentID=0, Status='live', Symbol='GRIN2A', Aliases=['EPND', 'FESD', 'GluN2A', 'LKS', 'NMDAR2A', 'NR2A'], description='glutamate ionotropic receptor NMDA type subunit 2A', other_designations='glutamate receptor ionotropic, NMDA 2A|N-methyl D-aspartate receptor subtype 2A|N-methyl-D-aspartate receptor channel, subunit epsilon-1|N-methyl-D-aspartate receptor subunit 2A|glutamate ionotropic receptor NMDA 2A|glutamate receptor, ionotropic, N-methyl D-aspartate 2A', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=9753404, end_position_on_the_genomic_accession=10182928, orientation='minus', exon_count=16, OMIM=[138253], no_hdr0=''),
    2904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2904, CurrentID=0, Status='live', Symbol='GRIN2B', Aliases=['DEE27', 'EIEE27', 'GluN2B', 'MRD6', 'NMDAR2B', 'NR2B', 'NR3', 'hNR3'], description='glutamate ionotropic receptor NMDA type subunit 2B', other_designations="glutamate receptor ionotropic, NMDA 2B|GluN2B(alt_5'UTR)|N-methyl D-aspartate receptor subtype 2B|N-methyl-D-aspartate receptor subunit 3|glutamate [NMDA] receptor subunit epsilon-2|glutamate receptor subunit epsilon-2|glutamate receptor, ionotropic, N-methyl D-aspartate 2B", map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=13537337, end_position_on_the_genomic_accession=13982012, orientation='minus', exon_count=16, OMIM=[138252], no_hdr0=''),
    2905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2905, CurrentID=0, Status='live', Symbol='GRIN2C', Aliases=['GluN2C', 'NMDAR2C', 'NR2C'], description='glutamate ionotropic receptor NMDA type subunit 2C', other_designations="glutamate receptor ionotropic, NMDA 2C|GluN2C(alt_5'UTR_77nt)|GluN2C(alt_5'UTR_87nt)|GluN2C(del_e2)|N-methyl D-aspartate receptor subtype 2C|N-methyl-D-aspartate receptor subunit 2C|glutamate [NMDA] receptor subunit epsilon-3|glutamate receptor, ionotropic, N-methyl D-aspartate 2C|putative NMDtranscript(altAcc_e11)|putative NMDtranscript(altDon_e4)|putative NMDtranscript(del_e4)", map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74842021, end_position_on_the_genomic_accession=74860843, orientation='minus', exon_count=15, OMIM=[138254], no_hdr0=''),
    2906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2906, CurrentID=0, Status='live', Symbol='GRIN2D', Aliases=['DEE46', 'EB11', 'EIEE46', 'GluN2D', 'NMDAR2D', 'NR2D'], description='glutamate ionotropic receptor NMDA type subunit 2D', other_designations='glutamate receptor ionotropic, NMDA 2D|N-methyl D-aspartate receptor subtype 2D|N-methyl-d-aspartate receptor subunit 2D|estrogen receptor binding CpG island|glutamate [NMDA] receptor subunit epsilon-4|glutamate receptor, ionotropic, N-methyl D-aspartate 2D', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48393668, end_position_on_the_genomic_accession=48444937, orientation='plus', exon_count=14, OMIM=[602717], no_hdr0=''),
    2907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2907, CurrentID=0, Status='live', Symbol='GRINA', Aliases=['HNRGW', 'LFG1', 'NMDARA1', 'TMBIM3'], description='glutamate ionotropic receptor NMDA type subunit associated protein 1', other_designations='protein lifeguard 1|NMDA receptor glutamate-binding subunit|glutamate [NMDA] receptor-associated protein 1|glutamate receptor, NMDA subtype, glutamate-binding subunit|glutamate receptor, ionotropic, N-methyl D-aspartate-associated protein 1 (glutamate binding)|lifeguard 1|putative MAPK-activating protein PM02|transmembrane BAX inhibitor motif containing 3|transmembrane BAX inhibitor motif-containing protein 3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143990056, end_position_on_the_genomic_accession=143993415, orientation='plus', exon_count=7, OMIM=[138251], no_hdr0=''),
    2908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2908, CurrentID=0, Status='live', Symbol='NR3C1', Aliases=['GCCR', 'GCR', 'GCRST', 'GR', 'GRL'], description='nuclear receptor subfamily 3 group C member 1', other_designations='glucocorticoid receptor|glucocorticoid nuclear receptor variant 1|nuclear receptor subfamily 3 group C member 1 variant hGR-B(54)|nuclear receptor subfamily 3 group C member 1 variant hGR-B(77)|nuclear receptor subfamily 3 group C member 1 variant hGR-B(93)|nuclear receptor subfamily 3, group C, member 1 (glucocorticoid receptor)', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=143277931, end_position_on_the_genomic_accession=143435512, orientation='minus', exon_count=16, OMIM=[138040], no_hdr0=''),
    2909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2909, CurrentID=0, Status='live', Symbol='ARHGAP35', Aliases=['GRF-1', 'GRLF1', 'P190-A', 'P190A', 'p190ARhoGAP', 'p190RhoGAP'], description='Rho GTPase activating protein 35', other_designations='rho GTPase-activating protein 35|glucocorticoid receptor DNA-binding factor 1|glucocorticoid receptor repression factor 1|rho GAP p190A', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46860997, end_position_on_the_genomic_accession=47005077, orientation='plus', exon_count=9, OMIM=[605277], no_hdr0=''),
    2911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2911, CurrentID=0, Status='live', Symbol='GRM1', Aliases=['GPRC1A', 'MGLU1', 'MGLUR1', 'PPP1R85', 'SCA44', 'SCAR13'], description='glutamate metabotropic receptor 1', other_designations='metabotropic glutamate receptor 1|glutamate receptor, metabotropic 1|protein phosphatase 1, regulatory subunit 85', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=146027634, end_position_on_the_genomic_accession=146437601, orientation='plus', exon_count=11, OMIM=[604473], no_hdr0=''),
    2912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2912, CurrentID=0, Status='live', Symbol='GRM2', Aliases=['GLUR2', 'GPRC1B', 'MGLUR2', 'mGlu2'], description='glutamate metabotropic receptor 2', other_designations='metabotropic glutamate receptor 2|glutamate receptor homolog|glutamate receptor, metabotropic 2', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51707068, end_position_on_the_genomic_accession=51718616, orientation='plus', exon_count=8, OMIM=[604099], no_hdr0=''),
    2913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2913, CurrentID=0, Status='live', Symbol='GRM3', Aliases=['GLUR3', 'GPRC1C', 'MGLUR3', 'mGlu3'], description='glutamate metabotropic receptor 3', other_designations='metabotropic glutamate receptor 3|glutamate receptor, metabotropic 3', map_location='7q21.11-q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=86643909, end_position_on_the_genomic_accession=86864879, orientation='plus', exon_count=7, OMIM=[601115], no_hdr0=''),
    2914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2914, CurrentID=0, Status='live', Symbol='GRM4', Aliases=['GPRC1D', 'MGLUR4', 'mGlu4'], description='glutamate metabotropic receptor 4', other_designations='metabotropic glutamate receptor 4|glutamate receptor, metabotropic 4', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34018643, end_position_on_the_genomic_accession=34155622, orientation='minus', exon_count=15, OMIM=[604100], no_hdr0=''),
    2915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2915, CurrentID=0, Status='live', Symbol='GRM5', Aliases=['GPRC1E', 'MGLUR5', 'PPP1R86', 'mGlu5'], description='glutamate metabotropic receptor 5', other_designations='metabotropic glutamate receptor 5|glutamate receptor, metabotropic 5|protein phosphatase 1, regulatory subunit 86', map_location='11q14.2-q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=88504576, end_position_on_the_genomic_accession=89065982, orientation='minus', exon_count=11, OMIM=[604102], no_hdr0=''),
    2916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2916, CurrentID=0, Status='live', Symbol='GRM6', Aliases=['CSNB1B', 'GPRC1F', 'MGLUR6', 'mGlu6'], description='glutamate metabotropic receptor 6', other_designations='metabotropic glutamate receptor 6|glutamate receptor, metabotropic 6', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178978327, end_position_on_the_genomic_accession=178995320, orientation='minus', exon_count=11, OMIM=[604096], no_hdr0=''),
    2917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2917, CurrentID=0, Status='live', Symbol='GRM7', Aliases=['GLUR7', 'GPRC1G', 'MGLU7', 'MGLUR7', 'NEDSHBA', 'PPP1R87'], description='glutamate metabotropic receptor 7', other_designations='metabotropic glutamate receptor 7|glutamate receptor, metabotropic 7|protein phosphatase 1, regulatory subunit 87', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=6861115, end_position_on_the_genomic_accession=7743038, orientation='plus', exon_count=19, OMIM=[604101], no_hdr0=''),
    2918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2918, CurrentID=0, Status='live', Symbol='GRM8', Aliases=['GLUR8', 'GPRC1H', 'MGLUR8', 'mGlu8'], description='glutamate metabotropic receptor 8', other_designations='metabotropic glutamate receptor 8|glutamate receptor, metabotropic 8', map_location='7q31.33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=126438598, end_position_on_the_genomic_accession=127252941, orientation='minus', exon_count=24, OMIM=[601116], no_hdr0=''),
    2919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2919, CurrentID=0, Status='live', Symbol='CXCL1', Aliases=['FSP', 'GRO1', 'GROa', 'MGSA', 'MGSA-a', 'NAP-3', 'SCYB1'], description='C-X-C motif chemokine ligand 1', other_designations='growth-regulated alpha protein|C-X-C motif chemokine 1|GRO-alpha(1-73)|GRO1 oncogene (melanoma growth stimulating activity, alpha)|GRO1 oncogene (melanoma growth-stimulating activity)|MGSA alpha|chemokine (C-X-C motif) ligand 1 (melanoma growth stimulating activity, alpha)|fibroblast secretory protein|melanoma growth stimulating activity, alpha|melanoma growth stimulatory activity alpha|neutrophil-activating protein 3', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73869393, end_position_on_the_genomic_accession=73871308, orientation='plus', exon_count=4, OMIM=[155730], no_hdr0=''),
    2920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2920, CurrentID=0, Status='live', Symbol='CXCL2', Aliases=['CINC-2a', 'GRO2', 'GROb', 'MGSA-b', 'MIP-2a', 'MIP2', 'MIP2A', 'SCYB2'], description='C-X-C motif chemokine ligand 2', other_designations='C-X-C motif chemokine 2|GRO2 oncogene|MGSA beta|MIP2-alpha|chemokine (C-X-C motif) ligand 2|gro-beta|growth-regulated protein beta|macrophage inflammatory protein 2-alpha|melanoma growth stimulatory activity beta', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74097040, end_position_on_the_genomic_accession=74099195, orientation='minus', exon_count=4, OMIM=[139110], no_hdr0=''),
    2921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2921, CurrentID=0, Status='live', Symbol='CXCL3', Aliases=['CINC-2b', 'GRO3', 'GROg', 'MIP-2b', 'MIP2B', 'SCYB3'], description='C-X-C motif chemokine ligand 3', other_designations='C-X-C motif chemokine 3|GRO-gamma|GRO-gamma(1-73)|GRO3 oncogene|MGSA gamma|MIP2-beta|chemokine (C-X-C motif) ligand 3|growth-regulated protein gamma|macrophage inflammatory protein 2-beta|melanoma growth stimulatory activity gamma', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74036589, end_position_on_the_genomic_accession=74038689, orientation='minus', exon_count=4, OMIM=[139111], no_hdr0=''),
    2922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2922, CurrentID=0, Status='live', Symbol='GRP', Aliases=['BN-10', 'preproGRP', 'proGRP', 'GRP'], description='gastrin releasing peptide', other_designations='gastrin-releasing peptide|bombesin|neuromedin C|pre-progastrin releasing peptide|prepro-GRP|testicular tissue protein Li 103', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59219188, end_position_on_the_genomic_accession=59230771, orientation='plus', exon_count=5, OMIM=[137260], no_hdr0=''),
    2923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2923, CurrentID=0, Status='live', Symbol='PDIA3', Aliases=['ER60', 'ERp57', 'ERp60', 'ERp61', 'GRP57', 'GRP58', 'HEL-S-269', 'HEL-S-93n', 'HsT17083', 'P58', 'PI-PLC'], description='protein disulfide isomerase family A member 3', other_designations='protein disulfide-isomerase A3|58 kDa glucose-regulated protein|58 kDa microsomal protein|ER protein 57|ER protein 60|disulfide isomerase ER-60|endoplasmic reticulum P58|endoplasmic reticulum resident protein 57|endoplasmic reticulum resident protein 60|epididymis secretory protein Li 269|epididymis secretory sperm binding protein Li 93n|glucose regulated protein, 58kDa|phospholipase C-alpha|protein disulfide isomerase-associated 3', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43746438, end_position_on_the_genomic_accession=43773278, orientation='plus', exon_count=13, OMIM=[602046], no_hdr0=''),
    2925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2925, CurrentID=0, Status='live', Symbol='GRPR', Aliases=['BB2', 'BB2R', 'BRS2'], description='gastrin releasing peptide receptor', other_designations='gastrin-releasing peptide receptor|GRP-R|GRP-preferring bombesin receptor|bombesin receptor 2', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16123565, end_position_on_the_genomic_accession=16153518, orientation='plus', exon_count=3, OMIM=[305670], no_hdr0=''),
    2926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2926, CurrentID=0, Status='live', Symbol='GRSF1', Aliases=[], description='G-rich RNA sequence binding factor 1', other_designations='G-rich sequence factor 1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70815783, end_position_on_the_genomic_accession=70843274, orientation='minus', exon_count=12, OMIM=[604851], no_hdr0=''),
    2928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2928, CurrentID=0, Status='live', Symbol='GSC2', Aliases=['GSCL'], description='goosecoid homeobox 2', other_designations='homeobox protein goosecoid-2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19146993, end_position_on_the_genomic_accession=19150292, orientation='minus', exon_count=3, OMIM=[601845], no_hdr0=''),
    2931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2931, CurrentID=0, Status='live', Symbol='GSK3A', Aliases=[], description='glycogen synthase kinase 3 alpha', other_designations='glycogen synthase kinase-3 alpha|GSK-3 alpha|serine/threonine-protein kinase GSK3A', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42230186, end_position_on_the_genomic_accession=42243330, orientation='minus', exon_count=12, OMIM=[606784], no_hdr0=''),
    2932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2932, CurrentID=0, Status='live', Symbol='GSK3B', Aliases=[], description='glycogen synthase kinase 3 beta', other_designations='glycogen synthase kinase-3 beta|GSK-3 beta|serine/threonine-protein kinase GSK3B', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119821321, end_position_on_the_genomic_accession=120095823, orientation='minus', exon_count=13, OMIM=[605004], no_hdr0=''),
    2934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2934, CurrentID=0, Status='live', Symbol='GSN', Aliases=['ADF', 'AGEL'], description='gelsolin', other_designations='gelsolin|actin-depolymerizing factor|brevin|epididymis secretory sperm binding protein', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121201483, end_position_on_the_genomic_accession=121332844, orientation='plus', exon_count=42, OMIM=[137350], no_hdr0=''),
    2935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2935, CurrentID=0, Status='live', Symbol='GSPT1', Aliases=['551G9.2', 'ETF3A', 'GST1', 'eRF3a'], description='G1 to S phase transition 1', other_designations='eukaryotic peptide chain release factor GTP-binding subunit ERF3A|G1 to S phase transition protein 1 homolog|eukaryotic peptide chain release factor subunit 3a|eukaryotic release factor 3a', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11868128, end_position_on_the_genomic_accession=11916654, orientation='minus', exon_count=16, OMIM=[139259], no_hdr0=''),
    2936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2936, CurrentID=0, Status='live', Symbol='GSR', Aliases=['GRD', 'HEL-75', 'HEL-S-122m', 'GSR'], description='glutathione-disulfide reductase', other_designations='glutathione reductase, mitochondrial|GRase|epididymis luminal protein 75|epididymis secretory sperm binding protein Li 122m|glutathione S-reductase', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30678066, end_position_on_the_genomic_accession=30727846, orientation='minus', exon_count=13, OMIM=[138300], no_hdr0=''),
    2937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2937, CurrentID=0, Status='live', Symbol='GSS', Aliases=['GSHS', 'HEL-S-64p', 'HEL-S-88n'], description='glutathione synthetase', other_designations='glutathione synthetase|GSH synthetase|GSH-S|glutathione synthase', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34928432, end_position_on_the_genomic_accession=34956027, orientation='minus', exon_count=15, OMIM=[601002], no_hdr0=''),
    2938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2938, CurrentID=0, Status='live', Symbol='GSTA1', Aliases=['GST-epsilon', 'GST2-1', 'GTH1', 'GSTA1'], description='glutathione S-transferase alpha 1', other_designations='glutathione S-transferase A1|13-hydroperoxyoctadecadienoate peroxidase|GST HA subunit 1|GST class-alpha member 1|S-(hydroxyalkyl)glutathione lyase A1|androst-5-ene-3,17-dione isomerase|glutathione S-alkyltransferase A1|glutathione S-aryltransferase A1|glutathione S-transferase 2|glutathione S-transferase Ha subunit 1|testicular tissue protein Li 80', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52791371, end_position_on_the_genomic_accession=52803827, orientation='minus', exon_count=7, OMIM=[138359], no_hdr0=''),
    2939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2939, CurrentID=0, Status='live', Symbol='GSTA2', Aliases=['GST2-2', 'GTA2', 'GTH2', 'GSTA2'], description='glutathione S-transferase alpha 2', other_designations='glutathione S-transferase A2|GST HA subunit 2|GST class-alpha member 2|GST-gamma|S-(hydroxyalkyl)glutathione lyase A2|glutathione S-alkyltransferase A2|glutathione S-aralkyltransferase A2|glutathione S-aryltransferase A2|liver GST2|testis tissue sperm-binding protein Li 59n', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52750087, end_position_on_the_genomic_accession=52763475, orientation='minus', exon_count=8, OMIM=[138360], no_hdr0=''),
    2940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2940, CurrentID=0, Status='live', Symbol='GSTA3', Aliases=['GSTA3-3', 'GTA3'], description='glutathione S-transferase alpha 3', other_designations='glutathione S-transferase A3|GST class-alpha member 3|S-(hydroxyalkyl)glutathione lyase A3|glutathione S-alkyltransferase A3|glutathione S-aralkyltransferase A3|glutathione S-aryltransferase A3|glutathione S-transferase A3-3', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52896646, end_position_on_the_genomic_accession=52909799, orientation='minus', exon_count=9, OMIM=[605449], no_hdr0=''),
    2941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2941, CurrentID=0, Status='live', Symbol='GSTA4', Aliases=['GSTA4-4', 'GTA4'], description='glutathione S-transferase alpha 4', other_designations='glutathione S-transferase A4|GST class-alpha member 4|S-(hydroxyalkyl)glutathione lyase A4|glutathione S-alkyltransferase A4|glutathione S-aralkyltransferase A4|glutathione S-aryltransferase A4|glutathione S-transferase A4-4|glutathione transferase A4-4', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52977952, end_position_on_the_genomic_accession=52995332, orientation='minus', exon_count=7, OMIM=[605450], no_hdr0=''),
    2944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2944, CurrentID=0, Status='live', Symbol='GSTM1', Aliases=['GST1-1', 'GSTM1a-1a', 'GSTM1b-1b', 'GTH4', 'GTM1', 'H-B', 'MU', 'MU-1', 'GSTM1'], description='glutathione S-transferase mu 1', other_designations='glutathione S-transferase Mu 1|GST HB subunit 4|GST class-mu 1|HB subunit 4|S-(hydroxyalkyl)glutathione lyase|glutathione S-alkyltransferase|glutathione S-aralkyltransferase|glutathione S-aryltransferase|glutathione S-transferase M1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109687817, end_position_on_the_genomic_accession=109693745, orientation='plus', exon_count=8, OMIM=[138350], no_hdr0=''),
    2946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2946, CurrentID=0, Status='live', Symbol='GSTM2', Aliases=['GST4', 'GSTM-2', 'GTHMUS', 'GSTM2'], description='glutathione S-transferase mu 2', other_designations='glutathione S-transferase Mu 2|GST class-mu 2|GST, muscle|S-(hydroxyalkyl)glutathione lyase M2|epididymis secretory sperm binding protein|glutathione S-alkyltransferase M2|glutathione S-aralkyltransferase M2|glutathione S-aryltransferase M2|glutathione S-transferase 4|glutathione S-transferase M1|glutathione S-transferase M2 (muscle)|glutathione S-transferase mu 2 (muscle)', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109668057, end_position_on_the_genomic_accession=109683997, orientation='plus', exon_count=10, OMIM=[138380], no_hdr0=''),
    2947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2947, CurrentID=0, Status='live', Symbol='GSTM3', Aliases=['GST5', 'GSTB-3', 'GTM3', 'GSTM3'], description='glutathione S-transferase mu 3', other_designations='glutathione S-transferase Mu 3|GST class-mu 3|S-(hydroxyalkyl)glutathione lyase M3|brain GST|brain type mu-glutathione S-transferase|epididymis secretory sperm binding protein|glutathione S-alkyltransferase M3|glutathione S-aralkyltransferase M3|glutathione S-aryltransferase M3|glutathione S-transferase M3 (brain)|glutathione S-transferase mu 3 (brain)|glutathione S-transferase, Mu-3|hGSTM3-3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109733937, end_position_on_the_genomic_accession=109741038, orientation='minus', exon_count=9, OMIM=[138390], no_hdr0=''),
    2948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2948, CurrentID=0, Status='live', Symbol='GSTM4', Aliases=['GSTM4-4', 'GTM4'], description='glutathione S-transferase mu 4', other_designations='glutathione S-transferase Mu 4|GST class-mu 4|GST-Mu2|GTS-Mu2|S-(hydroxyalkyl)glutathione lyase M4|glutathione S-alkyltransferase M4|glutathione S-aralkyltransferase M4|glutathione S-aryltransferase M4|glutathione S-transferase M4|leukotriene C4 synthase GSTM4|testis tissue sperm-binding protein Li 60n', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109656076, end_position_on_the_genomic_accession=109665497, orientation='plus', exon_count=10, OMIM=[138333], no_hdr0=''),
    2949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2949, CurrentID=0, Status='live', Symbol='GSTM5', Aliases=['GSTM5-5', 'GTM5'], description='glutathione S-transferase mu 5', other_designations='glutathione S-transferase Mu 5|GST class-mu 5|S-(hydroxyalkyl)glutathione lyase M5|epididymis secretory sperm binding protein|glutathione S-alkyltransferase M5|glutathione S-aralkyltransferase M5|glutathione S-aryltransferase M5|glutathione S-transferase M5', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109711751, end_position_on_the_genomic_accession=109718268, orientation='plus', exon_count=9, OMIM=[138385], no_hdr0=''),
    2950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2950, CurrentID=0, Status='live', Symbol='GSTP1', Aliases=['DFN7', 'FAEES3', 'GST3', 'GSTP', 'HEL-S-22', 'PI'], description='glutathione S-transferase pi 1', other_designations='glutathione S-transferase P|GST class-pi|GSTP1-1|deafness, X-linked 7|epididymis secretory protein Li 22|fatty acid ethyl ester synthase III', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67583812, end_position_on_the_genomic_accession=67586653, orientation='plus', exon_count=7, OMIM=[134660], no_hdr0=''),
    2952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2952, CurrentID=0, Status='live', Symbol='GSTT1', Aliases=[], description='glutathione S-transferase theta 1', other_designations='glutathione S-transferase theta-1|GST class-theta-1|glutathione transferase T1-1', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[600436], no_hdr0=''),
    2953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2953, CurrentID=0, Status='live', Symbol='GSTT2', Aliases=[], description='glutathione S-transferase theta 2 (gene/pseudogene)', other_designations='glutathione S-transferase theta-2|GST class-theta-2', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23980134, end_position_on_the_genomic_accession=23983915, orientation='plus', exon_count=5, OMIM=[600437], no_hdr0=''),
    2954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2954, CurrentID=0, Status='live', Symbol='GSTZ1', Aliases=['GSTZ1-1', 'MAAI', 'MAAID', 'MAI'], description='glutathione S-transferase zeta 1', other_designations='maleylacetoacetate isomerase|S-(hydroxyalkyl)glutathione lyase|glutathione S-alkyltransferase|glutathione S-aralkyltransferase|glutathione S-aryltransferase|glutathione transferase zeta 1|maleylacetone isomerase', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77321002, end_position_on_the_genomic_accession=77331597, orientation='plus', exon_count=9, OMIM=[603758], no_hdr0=''),
    2956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2956, CurrentID=0, Status='live', Symbol='MSH6', Aliases=['GTBP', 'GTMBP', 'HNPCC5', 'HSAP', 'MMRCS3', 'p160'], description='mutS homolog 6', other_designations='DNA mismatch repair protein Msh6|G/T mismatch-binding protein|mutS protein homolog 6|mutS-alpha 160 kDa subunit|sperm-associated protein', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47783145, end_position_on_the_genomic_accession=47806954, orientation='plus', exon_count=11, OMIM=[600678], no_hdr0=''),
    2957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2957, CurrentID=0, Status='live', Symbol='GTF2A1', Aliases=['TF2A1', 'TFIIA', 'TFIIA-42', 'TFIIAL'], description='general transcription factor IIA subunit 1', other_designations='transcription initiation factor IIA subunit 1|TFIIA alpha/beta subunits|general transcription factor IIA 1|general transcription factor IIA, 1, 19/37kDa|glucose regulated protein, 58kD pseudogene|transcription initiation factor TFIIA 42 kDa subunit', map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=81175452, end_position_on_the_genomic_accession=81221390, orientation='minus', exon_count=11, OMIM=[600520], no_hdr0=''),
    2958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2958, CurrentID=0, Status='live', Symbol='GTF2A2', Aliases=['HsT18745', 'T18745', 'TF2A2', 'TFIIA', 'TFIIA-12', 'TFIIA-gamma', 'TFIIAS'], description='general transcription factor IIA subunit 2', other_designations='transcription initiation factor IIA subunit 2|TFIIA gamma subunit|TFIIA p12 subunit|general transcription factor IIA 2|general transcription factor IIA, 2, 12kDa|transcription initiation factor IIA gamma chain', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59638062, end_position_on_the_genomic_accession=59657515, orientation='minus', exon_count=7, OMIM=[600519], no_hdr0=''),
    2959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2959, CurrentID=0, Status='live', Symbol='GTF2B', Aliases=['TF2B', 'TFIIB'], description='general transcription factor IIB', other_designations='transcription initiation factor IIB|RNA polymerase II transcription factor IIB|S300-II|general transcription factor TFIIB', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=88852633, end_position_on_the_genomic_accession=88891944, orientation='minus', exon_count=9, OMIM=[189963], no_hdr0=''),
    2960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2960, CurrentID=0, Status='live', Symbol='GTF2E1', Aliases=['FE', 'TF2E1', 'TFIIE-A'], description='general transcription factor IIE subunit 1', other_designations='general transcription factor IIE subunit 1|TFIIE alpha subunit|TFIIE-alpha|general transcription factor IIE 56 kDa subunit|general transcription factor IIE, polypeptide 1, alpha 56kDa|transcription initiation factor IIE subunit alpha', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120742744, end_position_on_the_genomic_accession=120783069, orientation='plus', exon_count=5, OMIM=[189962], no_hdr0=''),
    2961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2961, CurrentID=0, Status='live', Symbol='GTF2E2', Aliases=['FE', 'TF2E2', 'TFIIE-B', 'TTD6'], description='general transcription factor IIE subunit 2', other_designations='transcription initiation factor IIE subunit beta|TFIIE beta subunit|TFIIE-beta|general transcription factor IIE, polypeptide 2, beta 34kDa', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30578318, end_position_on_the_genomic_accession=30658241, orientation='minus', exon_count=13, OMIM=[189964], no_hdr0=''),
    2962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2962, CurrentID=0, Status='live', Symbol='GTF2F1', Aliases=['BTF4', 'RAP74', 'TF2F1', 'TFIIF'], description='general transcription factor IIF subunit 1', other_designations='general transcription factor IIF subunit 1|TFIIF-alpha|general transcription factor IIF 74 kDa subunit|general transcription factor IIF, polypeptide 1, 74kDa|transcription initiation factor IIF subunit alpha|transcription initiation factor RAP74', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6379569, end_position_on_the_genomic_accession=6393186, orientation='minus', exon_count=13, OMIM=[189968], no_hdr0=''),
    2963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2963, CurrentID=0, Status='live', Symbol='GTF2F2', Aliases=['BTF4', 'RAP30', 'TF2F2', 'TFIIF'], description='general transcription factor IIF subunit 2', other_designations='general transcription factor IIF subunit 2|ATP-dependent helicase GTF2F2|TFIIF-beta|general transcription factor IIF 30 kDa subunit|general transcription factor IIF, polypeptide 2, 30kDa|transcription initiation factor IIF subunit beta|transcription initiation factor RAP30', map_location='13q14.12-q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45119830, end_position_on_the_genomic_accession=45284893, orientation='plus', exon_count=12, OMIM=[189969], no_hdr0=''),
    2965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2965, CurrentID=0, Status='live', Symbol='GTF2H1', Aliases=['BTF2', 'P62', 'TFB1', 'TFIIH'], description='general transcription factor IIH subunit 1', other_designations='general transcription factor IIH subunit 1|BTF2 p62|TFIIH basal transcription factor complex p62 subunit|basic transcription factor 2 62 kDa subunit|epididymis secretory sperm binding protein|general transcription factor IIH polypeptide 1|general transcription factor IIH, polypeptide 1, 62kDa', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18322567, end_position_on_the_genomic_accession=18367045, orientation='plus', exon_count=18, OMIM=[189972], no_hdr0=''),
    2966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2966, CurrentID=0, Status='live', Symbol='GTF2H2', Aliases=['BTF2', 'BTF2 p44', 'BTF2P44', 'T-BTF2P44', 'TFIIH', 'p44'], description='general transcription factor IIH subunit 2', other_designations='general transcription factor IIH subunit 2|TFIIH basal transcription factor complex p44 subunit|basic transcription factor 2 44 kDa subunit|general transcription factor IIH polypeptide 2|general transcription factor IIH, polypeptide 2, 44kD subunit|general transcription factor IIH, polypeptide 2, 44kDa', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=71035124, end_position_on_the_genomic_accession=71109113, orientation='minus', exon_count=21, OMIM=[601748], no_hdr0=''),
    2967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2967, CurrentID=0, Status='live', Symbol='GTF2H3', Aliases=['BTF2', 'P34', 'TFB4', 'TFIIH'], description='general transcription factor IIH subunit 3', other_designations='general transcription factor IIH subunit 3|TFIIH basal transcription factor complex p34 subunit|basic transcription factor 2 34 kDa subunit|general transcription factor IIH, polypeptide 3, 34kDa', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123633829, end_position_on_the_genomic_accession=123662604, orientation='plus', exon_count=13, OMIM=[601750], no_hdr0=''),
    2968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2968, CurrentID=0, Status='live', Symbol='GTF2H4', Aliases=['P52', 'TFB2', 'TFIIH'], description='general transcription factor IIH subunit 4', other_designations='general transcription factor IIH subunit 4|BTF2 p52|TFIIH basal transcription factor complex p52 subunit|basic transcription factor 2 52 kDa subunit|general transcription factor IIH polypeptide 4|general transcription factor IIH, polypeptide 4, 52kDa', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30908207, end_position_on_the_genomic_accession=30914106, orientation='plus', exon_count=14, OMIM=[601760], no_hdr0=''),
    2969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2969, CurrentID=0, Status='live', Symbol='GTF2I', Aliases=['BAP135', 'BTKAP1', 'DIWS', 'GTFII-I', 'IB291', 'SPIN', 'TFII-I', 'WBS', 'WBSCR6'], description='general transcription factor IIi', other_designations='general transcription factor II-I|BTK-associated protein, 135kD|Bruton tyrosine kinase-associated protein 135|SRF-Phox1-interacting protein|Williams-Beuren syndrome chromosome region 6', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74657718, end_position_on_the_genomic_accession=74760692, orientation='plus', exon_count=35, OMIM=[601679], no_hdr0=''),
    2971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2971, CurrentID=0, Status='live', Symbol='GTF3A', Aliases=['AP2', 'TFIIIA'], description='general transcription factor IIIA', other_designations='transcription factor IIIA', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27424619, end_position_on_the_genomic_accession=27435823, orientation='plus', exon_count=9, OMIM=[600860], no_hdr0=''),
    2972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2972, CurrentID=0, Status='live', Symbol='BRF1', Aliases=['BRF', 'BRF-1', 'CFDS', 'GTF3B', 'HEL-S-76p', 'TAF3B2', 'TAF3C', 'TAFIII90', 'TF3B90', 'TFIIIB90', 'hBRF'], description='BRF1 RNA polymerase III transcription initiation factor subunit', other_designations='transcription factor IIIB 90 kDa subunit|B - related factor 1|BRF1 homolog, subunit of RNA polymerase III transcription initiation factor IIIB|BRF1, RNA polymerase III transcription initiation factor 90 kDa subunit|TATA box binding protein (TBP)-associated factor 3C|TATA box binding protein (TBP)-associated factor, RNA polymerase III, GTF3B subunit 2|TBP - associated factor, RNA polymerase III, 90kD|epididymis secretory sperm binding protein Li 76p|general transcription factor IIIB, 90kD subunit', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105209286, end_position_on_the_genomic_accession=105315589, orientation='minus', exon_count=23, OMIM=[604902], no_hdr0=''),
    2975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2975, CurrentID=0, Status='live', Symbol='GTF3C1', Aliases=['TFIIIC', 'TFIIIC220', 'TFIIICalpha'], description='general transcription factor IIIC subunit 1', other_designations='general transcription factor 3C polypeptide 1|TF3C-alpha|TFIIIC 220 kDa subunit|TFIIIC box B-binding subunit|general transcription factor IIIC, polypeptide 1 (alpha subunit)|general transcription factor IIIC, polypeptide 1, alpha 220kDa|transcription factor IIIC 220 kDa subunit|transcription factor IIIC subunit alpha', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27460613, end_position_on_the_genomic_accession=27549922, orientation='minus', exon_count=37, OMIM=[603246], no_hdr0=''),
    2976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2976, CurrentID=0, Status='live', Symbol='GTF3C2', Aliases=['TF3C-beta', 'TFIIIC-BETA', 'TFIIIC110'], description='general transcription factor IIIC subunit 2', other_designations='general transcription factor 3C polypeptide 2|TFIIIC 110 kDa subunit|general transcription factor IIIC, polypeptide 2, beta 110kDa|transcription factor IIIC 110 kDa subunit|transcription factor IIIC subunit beta', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27325854, end_position_on_the_genomic_accession=27356764, orientation='minus', exon_count=22, OMIM=[604883], no_hdr0=''),
    2977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2977, CurrentID=0, Status='live', Symbol='GUCY1A2', Aliases=['GC-SA2', 'GUC1A2'], description='guanylate cyclase 1 soluble subunit alpha 2', other_designations='guanylate cyclase soluble subunit alpha-2|GCS-alpha-2|guanylate cyclase 1, soluble, alpha 2', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=106674019, end_position_on_the_genomic_accession=107018476, orientation='minus', exon_count=9, OMIM=[601244], no_hdr0=''),
    2978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2978, CurrentID=0, Status='live', Symbol='GUCA1A', Aliases=['C6orf131', 'COD3', 'CORD14', 'GCAP', 'GCAP1', 'GUCA', 'GUCA1'], description='guanylate cyclase activator 1A', other_designations='guanylyl cyclase-activating protein 1|cone dystrophy 3|guanylate cyclase-activating protein, photoreceptor 1|guanylin 1, retina', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42173364, end_position_on_the_genomic_accession=42180056, orientation='plus', exon_count=4, OMIM=[600364], no_hdr0=''),
    2979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2979, CurrentID=0, Status='live', Symbol='GUCA1B', Aliases=['GCAP 2', 'GCAP2', 'GUCA2', 'RP48'], description='guanylate cyclase activator 1B', other_designations='guanylyl cyclase-activating protein 2|guanylate cyclase activator 1B (retina)|guanylate cyclase-activating protein, photoreceptor 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42183284, end_position_on_the_genomic_accession=42194956, orientation='minus', exon_count=4, OMIM=[602275], no_hdr0=''),
    2980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2980, CurrentID=0, Status='live', Symbol='GUCA2A', Aliases=['GCAP-I', 'GUCA2', 'STARA'], description='guanylate cyclase activator 2A', other_designations='guanylin|guanylate cyclase activator 2A (guanylin 2, intestinal, heat-stable)|guanylate cyclase-activating protein 1|guanylate cyclase-activating protein I|prepro-guanylin', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42162690, end_position_on_the_genomic_accession=42164745, orientation='minus', exon_count=3, OMIM=[139392], no_hdr0=''),
    2981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2981, CurrentID=0, Status='live', Symbol='GUCA2B', Aliases=['GCAP-II', 'UGN'], description='guanylate cyclase activator 2B', other_designations='guanylate cyclase activator 2B|prepro-uroguanylin|uroguanylin', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42153410, end_position_on_the_genomic_accession=42155820, orientation='plus', exon_count=3, OMIM=[601271], no_hdr0=''),
    2982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2982, CurrentID=0, Status='live', Symbol='GUCY1A1', Aliases=['GC-S-alpha-1', 'GC-SA3', 'GCS-alpha-3', 'GUC1A3', 'GUCA3', 'GUCSA3', 'GUCY1A3', 'MYMY6'], description='guanylate cyclase 1 soluble subunit alpha 1', other_designations='guanylate cyclase soluble subunit alpha-1|guanylate cyclase 1, soluble, alpha 3|soluble guanylate cyclase large subunit', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155666725, end_position_on_the_genomic_accession=155737059, orientation='plus', exon_count=13, OMIM=[139396], no_hdr0=''),
    2983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2983, CurrentID=0, Status='live', Symbol='GUCY1B1', Aliases=['GC-S-beta-1', 'GC-SB3', 'GUC1B3', 'GUCB3', 'GUCSB3', 'GUCY1B3'], description='guanylate cyclase 1 soluble subunit beta 1', other_designations='guanylate cyclase soluble subunit beta-1|GCS-beta-1|GCS-beta-3|guanylate cyclase 1, soluble, beta 3|guanylate cyclase soluble subunit beta-3|soluble guanylate cyclase small subunit', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155759021, end_position_on_the_genomic_accession=155807811, orientation='plus', exon_count=18, OMIM=[139397], no_hdr0=''),
    2984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2984, CurrentID=0, Status='live', Symbol='GUCY2C', Aliases=['DIAR6', 'GC-C', 'GUC2C', 'MECIL', 'MUCIL', 'STAR'], description='guanylate cyclase 2C', other_designations='heat-stable enterotoxin receptor|STA receptor|guanylyl cyclase C|intestinal guanylate cyclase', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14612632, end_position_on_the_genomic_accession=14696625, orientation='minus', exon_count=27, OMIM=[601330], no_hdr0=''),
    2986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2986, CurrentID=0, Status='live', Symbol='GUCY2F', Aliases=['CYGF', 'GC-F', 'GUC2DL', 'GUC2F', 'RETGC-2', 'ROS-GC2'], description='guanylate cyclase 2F, retinal', other_designations='retinal guanylyl cyclase 2|guanylate cyclase 2D-like, membrane (retina-specific)|guanylate cyclase F|rod outer segment membrane guanylate cyclase 2', map_location='Xq22.3-q23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=109372061, end_position_on_the_genomic_accession=109482086, orientation='minus', exon_count=22, OMIM=[300041], no_hdr0=''),
    2987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2987, CurrentID=0, Status='live', Symbol='GUK1', Aliases=['GMK'], description='guanylate kinase 1', other_designations='guanylate kinase|ATP:GMP phosphotransferase|GMP kinase', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228140084, end_position_on_the_genomic_accession=228148955, orientation='plus', exon_count=12, OMIM=[139270], no_hdr0=''),
    2988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2988, CurrentID=0, Status='live', Symbol='GUK2', Aliases=[], description='guanylate kinase 2', other_designations='guanylate kinase 2', map_location='1q32.1-q42', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[139280], no_hdr0=''),
    2990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2990, CurrentID=0, Status='live', Symbol='GUSB', Aliases=['BG', 'MPS7'], description='glucuronidase beta', other_designations='beta-glucuronidase|beta-D-glucuronidase|beta-G1', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=65960684, end_position_on_the_genomic_accession=65982230, orientation='minus', exon_count=12, OMIM=[611499], no_hdr0=''),
    2992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2992, CurrentID=0, Status='live', Symbol='GYG1', Aliases=['GSD15', 'GYG'], description='glycogenin 1', other_designations='glycogenin-1|GN-1|glycogenin glucosyltransferase', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=148991515, end_position_on_the_genomic_accession=149031775, orientation='plus', exon_count=10, OMIM=[603942], no_hdr0=''),
    2993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2993, CurrentID=0, Status='live', Symbol='GYPA', Aliases=['CD235a', 'GPA', 'GPErik', 'GPSAT', 'HGpMiV', 'HGpMiXI', 'HGpSta(C)', 'MN', 'MNS', 'PAS-2'], description='glycophorin A (MNS blood group)', other_designations='glycophorin-A|MN sialoglycoprotein|Mi.V glycoprotein (24 AA)|erythroid-lineage-specific membrane sialoglycoprotein|glycophorin A (MN blood group)|glycophorin A, GPA|glycophorin Erik|glycophorin MiI|glycophorin MiV|glycophorin SAT|glycophorin Sta type C|recombinant glycophorin A-B Miltenberger-DR|sialoglycoprotein alpha', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=144109303, end_position_on_the_genomic_accession=144140854, orientation='minus', exon_count=8, OMIM=[617922], no_hdr0=''),
    2994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2994, CurrentID=0, Status='live', Symbol='GYPB', Aliases=['CD235b', 'GPB', 'GYP', 'GYPA', 'MNS', 'PAS-3', 'SS'], description='glycophorin B (MNS blood group)', other_designations='glycophorin-B|GYPB-A fusion|GYPB-A-B fusion|GYPB/GYPA fusion|SS-active sialoglycoprotein|Ss blood group|blood group system MNSs, Mur-like|blood group system MNSs, St(a) type E|blood group system MNSs, St(a) type F|glycophorin A|glycophorin B blood group antigen|glycophorin B, blood group system Ss, S, Mit+|glycophorin B/glycophorin A fusion protein|glycophorin Hop|hybrid glycophorin Kip|sialoglycoprotein delta', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143995172, end_position_on_the_genomic_accession=144021861, orientation='minus', exon_count=8, OMIM=[617923], no_hdr0=''),
    2995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2995, CurrentID=0, Status='live', Symbol='GYPC', Aliases=['CD236', 'CD236R', 'GE', 'GPC', 'GPD', 'GYPD', 'PAS-2', "PAS-2'"], description='glycophorin C (Gerbich blood group)', other_designations='glycophorin-C|Gerbich blood group antigen|glycoconnectin|glycophorin-D|glycoprotein beta|sialoglycoprotein D', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=126656158, end_position_on_the_genomic_accession=126696668, orientation='plus', exon_count=6, OMIM=[110750], no_hdr0=''),
    2996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2996, CurrentID=0, Status='live', Symbol='GYPE', Aliases=['GPE', 'GYPA', 'MNS', 'MiIX'], description='glycophorin E (MNS blood group)', other_designations='glycophorin-E|glycophorin A', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143870864, end_position_on_the_genomic_accession=143912131, orientation='minus', exon_count=6, OMIM=[138590], no_hdr0=''),
    2997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2997, CurrentID=0, Status='live', Symbol='GYS1', Aliases=['GSY', 'GYS'], description='glycogen synthase 1', other_designations='glycogen [starch] synthase, muscle|glycogen synthase 1 (muscle)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48968130, end_position_on_the_genomic_accession=48993309, orientation='minus', exon_count=16, OMIM=[138570], no_hdr0=''),
    2998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2998, CurrentID=0, Status='live', Symbol='GYS2', Aliases=[], description='glycogen synthase 2', other_designations='glycogen [starch] synthase, liver|glycogen synthase 2 (liver)', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21531527, end_position_on_the_genomic_accession=21604858, orientation='minus', exon_count=19, OMIM=[138571], no_hdr0=''),
    2999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=2999, CurrentID=0, Status='live', Symbol='GZMH', Aliases=['CCP-X', 'CGL-2', 'CSP-C', 'CTLA1', 'CTSGL2'], description='granzyme H', other_designations='granzyme H|cathepsin G-like 2, protein h-CCPX|cytotoxic T-lymphocyte proteinase|cytotoxic T-lymphocyte-associated serine esterase 1|cytotoxin serine protease-C', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24606480, end_position_on_the_genomic_accession=24609763, orientation='minus', exon_count=5, OMIM=[116831], no_hdr0=''),
    3000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3000, CurrentID=0, Status='live', Symbol='GUCY2D', Aliases=['CACD1', 'CG-E', 'CORD5', 'CORD6', 'CSNB1I', 'CYGD', 'GUC1A4', 'GUC2D', 'LCA', 'LCA1', 'RCD2', 'RETGC-1', 'ROS-GC1', 'ROSGC', 'retGC'], description='guanylate cyclase 2D, retinal', other_designations='retinal guanylyl cyclase 1|ROS-GC|cone rod dystrophy 6|guanylate cyclase 2D, membrane (retina-specific)|retinal guanylate cyclase 1|rod outer segment membrane guanylate cyclase', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8002615, end_position_on_the_genomic_accession=8020342, orientation='plus', exon_count=20, OMIM=[600179], no_hdr0=''),
    3001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3001, CurrentID=0, Status='live', Symbol='GZMA', Aliases=['CTLA3', 'HFSP'], description='granzyme A', other_designations='granzyme A|CTL tryptase|Cytotoxic T-lymphocyte-associated serine esterase-3|Granzyme A (Cytotoxic T-lymphocyte-associated serine esterase-3; Hanukah factor serine protease)|HF|Hanukah factor serine protease)|cytotoxic T-lymphocyte proteinase 1|fragmentin-1|granzyme 1|granzyme A (granzyme 1, cytotoxic T-lymphocyte-associated serine esterase 3)|h factor', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55102646, end_position_on_the_genomic_accession=55110252, orientation='plus', exon_count=5, OMIM=[140050], no_hdr0=''),
    3002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3002, CurrentID=0, Status='live', Symbol='GZMB', Aliases=['C11', 'CCPI', 'CGL-1', 'CGL1', 'CSP-B', 'CSPB', 'CTLA1', 'CTSGL1', 'HLP', 'SECT'], description='granzyme B', other_designations='granzyme B|T-cell serine protease 1-3E|cathepsin G-like 1|cytotoxic T-lymphocyte proteinase 2|cytotoxic serine protease B|fragmentin 2|granzyme B (granzyme 2, cytotoxic T-lymphocyte-associated serine esterase 1)|human lymphocyte protein', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24630954, end_position_on_the_genomic_accession=24634190, orientation='minus', exon_count=5, OMIM=[123910], no_hdr0=''),
    3003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3003, CurrentID=0, Status='live', Symbol='GZMK', Aliases=['TRYP2'], description='granzyme K', other_designations='granzyme K|NK-Tryp-2|NK-tryptase-2|fragmentin-3|granzyme 3|granzyme K (granzyme 3; tryptase II)|granzyme K (serine protease, granzyme 3; tryptase II)|tryptase II', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55024256, end_position_on_the_genomic_accession=55034570, orientation='plus', exon_count=5, OMIM=[600784], no_hdr0=''),
    3004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3004, CurrentID=0, Status='live', Symbol='GZMM', Aliases=['LMET1', 'MET1'], description='granzyme M', other_designations='granzyme M|HU-Met-1|Met-1 serine protease|lymphocyte met-ase 1|met-ase|natural killer cell granular protease', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=544053, end_position_on_the_genomic_accession=549922, orientation='plus', exon_count=5, OMIM=[600311], no_hdr0=''),
    3005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3005, CurrentID=0, Status='live', Symbol='H1-0', Aliases=['H1.0', 'H10', 'H1F0', 'H1FV'], description='H1.0 linker histone', other_designations="histone H1.0|H1 histone family member 0|H1.0, H1(0), H1-0|histone H1'|histone H1(0)", map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37805229, end_position_on_the_genomic_accession=37807432, orientation='plus', exon_count=1, OMIM=[142708], no_hdr0=''),
    3006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3006, CurrentID=0, Status='live', Symbol='H1-2', Aliases=['H1.2', 'H1C', 'H1F2', 'H1s-1', 'HIST1H1C'], description='H1.2 linker histone, cluster member', other_designations='histone H1.2|H1 histone family, member 2|histone 1, H1c|histone H1c|histone H1d|histone H1s-1|histone cluster 1 H1 family member c|histone cluster 1, H1c', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26055740, end_position_on_the_genomic_accession=26056470, orientation='minus', exon_count=1, OMIM=[142710], no_hdr0=''),
    3007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3007, CurrentID=0, Status='live', Symbol='H1-3', Aliases=['H1.3', 'H1D', 'H1F3', 'H1s-2', 'HIST1H1D'], description='H1.3 linker histone, cluster member', other_designations='histone H1.3|H1 histone family, member 3|histone 1, H1d|histone H1c|histone H1s-2|histone cluster 1 H1 family member d|histone cluster 1, H1d', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26234212, end_position_on_the_genomic_accession=26234987, orientation='minus', exon_count=1, OMIM=[142210], no_hdr0=''),
    3008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3008, CurrentID=0, Status='live', Symbol='H1-4', Aliases=['H1.4', 'H1E', 'H1F4', 'H1s-4', 'HIST1H1E', 'RMNS', 'dJ221C16.5'], description='H1.4 linker histone, cluster member', other_designations='histone H1.4|H1 histone family, member 4|histone 1, H1e|histone H1b|histone H1s-4|histone cluster 1 H1 family member e|histone cluster 1, H1e', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26156329, end_position_on_the_genomic_accession=26157115, orientation='plus', exon_count=1, OMIM=[142220], no_hdr0=''),
    3009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3009, CurrentID=0, Status='live', Symbol='H1-5', Aliases=['H1', 'H1.5', 'H1B', 'H1F5', 'H1s-3', 'HIST1H1B'], description='H1.5 linker histone, cluster member', other_designations='histone H1.5|H1 histone family, member 5|histone 1, H1b|histone H1a|histone H1b|histone H1s-3|histone cluster 1 H1 family member b|histone cluster 1, H1b', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27866792, end_position_on_the_genomic_accession=27867588, orientation='minus', exon_count=1, OMIM=[142711], no_hdr0=''),
    3010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3010, CurrentID=0, Status='live', Symbol='H1-6', Aliases=['H1.6', 'H1FT', 'H1t', 'HIST1H1T', 'dJ221C16.2'], description='H1.6 linker histone, cluster member', other_designations='histone H1t|H1 histone family, member T (testis-specific)|histone 1, H1t|histone cluster 1 H1 family member t|histone cluster 1, H1t|testicular H1 histone', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26107412, end_position_on_the_genomic_accession=26108135, orientation='minus', exon_count=1, OMIM=[142712], no_hdr0=''),
    3012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3012, CurrentID=0, Status='live', Symbol='H2AC8', Aliases=['H2A.1', 'H2A.2', 'H2A/a', 'H2AC4', 'H2AFA', 'HIST1H2AE'], description='H2A clustered histone 8', other_designations='histone H2A type 1-B/E|H2A histone family, member A|histone 1, H2ae|histone H2A/a|histone H2AE|histone cluster 1 H2A family member e|histone cluster 1, H2ae', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26216921, end_position_on_the_genomic_accession=26217483, orientation='plus', exon_count=1, OMIM=[602786], no_hdr0=''),
    3013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3013, CurrentID=0, Status='live', Symbol='H2AC7', Aliases=['H2A.3', 'H2A/g', 'H2AFG', 'HIST1H2AD'], description='H2A clustered histone 7', other_designations='histone H2A type 1-D|H2A histone family, member G|histone 1, H2ad|histone H2A.3|histone H2A/g|histone H2AD|histone cluster 1 H2A family member d|histone cluster 1, H2ad', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26198784, end_position_on_the_genomic_accession=26199293, orientation='minus', exon_count=1, OMIM=[602792], no_hdr0=''),
    3014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3014, CurrentID=0, Status='live', Symbol='H2AX', Aliases=['H2A.X', 'H2A/X', 'H2AFX'], description='H2A.X variant histone', other_designations='histone H2AX|H2A histone family member X|H2AX histone|histone H2A.x', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119093874, end_position_on_the_genomic_accession=119095465, orientation='minus', exon_count=1, OMIM=[601772], no_hdr0=''),
    3015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3015, CurrentID=0, Status='live', Symbol='H2AZ1', Aliases=['H2A.Z-1', 'H2A.z', 'H2A/z', 'H2AFZ', 'H2AZ'], description='H2A.Z variant histone 1', other_designations='histone H2A.Z|H2A histone family member Z|H2AZ histone', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99948088, end_position_on_the_genomic_accession=99950275, orientation='minus', exon_count=5, OMIM=[142763], no_hdr0=''),
    3017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3017, CurrentID=0, Status='live', Symbol='H2BC5', Aliases=['H2B.1B', 'H2B/a', 'H2B/b', 'H2B/g', 'H2B/h', 'H2B/k', 'H2B/l', 'H2BFA', 'H2BFB', 'H2BFG', 'H2BFH', 'H2BFK', 'H2BFL', 'HIRIP2', 'HIST1H2BC', 'HIST1H2BD', 'HIST1H2BE', 'HIST1H2BF', 'HIST1H2BG', 'HIST1H2BI', 'dJ221C16.6'], description='H2B clustered histone 5', other_designations='histone H2B type 1-D|H2B histone family, member B|HIRA-interacting protein 2|Histone H2B type 1-C/E/F/G/I|Histone H2B.1 A|Histone H2B.a|Histone H2B.g|Histone H2B.h|Histone H2B.k|Histone H2B.l|histone 1, H2bd|histone H2B.1 B|histone H2B.b|histone cluster 1 H2B family member d|histone cluster 1, H2bd', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26158008, end_position_on_the_genomic_accession=26171349, orientation='plus', exon_count=3, OMIM=[602799], no_hdr0=''),
    3018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3018, CurrentID=0, Status='live', Symbol='H2BC3', Aliases=['H2B.1', 'H2B/f', 'H2BFF', 'HIST1H2BB'], description='H2B clustered histone 3', other_designations='histone H2B type 1-B|H2B histone family, member F|histone 1, H2bb|histone H2B.1|histone H2B.f|histone cluster 1 H2B family member b|histone cluster 1, H2bb', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26043227, end_position_on_the_genomic_accession=26043713, orientation='minus', exon_count=1, OMIM=[602803], no_hdr0=''),
    3020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3020, CurrentID=0, Status='live', Symbol='H3-3A', Aliases=['H3-3B', 'H3.3A', 'H3F3', 'H3F3A'], description='H3.3 histone A', other_designations='histone H3.3|H3 histone family member 3A|H3 histone, family 3A', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226061831, end_position_on_the_genomic_accession=226072019, orientation='plus', exon_count=7, OMIM=[601128], no_hdr0=''),
    3021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3021, CurrentID=0, Status='live', Symbol='H3-3B', Aliases=['H3-3A', 'H3.3B', 'H3F3B'], description='H3.3 histone B', other_designations='histone H3.3|H3 histone family member 3B|H3 histone, family 3B (H3.3B)', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75776434, end_position_on_the_genomic_accession=75779779, orientation='minus', exon_count=4, OMIM=[601058], no_hdr0=''),
    3024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3024, CurrentID=0, Status='live', Symbol='H1-1', Aliases=['H1.1', 'H1A', 'H1F1', 'HIST1', 'HIST1H1A'], description='H1.1 linker histone, cluster member', other_designations='histone H1.1|H1 histone family, member 1|histone 1, H1a|histone H1a|histone cluster 1 H1 family member a|histone cluster 1, H1a', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26017032, end_position_on_the_genomic_accession=26017787, orientation='minus', exon_count=1, OMIM=[142709], no_hdr0=''),
    3026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3026, CurrentID=0, Status='live', Symbol='HABP2', Aliases=['FSAP', 'HABP', 'HGFAL', 'NMTC5', 'PHBP'], description='hyaluronan binding protein 2', other_designations='hyaluronan-binding protein 2|factor VII activating protein|factor VII-activating protease|factor seven-activating protease|hepatocyte growth factor activator-like protein|hyaluronic acid binding protein 2|plasma hyaluronan binding protein', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113550831, end_position_on_the_genomic_accession=113589602, orientation='plus', exon_count=14, OMIM=[603924], no_hdr0=''),
    3028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3028, CurrentID=0, Status='live', Symbol='HSD17B10', Aliases=['17b-HSD10', 'ABAD', 'CAMR', 'DUPXp11.22', 'ERAB', 'HADH2', 'HCD2', 'HSD10MD', 'MHBD', 'MRPP2', 'MRX17', 'MRX31', 'MRXS10', 'SCHAD', 'SDR5C1'], description='hydroxysteroid 17-beta dehydrogenase 10', other_designations='3-hydroxyacyl-CoA dehydrogenase type-2|3-hydroxy-2-methylbutyryl-CoA dehydrogenase|AB-binding alcohol dehydrogenase|amyloid-beta peptide binding alcohol dehydrogenase|endoplasmic reticulum-associated amyloid beta-peptide-binding protein|mitochondrial RNase P subunit 2|mitochondrial ribonuclease P protein 2|short chain L-3-hydroxyacyl-CoA dehydrogenase type 2|short chain type dehydrogenase/reductase XH98G2', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53431258, end_position_on_the_genomic_accession=53434376, orientation='minus', exon_count=6, OMIM=[300256], no_hdr0=''),
    3029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3029, CurrentID=0, Status='live', Symbol='HAGH', Aliases=['GLO2', 'GLX2', 'GLXII1', 'HAGH'], description='hydroxyacylglutathione hydrolase', other_designations='hydroxyacylglutathione hydrolase, mitochondrial|glyoxalase II|hydroxyacylglutathione hydroxylase', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1807629, end_position_on_the_genomic_accession=1827194, orientation='minus', exon_count=10, OMIM=[138760], no_hdr0=''),
    3030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3030, CurrentID=0, Status='live', Symbol='HADHA', Aliases=['ECHA', 'GBP', 'HADH', 'LCEH', 'LCHAD', 'MTPA', 'TP-ALPHA'], description='hydroxyacyl-CoA dehydrogenase trifunctional multienzyme complex subunit alpha', other_designations='trifunctional enzyme subunit alpha, mitochondrial|3-ketoacyl-Coenzyme A (CoA) thiolase, alpha subunit|3-oxoacyl-CoA thiolase|78 kDa gastrin-binding protein|gastrin-binding protein|hydroxyacyl-CoA dehydrogenase/3-ketoacyl-CoA thiolase/enoyl-CoA hydratase (trifunctional protein), alpha subunit|hydroxyacyl-Coenzyme A dehydrogenase/3-ketoacyl-Coenzyme A thiolase/enoyl-Coenzyme A hydratase (trifunctional protein), alpha subunit|long-chain 2-enoyl-CoA hydratase|long-chain-3-hydroxyacyl-CoA dehydrogenase|mitochondrial long-chain 2-enoyl-Coenzyme A (CoA) hydratase, alpha subunit|mitochondrial long-chain L-3-hydroxyacyl-Coenzyme A (CoA) dehydrogenase, alpha subunit|mitochondrial trifunctional enzyme, alpha subunit|mitochondrial trifunctional protein, alpha subunit|monolysocardiolipin acyltransferase', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26190635, end_position_on_the_genomic_accession=26244632, orientation='minus', exon_count=20, OMIM=[600890], no_hdr0=''),
    3032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3032, CurrentID=0, Status='live', Symbol='HADHB', Aliases=['ECHB', 'MSTP029', 'MTPB', 'TP-BETA'], description='hydroxyacyl-CoA dehydrogenase trifunctional multienzyme complex subunit beta', other_designations='trifunctional enzyme subunit beta, mitochondrial|2-enoyl-Coenzyme A (CoA) hydratase, beta subunit|3-ketoacyl-Coenzyme A (CoA) thiolase of mitochondrial trifunctional protein, beta subunit|acetyl-CoA acyltransferase|beta-ketothiolase|hydroxyacyl-CoA dehydrogenase/3-ketoacyl-CoA thiolase/enoyl-CoA hydratase (trifunctional protein), beta subunit|hydroxyacyl-Coenzyme A dehydrogenase/3-ketoacyl-Coenzyme A thiolase/enoyl-Coenzyme A hydratase (trifunctional protein), beta subunit', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26244917, end_position_on_the_genomic_accession=26290465, orientation='plus', exon_count=17, OMIM=[143450], no_hdr0=''),
    3033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3033, CurrentID=0, Status='live', Symbol='HADH', Aliases=['HAD1', 'HADHSC', 'HCDH', 'HHF4', 'MSCHAD', 'SCHAD', 'HADH'], description='hydroxyacyl-CoA dehydrogenase', other_designations='hydroxyacyl-coenzyme A dehydrogenase, mitochondrial|L-3-hydroxyacyl-Coenzyme A dehydrogenase, short chain|medium and short-chain L-3-hydroxyacyl-coenzyme A dehydrogenase|short-chain 3-hydroxyacyl-CoA dehydrogenase|testis secretory sperm-binding protein Li 203a', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=107989839, end_position_on_the_genomic_accession=108035171, orientation='plus', exon_count=10, OMIM=[601609], no_hdr0=''),
    3034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3034, CurrentID=0, Status='live', Symbol='HAL', Aliases=['HIS', 'HSTD'], description='histidine ammonia-lyase', other_designations='histidine ammonia-lyase|histidase', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95972662, end_position_on_the_genomic_accession=95996344, orientation='minus', exon_count=22, OMIM=[609457], no_hdr0=''),
    3035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3035, CurrentID=0, Status='live', Symbol='HARS1', Aliases=['CMT2W', 'HARS', 'HRS', 'USH3B'], description='histidyl-tRNA synthetase 1', other_designations='histidine--tRNA ligase, cytoplasmic|HisRS|Jo-1 antigen|histidine translase', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140673905, end_position_on_the_genomic_accession=140691370, orientation='minus', exon_count=13, OMIM=[142810], no_hdr0=''),
    3036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3036, CurrentID=0, Status='live', Symbol='HAS1', Aliases=['HAS'], description='hyaluronan synthase 1', other_designations='hyaluronan synthase 1|HA synthase 1|hyaluronate synthase 1|hyaluronic acid synthase 1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51713112, end_position_on_the_genomic_accession=51723991, orientation='minus', exon_count=5, OMIM=[601463], no_hdr0=''),
    3037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3037, CurrentID=0, Status='live', Symbol='HAS2', Aliases=[], description='hyaluronan synthase 2', other_designations='hyaluronan synthase 2|HA synthase 2|hyaluronate synthase 2|hyaluronic acid synthase 2', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=121612116, end_position_on_the_genomic_accession=121641440, orientation='minus', exon_count=4, OMIM=[601636], no_hdr0=''),
    3038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3038, CurrentID=0, Status='live', Symbol='HAS3', Aliases=[], description='hyaluronan synthase 3', other_designations='hyaluronan synthase 3|HA synthase 3|hyaluronate synthase 3|hyaluronic acid synthase 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69105653, end_position_on_the_genomic_accession=69118719, orientation='plus', exon_count=8, OMIM=[602428], no_hdr0=''),
    3039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3039, CurrentID=0, Status='live', Symbol='HBA1', Aliases=['ECYT7', 'HBA-T3', 'HBH', 'METHBA'], description='hemoglobin subunit alpha 1', other_designations='hemoglobin subunit alpha|alpha globin chain|alpha one globin|alpha-2 globin chain|delta globin|hemoglobin alpha 1 globin chain|hemoglobin, alpha 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=176680, end_position_on_the_genomic_accession=177522, orientation='plus', exon_count=3, OMIM=[141800], no_hdr0=''),
    3040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3040, CurrentID=0, Status='live', Symbol='HBA2', Aliases=['ECYT7', 'HBA-T2', 'HBH'], description='hemoglobin subunit alpha 2', other_designations='hemoglobin subunit alpha|alpha globin|alpha-2 globin|hemoglobin alpha chain|hemoglobin, alpha 2|mutant hemoglobin alpha 2 globin chain|truncated HbA2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=172876, end_position_on_the_genomic_accession=173710, orientation='plus', exon_count=3, OMIM=[141850], no_hdr0=''),
    3042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3042, CurrentID=0, Status='live', Symbol='HBM', Aliases=['HBAP2', 'HBK'], description='hemoglobin subunit mu', other_designations='hemoglobin subunit mu|alpha globin pseudogene 2|hemoglobin mu chain|hemoglobin, alpha pseudogene 2|hemoglobin, mu|mu-globin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=165978, end_position_on_the_genomic_accession=166764, orientation='plus', exon_count=3, OMIM=[609639], no_hdr0=''),
    3043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3043, CurrentID=0, Status='live', Symbol='HBB', Aliases=['CD113t-C', 'ECYT6', 'beta-globin'], description='hemoglobin subunit beta', other_designations='hemoglobin subunit beta|beta globin chain|hemoglobin beta subunit|hemoglobin, beta', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5225464, end_position_on_the_genomic_accession=5227071, orientation='minus', exon_count=3, OMIM=[141900], no_hdr0=''),
    3045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3045, CurrentID=0, Status='live', Symbol='HBD', Aliases=[], description='hemoglobin subunit delta', other_designations='hemoglobin subunit delta|delta globin|delta-globin chain|hemoglobin delta chain|hemoglobin, delta', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5232838, end_position_on_the_genomic_accession=5234483, orientation='minus', exon_count=3, OMIM=[142000], no_hdr0=''),
    3046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3046, CurrentID=0, Status='live', Symbol='HBE1', Aliases=['HBE'], description='hemoglobin subunit epsilon 1', other_designations='hemoglobin subunit epsilon|epsilon globin|hemoglobin epsilon chain|hemoglobin, epsilon 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5268345, end_position_on_the_genomic_accession=5269945, orientation='minus', exon_count=3, OMIM=[142100], no_hdr0=''),
    3047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3047, CurrentID=0, Status='live', Symbol='HBG1', Aliases=['HBG-T2', 'HBGA', 'HBGR', 'HSGGL1', 'PRO2979'], description='hemoglobin subunit gamma 1', other_designations='hemoglobin subunit gamma-1|A-gamma globin|gamma A hemoglobin|gamma globin|gamma-1-globin|hb F Agamma|hemoglobin gamma-1 chain|hemoglobin gamma-a chain|hemoglobin, gamma A|hemoglobin, gamma, regulator of', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5248269, end_position_on_the_genomic_accession=5249857, orientation='minus', exon_count=3, OMIM=[142200], no_hdr0=''),
    3048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3048, CurrentID=0, Status='live', Symbol='HBG2', Aliases=['HBG-T1', 'TNCY'], description='hemoglobin subunit gamma 2', other_designations='hemoglobin subunit gamma-2|G-gamma globin Paulinia|abnormal hemoglobin|gamma globin|gamma-2-globin|gamma-globin chain|hb F Ggamma|hemoglobin gamma-2 chain|hemoglobin gamma-G chain|hemoglobin, gamma G|methemoglobin', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5253188, end_position_on_the_genomic_accession=5254781, orientation='minus', exon_count=3, OMIM=[142250], no_hdr0=''),
    3049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3049, CurrentID=0, Status='live', Symbol='HBQ1', Aliases=['HBQ'], description='hemoglobin subunit theta 1', other_designations='hemoglobin subunit theta-1|hemoglobin theta-1 chain|hemoglobin, theta 1|theta-1-globin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=180459, end_position_on_the_genomic_accession=181179, orientation='plus', exon_count=3, OMIM=[142240], no_hdr0=''),
    3050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3050, CurrentID=0, Status='live', Symbol='HBZ', Aliases=['HBAZ-T1', 'HBZ1', 'HBZ'], description='hemoglobin subunit zeta', other_designations='hemoglobin subunit zeta|hemoglobin zeta chain|hemoglobin, zeta|zeta-globin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=152644, end_position_on_the_genomic_accession=154503, orientation='plus', exon_count=3, OMIM=[142310], no_hdr0=''),
    3052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3052, CurrentID=0, Status='live', Symbol='HCCS', Aliases=['CCHL', 'LSDMCA1', 'MCOPS7', 'MLS'], description='holocytochrome c synthase', other_designations='holocytochrome c-type synthase|cytochrome c heme-lyase|cytochrome c-type heme lyase|holocytochrome-c synthetase|microphthalamia with linear skin defects|microphthalmia with linear skin defects', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=11111332, end_position_on_the_genomic_accession=11123086, orientation='plus', exon_count=7, OMIM=[300056], no_hdr0=''),
    3053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3053, CurrentID=0, Status='live', Symbol='SERPIND1', Aliases=['D22S673', 'HC2', 'HCF2', 'HCII', 'HLS2', 'LS2', 'THPH10'], description='serpin family D member 1', other_designations='heparin cofactor 2|heparin cofactor II splice isoform|leuserpin 2|protease inhibitor leuserpin-2|serine (or cysteine) proteinase inhibitor, clade D (heparin cofactor), member 1|serpin D1|serpin peptidase inhibitor, clade D (heparin cofactor), member 1', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20774113, end_position_on_the_genomic_accession=20787720, orientation='plus', exon_count=5, OMIM=[142360], no_hdr0=''),
    3054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3054, CurrentID=0, Status='live', Symbol='HCFC1', Aliases=['CFF', 'HCF', 'HCF-1', 'HCF1', 'HFC1', 'MRX3', 'PPP1R89', 'VCAF'], description='host cell factor C1', other_designations='host cell factor 1|VP16-accessory protein|protein phosphatase 1, regulatory subunit 89', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153947556, end_position_on_the_genomic_accession=153972360, orientation='minus', exon_count=26, OMIM=[300019], no_hdr0=''),
    3055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3055, CurrentID=0, Status='live', Symbol='HCK', Aliases=['JTK9', 'p59Hck', 'p61Hck'], description='HCK proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase HCK|hematopoietic cell kinase|hemopoietic cell kinase|p59-HCK/p60-HCK', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32052242, end_position_on_the_genomic_accession=32101856, orientation='plus', exon_count=15, OMIM=[142370], no_hdr0=''),
    3059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3059, CurrentID=0, Status='live', Symbol='HCLS1', Aliases=['CTTNL', 'HS1', 'lckBP1', 'p75'], description='hematopoietic cell-specific Lyn substrate 1', other_designations='hematopoietic lineage cell-specific protein', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121631399, end_position_on_the_genomic_accession=121660903, orientation='minus', exon_count=14, OMIM=[601306], no_hdr0=''),
    3060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3060, CurrentID=0, Status='live', Symbol='HCRT', Aliases=['NRCLP1', 'OX', 'PPOX'], description='hypocretin neuropeptide precursor', other_designations='orexin|hypocretin (orexin) neuropeptide|prepro-orexin', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42184060, end_position_on_the_genomic_accession=42185452, orientation='minus', exon_count=2, OMIM=[602358], no_hdr0=''),
    3061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3061, CurrentID=0, Status='live', Symbol='HCRTR1', Aliases=['ORXR1', 'OX1R', 'OXR1'], description='hypocretin receptor 1', other_designations='orexin receptor type 1|hypocretin (orexin) receptor 1|hypocretin receptor type 1|orexin receptor 1', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31617689, end_position_on_the_genomic_accession=31632518, orientation='plus', exon_count=9, OMIM=[602392], no_hdr0=''),
    3062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3062, CurrentID=0, Status='live', Symbol='HCRTR2', Aliases=['ORXR2', 'OX2R', 'OXR2'], description='hypocretin receptor 2', other_designations='orexin receptor type 2|hypocretin (orexin) receptor 2|hypocretin receptor type 2|orexin type-2 receptor', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=55106469, end_position_on_the_genomic_accession=55284698, orientation='plus', exon_count=9, OMIM=[602393], no_hdr0=''),
    3064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3064, CurrentID=0, Status='live', Symbol='HTT', Aliases=['HD', 'IT15', 'LOMARS'], description='huntingtin', other_designations='huntingtin|huntington disease protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3074681, end_position_on_the_genomic_accession=3243960, orientation='plus', exon_count=67, OMIM=[613004], no_hdr0=''),
    3065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3065, CurrentID=0, Status='live', Symbol='HDAC1', Aliases=['GON-10', 'HD1', 'KDAC1', 'RPD3', 'RPD3L1'], description='histone deacetylase 1', other_designations='histone deacetylase 1|reduced potassium dependency, yeast homolog-like 1', map_location='1p35.2-p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32292083, end_position_on_the_genomic_accession=32333628, orientation='plus', exon_count=14, OMIM=[601241], no_hdr0=''),
    3066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3066, CurrentID=0, Status='live', Symbol='HDAC2', Aliases=['HD2', 'KDAC2', 'RPD3', 'YAF1'], description='histone deacetylase 2', other_designations='histone deacetylase 2|YY1-associated factor 1|transcriptional regulator homolog RPD3', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=113933028, end_position_on_the_genomic_accession=113971148, orientation='minus', exon_count=17, OMIM=[605164], no_hdr0=''),
    3067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3067, CurrentID=0, Status='live', Symbol='HDC', Aliases=[], description='histidine decarboxylase', other_designations='histidine decarboxylase', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50241945, end_position_on_the_genomic_accession=50266049, orientation='minus', exon_count=15, OMIM=[142704], no_hdr0=''),
    3068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3068, CurrentID=0, Status='live', Symbol='HDGF', Aliases=['HMG1L2'], description='heparin binding growth factor', other_designations='hepatoma-derived growth factor|epididymis secretory sperm binding protein|hepatoma derived growth factor|high mobility group protein 1-like 2', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156742107, end_position_on_the_genomic_accession=156752448, orientation='minus', exon_count=13, OMIM=[600339], no_hdr0=''),
    3069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3069, CurrentID=0, Status='live', Symbol='HDLBP', Aliases=['HBP', 'PRO2900', 'VGL'], description='high density lipoprotein binding protein', other_designations='vigilin|HDL-binding protein', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241227291, end_position_on_the_genomic_accession=241315815, orientation='minus', exon_count=35, OMIM=[142695], no_hdr0=''),
    3070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3070, CurrentID=0, Status='live', Symbol='HELLS', Aliases=['ICF4', 'LSH', 'Nbla10143', 'PASG', 'SMARCA6'], description='helicase, lymphoid specific', other_designations='lymphoid-specific helicase|SWI/SNF2-related, matrix-associated, actin-dependent regulator of chromatin, subfamily A, member 6|proliferation-associated SNF2-like protein', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94545778, end_position_on_the_genomic_accession=94613905, orientation='plus', exon_count=26, OMIM=[603946], no_hdr0=''),
    3071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3071, CurrentID=0, Status='live', Symbol='NCKAP1L', Aliases=['HEM1', 'IMD72'], description='NCK associated protein 1 like', other_designations='nck-associated protein 1-like|hematopoietic protein 1|membrane-associated protein hem-1', map_location='12q13.13-q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54497752, end_position_on_the_genomic_accession=54548243, orientation='plus', exon_count=32, OMIM=[141180], no_hdr0=''),
    3073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3073, CurrentID=0, Status='live', Symbol='HEXA', Aliases=['TSD'], description='hexosaminidase subunit alpha', other_designations='beta-hexosaminidase subunit alpha|N-acetyl-beta-glucosaminidase subunit alpha|beta-N-acetylhexosaminidase subunit alpha|hexosaminidase A (alpha polypeptide)|hexosaminidase subunit A', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72340924, end_position_on_the_genomic_accession=72376014, orientation='minus', exon_count=14, OMIM=[606869], no_hdr0=''),
    3074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3074, CurrentID=0, Status='live', Symbol='HEXB', Aliases=['ENC-1AS', 'HEL-248', 'HEL-S-111'], description='hexosaminidase subunit beta', other_designations='beta-hexosaminidase subunit beta|HCC-7|N-acetyl-beta-glucosaminidase subunit beta|beta-N-acetylhexosaminidase subunit beta|beta-hexosaminidase beta-subunit|cervical cancer proto-oncogene 7 protein|epididymis luminal protein 248|epididymis secretory protein Li 111|epididymis secretory sperm binding protein|hexosaminidase B (beta polypeptide)|hexosaminidase subunit B', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=74640023, end_position_on_the_genomic_accession=74721288, orientation='plus', exon_count=15, OMIM=[606873], no_hdr0=''),
    3075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3075, CurrentID=0, Status='live', Symbol='CFH', Aliases=['AHUS1', 'AMBP1', 'ARMD4', 'ARMS1L3', 'FH', 'FHL1', 'HF', 'HF1', 'HF2', 'HUS', 'CFH'], description='complement factor H', other_designations='complement factor H|H factor 1 (complement)|H factor 2 (complement)|adrenomedullin binding protein|age-related maculopathy susceptibility 1|beta-1-H-globulin|beta-1H|factor H|factor H-like 1', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196652033, end_position_on_the_genomic_accession=196747504, orientation='plus', exon_count=25, OMIM=[134370], no_hdr0=''),
    3077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3077, CurrentID=0, Status='live', Symbol='HFE', Aliases=['HFE1', 'HH', 'HLA-H', 'MVCD7', 'TFQTL2'], description='homeostatic iron regulator', other_designations='hereditary hemochromatosis protein|MHC class I-like protein HFE|hereditary hemochromatosis protein HLA-H|high Fe', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26087347, end_position_on_the_genomic_accession=26098343, orientation='plus', exon_count=7, OMIM=[613609], no_hdr0=''),
    3078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3078, CurrentID=0, Status='live', Symbol='CFHR1', Aliases=['CFHL', 'CFHL1', 'CFHL1PP', 'FHR-1', 'FHR1', 'H36', 'H36-1', 'H36-2', 'HFL1', 'HFL2', 'CFHR1'], description='complement factor H related 1', other_designations='complement factor H-related protein 1|H factor (complement)-like 1|H factor (complement)-like 2|H-factor-like 1|complement factor H-related 1 pseudogene|h factor-like protein 1', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196819731, end_position_on_the_genomic_accession=196832189, orientation='plus', exon_count=6, OMIM=[134371], no_hdr0=''),
    3080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3080, CurrentID=0, Status='live', Symbol='CFHR2', Aliases=['CFHL2', 'FHR2', 'HFL3'], description='complement factor H related 2', other_designations='complement factor H-related protein 2|DDESK59|FHR-2|H factor (complement)-like 3|factor H-related gene 2|h factor-like 3|h factor-like protein 2', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196943738, end_position_on_the_genomic_accession=196959622, orientation='plus', exon_count=5, OMIM=[600889], no_hdr0=''),
    3081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3081, CurrentID=0, Status='live', Symbol='HGD', Aliases=['AKU', 'HGO'], description='homogentisate 1,2-dioxygenase', other_designations='homogentisate 1,2-dioxygenase|homogentisate oxidase|homogentisate oxygenase|homogentisic acid oxidase|homogentisicase', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120628168, end_position_on_the_genomic_accession=120682555, orientation='minus', exon_count=16, OMIM=[607474], no_hdr0=''),
    3082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3082, CurrentID=0, Status='live', Symbol='HGF', Aliases=['DFNB39', 'F-TCFB', 'HPTA', 'SF', 'HGF'], description='hepatocyte growth factor', other_designations='hepatocyte growth factor|fibroblast-derived tumor cytotoxic factor|hepatocyte growth factor (hepapoietin A; scatter factor)|hepatopoietin-A|lung fibroblast-derived mitogen', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=81699006, end_position_on_the_genomic_accession=81770438, orientation='minus', exon_count=20, OMIM=[142409], no_hdr0=''),
    3083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3083, CurrentID=0, Status='live', Symbol='HGFAC', Aliases=['HGFA'], description='HGF activator', other_designations='hepatocyte growth factor activator', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3441968, end_position_on_the_genomic_accession=3449486, orientation='plus', exon_count=15, OMIM=[604552], no_hdr0=''),
    3084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3084, CurrentID=0, Status='live', Symbol='NRG1', Aliases=['ARIA', 'GGF', 'GGF2', 'HGL', 'HRG', 'HRG1', 'HRGA', 'MST131', 'MSTP131', 'NDF-IT2', 'SMDF', 'NRG1'], description='neuregulin 1', other_designations='pro-neuregulin-1, membrane-bound isoform|acetylcholine receptor-inducing activity|glial growth factor 2|heregulin, alpha (45kD, ERBB2 p185-activator)|neu differentiation factor|pro-NRG1|sensory and motor neuron derived factor', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=31639245, end_position_on_the_genomic_accession=32774046, orientation='plus', exon_count=19, OMIM=[142445], no_hdr0=''),
    3087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3087, CurrentID=0, Status='live', Symbol='HHEX', Aliases=['HEX', 'HMPH', 'HOX11L-PEN', 'PRH', 'PRHX'], description='hematopoietically expressed homeobox', other_designations='hematopoietically-expressed homeobox protein HHEX|homeobox protein HEX|homeobox protein PRH|homeobox, hematopoietically expressed|proline-rich homeodomain-containing transcription factor', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92689955, end_position_on_the_genomic_accession=92695647, orientation='plus', exon_count=4, OMIM=[604420], no_hdr0=''),
    3090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3090, CurrentID=0, Status='live', Symbol='HIC1', Aliases=['ZBTB29', 'ZNF901', 'hic-1'], description='HIC ZBTB transcriptional repressor 1', other_designations='hypermethylated in cancer 1 protein|hypermethylated in cancer 1|zinc finger and BTB domain-containing protein 29', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2055103, end_position_on_the_genomic_accession=2063241, orientation='plus', exon_count=3, OMIM=[603825], no_hdr0=''),
    3091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3091, CurrentID=0, Status='live', Symbol='HIF1A', Aliases=['HIF-1-alpha', 'HIF-1A', 'HIF-1alpha', 'HIF1', 'HIF1-ALPHA', 'MOP1', 'PASD8', 'bHLHe78'], description='hypoxia inducible factor 1 subunit alpha', other_designations='hypoxia-inducible factor 1-alpha|ARNT interacting protein|PAS domain-containing protein 8|basic-helix-loop-helix-PAS protein MOP1|class E basic helix-loop-helix protein 78|hypoxia inducible factor 1 alpha subunit|hypoxia inducible factor 1, alpha subunit (basic helix-loop-helix transcription factor)|hypoxia-inducible factor1alpha|member of PAS protein 1|member of PAS superfamily 1', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=61695513, end_position_on_the_genomic_accession=61748258, orientation='plus', exon_count=16, OMIM=[603348], no_hdr0=''),
    3092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3092, CurrentID=0, Status='live', Symbol='HIP1', Aliases=['HIP-I', 'ILWEQ', 'SHON', 'SHONbeta', 'SHONgamma'], description='huntingtin interacting protein 1', other_designations='huntingtin-interacting protein 1|huntingtin-interacting protein I', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75533298, end_position_on_the_genomic_accession=75738976, orientation='minus', exon_count=35, OMIM=[601767], no_hdr0=''),
    3093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3093, CurrentID=0, Status='live', Symbol='UBE2K', Aliases=['E2-25K', 'HIP2', 'HYPG', 'LIG', 'UBC1'], description='ubiquitin conjugating enzyme E2 K', other_designations='ubiquitin-conjugating enzyme E2 K|E2 ubiquitin-conjugating enzyme K|E2(25K)|HIP-2|huntingtin-interacting protein 2|ubiquitin carrier protein|ubiquitin conjugating enzyme E2K|ubiquitin-conjugating enzyme E2(25K)|ubiquitin-conjugating enzyme E2-25 KDA|ubiquitin-conjugating enzyme E2K (UBC1 homolog, yeast)|ubiquitin-protein ligase', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39698136, end_position_on_the_genomic_accession=39782792, orientation='plus', exon_count=7, OMIM=[602846], no_hdr0=''),
    3094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3094, CurrentID=0, Status='live', Symbol='HINT1', Aliases=['HINT', 'NMAN', 'PKCI-1', 'PRKCNH1'], description='histidine triad nucleotide binding protein 1', other_designations="histidine triad nucleotide-binding protein 1|adenosine 5'-monophosphoramidase|epididymis secretory sperm binding protein|protein kinase C inhibitor 1|protein kinase C-interacting protein 1", map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131159027, end_position_on_the_genomic_accession=131165256, orientation='minus', exon_count=5, OMIM=[601314], no_hdr0=''),
    3096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3096, CurrentID=0, Status='live', Symbol='HIVEP1', Aliases=['CIRIP', 'CRYBP1', 'GAAP', 'MBP-1', 'PRDII-BF1', 'Schnurri-1', 'ZAS1', 'ZNF40', 'ZNF40A'], description='HIVEP zinc finger 1', other_designations='zinc finger protein 40|cirhin interaction protein|gate keeper of apoptosis-activating protein|human immunodeficiency virus type I enhancer binding protein 1|major histocompatibility complex binding protein 1|positive regulatory domain II binding factor 1', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=12002096, end_position_on_the_genomic_accession=12212034, orientation='plus', exon_count=19, OMIM=[194540], no_hdr0=''),
    3097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3097, CurrentID=0, Status='live', Symbol='HIVEP2', Aliases=['HIV-EP2', 'MBP-2', 'MIBP1', 'MRD43', 'SHN2', 'ZAS2', 'ZNF40B'], description='HIVEP zinc finger 2', other_designations='transcription factor HIVEP2|MHC binding protein-2|Schnurri-2|c-myc intron binding protein 1|human immunodeficiency virus type I enhancer binding protein 2', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=142751469, end_position_on_the_genomic_accession=142945756, orientation='minus', exon_count=15, OMIM=[143054], no_hdr0=''),
    3098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3098, CurrentID=0, Status='live', Symbol='HK1', Aliases=['HK-ta', 'HK1-tb', 'HK1-tc', 'HKD', 'HKI', 'HMSNR', 'HXK1', 'NEDVIBA', 'RP79', 'hexokinase', 'HK1'], description='hexokinase 1', other_designations='hexokinase-1|brain form hexokinase|glycolytic enzyme|hexokinase IR|hexokinase type I|hexokinase-A', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69269991, end_position_on_the_genomic_accession=69401882, orientation='plus', exon_count=29, OMIM=[142600], no_hdr0=''),
    3099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3099, CurrentID=0, Status='live', Symbol='HK2', Aliases=['HKII', 'HXK2'], description='hexokinase 2', other_designations='hexokinase-2|hexokinase type II|hexokinase-2, muscle|hexokinase-B|muscle form hexokinase', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74834126, end_position_on_the_genomic_accession=74893359, orientation='plus', exon_count=19, OMIM=[601125], no_hdr0=''),
    3101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3101, CurrentID=0, Status='live', Symbol='HK3', Aliases=['HKIII', 'HXK3'], description='hexokinase 3', other_designations='hexokinase-3|ATP:D-hexose 6-phosphotransferase|HK III|hexokinase 3 (white cell)|hexokinase type III|hexokinase-C', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176880869, end_position_on_the_genomic_accession=176899373, orientation='minus', exon_count=22, OMIM=[142570], no_hdr0=''),
    3104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3104, CurrentID=0, Status='live', Symbol='ZBTB48', Aliases=['HKR3', 'TZAP', 'ZNF855', 'pp9964'], description='zinc finger and BTB domain containing 48', other_designations='telomere zinc finger-associated protein|GLI-Kruppel family member HKR3|krueppel-related zinc finger protein 3|telomeric zinc finger-associated protein|zinc finger and BTB domain-containing protein 48|zinc finger protein 855', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6579994, end_position_on_the_genomic_accession=6589280, orientation='plus', exon_count=12, OMIM=[165270], no_hdr0=''),
    3105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3105, CurrentID=0, Status='live', Symbol='HLA-A', Aliases=['HLAA'], description='major histocompatibility complex, class I, A', other_designations='HLA class I histocompatibility antigen, A alpha chain|HLA class I histocompatibility antigen, A-1 alpha chain|MHC class I antigen HLA-A heavy chain|leukocyte antigen class I-A', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29942532, end_position_on_the_genomic_accession=29945870, orientation='plus', exon_count=8, OMIM=[142800], no_hdr0=''),
    3106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3106, CurrentID=0, Status='live', Symbol='HLA-B', Aliases=['AS', 'B-4901', 'HLAB'], description='major histocompatibility complex, class I, B', other_designations='major histocompatibility complex, class I, B|HLA class I antigen HLA-B|HLA class I histocompatibility antigen, B alpha chain|MHC HLA-B cell surface glycoprotein|MHC HLA-B transmembrane glycoprotein|MHC class 1 antigen|MHC class I antigen HLA-B alpha chain|MHC class I antigen HLA-B heavy chain|MHC class I antigen SHCHA|MHC class I molecule|leukocyte antigen class I-B', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31353875, end_position_on_the_genomic_accession=31357179, orientation='minus', exon_count=8, OMIM=[142830], no_hdr0=''),
    3107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3107, CurrentID=0, Status='live', Symbol='HLA-C', Aliases=['D6S204', 'HLA-JY3', 'HLAC', 'HLC-C', 'MHC', 'PSORS1'], description='major histocompatibility complex, class I, C', other_designations='HLA class I histocompatibility antigen, C alpha chain|HLA-C antigen|MHC class I antigen heavy chain HLA-C|human leukocyte antigen-C alpha chain|major histocompatibility antigen HLA-C', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31268749, end_position_on_the_genomic_accession=31272092, orientation='minus', exon_count=8, OMIM=[142840], no_hdr0=''),
    3108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3108, CurrentID=0, Status='live', Symbol='HLA-DMA', Aliases=['D6S222E', 'DMA', 'HLADM', 'RING6'], description='major histocompatibility complex, class II, DM alpha', other_designations='HLA class II histocompatibility antigen, DM alpha chain|MHC class II antigen DMA|class II histocompatibility antigen, M alpha chain|really interesting new gene 6 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32948618, end_position_on_the_genomic_accession=32953097, orientation='minus', exon_count=5, OMIM=[142855], no_hdr0=''),
    3109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3109, CurrentID=0, Status='live', Symbol='HLA-DMB', Aliases=['D6S221E', 'RING7'], description='major histocompatibility complex, class II, DM beta', other_designations='HLA class II histocompatibility antigen, DM beta chain|MHC class II HLA-DMB|MHC class II antigen DMB|MHC class II antigen HLA-DM beta chain|class II histocompatibility antigen, M beta chain|really interesting new gene 7 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32934636, end_position_on_the_genomic_accession=32941028, orientation='minus', exon_count=6, OMIM=[142856], no_hdr0=''),
    3110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3110, CurrentID=0, Status='live', Symbol='MNX1', Aliases=['HB9', 'HLXB9', 'HOXHB9', 'SCRA1'], description='motor neuron and pancreas homeobox 1', other_designations='motor neuron and pancreas homeobox protein 1|homeobox HB9|homeobox protein HB9', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=157004854, end_position_on_the_genomic_accession=157010663, orientation='minus', exon_count=4, OMIM=[142994], no_hdr0=''),
    3111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3111, CurrentID=0, Status='live', Symbol='HLA-DOA', Aliases=['HLA-DNA', 'HLA-DZA', 'HLADZ'], description='major histocompatibility complex, class II, DO alpha', other_designations='HLA class II histocompatibility antigen, DO alpha chain|HLA-D0-alpha|MHC DN-alpha|MHC DZ alpha|MHC class II antigen DOA|lymphocyte antigen|major histocompatibility complex, class II, DN alpha', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33004182, end_position_on_the_genomic_accession=33009591, orientation='minus', exon_count=5, OMIM=[142930], no_hdr0=''),
    3112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3112, CurrentID=0, Status='live', Symbol='HLA-DOB', Aliases=['DOB', 'HLA_DOB'], description='major histocompatibility complex, class II, DO beta', other_designations='HLA class II histocompatibility antigen, DO beta chain|MHC class II antigen DOB', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32812763, end_position_on_the_genomic_accession=32817002, orientation='minus', exon_count=6, OMIM=[600629], no_hdr0=''),
    3113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3113, CurrentID=0, Status='live', Symbol='HLA-DPA1', Aliases=['DP(W3)', 'DP(W4)', 'DPA1', 'HLA-DP1A', 'HLA-DPA', 'HLA-DPB1', 'HLADP', 'HLASB', 'PLT1'], description='major histocompatibility complex, class II, DP alpha 1', other_designations='HLA class II histocompatibility antigen, DP alpha 1 chain|HLA DPA1|HLA-DPA1*01:03:01:New|HLA-DPA1*02:01:01:NEW|HLA-SB alpha chain|MHC class II DP alpha chain|MHC class II DP3-alpha|MHC class II HLA-DPA1 antigen|MHC class II antigen DP alpha chain|MHC class II protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33064569, end_position_on_the_genomic_accession=33080748, orientation='minus', exon_count=6, OMIM=[142880], no_hdr0=''),
    3115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3115, CurrentID=0, Status='live', Symbol='HLA-DPB1', Aliases=['DPB1', 'HLA-DP', 'HLA-DP1B', 'HLA-DPB'], description='major histocompatibility complex, class II, DP beta 1', other_designations='HLA class II histocompatibility antigen, DP beta 1 chain|HLA class II histocompatibility antigen, DP(W4) beta chain|HLA-DP histocompatibility type, beta-1 subunit|MHC HLA DPB1|MHC class II HLA-DP-beta-1|MHC class II antigen DPB1', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33075990, end_position_on_the_genomic_accession=33089696, orientation='plus', exon_count=6, OMIM=[142858], no_hdr0=''),
    3117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3117, CurrentID=0, Status='live', Symbol='HLA-DQA1', Aliases=['CELIAC1', 'DQ-A1', 'DQA1', 'HLA-DQA'], description='major histocompatibility complex, class II, DQ alpha 1', other_designations='HLA class II histocompatibility antigen, DQ alpha 1 chain|DC-1 alpha chain|DC-alpha|HLA class II histocompatibility antigen DQ alpha chain|HLA-DCA|MHC HLA-DQ alpha|MHC class II DQ alpha chain|MHC class II DQA1|MHC class II HLA-DQ-alpha-1|MHC class II antigen DQA1|MHC class II protein|truncated MHC class II antigen', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32637406, end_position_on_the_genomic_accession=32654846, orientation='plus', exon_count=6, OMIM=[146880], no_hdr0=''),
    3118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3118, CurrentID=0, Status='live', Symbol='HLA-DQA2', Aliases=['DC-alpha', 'DX-ALPHA', 'HLA-DCA', 'HLA-DXA', 'HLADQA2'], description='major histocompatibility complex, class II, DQ alpha 2', other_designations='HLA class II histocompatibility antigen, DQ alpha 2 chain|DC-1 alpha chain|DX alpha chain|HLA class II histocompatibility antigen, DQ alpha 1 chain|HLA class II histocompatibility antigen, DQ(6) alpha chain|MHC class II DQA1|MHC class II DQA2|MHC class II antigen', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32741391, end_position_on_the_genomic_accession=32747198, orientation='plus', exon_count=5, OMIM=[613503], no_hdr0=''),
    3119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3119, CurrentID=0, Status='live', Symbol='HLA-DQB1', Aliases=['CELIAC1', 'HLA-DQB', 'IDDM1'], description='major histocompatibility complex, class II, DQ beta 1', other_designations='HLA class II histocompatibility antigen, DQ beta 1 chain|MHC class II DQ beta chain|MHC class II HLA-DQ beta glycoprotein|MHC class II antigen DQB1|MHC class II antigen HLA-DQ-beta-1', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32659467, end_position_on_the_genomic_accession=32666657, orientation='minus', exon_count=6, OMIM=[604305], no_hdr0=''),
    3120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3120, CurrentID=0, Status='live', Symbol='HLA-DQB2', Aliases=['DQB2', 'HLA-DQB1', 'HLA-DXB'], description='major histocompatibility complex, class II, DQ beta 2', other_designations='HLA class II histocompatibility antigen, DQ beta 2 chain|DV19.1 (major histocompatibility complex, class II, DQ beta 2 (HLA-DXB))|HLA class II histocompatibility antigen, DX beta chain|MHC class II antigen DQB2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32756094, end_position_on_the_genomic_accession=32763553, orientation='minus', exon_count=6, OMIM=[615161], no_hdr0=''),
    3121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3121, CurrentID=0, Status='live', Symbol='HLA-DQB3', Aliases=['D6S205', 'D6S205E', 'DQB3', 'DVB', 'DVbeta', 'HLA-DVB'], description='major histocompatibility complex, class II, DQ beta 3', other_designations='major histocompatibility complex, class II, DQ beta 3', map_location='6p21.3', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    3122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3122, CurrentID=0, Status='live', Symbol='HLA-DRA', Aliases=['HLA-DRA1'], description='major histocompatibility complex, class II, DR alpha', other_designations='HLA class II histocompatibility antigen, DR alpha chain|MHC class II antigen DRA|histocompatibility antigen HLA-DR alpha', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32439887, end_position_on_the_genomic_accession=32445046, orientation='plus', exon_count=5, OMIM=[142860], no_hdr0=''),
    3123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3123, CurrentID=0, Status='live', Symbol='HLA-DRB1', Aliases=['DRB1', 'HLA-DR1B', 'HLA-DRB', 'SS1'], description='major histocompatibility complex, class II, DR beta 1', other_designations='major histocompatibility complex, class II, DR beta 1 precursor|HLA class II histocompatibility antigen, DR-1 beta chain|MHC class II HLA-DR beta 1 chain|human leucocyte antigen DRB1|lymphocyte antigen DRB1', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32578775, end_position_on_the_genomic_accession=32589848, orientation='minus', exon_count=6, OMIM=[142857], no_hdr0=''),
    3125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3125, CurrentID=0, Status='live', Symbol='HLA-DRB3', Aliases=['DRB3', 'HLA-DPB1', 'HLA-DR1B', 'HLA-DR3B*', 'HLA-DRB3'], description='major histocompatibility complex, class II, DR beta 3', other_designations='major histocompatibility complex, class II, DR beta 3|HLA DRB3|HLA class II histocompatibility antigen, DR beta 3 chain|MHC class II DR beta chain|MHC class II HLA-DR beta 3 chain|MHC class II antigen DR beta 3 chain|MHC class II antigen DRB3|MHC class II protein|human leucocyte antigen DRB3', map_location='6p21.3', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[612735], no_hdr0=''),
    3126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3126, CurrentID=0, Status='live', Symbol='HLA-DRB4', Aliases=['DR4', 'DRB4', 'HLA-DR4B*', 'HLA-DRB4'], description='major histocompatibility complex, class II, DR beta 4', other_designations='major histocompatibility complex, class II, DR beta 4|HLA class II histocompatibility antigen, DR beta 4 chain|MHC class II antigen DRB4', map_location='6p21.3', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    3127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3127, CurrentID=0, Status='live', Symbol='HLA-DRB5', Aliases=['HLA-DRB5*'], description='major histocompatibility complex, class II, DR beta 5', other_designations='major histocompatibility complex, class II, DR beta 5|DR beta-5|HLA class II histocompatibility antigen, DR-5 beta chain|MHC class II antigen DRB5', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32517343, end_position_on_the_genomic_accession=32530316, orientation='minus', exon_count=6, OMIM=[604776], no_hdr0=''),
    3131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3131, CurrentID=0, Status='live', Symbol='HLF', Aliases=[], description='HLF transcription factor, PAR bZIP family member', other_designations='hepatic leukemia factor|E2A-HLF fusion transcript protein|HLF, PAR bZIP transcription factor|PAR bZIP transcription factor', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=55264960, end_position_on_the_genomic_accession=55325187, orientation='plus', exon_count=7, OMIM=[142385], no_hdr0=''),
    3133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3133, CurrentID=0, Status='live', Symbol='HLA-E', Aliases=['HLA-6.2', 'QA1'], description='major histocompatibility complex, class I, E', other_designations='HLA class I histocompatibility antigen, alpha chain E|MHC class I antigen E|MHC class Ib antigen', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30489508, end_position_on_the_genomic_accession=30494194, orientation='plus', exon_count=8, OMIM=[143010], no_hdr0=''),
    3134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3134, CurrentID=0, Status='live', Symbol='HLA-F', Aliases=['CDA12', 'HLA-5.4', 'HLA-CDA12', 'HLAF'], description='major histocompatibility complex, class I, F', other_designations='HLA class I histocompatibility antigen, alpha chain F|HLA F antigen|MHC class I antigen F|leukocyte antigen F', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29723434, end_position_on_the_genomic_accession=29740355, orientation='plus', exon_count=13, OMIM=[143110], no_hdr0=''),
    3135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3135, CurrentID=0, Status='live', Symbol='HLA-G', Aliases=['MHC-G'], description='major histocompatibility complex, class I, G', other_designations='HLA class I histocompatibility antigen, alpha chain G|HLA G antigen|HLA-G histocompatibility antigen, class I, G|MHC class I antigen G|MHC class Ib antigen|b2 microglobulin|mutant MHC class I antigen|mutant MHC class Ib antigen', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29826474, end_position_on_the_genomic_accession=29831130, orientation='plus', exon_count=10, OMIM=[142871], no_hdr0=''),
    3140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3140, CurrentID=0, Status='live', Symbol='MR1', Aliases=['HLALS'], description='major histocompatibility complex, class I-related', other_designations='major histocompatibility complex class I-related gene protein|MHC class I-like antigen MR-1|MHC class-I related-gene protein|major histocompatibility complex, class I-like sequence', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=181033387, end_position_on_the_genomic_accession=181061938, orientation='plus', exon_count=8, OMIM=[600764], no_hdr0=''),
    3141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3141, CurrentID=0, Status='live', Symbol='HLCS', Aliases=['HCS'], description='holocarboxylase synthetase', other_designations='biotin--protein ligase|biotin apo-protein ligase|biotin--[acetyl-CoA-carboxylase] ligase|biotin--[methylcrotonoyl-CoA-carboxylase] ligase|biotin--[methylmalonyl-CoA-carboxytransferase] ligase|holocarboxylase synthetase (biotin-(proprionyl-CoA-carboxylase (ATP-hydrolysing)) ligase)|holocarboxylase synthetase (biotin-(proprionyl-Coenzyme A-carboxylase (ATP-hydrolysing)) ligase)', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36748625, end_position_on_the_genomic_accession=36990255, orientation='minus', exon_count=20, OMIM=[609018], no_hdr0=''),
    3142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3142, CurrentID=0, Status='live', Symbol='HLX', Aliases=['HB241', 'HLX'], description='H2.0 like homeobox', other_designations='H2.0-like homeobox protein|H2.0-like homeo box-1|H2.0-like homeobox 1|homeobox protein HB24|homeobox protein HLX1', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220879443, end_position_on_the_genomic_accession=220885059, orientation='plus', exon_count=4, OMIM=[142995], no_hdr0=''),
    3145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3145, CurrentID=0, Status='live', Symbol='HMBS', Aliases=['PBG-D', 'PBGD', 'PORC', 'UPS'], description='hydroxymethylbilane synthase', other_designations='porphobilinogen deaminase|porphyria, acute; Chester type|pre-uroporphyrinogen synthase|uroporphyrinogen I synthase|uroporphyrinogen I synthetase', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119084864, end_position_on_the_genomic_accession=119093549, orientation='plus', exon_count=15, OMIM=[609806], no_hdr0=''),
    3146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3146, CurrentID=0, Status='live', Symbol='HMGB1', Aliases=['HMG-1', 'HMG1', 'HMG3', 'SBP-1'], description='high mobility group box 1', other_designations='high mobility group protein B1|Amphoterin|Sulfoglucuronyl carbohydrate binding protein|high-mobility group (nonhistone chromosomal) protein 1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30456704, end_position_on_the_genomic_accession=30617597, orientation='minus', exon_count=9, OMIM=[163905], no_hdr0=''),
    3148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3148, CurrentID=0, Status='live', Symbol='HMGB2', Aliases=['HMG2'], description='high mobility group box 2', other_designations='high mobility group protein B2|HMG-2|high mobility group protein 2|high-mobility group (nonhistone chromosomal) protein 2', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=173331376, end_position_on_the_genomic_accession=173334358, orientation='minus', exon_count=5, OMIM=[163906], no_hdr0=''),
    3149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3149, CurrentID=0, Status='live', Symbol='HMGB3', Aliases=['HMG-2a', 'HMG-4', 'HMG2A', 'HMG4'], description='high mobility group box 3', other_designations='high mobility group protein B3|high mobility group protein 2a|high-mobility group (nonhistone chromosomal) protein 4', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=150980507, end_position_on_the_genomic_accession=150990773, orientation='plus', exon_count=7, OMIM=[300193], no_hdr0=''),
    3150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3150, CurrentID=0, Status='live', Symbol='HMGN1', Aliases=['HMG14'], description='high mobility group nucleosome binding domain 1', other_designations='non-histone chromosomal protein HMG-14|high mobility group nucleosome-binding domain-containing protein 1|high-mobility group (nonhistone chromosomal) protein 14|high-mobility group nucleosome binding 1|nonhistone chromosomal protein HMG-14', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39342315, end_position_on_the_genomic_accession=39349088, orientation='minus', exon_count=10, OMIM=[163920], no_hdr0=''),
    3151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3151, CurrentID=0, Status='live', Symbol='HMGN2', Aliases=['HMG17'], description='high mobility group nucleosomal binding domain 2', other_designations='non-histone chromosomal protein HMG-17|high mobility group nucleosome-binding domain-containing protein 2|high mobility group protein N2|high-mobility group (nonhistone chromosomal) protein 17|nonhistone chromosomal protein HMG-17', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26472440, end_position_on_the_genomic_accession=26476642, orientation='plus', exon_count=6, OMIM=[163910], no_hdr0=''),
    3155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3155, CurrentID=0, Status='live', Symbol='HMGCL', Aliases=['HL'], description='3-hydroxy-3-methylglutaryl-CoA lyase', other_designations='hydroxymethylglutaryl-CoA lyase, mitochondrial|3-hydroxy-3-methylglutarate-CoA lyase|3-hydroxymethyl-3-methylglutaryl-CoA lyase|3-hydroxymethyl-3-methylglutaryl-Coenzyme A lyase|HMG-CoA lyase|hydroxymethylglutaricaciduria|mitochondrial 3-hydroxy-3-methylglutaryl-CoA lyase', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23801885, end_position_on_the_genomic_accession=23825429, orientation='minus', exon_count=9, OMIM=[613898], no_hdr0=''),
    3156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3156, CurrentID=0, Status='live', Symbol='HMGCR', Aliases=['LDLCQ3'], description='3-hydroxy-3-methylglutaryl-CoA reductase', other_designations='3-hydroxy-3-methylglutaryl-Coenzyme A reductase|3-hydroxy-3-methylglutaryl CoA reductase (NADPH)|HMG-CoA reductase|hydroxymethylglutaryl-CoA reductase', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75336334, end_position_on_the_genomic_accession=75362116, orientation='plus', exon_count=23, OMIM=[142910], no_hdr0=''),
    3157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3157, CurrentID=0, Status='live', Symbol='HMGCS1', Aliases=['HMGCS'], description='3-hydroxy-3-methylglutaryl-CoA synthase 1', other_designations='hydroxymethylglutaryl-CoA synthase, cytoplasmic|3-hydroxy-3-methylglutaryl coenzyme A (HMG-CoA) synthase|3-hydroxy-3-methylglutaryl-CoA synthase 1 (soluble)|3-hydroxy-3-methylglutaryl-Coenzyme A synthase 1 (soluble)', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43287470, end_position_on_the_genomic_accession=43313477, orientation='minus', exon_count=12, OMIM=[142940], no_hdr0=''),
    3158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3158, CurrentID=0, Status='live', Symbol='HMGCS2', Aliases=[], description='3-hydroxy-3-methylglutaryl-CoA synthase 2', other_designations='hydroxymethylglutaryl-CoA synthase, mitochondrial|3-hydroxy-3-methylglutaryl-CoA synthase 2 (mitochondrial)|3-hydroxy-3-methylglutaryl-Coenzyme A synthase 2 (mitochondrial)|HMG-CoA synthase|testicular tissue protein Li 88', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119747996, end_position_on_the_genomic_accession=119768932, orientation='minus', exon_count=10, OMIM=[600234], no_hdr0=''),
    3159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3159, CurrentID=0, Status='live', Symbol='HMGA1', Aliases=['HMG-RA', 'HMGIY', 'HMGA1'], description='high mobility group AT-hook 1', other_designations='high mobility group protein HMG-I/HMG-Y|high mobility group protein A1|high mobility group protein R|nonhistone chromosomal high-mobility group protein HMG-I/HMG-Y', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34236873, end_position_on_the_genomic_accession=34246231, orientation='plus', exon_count=6, OMIM=[600701], no_hdr0=''),
    3161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3161, CurrentID=0, Status='live', Symbol='HMMR', Aliases=['CD168', 'IHABP', 'RHAMM'], description='hyaluronan mediated motility receptor', other_designations='hyaluronan mediated motility receptor|intracellular hyaluronic acid-binding protein|receptor for hyaluronan-mediated motility', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=163460632, end_position_on_the_genomic_accession=163491941, orientation='plus', exon_count=18, OMIM=[600936], no_hdr0=''),
    3162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3162, CurrentID=0, Status='live', Symbol='HMOX1', Aliases=['HMOX1D', 'HO-1', 'HSP32', 'bK286B10'], description='heme oxygenase 1', other_designations='heme oxygenase 1|heat shock protein, 32-kD|heme oxygenase (decycling) 1', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35381096, end_position_on_the_genomic_accession=35394207, orientation='plus', exon_count=5, OMIM=[141250], no_hdr0=''),
    3163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3163, CurrentID=0, Status='live', Symbol='HMOX2', Aliases=['HO-2'], description='heme oxygenase 2', other_designations='heme oxygenase 2|heme oxygenase (decycling) 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4474697, end_position_on_the_genomic_accession=4510347, orientation='plus', exon_count=14, OMIM=[141251], no_hdr0=''),
    3164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3164, CurrentID=0, Status='live', Symbol='NR4A1', Aliases=['GFRP1', 'HMR', 'N10', 'NAK-1', 'NGFIB', 'NP10', 'NUR77', 'TR3'], description='nuclear receptor subfamily 4 group A member 1', other_designations='nuclear receptor subfamily 4 group A member 1|ST-59|TR3 orphan receptor|early response protein NAK1|growth factor-inducible nuclear protein N10|hormone receptor|nerve growth factor IB nuclear receptor variant 1|nuclear hormone receptor NUR/77|orphan nuclear receptor HMR|orphan nuclear receptor TR3|steroid receptor TR3|testicular receptor 3', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52022832, end_position_on_the_genomic_accession=52059507, orientation='plus', exon_count=15, OMIM=[139139], no_hdr0=''),
    3166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3166, CurrentID=0, Status='live', Symbol='HMX1', Aliases=['H6', 'NKX5-3'], description='H6 family homeobox 1', other_designations='homeobox protein HMX1|H6 homeodomain protein|homeobox protein H6', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8846076, end_position_on_the_genomic_accession=8871839, orientation='minus', exon_count=3, OMIM=[142992], no_hdr0=''),
    3167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3167, CurrentID=0, Status='live', Symbol='HMX2', Aliases=['H6L', 'Nkx5-2'], description='H6 family homeobox 2', other_designations='homeobox protein HMX2|homeo box (H6 family) 2|homeobox protein H6 family member 2', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123142421, end_position_on_the_genomic_accession=123150673, orientation='plus', exon_count=3, OMIM=[600647], no_hdr0=''),
    3169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3169, CurrentID=0, Status='live', Symbol='FOXA1', Aliases=['HNF3A', 'TCF3A'], description='forkhead box A1', other_designations='hepatocyte nuclear factor 3-alpha|HNF-3-alpha|HNF-3A|TCF-3A|forkhead box protein A1|transcription factor 3A', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=37589552, end_position_on_the_genomic_accession=37595249, orientation='minus', exon_count=3, OMIM=[602294], no_hdr0=''),
    3170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3170, CurrentID=0, Status='live', Symbol='FOXA2', Aliases=['HNF-3-beta', 'HNF3B', 'TCF3B'], description='forkhead box A2', other_designations='hepatocyte nuclear factor 3-beta|forkhead box protein A2|hepatic nuclear factor-3-beta|transcription factor 3B', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=22580998, end_position_on_the_genomic_accession=22585490, orientation='minus', exon_count=3, OMIM=[600288], no_hdr0=''),
    3171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3171, CurrentID=0, Status='live', Symbol='FOXA3', Aliases=['FKHH3', 'HNF3G', 'TCF3G'], description='forkhead box A3', other_designations='hepatocyte nuclear factor 3-gamma|HNF-3-gamma|HNF-3G|TCF-3G|fork head-related protein FKH H3|forkhead box protein A3|transcription factor 3G', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45864326, end_position_on_the_genomic_accession=45873797, orientation='plus', exon_count=2, OMIM=[602295], no_hdr0=''),
    3172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3172, CurrentID=0, Status='live', Symbol='HNF4A', Aliases=['FRTS4', 'HNF4', 'HNF4a7', 'HNF4a8', 'HNF4a9', 'HNF4alpha', 'MODY', 'MODY1', 'NR2A1', 'NR2A21', 'TCF', 'TCF-14', 'TCF14'], description='hepatocyte nuclear factor 4 alpha', other_designations='hepatocyte nuclear factor 4-alpha|HNF4alpha10/11/12|hepatic nuclear factor 4 alpha|nuclear receptor subfamily 2 group A member 1|transcription factor 14|transcription factor HNF-4', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44355699, end_position_on_the_genomic_accession=44434596, orientation='plus', exon_count=13, OMIM=[600281], no_hdr0=''),
    3174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3174, CurrentID=0, Status='live', Symbol='HNF4G', Aliases=['NR2A2', 'NR2A3'], description='hepatocyte nuclear factor 4 gamma', other_designations='hepatocyte nuclear factor 4-gamma|HNF-4-gamma|nuclear receptor subfamily 2 group A member 2', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=75407567, end_position_on_the_genomic_accession=75566834, orientation='plus', exon_count=15, OMIM=[605966], no_hdr0=''),
    3175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3175, CurrentID=0, Status='live', Symbol='ONECUT1', Aliases=['HNF-6', 'HNF6', 'HNF6A'], description='one cut homeobox 1', other_designations='hepatocyte nuclear factor 6|hepatocyte nuclear factor 6, alpha|one cut domain family member 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52755053, end_position_on_the_genomic_accession=52790336, orientation='minus', exon_count=6, OMIM=[604164], no_hdr0=''),
    3176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3176, CurrentID=0, Status='live', Symbol='HNMT', Aliases=['HMT-S1', 'HNMT-S2', 'MRT51', 'HNMT'], description='histamine N-methyltransferase', other_designations='histamine N-methyltransferase', map_location='2q22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=137964068, end_position_on_the_genomic_accession=138016364, orientation='plus', exon_count=9, OMIM=[605238], no_hdr0=''),
    3177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3177, CurrentID=0, Status='live', Symbol='SLC29A2', Aliases=['DER12', 'ENT2', 'HNP36'], description='solute carrier family 29 member 2', other_designations='equilibrative nucleoside transporter 2|36 kDa nucleolar protein HNP36|delayed-early response protein 12|equilibrative NBMPR-insensitive nucleoside transporter|equilibrative nitrobenzylmercaptopurine riboside-insensitive nucleoside transporter|hydrophobic nucleolar protein, 36 kDa|hydrophobic nucleolar protein, 36kD|nucleoside transporter, ei-type|solute carrier family 29 (equilibrative nucleoside transporter), member 2|solute carrier family 29 (nucleoside transporters), member 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66362521, end_position_on_the_genomic_accession=66372476, orientation='minus', exon_count=15, OMIM=[602110], no_hdr0=''),
    3178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3178, CurrentID=0, Status='live', Symbol='HNRNPA1', Aliases=['ALS19', 'ALS20', 'HNRPA1', 'HNRPA1L3', 'IBMPFD3', 'UP 1', 'hnRNP A1', 'hnRNP-A1'], description='heterogeneous nuclear ribonucleoprotein A1', other_designations='heterogeneous nuclear ribonucleoprotein A1|epididymis secretory sperm binding protein|helix-destabilizing protein|heterogeneous nuclear ribonucleoprotein A1B protein|heterogeneous nuclear ribonucleoprotein B2 protein|heterogeneous nuclear ribonucleoprotein core protein A1|hnRNP core protein A1-like 3|nuclear ribonucleoprotein particle A1 protein|putative heterogeneous nuclear ribonucleoprotein A1-like 3|single-strand DNA-binding protein UP1|single-strand RNA-binding protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54280726, end_position_on_the_genomic_accession=54287087, orientation='plus', exon_count=12, OMIM=[164017], no_hdr0=''),
    3181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3181, CurrentID=0, Status='live', Symbol='HNRNPA2B1', Aliases=['HNRNPA2', 'HNRNPB1', 'HNRPA2', 'HNRPA2B1', 'HNRPB1', 'IBMPFD2', 'RNPA2', 'SNRPB1'], description='heterogeneous nuclear ribonucleoprotein A2/B1', other_designations='heterogeneous nuclear ribonucleoproteins A2/B1|HNRNPA2B1/MYC fusion|epididymis secretory sperm binding protein|hnRNP A2 / hnRNP B1|nuclear ribonucleoprotein particle A2 protein', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=26189920, end_position_on_the_genomic_accession=26200775, orientation='minus', exon_count=14, OMIM=[600124], no_hdr0=''),
    3182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3182, CurrentID=0, Status='live', Symbol='HNRNPAB', Aliases=['ABBP1', 'HNRPAB'], description='heterogeneous nuclear ribonucleoprotein A/B', other_designations='heterogeneous nuclear ribonucleoprotein A/B|ABBP-1|APOBEC1-binding protein 1|apobec-1 binding protein 1|apolipoprotein B mRNA editing enzyme, catalytic polypeptide 1-binding protein 1|hnRNP A/B|hnRNP type A/B protein', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178204533, end_position_on_the_genomic_accession=178211163, orientation='plus', exon_count=8, OMIM=[602688], no_hdr0=''),
    3183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3183, CurrentID=0, Status='live', Symbol='HNRNPC', Aliases=['C1', 'C2', 'HNRNP', 'HNRPC', 'SNRPC'], description='heterogeneous nuclear ribonucleoprotein C', other_designations='heterogeneous nuclear ribonucleoproteins C1/C2|heterogeneous nuclear ribonucleoprotein C (C1/C2)|hnRNP C1/C2|nuclear ribonucleoprotein particle C1 protein|nuclear ribonucleoprotein particle C2 protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21209147, end_position_on_the_genomic_accession=21269442, orientation='minus', exon_count=10, OMIM=[164020], no_hdr0=''),
    3184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3184, CurrentID=0, Status='live', Symbol='HNRNPD', Aliases=['AUF1', 'AUF1A', 'HNRPD', 'P37', 'hnRNPD0'], description='heterogeneous nuclear ribonucleoprotein D', other_designations='heterogeneous nuclear ribonucleoprotein D0|ARE-binding protein AUFI, type A|AU-rich element RNA binding protein 1, 37kDa|hnRNP D0', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82352498, end_position_on_the_genomic_accession=82373991, orientation='minus', exon_count=9, OMIM=[601324], no_hdr0=''),
    3185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3185, CurrentID=0, Status='live', Symbol='HNRNPF', Aliases=['HNRPF', 'OK/SW-cl.23', 'mcs94-1'], description='heterogeneous nuclear ribonucleoprotein F', other_designations='heterogeneous nuclear ribonucleoprotein F|HnRNP F protein|nucleolin-like protein mcs94-1', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43385618, end_position_on_the_genomic_accession=43409186, orientation='minus', exon_count=7, OMIM=[601037], no_hdr0=''),
    3187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3187, CurrentID=0, Status='live', Symbol='HNRNPH1', Aliases=['HNRPH', 'HNRPH1', 'hnRNPH'], description='heterogeneous nuclear ribonucleoprotein H1', other_designations='heterogeneous nuclear ribonucleoprotein H|epididymis secretory sperm binding protein|heterogeneous nuclear ribonucleoprotein H1 (H)', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179614178, end_position_on_the_genomic_accession=179634784, orientation='minus', exon_count=18, OMIM=[601035], no_hdr0=''),
    3188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3188, CurrentID=0, Status='live', Symbol='HNRNPH2', Aliases=['FTP3', "HNRPH'", 'HNRPH2', 'MRXSB', 'NRPH2', "hnRNPH'"], description='heterogeneous nuclear ribonucleoprotein H2', other_designations="heterogeneous nuclear ribonucleoprotein H2|FTP-3|epididymis secretory sperm binding protein|heterogeneous nuclear ribonucleoprotein H-prime|heterogeneous nuclear ribonucleoprotein H2 (H')|hnRNP H'|hnRNP H2", map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101408222, end_position_on_the_genomic_accession=101414133, orientation='plus', exon_count=2, OMIM=[300610], no_hdr0=''),
    3189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3189, CurrentID=0, Status='live', Symbol='HNRNPH3', Aliases=['2H9', 'HNRPH3'], description='heterogeneous nuclear ribonucleoprotein H3', other_designations='heterogeneous nuclear ribonucleoprotein H3|heterogeneous nuclear ribonucleoprotein 2H9|hnRNP 2H9|hnRNP H3', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68331693, end_position_on_the_genomic_accession=68343196, orientation='plus', exon_count=12, OMIM=[602324], no_hdr0=''),
    3190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3190, CurrentID=0, Status='live', Symbol='HNRNPK', Aliases=['AUKS', 'CSBP', 'HNRPK', 'TUNP'], description='heterogeneous nuclear ribonucleoprotein K', other_designations='heterogeneous nuclear ribonucleoprotein K|dC-stretch binding protein|transformation upregulated nuclear protein', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83968083, end_position_on_the_genomic_accession=83980630, orientation='minus', exon_count=18, OMIM=[600712], no_hdr0=''),
    3191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3191, CurrentID=0, Status='live', Symbol='HNRNPL', Aliases=['HNRPL', 'P/OKcl.14', 'hnRNP-L'], description='heterogeneous nuclear ribonucleoprotein L', other_designations='heterogeneous nuclear ribonucleoprotein L|epididymis secretory sperm binding protein|hnRNP L', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38836370, end_position_on_the_genomic_accession=38852347, orientation='minus', exon_count=17, OMIM=[603083], no_hdr0=''),
    3192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3192, CurrentID=0, Status='live', Symbol='HNRNPU', Aliases=['DEE54', 'EIEE54', 'GRIP120-AS1', 'HNRPU', 'SAF-A', 'SAFA', 'U21.1', 'hnRNP U', 'pp120', 'HNRNPU'], description='heterogeneous nuclear ribonucleoprotein U', other_designations='heterogeneous nuclear ribonucleoprotein U|HNRNPU antisense RNA 1|heterogeneous nuclear ribonucleoprotein U (scaffold attachment factor A)|nuclear p120 ribonucleoprotein|p120 nuclear protein', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244850297, end_position_on_the_genomic_accession=244864543, orientation='minus', exon_count=14, OMIM=[602869], no_hdr0=''),
    3195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3195, CurrentID=0, Status='live', Symbol='TLX1', Aliases=['HOX11', 'TCL3'], description='T cell leukemia homeobox 1', other_designations='T-cell leukemia homeobox protein 1|T-cell leukemia/lymphoma protein 3|homeo box-11 (T-cell leukemia-3 associated breakpoint, homologous to Drosophila Notch)|homeobox protein Hox-11|proto-oncogene TCL-3', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101130773, end_position_on_the_genomic_accession=101137789, orientation='plus', exon_count=4, OMIM=[186770], no_hdr0=''),
    3196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3196, CurrentID=0, Status='live', Symbol='TLX2', Aliases=['HOX11L1', 'NCX'], description='T cell leukemia homeobox 2', other_designations='T-cell leukemia homeobox protein 2|homeo box 11-like 1|homeobox protein Hox-11L1|neural crest homeobox protein', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74514450, end_position_on_the_genomic_accession=74517148, orientation='plus', exon_count=3, OMIM=[604240], no_hdr0=''),
    3198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3198, CurrentID=0, Status='live', Symbol='HOXA1', Aliases=['BSAS', 'HOX1', 'HOX1F'], description='homeobox A1', other_designations='homeobox protein Hox-A1|HOX A1 homeodomain protein|Hox 1.6-like protein|homeo box A1|homeobox 1F|homeobox protein Hox-1F|lab-like protein', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27092993, end_position_on_the_genomic_accession=27096000, orientation='minus', exon_count=3, OMIM=[142955], no_hdr0=''),
    3199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3199, CurrentID=0, Status='live', Symbol='HOXA2', Aliases=['HOX1K', 'MCOHI'], description='homeobox A2', other_designations='homeobox protein Hox-A2|homeobox protein Hox-1K', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27100354, end_position_on_the_genomic_accession=27102683, orientation='minus', exon_count=2, OMIM=[604685], no_hdr0=''),
    3200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3200, CurrentID=0, Status='live', Symbol='HOXA3', Aliases=['HOX1', 'HOX1E'], description='homeobox A3', other_designations='homeobox protein Hox-A3|Hox-1.5-like protein|homeo box 1E|homeo box A3|homeobox protein Hox-1E', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27107010, end_position_on_the_genomic_accession=27152583, orientation='minus', exon_count=13, OMIM=[142954], no_hdr0=''),
    3201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3201, CurrentID=0, Status='live', Symbol='HOXA4', Aliases=['HOX1', 'HOX1D'], description='homeobox A4', other_designations='homeobox protein Hox-A4|Dfd-like protein|Hox-1.4-like protein|homeo box A4|homeobox protein Hox-1.4|homeobox protein Hox-1D', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27128525, end_position_on_the_genomic_accession=27130757, orientation='minus', exon_count=2, OMIM=[142953], no_hdr0=''),
    3202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3202, CurrentID=0, Status='live', Symbol='HOXA5', Aliases=['HOX1', 'HOX1.3', 'HOX1C'], description='homeobox A5', other_designations='homeobox protein Hox-A5|homeo box 1C|homeo box A5|homeobox protein HOXA5|homeobox protein Hox-1C', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27141052, end_position_on_the_genomic_accession=27143681, orientation='minus', exon_count=2, OMIM=[142952], no_hdr0=''),
    3203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3203, CurrentID=0, Status='live', Symbol='HOXA6', Aliases=['HOX1', 'HOX1.2', 'HOX1B'], description='homeobox A6', other_designations='homeobox protein Hox-A6|homeo box 1B|homeo box A6|homeobox protein HOXA6|homeobox protein Hox-1B', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27145396, end_position_on_the_genomic_accession=27147774, orientation='minus', exon_count=2, OMIM=[142951], no_hdr0=''),
    3204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3204, CurrentID=0, Status='live', Symbol='HOXA7', Aliases=['ANTP', 'HOX1', 'HOX1.1', 'HOX1A'], description='homeobox A7', other_designations='homeobox protein Hox-A7|homeo box A7|homeobox protein HOX-1A|homeobox protein Hox 1.1', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27153716, end_position_on_the_genomic_accession=27156675, orientation='minus', exon_count=2, OMIM=[142950], no_hdr0=''),
    3205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3205, CurrentID=0, Status='live', Symbol='HOXA9', Aliases=['ABD-B', 'HOX1', 'HOX1.7', 'HOX1G'], description='homeobox A9', other_designations='homeobox protein Hox-A9|homeobox protein Hox-1G|homeodomain protein HOXA9', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27162438, end_position_on_the_genomic_accession=27165537, orientation='minus', exon_count=2, OMIM=[142956], no_hdr0=''),
    3206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3206, CurrentID=0, Status='live', Symbol='HOXA10', Aliases=['HOX1', 'HOX1.8', 'HOX1H', 'PL'], description='homeobox A10', other_designations='homeobox protein Hox-A10|homeo box A10|homeobox protein 1H|homeobox protein HOXA10|homeobox protein Hox-1.8|homeobox protein Hox-1H', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27170605, end_position_on_the_genomic_accession=27179861, orientation='minus', exon_count=3, OMIM=[142957], no_hdr0=''),
    3207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3207, CurrentID=0, Status='live', Symbol='HOXA11', Aliases=['HOX1', 'HOX1I', 'RUSAT1'], description='homeobox A11', other_designations='homeobox protein Hox-A11|homeo box 1I|homeobox protein HOXA11|homeobox protein Hox-1I', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27181157, end_position_on_the_genomic_accession=27185232, orientation='minus', exon_count=2, OMIM=[142958], no_hdr0=''),
    3208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3208, CurrentID=0, Status='live', Symbol='HPCA', Aliases=['BDR2', 'DYT2'], description='hippocalcin', other_designations='neuron-specific calcium-binding protein hippocalcin|calcium-binding protein BDR-2|dystonia 2, torsion (autosomal recessive)', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32885965, end_position_on_the_genomic_accession=32894646, orientation='plus', exon_count=6, OMIM=[142622], no_hdr0=''),
    3209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3209, CurrentID=0, Status='live', Symbol='HOXA13', Aliases=['HOX1', 'HOX1J'], description='homeobox A13', other_designations='homeobox protein Hox-A13|homeo box 1J|homeo box A13|homeobox protein HOXA13|homeobox protein Hox-1J|transcription factor HOXA13', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27194364, end_position_on_the_genomic_accession=27200091, orientation='minus', exon_count=2, OMIM=[142959], no_hdr0=''),
    3211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3211, CurrentID=0, Status='live', Symbol='HOXB1', Aliases=['HCFP3', 'HOX2', 'HOX2I', 'Hox-2.9'], description='homeobox B1', other_designations='homeobox protein Hox-B1|homeobox protein Hox-2I', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48528526, end_position_on_the_genomic_accession=48531011, orientation='minus', exon_count=2, OMIM=[142968], no_hdr0=''),
    3212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3212, CurrentID=0, Status='live', Symbol='HOXB2', Aliases=['HOX2', 'HOX2H', 'Hox-2.8', 'K8'], description='homeobox B2', other_designations='homeobox protein Hox-B2|K8 home protein|homeo box 2H|homeo box B2|homeobox protein Hox-2.8|homeobox protein Hox-2H', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48542655, end_position_on_the_genomic_accession=48545109, orientation='minus', exon_count=3, OMIM=[142967], no_hdr0=''),
    3213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3213, CurrentID=0, Status='live', Symbol='HOXB3', Aliases=['HOX2', 'HOX2G', 'Hox-2.7'], description='homeobox B3', other_designations='homeobox protein Hox-B3|homeo box 2G|homeobox protein Hox-2.7|homeobox protein Hox-2G', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48548870, end_position_on_the_genomic_accession=48590241, orientation='minus', exon_count=9, OMIM=[142966], no_hdr0=''),
    3214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3214, CurrentID=0, Status='live', Symbol='HOXB4', Aliases=['HOX-2.6', 'HOX2', 'HOX2F'], description='homeobox B4', other_designations='homeobox protein Hox-B4|homeo box 2F|homeo box B4|homeobox protein Hox-2.6|homeobox protein Hox-2F', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48575507, end_position_on_the_genomic_accession=48578350, orientation='minus', exon_count=2, OMIM=[142965], no_hdr0=''),
    3215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3215, CurrentID=0, Status='live', Symbol='HOXB5', Aliases=['HHO.C10', 'HOX2', 'HOX2A', 'HU-1', 'Hox2.1'], description='homeobox B5', other_designations='homeobox protein Hox-B5|homeo box 2A|homeo box B5|homeobox protein HHO.C10|homeobox protein Hox-2A|homeobox protein Hu-1', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48591257, end_position_on_the_genomic_accession=48593779, orientation='minus', exon_count=2, OMIM=[142960], no_hdr0=''),
    3216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3216, CurrentID=0, Status='live', Symbol='HOXB6', Aliases=['HOX2', 'HOX2B', 'HU-2', 'Hox-2.2'], description='homeobox B6', other_designations='homeobox protein Hox-B6|homeo box 2B|homeo box B6|homeobox protein Hox-2.2|homeobox protein Hox-2B|homeobox protein Hu-2', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48595736, end_position_on_the_genomic_accession=48604986, orientation='minus', exon_count=5, OMIM=[142961], no_hdr0=''),
    3217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3217, CurrentID=0, Status='live', Symbol='HOXB7', Aliases=['HHO.C1', 'HOX2', 'HOX2C', 'Hox-2.3'], description='homeobox B7', other_designations='homeobox protein Hox-B7|homeo box 2C|homeo box B7|homeo box c1 protein|homeobox protein HHO.C1|homeobox protein Hox-2C', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48607232, end_position_on_the_genomic_accession=48611017, orientation='minus', exon_count=2, OMIM=[142962], no_hdr0=''),
    3218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3218, CurrentID=0, Status='live', Symbol='HOXB8', Aliases=['HOX2', 'HOX2D', 'Hox-2.4'], description='homeobox B8', other_designations='homeobox protein Hox-B8|homeo box 2D|homeo box B8|homeobox protein Hox-2.4|homeobox protein Hox-2D', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48612346, end_position_on_the_genomic_accession=48619531, orientation='minus', exon_count=5, OMIM=[142963], no_hdr0=''),
    3219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3219, CurrentID=0, Status='live', Symbol='HOXB9', Aliases=['HOX-2.5', 'HOX2', 'HOX2E'], description='homeobox B9', other_designations='homeobox protein Hox-B9|homeo box 2E|homeo box B9|homeobox protein Hox-2.5|homeobox protein Hox-2E', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48621156, end_position_on_the_genomic_accession=48626358, orientation='minus', exon_count=2, OMIM=[142964], no_hdr0=''),
    3221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3221, CurrentID=0, Status='live', Symbol='HOXC4', Aliases=['HOX3', 'HOX3E', 'cp19'], description='homeobox C4', other_designations='homeobox protein Hox-C4|homeo box 3E|homeobox protein CP19|homeobox protein Hox-3E', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54016888, end_position_on_the_genomic_accession=54056030, orientation='plus', exon_count=4, OMIM=[142974], no_hdr0=''),
    3222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3222, CurrentID=0, Status='live', Symbol='HOXC5', Aliases=['CP11', 'HOX3', 'HOX3D'], description='homeobox C5', other_designations='homeobox protein Hox-C5|homeo box C5|homeobox protein CP11|homeobox protein Hox-3D', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54016888, end_position_on_the_genomic_accession=54035361, orientation='plus', exon_count=3, OMIM=[142973], no_hdr0=''),
    3223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3223, CurrentID=0, Status='live', Symbol='HOXC6', Aliases=['CP25', 'HHO.C8', 'HOX3', 'HOX3C'], description='homeobox C6', other_designations='homeobox protein Hox-C6|homeo box 3C|homeo box C8 protein|homeobox protein CP25|homeobox protein HHO.C8|homeobox protein Hox-3C', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54016888, end_position_on_the_genomic_accession=54030823, orientation='plus', exon_count=3, OMIM=[142972], no_hdr0=''),
    3224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3224, CurrentID=0, Status='live', Symbol='HOXC8', Aliases=['HOX3', 'HOX3A'], description='homeobox C8', other_designations='homeobox protein Hox-C8|Hox-3.1, mouse, homolog of|homeo box 3A|homeo box C8|homeobox protein Hox-3A', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54008985, end_position_on_the_genomic_accession=54012769, orientation='plus', exon_count=2, OMIM=[142970], no_hdr0=''),
    3225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3225, CurrentID=0, Status='live', Symbol='HOXC9', Aliases=['HOX3', 'HOX3B'], description='homeobox C9', other_designations='homeobox protein Hox-C9|homeo box C9|homeobox protein Hox-3B', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54000161, end_position_on_the_genomic_accession=54003337, orientation='plus', exon_count=2, OMIM=[142971], no_hdr0=''),
    3226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3226, CurrentID=0, Status='live', Symbol='HOXC10', Aliases=['HOX3I'], description='homeobox C10', other_designations='homeobox protein Hox-C10|homeo box C10|homeobox protein Hox-3I|homeoprotein C10', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53985146, end_position_on_the_genomic_accession=53990279, orientation='plus', exon_count=2, OMIM=[605560], no_hdr0=''),
    3227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3227, CurrentID=0, Status='live', Symbol='HOXC11', Aliases=['HOX3H'], description='homeobox C11', other_designations='homeobox protein Hox-C11|homeo box C11|homeobox protein Hox-3H', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53973126, end_position_on_the_genomic_accession=53977643, orientation='plus', exon_count=2, OMIM=[605559], no_hdr0=''),
    3228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3228, CurrentID=0, Status='live', Symbol='HOXC12', Aliases=['HOC3F', 'HOX3', 'HOX3F'], description='homeobox C12', other_designations='homeobox protein Hox-C12|homeo box 3F|homeo box C12|homeobox protein Hox-3F', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53954903, end_position_on_the_genomic_accession=53958956, orientation='plus', exon_count=2, OMIM=[142975], no_hdr0=''),
    3229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3229, CurrentID=0, Status='live', Symbol='HOXC13', Aliases=['ECTD9', 'HOX3', 'HOX3G'], description='homeobox C13', other_designations='homeobox protein Hox-C13|NUP98/HOXC13|homeo box 3G|homeobox protein Hox-3G', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53938831, end_position_on_the_genomic_accession=53946544, orientation='plus', exon_count=2, OMIM=[142976], no_hdr0=''),
    3231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3231, CurrentID=0, Status='live', Symbol='HOXD1', Aliases=['HOX4', 'HOX4G', 'Hox-4.7'], description='homeobox D1', other_designations='homeobox protein Hox-D1|homeo box 4G|homeo box D1|homeobox protein Hox-GG', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176188668, end_position_on_the_genomic_accession=176190907, orientation='plus', exon_count=2, OMIM=[142987], no_hdr0=''),
    3232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3232, CurrentID=0, Status='live', Symbol='HOXD3', Aliases=['HOX1D', 'HOX4', 'HOX4A', 'Hox-4.1'], description='homeobox D3', other_designations='homeobox protein Hox-D3|Hox-4.1, mouse, homolog of|homeo box D3|homeobox protein Hox-4A', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176157307, end_position_on_the_genomic_accession=176173102, orientation='plus', exon_count=8, OMIM=[142980], no_hdr0=''),
    3233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3233, CurrentID=0, Status='live', Symbol='HOXD4', Aliases=['HHO.C13', 'HOX-5.1', 'HOX4', 'HOX4B', 'Hox-4.2'], description='homeobox D4', other_designations='homeobox protein Hox-D4|Hox-4.2, mouse, homolog of homeo box X|homeobox protein HHO.C13|homeobox protein Hox-4B|homeobox protein Hox-5.1', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176150394, end_position_on_the_genomic_accession=176156078, orientation='plus', exon_count=2, OMIM=[142981], no_hdr0=''),
    3234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3234, CurrentID=0, Status='live', Symbol='HOXD8', Aliases=['HOX4', 'HOX4E', 'HOX5.4'], description='homeobox D8', other_designations='homeobox protein Hox-D8|Hox-4.5|homeo box 4E|homeo box D8|homeobox protein 5.4|homeobox protein Hox-4E|homeobox protein Hox-5.4', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176129705, end_position_on_the_genomic_accession=176132695, orientation='plus', exon_count=2, OMIM=[142985], no_hdr0=''),
    3235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3235, CurrentID=0, Status='live', Symbol='HOXD9', Aliases=['HOX4', 'HOX4C', 'Hox-4.3', 'Hox-5.2'], description='homeobox D9', other_designations='homeobox protein Hox-D9|Hox-4.3, mouse, homolog of|homeo box D9|homeobox protein Hox-4C|homeobox protein Hox-5.2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176122719, end_position_on_the_genomic_accession=176124937, orientation='plus', exon_count=2, OMIM=[142982], no_hdr0=''),
    3236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3236, CurrentID=0, Status='live', Symbol='HOXD10', Aliases=['HOX4', 'HOX4D', 'HOX4E', 'Hox-4.4'], description='homeobox D10', other_designations='homeobox protein Hox-D10|homeo box 4D|homeo box D10|homeobox protein Hox-4D|homeobox protein Hox-4E', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176116778, end_position_on_the_genomic_accession=176119937, orientation='plus', exon_count=2, OMIM=[142984], no_hdr0=''),
    3237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3237, CurrentID=0, Status='live', Symbol='HOXD11', Aliases=['HOX4', 'HOX4F'], description='homeobox D11', other_designations='homeobox protein Hox-D11|Hox-4.6, mouse, homolog of|homeo box 4F|homeo box D11|homeobox protein Hox-4F', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176107280, end_position_on_the_genomic_accession=176109754, orientation='plus', exon_count=2, OMIM=[142986], no_hdr0=''),
    3238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3238, CurrentID=0, Status='live', Symbol='HOXD12', Aliases=['HOX4H'], description='homeobox D12', other_designations='homeobox protein Hox-D12|Hox-4.7, mouse, homolog of|homeo box D12|homeobox protein Hox-4H', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176099795, end_position_on_the_genomic_accession=176102489, orientation='plus', exon_count=2, OMIM=[142988], no_hdr0=''),
    3239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3239, CurrentID=0, Status='live', Symbol='HOXD13', Aliases=['BDE', 'BDSD', 'HOX4I', 'SPD', 'SPD1'], description='homeobox D13', other_designations='homeobox protein Hox-D13|homeo box 4I|homeo box D13|homeobox protein Hox-4I|synpolydactyly', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176087487, end_position_on_the_genomic_accession=176095944, orientation='plus', exon_count=4, OMIM=[142989], no_hdr0=''),
    3240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3240, CurrentID=0, Status='live', Symbol='HP', Aliases=['BP2ALPHA2', 'HPA1S', 'HP'], description='haptoglobin', other_designations='haptoglobin|binding peptide|haptoglobin alpha(1S)-beta|haptoglobin alpha(2FS)-beta|haptoglobin, alpha polypeptide|haptoglobin, beta polypeptide|zonulin', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72054505, end_position_on_the_genomic_accession=72061055, orientation='plus', exon_count=7, OMIM=[140100], no_hdr0=''),
    3241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3241, CurrentID=0, Status='live', Symbol='HPCAL1', Aliases=['BDR1', 'HLP2', 'VILIP-3'], description='hippocalcin like 1', other_designations='hippocalcin-like protein 1|calcium-binding protein BDR-1|visinin-like protein 3', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10302124, end_position_on_the_genomic_accession=10427617, orientation='plus', exon_count=17, OMIM=[600207], no_hdr0=''),
    3242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3242, CurrentID=0, Status='live', Symbol='HPD', Aliases=['4-HPPD', '4HPPD', 'GLOD3', 'HPPDASE', 'PPD'], description='4-hydroxyphenylpyruvate dioxygenase', other_designations='4-hydroxyphenylpyruvate dioxygenase|4-hydroxyphenylpyruvic acid oxidase|glyoxalase domain containing 3', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121839527, end_position_on_the_genomic_accession=121888611, orientation='minus', exon_count=17, OMIM=[609695], no_hdr0=''),
    3248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3248, CurrentID=0, Status='live', Symbol='HPGD', Aliases=['15-PGDH', 'PGDH', 'PGDH1', 'PHOAR1', 'SDR36C1'], description='15-hydroxyprostaglandin dehydrogenase', other_designations='15-hydroxyprostaglandin dehydrogenase [NAD(+)]|15-hydroxyprostaglandin dehydrogenase (NAD(+))|NAD+-dependent 15-hydroxyprostaglandin dehydrogenase|hydroxyprostaglandin dehydrogenase 15-(NAD)|prostaglandin dehydrogenase 1|short chain dehydrogenase/reductase family 36C member 1', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=174490175, end_position_on_the_genomic_accession=174522893, orientation='minus', exon_count=10, OMIM=[601688], no_hdr0=''),
    3249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3249, CurrentID=0, Status='live', Symbol='HPN', Aliases=['TMPRSS1'], description='hepsin', other_designations='serine protease hepsin|testicular tissue protein Li 85|transmembrane protease serine 1', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35040506, end_position_on_the_genomic_accession=35066573, orientation='plus', exon_count=15, OMIM=[142440], no_hdr0=''),
    3250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3250, CurrentID=0, Status='live', Symbol='HPR', Aliases=['A-259H10.2', 'HP'], description='haptoglobin-related protein', other_designations='haptoglobin-related protein|Haptoglobin-related locus', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72063226, end_position_on_the_genomic_accession=72077246, orientation='plus', exon_count=7, OMIM=[140210], no_hdr0=''),
    3251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3251, CurrentID=0, Status='live', Symbol='HPRT1', Aliases=['HGPRT', 'HPRT'], description='hypoxanthine phosphoribosyltransferase 1', other_designations='hypoxanthine-guanine phosphoribosyltransferase|HGPRTase|hypoxanthine-guanine phosphoribosyltransferase 1|testicular tissue protein Li 89', map_location='Xq26.2-q26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134460165, end_position_on_the_genomic_accession=134500668, orientation='plus', exon_count=9, OMIM=[308000], no_hdr0=''),
    3257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3257, CurrentID=0, Status='live', Symbol='HPS1', Aliases=['BLOC3S1', 'HPS'], description='HPS1 biogenesis of lysosomal organelles complex 3 subunit 1', other_designations='Hermansky-Pudlak syndrome 1 protein', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=98416193, end_position_on_the_genomic_accession=98446963, orientation='minus', exon_count=22, OMIM=[604982], no_hdr0=''),
    3263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3263, CurrentID=0, Status='live', Symbol='HPX', Aliases=['HX'], description='hemopexin', other_designations='hemopexin|beta-1B-glycoprotein|epididymis secretory sperm binding protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6431049, end_position_on_the_genomic_accession=6440987, orientation='minus', exon_count=10, OMIM=[142290], no_hdr0=''),
    3265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3265, CurrentID=0, Status='live', Symbol='HRAS', Aliases=['C-BAS/HAS', 'C-H-RAS', 'C-HA-RAS1', 'CTLO', 'H-RASIDX', 'HAMSV1', 'RASH1', 'p21ras', 'HRAS'], description='HRas proto-oncogene, GTPase', other_designations='GTPase HRas|GTP- and GDP-binding peptide B|Ha-Ras1 proto-oncoprotein|Harvey rat sarcoma viral oncogene homolog|Harvey rat sarcoma viral oncoprotein|Ras family small GTP binding protein H-Ras|c-has/bas p21 protein|p19 H-RasIDX protein|transformation gene: oncogene HAMSV|transforming protein p21|v-Ha-ras Harvey rat sarcoma viral oncogene homolog', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=532242, end_position_on_the_genomic_accession=535576, orientation='minus', exon_count=7, OMIM=[190020], no_hdr0=''),
    3266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3266, CurrentID=0, Status='live', Symbol='ERAS', Aliases=['HRAS2', 'HRASP'], description='ES cell expressed Ras', other_designations='GTPase ERas|E-Ras|embryonic stem cell-expressed Ras|small GTPase protein E-Ras|v-Ha-ras Harvey rat sarcoma viral oncogene homolog 2|v-Ha-ras Harvey rat sarcoma viral oncogene homolog pseudogene', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48826513, end_position_on_the_genomic_accession=48829869, orientation='plus', exon_count=2, OMIM=[300437], no_hdr0=''),
    3267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3267, CurrentID=0, Status='live', Symbol='AGFG1', Aliases=['HRB', 'RAB', 'RIP'], description='ArfGAP with FG repeats 1', other_designations='arf-GAP domain and FG repeat-containing protein 1|HIV-1 Rev-binding protein|Rab, Rev/Rex activation domain-binding protein|arf-GAP domain and FG repeats-containing protein 1|hRIP, Rev interacting protein|nucleoporin-like protein RIP|rev-interacting protein|rev/Rex activation domain-binding protein', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227472156, end_position_on_the_genomic_accession=227561217, orientation='plus', exon_count=14, OMIM=[600862], no_hdr0=''),
    3268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3268, CurrentID=0, Status='live', Symbol='AGFG2', Aliases=['HRBL', 'RABR'], description='ArfGAP with FG repeats 2', other_designations='arf-GAP domain and FG repeat-containing protein 2|HIV-1 Rev-binding protein-like protein|Rev/Rex activation domain binding protein-related|arf-GAP domain and FG repeats-containing protein 2|nucleoporin|rev/Rex activation domain-binding protein related', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100539203, end_position_on_the_genomic_accession=100568220, orientation='plus', exon_count=14, OMIM=[604019], no_hdr0=''),
    3269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3269, CurrentID=0, Status='live', Symbol='HRH1', Aliases=['H1-R', 'H1R', 'HH1R', 'hisH1'], description='histamine receptor H1', other_designations='histamine H1 receptor|histamine receptor, subclass H1', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=11137238, end_position_on_the_genomic_accession=11263557, orientation='plus', exon_count=6, OMIM=[600167], no_hdr0=''),
    3270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3270, CurrentID=0, Status='live', Symbol='HRC', Aliases=[], description='histidine rich calcium binding protein', other_designations='sarcoplasmic reticulum histidine-rich calcium-binding protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49151198, end_position_on_the_genomic_accession=49155464, orientation='minus', exon_count=6, OMIM=[142705], no_hdr0=''),
    3273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3273, CurrentID=0, Status='live', Symbol='HRG', Aliases=['HPRGP', 'THPH11', 'HRG'], description='histidine rich glycoprotein', other_designations='histidine-rich glycoprotein|histidine-proline-rich glycoprotein', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186665975, end_position_on_the_genomic_accession=186678235, orientation='plus', exon_count=7, OMIM=[142640], no_hdr0=''),
    3274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3274, CurrentID=0, Status='live', Symbol='HRH2', Aliases=['H2R', 'HH2R'], description='histamine receptor H2', other_designations='histamine H2 receptor|gastric receptor 1|gastric receptor I', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=175657762, end_position_on_the_genomic_accession=175710756, orientation='plus', exon_count=8, OMIM=[142703], no_hdr0=''),
    3275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3275, CurrentID=0, Status='live', Symbol='PRMT2', Aliases=['HRMT1L1'], description='protein arginine methyltransferase 2', other_designations='protein arginine N-methyltransferase 2|HMT1 (hnRNP methyltransferase, S. cerevisiae)-like 1|HMT1 hnRNP methyltransferase-like 1|PRMT2 alpha|PRMT2 beta|PRMT2 gamma|histone-arginine N-methyltransferase PRMT2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46635156, end_position_on_the_genomic_accession=46665685, orientation='plus', exon_count=13, OMIM=[601961], no_hdr0=''),
    3276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3276, CurrentID=0, Status='live', Symbol='PRMT1', Aliases=['ANM1', 'HCP1', 'HRMT1L2', 'IR1B4'], description='protein arginine methyltransferase 1', other_designations='protein arginine N-methyltransferase 1|HMT1 (hnRNP methyltransferase, S. cerevisiae)-like 2|heterogeneous nuclear ribonucleoprotein methyltransferase 1-like 2|histone-arginine N-methyltransferase PRMT1|interferon receptor 1-bound protein 4', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49676166, end_position_on_the_genomic_accession=49688447, orientation='plus', exon_count=13, OMIM=[602950], no_hdr0=''),
    3280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3280, CurrentID=0, Status='live', Symbol='HES1', Aliases=['HES-1', 'HHL', 'HRY', 'bHLHb39'], description='hes family bHLH transcription factor 1', other_designations='transcription factor HES-1|class B basic helix-loop-helix protein 39|hairy homolog|hairy-like protein', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194136148, end_position_on_the_genomic_accession=194138732, orientation='plus', exon_count=4, OMIM=[139605], no_hdr0=''),
    3281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3281, CurrentID=0, Status='live', Symbol='HSBP1', Aliases=['NPC-A-13'], description='heat shock factor binding protein 1', other_designations='heat shock factor-binding protein 1|nasopharyngeal carcinoma-associated antigen 13', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=83807978, end_position_on_the_genomic_accession=83819737, orientation='plus', exon_count=4, OMIM=[604553], no_hdr0=''),
    3283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3283, CurrentID=0, Status='live', Symbol='HSD3B1', Aliases=['3BETAHSD', 'HSD3B', 'HSDB3', 'HSDB3A', 'SDR11E1'], description='hydroxy-delta-5-steroid dehydrogenase, 3 beta- and steroid delta-isomerase 1', other_designations='3 beta-hydroxysteroid dehydrogenase/Delta 5-->4-isomerase type 1|3 beta-hydroxysteroid dehydrogenase/Delta 5-->4-isomerase type I|3-beta-HSD I|3-beta-hydroxy-5-ene steroid dehydrogenase|3-beta-hydroxy-Delta(5)-steroid dehydrogenase|3-beta-hydroxysteroid 3-dehydrogenase|delta-5-3-ketosteroid isomerase|dihydrotestosterone oxidoreductase|progesterone reductase|short chain dehydrogenase/reductase family 11E, member 1|steroid Delta-isomerase|trophoblast antigen FDO161G', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119507203, end_position_on_the_genomic_accession=119515058, orientation='plus', exon_count=4, OMIM=[109715], no_hdr0=''),
    3284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3284, CurrentID=0, Status='live', Symbol='HSD3B2', Aliases=['HSD3B', 'HSDB', 'SDR11E2'], description='hydroxy-delta-5-steroid dehydrogenase, 3 beta- and steroid delta-isomerase 2', other_designations='3 beta-hydroxysteroid dehydrogenase/Delta 5-->4-isomerase type 2|3 beta-HSD type II|3 beta-hydroxysteroid dehydrogenase type II, delta 5-delta 4-isomerase type II, 3 beta-HSD type II|3 beta-hydroxysteroid dehydrogenase/Delta 5-->4-isomerase type II|3-beta-HSD II|3-beta-HSD adrenal and gonadal type|3-beta-hydroxy-5-ene steroid dehydrogenase|3-beta-hydroxy-Delta(5)-steroid dehydrogenase|delta 5-delta 4-isomerase type II|progesterone reductase|short chain dehydrogenase/reductase family 11E, member 2', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119414931, end_position_on_the_genomic_accession=119423034, orientation='plus', exon_count=5, OMIM=[613890], no_hdr0=''),
    3290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3290, CurrentID=0, Status='live', Symbol='HSD11B1', Aliases=['11-DH', '11-beta-HSD1', 'CORTRD2', 'HDL', 'HSD11', 'HSD11B', 'HSD11L', 'SDR26C1'], description='hydroxysteroid 11-beta dehydrogenase 1', other_designations='corticosteroid 11-beta-dehydrogenase isozyme 1|short chain dehydrogenase/reductase family 26C member 1', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209686179, end_position_on_the_genomic_accession=209734929, orientation='plus', exon_count=7, OMIM=[600713], no_hdr0=''),
    3291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3291, CurrentID=0, Status='live', Symbol='HSD11B2', Aliases=['AME', 'AME1', 'HSD11K', 'HSD2', 'SDR9C3'], description='hydroxysteroid 11-beta dehydrogenase 2', other_designations='corticosteroid 11-beta-dehydrogenase isozyme 2|-HSD11 type II|11-DH2|11-HSD type II|11-beta-HSD type II|11-beta-HSD2|11-beta-hydroxysteroid dehydrogenase type 2|11-beta-hydroxysteroid dehydrogenase type II|NAD-dependent 11-beta-hydroxysteroid dehydrogenase|short chain dehydrogenase/reductase family 9C member 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67431121, end_position_on_the_genomic_accession=67437553, orientation='plus', exon_count=5, OMIM=[614232], no_hdr0=''),
    3292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3292, CurrentID=0, Status='live', Symbol='HSD17B1', Aliases=['17-beta-HSD', '20-alpha-HSD', 'E2DH', 'EDH17B2', 'EDHB17', 'HSD17', 'SDR28C1'], description='hydroxysteroid 17-beta dehydrogenase 1', other_designations='17-beta-hydroxysteroid dehydrogenase type 1|17-beta-HSD 1|20 alpha-hydroxysteroid dehydrogenase|estradiol 17-beta-dehydrogenase 1|placental 17-beta-hydroxysteroid dehydrogenase|short chain dehydrogenase/reductase family 28C member 1|short chain dehydrogenase/reductase family 28CE, member 1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42552923, end_position_on_the_genomic_accession=42555214, orientation='plus', exon_count=6, OMIM=[109684], no_hdr0=''),
    3293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3293, CurrentID=0, Status='live', Symbol='HSD17B3', Aliases=['EDH17B3', 'SDR12C2'], description='hydroxysteroid 17-beta dehydrogenase 3', other_designations='testosterone 17-beta-dehydrogenase 3|17-beta-HSD 3|17-beta-HSD3|17-beta-hydroxysteroid dehydrogenase type 3|estradiol 17-beta-dehydrogenase 2|hydroxysteroid dehydrogenase 3|short chain dehydrogenase/reductase family 12C member 2|testicular 17-beta-hydroxysteroid dehydrogenase', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96235306, end_position_on_the_genomic_accession=96313987, orientation='minus', exon_count=16, OMIM=[605573], no_hdr0=''),
    3294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3294, CurrentID=0, Status='live', Symbol='HSD17B2', Aliases=['EDH17B2', 'HSD17', 'SDR9C2'], description='hydroxysteroid 17-beta dehydrogenase 2', other_designations='17-beta-hydroxysteroid dehydrogenase type 2|17-beta-HSD 2|20 alpha-hydroxysteroid dehydrogenase|20-alpha-HSD|E2DH|estradiol 17-beta-dehydrogenase 2|microsomal 17-beta-hydroxysteroid dehydrogenase|short chain dehydrogenase/reductase family 9C member 2|testosterone 17-beta-dehydrogenase', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=82035253, end_position_on_the_genomic_accession=82098534, orientation='plus', exon_count=6, OMIM=[109685], no_hdr0=''),
    3295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3295, CurrentID=0, Status='live', Symbol='HSD17B4', Aliases=['DBP', 'MFE-2', 'MFP-2', 'MPF-2', 'PRLTS1', 'SDR8C1'], description='hydroxysteroid 17-beta dehydrogenase 4', other_designations='peroxisomal multifunctional enzyme type 2|17-beta-HSD 4|17-beta-HSD IV|17-beta-hydroxysteroid dehydrogenase 4|17beta-estradiol dehydrogenase type IV|3-alpha,7-alpha,12-alpha-trihydroxy-5-beta-cholest-24-enoyl-CoA hydratase|D-3-hydroxyacyl-CoA dehydratase|D-bifunctional protein, peroxisomal|beta-hydroxyacyl dehydrogenase|beta-keto-reductase|epididymis secretory sperm binding protein|hydroxysteroid dehydrogenase 4|multifunctional protein 2|peroxisomal multifunctional protein 2|short chain dehydrogenase/reductase family 8C member 1', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=119452497, end_position_on_the_genomic_accession=119542332, orientation='plus', exon_count=27, OMIM=[601860], no_hdr0=''),
    3297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3297, CurrentID=0, Status='live', Symbol='HSF1', Aliases=['HSTF1'], description='heat shock transcription factor 1', other_designations='heat shock factor protein 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144291603, end_position_on_the_genomic_accession=144314720, orientation='plus', exon_count=14, OMIM=[140580], no_hdr0=''),
    3298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3298, CurrentID=0, Status='live', Symbol='HSF2', Aliases=['HSF 2', 'HSTF 2'], description='heat shock transcription factor 2', other_designations='heat shock factor protein 2', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122399551, end_position_on_the_genomic_accession=122433119, orientation='plus', exon_count=13, OMIM=[140581], no_hdr0=''),
    3299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3299, CurrentID=0, Status='live', Symbol='HSF4', Aliases=['CTM', 'CTRCT5'], description='heat shock transcription factor 4', other_designations='heat shock factor protein 4|HSF 4|HSTF 4|hHSF4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67163761, end_position_on_the_genomic_accession=67169941, orientation='plus', exon_count=15, OMIM=[602438], no_hdr0=''),
    3300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3300, CurrentID=0, Status='live', Symbol='DNAJB2', Aliases=['CMT2T', 'DSMA5', 'HSJ-1', 'HSJ1', 'HSPF3'], description='DnaJ heat shock protein family (Hsp40) member B2', other_designations='dnaJ homolog subfamily B member 2|DnaJ (Hsp40) homolog, subfamily B, member 2|dnaJ protein homolog 1|heat shock 40 kDa protein 3|heat shock protein J1|heat shock protein, neuronal DNAJ-like 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219279366, end_position_on_the_genomic_accession=219286895, orientation='plus', exon_count=9, OMIM=[604139], no_hdr0=''),
    3301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3301, CurrentID=0, Status='live', Symbol='DNAJA1', Aliases=['DJ-2', 'DjA1', 'HDJ2', 'HSDJ', 'HSJ-2', 'HSJ2', 'HSPF4', 'NEDD7', 'hDJ-2'], description='DnaJ heat shock protein family (Hsp40) member A1', other_designations='dnaJ homolog subfamily A member 1|DnaJ (Hsp40) homolog, subfamily A, member 1|dnaJ protein homolog 2|heat shock 40 kDa protein 4|heat shock protein J2|heat shock protein, DNAJ-like 2|human DnaJ protein 2|neural precursor cell expressed, developmentally down-regulated 7', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33025273, end_position_on_the_genomic_accession=33039907, orientation='plus', exon_count=9, OMIM=[602837], no_hdr0=''),
    3303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3303, CurrentID=0, Status='live', Symbol='HSPA1A', Aliases=['HEL-S-103', 'HSP70-1', 'HSP70-1A', 'HSP70-2', 'HSP70.1', 'HSP70.2', 'HSP70I', 'HSP72', 'HSPA1'], description='heat shock protein family A (Hsp70) member 1A', other_designations='heat shock 70 kDa protein 1A|HSP70-1/HSP70-2|HSP70.1/HSP70.2|Heat shock 70 kDa protein 1B|Heat shock 70 kDa protein 2|dnaK-type molecular chaperone HSP70-1|epididymis secretory protein Li 103|epididymis secretory sperm binding protein|heat shock 70 kDa protein 1|heat shock 70 kDa protein 1/2|heat shock 70 kDa protein 1A/1B|heat shock 70kD protein 1A|heat shock 70kDa protein 1A|heat shock-induced protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31815543, end_position_on_the_genomic_accession=31817942, orientation='plus', exon_count=1, OMIM=[140550], no_hdr0=''),
    3304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3304, CurrentID=0, Status='live', Symbol='HSPA1B', Aliases=['HSP70-1', 'HSP70-1B', 'HSP70-2', 'HSP70.1', 'HSP70.2', 'HSP72', 'HSPA1', 'HSX70'], description='heat shock protein family A (Hsp70) member 1B', other_designations='heat shock 70 kDa protein 1B|HSP70-1/HSP70-2|HSP70.1/HSP70.2|Heat shock 70 kDa protein 1|Heat shock 70 kDa protein 1A|heat shock 70 kDa protein 1/2|heat shock 70 kDa protein 1A/1B|heat shock 70 kDa protein 2|heat shock 70kD protein 1B|heat shock 70kDa protein 1B', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31827738, end_position_on_the_genomic_accession=31830254, orientation='plus', exon_count=1, OMIM=[603012], no_hdr0=''),
    3305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3305, CurrentID=0, Status='live', Symbol='HSPA1L', Aliases=['HSP70-1L', 'HSP70-HOM', 'HSP70T', 'hum70t'], description='heat shock protein family A (Hsp70) member 1 like', other_designations='heat shock 70 kDa protein 1-like|epididymis secretory sperm binding protein|heat shock 10kDa protein 1-like|heat shock 70 kDa protein 1-Hom|heat shock 70 kDa protein 1L|heat shock 70kD protein-like 1|heat shock 70kDa protein 1-like', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31809619, end_position_on_the_genomic_accession=31815283, orientation='minus', exon_count=2, OMIM=[140559], no_hdr0=''),
    3306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3306, CurrentID=0, Status='live', Symbol='HSPA2', Aliases=['HSP70-2', 'HSP70-3'], description='heat shock protein family A (Hsp70) member 2', other_designations='heat shock-related 70 kDa protein 2|epididymis secretory sperm binding protein|heat shock 70kD protein 2|heat shock 70kDa protein 2', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64535905, end_position_on_the_genomic_accession=64543237, orientation='plus', exon_count=2, OMIM=[140560], no_hdr0=''),
    3308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3308, CurrentID=0, Status='live', Symbol='HSPA4', Aliases=['APG-2', 'HEL-S-5a', 'HS24/P52', 'HSPH2', 'RY', 'hsp70', 'hsp70RY'], description='heat shock protein family A (Hsp70) member 4', other_designations='heat shock 70 kDa protein 4|epididymis secretory sperm binding protein Li 5a|heat shock 70-related protein APG-2|heat shock 70kD protein 4|heat shock protein, 110 kDa|hsp70 RY', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=133052013, end_position_on_the_genomic_accession=133106449, orientation='plus', exon_count=19, OMIM=[601113], no_hdr0=''),
    3309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3309, CurrentID=0, Status='live', Symbol='HSPA5', Aliases=['BIP', 'GRP78', 'HEL-S-89n'], description='heat shock protein family A (Hsp70) member 5', other_designations='endoplasmic reticulum chaperone BiP|78 kDa glucose-regulated protein|HSP70 family protein 5|binding-immunoglobulin protein|endoplasmic reticulum lumenal Ca(2+)-binding protein grp78|epididymis secretory sperm binding protein Li 89n|glucose-regulated protein, 78kDa|heat shock 70kDa protein 5 (glucose-regulated protein, 78kDa)|heat shock protein 70 family protein 5|heat shock protein family A member 5|immunoglobulin heavy chain-binding protein', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125234853, end_position_on_the_genomic_accession=125241343, orientation='minus', exon_count=8, OMIM=[138120], no_hdr0=''),
    3310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3310, CurrentID=0, Status='live', Symbol='HSPA6', Aliases=["HSP70B'"], description='heat shock protein family A (Hsp70) member 6', other_designations="heat shock 70 kDa protein 6|epididymis secretory sperm binding protein|heat shock 70 kDa protein B'|heat shock 70kD protein 6 (HSP70B')|heat shock 70kDa protein 6 (HSP70B')", map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161524540, end_position_on_the_genomic_accession=161526894, orientation='plus', exon_count=1, OMIM=[140555], no_hdr0=''),
    3312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3312, CurrentID=0, Status='live', Symbol='HSPA8', Aliases=['HEL-33', 'HEL-S-72p', 'HSC54', 'HSC70', 'HSC71', 'HSP71', 'HSP73', 'HSPA10', 'LAP-1', 'LAP1', 'NIP71'], description='heat shock protein family A (Hsp70) member 8', other_designations='heat shock cognate 71 kDa protein|LPS-associated protein 1|N-myristoyltransferase inhibitor protein 71|constitutive heat shock protein 70|epididymis luminal protein 33|epididymis secretory sperm binding protein Li 72p|heat shock 70kDa protein 8|heat shock 70kd protein 10|heat shock cognate protein 54|lipopolysaccharide-associated protein 1', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123057489, end_position_on_the_genomic_accession=123062366, orientation='minus', exon_count=10, OMIM=[600816], no_hdr0=''),
    3313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3313, CurrentID=0, Status='live', Symbol='HSPA9', Aliases=['CRP40', 'CSA', 'EVPLS', 'GRP-75', 'GRP75', 'HEL-S-124mB', 'MOT', 'MOT2', 'MTHSP75', 'PBP74', 'SAAN', 'SIDBA4', 'HSPA9'], description='heat shock protein family A (Hsp70) member 9', other_designations='stress-70 protein, mitochondrial|75 kDa glucose-regulated protein|catecholamine-regulated protein 40|epididymis secretory sperm binding protein Li 124m|heat shock 70kD protein 9B|heat shock 70kDa protein 9 (mortalin)|mortalin, perinuclear|mortalin-2|mortalin2|p66-mortalin|peptide-binding protein 74', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138553756, end_position_on_the_genomic_accession=138575401, orientation='minus', exon_count=17, OMIM=[600548], no_hdr0=''),
    3315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3315, CurrentID=0, Status='live', Symbol='HSPB1', Aliases=['CMT2F', 'HEL-S-102', 'HMN2B', 'HS.76067', 'HSP27', 'HSP28', 'Hsp25', 'SRP27'], description='heat shock protein family B (small) member 1', other_designations='heat shock protein beta-1|28 kDa heat shock protein|epididymis secretory protein Li 102|estrogen-regulated 24 kDa protein|heat shock 27 kDa protein|heat shock 27kD protein 1|heat shock 27kDa protein 1|putative heat shock protein family B member 1 isoform|stress-responsive protein 27', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76302673, end_position_on_the_genomic_accession=76304292, orientation='plus', exon_count=3, OMIM=[602195], no_hdr0=''),
    3316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3316, CurrentID=0, Status='live', Symbol='HSPB2', Aliases=['HSP27', 'Hs.78846', 'LOH11CR1K', 'MKBP'], description='heat shock protein family B (small) member 2', other_designations='heat shock protein beta-2|DMPK-binding protein|heat shock 27kDa protein 2|heat-shock protein beta-2', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111912734, end_position_on_the_genomic_accession=111914093, orientation='plus', exon_count=2, OMIM=[602179], no_hdr0=''),
    3320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3320, CurrentID=0, Status='live', Symbol='HSP90AA1', Aliases=['EL52', 'HEL-S-65p', 'HSP86', 'HSP89A', 'HSP90A', 'HSP90N', 'HSPC1', 'HSPCA', 'HSPCAL1', 'HSPCAL4', 'HSPN', 'Hsp103', 'Hsp89', 'Hsp90', 'LAP-2', 'LAP2'], description='heat shock protein 90 alpha family class A member 1', other_designations='heat shock protein HSP 90-alpha|HSP 86|LPS-associated protein 2|epididymis luminal secretory protein 52|epididymis secretory sperm binding protein Li 65p|heat shock 86 kDa|heat shock 90kD protein 1, alpha|heat shock 90kD protein 1, alpha-like 4|heat shock 90kD protein, alpha-like 4|heat shock 90kDa protein 1, alpha|heat shock protein 90kDa alpha (cytosolic), class A member 1|heat shock protein 90kDa alpha family class A member 1|lipopolysaccharide-associated protein 2|renal carcinoma antigen NY-REN-38', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102080742, end_position_on_the_genomic_accession=102139749, orientation='minus', exon_count=13, OMIM=[140571], no_hdr0=''),
    3321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3321, CurrentID=0, Status='live', Symbol='IGSF3', Aliases=['EWI-3', 'LCDD', 'V8'], description='immunoglobulin superfamily member 3', other_designations='immunoglobulin superfamily member 3|glu-Trp-Ile EWI motif-containing protein 3|immunoglobin superfamily, member 3', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116574398, end_position_on_the_genomic_accession=116667755, orientation='minus', exon_count=15, OMIM=[603491], no_hdr0=''),
    3326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3326, CurrentID=0, Status='live', Symbol='HSP90AB1', Aliases=['D6S182', 'HSP84', 'HSP90B', 'HSPC2', 'HSPCB'], description='heat shock protein 90 alpha family class B member 1', other_designations='heat shock protein HSP 90-beta|HSP90-beta|heat shock 84 kDa|heat shock 90kD protein 1, beta|heat shock protein 90 kDa|heat shock protein 90kDa alpha (cytosolic), class B member 1|heat shock protein 90kDa alpha family class B member 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44246194, end_position_on_the_genomic_accession=44253883, orientation='plus', exon_count=14, OMIM=[140572], no_hdr0=''),
    3329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3329, CurrentID=0, Status='live', Symbol='HSPD1', Aliases=['CPN60', 'GROEL', 'HLD4', 'HSP-60', 'HSP60', 'HSP65', 'HuCHA60', 'SPG13'], description='heat shock protein family D (Hsp60) member 1', other_designations='60 kDa heat shock protein, mitochondrial|60 kDa chaperonin|P60 lymphocyte protein|chaperonin 60|epididymis secretory sperm binding protein|heat shock 60kDa protein 1 (chaperonin)|heat shock protein 65|mitochondrial matrix protein P1|short heat shock protein 60 Hsp60s1', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197486584, end_position_on_the_genomic_accession=197500274, orientation='minus', exon_count=13, OMIM=[118190], no_hdr0=''),
    3336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3336, CurrentID=0, Status='live', Symbol='HSPE1', Aliases=['CPN10', 'EPF', 'GROES', 'HSP10'], description='heat shock protein family E (Hsp10) member 1', other_designations='10 kDa heat shock protein, mitochondrial|10 kDa chaperonin|chaperonin 10|early-pregnancy factor|epididymis secretory sperm binding protein|heat shock 10kD protein 1 (chaperonin 10)|heat shock 10kDa protein 1', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197500379, end_position_on_the_genomic_accession=197503449, orientation='plus', exon_count=4, OMIM=[600141], no_hdr0=''),
    3337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3337, CurrentID=0, Status='live', Symbol='DNAJB1', Aliases=['HSPF1', 'Hdj1', 'Hsp40', 'RSPH16B', 'Sis1'], description='DnaJ heat shock protein family (Hsp40) member B1', other_designations='dnaJ homolog subfamily B member 1|DnaJ (Hsp40) homolog, subfamily B, member 1|dnaJ protein homolog 1|heat shock 40 kDa protein 1|human DnaJ protein 1|radial spoke 16 homolog B', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14514769, end_position_on_the_genomic_accession=14530597, orientation='minus', exon_count=7, OMIM=[604572], no_hdr0=''),
    3338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3338, CurrentID=0, Status='live', Symbol='DNAJC4', Aliases=['DANJC4', 'HSPF2', 'MCG18'], description='DnaJ heat shock protein family (Hsp40) member C4', other_designations='dnaJ homolog subfamily C member 4|DnaJ (Hsp40) homolog, subfamily C, member 4|dnaJ-like protein HSPF2|heat shock 40kD protein 2|multiple endocrine neoplasia type 1 candidate protein number 18', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64230432, end_position_on_the_genomic_accession=64234281, orientation='plus', exon_count=5, OMIM=[604189], no_hdr0=''),
    3339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3339, CurrentID=0, Status='live', Symbol='HSPG2', Aliases=['HSPG', 'PLC', 'PRCAN', 'SJA', 'SJS', 'SJS1'], description='heparan sulfate proteoglycan 2', other_designations='basement membrane-specific heparan sulfate proteoglycan core protein|endorepellin (domain V region)|perlecan proteoglycan', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21822244, end_position_on_the_genomic_accession=21937310, orientation='minus', exon_count=103, OMIM=[142461], no_hdr0=''),
    3340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3340, CurrentID=0, Status='live', Symbol='NDST1', Aliases=['HSST', 'MRT46', 'NST1'], description='N-deacetylase and N-sulfotransferase 1', other_designations='bifunctional heparan sulfate N-deacetylase/N-sulfotransferase 1|HSNST 1|N-Deacetylase-N-sulfotransferase 1|N-HSST 1|N-deacetylase/N-sulfotransferase (heparan glucosaminyl) 1|N-deacetylase/N-sulfotransferase 1|N-heparan sulfate sulfotransferase 1|NDST-1|[Heparan sulfate]-glucosamine N-sulfotransferase 1|glucosaminyl N-deacetylase/N-sulfotransferase 1|heparan sulfate-N-deacetylase/N-sulfotransferase|heparan sulfate/heparin GlcNAc N-deacetylase/GlcN N-sulfotransferase 1', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150497779, end_position_on_the_genomic_accession=150558211, orientation='plus', exon_count=16, OMIM=[600853], no_hdr0=''),
    3344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3344, CurrentID=0, Status='live', Symbol='FOXN2', Aliases=['HTLF'], description='forkhead box N2', other_designations='forkhead box protein N2|human T-cell leukemia virus enhancer factor', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48314299, end_position_on_the_genomic_accession=48379295, orientation='plus', exon_count=11, OMIM=[143089], no_hdr0=''),
    3346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3346, CurrentID=0, Status='live', Symbol='HTN1', Aliases=['HIS1'], description='histatin 1', other_designations='histatin-1|PPB|histidine-rich protein 1|post-PB protein', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70050438, end_position_on_the_genomic_accession=70058848, orientation='plus', exon_count=6, OMIM=[142701], no_hdr0=''),
    3347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3347, CurrentID=0, Status='live', Symbol='HTN3', Aliases=['HIS2', 'HTN2', 'HTN5', 'PB'], description='histatin 3', other_designations='histatin-3|basic histidine-rich protein|histatin-4|histatin-5|histatin-6|histatin-7|histatin-8|histatin-9|histidine-rich protein 3', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70028459, end_position_on_the_genomic_accession=70036538, orientation='plus', exon_count=6, OMIM=[142702], no_hdr0=''),
    3350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3350, CurrentID=0, Status='live', Symbol='HTR1A', Aliases=['5-HT-1A', '5-HT1A', '5HT1a', 'ADRB2RL1', 'ADRBRL1', 'G-21', 'PFMCD'], description='5-hydroxytryptamine receptor 1A', other_designations='5-hydroxytryptamine receptor 1A|5-HT1a receptor|5-hydroxytryptamine (serotonin) receptor 1A, G protein-coupled|guanine nucleotide-binding regulatory protein-coupled receptor', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=63957874, end_position_on_the_genomic_accession=63962445, orientation='minus', exon_count=1, OMIM=[109760], no_hdr0=''),
    3351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3351, CurrentID=0, Status='live', Symbol='HTR1B', Aliases=['5-HT-1B', '5-HT-1D-beta', '5-HT1B', '5-HT1DB', 'HTR1D2', 'HTR1DB', 'S12'], description='5-hydroxytryptamine receptor 1B', other_designations='5-hydroxytryptamine receptor 1B|5-hydroxytryptamine (serotonin) receptor 1B, G protein-coupled|serotonin 1D beta receptor|serotonin receptor 1B', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=77460924, end_position_on_the_genomic_accession=77463491, orientation='minus', exon_count=1, OMIM=[182131], no_hdr0=''),
    3352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3352, CurrentID=0, Status='live', Symbol='HTR1D', Aliases=['5-HT1D', 'HT1DAA', 'HTRL', 'RDC4', 'HTR1D'], description='5-hydroxytryptamine receptor 1D', other_designations='5-hydroxytryptamine receptor 1D|5-HT-1D|5-HT-1D-alpha|5-hydroxytryptamine (serotonin) receptor 1D, G protein-coupled|serotonin 1D alpha receptor|serotonin receptor 1D', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23191895, end_position_on_the_genomic_accession=23217502, orientation='minus', exon_count=2, OMIM=[182133], no_hdr0=''),
    3354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3354, CurrentID=0, Status='live', Symbol='HTR1E', Aliases=['5-HT1E'], description='5-hydroxytryptamine receptor 1E', other_designations='5-hydroxytryptamine receptor 1E|5-HT-1E|5-hydroxytryptamine (serotonin) receptor 1E, G protein-coupled|S31|serotonin receptor 1E', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=86936919, end_position_on_the_genomic_accession=87020068, orientation='plus', exon_count=2, OMIM=[182132], no_hdr0=''),
    3355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3355, CurrentID=0, Status='live', Symbol='HTR1F', Aliases=['5-HT-1F', '5-HT1F', '5HT6', 'HTR1EL', 'MR77'], description='5-hydroxytryptamine receptor 1F', other_designations='5-hydroxytryptamine receptor 1F|5-hydroxytryptamine (serotonin) receptor 1F, G protein-coupled|serotonin receptor 1F', map_location='3p11.2-p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=87792706, end_position_on_the_genomic_accession=87994856, orientation='plus', exon_count=6, OMIM=[182134], no_hdr0=''),
    3356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3356, CurrentID=0, Status='live', Symbol='HTR2A', Aliases=['5-HT2A', 'HTR2'], description='5-hydroxytryptamine receptor 2A', other_designations='5-hydroxytryptamine receptor 2A|5-HT2 receptor|5-hydroxytryptamine (serotonin) receptor 2A, G protein-coupled|serotonin 5-HT-2A receptor', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46831546, end_position_on_the_genomic_accession=46898082, orientation='minus', exon_count=5, OMIM=[182135], no_hdr0=''),
    3357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3357, CurrentID=0, Status='live', Symbol='HTR2B', Aliases=['5-HT(2B)', '5-HT-2B', '5-HT2B'], description='5-hydroxytryptamine receptor 2B', other_designations='5-hydroxytryptamine receptor 2B|5-HT 2B receptor|5-hydroxytryptamine (serotonin) receptor 2B, G protein-coupled|5-hydroxytryptamine 2B receptor|5-hydroxytryptamine receptor 2B variant b|serotonin receptor 2B', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231108230, end_position_on_the_genomic_accession=231126172, orientation='minus', exon_count=4, OMIM=[601122], no_hdr0=''),
    3358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3358, CurrentID=0, Status='live', Symbol='HTR2C', Aliases=['5-HT1C', '5-HT2C', '5-HTR2C', '5HTR2C', 'HTR1C'], description='5-hydroxytryptamine receptor 2C', other_designations='5-hydroxytryptamine receptor 2C|5-hydroxytryptamine (serotonin) receptor 2C, G protein-coupled|5-hydroxytryptamine receptor 1C|serotonin 5-HT-1C receptor|serotonin 5-HT-2C receptor', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=114584086, end_position_on_the_genomic_accession=114910061, orientation='plus', exon_count=7, OMIM=[312861], no_hdr0=''),
    3359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3359, CurrentID=0, Status='live', Symbol='HTR3A', Aliases=['5-HT-3', '5-HT3A', '5-HT3R', '5HT3R', 'HTR3'], description='5-hydroxytryptamine receptor 3A', other_designations='5-hydroxytryptamine receptor 3A|5-hydroxytryptamine (serotonin) receptor 3A, ionotropic|5-hydroxytryptamine receptor 3|5HT3 serotonin receptor|serotonin receptor 3A|serotonin-gated ion channel receptor', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113975108, end_position_on_the_genomic_accession=113990313, orientation='plus', exon_count=10, OMIM=[182139], no_hdr0=''),
    3360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3360, CurrentID=0, Status='live', Symbol='HTR4', Aliases=['5-HT4', '5-HT4R'], description='5-hydroxytryptamine receptor 4', other_designations='5-hydroxytryptamine receptor 4|5-hydroxytryptamine (serotonin) receptor 4, G protein-coupled|5-hydroxytryptamine receptor 4 transcript variant b2|5-hydroxytryptamine receptor 4 transcript variant b3|cardiac 5-HT4 receptor', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148451032, end_position_on_the_genomic_accession=148654527, orientation='minus', exon_count=12, OMIM=[602164], no_hdr0=''),
    3361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3361, CurrentID=0, Status='live', Symbol='HTR5A', Aliases=['5-HT5A'], description='5-hydroxytryptamine receptor 5A', other_designations='5-hydroxytryptamine receptor 5A|5-HT-5|5-HT-5A|5-hydroxytryptamine (serotonin) receptor 5A, G protein-coupled', map_location='7q36.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155070324, end_position_on_the_genomic_accession=155087392, orientation='plus', exon_count=2, OMIM=[601305], no_hdr0=''),
    3362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3362, CurrentID=0, Status='live', Symbol='HTR6', Aliases=['5-HT6', '5-HT6R'], description='5-hydroxytryptamine receptor 6', other_designations='5-hydroxytryptamine receptor 6|5-hydroxytryptamine (serotonin) receptor 6, G protein-coupled|serotonin receptor 6', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19664875, end_position_on_the_genomic_accession=19680966, orientation='plus', exon_count=3, OMIM=[601109], no_hdr0=''),
    3363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3363, CurrentID=0, Status='live', Symbol='HTR7', Aliases=['5-HT7'], description='5-hydroxytryptamine receptor 7', other_designations='5-hydroxytryptamine receptor 7|5-HT-7|5-HT-X|5-hydroxytryptamine (serotonin) receptor 7 (adenylate cyclase-coupled)', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=90738693, end_position_on_the_genomic_accession=90858039, orientation='minus', exon_count=5, OMIM=[182137], no_hdr0=''),
    3364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3364, CurrentID=0, Status='live', Symbol='HUS1', Aliases=['hHUS1'], description='HUS1 checkpoint clamp component', other_designations='checkpoint protein HUS1|HUS1 checkpoint homolog|hus1+-like protein', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=47962980, end_position_on_the_genomic_accession=47979619, orientation='minus', exon_count=10, OMIM=[603760], no_hdr0=''),
    3371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3371, CurrentID=0, Status='live', Symbol='TNC', Aliases=['150-225', 'DFNA56', 'GMEM', 'GP', 'HXB', 'JI', 'TN', 'TN-C'], description='tenascin C', other_designations='tenascin|GP 150-225|cytotactin|deafness, autosomal dominant 56|glioma-associated-extracellular matrix antigen|hexabrachion (tenascin)|myotendinous antigen|neuronectin|tenascin-C additional domain 1', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=115019575, end_position_on_the_genomic_accession=115118244, orientation='minus', exon_count=31, OMIM=[187380], no_hdr0=''),
    3373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3373, CurrentID=0, Status='live', Symbol='HYAL1', Aliases=['HYAL-1', 'LUCA1', 'MPS9', 'NAT6'], description='hyaluronidase 1', other_designations='hyaluronidase-1|hyaluronoglucosaminidase 1|luCa-1|lung carcinoma protein 1|plasma hyaluronidase|tumor suppressor LUCA-1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50299889, end_position_on_the_genomic_accession=50312951, orientation='minus', exon_count=6, OMIM=[607071], no_hdr0=''),
    3375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3375, CurrentID=0, Status='live', Symbol='IAPP', Aliases=['DAP', 'IAP'], description='islet amyloid polypeptide', other_designations='islet amyloid polypeptide|Islet amyloid polypeptide (diabetes-associated peptide; amylin)|amylin|diabetes-associated peptide|insulinoma amyloid peptide', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21354959, end_position_on_the_genomic_accession=21379980, orientation='plus', exon_count=4, OMIM=[147940], no_hdr0=''),
    3376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3376, CurrentID=0, Status='live', Symbol='IARS1', Aliases=['GRIDHH', 'IARS', 'ILERS', 'ILRS', 'IRS', 'PRO0785'], description='isoleucyl-tRNA synthetase 1', other_designations='isoleucine--tRNA ligase, cytoplasmic|isoleucine tRNA ligase 1, cytoplasmic', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92210207, end_position_on_the_genomic_accession=92293697, orientation='minus', exon_count=35, OMIM=[600709], no_hdr0=''),
    3381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3381, CurrentID=0, Status='live', Symbol='IBSP', Aliases=['BNSP', 'BSP', 'BSP-II', 'SP-II'], description='integrin binding sialoprotein', other_designations='bone sialoprotein 2|BSP II|bone sialoprotein II|cell-binding sialoprotein', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87799554, end_position_on_the_genomic_accession=87812435, orientation='plus', exon_count=7, OMIM=[147563], no_hdr0=''),
    3382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3382, CurrentID=0, Status='live', Symbol='ICA1', Aliases=['ICA69', 'ICAp69'], description='islet cell autoantigen 1', other_designations='islet cell autoantigen 1|69 kDa islet cell autoantigen|diabetes mellitus type I autoantigen|islet cell autoantigen 1, 69kDa|islet cell autoantigen p69|p69|testicular tissue protein Li 162', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=8113184, end_position_on_the_genomic_accession=8262687, orientation='minus', exon_count=22, OMIM=[147625], no_hdr0=''),
    3383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3383, CurrentID=0, Status='live', Symbol='ICAM1', Aliases=['BB2', 'CD54', 'P3.58'], description='intercellular adhesion molecule 1', other_designations='intercellular adhesion molecule 1|ICAM-1|cell surface glycoprotein P3.58|epididymis secretory sperm binding protein|intercellular adhesion molecule 1 (CD54), human rhinovirus receptor|major group rhinovirus receptor', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10271120, end_position_on_the_genomic_accession=10286615, orientation='plus', exon_count=7, OMIM=[147840], no_hdr0=''),
    3384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3384, CurrentID=0, Status='live', Symbol='ICAM2', Aliases=['CD102'], description='intercellular adhesion molecule 2', other_designations='intercellular adhesion molecule 2|ICAM-2', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64002595, end_position_on_the_genomic_accession=64020633, orientation='minus', exon_count=6, OMIM=[146630], no_hdr0=''),
    3385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3385, CurrentID=0, Status='live', Symbol='ICAM3', Aliases=['CD50', 'CDW50', 'ICAM-R'], description='intercellular adhesion molecule 3', other_designations='intercellular adhesion molecule 3|ICAM-3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10333776, end_position_on_the_genomic_accession=10339624, orientation='minus', exon_count=7, OMIM=[146631], no_hdr0=''),
    3386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3386, CurrentID=0, Status='live', Symbol='ICAM4', Aliases=['CD242', 'LW'], description='intercellular adhesion molecule 4 (Landsteiner-Wiener blood group)', other_designations='intercellular adhesion molecule 4|CD242 antigen|LW antigen a|Landsteiner-Wiener blood group antigen a|Landsteiner-Wiener blood group glycoprotein|intercellular adhesion molecule 4 (LW blood group)', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10286955, end_position_on_the_genomic_accession=10288520, orientation='plus', exon_count=3, OMIM=[614088], no_hdr0=''),
    3394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3394, CurrentID=0, Status='live', Symbol='IRF8', Aliases=['H-ICSBP', 'ICSBP', 'ICSBP1', 'IMD32A', 'IMD32B', 'IRF-8'], description='interferon regulatory factor 8', other_designations='interferon regulatory factor 8|interferon consensus sequence binding protein 1', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85899162, end_position_on_the_genomic_accession=85922609, orientation='plus', exon_count=10, OMIM=[601565], no_hdr0=''),
    3396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3396, CurrentID=0, Status='live', Symbol='MRPL58', Aliases=['DS-1', 'DS1', 'ICT1', 'MRP-L58'], description='mitochondrial ribosomal protein L58', other_designations='peptidyl-tRNA hydrolase ICT1, mitochondrial|39S ribosomal protein L58, mitochondrial|digestion substraction 1|immature colon carcinoma transcript 1 protein|mitochondrial large ribosomal subunit protein ICT1|mitochondrial large ribosomal subunit protein mL62', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75012670, end_position_on_the_genomic_accession=75021261, orientation='plus', exon_count=7, OMIM=[603000], no_hdr0=''),
    3397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3397, CurrentID=0, Status='live', Symbol='ID1', Aliases=['ID', 'bHLHb24'], description='inhibitor of DNA binding 1, HLH protein', other_designations='DNA-binding protein inhibitor ID-1|class B basic helix-loop-helix protein 24|dJ857M17.1.2 (inhibitor of DNA binding 1, dominant negative helix-loop-helix protein)|inhibitor of DNA binding 1, dominant negative helix-loop-helix protein|inhibitor of differentiation 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31605289, end_position_on_the_genomic_accession=31606510, orientation='plus', exon_count=1, OMIM=[600349], no_hdr0=''),
    3398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3398, CurrentID=0, Status='live', Symbol='ID2', Aliases=['GIG8A', 'ID2H', 'bHLHb26', 'ID2'], description='inhibitor of DNA binding 2', other_designations='DNA-binding protein inhibitor ID-2|DNA-binding protein inhibitor ID2|cell growth-inhibiting gene 8|class B basic helix-loop-helix protein 26|helix-loop-helix protein ID2|inhibitor of DNA binding 2, HLH protein|inhibitor of DNA binding 2, dominant negative helix-loop-helix protein|inhibitor of differentiation 2', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=8682056, end_position_on_the_genomic_accession=8684461, orientation='plus', exon_count=3, OMIM=[600386], no_hdr0=''),
    3399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3399, CurrentID=0, Status='live', Symbol='ID3', Aliases=['HEIR-1', 'bHLHb25'], description='inhibitor of DNA binding 3, HLH protein', other_designations='DNA-binding protein inhibitor ID-3|ID-like protein inhibitor HLH 1R21|class B basic helix-loop-helix protein 25|helix-loop-helix protein HEIR-1|inhibitor of DNA binding 3, dominant negative helix-loop-helix protein|inhibitor of differentiation 3', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23557926, end_position_on_the_genomic_accession=23559501, orientation='minus', exon_count=3, OMIM=[600277], no_hdr0=''),
    3400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3400, CurrentID=0, Status='live', Symbol='ID4', Aliases=['IDB4', 'bHLHb27'], description='inhibitor of DNA binding 4, HLH protein', other_designations='DNA-binding protein inhibitor ID-4|class B basic helix-loop-helix protein 27|inhibitor of DNA binding 4, dominant negative helix-loop-helix protein|inhibitor of differentiation 4', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=19837370, end_position_on_the_genomic_accession=19842197, orientation='plus', exon_count=3, OMIM=[600581], no_hdr0=''),
    3416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3416, CurrentID=0, Status='live', Symbol='IDE', Aliases=['INSULYSIN'], description='insulin degrading enzyme', other_designations='insulin-degrading enzyme|Abeta-degrading protease|insulin protease|insulinase', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92451684, end_position_on_the_genomic_accession=92574093, orientation='minus', exon_count=34, OMIM=[146680], no_hdr0=''),
    3417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3417, CurrentID=0, Status='live', Symbol='IDH1', Aliases=['HEL-216', 'HEL-S-26', 'IDCD', 'IDH', 'IDP', 'IDPC', 'PICD'], description='isocitrate dehydrogenase (NADP(+)) 1', other_designations='isocitrate dehydrogenase [NADP] cytoplasmic|NADP(+)-specific ICDH|NADP-dependent isocitrate dehydrogenase, cytosolic|NADP-dependent isocitrate dehydrogenase, peroxisomal|epididymis luminal protein 216|epididymis secretory protein Li 26|epididymis secretory sperm binding protein|isocitrate dehydrogenase (NADP(+)) 1, cytosolic|isocitrate dehydrogenase 1 (NADP+), soluble|oxalosuccinate decarboxylase', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208236227, end_position_on_the_genomic_accession=208255071, orientation='minus', exon_count=12, OMIM=[147700], no_hdr0=''),
    3418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3418, CurrentID=0, Status='live', Symbol='IDH2', Aliases=['D2HGA2', 'ICD-M', 'IDH', 'IDHM', 'IDP', 'IDPM', 'mNADP-IDH'], description='isocitrate dehydrogenase (NADP(+)) 2', other_designations='isocitrate dehydrogenase [NADP], mitochondrial|NADP(+)-specific ICDH|isocitrate dehydrogenase (NADP(+)) 2, mitochondrial|isocitrate dehydrogenase 2 (NADP+), mitochondrial|oxalosuccinate decarboxylase', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90083045, end_position_on_the_genomic_accession=90102468, orientation='minus', exon_count=12, OMIM=[147650], no_hdr0=''),
    3419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3419, CurrentID=0, Status='live', Symbol='IDH3A', Aliases=['RP90'], description='isocitrate dehydrogenase (NAD(+)) 3 catalytic subunit alpha', other_designations='isocitrate dehydrogenase [NAD] subunit alpha, mitochondrial|H-IDH alpha|NAD(+)-specific ICDH subunit alpha|NAD(H)-specific isocitrate dehydrogenase alpha subunit|NAD+-specific ICDH|isocitrate dehydrogenase (NAD(+)) 3 alpha|isocitrate dehydrogenase (NAD+) alpha chain|isocitrate dehydrogenase 3 (NAD(+)) alpha|isocitrate dehydrogenase 3 (NAD+) alpha|isocitric dehydrogenase subunit alpha', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78149362, end_position_on_the_genomic_accession=78171945, orientation='plus', exon_count=12, OMIM=[601149], no_hdr0=''),
    3420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3420, CurrentID=0, Status='live', Symbol='IDH3B', Aliases=['RP46'], description='isocitrate dehydrogenase (NAD(+)) 3 non-catalytic subunit beta', other_designations='isocitrate dehydrogenase [NAD] subunit beta, mitochondrial|NAD(+)-specific ICDH subunit beta|isocitrate dehydrogenase (NAD(+)) 3 beta|isocitrate dehydrogenase 3 (NAD(+)) beta|isocitrate dehydrogenase 3 (NAD+) beta|isocitric dehydrogenase subunit beta', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2658394, end_position_on_the_genomic_accession=2664216, orientation='minus', exon_count=14, OMIM=[604526], no_hdr0=''),
    3421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3421, CurrentID=0, Status='live', Symbol='IDH3G', Aliases=['H-IDHG'], description='isocitrate dehydrogenase (NAD(+)) 3 non-catalytic subunit gamma', other_designations='isocitrate dehydrogenase [NAD] subunit gamma, mitochondrial|IDH-gamma|NAD (H)-specific isocitrate dehydrogenase gamma subunit|NAD(+)-specific ICDH subunit gamma|NAD+-specific ICDH|isocitrate dehydrogenase (NAD(+)) 3 gamma|isocitrate dehydrogenase 3 (NAD(+)) gamma|isocitrate dehydrogenase 3 (NAD+) gamma|isocitrate dehydrogenase 3 gamma|isocitrate dehydrogenase, NAD(+)-specific, mitochondrial, gamma subunit|isocitric dehydrogenase subunit gamma', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153785768, end_position_on_the_genomic_accession=153794375, orientation='minus', exon_count=12, OMIM=[300089], no_hdr0=''),
    3422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3422, CurrentID=0, Status='live', Symbol='IDI1', Aliases=['IPP1', 'IPPI1'], description='isopentenyl-diphosphate delta isomerase 1', other_designations='isopentenyl-diphosphate Delta-isomerase 1|IPP isomerase 1|isopentenyl diphosphate dimethylallyl diphosphate isomerase 1|isopentenyl pyrophosphate isomerase 1', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=1039152, end_position_on_the_genomic_accession=1056704, orientation='minus', exon_count=8, OMIM=[604055], no_hdr0=''),
    3423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3423, CurrentID=0, Status='live', Symbol='IDS', Aliases=['ID2S', 'MPS2', 'SIDS'], description='iduronate 2-sulfatase', other_designations='iduronate 2-sulfatase|alpha-L-iduronate sulfate sulfatase|iduronate 2-sulfatase 14 kDa chain|iduronate 2-sulfatase 42 kDa chain|idursulfase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149476988, end_position_on_the_genomic_accession=149505306, orientation='minus', exon_count=11, OMIM=[300823], no_hdr0=''),
    3425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3425, CurrentID=0, Status='live', Symbol='IDUA', Aliases=['IDA', 'MPS1', 'MPSI'], description='alpha-L-iduronidase', other_designations='alpha-L-iduronidase|iduronidase alpha-L-|mucopolysaccharidosis type I', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=986997, end_position_on_the_genomic_accession=1004564, orientation='plus', exon_count=16, OMIM=[252800], no_hdr0=''),
    3426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3426, CurrentID=0, Status='live', Symbol='CFI', Aliases=['AHUS3', 'ARMD13', 'C3BINA', 'C3b-INA', 'FI', 'IF', 'KAF'], description='complement factor I', other_designations='complement factor I|C3B/C4B inactivator|C3b-inactivator|Konglutinogen-activating factor|complement component I|complement control protein factor I|complement factor I heavy chain|light chain of factor I', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109730982, end_position_on_the_genomic_accession=109802040, orientation='minus', exon_count=17, OMIM=[217030], no_hdr0=''),
    3428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3428, CurrentID=0, Status='live', Symbol='IFI16', Aliases=['IFNGIP1', 'PYHIN2'], description='interferon gamma inducible protein 16', other_designations='gamma-interferon-inducible protein 16|interferon-gamma induced protein IFI 16|interferon-inducible myeloid differentiation transcriptional activator', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158999976, end_position_on_the_genomic_accession=159055151, orientation='plus', exon_count=15, OMIM=[147586], no_hdr0=''),
    3429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3429, CurrentID=0, Status='live', Symbol='IFI27', Aliases=['FAM14D', 'ISG12', 'ISG12A', 'P27'], description='interferon alpha inducible protein 27', other_designations='interferon alpha-inducible protein 27, mitochondrial|2310061N23Rik|ISG12(a)|interferon alpha-induced 11.5 kDa protein|interferon-stimulated gene 12a protein', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94110736, end_position_on_the_genomic_accession=94116690, orientation='plus', exon_count=6, OMIM=[600009], no_hdr0=''),
    3430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3430, CurrentID=0, Status='live', Symbol='IFI35', Aliases=['IFP35'], description='interferon induced protein 35', other_designations='interferon-induced 35 kDa protein|IFP 35|ifi-35', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43006784, end_position_on_the_genomic_accession=43014459, orientation='plus', exon_count=8, OMIM=[600735], no_hdr0=''),
    3431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3431, CurrentID=0, Status='live', Symbol='SP110', Aliases=['IFI41', 'IFI75', 'IPR1', 'VODI'], description='SP110 nuclear body protein', other_designations='sp110 nuclear body protein|interferon-induced protein 41, 30kD|interferon-induced protein 41/75|interferon-induced protein 75, 52kD|phosphoprotein 41|phosphoprotein 75|speckled 110 kDa|transcriptional coactivator Sp110', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230165186, end_position_on_the_genomic_accession=230225729, orientation='minus', exon_count=24, OMIM=[604457], no_hdr0=''),
    3433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3433, CurrentID=0, Status='live', Symbol='IFIT2', Aliases=['G10P2', 'GARG-39', 'IFI-54', 'IFI-54K', 'IFI54', 'IFIT-2', 'ISG-54', 'ISG-54 K', 'ISG-54K', 'ISG54', 'P54', 'cig42'], description='interferon induced protein with tetratricopeptide repeats 2', other_designations='interferon-induced protein with tetratricopeptide repeats 2|Interferon, alpha-inducible protein (MW 54kD)|interferon-induced 54 kDa protein|interferon-induced protein 54', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89302046, end_position_on_the_genomic_accession=89309271, orientation='plus', exon_count=2, OMIM=[147040], no_hdr0=''),
    3434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3434, CurrentID=0, Status='live', Symbol='IFIT1', Aliases=['C56', 'G10P1', 'IFI-56', 'IFI-56K', 'IFI56', 'IFIT-1', 'IFNAI1', 'ISG56', 'P56', 'RNM561'], description='interferon induced protein with tetratricopeptide repeats 1', other_designations='interferon-induced protein with tetratricopeptide repeats 1|interferon, alpha-inducible protein (MW 56kD)|interferon-induced 56 kDa protein|interferon-inducible mRNA 561', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89392623, end_position_on_the_genomic_accession=89406487, orientation='plus', exon_count=4, OMIM=[147690], no_hdr0=''),
    3437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3437, CurrentID=0, Status='live', Symbol='IFIT3', Aliases=['CIG-49', 'GARG-49', 'IFI60', 'IFIT4', 'IRG2', 'ISG60', 'P60', 'RIG-G', 'cig41'], description='interferon induced protein with tetratricopeptide repeats 3', other_designations='interferon-induced protein with tetratricopeptide repeats 3|CIG49|IFI-60K|IFIT-3|IFIT-4|ISG-60|interferon-induced 60 kDa protein|interferon-induced protein with tetratricopeptide repeats 4|retinoic acid-induced gene G protein', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89327997, end_position_on_the_genomic_accession=89340968, orientation='plus', exon_count=4, OMIM=[604650], no_hdr0=''),
    3439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3439, CurrentID=0, Status='live', Symbol='IFNA1', Aliases=['IFL', 'IFN', 'IFN-ALPHA', 'IFN-alphaD3', 'IFNA@', 'leIF D', 'IFNA1'], description='interferon alpha 1', other_designations='interferon alpha-1/13|IFN-alpha-1/13|interferon alpha 1b|interferon alpha-D|interferon-alpha1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21440439, end_position_on_the_genomic_accession=21441316, orientation='plus', exon_count=1, OMIM=[147660], no_hdr0=''),
    3440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3440, CurrentID=0, Status='live', Symbol='IFNA2', Aliases=['IFN-alpha-2', 'IFN-alphaA', 'IFNAB', 'leIF A', 'IFNA2'], description='interferon alpha 2', other_designations='interferon alpha-2|alpha-2a interferon|interferon alpha 2a|interferon alpha 2b|interferon alpha A', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21384255, end_position_on_the_genomic_accession=21385398, orientation='minus', exon_count=1, OMIM=[147562], no_hdr0=''),
    3441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3441, CurrentID=0, Status='live', Symbol='IFNA4', Aliases=['IFN-alpha4a', 'INFA4'], description='interferon alpha 4', other_designations='interferon alpha-4|IFN-alpha-4|interferon alpha-4B|interferon alpha-76|interferon alpha-M1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21186618, end_position_on_the_genomic_accession=21187682, orientation='minus', exon_count=1, OMIM=[147564], no_hdr0=''),
    3442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3442, CurrentID=0, Status='live', Symbol='IFNA5', Aliases=['IFN-alpha-5', 'IFN-alphaG', 'INA5', 'INFA5', 'leIF G'], description='interferon alpha 5', other_designations='interferon alpha-5|interferon alpha-61|interferon alpha-G', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21304326, end_position_on_the_genomic_accession=21305313, orientation='minus', exon_count=1, OMIM=[147565], no_hdr0=''),
    3443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3443, CurrentID=0, Status='live', Symbol='IFNA6', Aliases=['IFN-alphaK'], description='interferon alpha 6', other_designations='interferon alpha-6|IFN-alpha-6|interferon alpha-54|interferon alpha-K|leIF K', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21350318, end_position_on_the_genomic_accession=21350887, orientation='minus', exon_count=1, OMIM=[147566], no_hdr0=''),
    3444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3444, CurrentID=0, Status='live', Symbol='IFNA7', Aliases=['IFN-alphaJ', 'IFNA-J'], description='interferon alpha 7', other_designations='interferon alpha-7|IFN-alpha 7|IFN-alpha-J1|interferon alpha-J|interferon alpha-J1|leIF J', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21201469, end_position_on_the_genomic_accession=21202205, orientation='minus', exon_count=1, OMIM=[147567], no_hdr0=''),
    3445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3445, CurrentID=0, Status='live', Symbol='IFNA8', Aliases=['IFN-alphaB'], description='interferon alpha 8', other_designations="interferon alpha-8|IFN-alpha-8|interferon alpha type 201|interferon alpha-B|interferon alpha-B'|interferon alpha-B2|leIF B", map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21409117, end_position_on_the_genomic_accession=21410185, orientation='plus', exon_count=1, OMIM=[147568], no_hdr0=''),
    3446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3446, CurrentID=0, Status='live', Symbol='IFNA10', Aliases=['IFN-alphaC'], description='interferon alpha 10', other_designations='interferon alpha-10|IFN-alpha-10|interferon alpha-6L|interferon alpha-C|leIF C', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21206181, end_position_on_the_genomic_accession=21207143, orientation='minus', exon_count=1, OMIM=[147577], no_hdr0=''),
    3447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3447, CurrentID=0, Status='live', Symbol='IFNA13', Aliases=[], description='interferon alpha 13', other_designations='interferon alpha-1/13|IFN-alpha-1/13|interferon alpha-D|leIF D', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21367372, end_position_on_the_genomic_accession=21368057, orientation='minus', exon_count=1, OMIM=[147578], no_hdr0=''),
    3448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3448, CurrentID=0, Status='live', Symbol='IFNA14', Aliases=['IFN-alphaH', 'LEIF2H'], description='interferon alpha 14', other_designations='interferon alpha-14|IFN-alpha-14|interferon alpha-H|interferon lambda-2-H|leIF H', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21239002, end_position_on_the_genomic_accession=21240005, orientation='minus', exon_count=1, OMIM=[147579], no_hdr0=''),
    3449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3449, CurrentID=0, Status='live', Symbol='IFNA16', Aliases=['IFN-alpha-16', 'IFN-alphaO'], description='interferon alpha 16', other_designations='interferon alpha-16|IFN-alpha-N-protein|interferon alpha-WA', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21216373, end_position_on_the_genomic_accession=21217311, orientation='minus', exon_count=1, OMIM=[147580], no_hdr0=''),
    3451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3451, CurrentID=0, Status='live', Symbol='IFNA17', Aliases=['IFN-alphaI', 'IFNA', 'INFA', 'LEIF2C1'], description='interferon alpha 17', other_designations="interferon alpha-17|IFN-alpha-17|interferon alpha-88|interferon alpha-I'|interferon alpha-T|interferon alpha-WA|leIF I", map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21227243, end_position_on_the_genomic_accession=21228222, orientation='minus', exon_count=1, OMIM=[147583], no_hdr0=''),
    3452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3452, CurrentID=0, Status='live', Symbol='IFNA21', Aliases=['IFN-alphaI', 'LeIF F', 'leIF-F'], description='interferon alpha 21', other_designations='interferon alpha-21|IFN-alpha-21|interferon alpha-F|leukocyte interferon protein', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21165637, end_position_on_the_genomic_accession=21166660, orientation='minus', exon_count=1, OMIM=[147584], no_hdr0=''),
    3454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3454, CurrentID=0, Status='live', Symbol='IFNAR1', Aliases=['AVP', 'IFN-alpha-REC', 'IFNAR', 'IFNBR', 'IFRC'], description='interferon alpha and beta receptor subunit 1', other_designations='interferon alpha/beta receptor 1|CRF2-1|IFN-R-1|IFN-alpha/beta receptor 1|IFNalpha/beta receptor 1|alpha-type antiviral protein|beta-type antiviral protein|cytokine receptor class-II member 1|cytokine receptor family 2 member 1|interferon (alpha, beta and omega) receptor 1|interferon receptor 1|interferon-alpha/beta receptor alpha chain|interferon-beta receptor 1|type I interferon receptor 1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33324395, end_position_on_the_genomic_accession=33359864, orientation='plus', exon_count=12, OMIM=[107450], no_hdr0=''),
    3455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3455, CurrentID=0, Status='live', Symbol='IFNAR2', Aliases=['IFN-R', 'IFN-alpha-REC', 'IFNABR', 'IFNARB', 'IMD45'], description='interferon alpha and beta receptor subunit 2', other_designations='interferon alpha/beta receptor 2|IFN-R-2|IFN-alpha/beta receptor 2|IFNalpha/beta receptor subunit 2|human interferon alpha/beta receptor|interferon (alpha, beta and omega) receptor 2|interferon alpha binding protein|interferon receptor|interferon-alpha/beta receptor beta chain|type I interferon receptor 2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33229938, end_position_on_the_genomic_accession=33265664, orientation='plus', exon_count=9, OMIM=[602376], no_hdr0=''),
    3456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3456, CurrentID=0, Status='live', Symbol='IFNB1', Aliases=['IFB', 'IFF', 'IFN-beta', 'IFNB'], description='interferon beta 1', other_designations='interferon beta|fibroblast interferon|interferon, beta 1, fibroblast|interferon-beta', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21077104, end_position_on_the_genomic_accession=21077942, orientation='minus', exon_count=1, OMIM=[147640], no_hdr0=''),
    3458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3458, CurrentID=0, Status='live', Symbol='IFNG', Aliases=['IFG', 'IFI', 'IMD69'], description='interferon gamma', other_designations='interferon gamma|IFN-gamma|immune interferon', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68154768, end_position_on_the_genomic_accession=68159740, orientation='minus', exon_count=4, OMIM=[147570], no_hdr0=''),
    3459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3459, CurrentID=0, Status='live', Symbol='IFNGR1', Aliases=['CD119', 'IFNGR', 'IMD27A', 'IMD27B'], description='interferon gamma receptor 1', other_designations='interferon gamma receptor 1|AVP, type 2|CD119 antigen|CDw119|IFN-gamma receptor 1|IFN-gamma-R-alpha|IFN-gamma-R1|antiviral protein, type 2|immune interferon receptor 1|interferon-gamma receptor alpha chain', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=137197484, end_position_on_the_genomic_accession=137220351, orientation='minus', exon_count=9, OMIM=[107470], no_hdr0=''),
    3460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3460, CurrentID=0, Status='live', Symbol='IFNGR2', Aliases=['AF-1', 'IFGR2', 'IFNGT1', 'IMD28'], description='interferon gamma receptor 2', other_designations='interferon gamma receptor 2|IFN-gamma receptor 2|IFN-gamma-R-beta|IFN-gamma-R2|interferon gamma receptor accessory factor-1|interferon gamma receptor beta chain|interferon gamma transducer 1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33402882, end_position_on_the_genomic_accession=33437516, orientation='plus', exon_count=8, OMIM=[147569], no_hdr0=''),
    3467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3467, CurrentID=0, Status='live', Symbol='IFNW1', Aliases=[], description='interferon omega 1', other_designations='interferon omega-1|IFN-omega 1, interferon omega-1|interferon alpha-II-1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21140632, end_position_on_the_genomic_accession=21141832, orientation='minus', exon_count=1, OMIM=[147553], no_hdr0=''),
    3475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3475, CurrentID=0, Status='live', Symbol='IFRD1', Aliases=['PC4', 'TIS7'], description='interferon related developmental regulator 1', other_designations='interferon-related developmental regulator 1|12-O-tetradecanoylphorbol-13-acetate-induced sequence 7|TPA induced sequence 7|nerve growth factor-inducible protein PC4|pheochromocytoma cell-4', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=112423174, end_position_on_the_genomic_accession=112477203, orientation='plus', exon_count=15, OMIM=[603502], no_hdr0=''),
    3476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3476, CurrentID=0, Status='live', Symbol='IGBP1', Aliases=['ALPHA-4', 'IBP1', 'alpha4'], description='immunoglobulin binding protein 1', other_designations='immunoglobulin-binding protein 1|B cell signal transduction molecule alpha 4|CD79a-binding protein 1|bA351K23.1 (immunoglobulin binding protein 1 (CD79A) )|immunoglobulin (CD79A) binding protein 1|protein alpha-4|protein phosphatase 2/4/6 regulatory subunit|protein phosphatase 2A, regulatory subunit alpha-4|renal carcinoma antigen NY-REN-16', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70133447, end_position_on_the_genomic_accession=70166324, orientation='plus', exon_count=7, OMIM=[300139], no_hdr0=''),
    3479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3479, CurrentID=0, Status='live', Symbol='IGF1', Aliases=['IGF', 'IGF-I', 'IGFI', 'MGF'], description='insulin like growth factor 1', other_designations='insulin-like growth factor I|insulin-like growth factor 1 (somatomedin C)|insulin-like growth factor IB|mechano growth factor|somatomedin-C', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102395860, end_position_on_the_genomic_accession=102481839, orientation='minus', exon_count=7, OMIM=[147440], no_hdr0=''),
    3480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3480, CurrentID=0, Status='live', Symbol='IGF1R', Aliases=['CD221', 'IGFIR', 'IGFR', 'JTK13'], description='insulin like growth factor 1 receptor', other_designations='insulin-like growth factor 1 receptor|IGF-I receptor|soluble IGF1R variant 1|soluble IGF1R variant 2', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=98648539, end_position_on_the_genomic_accession=98964530, orientation='plus', exon_count=26, OMIM=[147370], no_hdr0=''),
    3481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3481, CurrentID=0, Status='live', Symbol='IGF2', Aliases=['C11orf43', 'GRDF', 'IGF-II', 'PP9974', 'SRS3'], description='insulin like growth factor 2', other_designations='insulin-like growth factor II|T3M-11-derived growth factor|insulin-like growth factor 2 (somatomedin A)|insulin-like growth factor type 2|preptin', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2129117, end_position_on_the_genomic_accession=2149566, orientation='minus', exon_count=9, OMIM=[147470], no_hdr0=''),
    3482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3482, CurrentID=0, Status='live', Symbol='IGF2R', Aliases=['CD222', 'CI-M6PR', 'CIMPR', 'M6P-R', 'M6P/IGF2R', 'MPR 300', 'MPR1', 'MPR300', 'MPRI'], description='insulin like growth factor 2 receptor', other_designations='cation-independent mannose-6-phosphate receptor|300 kDa mannose 6-phosphate receptor|CI Man-6-P receptor|IGF-II receptor|M6P/IGF2 receptor|insulin-like growth factor II receptor', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159969082, end_position_on_the_genomic_accession=160111504, orientation='plus', exon_count=48, OMIM=[147280], no_hdr0=''),
    3483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3483, CurrentID=0, Status='live', Symbol='IGFALS', Aliases=['ACLSD', 'ALS'], description='insulin like growth factor binding protein acid labile subunit', other_designations='insulin-like growth factor-binding protein complex acid labile subunit|insulin-like growth factor binding protein complex acid labile chain', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1790413, end_position_on_the_genomic_accession=1794908, orientation='minus', exon_count=3, OMIM=[601489], no_hdr0=''),
    3484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3484, CurrentID=0, Status='live', Symbol='IGFBP1', Aliases=['AFBP', 'IBP1', 'IGF-BP25', 'PP12', 'hIGFBP-1'], description='insulin like growth factor binding protein 1', other_designations='insulin-like growth factor-binding protein 1|IBP-1|IGF-binding protein 1|IGFBP-1|alpha-pregnancy-associated endometrial globulin|amniotic fluid binding protein|binding protein-25|binding protein-26|binding protein-28|growth hormone independent-binding protein|placental protein 12', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45888488, end_position_on_the_genomic_accession=45893660, orientation='plus', exon_count=4, OMIM=[146730], no_hdr0=''),
    3485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3485, CurrentID=0, Status='live', Symbol='IGFBP2', Aliases=['IBP2', 'IGF-BP53'], description='insulin like growth factor binding protein 2', other_designations='insulin-like growth factor-binding protein 2|IGF-binding protein 2|insulin-like growth factor binding protein 2, 36kDa', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216632828, end_position_on_the_genomic_accession=216664436, orientation='plus', exon_count=6, OMIM=[146731], no_hdr0=''),
    3486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3486, CurrentID=0, Status='live', Symbol='IGFBP3', Aliases=['BP-53', 'IBP3'], description='insulin like growth factor binding protein 3', other_designations='insulin-like growth factor-binding protein 3|IBP-3|IGF-binding protein 3|IGFBP-3|acid stable subunit of the 140 K IGF complex|binding protein 29|binding protein 53|growth hormone-dependent binding protein', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45912245, end_position_on_the_genomic_accession=45921272, orientation='minus', exon_count=5, OMIM=[146732], no_hdr0=''),
    3487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3487, CurrentID=0, Status='live', Symbol='IGFBP4', Aliases=['BP-4', 'HT29-IGFBP', 'IBP4', 'IGFBP-4'], description='insulin like growth factor binding protein 4', other_designations='insulin-like growth factor-binding protein 4|IBP-4|IGF-binding protein 4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40443450, end_position_on_the_genomic_accession=40457725, orientation='plus', exon_count=4, OMIM=[146733], no_hdr0=''),
    3488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3488, CurrentID=0, Status='live', Symbol='IGFBP5', Aliases=['IBP5'], description='insulin like growth factor binding protein 5', other_designations='insulin-like growth factor-binding protein 5|IBP-5|IGF-binding protein 5|IGFBP-5', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216672105, end_position_on_the_genomic_accession=216695549, orientation='minus', exon_count=4, OMIM=[146734], no_hdr0=''),
    3489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3489, CurrentID=0, Status='live', Symbol='IGFBP6', Aliases=['IBP6'], description='insulin like growth factor binding protein 6', other_designations='insulin-like growth factor-binding protein 6|IBP-6|IGF binding protein 6|IGFBP-6', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53097667, end_position_on_the_genomic_accession=53102340, orientation='plus', exon_count=4, OMIM=[146735], no_hdr0=''),
    3490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3490, CurrentID=0, Status='live', Symbol='IGFBP7', Aliases=['AGM', 'FSTL2', 'IBP-7', 'IGFBP-7', 'IGFBP-7v', 'IGFBPRP1', 'MAC25', 'PSF', 'RAMSVPS', 'TAF'], description='insulin like growth factor binding protein 7', other_designations='insulin-like growth factor-binding protein 7|IGF-binding protein 7|IGFBP-rP1|PGI2-stimulating factor|angiomodulin|prostacyclin-stimulating factor|tumor-derived adhesion factor', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=57030773, end_position_on_the_genomic_accession=57110385, orientation='minus', exon_count=5, OMIM=[602867], no_hdr0=''),
    3491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3491, CurrentID=0, Status='live', Symbol='CCN1', Aliases=['CYR61', 'GIG1', 'IGFBP10'], description='cellular communication network factor 1', other_designations='CCN family member 1|IBP-10|IGF-binding protein 10|IGFBP-10|cysteine rich angiogenic inducer 61|cysteine-rich heparin-binding protein 61|cysteine-rich, anigogenic inducer, 61|insulin-like growth factor-binding protein 10|protein CYR61', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85580761, end_position_on_the_genomic_accession=85583950, orientation='plus', exon_count=5, OMIM=[602369], no_hdr0=''),
    3492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3492, CurrentID=0, Status='live', Symbol='IGH', Aliases=['IGD1.1@', 'IGH@', 'IGHD@', 'IGHDY1', 'IGHJ', 'IGHJ@', 'IGHV', 'IGHV@', 'IGH'], description='immunoglobulin heavy locus', other_designations='D (diversity) region of heavy chains|J (joining) region of heavy chains|immunglobulin heavy chain variable region|immunoglobulin heavy diversity cluster|immunoglobulin heavy diversity group|immunoglobulin heavy diversity locus|immunoglobulin heavy joining cluster|immunoglobulin heavy joining group|immunoglobulin heavy polypeptide, joining region|immunoglobulin heavy variable cluster|immunoglobulin heavy variable group', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105586437, end_position_on_the_genomic_accession=106879844, orientation='minus', exon_count=0, OMIM=[146910, 147010, 147070], no_hdr0=''),
    3508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3508, CurrentID=0, Status='live', Symbol='IGHMBP2', Aliases=['CATF1', 'CMT2S', 'HCSA', 'HMN6', 'SMARD1', 'SMUBP2', 'ZFAND7'], description='immunoglobulin mu DNA binding protein 2', other_designations='DNA-binding protein SMUBP-2|ATP-dependent helicase IGHMBP2|GF-1|cardiac transcription factor 1|glial factor 1|immunoglobulin mu binding protein 2|zinc finger, AN1-type domain 7', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68903855, end_position_on_the_genomic_accession=68940601, orientation='plus', exon_count=19, OMIM=[600502], no_hdr0=''),
    3512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3512, CurrentID=0, Status='live', Symbol='JCHAIN', Aliases=['IGCJ', 'IGJ', 'JCH'], description='joining chain of multimeric IgA and IgM', other_designations='immunoglobulin J chain|IgJ chain|J chain|immunoglobulin J polypeptide, linker protein for immunoglobulin alpha and mu polypeptides', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70655541, end_position_on_the_genomic_accession=70666508, orientation='minus', exon_count=4, OMIM=[147790], no_hdr0=''),
    3516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3516, CurrentID=0, Status='live', Symbol='RBPJ', Aliases=['AOS3', 'CBF-1', 'CBF1', 'IGKJRB', 'IGKJRB1', 'KBF2', 'RBP-J', 'RBP-J kappa', 'RBP-JKK', 'RBPSUH', 'SUH', 'csl', 'RBPJ'], description='recombination signal binding protein for immunoglobulin kappa J region', other_designations='recombining binding protein suppressor of hairless|H-2K binding factor-2|immunoglobulin kappa J region recombination signal binding protein 1|renal carcinoma antigen NY-REN-30|suppressor of hairless homolog', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=26163458, end_position_on_the_genomic_accession=26435131, orientation='plus', exon_count=19, OMIM=[147183], no_hdr0=''),
    3535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3535, CurrentID=0, Status='live', Symbol='IGL', Aliases=['IGL@C6', 'IGL'], description='immunoglobulin lambda locus', other_designations='ig lambda-6 chain C region|immunoglobulin lambda gene cluster', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22026076, end_position_on_the_genomic_accession=22922913, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    3543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3543, CurrentID=0, Status='live', Symbol='IGLL1', Aliases=['14.1', 'AGM2', 'CD179b', 'IGL1', 'IGL5', 'IGLJ14.1', 'IGLL', 'IGO', 'IGVPB', 'VPREB2'], description='immunoglobulin lambda like polypeptide 1', other_designations='immunoglobulin lambda-like polypeptide 1|CD179 antigen-like family member B|CD179b antigen|Pre-B lymphocyte-specific protein-2|ig lambda-5|immunoglobulin omega polypeptide chain|immunoglobulin-related 14.1 protein|immunoglobulin-related protein 14.1|lambda5', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23573125, end_position_on_the_genomic_accession=23580290, orientation='minus', exon_count=3, OMIM=[146770], no_hdr0=''),
    3547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3547, CurrentID=0, Status='live', Symbol='IGSF1', Aliases=['CHTE', 'IGCD1', 'IGDC1', 'INHBP', 'PGSF2', 'p120'], description='immunoglobulin superfamily member 1', other_designations='immunoglobulin superfamily member 1|immunoglobulin-like domain-containing protein 1|inhibin-binding protein|pituitary gland-specific factor 2', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=131273506, end_position_on_the_genomic_accession=131289457, orientation='minus', exon_count=22, OMIM=[300137], no_hdr0=''),
    3549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3549, CurrentID=0, Status='live', Symbol='IHH', Aliases=['BDA1', 'HHG2'], description='Indian hedgehog signaling molecule', other_designations='indian hedgehog protein|Indian hedgehog homolog', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219054424, end_position_on_the_genomic_accession=219060921, orientation='minus', exon_count=3, OMIM=[600726], no_hdr0=''),
    3550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3550, CurrentID=0, Status='live', Symbol='IK', Aliases=['CSA2', 'RED', 'RER'], description='IK cytokine', other_designations='protein Red|IK cytokine, down-regulator of HLA II|IK factor|RD element|chondrosarcoma-associated protein 2|cytokine IK|prer protein', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140647818, end_position_on_the_genomic_accession=140662480, orientation='plus', exon_count=20, OMIM=[600549], no_hdr0=''),
    3551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3551, CurrentID=0, Status='live', Symbol='IKBKB', Aliases=['IKK-beta', 'IKK2', 'IKKB', 'IMD15', 'IMD15A', 'IMD15B', 'NFKBIKB'], description='inhibitor of nuclear factor kappa B kinase subunit beta', other_designations='inhibitor of nuclear factor kappa-B kinase subunit beta|I-kappa-B kinase 2|I-kappa-B-kinase beta|inhibitor of kappa light polypeptide gene enhancer in B-cells, kinase beta|nuclear factor NF-kappa-B inhibitor kinase beta|serine/threonine protein kinase IKBKB', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42270727, end_position_on_the_genomic_accession=42332460, orientation='plus', exon_count=24, OMIM=[603258], no_hdr0=''),
    3552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3552, CurrentID=0, Status='live', Symbol='IL1A', Aliases=['IL-1 alpha', 'IL-1A', 'IL1', 'IL1-ALPHA', 'IL1F1'], description='interleukin 1 alpha', other_designations='interleukin-1 alpha|hematopoietin-1|preinterleukin 1 alpha|pro-interleukin-1-alpha', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112773925, end_position_on_the_genomic_accession=112784493, orientation='minus', exon_count=8, OMIM=[147760], no_hdr0=''),
    3553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3553, CurrentID=0, Status='live', Symbol='IL1B', Aliases=['IL-1', 'IL1-BETA', 'IL1F2', 'IL1beta'], description='interleukin 1 beta', other_designations='interleukin-1 beta|IL-1 beta|catabolin|interleukin 1beta|preinterleukin 1 beta|pro-interleukin-1-beta', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112829751, end_position_on_the_genomic_accession=112836843, orientation='minus', exon_count=7, OMIM=[147720], no_hdr0=''),
    3554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3554, CurrentID=0, Status='live', Symbol='IL1R1', Aliases=['CD121A', 'D2S1473', 'IL-1R-alpha', 'IL1R', 'IL1RA', 'P80'], description='interleukin 1 receptor type 1', other_designations='interleukin-1 receptor type 1|CD121 antigen-like family member A|IL-1R-1|IL-1RT-1|IL-1RT1|interleukin 1 receptor alpha, type I|interleukin-1 receptor alpha|interleukin-1 receptor type I', map_location='2q11.2-q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102069638, end_position_on_the_genomic_accession=102179874, orientation='plus', exon_count=21, OMIM=[147810], no_hdr0=''),
    3556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3556, CurrentID=0, Status='live', Symbol='IL1RAP', Aliases=['C3orf13', 'IL-1RAcP', 'IL1R3'], description='interleukin 1 receptor accessory protein', other_designations='interleukin-1 receptor accessory protein|IL-1 receptor accessory protein|interleukin-1 receptor 3|interleukin-1 receptor accessory protein beta', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=190514085, end_position_on_the_genomic_accession=190659750, orientation='plus', exon_count=16, OMIM=[602626], no_hdr0=''),
    3557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3557, CurrentID=0, Status='live', Symbol='IL1RN', Aliases=['DIRA', 'ICIL-1RA', 'IL-1RN', 'IL-1ra', 'IL-1ra3', 'IL1F3', 'IL1RA', 'IRAP', 'MVCD4'], description='interleukin 1 receptor antagonist', other_designations='interleukin-1 receptor antagonist protein|IL1 inhibitor|intracellular IL-1 receptor antagonist type II|intracellular interleukin-1 receptor antagonist (icIL-1ra)|type II interleukin-1 receptor antagonist', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113099365, end_position_on_the_genomic_accession=113134016, orientation='plus', exon_count=11, OMIM=[147679], no_hdr0=''),
    3558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3558, CurrentID=0, Status='live', Symbol='IL2', Aliases=['IL-2', 'TCGF', 'lymphokine'], description='interleukin 2', other_designations='interleukin-2|T cell growth factor|aldesleukin|involved in regulation of T-cell clonal expansion', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122451470, end_position_on_the_genomic_accession=122456725, orientation='minus', exon_count=4, OMIM=[147680], no_hdr0=''),
    3559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3559, CurrentID=0, Status='live', Symbol='IL2RA', Aliases=['CD25', 'IDDM10', 'IL2R', 'IMD41', 'TCGFR', 'p55'], description='interleukin 2 receptor subunit alpha', other_designations='interleukin-2 receptor subunit alpha|IL-2 receptor subunit alpha|IL-2R subunit alpha|TAC antigen|interleukin 2 receptor, alpha', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=6010689, end_position_on_the_genomic_accession=6062367, orientation='minus', exon_count=8, OMIM=[147730], no_hdr0=''),
    3560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3560, CurrentID=0, Status='live', Symbol='IL2RB', Aliases=['CD122', 'IL15RB', 'IMD63', 'P70-75'], description='interleukin 2 receptor subunit beta', other_designations='interleukin-2 receptor subunit beta|CD122 antigen|IL-2 receptor subunit beta|IL-2R subunit beta|IL-2RB|high affinity IL-2 receptor beta subunit|high affinity IL-2 receptor subunit beta|interleukin 15 receptor, beta|interleukin 2 receptor, beta|interleukin-15 receptor subunit beta|p75', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37125838, end_position_on_the_genomic_accession=37175118, orientation='minus', exon_count=11, OMIM=[146710], no_hdr0=''),
    3561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3561, CurrentID=0, Status='live', Symbol='IL2RG', Aliases=['CD132', 'CIDX', 'IL-2RG', 'IMD4', 'P64', 'SCIDX', 'SCIDX1'], description='interleukin 2 receptor subunit gamma', other_designations='cytokine receptor common subunit gamma|CD132 antigen|IL-2 receptor subunit gamma|IL-2R subunit gamma|common cytokine receptor gamma chain|gammaC|interleukin 2 receptor, gamma|nonfunctional common cytokine receptor gamma chain', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71107404, end_position_on_the_genomic_accession=71111577, orientation='minus', exon_count=8, OMIM=[308380], no_hdr0=''),
    3562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3562, CurrentID=0, Status='live', Symbol='IL3', Aliases=['IL-3', 'MCGF', 'MULTI-CSF'], description='interleukin 3', other_designations='interleukin-3|P-cell stimulating factor|colony-stimulating factor, multiple|hematopoietic growth factor|mast-cell growth factor|multilineage-colony-stimulating factor|multipotential colony-stimulating factor', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132060655, end_position_on_the_genomic_accession=132063204, orientation='plus', exon_count=5, OMIM=[147740], no_hdr0=''),
    3563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3563, CurrentID=0, Status='live', Symbol='IL3RA', Aliases=['CD123', 'IL3RY', 'IL3RX', 'IL3RY', 'hIL-3Ra', 'IL3RA'], description='interleukin 3 receptor subunit alpha', other_designations='interleukin-3 receptor subunit alpha|CD123 antigen|IL-3 receptor subunit alpha|IL-3R subunit alpha|IL-3R-alpha|IL-3RA|interleukin 3 receptor, alpha (low affinity)', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1336574, end_position_on_the_genomic_accession=1382689, orientation='plus', exon_count=12, OMIM=[308385, 430000], no_hdr0=''),
    3565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3565, CurrentID=0, Status='live', Symbol='IL4', Aliases=['BCGF-1', 'BCGF1', 'BSF-1', 'BSF1', 'IL-4'], description='interleukin 4', other_designations='interleukin-4|B cell growth factor 1|B_cell stimulatory factor 1|binetrakin|interleukin 4 variant 2|lymphocyte stimulatory factor 1|pitrakinra', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132673989, end_position_on_the_genomic_accession=132682678, orientation='plus', exon_count=5, OMIM=[147780], no_hdr0=''),
    3566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3566, CurrentID=0, Status='live', Symbol='IL4R', Aliases=['CD124', 'IL-4RAA', 'IL4R'], description='interleukin 4 receptor', other_designations='interleukin-4 receptor subunit alpha|IL-4 receptor subunit alpha|IL4R nirs variant 1|interleukin 13 receptor|interleukin-4 receptor alpha chain', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27313668, end_position_on_the_genomic_accession=27364778, orientation='plus', exon_count=16, OMIM=[147781], no_hdr0=''),
    3567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3567, CurrentID=0, Status='live', Symbol='IL5', Aliases=['EDF', 'IL-5', 'TRF'], description='interleukin 5', other_designations='interleukin-5|B-cell differentiation factor I|T-cell replacing factor|colony-stimulating factor, eosinophil|eosinophil differentiation factor', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132539194, end_position_on_the_genomic_accession=132556864, orientation='minus', exon_count=6, OMIM=[147850], no_hdr0=''),
    3568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3568, CurrentID=0, Status='live', Symbol='IL5RA', Aliases=['CD125', 'CDw125', 'HSIL5R3', 'IL5R'], description='interleukin 5 receptor subunit alpha', other_designations='interleukin-5 receptor subunit alpha|CD125 antigen|IL-5 receptor subunit alpha|IL-5R subunit alpha|interleukin 5 receptor type 3|interleukin 5 receptor, alpha|interleukin-5 receptor alpha chain', map_location='3p26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=3066324, end_position_on_the_genomic_accession=3110414, orientation='minus', exon_count=15, OMIM=[147851], no_hdr0=''),
    3569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3569, CurrentID=0, Status='live', Symbol='IL6', Aliases=['BSF-2', 'BSF2', 'CDF', 'HGF', 'HSF', 'IFN-beta-2', 'IFNB2', 'IL-6'], description='interleukin 6', other_designations='interleukin-6|B-cell differentiation factor|B-cell stimulatory factor 2|CTL differentiation factor|hybridoma growth factor|interferon beta-2|interleukin BSF-2', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=22725889, end_position_on_the_genomic_accession=22732002, orientation='plus', exon_count=6, OMIM=[147620], no_hdr0=''),
    3570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3570, CurrentID=0, Status='live', Symbol='IL6R', Aliases=['CD126', 'HIES5', 'IL-1Ra', 'IL-6R', 'IL-6R-1', 'IL-6RA', 'IL6Q', 'IL6QTLA', 'IL6RQ', 'gp80', 'IL6R'], description='interleukin 6 receptor', other_designations='interleukin-6 receptor subunit alpha|CD126 antigen|IL-6 receptor subunit alpha|membrane glycoprotein 80', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154405343, end_position_on_the_genomic_accession=154469450, orientation='plus', exon_count=14, OMIM=[147880], no_hdr0=''),
    3572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3572, CurrentID=0, Status='live', Symbol='IL6ST', Aliases=['CD130', 'CDW130', 'GP130', 'HIES4', 'IL-6RB', 'sGP130'], description='interleukin 6 cytokine family signal transducer', other_designations='interleukin-6 receptor subunit beta|CD130 antigen|IL-6 receptor subunit beta|IL-6R subunit beta|gp130 of the rheumatoid arthritis antigenic peptide-bearing soluble form|gp130, oncostatin M receptor|interleukin receptor beta chain|interleukin-6 signal transducer|membrane glycoprotein 130|membrane glycoprotein gp130|oncostatin-M receptor subunit alpha', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55935095, end_position_on_the_genomic_accession=55994963, orientation='minus', exon_count=19, OMIM=[600694], no_hdr0=''),
    3574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3574, CurrentID=0, Status='live', Symbol='IL7', Aliases=['IL-7'], description='interleukin 7', other_designations='interleukin-7', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=78675870, end_position_on_the_genomic_accession=78806830, orientation='minus', exon_count=8, OMIM=[146660], no_hdr0=''),
    3575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3575, CurrentID=0, Status='live', Symbol='IL7R', Aliases=['CD127', 'CDW127', 'IL-7R-alphaA', 'ILRA', 'IL7R'], description='interleukin 7 receptor', other_designations='interleukin-7 receptor subunit alpha|CD127 antigen|IL-7 receptor subunit alpha|IL-7R subunit alpha|interleukin 7 receptor alpha chain', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=35856891, end_position_on_the_genomic_accession=35879603, orientation='plus', exon_count=8, OMIM=[146661], no_hdr0=''),
    3576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3576, CurrentID=0, Status='live', Symbol='CXCL8', Aliases=['GCP-1', 'GCP1', 'IL8', 'LECT', 'LUCT', 'LYNAP', 'MDNCF', 'MONAP', 'NAF', 'NAP-1', 'NAP1', 'SCYB8'], description='C-X-C motif chemokine ligand 8', other_designations='interleukin-8|T-cell chemotactic factor|alveolar macrophage chemotactic factor I|beta endothelial cell-derived neutrophil activating peptide|beta-thromboglobulin-like protein|chemokine (C-X-C motif) ligand 8|emoctakin|granulocyte chemotactic protein 1|interleukin 8|lung giant cell carcinoma-derived chemotactic protein|lymphocyte derived neutrophil activating peptide|monocyte-derived neutrophil chemotactic factor|monocyte-derived neutrophil-activating peptide|neutrophil-activating peptide 1|small inducible cytokine subfamily B, member 8|tumor necrosis factor-induced gene 1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73740569, end_position_on_the_genomic_accession=73743716, orientation='plus', exon_count=3, OMIM=[146930], no_hdr0=''),
    3577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3577, CurrentID=0, Status='live', Symbol='CXCR1', Aliases=['C-C', 'C-C-CKR-1', 'CD128', 'CD181', 'CDw128a', 'CKR-1', 'CMKAR1', 'IL8R1', 'IL8RA', 'IL8RBA'], description='C-X-C motif chemokine receptor 1', other_designations='C-X-C chemokine receptor type 1|CXC-R1|CXCR-1|IL-8 receptor type 1|IL-8R A|chemokine (C-X-C motif) receptor 1|high affinity interleukin-8 receptor A|interleukin 8 receptor, alpha|interleukin-8 receptor type 1|interleukin-8 receptor type A', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218162841, end_position_on_the_genomic_accession=218166962, orientation='minus', exon_count=2, OMIM=[146929], no_hdr0=''),
    3578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3578, CurrentID=0, Status='live', Symbol='IL9', Aliases=['HP40', 'IL-9', 'P40'], description='interleukin 9', other_designations='interleukin-9|T-cell growth factor p40|cytokine P40|homolog of mouse T cell and mast cell growth factor 40|p40 T-cell and mast cell growth factor|p40 cytokine', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135892246, end_position_on_the_genomic_accession=135895841, orientation='minus', exon_count=5, OMIM=[146931], no_hdr0=''),
    3579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3579, CurrentID=0, Status='live', Symbol='CXCR2', Aliases=['CD182', 'CDw128b', 'CMKAR2', 'IL8R2', 'IL8RA', 'IL8RB', 'WHIMS2'], description='C-X-C motif chemokine receptor 2', other_designations='C-X-C chemokine receptor type 2|CXC-R2|CXCR-2|CXCR2 gene for IL8 receptor type B|GRO/MGSA receptor|IL-8 receptor type 2|IL-8R B|chemokine (CXC) receptor 2|high affinity interleukin-8 receptor B|interleukin 8 receptor type 2|interleukin 8 receptor, beta|interleukin-8 receptor type B', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218125294, end_position_on_the_genomic_accession=218137253, orientation='plus', exon_count=6, OMIM=[146928], no_hdr0=''),
    3581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3581, CurrentID=0, Status='live', Symbol='IL9R', Aliases=['CD129', 'IL-9R'], description='interleukin 9 receptor', other_designations='interleukin-9 receptor|IL-9 receptor', map_location='Xq28 and Yq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155997631, end_position_on_the_genomic_accession=156013017, orientation='plus', exon_count=14, OMIM=[300007], no_hdr0=''),
    3586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3586, CurrentID=0, Status='live', Symbol='IL10', Aliases=['CSIF', 'GVHDS', 'IL-10A', 'TGIF', 'IL10'], description='interleukin 10', other_designations='interleukin-10|T-cell growth inhibitory factor|cytokine synthesis inhibitory factor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206767602, end_position_on_the_genomic_accession=206772494, orientation='minus', exon_count=7, OMIM=[124092], no_hdr0=''),
    3587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3587, CurrentID=0, Status='live', Symbol='IL10RA', Aliases=['CD210', 'CD210a', 'CDW210A', 'HIL-10R', 'IL-10R1', 'IL10R'], description='interleukin 10 receptor subunit alpha', other_designations='interleukin-10 receptor subunit alpha|IL-10 receptor subunit alpha|IL-10R subunit 1|IL-10R subunit alpha|IL-10RA|interleukin 10 receptor, alpha|interleukin-10 receptor alpha chain|interleukin-10 receptor subunit 1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117986394, end_position_on_the_genomic_accession=118003037, orientation='plus', exon_count=8, OMIM=[146933], no_hdr0=''),
    3588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3588, CurrentID=0, Status='live', Symbol='IL10RB', Aliases=['CDW210B', 'CRF2-4', 'CRFB4', 'D21S58', 'D21S66', 'IL-10R2'], description='interleukin 10 receptor subunit beta', other_designations='interleukin-10 receptor subunit beta|IL-10 receptor subunit beta|IL-10R subunit 2|IL-10R subunit beta|IL-10RB|cytokine receptor class-II CRF2-4|cytokine receptor class-II member 4|cytokine receptor family 2 member 4|cytokine receptor family II, member 4|interleukin 10 receptor, beta|interleukin-10 receptor subunit 2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33266367, end_position_on_the_genomic_accession=33297221, orientation='plus', exon_count=7, OMIM=[123889], no_hdr0=''),
    3589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3589, CurrentID=0, Status='live', Symbol='IL11', Aliases=['AGIF', 'IL-11'], description='interleukin 11', other_designations='interleukin-11|adipogenesis inhibitory factor|oprelvekin', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55364382, end_position_on_the_genomic_accession=55370463, orientation='minus', exon_count=5, OMIM=[147681], no_hdr0=''),
    3590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3590, CurrentID=0, Status='live', Symbol='IL11RA', Aliases=['CRSDA'], description='interleukin 11 receptor subunit alpha', other_designations='interleukin-11 receptor subunit alpha|IL-11 receptor subunit alpha|IL-11R subunit alpha|interleukin 11 receptor, alpha|interleukin-11 receptor alpha chain', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34652185, end_position_on_the_genomic_accession=34661902, orientation='plus', exon_count=14, OMIM=[600939], no_hdr0=''),
    3592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3592, CurrentID=0, Status='live', Symbol='IL12A', Aliases=['CLMF', 'IL-12A', 'NFSK', 'NKSF1', 'P35'], description='interleukin 12A', other_designations='interleukin-12 subunit alpha|CLMF p35|IL-12, subunit p35|IL35 subunit|NF cell stimulatory factor chain 1|NK cell stimulatory factor chain 1|cytotoxic lymphocyte maturation factor 1, p35|cytotoxic lymphocyte maturation factor 35 kDa subunit|interleukin 12, p35|interleukin 12A (natural killer cell stimulatory factor 1, cytotoxic lymphocyte maturation factor 1, p35)|interleukin-12 alpha chain', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=159988835, end_position_on_the_genomic_accession=159996019, orientation='plus', exon_count=7, OMIM=[161560], no_hdr0=''),
    3593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3593, CurrentID=0, Status='live', Symbol='IL12B', Aliases=['CLMF', 'CLMF2', 'IL-12B', 'IMD28', 'IMD29', 'NKSF', 'NKSF2'], description='interleukin 12B', other_designations='interleukin-12 subunit beta|CLMF p40|IL-12 subunit p40|IL12, subunit p40|NK cell stimulatory factor chain 2|cytotoxic lymphocyte maturation factor 40 kDa subunit|interleukin 12, p40|interleukin 12B (natural killer cell stimulatory factor 2, cytotoxic lymphocyte maturation factor 2, p40)|interleukin-12 beta chain|natural killer cell stimulatory factor, 40 kD subunit', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=159314780, end_position_on_the_genomic_accession=159330487, orientation='minus', exon_count=8, OMIM=[161561], no_hdr0=''),
    3594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3594, CurrentID=0, Status='live', Symbol='IL12RB1', Aliases=['CD212', 'IL-12R-BETA1', 'IL12RB', 'IMD30'], description='interleukin 12 receptor subunit beta 1', other_designations='interleukin-12 receptor subunit beta-1|IL-12 receptor beta component|IL-12 receptor subunit beta-1|IL-12R subunit beta-1|cluster of differentiation 212|interleukin 12 receptor, beta 1|interleukin-12 receptor beta-1 chain', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18058994, end_position_on_the_genomic_accession=18099027, orientation='minus', exon_count=20, OMIM=[601604], no_hdr0=''),
    3595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3595, CurrentID=0, Status='live', Symbol='IL12RB2', Aliases=[], description='interleukin 12 receptor subunit beta 2', other_designations='interleukin-12 receptor subunit beta-2|IL-12 receptor subunit beta-2|IL-12R subunit beta-2|interleukin 12 receptor, beta 2|interleukin-12 receptor beta-2 chain', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67307351, end_position_on_the_genomic_accession=67398724, orientation='plus', exon_count=20, OMIM=[601642], no_hdr0=''),
    3596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3596, CurrentID=0, Status='live', Symbol='IL13', Aliases=['IL-13', 'P600'], description='interleukin 13', other_designations='interleukin-13', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132656522, end_position_on_the_genomic_accession=132661110, orientation='plus', exon_count=6, OMIM=[147683], no_hdr0=''),
    3597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3597, CurrentID=0, Status='live', Symbol='IL13RA1', Aliases=['CD213A1', 'CT19', 'IL-13Ra', 'NR4'], description='interleukin 13 receptor subunit alpha 1', other_designations='interleukin-13 receptor subunit alpha-1|CD213a1 antigen|IL-13 receptor subunit alpha-1|IL-13R subunit alpha-1|IL13 receptor alpha-1 chain|cancer/testis antigen 19|interleukin 13 receptor, alpha 1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=118726954, end_position_on_the_genomic_accession=118794533, orientation='plus', exon_count=12, OMIM=[300119], no_hdr0=''),
    3598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3598, CurrentID=0, Status='live', Symbol='IL13RA2', Aliases=['CD213A2', 'CT19', 'IL-13R', 'IL13BP'], description='interleukin 13 receptor subunit alpha 2', other_designations='interleukin-13 receptor subunit alpha-2|IL-13 receptor subunit alpha-2|IL-13R subunit alpha-2|IL-13R-alpha-2|IL-13RA2|cancer/testis antigen 19|interleukin 13 binding protein|interleukin 13 receptor alpha 2 chain|interleukin 13 receptor, alpha 2', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=115003982, end_position_on_the_genomic_accession=115017616, orientation='minus', exon_count=10, OMIM=[300130], no_hdr0=''),
    3600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3600, CurrentID=0, Status='live', Symbol='IL15', Aliases=['IL-15'], description='interleukin 15', other_designations='interleukin-15', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=141636583, end_position_on_the_genomic_accession=141733987, orientation='plus', exon_count=10, OMIM=[600554], no_hdr0=''),
    3601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3601, CurrentID=0, Status='live', Symbol='IL15RA', Aliases=['CD215'], description='interleukin 15 receptor subunit alpha', other_designations='interleukin-15 receptor subunit alpha|interleukin 15 receptor, alpha', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5948897, end_position_on_the_genomic_accession=5978741, orientation='minus', exon_count=13, OMIM=[601070], no_hdr0=''),
    3603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3603, CurrentID=0, Status='live', Symbol='IL16', Aliases=['LCF', 'NIL16', 'PRIL16', 'prIL-16'], description='interleukin 16', other_designations='pro-interleukin-16|lymphocyte chemoattractant factor|neuronal interleukin 16|prointerleukin 16', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=81196879, end_position_on_the_genomic_accession=81314058, orientation='plus', exon_count=22, OMIM=[603035], no_hdr0=''),
    3604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3604, CurrentID=0, Status='live', Symbol='TNFRSF9', Aliases=['4-1BB', 'CD137', 'CDw137', 'ILA'], description='TNF receptor superfamily member 9', other_designations='tumor necrosis factor receptor superfamily member 9|4-1BB ligand receptor|CD137 antigen|T cell antigen ILA|T-cell antigen 4-1BB homolog|homolog of mouse 4-1BB|induced by lymphocyte activation (ILA)|interleukin-activated receptor, homolog of mouse Ly63|receptor protein 4-1BB', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=7915871, end_position_on_the_genomic_accession=7941607, orientation='minus', exon_count=9, OMIM=[602250], no_hdr0=''),
    3605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3605, CurrentID=0, Status='live', Symbol='IL17A', Aliases=['CTLA-8', 'CTLA8', 'IL-17', 'IL-17A', 'IL17', 'ILA17'], description='interleukin 17A', other_designations='interleukin-17A|cytotoxic T-lymphocyte-associated antigen 8|cytotoxic T-lymphocyte-associated protein 8|interleukin 17 (cytotoxic T-lymphocyte-associated serine esterase 8)|interleukin-17', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52186375, end_position_on_the_genomic_accession=52190638, orientation='plus', exon_count=3, OMIM=[603149], no_hdr0=''),
    3606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3606, CurrentID=0, Status='live', Symbol='IL18', Aliases=['IGIF', 'IL-18', 'IL-1g', 'IL1F4'], description='interleukin 18', other_designations='interleukin-18|IFN-gamma-inducing factor|IL-1 gamma|iboctadekin|interleukin 18 (interferon-gamma-inducing factor)|interleukin-1 gamma', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112143251, end_position_on_the_genomic_accession=112164104, orientation='minus', exon_count=6, OMIM=[600953], no_hdr0=''),
    3607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3607, CurrentID=0, Status='live', Symbol='FOXK2', Aliases=['ILF', 'ILF-1', 'ILF1', 'nGTBP'], description='forkhead box K2', other_designations='forkhead box protein K2|FOXK1|G/T-mismatch specific binding protein|cellular transcription factor ILF-1|interleukin enhancer-binding factor 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82519732, end_position_on_the_genomic_accession=82604602, orientation='plus', exon_count=11, OMIM=[147685], no_hdr0=''),
    3608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3608, CurrentID=0, Status='live', Symbol='ILF2', Aliases=['NF45', 'PRO3063'], description='interleukin enhancer binding factor 2', other_designations='interleukin enhancer-binding factor 2|interleukin enhancer binding factor 2, 45kD|interleukin enhancer binding factor 2, 45kDa|nuclear factor of activated T-cells, 45-kDa', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153661788, end_position_on_the_genomic_accession=153670993, orientation='minus', exon_count=14, OMIM=[603181], no_hdr0=''),
    3609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3609, CurrentID=0, Status='live', Symbol='ILF3', Aliases=['CBTF', 'DRBF', 'DRBP76', 'MMP4', 'MPHOSPH4', 'MPP4', 'MPP4110', 'NF-AT-90', 'NF110', 'NF110b', 'NF90', 'NF90a', 'NF90b', 'NF90c', 'NF90ctv', 'NFAR', 'NFAR-1', 'NFAR-2', 'NFAR110', 'NFAR2', 'NFAR90', 'TCP110', 'TCP80'], description='interleukin enhancer binding factor 3', other_designations='interleukin enhancer-binding factor 3|M phase phosphoprotein 4, nuclear factor associated with DS RNA|M-phase phosphoprotein 4|double-stranded RNA-binding protein, 76 kD|dsRNA binding protein NFAR-2/MPP4|interleukin enhancer binding factor 3, 90kD|interleukin enhancer binding factor 3, 90kDa|nuclear factor associated with dsRNA|nuclear factor of activated T-cells 110 kDa|nuclear factor of activated T-cells 90 kDa|nuclear factor of activated T-cells, 90 kD|translational control protein 80', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10654346, end_position_on_the_genomic_accession=10692400, orientation='plus', exon_count=23, OMIM=[603182], no_hdr0=''),
    3611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3611, CurrentID=0, Status='live', Symbol='ILK', Aliases=['HEL-S-28-1', 'ILK-2', 'P59', 'p59ILK', 'ILK'], description='integrin linked kinase', other_designations='integrin-linked protein kinase|59 kDa serine/threonine-protein kinase|beta-integrin-linked kinase|epididymis secretory protein Li 28|integrin-linked kinase-2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6603748, end_position_on_the_genomic_accession=6610873, orientation='plus', exon_count=15, OMIM=[602366], no_hdr0=''),
    3612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3612, CurrentID=0, Status='live', Symbol='IMPA1', Aliases=['IMP', 'IMPA', 'MRT59'], description='inositol monophosphatase 1', other_designations='inositol monophosphatase 1|D-galactose 1-phosphate phosphatase|IMP 1|IMPase 1|inositol(myo)-1(or 4)-monophosphatase 1|inositol-1(or 4)-monophosphatase 1|lithium-sensitive myo-inositol monophosphatase A1|myo-inositol monophosphatase 1|testicular tissue protein Li 94', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81656914, end_position_on_the_genomic_accession=81686325, orientation='minus', exon_count=10, OMIM=[602064], no_hdr0=''),
    3613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3613, CurrentID=0, Status='live', Symbol='IMPA2', Aliases=[], description='inositol monophosphatase 2', other_designations='inositol monophosphatase 2|IMP 2|IMPase 2|inosine monophosphatase 2|inositol monophosphatase 2 variant 1|inositol monophosphatase 2 variant 2|inositol(myo)-1(or 4)-monophosphatase 2|myo-inositol monophosphatase 2|myo-inositol monophosphatase A2', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=11981465, end_position_on_the_genomic_accession=12030878, orientation='plus', exon_count=9, OMIM=[605922], no_hdr0=''),
    3614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3614, CurrentID=0, Status='live', Symbol='IMPDH1', Aliases=['IMPD', 'IMPD1', 'IMPDH-I', 'LCA11', 'RP10', 'sWSS2608'], description='inosine monophosphate dehydrogenase 1', other_designations="inosine-5'-monophosphate dehydrogenase 1|IMP (inosine 5'-monophosphate) dehydrogenase 1|IMP (inosine monophosphate) dehydrogenase 1|IMPD 1|IMPDH 1", map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128392277, end_position_on_the_genomic_accession=128409989, orientation='minus', exon_count=18, OMIM=[146690], no_hdr0=''),
    3615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3615, CurrentID=0, Status='live', Symbol='IMPDH2', Aliases=['IMPD2', 'IMPDH-II'], description='inosine monophosphate dehydrogenase 2', other_designations="inosine-5'-monophosphate dehydrogenase 2|IMP (inosine 5'-monophosphate) dehydrogenase 2|IMP (inosine monophosphate) dehydrogenase 2|IMP dehydrogenase II|IMP oxireductase 2|IMPD 2|IMPDH 2|epididymis secretory sperm binding protein|inosine 5' phosphate dehydrogenase 2|inosine monophosphate dehydrogenase type II|inosine-5'-monophosphate dehydrogenase type II", map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49024325, end_position_on_the_genomic_accession=49029750, orientation='minus', exon_count=15, OMIM=[146691], no_hdr0=''),
    3617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3617, CurrentID=0, Status='live', Symbol='IMPG1', Aliases=['GP147', 'IPM150', 'SPACR', 'VMD4'], description='interphotoreceptor matrix proteoglycan 1', other_designations='interphotoreceptor matrix proteoglycan 1|interphotoreceptor matrix proteoglycan of 150 kDa|sialoprotein associated with cones and rods', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75921114, end_position_on_the_genomic_accession=76072662, orientation='minus', exon_count=17, OMIM=[602870], no_hdr0=''),
    3619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3619, CurrentID=0, Status='live', Symbol='INCENP', Aliases=[], description='inner centromere protein', other_designations='inner centromere protein|binds and activates aurora-B and -C in vivo and in vitro|chromosomal passenger protein|inner centromere protein INCENP|inner centromere protein antigens 135/155kDa', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62123998, end_position_on_the_genomic_accession=62155474, orientation='plus', exon_count=19, OMIM=[604411], no_hdr0=''),
    3620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3620, CurrentID=0, Status='live', Symbol='IDO1', Aliases=['IDO', 'IDO-1', 'INDO'], description='indoleamine 2,3-dioxygenase 1', other_designations='indoleamine 2,3-dioxygenase 1|indolamine 2,3 dioxygenase|indole 2,3-dioxygenase|indoleamine-pyrrole 2,3-dioxygenase', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=39913891, end_position_on_the_genomic_accession=39928790, orientation='plus', exon_count=10, OMIM=[147435], no_hdr0=''),
    3621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3621, CurrentID=0, Status='live', Symbol='ING1', Aliases=['p24ING1c', 'p33', 'p33ING1', 'p33ING1b', 'p47', 'p47ING1a'], description='inhibitor of growth family member 1', other_designations='inhibitor of growth protein 1|growth inhibitor ING1|growth inhibitory protein ING1|tumor suppressor ING1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110712623, end_position_on_the_genomic_accession=110723339, orientation='plus', exon_count=5, OMIM=[601566], no_hdr0=''),
    3622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3622, CurrentID=0, Status='live', Symbol='ING2', Aliases=['ING1L', 'p33ING2'], description='inhibitor of growth family member 2', other_designations='inhibitor of growth protein 2|ING1Lp|inhibitor of growth 1-like protein|p32', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183505058, end_position_on_the_genomic_accession=183512429, orientation='plus', exon_count=4, OMIM=[604215], no_hdr0=''),
    3623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3623, CurrentID=0, Status='live', Symbol='INHA', Aliases=[], description='inhibin subunit alpha', other_designations='inhibin alpha chain|A-inhibin subunit|inhibin alpha subunit', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219572310, end_position_on_the_genomic_accession=219575711, orientation='plus', exon_count=2, OMIM=[147380], no_hdr0=''),
    3624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3624, CurrentID=0, Status='live', Symbol='INHBA', Aliases=['EDF', 'FRP'], description='inhibin subunit beta A', other_designations='inhibin beta A chain|FSH-releasing protein|Inhibin, beta-1|activin beta-A chain|erythroid differentiation factor|erythroid differentiation protein|follicle-stimulating hormone-releasing protein|inhibin beta A subunit|inhibin, beta A (activin A, activin AB alpha polypeptide)', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=41685101, end_position_on_the_genomic_accession=41710532, orientation='minus', exon_count=7, OMIM=[147290], no_hdr0=''),
    3625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3625, CurrentID=0, Status='live', Symbol='INHBB', Aliases=[], description='inhibin subunit beta B', other_designations='inhibin beta B chain|Inhibin, beta-2|activin AB beta polypeptide|activin beta-B chain|inhibin beta B subunit', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120346136, end_position_on_the_genomic_accession=120351803, orientation='plus', exon_count=2, OMIM=[147390], no_hdr0=''),
    3626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3626, CurrentID=0, Status='live', Symbol='INHBC', Aliases=['IHBC'], description='inhibin subunit beta C', other_designations='inhibin beta C chain|activin beta-C chain|inhibin beta C subunit', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57434784, end_position_on_the_genomic_accession=57452062, orientation='plus', exon_count=2, OMIM=[601233], no_hdr0=''),
    3627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3627, CurrentID=0, Status='live', Symbol='CXCL10', Aliases=['C7', 'IFI10', 'INP10', 'IP-10', 'SCYB10', 'crg-2', 'gIP-10', 'mob-1'], description='C-X-C motif chemokine ligand 10', other_designations='C-X-C motif chemokine 10|10 kDa interferon gamma-induced protein|gamma IP10|interferon-inducible cytokine IP-10|protein 10 from interferon (gamma)-induced cell line|small inducible cytokine subfamily B (Cys-X-Cys), member 10|small-inducible cytokine B10', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76021118, end_position_on_the_genomic_accession=76023497, orientation='minus', exon_count=4, OMIM=[147310], no_hdr0=''),
    3628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3628, CurrentID=0, Status='live', Symbol='INPP1', Aliases=[], description='inositol polyphosphate-1-phosphatase', other_designations='inositol polyphosphate 1-phosphatase|IPP|IPPase', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190343589, end_position_on_the_genomic_accession=190371665, orientation='plus', exon_count=9, OMIM=[147263], no_hdr0=''),
    3630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3630, CurrentID=0, Status='live', Symbol='INS', Aliases=['IDDM', 'IDDM1', 'IDDM2', 'ILPR', 'IRDN', 'MODY10', 'PNDM4'], description='insulin', other_designations='insulin|preproinsulin|proinsulin', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2159779, end_position_on_the_genomic_accession=2161209, orientation='minus', exon_count=3, OMIM=[176730], no_hdr0=''),
    3631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3631, CurrentID=0, Status='live', Symbol='INPP4A', Aliases=['INPP4', 'TVAS1'], description='inositol polyphosphate-4-phosphatase type I A', other_designations='inositol polyphosphate-4-phosphatase type I A|inositol polyphosphate-4-phosphatase, type I, 107kD|inositol polyphosphate-4-phosphatase, type I, 107kDa|type I inositol 3,4-bisphosphate 4-phosphatase', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98444538, end_position_on_the_genomic_accession=98594392, orientation='plus', exon_count=36, OMIM=[600916], no_hdr0=''),
    3632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3632, CurrentID=0, Status='live', Symbol='INPP5A', Aliases=['5PTASE'], description='inositol polyphosphate-5-phosphatase A', other_designations='inositol polyphosphate-5-phosphatase A|43 kDa inositol polyphosphate 5-phophatase|43 kDa inositol polyphosphate 5-phosphatase|CTCL tumor antigen HD-CL-02|InsP3 5-phosphatase|inositol polyphosphate-5-phosphatase, 40kD|inositol polyphosphate-5-phosphatase, 40kDa|inositol trisphosphate-5-phosphatase, 40kD|type I inositol 1,4,5-trisphosphate 5-phosphatase|type I inositol-1,4,5-trisphosphate 5-phophatase', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132537784, end_position_on_the_genomic_accession=132783480, orientation='plus', exon_count=21, OMIM=[600106], no_hdr0=''),
    3633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3633, CurrentID=0, Status='live', Symbol='INPP5B', Aliases=['5PTase'], description='inositol polyphosphate-5-phosphatase B', other_designations='type II inositol 1,4,5-trisphosphate 5-phosphatase|inositol polyphosphate-5-phosphatase, 75kDa|phosphoinositide 5-phosphatase', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37860697, end_position_on_the_genomic_accession=37947095, orientation='minus', exon_count=32, OMIM=[147264], no_hdr0=''),
    3635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3635, CurrentID=0, Status='live', Symbol='INPP5D', Aliases=['SHIP', 'SHIP-1', 'SHIP1', 'SIP-145', 'hp51CN', 'p150Ship'], description='inositol polyphosphate-5-phosphatase D', other_designations="phosphatidylinositol 3,4,5-trisphosphate 5-phosphatase 1|SH2 domain-containing inositol 5'-phosphatase 1|inositol polyphosphate-5-phosphatase, 145kD|inositol polyphosphate-5-phosphatase, 145kDa|phosphatidylinositol 4,5-bisphosphate 5-phosphatase|signaling inositol polyphosphate 5 phosphatase SIP-145|signaling inositol polyphosphate phosphatase SHIP II", map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233060342, end_position_on_the_genomic_accession=233207903, orientation='plus', exon_count=27, OMIM=[601582], no_hdr0=''),
    3636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3636, CurrentID=0, Status='live', Symbol='INPPL1', Aliases=['OPSMD', 'SHIP2'], description='inositol polyphosphate phosphatase like 1', other_designations="phosphatidylinositol 3,4,5-trisphosphate 5-phosphatase 2|51C protein|INPPL-1|SH2 domain-containing inositol-5'-phosphatase 2|SHIP-2|protein 51C", map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72223861, end_position_on_the_genomic_accession=72239147, orientation='plus', exon_count=29, OMIM=[600829], no_hdr0=''),
    3638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3638, CurrentID=0, Status='live', Symbol='INSIG1', Aliases=['CL6'], description='insulin induced gene 1', other_designations='insulin-induced gene 1 protein|INSIG-1 membrane protein', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155297878, end_position_on_the_genomic_accession=155310235, orientation='plus', exon_count=7, OMIM=[602055], no_hdr0=''),
    3640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3640, CurrentID=0, Status='live', Symbol='INSL3', Aliases=['RLF', 'RLNL', 'ley-I-L'], description='insulin like 3', other_designations='insulin-like 3|insulin-like 3 (Leydig cell)|leydig insulin -like hormone|leydig insulin-like peptide|prepro-INSL3|relaxin-like factor b', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17816512, end_position_on_the_genomic_accession=17821519, orientation='minus', exon_count=3, OMIM=[146738], no_hdr0=''),
    3641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3641, CurrentID=0, Status='live', Symbol='INSL4', Aliases=['EPIL', 'PLACENTIN'], description='insulin like 4', other_designations='early placenta insulin-like peptide|early placenta insulin-like peptide (EPIL)|insulin-like 4 (placenta)|insulin-like peptide 4', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5231419, end_position_on_the_genomic_accession=5235304, orientation='plus', exon_count=2, OMIM=[600910], no_hdr0=''),
    3642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3642, CurrentID=0, Status='live', Symbol='INSM1', Aliases=['IA-1', 'IA1'], description='INSM transcriptional repressor 1', other_designations='insulinoma-associated protein 1|insulinoma-associated 1|zinc finger protein IA-1', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=20368104, end_position_on_the_genomic_accession=20370949, orientation='plus', exon_count=1, OMIM=[600010], no_hdr0=''),
    3643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3643, CurrentID=0, Status='live', Symbol='INSR', Aliases=['CD220', 'HHF5'], description='insulin receptor', other_designations='insulin receptor|IR', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7112257, end_position_on_the_genomic_accession=7294414, orientation='minus', exon_count=22, OMIM=[147670], no_hdr0=''),
    3645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3645, CurrentID=0, Status='live', Symbol='INSRR', Aliases=['IRR'], description='insulin receptor related receptor', other_designations='insulin receptor-related protein|IR-related receptor', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156840063, end_position_on_the_genomic_accession=156859117, orientation='minus', exon_count=22, OMIM=[147671], no_hdr0=''),
    3646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3646, CurrentID=0, Status='live', Symbol='EIF3E', Aliases=['EIF3-P48', 'EIF3S6', 'INT6', 'eIF3-p46'], description='eukaryotic translation initiation factor 3 subunit E', other_designations='eukaryotic translation initiation factor 3 subunit E|eIF-3 p48|eukaryotic translation initiation factor 3 subunit 6|eukaryotic translation initiation factor 3, subunit 6 (48kD)|eukaryotic translation initiation factor 3, subunit 6 48kDa|mammary tumor-associated protein INT6|murine mammary tumor integration site 6 (oncogene homolog)|viral integration site protein INT-6 homolog', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=108201216, end_position_on_the_genomic_accession=108248734, orientation='minus', exon_count=13, OMIM=[602210], no_hdr0=''),
    3651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3651, CurrentID=0, Status='live', Symbol='PDX1', Aliases=['GSF', 'IDX-1', 'IPF1', 'IUF1', 'MODY4', 'PAGEN1', 'PDX-1', 'STF-1'], description='pancreatic and duodenal homeobox 1', other_designations='pancreas/duodenum homeobox protein 1|IPF-1|IUF-1|glucose-sensitive factor|insulin promoter factor 1, homeodomain transcription factor|insulin upstream factor 1|islet/duodenum homeobox-1|pancreatic-duodenal homeobox factor 1|somatostatin transcription factor 1|somatostatin-transactivating factor 1', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27919982, end_position_on_the_genomic_accession=27926313, orientation='plus', exon_count=2, OMIM=[600733], no_hdr0=''),
    3652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3652, CurrentID=0, Status='live', Symbol='IPP', Aliases=['KLHL27'], description='intracisternal A particle-promoted polypeptide', other_designations='actin-binding protein IPP|kelch-like family member 27|kelch-like protein 27', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45694324, end_position_on_the_genomic_accession=45750805, orientation='minus', exon_count=12, OMIM=[147485], no_hdr0=''),
    3654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3654, CurrentID=0, Status='live', Symbol='IRAK1', Aliases=['IRAK', 'pelle'], description='interleukin 1 receptor associated kinase 1', other_designations='interleukin-1 receptor-associated kinase 1|IRAK-1|Pelle homolog', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154010507, end_position_on_the_genomic_accession=154019984, orientation='minus', exon_count=13, OMIM=[300283], no_hdr0=''),
    3655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3655, CurrentID=0, Status='live', Symbol='ITGA6', Aliases=['CD49fB', 'VLA-6', 'ITGA6'], description='integrin subunit alpha 6', other_designations='integrin alpha-6|CD49 antigen-like family member F|integrin alpha6B|integrin, alpha 6', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=172427336, end_position_on_the_genomic_accession=172506459, orientation='plus', exon_count=28, OMIM=[147556], no_hdr0=''),
    3656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3656, CurrentID=0, Status='live', Symbol='IRAK2', Aliases=['IRAK-2'], description='interleukin 1 receptor associated kinase 2', other_designations='interleukin-1 receptor-associated kinase-like 2', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10164919, end_position_on_the_genomic_accession=10243745, orientation='plus', exon_count=13, OMIM=[603304], no_hdr0=''),
    3658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3658, CurrentID=0, Status='live', Symbol='IREB2', Aliases=['ACO3', 'IRE-BP 2', 'IRE-BP2', 'IRP2', 'IRP2AD', 'NDCAMA'], description='iron responsive element binding protein 2', other_designations='iron-responsive element-binding protein 2|iron regulatory protein 2', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78437431, end_position_on_the_genomic_accession=78501453, orientation='plus', exon_count=24, OMIM=[147582], no_hdr0=''),
    3659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3659, CurrentID=0, Status='live', Symbol='IRF1', Aliases=['IRF-1', 'MAR'], description='interferon regulatory factor 1', other_designations='interferon regulatory factor 1', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132481609, end_position_on_the_genomic_accession=132490789, orientation='minus', exon_count=10, OMIM=[147575], no_hdr0=''),
    3660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3660, CurrentID=0, Status='live', Symbol='IRF2', Aliases=['IRF-2'], description='interferon regulatory factor 2', other_designations='interferon regulatory factor 2', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184382741, end_position_on_the_genomic_accession=184474580, orientation='minus', exon_count=12, OMIM=[147576], no_hdr0=''),
    3661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3661, CurrentID=0, Status='live', Symbol='IRF3', Aliases=['IIAE7'], description='interferon regulatory factor 3', other_designations='interferon regulatory factor 3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49659572, end_position_on_the_genomic_accession=49665857, orientation='minus', exon_count=10, OMIM=[603734], no_hdr0=''),
    3662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3662, CurrentID=0, Status='live', Symbol='IRF4', Aliases=['LSIRF', 'MUM1', 'NF-EM5', 'SHEP8'], description='interferon regulatory factor 4', other_designations='interferon regulatory factor 4|lymphocyte-specific interferon regulatory factor|multiple myeloma oncogene 1', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=391752, end_position_on_the_genomic_accession=411443, orientation='plus', exon_count=10, OMIM=[601900], no_hdr0=''),
    3663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3663, CurrentID=0, Status='live', Symbol='IRF5', Aliases=['SLEB10'], description='interferon regulatory factor 5', other_designations='interferon regulatory factor 5', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128937032, end_position_on_the_genomic_accession=128950038, orientation='plus', exon_count=14, OMIM=[607218], no_hdr0=''),
    3664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3664, CurrentID=0, Status='live', Symbol='IRF6', Aliases=['LPS', 'OFC6', 'PIT', 'PPS', 'PPS1', 'VWS', 'VWS1'], description='interferon regulatory factor 6', other_designations='interferon regulatory factor 6', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209785617, end_position_on_the_genomic_accession=209806142, orientation='minus', exon_count=9, OMIM=[607199], no_hdr0=''),
    3665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3665, CurrentID=0, Status='live', Symbol='IRF7', Aliases=['IMD39', 'IRF-7', 'IRF-7HA', 'IRF7B', 'IRF7C', 'IRF7H', 'IRF7'], description='interferon regulatory factor 7', other_designations='interferon regulatory factor 7|interferon regulatory factor-7H', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=612555, end_position_on_the_genomic_accession=615999, orientation='minus', exon_count=11, OMIM=[605047], no_hdr0=''),
    3667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3667, CurrentID=0, Status='live', Symbol='IRS1', Aliases=['HIRS-1'], description='insulin receptor substrate 1', other_designations='insulin receptor substrate 1', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=226731312, end_position_on_the_genomic_accession=226799820, orientation='minus', exon_count=2, OMIM=[147545], no_hdr0=''),
    3669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3669, CurrentID=0, Status='live', Symbol='ISG20', Aliases=['CD25', 'HEM45'], description='interferon stimulated exonuclease gene 20', other_designations='interferon-stimulated gene 20 kDa protein|estrogen-regulated transcript 45 protein|interferon stimulated exonuclease gene 20kDa|promyelocytic leukemia nuclear body-associated protein ISG20', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88635614, end_position_on_the_genomic_accession=88656483, orientation='plus', exon_count=8, OMIM=[604533], no_hdr0=''),
    3670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3670, CurrentID=0, Status='live', Symbol='ISL1', Aliases=['ISLET1', 'Isl-1'], description='ISL LIM homeobox 1', other_designations='insulin gene enhancer protein ISL-1|islet-1', map_location='5q11.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=51383448, end_position_on_the_genomic_accession=51394730, orientation='plus', exon_count=7, OMIM=[600366], no_hdr0=''),
    3671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3671, CurrentID=0, Status='live', Symbol='ISLR', Aliases=['HsT17563', 'Meflin'], description='immunoglobulin superfamily containing leucine rich repeat', other_designations='immunoglobulin superfamily containing leucine-rich repeat protein|mesenchymal stromal cell- and fibroblast-expressing Linx paralogue', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74173710, end_position_on_the_genomic_accession=74176871, orientation='plus', exon_count=3, OMIM=[602059], no_hdr0=''),
    3672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3672, CurrentID=0, Status='live', Symbol='ITGA1', Aliases=['CD49a', 'VLA1'], description='integrin subunit alpha 1', other_designations='integrin alpha-1|CD49 antigen-like family member A|VLA-1|laminin and collagen receptor|very late activation protein 1', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=52787916, end_position_on_the_genomic_accession=52959209, orientation='plus', exon_count=29, OMIM=[192968], no_hdr0=''),
    3673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3673, CurrentID=0, Status='live', Symbol='ITGA2', Aliases=['BR', 'CD49B', 'GPIa', 'HPA-5', 'VLA-2', 'VLAA2'], description='integrin subunit alpha 2', other_designations='integrin alpha-2|CD49 antigen-like family member B|alpha 2 subunit of VLA-2 receptor|collagen receptor|human platelet alloantigen system 5|integrin, alpha 2 (CD49B, alpha 2 subunit of VLA-2 receptor)|platelet antigen Br|platelet glycoprotein GPIa|platelet membrane glycoprotein Ia|very late activation protein 2 receptor, alpha-2 subunit', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=52989352, end_position_on_the_genomic_accession=53094779, orientation='plus', exon_count=30, OMIM=[192974], no_hdr0=''),
    3674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3674, CurrentID=0, Status='live', Symbol='ITGA2B', Aliases=['BDPLT16', 'BDPLT2', 'CD41', 'CD41B', 'GP2B', 'GPIIb', 'GT', 'GT1', 'GTA', 'HPA3', 'PPP1R93'], description='integrin subunit alpha 2b', other_designations='integrin alpha-IIb|GPalpha IIb|alphaIIb protein|integrin, alpha 2b (platelet glycoprotein IIb of IIb/IIIa complex, antigen CD41)|platelet fibrinogen receptor, alpha subunit|platelet glycoprotein IIb of IIb/IIIa complex|platelet membrane glycoprotein IIb|platelet-specific antigen BAK|protein phosphatase 1, regulatory subunit 93', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44372181, end_position_on_the_genomic_accession=44389649, orientation='minus', exon_count=30, OMIM=[607759], no_hdr0=''),
    3675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3675, CurrentID=0, Status='live', Symbol='ITGA3', Aliases=['CD49C', 'FRP-2', 'GAP-B3', 'GAPB3', 'ILNEB', 'MSK18', 'VCA-2', 'VL3A', 'VLA3a'], description='integrin subunit alpha 3', other_designations='integrin alpha-3|CD49 antigen-like family member C|alpha 3 subunit of VLA-3 receptor|antigen CD49C|antigen identified by monoclonal antibody J143|galactoprotein B3|integrin alpha 3|integrin, alpha 3 (antigen CD49C, alpha 3 subunit of VLA-3 receptor)|testicular tissue protein Li 96|testicular tissue protein Li 98|very late activation protein 3 receptor, alpha-3 subunit', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50056065, end_position_on_the_genomic_accession=50090481, orientation='plus', exon_count=26, OMIM=[605025], no_hdr0=''),
    3676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3676, CurrentID=0, Status='live', Symbol='ITGA4', Aliases=['CD49D', 'IA4'], description='integrin subunit alpha 4', other_designations='integrin alpha-4|269C wild type|CD49 antigen-like family member D|VLA-4 subunit alpha|alpha 4 subunit of VLA-4 receptor|antigen CD49D, alpha-4 subunit of VLA-4 receptor|integrin alpha-IV|very late activation protein 4 receptor, alpha 4 subunit', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=181457205, end_position_on_the_genomic_accession=181538940, orientation='plus', exon_count=29, OMIM=[192975], no_hdr0=''),
    3678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3678, CurrentID=0, Status='live', Symbol='ITGA5', Aliases=['CD49e', 'FNRA', 'VLA-5', 'VLA5A'], description='integrin subunit alpha 5', other_designations='integrin alpha-5|CD49 antigen-like family member E|ITGA5/SLC9B1 fusion|fibronectin receptor subunit alpha|fibronectin receptor, alpha polypeptide|fibronectin receptor, alpha subunit|integrin alpha-F|integrin, alpha 5 (fibronectin receptor, alpha polypeptide)|very late activation protein 5, alpha subunit', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54395261, end_position_on_the_genomic_accession=54419266, orientation='minus', exon_count=31, OMIM=[135620], no_hdr0=''),
    3679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3679, CurrentID=0, Status='live', Symbol='ITGA7', Aliases=[], description='integrin subunit alpha 7', other_designations='integrin alpha-7|integrin alpha 7 chain', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55684568, end_position_on_the_genomic_accession=55716037, orientation='minus', exon_count=31, OMIM=[600536], no_hdr0=''),
    3680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3680, CurrentID=0, Status='live', Symbol='ITGA9', Aliases=['ALPHA-RLC', 'ITGA4L', 'RLC'], description='integrin subunit alpha 9', other_designations='integrin alpha-9|integrin alpha-RLC', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37452141, end_position_on_the_genomic_accession=37823507, orientation='plus', exon_count=28, OMIM=[603963], no_hdr0=''),
    3681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3681, CurrentID=0, Status='live', Symbol='ITGAD', Aliases=['ADB2', 'CD11D'], description='integrin subunit alpha D', other_designations='integrin alpha-D|CD11 antigen-like family member D|beta-2 integrin alphaD subunit|leukointegrin alpha D', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31393223, end_position_on_the_genomic_accession=31426513, orientation='plus', exon_count=32, OMIM=[602453], no_hdr0=''),
    3682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3682, CurrentID=0, Status='live', Symbol='ITGAE', Aliases=['CD103', 'HUMINAE'], description='integrin subunit alpha E', other_designations='integrin alpha-E|HML-1 antigen|antigen CD103, human mucosal lymphocyte antigen 1; alpha polypeptide|human mucosal lymphocyte antigen 1, alpha polypeptide|integrin alpha-IEL|integrin, alpha E (antigen CD103, human mucosal lymphocyte antigen 1; alpha polypeptide)|mucosal lymphocyte 1 antigen', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3714628, end_position_on_the_genomic_accession=3803766, orientation='minus', exon_count=32, OMIM=[604682], no_hdr0=''),
    3683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3683, CurrentID=0, Status='live', Symbol='ITGAL', Aliases=['CD11A', 'LFA-1', 'LFA1A'], description='integrin subunit alpha L', other_designations='integrin alpha-L|CD11 antigen-like family member A|LFA-1 alpha|LFA-1A|antigen CD11A (p180), lymphocyte function-associated antigen 1, alpha polypeptide|integrin gene promoter|integrin, alpha L (antigen CD11A (p180), lymphocyte function-associated antigen 1; alpha polypeptide)|leukocyte adhesion glycoprotein LFA-1 alpha chain|leukocyte function-associated molecule 1 alpha chain|lymphocyte function-associated antigen 1, alpha polypeptide', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30472683, end_position_on_the_genomic_accession=30523185, orientation='plus', exon_count=31, OMIM=[153370], no_hdr0=''),
    3684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3684, CurrentID=0, Status='live', Symbol='ITGAM', Aliases=['CD11B', 'CR3A', 'MAC-1', 'MAC1A', 'MO1A', 'SLEB6'], description='integrin subunit alpha M', other_designations='integrin alpha-M|CD11 antigen-like family member B|CR-3 alpha chain|antigen CD11b (p170)|cell surface glycoprotein MAC-1 subunit alpha|complement component 3 receptor 3 subunit|integrin, alpha M (complement component 3 receptor 3 subunit)|leukocyte adhesion receptor MO1|macrophage antigen alpha polypeptide|neutrophil adherence receptor alpha-M subunit', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31259975, end_position_on_the_genomic_accession=31332877, orientation='plus', exon_count=31, OMIM=[120980], no_hdr0=''),
    3685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3685, CurrentID=0, Status='live', Symbol='ITGAV', Aliases=['CD51', 'MSK8', 'VNRA', 'VTNR'], description='integrin subunit alpha V', other_designations='integrin alpha-V|antigen identified by monoclonal antibody L230|integrin alphaVbeta3|integrin, alpha V (vitronectin receptor, alpha polypeptide, antigen CD51)|vitronectin receptor subunit alpha', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=186590056, end_position_on_the_genomic_accession=186680901, orientation='plus', exon_count=31, OMIM=[193210], no_hdr0=''),
    3687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3687, CurrentID=0, Status='live', Symbol='ITGAX', Aliases=['CD11C', 'SLEB6'], description='integrin subunit alpha X', other_designations='integrin alpha-X|CD11 antigen-like family member C|complement component 3 receptor 4 subunit|integrin alpha X|integrin, alpha X (antigen CD11C (p150), alpha polypeptide)|integrin, alpha X (complement component 3 receptor 4 subunit)|leu M5, alpha subunit|leukocyte adhesion glycoprotein p150,95 alpha chain|leukocyte adhesion receptor p150,95|leukocyte surface antigen p150,95, alpha subunit|myeloid membrane antigen, alpha subunit|p150 95 integrin alpha chain', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31355167, end_position_on_the_genomic_accession=31382999, orientation='plus', exon_count=32, OMIM=[151510], no_hdr0=''),
    3688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3688, CurrentID=0, Status='live', Symbol='ITGB1', Aliases=['CD29', 'FNRB', 'GPIIA', 'MDF2', 'MSK12', 'VLA-BETA', 'VLAB'], description='integrin subunit beta 1', other_designations='integrin beta-1|glycoprotein IIa|integrin VLA-4 beta subunit|integrin beta 1|integrin, beta 1 (fibronectin receptor, beta polypeptide, antigen CD29 includes MDF2, MSK12)|very late activation protein, beta polypeptide', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=32900318, end_position_on_the_genomic_accession=32958230, orientation='minus', exon_count=18, OMIM=[135630], no_hdr0=''),
    3689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3689, CurrentID=0, Status='live', Symbol='ITGB2', Aliases=['CD18', 'LAD', 'LCAMB', 'LFA-1', 'MAC-1', 'MF17', 'MFI7'], description='integrin subunit beta 2', other_designations='integrin beta-2|cell surface adhesion glycoprotein (LFA-1/CR3/P150,959 beta subunit precursor)|complement component 3 receptor 3 and 4 subunit|complement receptor C3 beta-subunit|integrin beta chain, beta 2|integrin, beta 2 (complement component 3 receptor 3 and 4 subunit)|leukocyte cell adhesion molecule CD18|leukocyte-associated antigens CD18/11A, CD18/11B, CD18/11C|truncated integrin beta-2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44885949, end_position_on_the_genomic_accession=44928815, orientation='minus', exon_count=17, OMIM=[600065], no_hdr0=''),
    3690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3690, CurrentID=0, Status='live', Symbol='ITGB3', Aliases=['BDPLT16', 'BDPLT2', 'BDPLT24', 'CD61', 'GP3A', 'GPIIIa', 'GT', 'GT2'], description='integrin subunit beta 3', other_designations='integrin beta-3|antigen CD61|integrin beta 3|integrin beta chain, beta 3|integrin, beta 3 (platelet glycoprotein IIIa, antigen CD61)|platelet membrane glycoprotein IIIa', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47253827, end_position_on_the_genomic_accession=47313743, orientation='plus', exon_count=15, OMIM=[173470], no_hdr0=''),
    3691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3691, CurrentID=0, Status='live', Symbol='ITGB4', Aliases=['CD104', 'GP150'], description='integrin subunit beta 4', other_designations='integrin beta-4|CD104 antigen', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75721339, end_position_on_the_genomic_accession=75757819, orientation='plus', exon_count=43, OMIM=[147557], no_hdr0=''),
    3692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3692, CurrentID=0, Status='live', Symbol='EIF6', Aliases=['CAB', 'EIF3A', 'ITGB4BP', 'b(2)gcn', 'eIF-6', 'p27(BBP)', 'p27BBP'], description='eukaryotic translation initiation factor 6', other_designations='eukaryotic translation initiation factor 6|B4 integrin interactor|eukaryotic translation initiation factor 3A|p27 beta-4 integrin-binding protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35278906, end_position_on_the_genomic_accession=35284772, orientation='minus', exon_count=8, OMIM=[602912], no_hdr0=''),
    3693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3693, CurrentID=0, Status='live', Symbol='ITGB5', Aliases=[], description='integrin subunit beta 5', other_designations='integrin beta-5|testis secretory sperm-binding protein Li 217p', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=124761948, end_position_on_the_genomic_accession=124901418, orientation='minus', exon_count=18, OMIM=[147561], no_hdr0=''),
    3694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3694, CurrentID=0, Status='live', Symbol='ITGB6', Aliases=['AI1H'], description='integrin subunit beta 6', other_designations='integrin beta-6|integrin, beta 6', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=160099671, end_position_on_the_genomic_accession=160200272, orientation='minus', exon_count=16, OMIM=[147558], no_hdr0=''),
    3695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3695, CurrentID=0, Status='live', Symbol='ITGB7', Aliases=[], description='integrin subunit beta 7', other_designations='integrin beta-7|gut homing receptor beta subunit|integrin beta 7 subunit', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53191318, end_position_on_the_genomic_accession=53207375, orientation='minus', exon_count=16, OMIM=[147559], no_hdr0=''),
    3696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3696, CurrentID=0, Status='live', Symbol='ITGB8', Aliases=[], description='integrin subunit beta 8', other_designations='integrin beta-8', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=20329819, end_position_on_the_genomic_accession=20415754, orientation='plus', exon_count=20, OMIM=[604160], no_hdr0=''),
    3697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3697, CurrentID=0, Status='live', Symbol='ITIH1', Aliases=['H1P', 'IATIH', 'IGHEP1', 'ITI-HC1', 'ITIH', 'SHAP'], description='inter-alpha-trypsin inhibitor heavy chain 1', other_designations='inter-alpha-trypsin inhibitor heavy chain H1|ITI heavy chain H1|inter-alpha (globulin) inhibitor, H1 polypeptide|inter-alpha-inhibitor heavy chain 1|inter-alpha-trypsin inhibitor complex component III|serum-derived hyaluronan-associated protein', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52777599, end_position_on_the_genomic_accession=52792068, orientation='plus', exon_count=23, OMIM=[147270], no_hdr0=''),
    3698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3698, CurrentID=0, Status='live', Symbol='ITIH2', Aliases=['H2P', 'SHAP'], description='inter-alpha-trypsin inhibitor heavy chain 2', other_designations='inter-alpha-trypsin inhibitor heavy chain H2|ITI heavy chain H2|ITI-HC2|inter-alpha (globulin) inhibitor H2|inter-alpha (globulin) inhibitor, H2 polypeptide|inter-alpha-inhibitor heavy chain 2|inter-alpha-trypsin inhibitor complex component II|serum-derived hyaluronan-associated protein', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7703316, end_position_on_the_genomic_accession=7749520, orientation='plus', exon_count=21, OMIM=[146640], no_hdr0=''),
    3699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3699, CurrentID=0, Status='live', Symbol='ITIH3', Aliases=['H3P', 'ITI-HC3', 'SHAP'], description='inter-alpha-trypsin inhibitor heavy chain 3', other_designations='inter-alpha-trypsin inhibitor heavy chain H3|ITI heavy chain H3|inter-alpha (globulin) inhibitor H3|inter-alpha (globulin) inhibitor, H3 polypeptide|inter-alpha-inhibitor heavy chain 3|pre-alpha (globulin) inhibitor, H3 polypeptide|serum-derived hyaluronan-associated protein', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52794796, end_position_on_the_genomic_accession=52808799, orientation='plus', exon_count=24, OMIM=[146650], no_hdr0=''),
    3700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3700, CurrentID=0, Status='live', Symbol='ITIH4', Aliases=['GP120', 'H4P', 'IHRP', 'ITI-HC4', 'ITIHL1', 'PK-120', 'PK120'], description='inter-alpha-trypsin inhibitor heavy chain 4', other_designations='inter-alpha-trypsin inhibitor heavy chain H4|ITI heavy chain H4|inter-alpha (globulin) inhibitor H4 (plasma Kallikrein-sensitive glycoprotein)|inter-alpha-inhibitor heavy chain 4|inter-alpha-trypsin inhibitor family heavy chain-related protein|inter-alpha-trypsin inhibitor heavy chain family member 4|inter-alpha-trypsin inhibitor, heavy chain-like, 1|plasma kallikrein-sensitive glycoprotein 120', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52812962, end_position_on_the_genomic_accession=52830672, orientation='minus', exon_count=24, OMIM=[600564], no_hdr0=''),
    3702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3702, CurrentID=0, Status='live', Symbol='ITK', Aliases=['EMT', 'LPFS1', 'LYK', 'PSCTK2'], description='IL2 inducible T cell kinase', other_designations='tyrosine-protein kinase ITK/TSK|IL-2-inducible T-cell kinase|T-cell-specific kinase|homolog of mouse T-cell itk/tsk|interleukin-2-inducible T-cell kinase|kinase EMT|tyrosine-protein kinase LYK', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157180840, end_position_on_the_genomic_accession=157255185, orientation='plus', exon_count=18, OMIM=[186973], no_hdr0=''),
    3703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3703, CurrentID=0, Status='live', Symbol='STT3A', Aliases=['ITM1', 'STT3-A', 'TMC'], description='STT3 oligosaccharyltransferase complex catalytic subunit A', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit STT3A|B5|STT3, subunit of the oligosaccharyltransferase complex, homolog A|STT3A, catalytic subunit of the oligosaccharyltransferase complex|STT3A, subunit of the oligosaccharyltransferase complex (catalytic)|dolichyl-diphosphooligosaccharide protein glycotransferase|integral membrane protein 1|integral transmembrane protein 1|oligosaccharyl transferase subunit STT3A|transmembrane conserved|transmembrane protein TMC', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125592847, end_position_on_the_genomic_accession=125623091, orientation='plus', exon_count=21, OMIM=[601134], no_hdr0=''),
    3704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3704, CurrentID=0, Status='live', Symbol='ITPA', Aliases=['C20orf37', 'DEE35', 'HLC14-06-P', 'ITPase', 'My049', 'NTPase', 'dJ794I6.3'], description='inosine triphosphatase', other_designations='inosine triphosphate pyrophosphatase|epididymis secretory sperm binding protein|inosine triphosphatase (nucleoside triphosphate pyrophosphatase)|inosine triphosphate pyrophosphohydrolase|non-canonical purine NTP pyrophosphatase|non-standard purine NTP pyrophosphatase|nucleoside-triphosphate diphosphatase|putative oncogene protein HLC14-06-P', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3208676, end_position_on_the_genomic_accession=3227449, orientation='plus', exon_count=12, OMIM=[147520], no_hdr0=''),
    3705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3705, CurrentID=0, Status='live', Symbol='ITPK1', Aliases=['ITRPK1'], description='inositol-tetrakisphosphate 1-kinase', other_designations='inositol-tetrakisphosphate 1-kinase|inositol 1,3,4-trisphosphate 5/6-kinase|ins(1,3,4)P(3) 5/6-kinase', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92936914, end_position_on_the_genomic_accession=93115925, orientation='minus', exon_count=13, OMIM=[601838], no_hdr0=''),
    3706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3706, CurrentID=0, Status='live', Symbol='ITPKA', Aliases=['IP3-3KA', 'IP3KA'], description='inositol-trisphosphate 3-kinase A', other_designations='inositol-trisphosphate 3-kinase A|IP3 3-kinase A|IP3K A|inositol 1,4,5-trisphosphate 3-kinase A|insP 3-kinase A', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41493874, end_position_on_the_genomic_accession=41503555, orientation='plus', exon_count=8, OMIM=[147521], no_hdr0=''),
    3707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3707, CurrentID=0, Status='live', Symbol='ITPKB', Aliases=['IP3-3KB', 'IP3K', 'IP3K-B', 'IP3KB', 'PIG37'], description='inositol-trisphosphate 3-kinase B', other_designations='inositol-trisphosphate 3-kinase B|IP3 3-kinase B|IP3K B|inositol 1,4,5-trisphosphate 3-kinase B|insP 3-kinase B|proliferation-inducing protein 37', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226631690, end_position_on_the_genomic_accession=226739296, orientation='minus', exon_count=10, OMIM=[147522], no_hdr0=''),
    3708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3708, CurrentID=0, Status='live', Symbol='ITPR1', Aliases=['ACV', 'CLA4', 'INSP3R1', 'IP3R', 'IP3R1', 'PPP1R94', 'SCA15', 'SCA16', 'SCA29'], description='inositol 1,4,5-trisphosphate receptor type 1', other_designations='inositol 1,4,5-trisphosphate receptor type 1|IP3 receptor|IP3R 1|inositol 1,4,5-triphosphate receptor, type 1|protein phosphatase 1, regulatory subunit 94|type 1 InsP3 receptor|type 1 inositol 1,4,5-trisphosphate receptor', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=4493348, end_position_on_the_genomic_accession=4847506, orientation='plus', exon_count=63, OMIM=[147265], no_hdr0=''),
    3709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3709, CurrentID=0, Status='live', Symbol='ITPR2', Aliases=['ANHD', 'CFAP48', 'INSP3R2', 'IP3R2'], description='inositol 1,4,5-trisphosphate receptor type 2', other_designations='inositol 1,4,5-trisphosphate receptor type 2|IP3 receptor|IP3R 2|cilia and flagella associated protein 48|type 2 InsP3 receptor', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26335352, end_position_on_the_genomic_accession=26833197, orientation='minus', exon_count=62, OMIM=[600144], no_hdr0=''),
    3710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3710, CurrentID=0, Status='live', Symbol='ITPR3', Aliases=['IP3R', 'IP3R3'], description='inositol 1,4,5-trisphosphate receptor type 3', other_designations='inositol 1,4,5-trisphosphate receptor type 3|IP3 receptor|inositol 1,4,5-triphosphate receptor, type 3|insP3R3|type 3 InsP3 receptor', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33621322, end_position_on_the_genomic_accession=33696562, orientation='plus', exon_count=59, OMIM=[147267], no_hdr0=''),
    3712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3712, CurrentID=0, Status='live', Symbol='IVD', Aliases=['ACAD2H', 'IVD'], description='isovaleryl-CoA dehydrogenase', other_designations='isovaleryl-CoA dehydrogenase, mitochondrial|butyryl-CoA dehydrogenase|epididymis secretory sperm binding protein|isovaleryl Coenzyme A dehydrogenase', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40405787, end_position_on_the_genomic_accession=40435948, orientation='plus', exon_count=17, OMIM=[607036], no_hdr0=''),
    3713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3713, CurrentID=0, Status='live', Symbol='IVL', Aliases=[], description='involucrin', other_designations='involucrin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152908546, end_position_on_the_genomic_accession=152911886, orientation='plus', exon_count=2, OMIM=[147360], no_hdr0=''),
    3714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3714, CurrentID=0, Status='live', Symbol='JAG2', Aliases=['HJ2', 'SER2'], description='jagged canonical Notch ligand 2', other_designations='protein jagged-2|jagged 2', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105140981, end_position_on_the_genomic_accession=105168776, orientation='minus', exon_count=26, OMIM=[602570], no_hdr0=''),
    3716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3716, CurrentID=0, Status='live', Symbol='JAK1', Aliases=['AIIDEA', 'JAK1B', 'JTK3', 'JAK1'], description='Janus kinase 1', other_designations='tyrosine-protein kinase JAK1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=64833229, end_position_on_the_genomic_accession=65067746, orientation='minus', exon_count=29, OMIM=[147795], no_hdr0=''),
    3717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3717, CurrentID=0, Status='live', Symbol='JAK2', Aliases=['JTK10'], description='Janus kinase 2', other_designations='tyrosine-protein kinase JAK2|JAK-2|Janus kinase 2 (a protein tyrosine kinase)', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4984390, end_position_on_the_genomic_accession=5129948, orientation='plus', exon_count=27, OMIM=[147796], no_hdr0=''),
    3718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3718, CurrentID=0, Status='live', Symbol='JAK3', Aliases=['JAK-3_HUMAN', 'JAKL', 'L-JAK', 'LJAK', 'JAK3'], description='Janus kinase 3', other_designations='tyrosine-protein kinase JAK3|Janus kinase 3 (a protein tyrosine kinase, leukocyte)|leukocyte Janus kinase', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17824782, end_position_on_the_genomic_accession=17848071, orientation='minus', exon_count=25, OMIM=[600173], no_hdr0=''),
    3720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3720, CurrentID=0, Status='live', Symbol='JARID2', Aliases=['JMJ'], description='jumonji and AT-rich interaction domain containing 2', other_designations='protein Jumonji|jumonji homolog|jumonji, AT rich interactive domain 2|jumonji-like protein|jumonji/ARID domain-containing protein 2', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=15245975, end_position_on_the_genomic_accession=15522042, orientation='plus', exon_count=23, OMIM=[601594], no_hdr0=''),
    3725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3725, CurrentID=0, Status='live', Symbol='JUN', Aliases=['AP-1', 'AP1', 'c-Jun', 'cJUN', 'p39'], description='Jun proto-oncogene, AP-1 transcription factor subunit', other_designations='transcription factor AP-1|Jun activation domain binding protein|activator protein 1|enhancer-binding protein AP1|jun oncogene|proto-oncogene c-Jun|proto-oncogene cJun|v-jun avian sarcoma virus 17 oncogene homolog|v-jun sarcoma virus 17 oncogene homolog', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=58780791, end_position_on_the_genomic_accession=58784047, orientation='minus', exon_count=1, OMIM=[165160], no_hdr0=''),
    3726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3726, CurrentID=0, Status='live', Symbol='JUNB', Aliases=['AP-1'], description='JunB proto-oncogene, AP-1 transcription factor subunit', other_designations='transcription factor jun-B|activator protein 1|jun B proto-oncogene', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12791486, end_position_on_the_genomic_accession=12793315, orientation='plus', exon_count=1, OMIM=[165161], no_hdr0=''),
    3727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3727, CurrentID=0, Status='live', Symbol='JUND', Aliases=['AP-1'], description='JunD proto-oncogene, AP-1 transcription factor subunit', other_designations='transcription factor jun-D|activator protein 1|jun D proto-oncogene', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18279694, end_position_on_the_genomic_accession=18281622, orientation='minus', exon_count=1, OMIM=[165162], no_hdr0=''),
    3728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3728, CurrentID=0, Status='live', Symbol='JUP', Aliases=['CTNNG', 'DP3', 'DPIII', 'PDGB', 'PG', 'PKGB'], description='junction plakoglobin', other_designations='junction plakoglobin|catenin (cadherin-associated protein), gamma 80kDa|desmoplakin III|desmoplakin-3|desmosomal protein 3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41754608, end_position_on_the_genomic_accession=41786711, orientation='minus', exon_count=19, OMIM=[173325], no_hdr0=''),
    3730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3730, CurrentID=0, Status='live', Symbol='ANOS1', Aliases=['ADMLX', 'HH1', 'HHA', 'KAL', 'KAL1', 'KALIG-1', 'KMS', 'WFDC19'], description='anosmin 1', other_designations='anosmin-1|Kallmann syndrome interval gene 1|Kallmann syndrome-1 sequence (anosmin-1)|WAP four-disulfide core domain 19|adhesion molecule-like X-linked|kallmann syndrome protein', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=8528874, end_position_on_the_genomic_accession=8732137, orientation='minus', exon_count=15, OMIM=[300836], no_hdr0=''),
    3732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3732, CurrentID=0, Status='live', Symbol='CD82', Aliases=['4F9', 'C33', 'GR15', 'IA4', 'KAI1', 'R2', 'SAR2', 'ST6', 'TSPAN27'], description='CD82 molecule', other_designations='CD82 antigen|C33 antigen|inducible membrane protein R2|kangai 1 (suppression of tumorigenicity 6, prostate; CD82 antigen (R2 leukocyte antigen, antigen detected by monoclonal and antibody IA4))|metastasis suppressor Kangai-1|tetraspanin-27|tspan-27', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44565610, end_position_on_the_genomic_accession=44620363, orientation='plus', exon_count=12, OMIM=[600623], no_hdr0=''),
    3735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3735, CurrentID=0, Status='live', Symbol='KARS1', Aliases=['CMTRIB', 'DEAPLE', 'DFNB89', 'KARS', 'KARS2', 'KRS', 'LEPID'], description='lysyl-tRNA synthetase 1', other_designations='lysine--tRNA ligase|lysRS|lysine tRNA ligase', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75627724, end_position_on_the_genomic_accession=75647665, orientation='minus', exon_count=15, OMIM=[601421], no_hdr0=''),
    3736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3736, CurrentID=0, Status='live', Symbol='KCNA1', Aliases=['AEMK', 'EA1', 'HBK1', 'HUK1', 'KV1.1', 'MBK1', 'MK1', 'RBK1'], description='potassium voltage-gated channel subfamily A member 1', other_designations='potassium voltage-gated channel subfamily A member 1|potassium channel, voltage gated shaker related subfamily A, member 1|potassium voltage-gated channel, shaker-related subfamily, member 1 (episodic ataxia with myokymia)|voltage-gated K(+) channel HuKI|voltage-gated potassium channel HBK1|voltage-gated potassium channel subunit Kv1.1', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4909905, end_position_on_the_genomic_accession=4918256, orientation='plus', exon_count=2, OMIM=[176260], no_hdr0=''),
    3737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3737, CurrentID=0, Status='live', Symbol='KCNA2', Aliases=['DEE32', 'EIEE32', 'HBK5', 'HK4', 'HUKIV', 'KV1.2', 'MK2', 'NGK1', 'RBK2'], description='potassium voltage-gated channel subfamily A member 2', other_designations='potassium voltage-gated channel subfamily A member 2|potassium channel, voltage gated shaker related subfamily A, member 2|potassium voltage-gated channel, shaker-related subfamily, member 2|voltage-gated K(+) channel HuKIV|voltage-gated potassium channel HBK5|voltage-gated potassium channel protein Kv1.2|voltage-gated potassium channel subunit Kv1.2', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110593580, end_position_on_the_genomic_accession=110631536, orientation='minus', exon_count=9, OMIM=[176262], no_hdr0=''),
    3738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3738, CurrentID=0, Status='live', Symbol='KCNA3', Aliases=['HGK5', 'HLK3', 'HPCN3', 'HUKIII', 'KV1.3', 'MK3', 'PCN3'], description='potassium voltage-gated channel subfamily A member 3', other_designations='potassium voltage-gated channel subfamily A member 3|potassium channel 3|potassium channel, voltage gated shaker related subfamily A, member 3|potassium voltage-gated channel, shaker-related subfamily, member 3|type n potassium channel|voltage-gated K(+) channel HuKIII|voltage-gated potassium channel protein Kv1.3|voltage-gated potassium channel subunit Kv1.3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110653560, end_position_on_the_genomic_accession=110674940, orientation='minus', exon_count=4, OMIM=[176263], no_hdr0=''),
    3739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3739, CurrentID=0, Status='live', Symbol='KCNA4', Aliases=['HBK4', 'HK1', 'HPCN2', 'HUKIIL', 'KCNA8', 'KV1.4', 'MCIDDS', 'PCN2', 'KCNA4'], description='potassium voltage-gated channel subfamily A member 4', other_designations='potassium voltage-gated channel subfamily A member 4|cardiac potassium channel|fetal skeletal muscle potassium channel|potassium channel 2|potassium channel, voltage gated shaker related subfamily A, member 4|rapidly inactivating potassium channel|shaker-related potassium channel Kv1.4|type A potassium channel|voltage-gated K(+) channel HuKII|voltage-gated potassium channel HBK4|voltage-gated potassium channel HK1|voltage-gated potassium channel subunit Kv1.4', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=30009730, end_position_on_the_genomic_accession=30017030, orientation='minus', exon_count=2, OMIM=[176266], no_hdr0=''),
    3741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3741, CurrentID=0, Status='live', Symbol='KCNA5', Aliases=['ATFB7', 'HCK1', 'HK2', 'HPCN1', 'KV1.5', 'PCN1'], description='potassium voltage-gated channel subfamily A member 5', other_designations='potassium voltage-gated channel subfamily A member 5|cardiac potassium channel|insulinoma and islet potassium channel|potassium channel 1|potassium channel, voltage gated shaker related subfamily A, member 5|potassium voltage-gated channel, shaker-related subfamily, member 5|voltage-gated potassium channel HK2|voltage-gated potassium channel protein Kv1.5|voltage-gated potassium channel subunit Kv1.5', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=5043879, end_position_on_the_genomic_accession=5046788, orientation='plus', exon_count=1, OMIM=[176267], no_hdr0=''),
    3742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3742, CurrentID=0, Status='live', Symbol='KCNA6', Aliases=['HBK2', 'KV1.6', 'PPP1R96'], description='potassium voltage-gated channel subfamily A member 6', other_designations='potassium voltage-gated channel subfamily A member 6|human brain potassium channel-2|potassium channel, voltage gated shaker related subfamily A, member 6|potassium voltage-gated channel, shaker-related subfamily, member 6|protein phosphatase 1, regulatory subunit 96|voltage-gated potassium channel HBK2|voltage-gated potassium channel protein Kv1.6|voltage-gated potassium channel subunit Kv1.6', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4806877, end_position_on_the_genomic_accession=4851927, orientation='plus', exon_count=4, OMIM=[176257], no_hdr0=''),
    3743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3743, CurrentID=0, Status='live', Symbol='KCNA7', Aliases=['HAK6', 'KV1.7'], description='potassium voltage-gated channel subfamily A member 7', other_designations='potassium voltage-gated channel subfamily A member 7|potassium channel, voltage gated shaker related subfamily A, member 7|potassium voltage-gated channel, shaker-related subfamily, member 7|voltage-dependent potassium channel Kv1.7|voltage-gated potassium channel KCNA7|voltage-gated potassium channel subunit Kv1.7', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49067397, end_position_on_the_genomic_accession=49072699, orientation='minus', exon_count=2, OMIM=[176268], no_hdr0=''),
    3744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3744, CurrentID=0, Status='live', Symbol='KCNA10', Aliases=['Kcn1', 'Kv1.8'], description='potassium voltage-gated channel subfamily A member 10', other_designations='potassium voltage-gated channel subfamily A member 10|cyclic GMP gated potassium channel|potassium channel, voltage gated shaker related subfamily A, member 10|potassium voltage-gated channel, shaker-related subfamily, member 10|voltage-gated potassium channel subunit Kv1.8', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110517217, end_position_on_the_genomic_accession=110519175, orientation='minus', exon_count=1, OMIM=[602420], no_hdr0=''),
    3745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3745, CurrentID=0, Status='live', Symbol='KCNB1', Aliases=['DEE26', 'DRK1', 'Kv2.1'], description='potassium voltage-gated channel subfamily B member 1', other_designations='potassium voltage-gated channel subfamily B member 1|delayed rectifier potassium channel 1|potassium voltage-gated channel, Shab-related subfamily, member 1|voltage-gated potassium channel subunit Kv2.1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49363877, end_position_on_the_genomic_accession=49484033, orientation='minus', exon_count=4, OMIM=[600397], no_hdr0=''),
    3746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3746, CurrentID=0, Status='live', Symbol='KCNC1', Aliases=['EPM7', 'KV3.1', 'KV4', 'NGK2'], description='potassium voltage-gated channel subfamily C member 1', other_designations='potassium voltage-gated channel subfamily C member 1|potassium channel, voltage gated Shaw related subfamily C, member 1|voltage-gated potassium channel protein KV3.1|voltage-gated potassium channel subunit Kv4', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17734781, end_position_on_the_genomic_accession=17783057, orientation='plus', exon_count=5, OMIM=[176258], no_hdr0=''),
    3747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3747, CurrentID=0, Status='live', Symbol='KCNC2', Aliases=['KV3.2'], description='potassium voltage-gated channel subfamily C member 2', other_designations='potassium voltage-gated channel subfamily C member 2|potassium channel, voltage gated Shaw related subfamily C, member 2|potassium voltage-gated channel, Shaw-related subfamily, member 2|shaw-like potassium channel|voltage-gated potassium channel Kv3.2', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75040078, end_position_on_the_genomic_accession=75209839, orientation='minus', exon_count=8, OMIM=[176256], no_hdr0=''),
    3748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3748, CurrentID=0, Status='live', Symbol='KCNC3', Aliases=['KSHIIID', 'KV3.3', 'SCA13'], description='potassium voltage-gated channel subfamily C member 3', other_designations='potassium voltage-gated channel subfamily C member 3|Shaw-related voltage-gated potassium channel protein 3|potassium channel, voltage gated Shaw related subfamily C, member 3|potassium voltage-gated channel, Shaw-related subfamily, member 3|voltage-gated potassium channel protein KV3.3|voltage-gated potassium channel subunit Kv3.3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50311937, end_position_on_the_genomic_accession=50333536, orientation='minus', exon_count=7, OMIM=[176264], no_hdr0=''),
    3749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3749, CurrentID=0, Status='live', Symbol='KCNC4', Aliases=['C1orf30', 'HKSHIIIC', 'KSHIIIC', 'KV3.4'], description='potassium voltage-gated channel subfamily C member 4', other_designations='potassium voltage-gated channel subfamily C member 4|K+ channel subunit|potassium channel, voltage gated Shaw related subfamily C, member 4|potassium voltage-gated channel, Shaw-related subfamily, member 4|voltage-gated potassium channel subunit KV3.4', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110210314, end_position_on_the_genomic_accession=110282649, orientation='plus', exon_count=8, OMIM=[176265], no_hdr0=''),
    3750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3750, CurrentID=0, Status='live', Symbol='KCND1', Aliases=['KV4.1'], description='potassium voltage-gated channel subfamily D member 1', other_designations='potassium voltage-gated channel subfamily D member 1|Shal-type potassium channel|potassium channel, voltage gated Shal related subfamily D, member 1|potassium voltage-gated channel, Shal-related subfamily, member 1|voltage-gated potassium channel subunit Kv4.1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48960983, end_position_on_the_genomic_accession=48972103, orientation='minus', exon_count=7, OMIM=[300281], no_hdr0=''),
    3751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3751, CurrentID=0, Status='live', Symbol='KCND2', Aliases=['KV4.2', 'RK5'], description='potassium voltage-gated channel subfamily D member 2', other_designations='potassium voltage-gated channel subfamily D member 2|potassium channel, voltage gated Shal related subfamily D, member 2|voltage-gated potassium channel subunit Kv4.2|voltage-sensitive potassium channel', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=120273175, end_position_on_the_genomic_accession=120750337, orientation='plus', exon_count=7, OMIM=[605410], no_hdr0=''),
    3752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3752, CurrentID=0, Status='live', Symbol='KCND3', Aliases=['BRGDA9L', 'KCND3S', 'KSHIVB', 'KV4.3', 'SCA19', 'SCA22', 'KCND3'], description='potassium voltage-gated channel subfamily D member 3', other_designations='potassium voltage-gated channel subfamily D member 3|potassium channel, voltage gated Shal related subfamily D, member 3|potassium ionic channel Kv4.3|potassium voltage-gated channel long|potassium voltage-gated channel, Shal-related subfamily, member 3|sha1-related potassium channel Kv4.3|voltage-gated K+ channel|voltage-gated potassium channel subunit Kv4.3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111770662, end_position_on_the_genomic_accession=111989668, orientation='minus', exon_count=14, OMIM=[605411], no_hdr0=''),
    3753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3753, CurrentID=0, Status='live', Symbol='KCNE1', Aliases=['ISK', 'JLNS', 'JLNS2', 'LQT2/5', 'LQT5', 'MinK'], description='potassium voltage-gated channel subfamily E regulatory subunit 1', other_designations='potassium voltage-gated channel subfamily E member 1|IKs producing slow voltage-gated potassium channel subunit beta Mink|Long QT syndrome 5|cardiac delayed rectifier potassium channel protein|delayed rectifier potassium channel subunit IsK|minimal potassium channel|potassium channel, voltage gated subfamily E regulatory beta subunit 1|potassium voltage-gated channel, Isk-related family, member 1|potassium voltage-gated channel, Isk-related subfamily, member 1|voltage gated potassiun channel accessory subunit', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34446688, end_position_on_the_genomic_accession=34512210, orientation='minus', exon_count=7, OMIM=[176261], no_hdr0=''),
    3754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3754, CurrentID=0, Status='live', Symbol='KCNF1', Aliases=['IK8', 'KCNF', 'KV5.1', 'kH1'], description='potassium voltage-gated channel modifier subfamily F member 1', other_designations='potassium voltage-gated channel subfamily F member 1|potassium channel KH1|voltage-gated potassium channel subunit Kv5.1', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10911934, end_position_on_the_genomic_accession=10914225, orientation='plus', exon_count=1, OMIM=[603787], no_hdr0=''),
    3755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3755, CurrentID=0, Status='live', Symbol='KCNG1', Aliases=['K13', 'KCNG', 'KV6.1', 'kH2'], description='potassium voltage-gated channel modifier subfamily G member 1', other_designations='potassium voltage-gated channel subfamily G member 1|potassium channel KH2|potassium channel Kv6.1|potassium channel, voltage gated modifier subfamily G, member 1|potassium voltage-gated channel, subfamily G, member 1|voltage-gated potassium channel subunit Kv6.1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=51003656, end_position_on_the_genomic_accession=51023176, orientation='minus', exon_count=5, OMIM=[603788], no_hdr0=''),
    3756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3756, CurrentID=0, Status='live', Symbol='KCNH1', Aliases=['EAG', 'EAG1', 'Kv10.1', 'TMBTS', 'ZLS1', 'h-eag', 'hEAG', 'hEAG1'], description='potassium voltage-gated channel subfamily H member 1', other_designations='potassium voltage-gated channel subfamily H member 1|EAG channel 1|ether-a-go-go 1|ether-a-go-go potassium channel 1|ether-a-go-go, Drosophila, homolog of|potassium channel, voltage gated eag related subfamily H, member 1|potassium voltage-gated channel, subfamily H (eag-related), member 1|voltage-gated potassium channel subunit Kv10.1', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=210678314, end_position_on_the_genomic_accession=211134148, orientation='minus', exon_count=12, OMIM=[603305], no_hdr0=''),
    3757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3757, CurrentID=0, Status='live', Symbol='KCNH2', Aliases=['ERG-1', 'ERG1', 'H-ERG', 'HERG', 'HERG1', 'Kv11.1', 'LQT2', 'SQT1'], description='potassium voltage-gated channel subfamily H member 2', other_designations='potassium voltage-gated channel subfamily H member 2|eag homolog|eag-related protein 1|ether-a-go-go-related gene potassium channel 1|ether-a-go-go-related potassium channel protein|ether-a-go-go-related protein 1|human ether-a-go-go-related|long QT syndrome type 2|potassium channel, voltage gated eag related subfamily H, member 2|potassium voltage-gated channel, subfamily H (eag-related), member 2|voltage-gated potassium channel subunit Kv11.1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150944956, end_position_on_the_genomic_accession=150978321, orientation='minus', exon_count=19, OMIM=[152427], no_hdr0=''),
    3758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3758, CurrentID=0, Status='live', Symbol='KCNJ1', Aliases=['KIR1.1', 'ROMK', 'ROMK1'], description='potassium inwardly rectifying channel subfamily J member 1', other_designations='ATP-sensitive inward rectifier potassium channel 1|ATP-regulated potassium channel ROM-K|inward rectifier K(+) channel Kir1.1|inwardly rectifying K+ channel|potassium channel, inwardly rectifying subfamily J member 1|potassium voltage-gated channel subfamily J member 1', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128838020, end_position_on_the_genomic_accession=128867296, orientation='minus', exon_count=5, OMIM=[600359], no_hdr0=''),
    3759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3759, CurrentID=0, Status='live', Symbol='KCNJ2', Aliases=['ATFB9', 'HHBIRK1', 'HHIRK1', 'IRK1', 'KIR2.1', 'LQT7', 'SQT3'], description='potassium inwardly rectifying channel subfamily J member 2', other_designations='inward rectifier potassium channel 2|IRK-1|cardiac inward rectifier potassium channel|hIRK1|inward rectifier K+ channel KIR2.1|potassium channel, inwardly rectifying subfamily J, member 2|potassium voltage-gated channel subfamily J member 2', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=70169532, end_position_on_the_genomic_accession=70180044, orientation='plus', exon_count=2, OMIM=[600681], no_hdr0=''),
    3760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3760, CurrentID=0, Status='live', Symbol='KCNJ3', Aliases=['GIRK1', 'KGA', 'KIR3.1'], description='potassium inwardly rectifying channel subfamily J member 3', other_designations='G protein-activated inward rectifier potassium channel 1|GIRK-1|inward rectifier K(+) channel Kir3.1|inward rectifier K+ channel KIR3.1|potassium channel, inwardly rectifying subfamily J member 3|potassium inwardly-rectifying channel subfamily J member 3 splice variant 1e|potassium voltage-gated channel subfamily J member 3', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=154698695, end_position_on_the_genomic_accession=154858354, orientation='plus', exon_count=3, OMIM=[601534], no_hdr0=''),
    3761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3761, CurrentID=0, Status='live', Symbol='KCNJ4', Aliases=['HIR', 'HIRK2', 'HRK1', 'IRK-3', 'IRK3', 'Kir2.3'], description='potassium inwardly rectifying channel subfamily J member 4', other_designations='inward rectifier potassium channel 4|hippocampal inward rectifier potassium channel|inward rectifier K(+) channel Kir2.3|potassium channel, inwardly rectifying subfamily J, member 4|potassium voltage-gated channel subfamily J member 4', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38426327, end_position_on_the_genomic_accession=38455199, orientation='minus', exon_count=3, OMIM=[600504], no_hdr0=''),
    3762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3762, CurrentID=0, Status='live', Symbol='KCNJ5', Aliases=['CIR', 'GIRK4', 'KATP1', 'KIR3.4', 'LQT13'], description='potassium inwardly rectifying channel subfamily J member 5', other_designations='G protein-activated inward rectifier potassium channel 4|IRK-4|cardiac ATP-sensitive potassium channel|heart KATP channel|inward rectifier K+ channel KIR3.4|potassium channel, inwardly rectifying subfamily J, member 5|potassium voltage-gated channel subfamily J member 5', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128891356, end_position_on_the_genomic_accession=128921163, orientation='plus', exon_count=5, OMIM=[600734], no_hdr0=''),
    3763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3763, CurrentID=0, Status='live', Symbol='KCNJ6', Aliases=['BIR1', 'GIRK-2', 'GIRK2', 'KATP-2', 'KATP2', 'KCNJ7', 'KIR3.2', 'KPLBS', 'hiGIRK2'], description='potassium inwardly rectifying channel subfamily J member 6', other_designations='G protein-activated inward rectifier potassium channel 2|inward rectifier K(+) channel Kir3.2|inward rectifier potassium channel KIR3.2|potassium channel, inwardly rectifying subfamily J, member 6|potassium voltage-gated channel subfamily J member 6', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37607373, end_position_on_the_genomic_accession=37916457, orientation='minus', exon_count=4, OMIM=[600877], no_hdr0=''),
    3764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3764, CurrentID=0, Status='live', Symbol='KCNJ8', Aliases=['KIR6.1', 'uKATP-1'], description='potassium inwardly rectifying channel subfamily J member 8', other_designations='ATP-sensitive inward rectifier potassium channel 8|inward rectifier K(+) channel Kir6.1|inwardly rectifying potassium channel KIR6.1|potassium channel, inwardly rectifying subfamily J member 8|potassium voltage-gated channel subfamily J member 8', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21764955, end_position_on_the_genomic_accession=21775593, orientation='minus', exon_count=5, OMIM=[600935], no_hdr0=''),
    3765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3765, CurrentID=0, Status='live', Symbol='KCNJ9', Aliases=['GIRK3', 'KIR3.3'], description='potassium inwardly rectifying channel subfamily J member 9', other_designations='G protein-activated inward rectifier potassium channel 3|G protein-coupled inward rectifier potassium channel|inward rectifier K(+) channel Kir3.3|inwardly rectifier K+ channel KIR3.3|potassium channel, inwardly rectifying subfamily J member 9|potassium voltage-gated channel subfamily J member 9', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160081538, end_position_on_the_genomic_accession=160090563, orientation='plus', exon_count=3, OMIM=[600932], no_hdr0=''),
    3766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3766, CurrentID=0, Status='live', Symbol='KCNJ10', Aliases=['BIRK-10', 'KCNJ13-PEN', 'KIR1.2', 'KIR4.1', 'SESAME'], description='potassium inwardly rectifying channel subfamily J member 10', other_designations='ATP-sensitive inward rectifier potassium channel 10|ATP-dependent inwardly rectifying potassium channel Kir4.1|glial ATP-dependent inwardly rectifying potassium channel KIR4.1|inward rectifier K(+) channel Kir1.2|inward rectifier K+ channel KIR1.2|potassium channel, inwardly rectifying subfamily J member 10|potassium voltage-gated channel subfamily J member 10', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160037467, end_position_on_the_genomic_accession=160070160, orientation='minus', exon_count=2, OMIM=[602208], no_hdr0=''),
    3767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3767, CurrentID=0, Status='live', Symbol='KCNJ11', Aliases=['BIR', 'HHF2', 'IKATP', 'KIR6.2', 'MODY13', 'PHHI', 'PNDM2', 'TNDM3'], description='potassium inwardly rectifying channel subfamily J member 11', other_designations='ATP-sensitive inward rectifier potassium channel 11|beta-cell inward rectifier subunit|inward rectifier K(+) channel Kir6.2|inwardly rectifing potassium channel subfamily J member 11|inwardly rectifying potassium channel KIR6.2|inwardly-rectifying potassium channel subfamily J member 11|potassium channel inwardly rectifing subfamily J member 11|potassium channel, inwardly rectifying subfamily J member 11|potassium voltage-gated channel subfamily J member 11', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17385246, end_position_on_the_genomic_accession=17389346, orientation='minus', exon_count=4, OMIM=[600937], no_hdr0=''),
    3768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3768, CurrentID=0, Status='live', Symbol='KCNJ12', Aliases=['IRK-2', 'IRK2', 'KCNJN1', 'Kir2.2', 'Kir2.2v', 'hIRK', 'hIRK1', 'hkir2.2x', 'kcnj12x'], description='potassium inwardly rectifying channel subfamily J member 12', other_designations='ATP-sensitive inward rectifier potassium channel 12|inward rectifier K(+) channel Kir2.2v|inward rectifier K(+) channel Kir2.6|potassium channel, inwardly rectifying subfamily J, member 12|potassium inwardly-rectifying channel, subfamily J, inhibitor 1|potassium voltage-gated channel subfamily J member 12', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21376357, end_position_on_the_genomic_accession=21419870, orientation='plus', exon_count=5, OMIM=[602323], no_hdr0=''),
    3769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3769, CurrentID=0, Status='live', Symbol='KCNJ13', Aliases=['KIR1.4', 'KIR7.1', 'LCA16', 'SVD'], description='potassium inwardly rectifying channel subfamily J member 13', other_designations='inward rectifier potassium channel 13|inward rectifier K(+) channel Kir7.1|potassium channel, inwardly rectifying subfamily J, member 13|potassium voltage-gated channel subfamily J member 13', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232765802, end_position_on_the_genomic_accession=232776565, orientation='minus', exon_count=3, OMIM=[603208], no_hdr0=''),
    3770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3770, CurrentID=0, Status='live', Symbol='KCNJ14', Aliases=['IRK4', 'KIR2.4'], description='potassium inwardly rectifying channel subfamily J member 14', other_designations='ATP-sensitive inward rectifier potassium channel 14|inward rectifier K(+) channel Kir2.4|inwardly rectifying potassium channel KIR2.4|potassium channel, inwardly rectifying subfamily J member 14|potassium voltage-gated channel subfamily J member 14', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48455574, end_position_on_the_genomic_accession=48466980, orientation='plus', exon_count=3, OMIM=[603953], no_hdr0=''),
    3772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3772, CurrentID=0, Status='live', Symbol='KCNJ15', Aliases=['IRKK', 'KIR1.3', 'KIR4.2'], description='potassium inwardly rectifying channel subfamily J member 15', other_designations='ATP-sensitive inward rectifier potassium channel 15|inward rectifier K(+) channel Kir1.3|inward rectifier K(+) channel Kir4.2|inward rectifier K+ channel KIR4.2|potassium channel, inwardly rectifying subfamily J member 15|potassium voltage-gated channel subfamily J member 15', map_location='21q22.13-q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=38229926, end_position_on_the_genomic_accession=38307357, orientation='plus', exon_count=11, OMIM=[602106], no_hdr0=''),
    3773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3773, CurrentID=0, Status='live', Symbol='KCNJ16', Aliases=['BIR9', 'HKTD', 'KIR5.1'], description='potassium inwardly rectifying channel subfamily J member 16', other_designations='inward rectifier potassium channel 16|inward rectifier K(+) channel Kir5.1|inward rectifier K+ channel KIR5.1|potassium channel, inwardly rectifying subfamily J member 16|potassium voltage-gated channel subfamily J member 16', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=70075225, end_position_on_the_genomic_accession=70135608, orientation='plus', exon_count=10, OMIM=[605722], no_hdr0=''),
    3775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3775, CurrentID=0, Status='live', Symbol='KCNK1', Aliases=['DPK', 'HOHO', 'K2P1', 'K2p1.1', 'KCNO1', 'TWIK-1', 'TWIK1'], description='potassium two pore domain channel subfamily K member 1', other_designations='potassium channel subfamily K member 1|inward rectifying potassium channel protein TWIK-1|potassium channel K2P1|potassium channel KCNO1|potassium channel, two pore domain subfamily K, member 1|potassium inwardly-rectifying channel, subfamily K, member 1|tandem of P domains in a weak inward rectifying K+ channel 1', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=233614106, end_position_on_the_genomic_accession=233672514, orientation='plus', exon_count=6, OMIM=[601745], no_hdr0=''),
    3776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3776, CurrentID=0, Status='live', Symbol='KCNK2', Aliases=['K2p2.1', 'TPKC1', 'TREK', 'TREK-1', 'TREK1', 'hTREK-1c', 'hTREK-1e'], description='potassium two pore domain channel subfamily K member 2', other_designations='potassium channel subfamily K member 2|K2P2.1 potassium channel|TREK-1 K(+) channel subunit|TWIK-related potassium channel 1|outward rectifying potassium channel protein TREK-1|potassium channel subfamily k member 2 variant 1|potassium channel subfamily k member 2 variant 2|potassium channel, two pore domain subfamily K, member 2|potassium inwardly-rectifying channel, subfamily K, member 2|tandem-pore-domain potassium channel TREK-1|two pore domain potassium channel TREK-1|two pore potassium channel TPKC1|two-pore potassium channel 1', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=215002920, end_position_on_the_genomic_accession=215237093, orientation='plus', exon_count=13, OMIM=[603219], no_hdr0=''),
    3777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3777, CurrentID=0, Status='live', Symbol='KCNK3', Aliases=['K2p3.1', 'OAT1', 'PPH4', 'TASK', 'TASK-1', 'TASK1', 'TBAK1'], description='potassium two pore domain channel subfamily K member 3', other_designations='potassium channel subfamily K member 3|TWIK-related acid-sensitive K(+) channel 1|TWIK-related acid-sensitive K+ 1|TWIK-related acid-sensitive K+ channel|acid-sensitive potassium channel protein TASK|acid-sensitive potassium channel protein TASK-1|cardiac potassium channel|potassium channel, two pore domain subfamily K, member 3|potassium inwardly-rectifying channel, subfamily K, member 3|two P domain potassium channel|two pore K(+) channel KT3.1|two pore potassium channel KT3.1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26692722, end_position_on_the_genomic_accession=26733420, orientation='plus', exon_count=3, OMIM=[603220], no_hdr0=''),
    3778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3778, CurrentID=0, Status='live', Symbol='KCNMA1', Aliases=['BKTM', 'CADEDS', 'IEG16', 'KCa1.1', 'LIWAS', 'MaxiK', 'PNKD3', 'SAKCA', 'SLO', 'SLO-ALPHA', 'SLO1', 'bA205K10.1', 'hSlo', 'mSLO1'], description='potassium calcium-activated channel subfamily M alpha 1', other_designations='calcium-activated potassium channel subunit alpha-1|uncharacterized protein LOC3778|BK channel alpha subunit|BKCA alpha subunit|big potassium channel alpha subunit|calcium-activated potassium channel, subfamily M subunit alpha-1|k(VCA)alpha|maxi-K channel HSLO|potassium channel, calcium activated large conductance subfamily M alpha, member 1|potassium large conductance calcium-activated channel, subfamily M, alpha member 1|slo homolog|slowpoke homolog|stretch-activated Kca channel', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=76869602, end_position_on_the_genomic_accession=77637969, orientation='minus', exon_count=46, OMIM=[600150], no_hdr0=''),
    3779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3779, CurrentID=0, Status='live', Symbol='KCNMB1', Aliases=['BKbeta1', 'K(VCA)beta', 'SLO-BETA', 'hbeta1', 'hslo-beta', 'k(VCA)beta-1', 'slo-beta-1'], description='potassium calcium-activated channel subfamily M regulatory beta subunit 1', other_designations='calcium-activated potassium channel subunit beta-1|BK channel beta subunit 1|BK channel subunit beta-1|MaxiK channel beta-subunit 1|big potassium channel beta subunit 1|calcium-activated potassium channel, subfamily M subunit beta-1|charybdotoxin receptor subunit beta-1|large conductance Ca2+-activated K+ channel beta 1 subunit|maxi K channel subunit beta-1|potassium channel subfamily M regulatory beta subunit 1|potassium large conductance calcium-activated channel, subfamily M, beta member 1', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170374671, end_position_on_the_genomic_accession=170389367, orientation='minus', exon_count=4, OMIM=[603951], no_hdr0=''),
    3780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3780, CurrentID=0, Status='live', Symbol='KCNN1', Aliases=['KCa2.1', 'SK1', 'SKCA1', 'hSK1'], description='potassium calcium-activated channel subfamily N member 1', other_designations='small conductance calcium-activated potassium channel protein 1|potassium channel, calcium activated intermediate/small conductance subfamily N alpha, member 1|potassium intermediate/small conductance calcium-activated channel, subfamily N, member 1|small conductance calcium-activated potassium channel 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17951290, end_position_on_the_genomic_accession=18000085, orientation='plus', exon_count=14, OMIM=[602982], no_hdr0=''),
    3781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3781, CurrentID=0, Status='live', Symbol='KCNN2', Aliases=['KCa2.2', 'SK2', 'SKCA2', 'SKCa 2', 'hSK2'], description='potassium calcium-activated channel subfamily N member 2', other_designations='small conductance calcium-activated potassium channel protein 2|apamin-sensitive small-conductance Ca2+-activated potassium channel|potassium channel, calcium activated intermediate/small conductance subfamily N alpha, member 2|potassium intermediate/small conductance calcium-activated channel, subfamily N, member 2|small conductance calcium-activated potassium channel 2', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=114055978, end_position_on_the_genomic_accession=114496500, orientation='plus', exon_count=16, OMIM=[605879], no_hdr0=''),
    3782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3782, CurrentID=0, Status='live', Symbol='KCNN3', Aliases=['KCa2.3', 'SK3', 'SKCA3', 'ZLS3', 'hSK3'], description='potassium calcium-activated channel subfamily N member 3', other_designations='small conductance calcium-activated potassium channel protein 3|SKCa 3|potassium channel, calcium activated intermediate/small conductance subfamily N alpha, member 3|potassium intermediate/small conductance calcium-activated channel, subfamily N, member 3|small conductance calcium-activated potassium channel 3', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154697455, end_position_on_the_genomic_accession=154870281, orientation='minus', exon_count=11, OMIM=[602983], no_hdr0=''),
    3783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3783, CurrentID=0, Status='live', Symbol='KCNN4', Aliases=['DHS2', 'IK', 'IK1', 'IKCA1', 'KCA4', 'KCa3.1', 'SK4', 'hIKCa1', 'hKCa4', 'hSK4'], description='potassium calcium-activated channel subfamily N member 4', other_designations='intermediate conductance calcium-activated potassium channel protein 4|SKCa 4|SKCa4|intermediate-conductance Ca2+-activated K+ channel, KCa3.1|potassium channel, calcium activated intermediate/small conductance subfamily N alpha, member 4|potassium intermediate/small conductance calcium-activated channel, subfamily N, member 4|putative Gardos channel|putative erythrocyte intermediate conductance calcium-activated potassium Gardos channel|small conductance calcium-activated potassium channel 4', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43766533, end_position_on_the_genomic_accession=43782139, orientation='minus', exon_count=10, OMIM=[602754], no_hdr0=''),
    3784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3784, CurrentID=0, Status='live', Symbol='KCNQ1', Aliases=['ATFB1', 'ATFB3', 'JLNS1', 'KCNA8', 'KCNA9', 'KVLQT1', 'Kv1.9', 'Kv7.1', 'LQT', 'LQT1', 'RWS', 'SQT2', 'WRS'], description='potassium voltage-gated channel subfamily Q member 1', other_designations='potassium voltage-gated channel subfamily KQT member 1|IKs producing slow voltage-gated potassium channel subunit alpha KvLQT1|kidney and cardiac voltage dependend K+ channel|potassium channel, voltage gated KQT-like subfamily Q, member 1|potassium voltage-gated channel, KQT-like subfamily, member 1|slow delayed rectifier channel subunit|voltage-gated potassium channel subunit Kv7.1', map_location='11p15.5-p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2445008, end_position_on_the_genomic_accession=2849110, orientation='plus', exon_count=17, OMIM=[607542], no_hdr0=''),
    3785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3785, CurrentID=0, Status='live', Symbol='KCNQ2', Aliases=['BFNC', 'DEE7', 'EBN', 'EBN1', 'ENB1', 'HNSPC', 'KCNA11', 'KV7.2'], description='potassium voltage-gated channel subfamily Q member 2', other_designations='potassium voltage-gated channel subfamily KQT member 2|neuroblastoma-specific potassium channel subunit alpha KvLQT2|potassium channel, voltage gated KQT-like subfamily Q, member 2|voltage-gated potassium channel subunit Kv7.2', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63400208, end_position_on_the_genomic_accession=63472655, orientation='minus', exon_count=19, OMIM=[602235], no_hdr0=''),
    3786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3786, CurrentID=0, Status='live', Symbol='KCNQ3', Aliases=['BFNC2', 'EBN2', 'KV7.3'], description='potassium voltage-gated channel subfamily Q member 3', other_designations='potassium voltage-gated channel subfamily KQT member 3|potassium channel subunit alpha KvLQT3|potassium channel, voltage gated KQT-like subfamily Q, member 3|potassium channel, voltage-gated, subfamily Q, member 3|potassium voltage-gated channel, KQT-like subfamily, member 3|voltage-gated potassium channel subunit Kv7.3', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132120858, end_position_on_the_genomic_accession=132481095, orientation='minus', exon_count=18, OMIM=[602232], no_hdr0=''),
    3787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3787, CurrentID=0, Status='live', Symbol='KCNS1', Aliases=['Kv9.1'], description='potassium voltage-gated channel modifier subfamily S member 1', other_designations='potassium voltage-gated channel subfamily S member 1|delayed-rectifier K(+) channel alpha subunit 1|potassium voltage-gated channel, delayed-rectifier, subfamily S, member 1|voltage-gated potassium channel subunit Kv9.1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45091214, end_position_on_the_genomic_accession=45101127, orientation='minus', exon_count=5, OMIM=[602905], no_hdr0=''),
    3788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3788, CurrentID=0, Status='live', Symbol='KCNS2', Aliases=['KV9.2'], description='potassium voltage-gated channel modifier subfamily S member 2', other_designations='potassium voltage-gated channel subfamily S member 2|delayed-rectifier K(+) channel alpha subunit 2|potassium voltage-gated channel, delayed-rectifier, subfamily S, member 2|voltage-gated potassium channel subunit Kv9.2', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98426958, end_position_on_the_genomic_accession=98432853, orientation='plus', exon_count=2, OMIM=[602906], no_hdr0=''),
    3790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3790, CurrentID=0, Status='live', Symbol='KCNS3', Aliases=['KV9.3'], description='potassium voltage-gated channel modifier subfamily S member 3', other_designations='potassium voltage-gated channel subfamily S member 3|Shab-related delayed-rectifier K+ channel alpha subunit 3|delayed-rectifier K(+) channel alpha subunit 3|potassium voltage-gated channel delayed-rectifier protein S3|potassium voltage-gated channel, delayed-rectifier, subfamily S, member 3|voltage-gated potassium channel protein Kv9.3|voltage-gated potassium channel subunit Kv9.3', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17877847, end_position_on_the_genomic_accession=17932961, orientation='plus', exon_count=5, OMIM=[603888], no_hdr0=''),
    3791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3791, CurrentID=0, Status='live', Symbol='KDR', Aliases=['CD309', 'FLK1', 'VEGFR', 'VEGFR2'], description='kinase insert domain receptor', other_designations='vascular endothelial growth factor receptor 2|fetal liver kinase-1|kinase insert domain receptor (a type III receptor tyrosine kinase)|protein-tyrosine kinase receptor Flk-1|soluble VEGFR2|tyrosine kinase growth factor receptor', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55078481, end_position_on_the_genomic_accession=55125595, orientation='minus', exon_count=30, OMIM=[191306], no_hdr0=''),
    3792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3792, CurrentID=0, Status='live', Symbol='KEL', Aliases=['CD238', 'ECE3', 'Kell'], description='Kell metallo-endopeptidase (Kell blood group)', other_designations='kell blood group glycoprotein|Kell blood group, metallo-endopeptidase|Kell glycoprotein|truncated Kell blood group antigen|truncated Kell blood group glycoprotein', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142941114, end_position_on_the_genomic_accession=142962363, orientation='minus', exon_count=20, OMIM=[613883], no_hdr0=''),
    3795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3795, CurrentID=0, Status='live', Symbol='KHK', Aliases=[], description='ketohexokinase', other_designations='ketohexokinase|fructokinase|hepatic fructokinase|testicular tissue protein Li 102', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27086760, end_position_on_the_genomic_accession=27100762, orientation='plus', exon_count=9, OMIM=[614058], no_hdr0=''),
    3796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3796, CurrentID=0, Status='live', Symbol='KIF2A', Aliases=['CDCBM3', 'HK2', 'KIF2'], description='kinesin family member 2A', other_designations='kinesin-like protein KIF2A|Kinesin, heavy chain, 2|kinesin heavy chain member 2A|kinesin-2', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=62306167, end_position_on_the_genomic_accession=62391025, orientation='plus', exon_count=23, OMIM=[602591], no_hdr0=''),
    3797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3797, CurrentID=0, Status='live', Symbol='KIF3C', Aliases=[], description='kinesin family member 3C', other_designations='kinesin-like protein KIF3C|KIF3C variant protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25926598, end_position_on_the_genomic_accession=25982740, orientation='minus', exon_count=8, OMIM=[602845], no_hdr0=''),
    3798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3798, CurrentID=0, Status='live', Symbol='KIF5A', Aliases=['ALS25', 'D12S1889', 'MY050', 'NEIMY', 'NKHC', 'SPG10'], description='kinesin family member 5A', other_designations='kinesin heavy chain isoform 5A|KIF5A variant protein|kinesin heavy chain neuron-specific 1|kinesin, heavy chain, neuron-specific|neuronal kinesin heavy chain', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57550039, end_position_on_the_genomic_accession=57586633, orientation='plus', exon_count=28, OMIM=[602821], no_hdr0=''),
    3799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3799, CurrentID=0, Status='live', Symbol='KIF5B', Aliases=['HEL-S-61', 'KINH', 'KNS', 'KNS1', 'UKHC'], description='kinesin family member 5B', other_designations='kinesin-1 heavy chain|conventional kinesin heavy chain|epididymis secretory protein Li 61|kinesin 1 (110-120kD)|kinesin heavy chain|ubiquitous kinesin heavy chain', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=32009015, end_position_on_the_genomic_accession=32056425, orientation='minus', exon_count=27, OMIM=[602809], no_hdr0=''),
    3800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3800, CurrentID=0, Status='live', Symbol='KIF5C', Aliases=['CDCBM2', 'KINN', 'NKHC', 'NKHC-2', 'NKHC2'], description='kinesin family member 5C', other_designations='kinesin heavy chain isoform 5C|kinesin heavy chain|kinesin heavy chain neuron-specific 2', map_location='2q23.1-q23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=148875227, end_position_on_the_genomic_accession=149026759, orientation='plus', exon_count=28, OMIM=[604593], no_hdr0=''),
    3801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3801, CurrentID=0, Status='live', Symbol='KIFC3', Aliases=[], description='kinesin family member C3', other_designations='kinesin-like protein KIFC3', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57758217, end_position_on_the_genomic_accession=57863053, orientation='minus', exon_count=34, OMIM=[604535], no_hdr0=''),
    3802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3802, CurrentID=0, Status='live', Symbol='KIR2DL1', Aliases=['CD158A', 'KIR-K64', 'KIR221', 'KIR2DL3', 'NKAT', 'NKAT-1', 'NKAT1', 'p58.1'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 1', other_designations='killer cell immunoglobulin-like receptor 2DL1|CD158 antigen-like family member A|KIR2DL protein|KIR2DL1/3DL2|MHC class I NK cell receptor|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 1|killer inhibitory receptor 2-2-1|natural killer-associated transcript 1|p58 NK cell inhibitory receptor NKR-K6|p58 NK receptor CL-42/47.11|p58 killer cell inhibitory receptor KIR-K64|p58 natural killer cell receptor clones CL-42/47.11|p58.1 MHC class-I-specific NK receptor', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54769208, end_position_on_the_genomic_accession=54784326, orientation='plus', exon_count=11, OMIM=[604936], no_hdr0=''),
    3803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3803, CurrentID=0, Status='live', Symbol='KIR2DL2', Aliases=['CD158B1', 'CD158b', 'NKAT-6', 'NKAT6', 'p58.2'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 2', other_designations='killer cell immunoglobulin-like receptor 2DL2|CD158 antigen-like family member B1|MHC class I NK cell receptor|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 2|natural killer-associated transcript 6|p58 NK receptor CL-43|p58 natural killer cell receptor clone CL-43', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604937], no_hdr0=''),
    3804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3804, CurrentID=0, Status='live', Symbol='KIR2DL3', Aliases=['CD158B2', 'CD158b', 'GL183', 'KIR-023GB', 'KIR-K7b', 'KIR-K7c', 'KIR2DL', 'KIR2DS5', 'KIRCL23', 'NKAT', 'NKAT2', 'NKAT2A', 'NKAT2B', 'p58'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 3', other_designations='killer cell immunoglobulin-like receptor 2DL3|CD158 antigen-like family member B2|NKAT-2|killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 3|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 5|killer inhibitory receptor cl 2-3|natural killer associated transcript 2|natural killer cell inhibitory receptor KIR2DL3|p58 NK receptor CL-6|p58 natural killer cell receptor clone CL-6|p58.2 MHC class-I specific NK receptor', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54738513, end_position_on_the_genomic_accession=54753052, orientation='plus', exon_count=8, OMIM=[604938], no_hdr0=''),
    3805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3805, CurrentID=0, Status='live', Symbol='KIR2DL4', Aliases=['CD158D', 'G9P', 'KIR-103AS', 'KIR-2DL4', 'KIR103', 'KIR103AS'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 4', other_designations='killer cell immunoglobulin-like receptor 2DL4|CD158 antigen-like family member D|KIR2DL4 Killer-cell Immunoglobulin-like Receptor|KIR2DL4_00201|KIR2DL4_00201 protein|MHC class I NK cell receptor KIR103AS|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 4|killer cell inhibitory receptor 103AS', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54803610, end_position_on_the_genomic_accession=54814517, orientation='plus', exon_count=8, OMIM=[604945], no_hdr0=''),
    3806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3806, CurrentID=0, Status='live', Symbol='KIR2DS1', Aliases=['CD158H', 'CD158a', 'p50.1'], description='killer cell immunoglobulin like receptor, two Ig domains and short cytoplasmic tail 1', other_designations='killer cell immunoglobulin-like receptor 2DS1|CD158 antigen-like family member H|KIR2DS1 Killer-cell Immunoglobulin-like Receptor|MHC class I NK cell receptor Eb6 ActI|killer cell immunoglobulin-like receptor KIRDS1|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 1|killer-cell immunoglobulin-like receptor', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604952], no_hdr0=''),
    3808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3808, CurrentID=0, Status='live', Symbol='KIR2DS3', Aliases=['NKAT7'], description='killer cell immunoglobulin like receptor, two Ig domains and short cytoplasmic tail 3', other_designations='killer cell immunoglobulin-like receptor 2DS3|MHC class I NK cell receptor|NKAT-7|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 3|natural killer cell inhibitory receptor|natural killer-associated transcript 7', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604954], no_hdr0=''),
    3809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3809, CurrentID=0, Status='live', Symbol='KIR2DS4', Aliases=['CD158I', 'KIR-2DS4', 'KIR1D', 'KIR412', 'KKA3', 'NKAT-8', 'NKAT8'], description='killer cell immunoglobulin like receptor, two Ig domains and short cytoplasmic tail 4', other_designations='killer cell immunoglobulin-like receptor 2DS4|CD158 antigen-like family member I|KIR antigen 2DS4|P58 natural killer cell receptor clones CL-39/CL-17|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 4|killer inhibitory receptor 4-1-2|natural killer-associated transcript 8|p50 killer cell activating receptor KAR-K1d|p58 NK receptor CL-39/CL-17', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54832707, end_position_on_the_genomic_accession=54848575, orientation='plus', exon_count=8, OMIM=[604955], no_hdr0=''),
    3810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3810, CurrentID=0, Status='live', Symbol='KIR2DS5', Aliases=['CD158G', 'NKAT9'], description='killer cell immunoglobulin like receptor, two Ig domains and short cytoplasmic tail 5', other_designations='killer cell immunoglobulin-like receptor 2DS5|CD158 antigen-like family member G|NKAT-9|killer Ig receptor|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 5|natural killer cell inhibitory receptor|natural killer-associated transcript 9', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604956], no_hdr0=''),
    3811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3811, CurrentID=0, Status='live', Symbol='KIR3DL1', Aliases=['CD158E1', 'KIR', 'KIR2DL5B/S1', 'NKAT-3', 'NKAT3', 'NKB1', 'NKB1B', 'KIR3DL1'], description='killer cell immunoglobulin like receptor, three Ig domains and long cytoplasmic tail 1', other_designations='killer cell immunoglobulin-like receptor 3DL1|CD158 antigen-like family member E|HLA-BW4-specific inhibitory NK cell receptor|KIR antigen 3DL1|killer cell immunoglobulin-like receptor, three domains, long cytoplasmic tail, 1|natural killer-associated transcript 3|p70 NK receptor CL-2/CL-11|p70 killer cell inhibitory receptor|p70 natural killer cell receptor clones CL-2/CL-11', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54816438, end_position_on_the_genomic_accession=54830778, orientation='plus', exon_count=9, OMIM=[604946], no_hdr0=''),
    3812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3812, CurrentID=0, Status='live', Symbol='KIR3DL2', Aliases=['3DL2', 'CD158K', 'KIR-3DL2', 'NKAT-4', 'NKAT4', 'NKAT4B', 'p140'], description='killer cell immunoglobulin like receptor, three Ig domains and long cytoplasmic tail 2', other_designations='killer cell immunoglobulin-like receptor 3DL2|CD158 antigen-like family member K|KIR antigen 3DL2|MHC class I NK cell receptor|killer Ig receptor|killer cell immunoglobulin-like receptor 2DL2|killer cell immunoglobulin-like receptor, three domains, long cytoplasmic tail, 2|killer-cell immunoglobulin-like receptor|natural killer-associated transcript 4|p70 NK receptor CL-5|p70 killer cell inhibitory receptor|p70 natural killer cell receptor clone CL-5', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54850320, end_position_on_the_genomic_accession=54867209, orientation='plus', exon_count=10, OMIM=[604947], no_hdr0=''),
    3813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3813, CurrentID=0, Status='live', Symbol='KIR3DS1', Aliases=['CD158E2', 'KIR-123FM', 'KIR-G1', 'NKAT-10', 'NKAT10'], description='killer cell immunoglobulin like receptor, three Ig domains and short cytoplasmic tail 1', other_designations='killer cell immunoglobulin-like receptor 3DS1|killer cell immunoglobulin-like receptor KIR3DS1|killer cell immunoglobulin-like receptor, three domains, short cytoplasmic tail, 1|natural killer-associated transcript 10', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    3814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3814, CurrentID=0, Status='live', Symbol='KISS1', Aliases=['HH13', 'KiSS-1'], description='KiSS-1 metastasis suppressor', other_designations='metastasis-suppressor KiSS-1|kisspeptin-1|malignant melanoma metastasis-suppressor|metastin|prepro-kisspeptin', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204190341, end_position_on_the_genomic_accession=204196491, orientation='minus', exon_count=3, OMIM=[603286], no_hdr0=''),
    3815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3815, CurrentID=0, Status='live', Symbol='KIT', Aliases=['C-Kit', 'CD117', 'MASTC', 'PBT', 'SCFR'], description='KIT proto-oncogene, receptor tyrosine kinase', other_designations='mast/stem cell growth factor receptor Kit|c-Kit protooncogene|p145 c-kit|piebald trait protein|proto-oncogene c-Kit|proto-oncogene tyrosine-protein kinase Kit|soluble KIT variant 1|tyrosine-protein kinase Kit|v-kit Hardy-Zuckerman 4 feline sarcoma viral oncogene homolog|v-kit Hardy-Zuckerman 4 feline sarcoma viral oncogene-like protein', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=54657957, end_position_on_the_genomic_accession=54740715, orientation='plus', exon_count=21, OMIM=[164920], no_hdr0=''),
    3816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3816, CurrentID=0, Status='live', Symbol='KLK1', Aliases=['KLKR', 'Klk6', 'hK1'], description='kallikrein 1', other_designations='kallikrein-1|glandular kallikrein 1|kallikrein 1, renal/pancreas/salivary|kallikrein serine protease 1|kidney/pancreas/salivary gland kallikrein|tissue kallikrein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50819146, end_position_on_the_genomic_accession=50823787, orientation='minus', exon_count=6, OMIM=[147910], no_hdr0=''),
    3817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3817, CurrentID=0, Status='live', Symbol='KLK2', Aliases=['KLK2A2', 'hGK-1', 'hK2'], description='kallikrein related peptidase 2', other_designations='kallikrein-2|glandular kallikrein 2|glandular kallikrein-1|kallikrein 2, prostatic|tissue kallikrein-2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50873439, end_position_on_the_genomic_accession=50880567, orientation='plus', exon_count=5, OMIM=[147960], no_hdr0=''),
    3818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3818, CurrentID=0, Status='live', Symbol='KLKB1', Aliases=['KLK3', 'PKK', 'PKKD', 'PPK'], description='kallikrein B1', other_designations='plasma kallikrein|kallikrein B, plasma (Fletcher factor) 1|kininogenin|plasma prekallikrein', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186215714, end_position_on_the_genomic_accession=186258477, orientation='plus', exon_count=17, OMIM=[229000], no_hdr0=''),
    3820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3820, CurrentID=0, Status='live', Symbol='KLRB1', Aliases=['CD161', 'CLEC5B', 'NKR', 'NKR-P1', 'NKR-P1A', 'NKRP1A', 'hNKR-P1A'], description='killer cell lectin like receptor B1', other_designations='killer cell lectin-like receptor subfamily B member 1|C-type lectin domain family 5 member B|killer cell lectin-like receptor subfamily B, member 1|natural killer cell surface protein P1A', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9594551, end_position_on_the_genomic_accession=9607916, orientation='minus', exon_count=6, OMIM=[602890], no_hdr0=''),
    3821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3821, CurrentID=0, Status='live', Symbol='KLRC1', Aliases=['CD159A', 'NKG2', 'NKG2A'], description='killer cell lectin like receptor C1', other_designations='NKG2-A/NKG2-B type II integral membrane protein|C-lectin type II protein|CD159 antigen-like family member A|NK cell receptor A|NKG2-1/B activating NK receptor|NKG2-A/B type II integral membrane protein|NKG2-A/B-activating NK receptor|killer cell lectin-like receptor subfamily C, member 1|natural killer cell lectin|natural killer group protein 2', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10441673, end_position_on_the_genomic_accession=10454685, orientation='minus', exon_count=9, OMIM=[161555], no_hdr0=''),
    3822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3822, CurrentID=0, Status='live', Symbol='KLRC2', Aliases=['CD159c', 'NKG2-C', 'NKG2C'], description='killer cell lectin like receptor C2', other_designations='NKG2-C type II integral membrane protein|CD159 antigen-like family member C|NK cell receptor C|NKG2-C-activating NK receptor|killer cell lectin-like receptor subfamily C, member 2|natural killer cell receptor G2-C', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10430599, end_position_on_the_genomic_accession=10436010, orientation='minus', exon_count=6, OMIM=[602891], no_hdr0=''),
    3823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3823, CurrentID=0, Status='live', Symbol='KLRC3', Aliases=['NKG2-E', 'NKG2E'], description='killer cell lectin like receptor C3', other_designations='NKG2-E type II integral membrane protein|NK cell receptor E|NKG2-E-activating NK receptor|killer cell lectin-like receptor subfamily C, member 3', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10412315, end_position_on_the_genomic_accession=10420595, orientation='minus', exon_count=7, OMIM=[602892], no_hdr0=''),
    3824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3824, CurrentID=0, Status='live', Symbol='KLRD1', Aliases=['CD94'], description='killer cell lectin like receptor D1', other_designations='natural killer cells antigen CD94|CD94 antigen|KP43|NK cell receptor|killer cell lectin-like receptor subfamily D, member 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10238383, end_position_on_the_genomic_accession=10329608, orientation='plus', exon_count=14, OMIM=[602894], no_hdr0=''),
    3827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3827, CurrentID=0, Status='live', Symbol='KNG1', Aliases=['BDK', 'BK', 'HAE6', 'HMWK', 'KNG'], description='kininogen 1', other_designations='kininogen-1|alpha-2-thiol proteinase inhibitor|bradykinin|fitzgerald factor|high molecular weight kininogen|williams-Fitzgerald-Flaujeac factor', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186717359, end_position_on_the_genomic_accession=186744410, orientation='plus', exon_count=10, OMIM=[612358], no_hdr0=''),
    3831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3831, CurrentID=0, Status='live', Symbol='KLC1', Aliases=['KLC', 'KNS2', 'KNS2A'], description='kinesin light chain 1', other_designations='kinesin light chain 1|kinesin 2 60/70kDa|medulloblastoma antigen MU-MB-2.50', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103629211, end_position_on_the_genomic_accession=103701544, orientation='plus', exon_count=20, OMIM=[600025], no_hdr0=''),
    3832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3832, CurrentID=0, Status='live', Symbol='KIF11', Aliases=['EG5', 'HKSP', 'KNSL1', 'MCLMR', 'TRIP5'], description='kinesin family member 11', other_designations='kinesin-like protein KIF11|TR-interacting protein 5|TRIP-5|kinesin-like protein 1|kinesin-like spindle protein HKSP|kinesin-related motor protein Eg5|thyroid receptor-interacting protein 5', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92593130, end_position_on_the_genomic_accession=92655395, orientation='plus', exon_count=22, OMIM=[148760], no_hdr0=''),
    3833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3833, CurrentID=0, Status='live', Symbol='KIFC1', Aliases=['HSET', 'KNSL2'], description='kinesin family member C1', other_designations='kinesin-like protein KIFC1|kinesin-like 2|kinesin-like protein 2|kinesin-related protein HSET', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33391524, end_position_on_the_genomic_accession=33410226, orientation='plus', exon_count=13, OMIM=[603763], no_hdr0=''),
    3834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3834, CurrentID=0, Status='live', Symbol='KIF25', Aliases=['KNSL3'], description='kinesin family member 25', other_designations='kinesin-like protein KIF25|kinesin-like 3|kinesin-like protein 3', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167997671, end_position_on_the_genomic_accession=168045106, orientation='plus', exon_count=13, OMIM=[603815], no_hdr0=''),
    3835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3835, CurrentID=0, Status='live', Symbol='KIF22', Aliases=['A-328A3.2', 'KID', 'KNSL4', 'OBP', 'OBP-1', 'OBP-2', 'SEMDJL2'], description='kinesin family member 22', other_designations='kinesin-like protein KIF22|kinesin-like DNA-binding protein pseudogene|kinesin-like protein 4|oriP binding protein|origin of plasmid DNA replication-binding protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29790734, end_position_on_the_genomic_accession=29805543, orientation='plus', exon_count=16, OMIM=[603213], no_hdr0=''),
    3836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3836, CurrentID=0, Status='live', Symbol='KPNA1', Aliases=['IPOA5', 'NPI-1', 'RCH2', 'SRP1'], description='karyopherin subunit alpha 1', other_designations='importin subunit alpha-5|RAG cohort protein 2|SRP1-beta|importin alpha 5|importin subunit alpha-1|importin-alpha-S1|karyopherin alpha 1 (importin alpha 5)|nucleoprotein interactor 1|recombination activating gene cohort 2', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122421902, end_position_on_the_genomic_accession=122514939, orientation='minus', exon_count=17, OMIM=[600686], no_hdr0=''),
    3837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3837, CurrentID=0, Status='live', Symbol='KPNB1', Aliases=['IMB1', 'IPO1', 'IPOB', 'Impnb', 'NTF97'], description='karyopherin subunit beta 1', other_designations='importin subunit beta-1|PTAC97|importin 1|importin 90|importin beta-1 subunit|karyopherin (importin) beta 1|nuclear factor p97|pore targeting complex 97 kDa subunit', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47649919, end_position_on_the_genomic_accession=47685505, orientation='plus', exon_count=23, OMIM=[602738], no_hdr0=''),
    3838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3838, CurrentID=0, Status='live', Symbol='KPNA2', Aliases=['IPOA1', 'QIP2', 'RCH1', 'SRP1-alpha', 'SRP1alpha'], description='karyopherin subunit alpha 2', other_designations='importin subunit alpha-1|RAG cohort protein 1|importin subunit alpha-2|importin-alpha-P1|karyopherin alpha 2 (RAG cohort 1, importin alpha 1)|pendulin', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68035735, end_position_on_the_genomic_accession=68046854, orientation='plus', exon_count=12, OMIM=[600685], no_hdr0=''),
    3839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3839, CurrentID=0, Status='live', Symbol='KPNA3', Aliases=['IPOA4', 'SRP1', 'SRP1gamma', 'SRP4', 'hSRP1'], description='karyopherin subunit alpha 3', other_designations='importin subunit alpha-4|SRP1-gamma|importin alpha 4|importin alpha Q2|importin alpha-3|importin subunit alpha-3|karyopherin alpha 3 (importin alpha 4)|qip2', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49699307, end_position_on_the_genomic_accession=49792682, orientation='minus', exon_count=18, OMIM=[601892], no_hdr0=''),
    3840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3840, CurrentID=0, Status='live', Symbol='KPNA4', Aliases=['IPOA3', 'QIP1', 'SRP3'], description='karyopherin subunit alpha 4', other_designations='importin subunit alpha-3|importin alpha Q1|importin subunit alpha-4|karyopherin alpha 4 (importin alpha 3)', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160495007, end_position_on_the_genomic_accession=160565571, orientation='minus', exon_count=17, OMIM=[602970], no_hdr0=''),
    3841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3841, CurrentID=0, Status='live', Symbol='KPNA5', Aliases=['IPOA6', 'SRP6'], description='karyopherin subunit alpha 5', other_designations='importin subunit alpha-6|importin alpha 6|karyopherin alpha 5 (importin alpha 6)', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116677643, end_position_on_the_genomic_accession=116741867, orientation='plus', exon_count=16, OMIM=[604545], no_hdr0=''),
    3842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3842, CurrentID=0, Status='live', Symbol='TNPO1', Aliases=['IPO2', 'KPNB2', 'MIP', 'MIP1', 'TRN'], description='transportin 1', other_designations='transportin-1|M9 region interaction protein|importin 2|importin beta 2|karyopherin (importin) beta 2|karyopherin beta-2', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72816650, end_position_on_the_genomic_accession=72914388, orientation='plus', exon_count=26, OMIM=[602901], no_hdr0=''),
    3843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3843, CurrentID=0, Status='live', Symbol='IPO5', Aliases=['IMB3', 'KPNB3', 'Pse1', 'RANBP5', 'imp5'], description='importin 5', other_designations='importin-5|RAN binding protein 5|Ran_GTP binding protein 5|importin beta-3 subunit|importin subunit beta-3|karyopherin (importin) beta 3|karyopherin beta-3|ran-binding protein 5', map_location='13q32.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=97953641, end_position_on_the_genomic_accession=98024296, orientation='plus', exon_count=31, OMIM=[602008], no_hdr0=''),
    3845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3845, CurrentID=0, Status='live', Symbol='KRAS', Aliases=["'C-K-RAS", 'C-K-RAS', 'CFC2', 'K-RAS2A', 'K-RAS2B', 'K-RAS4A', 'K-RAS4B', 'K-Ras', 'K-Ras 2', 'KI-RAS1', 'KRAS2', 'NS', 'NS3', 'OES', 'RALD', 'RASK2', 'c-Ki-ras', 'c-Ki-ras2', 'KRAS'], description='KRAS proto-oncogene, GTPase', other_designations='GTPase KRas|K-ras p21 protein|Kirsten rat sarcoma viral oncogene homolog|Kirsten rat sarcoma viral proto-oncogene|PR310 c-K-ras oncogene|c-Kirsten-ras protein|cellular c-Ki-ras2 proto-oncogene|cellular transforming proto-oncogene|oncogene KRAS2|transforming protein p21|v-Ki-ras2 Kirsten rat sarcoma 2 viral oncogene homolog', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=25205246, end_position_on_the_genomic_accession=25250929, orientation='minus', exon_count=6, OMIM=[190070], no_hdr0=''),
    3846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3846, CurrentID=0, Status='live', Symbol='KRTAP5-9', Aliases=['KRN1', 'KRTAP5-1', 'KRTAP5.9'], description='keratin associated protein 5-9', other_designations='keratin-associated protein 5-9|UHS KerA|UHS keratin A|keratin, cuticle, ultrahigh sulfur 1|keratin, cuticle, ultrahigh sulphur 1|keratin, ultra high-sulfur matrix protein A|keratin-associated protein 5.9|ultrahigh sulfur keratin-associated protein 5.9', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71548420, end_position_on_the_genomic_accession=71549608, orientation='plus', exon_count=1, OMIM=[148021], no_hdr0=''),
    3848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3848, CurrentID=0, Status='live', Symbol='KRT1', Aliases=['CK1', 'EHK', 'EHK1', 'EPPK', 'K1A', 'NEPPK', 'KRT1'], description='keratin 1', other_designations='keratin, type II cytoskeletal 1|67 kDa cytokeratin|CK-1|cytokeratin 1|epidermolytic hyperkeratosis 1|hair alpha protein|keratin 1, type II|type-II keratin Kb1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52674736, end_position_on_the_genomic_accession=52680407, orientation='minus', exon_count=9, OMIM=[139350], no_hdr0=''),
    3849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3849, CurrentID=0, Status='live', Symbol='KRT2', Aliases=['CK-2e', 'K2eA', 'KRT2E', 'KRTE', 'KRT2'], description='keratin 2', other_designations='keratin, type II cytoskeletal 2 epidermal|cytokeratin-2e|epithelial keratin-2e|keratin 2, type II|keratin-2 epidermis|keratin-2e|type-II keratin Kb2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52644558, end_position_on_the_genomic_accession=52652211, orientation='minus', exon_count=9, OMIM=[600194], no_hdr0=''),
    3850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3850, CurrentID=0, Status='live', Symbol='KRT3', Aliases=['CK3', 'K3', 'MECD2'], description='keratin 3', other_designations='keratin, type II cytoskeletal 3|65 kDa cytokeratin|CK-3|cytokeratin 3|keratin 3, type II|type-II keratin Kb3', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52789685, end_position_on_the_genomic_accession=52805735, orientation='minus', exon_count=10, OMIM=[148043], no_hdr0=''),
    3851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3851, CurrentID=0, Status='live', Symbol='KRT4', Aliases=['CK-4', 'CK4', 'CYK4', 'K4', 'WSN1'], description='keratin 4', other_designations='keratin, type II cytoskeletal 4|cytokeratin 4|keratin 4, type II|type-II keratin Kb4', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52806549, end_position_on_the_genomic_accession=52814116, orientation='minus', exon_count=9, OMIM=[123940], no_hdr0=''),
    3852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3852, CurrentID=0, Status='live', Symbol='KRT5', Aliases=['CK5', 'DDD', 'DDD1', 'EBS2', 'K5A', 'KRT5'], description='keratin 5', other_designations='keratin, type II cytoskeletal 5|58 kda cytokeratin|CK-5|cytokeratin-5|epidermolysis bullosa simplex 2 Dowling-Meara/Kobner/Weber-Cockayne types|keratin 5 (epidermolysis bullosa simplex, Dowling-Meara/Kobner/Weber-Cockayne types)|keratin 5, type II|type-II keratin Kb5', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52514575, end_position_on_the_genomic_accession=52520394, orientation='minus', exon_count=9, OMIM=[148040], no_hdr0=''),
    3853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3853, CurrentID=0, Status='live', Symbol='KRT6A', Aliases=['CK-6C', 'CK-6E', 'CK6A', 'CK6C', 'CK6D', 'K6A', 'K6C', 'K6D', 'KRT6C', 'KRT6D', 'PC3'], description='keratin 6A', other_designations='keratin, type II cytoskeletal 6A|cytokeratin 6A|cytokeratin 6C|cytokeratin 6D|keratin 6A, , type II|keratin 6A, type II|keratin, epidermal type II, K6A|type-II keratin Kb6', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52487176, end_position_on_the_genomic_accession=52493257, orientation='minus', exon_count=9, OMIM=[148041], no_hdr0=''),
    3854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3854, CurrentID=0, Status='live', Symbol='KRT6B', Aliases=['CK-6B', 'CK6B', 'K6B', 'KRTL1', 'PC2', 'PC4'], description='keratin 6B', other_designations='keratin, type II cytoskeletal 6B|cytokeratin 6B|keratin 6B, type II|keratin, epidermal, type II, K6B|keratin-like 1 (a type II keratin sequence)|type-II keratin Kb10', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52446651, end_position_on_the_genomic_accession=52452146, orientation='minus', exon_count=9, OMIM=[148042], no_hdr0=''),
    3855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3855, CurrentID=0, Status='live', Symbol='KRT7', Aliases=['CK7', 'K2C7', 'K7', 'SCL'], description='keratin 7', other_designations='keratin, type II cytoskeletal 7|CK-7|cytokeratin 7|keratin 7, type II|keratin, 55K type II cytoskeletal|keratin, simple epithelial type I, K7|sarcolectin|type II mesothelial keratin K7|type-II keratin Kb7', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52233243, end_position_on_the_genomic_accession=52252667, orientation='plus', exon_count=11, OMIM=[148059], no_hdr0=''),
    3856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3856, CurrentID=0, Status='live', Symbol='KRT8', Aliases=['CARD2', 'CK-8', 'CK8', 'CYK8', 'K2C8', 'K8', 'KO'], description='keratin 8', other_designations='keratin, type II cytoskeletal 8|cytokeratin-8|keratin 8, type II|type-II keratin Kb8', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52897191, end_position_on_the_genomic_accession=52949860, orientation='minus', exon_count=10, OMIM=[148060], no_hdr0=''),
    3857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3857, CurrentID=0, Status='live', Symbol='KRT9', Aliases=['CK-9', 'EPPK', 'K9'], description='keratin 9', other_designations='keratin, type I cytoskeletal 9|cytokeratin 9|keratin 9, type I|type I cytoskeletal 9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41565836, end_position_on_the_genomic_accession=41572059, orientation='minus', exon_count=8, OMIM=[607606], no_hdr0=''),
    3858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3858, CurrentID=0, Status='live', Symbol='KRT10', Aliases=['BCIE', 'BIE', 'CK10', 'EHK', 'K10', 'KPP'], description='keratin 10', other_designations='keratin, type I cytoskeletal 10|CK-10|cytokeratin 10|keratin 10, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40818117, end_position_on_the_genomic_accession=40822614, orientation='minus', exon_count=8, OMIM=[148080], no_hdr0=''),
    3859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3859, CurrentID=0, Status='live', Symbol='KRT12', Aliases=['K12', 'MECD1'], description='keratin 12', other_designations='keratin, type I cytoskeletal 12|CK-12|cytokeratin-12|keratin 12, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40861303, end_position_on_the_genomic_accession=40867223, orientation='minus', exon_count=8, OMIM=[601687], no_hdr0=''),
    3860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3860, CurrentID=0, Status='live', Symbol='KRT13', Aliases=['CK13', 'K13', 'WSN2'], description='keratin 13', other_designations='keratin, type I cytoskeletal 13|CK-13|cytokeratin 13|keratin 13, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41500981, end_position_on_the_genomic_accession=41505612, orientation='minus', exon_count=8, OMIM=[148065], no_hdr0=''),
    3861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3861, CurrentID=0, Status='live', Symbol='KRT14', Aliases=['CK14', 'EBS3', 'EBS4', 'K14', 'NFJ'], description='keratin 14', other_designations='keratin, type I cytoskeletal 14|cytokeratin 14|keratin 14, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41582279, end_position_on_the_genomic_accession=41586895, orientation='minus', exon_count=8, OMIM=[148066], no_hdr0=''),
    3866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3866, CurrentID=0, Status='live', Symbol='KRT15', Aliases=['CK15', 'K15', 'K1CO'], description='keratin 15', other_designations='keratin, type I cytoskeletal 15|CK-15|cytokeratin 15|keratin 15, type I|keratin-15, basic|keratin-15, beta|type I cytoskeletal 15', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41513745, end_position_on_the_genomic_accession=41521924, orientation='minus', exon_count=9, OMIM=[148030], no_hdr0=''),
    3868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3868, CurrentID=0, Status='live', Symbol='KRT16', Aliases=['CK16', 'FNEPPK', 'K16', 'K1CPA', 'NEPPK', 'PC1', 'KRT16'], description='keratin 16', other_designations='keratin, type I cytoskeletal 16|cytokeratin 16|focal non-epidermolytic palmoplantar keratoderma|keratin 16, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41609778, end_position_on_the_genomic_accession=41612767, orientation='minus', exon_count=8, OMIM=[148067], no_hdr0=''),
    3872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3872, CurrentID=0, Status='live', Symbol='KRT17', Aliases=['39.1', 'CK-17', 'K17', 'PC', 'PC2', 'PCHC1'], description='keratin 17', other_designations='keratin, type I cytoskeletal 17|cytokeratin-17|keratin 17, type I', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41619442, end_position_on_the_genomic_accession=41624575, orientation='minus', exon_count=8, OMIM=[148069], no_hdr0=''),
    3875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3875, CurrentID=0, Status='live', Symbol='KRT18', Aliases=['CK-18', 'CYK18', 'K18'], description='keratin 18', other_designations='keratin, type I cytoskeletal 18|cell proliferation-inducing gene 46 protein|cytokeratin 18|keratin 18, type I', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52948855, end_position_on_the_genomic_accession=52952906, orientation='plus', exon_count=8, OMIM=[148070], no_hdr0=''),
    3880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3880, CurrentID=0, Status='live', Symbol='KRT19', Aliases=['CK19', 'K19', 'K1CS'], description='keratin 19', other_designations='keratin, type I cytoskeletal 19|40-kDa keratin intermediate filament|CK-19|cytokeratin 19|keratin 19, type I|keratin, type I, 40-kd', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41523617, end_position_on_the_genomic_accession=41528308, orientation='minus', exon_count=6, OMIM=[148020], no_hdr0=''),
    3881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3881, CurrentID=0, Status='live', Symbol='KRT31', Aliases=['HA1', 'Ha-1', 'KRTHA1', 'hHa1'], description='keratin 31', other_designations='keratin, type I cuticular Ha1|K31|hair keratin, type I Ha1|hard keratin, type I, 1|keratin 31, type I|keratin, hair, acidic,1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41393721, end_position_on_the_genomic_accession=41397608, orientation='minus', exon_count=7, OMIM=[601077], no_hdr0=''),
    3882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3882, CurrentID=0, Status='live', Symbol='KRT32', Aliases=['HA2', 'HKA2', 'KRTHA2', 'hHa2'], description='keratin 32', other_designations='keratin, type I cuticular Ha2|K32|hair keratin, type I Ha2|hard keratin, type I, 2|keratin 32, type I|keratin, hair, acidic, 2|type I cuticular hair keratin', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41459513, end_position_on_the_genomic_accession=41469252, orientation='minus', exon_count=7, OMIM=[602760], no_hdr0=''),
    3883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3883, CurrentID=0, Status='live', Symbol='KRT33A', Aliases=['HA3I', 'Ha-3I', 'K33A', 'KRTHA3A', 'Krt1-3', 'hHa3-I'], description='keratin 33A', other_designations='keratin, type I cuticular Ha3-I|hair keratin, type I Ha3-I|hard keratin, type I,3I|keratin 33A, type I|keratin, hair, acidic, 3A', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41345704, end_position_on_the_genomic_accession=41350828, orientation='minus', exon_count=8, OMIM=[602761], no_hdr0=''),
    3884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3884, CurrentID=0, Status='live', Symbol='KRT33B', Aliases=['HA3II', 'Ha-3II', 'K33B', 'KRTHA3A', 'KRTHA3B', 'hHa3-II'], description='keratin 33B', other_designations='keratin, type I cuticular Ha3-II|hair keratin, type I Ha3-II|hard keratin, type I, 3II|keratin 33B, type I|keratin, hair, acidic, 3B|type I hair keratin 3B', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41363498, end_position_on_the_genomic_accession=41369813, orientation='minus', exon_count=7, OMIM=[602762], no_hdr0=''),
    3885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3885, CurrentID=0, Status='live', Symbol='KRT34', Aliases=['HA4', 'Ha-4', 'K34', 'KRTHA4', 'hHa4'], description='keratin 34', other_designations='keratin, type I cuticular Ha4|hair keratin, type I Ha4|hard keratin, type I, 4|keratin 34, type I|keratin, hair, acidic, 4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41377665, end_position_on_the_genomic_accession=41383816, orientation='minus', exon_count=8, OMIM=[602763], no_hdr0=''),
    3886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3886, CurrentID=0, Status='live', Symbol='KRT35', Aliases=['HA5', 'Ha-5', 'K35', 'KRTHA5', 'hHa5'], description='keratin 35', other_designations='keratin, type I cuticular Ha5|HHa5 hair keratin type I intermediate filament|hair keratin, type I Ha5|hard keratin, type I, 5|keratin 35, type I|keratin, hair, acidic, 5', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41476710, end_position_on_the_genomic_accession=41481151, orientation='minus', exon_count=7, OMIM=[602764], no_hdr0=''),
    3887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3887, CurrentID=0, Status='live', Symbol='KRT81', Aliases=['HB1', 'Hb-1', 'K81', 'KRTHB1', 'MLN137', 'ghHkb1', 'hHAKB2-1'], description='keratin 81', other_designations='keratin, type II cuticular Hb1|hair keratin K2.9|hard keratin, type II, 1|keratin 81, type II|keratin, hair, basic, 1|metastatic lymph node 137 gene protein|type II hair keratin Hb1|type-II keratin Kb21', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52285913, end_position_on_the_genomic_accession=52291534, orientation='minus', exon_count=9, OMIM=[602153], no_hdr0=''),
    3888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3888, CurrentID=0, Status='live', Symbol='KRT82', Aliases=['HB2', 'Hb-2', 'KRTHB2'], description='keratin 82', other_designations='keratin, type II cuticular Hb2|K82|hard keratin, type II, 2|keratin 82, type II|keratin, hair, basic, 2|type II hair keratin Hb2|type-II keratin Kb22', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52393931, end_position_on_the_genomic_accession=52406335, orientation='minus', exon_count=9, OMIM=[601078], no_hdr0=''),
    3889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3889, CurrentID=0, Status='live', Symbol='KRT83', Aliases=['EKVP5', 'HB3', 'Hb-3', 'KRTHB3', 'MNLIX'], description='keratin 83', other_designations='keratin, type II cuticular Hb3|K83|hHb3|hair keratin K2.10|hard keratin, type II, 3|keratin 83, type II|keratin, hair, basic, 3|type II hair keratin Hb3|type-II keratin Kb23', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52314301, end_position_on_the_genomic_accession=52321398, orientation='minus', exon_count=9, OMIM=[602765], no_hdr0=''),
    3890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3890, CurrentID=0, Status='live', Symbol='KRT84', Aliases=['HB4', 'KRTHB4'], description='keratin 84', other_designations='keratin, type II cuticular Hb4|K84|hard keratin, type II, 4|keratin 84, type II|keratin, hair, basic, 4|type II hair keratin 4|type II hair keratin Hb4|type-II keratin Kb24', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52377665, end_position_on_the_genomic_accession=52386977, orientation='minus', exon_count=10, OMIM=[602766], no_hdr0=''),
    3891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3891, CurrentID=0, Status='live', Symbol='KRT85', Aliases=['ECTD4', 'HB5', 'Hb-5', 'K85', 'KRTHB5', 'hHb5'], description='keratin 85', other_designations='keratin, type II cuticular Hb5|hair keratin K2.12|hard keratin, type II, 5|keratin 85, type II|keratin, hair, basic, 5|type II hair keratin Hb5|type-II keratin Kb25', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52360006, end_position_on_the_genomic_accession=52367481, orientation='minus', exon_count=10, OMIM=[602767], no_hdr0=''),
    3892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3892, CurrentID=0, Status='live', Symbol='KRT86', Aliases=['HB6', 'Hb1', 'K86', 'KRTHB1', 'KRTHB6', 'MNX'], description='keratin 86', other_designations='keratin, type II cuticular Hb6|hair keratin K2.11|hard keratin, type II, 6|keratin 86, type II|keratin protein HB6|keratin, hair, basic, 6 (monilethrix)|type II hair keratin Hb6|type-II keratin Kb26', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52270507, end_position_on_the_genomic_accession=52309163, orientation='plus', exon_count=11, OMIM=[601928], no_hdr0=''),
    3895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3895, CurrentID=0, Status='live', Symbol='KTN1', Aliases=['CG1', 'KNT', 'MU-RMS-40.19'], description='kinectin 1', other_designations='kinectin|CG-1 antigen|kinesin receptor', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55580207, end_position_on_the_genomic_accession=55684584, orientation='plus', exon_count=49, OMIM=[600381], no_hdr0=''),
    3897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3897, CurrentID=0, Status='live', Symbol='L1CAM', Aliases=['CAML1', 'CD171', 'HSAS', 'HSAS1', 'MASA', 'MIC5', 'N-CAM-L1', 'N-CAML1', 'NCAM-L1', 'S10', 'SPG1'], description='L1 cell adhesion molecule', other_designations='neural cell adhesion molecule L1|antigen identified by monoclonal antibody R1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153861514, end_position_on_the_genomic_accession=153886173, orientation='minus', exon_count=29, OMIM=[308840], no_hdr0=''),
    3898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3898, CurrentID=0, Status='live', Symbol='LAD1', Aliases=['LadA'], description='ladinin 1', other_designations='ladinin-1|lad-1|linear IgA bullous dermatosis antigen|linear IgA disease antigen homolog', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201380833, end_position_on_the_genomic_accession=201399324, orientation='minus', exon_count=10, OMIM=[602314], no_hdr0=''),
    3899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3899, CurrentID=0, Status='live', Symbol='AFF3', Aliases=['KINS', 'LAF4', 'MLLT2-like'], description='AF4/FMR2 family member 3', other_designations='AF4/FMR2 family member 3|MLLT2-related protein|lymphoid nuclear protein 4|lymphoid nuclear protein related to AF4|protein LAF-4', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99545419, end_position_on_the_genomic_accession=100142590, orientation='minus', exon_count=33, OMIM=[601464], no_hdr0=''),
    3902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3902, CurrentID=0, Status='live', Symbol='LAG3', Aliases=['CD223'], description='lymphocyte activating 3', other_designations='lymphocyte activation gene 3 protein|lymphocyte-activation gene 3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6772483, end_position_on_the_genomic_accession=6778455, orientation='plus', exon_count=8, OMIM=[153337], no_hdr0=''),
    3903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3903, CurrentID=0, Status='live', Symbol='LAIR1', Aliases=['CD305', 'LAIR-1'], description='leukocyte associated immunoglobulin like receptor 1', other_designations='leukocyte-associated immunoglobulin-like receptor 1|immunoglobulin heavy chain variable region|leukocyte-associated Ig-like receptor 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54351384, end_position_on_the_genomic_accession=54370558, orientation='minus', exon_count=12, OMIM=[602992], no_hdr0=''),
    3904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3904, CurrentID=0, Status='live', Symbol='LAIR2', Aliases=['CD306'], description='leukocyte associated immunoglobulin like receptor 2', other_designations='leukocyte-associated immunoglobulin-like receptor 2|LAIR-2|leukocyte-associated Ig-like receptor-2', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54502810, end_position_on_the_genomic_accession=54510693, orientation='plus', exon_count=5, OMIM=[602993], no_hdr0=''),
    3906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3906, CurrentID=0, Status='live', Symbol='LALBA', Aliases=['LYZG'], description='lactalbumin alpha', other_designations='alpha-lactalbumin|lactose synthase B protein|lysozyme G|lysozyme-like protein 7', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48567684, end_position_on_the_genomic_accession=48571845, orientation='minus', exon_count=5, OMIM=[149750], no_hdr0=''),
    3908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3908, CurrentID=0, Status='live', Symbol='LAMA2', Aliases=['LAMM', 'MDC1A'], description='laminin subunit alpha 2', other_designations='laminin subunit alpha-2|laminin M chain|laminin, alpha 2|laminin-12 subunit alpha|laminin-2 subunit alpha|laminin-4 subunit alpha|merosin heavy chain|mutant laminin subunit alpha 2', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=128883138, end_position_on_the_genomic_accession=129516566, orientation='plus', exon_count=69, OMIM=[156225], no_hdr0=''),
    3909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3909, CurrentID=0, Status='live', Symbol='LAMA3', Aliases=['BM600', 'E170', 'LAMNA', 'LOCS'], description='laminin subunit alpha 3', other_designations='laminin subunit alpha-3|BM600 150kD subunit|LAM3, alpha-3 subunit|epiligrin 170 kda subunit|epiligrin alpha 3 subunit|kalinin 165kD subunit|kalinin subunit alpha|laminin 5, alpha-3 subunit|laminin A3|laminin, alpha 3 (nicein (150kD), kalinin (165kD), BM600 (150kD), epilegrin)|laminin-5 alpha 3 chain|laminin-5 subunit alpha|laminin-6 subunit alpha|laminin-7 subunit alpha|nicein 150kD subunit|nicein subunit alpha', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23689443, end_position_on_the_genomic_accession=23955066, orientation='plus', exon_count=78, OMIM=[600805], no_hdr0=''),
    3910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3910, CurrentID=0, Status='live', Symbol='LAMA4', Aliases=['CMD1JJ', 'LAMA3*-1', 'LAMA4'], description='laminin subunit alpha 4', other_designations='laminin subunit alpha-4|laminin alpha 4 chain|laminin, alpha 4', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=112107931, end_position_on_the_genomic_accession=112254722, orientation='minus', exon_count=40, OMIM=[600133], no_hdr0=''),
    3911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3911, CurrentID=0, Status='live', Symbol='LAMA5', Aliases=[], description='laminin subunit alpha 5', other_designations='laminin subunit alpha-5|laminin alpha-5 chain|laminin-10 subunit alpha|laminin-11 subunit alpha|laminin-15 subunit alpha', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62309060, end_position_on_the_genomic_accession=62367318, orientation='minus', exon_count=81, OMIM=[601033], no_hdr0=''),
    3912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3912, CurrentID=0, Status='live', Symbol='LAMB1', Aliases=['CLM', 'LIS5'], description='laminin subunit beta 1', other_designations='laminin subunit beta-1|laminin B1 chain|laminin, beta 1', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107923799, end_position_on_the_genomic_accession=108003176, orientation='minus', exon_count=35, OMIM=[150240], no_hdr0=''),
    3913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3913, CurrentID=0, Status='live', Symbol='LAMB2', Aliases=['LAMS', 'NPHS5'], description='laminin subunit beta 2', other_designations='laminin subunit beta-2|S-LAM beta|S-laminin subunit beta|laminin B1s chain|laminin S|laminin, beta 2 (laminin S)', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49121114, end_position_on_the_genomic_accession=49133066, orientation='minus', exon_count=33, OMIM=[150325], no_hdr0=''),
    3914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3914, CurrentID=0, Status='live', Symbol='LAMB3', Aliases=['AI1A', 'BM600-125KDA', 'LAM5', 'LAMNB1'], description='laminin subunit beta 3', other_designations='laminin subunit beta-3|epiligrin subunit bata|kalinin B1 chain|kalinin subunit beta|kalinin-140kDa|laminin B1k chain|laminin S B3 chain|laminin beta 3|laminin, beta 3 (nicein (125kD), kalinin (140kD), BM600 (125kD))|laminin-5 subunit beta|nicein subunit beta|nicein-125kDa', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209614870, end_position_on_the_genomic_accession=209652467, orientation='minus', exon_count=25, OMIM=[150310], no_hdr0=''),
    3915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3915, CurrentID=0, Status='live', Symbol='LAMC1', Aliases=['LAMB2'], description='laminin subunit gamma 1', other_designations='laminin subunit gamma-1|S-LAM gamma|S-laminin subunit gamma|laminin B2 chain|laminin, gamma 1 (formerly LAMB2)|laminin-10 subunit gamma|laminin-11 subunit gamma|laminin-2 subunit gamma|laminin-3 subunit gamma|laminin-4 subunit gamma|laminin-6 subunit gamma|laminin-7 subunit gamma|laminin-8 subunit gamma|laminin-9 subunit gamma', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183023420, end_position_on_the_genomic_accession=183145592, orientation='plus', exon_count=28, OMIM=[150290], no_hdr0=''),
    3916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3916, CurrentID=0, Status='live', Symbol='LAMP1', Aliases=['CD107a', 'LAMPA', 'LGP120'], description='lysosomal associated membrane protein 1', other_designations='lysosome-associated membrane glycoprotein 1|CD107 antigen-like family member A|LAMP-1|lysosome-associated membrane protein 1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113297239, end_position_on_the_genomic_accession=113323672, orientation='plus', exon_count=10, OMIM=[153330], no_hdr0=''),
    3918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3918, CurrentID=0, Status='live', Symbol='LAMC2', Aliases=['B2T', 'BM600', 'CSF', 'EBR2', 'EBR2A', 'LAMB2T', 'LAMNB2'], description='laminin subunit gamma 2', other_designations='laminin subunit gamma-2|BM600-100kDa|CSF 140 kDa subunit|cell-scattering factor 140 kDa subunit|epiligrin subunit gamma|kalinin subunit gamma|ladsin 140 kDa subunit|laminin B2t chain|laminin, gamma 2|large adhesive scatter factor 140 kDa subunit|nicein subunit gamma', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183186264, end_position_on_the_genomic_accession=183245127, orientation='plus', exon_count=23, OMIM=[150292], no_hdr0=''),
    3920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3920, CurrentID=0, Status='live', Symbol='LAMP2', Aliases=['CD107b', 'DND', 'LAMP-2', 'LAMPB', 'LGP-96', 'LGP110'], description='lysosomal associated membrane protein 2', other_designations='lysosome-associated membrane glycoprotein 2|CD107 antigen-like family member B', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120426148, end_position_on_the_genomic_accession=120469349, orientation='minus', exon_count=10, OMIM=[309060], no_hdr0=''),
    3921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3921, CurrentID=0, Status='live', Symbol='RPSA', Aliases=['37LRP', '67LR', 'ICAS', 'LAMBR', 'LAMR1', 'LBP', 'LBP/p40', 'LRP', 'LRP/LR', 'NEM/1CHD4', 'SA', 'lamR', 'p40'], description='ribosomal protein SA', other_designations='40S ribosomal protein SA|37 kDa laminin receptor|37/67 kDa laminin receptor|67 kDa laminin receptor|colon carcinoma laminin-binding protein|laminin receptor 1 (67kD, ribosomal protein SA)|laminin-binding protein precursor p40|multidrug resistance-associated protein MGr1-Ag|small ribosomal subunit protein uS2', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39406720, end_position_on_the_genomic_accession=39412542, orientation='plus', exon_count=7, OMIM=[150370], no_hdr0=''),
    3925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3925, CurrentID=0, Status='live', Symbol='STMN1', Aliases=['C1orf215', 'LAP18', 'Lag', 'OP18', 'PP17', 'PP19', 'PR22', 'SMN'], description='stathmin 1', other_designations='stathmin|leukemia-associated phosphoprotein p18|metablastin|oncoprotein 18|phosphoprotein 19|phosphoprotein p19|prosolin|stathmin 1/oncoprotein 18|testicular tissue protein Li 189|transmembrane protein C1orf215', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25884179, end_position_on_the_genomic_accession=25906880, orientation='minus', exon_count=8, OMIM=[151442], no_hdr0=''),
    3927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3927, CurrentID=0, Status='live', Symbol='LASP1', Aliases=['Lasp-1', 'MLN50'], description='LIM and SH3 protein 1', other_designations='LIM and SH3 domain protein 1|metastatic lymph node gene 50 protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38870058, end_position_on_the_genomic_accession=38921770, orientation='plus', exon_count=8, OMIM=[602920], no_hdr0=''),
    3929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3929, CurrentID=0, Status='live', Symbol='LBP', Aliases=['BPIFD2'], description='lipopolysaccharide binding protein', other_designations='lipopolysaccharide-binding protein|BPI fold containing family D, member 2|LPS-binding protein', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38346482, end_position_on_the_genomic_accession=38377013, orientation='plus', exon_count=15, OMIM=[151990], no_hdr0=''),
    3930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3930, CurrentID=0, Status='live', Symbol='LBR', Aliases=['C14SR', 'DHCR14B', 'LMN2R', 'PHA', 'PHASK', 'TDRD18'], description='lamin B receptor', other_designations='delta(14)-sterol reductase LBR|3-beta-hydroxysterol Delta (14)-reductase|C-14 sterol reductase|delta-14-SR|integral nuclear envelope inner membrane protein|sterol C14-reductase|tudor domain containing 18', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225401502, end_position_on_the_genomic_accession=225428821, orientation='minus', exon_count=16, OMIM=[600024], no_hdr0=''),
    3931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3931, CurrentID=0, Status='live', Symbol='LCAT', Aliases=[], description='lecithin-cholesterol acyltransferase', other_designations='phosphatidylcholine-sterol acyltransferase|1-alkyl-2-acetylglycerophosphocholine esterase|PAF acetylhydrolase|phosphatidylcholine--sterol O-acyltransferase|phospholipid-cholesterol acyltransferase|platelet-activating factor acetylhydrolase|testicular secretory protein Li 24', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67939750, end_position_on_the_genomic_accession=67944120, orientation='minus', exon_count=6, OMIM=[606967], no_hdr0=''),
    3932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3932, CurrentID=0, Status='live', Symbol='LCK', Aliases=['IMD22', 'LSK', 'YT16', 'p56lck', 'pp58lck'], description='LCK proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Lck|T-lymphocyte specific protein tyrosine kinase p56lck|leukocyte C-terminal Src kinase|lymphocyte cell-specific protein-tyrosine kinase|p56(LSTRA) protein-tyrosine kinase|proto-oncogene tyrosine-protein kinase LCK|t cell-specific protein-tyrosine kinase', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32251265, end_position_on_the_genomic_accession=32286165, orientation='plus', exon_count=13, OMIM=[153390], no_hdr0=''),
    3933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3933, CurrentID=0, Status='live', Symbol='LCN1', Aliases=['PMFA', 'TLC', 'TP', 'VEGP'], description='lipocalin 1', other_designations='lipocalin-1|VEG protein|Von Ebner gland protein|protein migrating faster than albumin|tear prealbumin', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135521296, end_position_on_the_genomic_accession=135526540, orientation='plus', exon_count=7, OMIM=[151675], no_hdr0=''),
    3934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3934, CurrentID=0, Status='live', Symbol='LCN2', Aliases=['24p3', 'MSFI', 'NGAL', 'p25'], description='lipocalin 2', other_designations='neutrophil gelatinase-associated lipocalin|25 kDa alpha-2-microglobulin-related subunit of MMP-9|migration-stimulating factor inhibitor|oncogene 24p3|siderocalin LCN2', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128149453, end_position_on_the_genomic_accession=128153453, orientation='plus', exon_count=7, OMIM=[600181], no_hdr0=''),
    3936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3936, CurrentID=0, Status='live', Symbol='LCP1', Aliases=['CP64', 'HEL-S-37', 'L-PLASTIN', 'LC64P', 'LPL', 'PLS2'], description='lymphocyte cytosolic protein 1', other_designations='plastin-2|L-plastin (Lymphocyte cytosolic protein 1) (LCP-1) (LC64P)|LCP-1|Lymphocyte cytosolic protein-1 (plasmin)|bA139H14.1 (lymphocyte cytosolic protein 1 (L-plastin))|epididymis secretory protein Li 37', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46125923, end_position_on_the_genomic_accession=46182177, orientation='minus', exon_count=17, OMIM=[153430], no_hdr0=''),
    3937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3937, CurrentID=0, Status='live', Symbol='LCP2', Aliases=['IMD81', 'SLP-76', 'SLP76'], description='lymphocyte cytosolic protein 2', other_designations='lymphocyte cytosolic protein 2|76 kDa tyrosine phosphoprotein|SH2 domain-containing leukocyte protein of 76 kDa|SLP-76 tyrosine phosphoprotein', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170246233, end_position_on_the_genomic_accession=170297777, orientation='minus', exon_count=21, OMIM=[601603], no_hdr0=''),
    3938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3938, CurrentID=0, Status='live', Symbol='LCT', Aliases=['LAC', 'LPH', 'LPH1'], description='lactase', other_designations='lactase-phlorizin hydrolase|lactase-glycosylceramidase|lactase-phlorizin hydrolase-1', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135787850, end_position_on_the_genomic_accession=135837195, orientation='minus', exon_count=17, OMIM=[603202], no_hdr0=''),
    3939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3939, CurrentID=0, Status='live', Symbol='LDHA', Aliases=['GSD11', 'HEL-S-133P', 'LDHM', 'PIG19'], description='lactate dehydrogenase A', other_designations='L-lactate dehydrogenase A chain|LDH muscle subunit|LDH-A|LDH-M|cell proliferation-inducing gene 19 protein|epididymis secretory sperm binding protein Li 133P|lactate dehydrogenase M|proliferation-inducing gene 19|renal carcinoma antigen NY-REN-59', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18394563, end_position_on_the_genomic_accession=18408425, orientation='plus', exon_count=9, OMIM=[150000], no_hdr0=''),
    3945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3945, CurrentID=0, Status='live', Symbol='LDHB', Aliases=['HEL-S-281', 'LDH-B', 'LDH-HD', 'TRG-5', 'LDHB'], description='lactate dehydrogenase B', other_designations='L-lactate dehydrogenase B chain|LDH heart subunit|epididymis secretory protein Li 281|lactate dehydrogenase H chain|renal carcinoma antigen NY-REN-46|testicular secretory protein Li 25', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21635342, end_position_on_the_genomic_accession=21657971, orientation='minus', exon_count=8, OMIM=[150100], no_hdr0=''),
    3948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3948, CurrentID=0, Status='live', Symbol='LDHC', Aliases=['CT32', 'LDH3', 'LDHX'], description='lactate dehydrogenase C', other_designations='L-lactate dehydrogenase C chain|LDH testis subunit|LDH-C|LDH-X|cancer/testis antigen 32|lactate dehydrogenase C4|lactate dehydrogenase c variant 1|lactate dehydrogenase c variant 3|lactate dehydrogenase c variant 4|lactate dehydrogenase c variant 5|testis secretory sperm-binding protein Li 234P', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18412298, end_position_on_the_genomic_accession=18452063, orientation='plus', exon_count=8, OMIM=[150150], no_hdr0=''),
    3949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3949, CurrentID=0, Status='live', Symbol='LDLR', Aliases=['FH', 'FHC', 'FHCL1', 'LDLCQ2'], description='low density lipoprotein receptor', other_designations='low-density lipoprotein receptor|LDL receptor|low-density lipoprotein receptor class A domain-containing protein 3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11089432, end_position_on_the_genomic_accession=11133820, orientation='plus', exon_count=18, OMIM=[606945], no_hdr0=''),
    3950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3950, CurrentID=0, Status='live', Symbol='LECT2', Aliases=['chm-II', 'chm2'], description='leukocyte cell derived chemotaxin 2', other_designations='leukocyte cell-derived chemotaxin-2|chondromodulin-II', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135946904, end_position_on_the_genomic_accession=135954983, orientation='minus', exon_count=4, OMIM=[602882], no_hdr0=''),
    3952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3952, CurrentID=0, Status='live', Symbol='LEP', Aliases=['LEPD', 'OB', 'OBS'], description='leptin', other_designations='leptin|leptin (murine obesity homolog)|leptin (obesity homolog, mouse)|obese protein|obese, mouse, homolog of|obesity factor', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128241201, end_position_on_the_genomic_accession=128257629, orientation='plus', exon_count=3, OMIM=[164160], no_hdr0=''),
    3953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3953, CurrentID=0, Status='live', Symbol='LEPR', Aliases=['CD295', 'LEP-RD', 'OB-R', 'OBR', 'LEPR'], description='leptin receptor', other_designations='leptin receptor|OB receptor|huB219', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65420652, end_position_on_the_genomic_accession=65641559, orientation='plus', exon_count=24, OMIM=[601007], no_hdr0=''),
    3954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3954, CurrentID=0, Status='live', Symbol='LETM1', Aliases=['SLC55A1'], description='leucine zipper and EF-hand containing transmembrane protein 1', other_designations='mitochondrial proton/calcium exchanger protein|LETM1 and EF-hand domain-containing protein 1, mitochondrial|Mdm38 homolog|leucine zipper-EF-hand containing transmembrane protein 1', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1811479, end_position_on_the_genomic_accession=1856156, orientation='minus', exon_count=14, OMIM=[604407], no_hdr0=''),
    3955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3955, CurrentID=0, Status='live', Symbol='LFNG', Aliases=['SCDO3'], description='LFNG O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase', other_designations='beta-1,3-N-acetylglucosaminyltransferase lunatic fringe', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2512529, end_position_on_the_genomic_accession=2529177, orientation='plus', exon_count=13, OMIM=[602576], no_hdr0=''),
    3956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3956, CurrentID=0, Status='live', Symbol='LGALS1', Aliases=['GAL1', 'GBP'], description='galectin 1', other_designations='galectin-1|14 kDa laminin-binding protein|14 kDa lectin|HBL|HLBP14|HPL|S-Lac lectin 1|beta-galactoside-binding lectin L-14-I|beta-galactoside-binding protein 14kDa|epididymis secretory sperm binding protein|gal-1|galaptin|lactose-binding lectin 1|lectin, galactoside-binding, soluble, 1|putative MAPK-activating protein PM12', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37675636, end_position_on_the_genomic_accession=37679802, orientation='plus', exon_count=4, OMIM=[150570], no_hdr0=''),
    3957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3957, CurrentID=0, Status='live', Symbol='LGALS2', Aliases=['HL14'], description='galectin 2', other_designations='galectin-2|S-Lac lectin 2|beta-galactoside-binding lectin L-14-II|gal-2|lactose-binding lectin 2|lectin, galactoside-binding, soluble, 2', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37570248, end_position_on_the_genomic_accession=37580087, orientation='minus', exon_count=4, OMIM=[150571], no_hdr0=''),
    3958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3958, CurrentID=0, Status='live', Symbol='LGALS3', Aliases=['CBP35', 'GAL3', 'GALBP', 'GALIG', 'L31', 'LGALS2', 'MAC2'], description='galectin 3', other_designations='galectin-3|35 kDa lectin|IgE-binding protein|MAC-2 antigen|advanced glycation end-product receptor 3|carbohydrate-binding protein 35|epididymis secretory sperm binding protein|galactose-specific lectin 3|laminin-binding protein|lectin L-29|lectin, galactoside-binding, soluble, 3', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55129252, end_position_on_the_genomic_accession=55145430, orientation='plus', exon_count=6, OMIM=[153619], no_hdr0=''),
    3959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3959, CurrentID=0, Status='live', Symbol='LGALS3BP', Aliases=['90K', 'BTBD17B', 'CyCAP', 'M2BP', 'MAC-2-BP', 'TANGO10B', 'gp90'], description='galectin 3 binding protein', other_designations='galectin-3-binding protein|L3 antigen|MAC2BP|Mac-2-binding protein|basement membrane autoantigen p105|lectin galactoside-binding soluble 3-binding protein|mac-2 BP|serum protein 90K|transport and golgi organization 10 homolog B|tumor-associated antigen 90K', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78971255, end_position_on_the_genomic_accession=78979923, orientation='minus', exon_count=6, OMIM=[600626], no_hdr0=''),
    3960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3960, CurrentID=0, Status='live', Symbol='LGALS4', Aliases=['GAL4', 'L36LBP'], description='galectin 4', other_designations='galectin-4|L-36 lactose-binding protein|antigen NY-CO-27|gal-4|lactose-binding lectin 4|lectin, galactoside-binding, soluble, 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38801671, end_position_on_the_genomic_accession=38813614, orientation='minus', exon_count=10, OMIM=[602518], no_hdr0=''),
    3963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3963, CurrentID=0, Status='live', Symbol='LGALS7', Aliases=['GAL7A', 'LGALS7'], description='galectin 7', other_designations='galectin-7|lectin, galactoside-binding, soluble, 7', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38770968, end_position_on_the_genomic_accession=38773517, orientation='minus', exon_count=4, OMIM=[600615], no_hdr0=''),
    3964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3964, CurrentID=0, Status='live', Symbol='LGALS8', Aliases=['Gal-8', 'PCTA-1', 'PCTA1', 'Po66-CBP'], description='galectin 8', other_designations='galectin-8|Po66 carbohydrate binding protein|galectin-8g|lectin, galactoside-binding, soluble, 8|po66 carbohydrate-binding protein|prostate carcinoma tumor antigen 1', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236518214, end_position_on_the_genomic_accession=236552981, orientation='plus', exon_count=15, OMIM=[606099], no_hdr0=''),
    3965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3965, CurrentID=0, Status='live', Symbol='LGALS9', Aliases=['HUATA', 'LGALS9'], description='galectin 9', other_designations='galectin-9|ecalectin|gal-9|lectin, galactoside-binding, soluble, 9|tumor antigen HOM-HD-21|urate transporter/channel protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=27631172, end_position_on_the_genomic_accession=27649560, orientation='plus', exon_count=12, OMIM=[601879], no_hdr0=''),
    3972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3972, CurrentID=0, Status='live', Symbol='LHB', Aliases=['CGB4', 'HH23', 'LSH-B', 'LSH-beta'], description='luteinizing hormone subunit beta', other_designations='lutropin subunit beta|interstitial cell stimulating hormone, beta chain|luteinizing hormone beta polypeptide|luteinizing hormone beta subunit|lutropin beta chain', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49015980, end_position_on_the_genomic_accession=49017091, orientation='minus', exon_count=3, OMIM=[152780], no_hdr0=''),
    3973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3973, CurrentID=0, Status='live', Symbol='LHCGR', Aliases=['HHG', 'LCGR', 'LGR2', 'LH/CG-R', 'LH/CGR', 'LHR', 'LHRHR', 'LSH-R', 'ULG5'], description='luteinizing hormone/choriogonadotropin receptor', other_designations='lutropin-choriogonadotropic hormone receptor|hypergonadotropic hypogonadism|lutropin/choriogonadotropin receptor', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48686774, end_position_on_the_genomic_accession=48755724, orientation='minus', exon_count=14, OMIM=[152790], no_hdr0=''),
    3975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3975, CurrentID=0, Status='live', Symbol='LHX1', Aliases=['LIM-1', 'LIM1'], description='LIM homeobox 1', other_designations='LIM/homeobox protein Lhx1|LIM homeobox protein 1|homeobox protein Lim-1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36937475, end_position_on_the_genomic_accession=36944612, orientation='plus', exon_count=5, OMIM=[601999], no_hdr0=''),
    3976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3976, CurrentID=0, Status='live', Symbol='LIF', Aliases=['CDF', 'DIA', 'HILDA', 'MLPLI'], description='LIF interleukin 6 family cytokine', other_designations='leukemia inhibitory factor|D factor|cholinergic differentiation factor|differentiation inhibitory activity|differentiation-inducing factor|differentiation-stimulating factor|hepatocyte-stimulating factor III|human interleukin in DA cells|melanoma-derived LPL inhibitor', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30240453, end_position_on_the_genomic_accession=30257487, orientation='minus', exon_count=5, OMIM=[159540], no_hdr0=''),
    3977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3977, CurrentID=0, Status='live', Symbol='LIFR', Aliases=['CD118', 'LIF-R', 'SJS2', 'STWS', 'SWS'], description='LIF receptor subunit alpha', other_designations='leukemia inhibitory factor receptor|CD118 antigen|LIF receptor alpha|leukemia inhibitory factor receptor alpha', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=38474668, end_position_on_the_genomic_accession=38606290, orientation='minus', exon_count=25, OMIM=[151443], no_hdr0=''),
    3978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3978, CurrentID=0, Status='live', Symbol='LIG1', Aliases=[], description='DNA ligase 1', other_designations='DNA ligase 1|ligase I, DNA, ATP-dependent|polydeoxyribonucleotide synthase [ATP] 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48115445, end_position_on_the_genomic_accession=48170595, orientation='minus', exon_count=29, OMIM=[126391], no_hdr0=''),
    3980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3980, CurrentID=0, Status='live', Symbol='LIG3', Aliases=['LIG2alpha', 'LIG3'], description='DNA ligase 3', other_designations='DNA ligase 3|ligase II, DNA, ATP-dependent|ligase III, DNA, ATP-dependent|polydeoxyribonucleotide synthase [ATP] 3', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34980504, end_position_on_the_genomic_accession=35009743, orientation='plus', exon_count=22, OMIM=[600940], no_hdr0=''),
    3981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3981, CurrentID=0, Status='live', Symbol='LIG4', Aliases=['LIG4S'], description='DNA ligase 4', other_designations='DNA ligase 4|DNA joinase|DNA ligase IV|DNA repair enzyme|ligase IV, DNA, ATP-dependent|polydeoxyribonucleotide synthase [ATP] 4|polynucleotide ligase|sealase', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=108207442, end_position_on_the_genomic_accession=108218349, orientation='minus', exon_count=6, OMIM=[601837], no_hdr0=''),
    3982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3982, CurrentID=0, Status='live', Symbol='LIM2', Aliases=['CTRCT19', 'MP17', 'MP19'], description='lens intrinsic membrane protein 2', other_designations='lens fiber membrane intrinsic protein|MP18|MP20|lens intrinsic membrane protein 2, 19kDa', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51379909, end_position_on_the_genomic_accession=51387974, orientation='minus', exon_count=5, OMIM=[154045], no_hdr0=''),
    3983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3983, CurrentID=0, Status='live', Symbol='ABLIM1', Aliases=['ABLIM', 'LIMAB1', 'LIMATIN', 'abLIM-1'], description='actin binding LIM protein 1', other_designations='actin-binding LIM protein 1|actin-binding LIM protein family member 1|actin-binding double-zinc-finger protein', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114431110, end_position_on_the_genomic_accession=114821643, orientation='minus', exon_count=33, OMIM=[602330], no_hdr0=''),
    3984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3984, CurrentID=0, Status='live', Symbol='LIMK1', Aliases=['LIMK', 'LIMK-1'], description='LIM domain kinase 1', other_designations='LIM domain kinase 1|LIM motif-containing protein kinase', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74083804, end_position_on_the_genomic_accession=74122525, orientation='plus', exon_count=17, OMIM=[601329], no_hdr0=''),
    3985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3985, CurrentID=0, Status='live', Symbol='LIMK2', Aliases=[], description='LIM domain kinase 2', other_designations='LIM domain kinase 2', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31212298, end_position_on_the_genomic_accession=31280080, orientation='plus', exon_count=18, OMIM=[601988], no_hdr0=''),
    3987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3987, CurrentID=0, Status='live', Symbol='LIMS1', Aliases=['PINCH', 'PINCH-1', 'PINCH1'], description='LIM zinc finger domain containing 1', other_designations='LIM and senescent cell antigen-like-containing domain protein 1|LIM and senescent cell antigen-like domains 1|LIM-type zinc finger domains 1|particularly interesting new Cys-His protein 1|renal carcinoma antigen NY-REN-48|senescent cell antigen', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108533671, end_position_on_the_genomic_accession=108687246, orientation='plus', exon_count=19, OMIM=[602567], no_hdr0=''),
    3988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3988, CurrentID=0, Status='live', Symbol='LIPA', Aliases=['CESD', 'LAL'], description='lipase A, lysosomal acid type', other_designations='lysosomal acid lipase/cholesteryl ester hydrolase|acid cholesteryl ester hydrolase|cholesterol ester hydrolase|cholesteryl esterase|lipase A, lysosomal acid, cholesterol esterase|lysosomal acid lipase|sterol esterase', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89213571, end_position_on_the_genomic_accession=89251926, orientation='minus', exon_count=10, OMIM=[613497], no_hdr0=''),
    3989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3989, CurrentID=0, Status='live', Symbol='LIPB', Aliases=[], description='lipase B, lysosomal acid type', other_designations='', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[247980], no_hdr0=''),
    3990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3990, CurrentID=0, Status='live', Symbol='LIPC', Aliases=['HDLCQ12', 'HL', 'HTGL', 'LIPH'], description='lipase C, hepatic type', other_designations='hepatic triacylglycerol lipase|Triacylglycerol lipase|hepatic lipase|lipase member C|lipase, hepatic|lysophospholipase|phospholipase A1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58410457, end_position_on_the_genomic_accession=58569844, orientation='plus', exon_count=15, OMIM=[151670], no_hdr0=''),
    3991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3991, CurrentID=0, Status='live', Symbol='LIPE', Aliases=['AOMS4', 'FPLD6', 'HSL', 'LHS', 'REH'], description='lipase E, hormone sensitive type', other_designations='hormone-sensitive lipase|lipase, hormone-sensitive|monoacylglycerol lipase LIPE|retinyl ester hydrolase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42401512, end_position_on_the_genomic_accession=42427421, orientation='minus', exon_count=15, OMIM=[151750], no_hdr0=''),
    3992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3992, CurrentID=0, Status='live', Symbol='FADS1', Aliases=['D5D', 'FADS6', 'FADSD5', 'LLCDL1', 'TU12'], description='fatty acid desaturase 1', other_designations='acyl-CoA (8-3)-desaturase|delta(5) desaturase|delta-5 fatty acid desaturase|linoleoyl-CoA desaturase (delta-6-desaturase)-like 1', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61799627, end_position_on_the_genomic_accession=61817003, orientation='minus', exon_count=13, OMIM=[606148], no_hdr0=''),
    3993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3993, CurrentID=0, Status='live', Symbol='LLGL2', Aliases=['HGL', 'Hugl-2', 'LGL2'], description='LLGL scribble cell polarity complex component 2', other_designations='LLGL scribble cell polarity complex component 2|LLGL2, scribble cell polarity complex component|human giant larvae homolog|lethal giant larvae homolog 2, scribble cell polarity complex component|lethal(2) giant larvae protein homolog 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75525080, end_position_on_the_genomic_accession=75575209, orientation='plus', exon_count=33, OMIM=[618483], no_hdr0=''),
    3995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3995, CurrentID=0, Status='live', Symbol='FADS3', Aliases=['CYB5RP', 'LLCDL3'], description='fatty acid desaturase 3', other_designations='fatty acid desaturase 3|cytochrome b5-related protein|delta(13) desaturase|delta(13) fatty acid desaturase|delta-9 fatty acid desaturase|delta-9-desaturase|linoleoyl-CoA desaturase (delta-9-desaturase)-like 3', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61873526, end_position_on_the_genomic_accession=61892224, orientation='minus', exon_count=12, OMIM=[606150], no_hdr0=''),
    3996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3996, CurrentID=0, Status='live', Symbol='LLGL1', Aliases=['DLG4', 'HUGL', 'HUGL-1', 'HUGL1', 'LLGL', 'Lgl1', 'Mgl1'], description='LLGL scribble cell polarity complex component 1', other_designations='lethal(2) giant larvae protein homolog 1|LLGL1, scribble cell polarity complex component|human homolog to the D-lgl gene protein|lethal giant larvae homolog 1, scribble cell polarity complex component', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18225593, end_position_on_the_genomic_accession=18244875, orientation='plus', exon_count=23, OMIM=[600966], no_hdr0=''),
    3998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=3998, CurrentID=0, Status='live', Symbol='LMAN1', Aliases=['ERGIC-53', 'ERGIC53', 'F5F8D', 'FMFD1', 'MCFD1', 'MR60', 'gp58'], description='lectin, mannose binding 1', other_designations='protein ERGIC-53|ER-Golgi intermediate compartment 53 kDa protein|endoplasmic reticulum-golgi intermediate compartment protein 53|intracellular mannose-specific lectin MR60', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59327823, end_position_on_the_genomic_accession=59359265, orientation='minus', exon_count=13, OMIM=[601567], no_hdr0=''),
    4000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4000, CurrentID=0, Status='live', Symbol='LMNA', Aliases=['CDCD1', 'CDDC', 'CMD1A', 'CMT2B1', 'EMD2', 'FPL', 'FPLD', 'FPLD2', 'HGPS', 'IDC', 'LDP1', 'LFP', 'LGMD1B', 'LMN1', 'LMNC', 'LMNL1', 'MADA', 'PRO1'], description='lamin A/C', other_designations='lamin|70 kDa lamin|epididymis secretory sperm binding protein|lamin A/C-like 1|mandibuloacral dysplasia type A|prelamin-A/C|renal carcinoma antigen NY-REN-32', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156082573, end_position_on_the_genomic_accession=156140081, orientation='plus', exon_count=17, OMIM=[150330], no_hdr0=''),
    4001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4001, CurrentID=0, Status='live', Symbol='LMNB1', Aliases=['ADLD', 'LMN', 'LMN2', 'LMNB', 'MCPH26'], description='lamin B1', other_designations='lamin-B1', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126776623, end_position_on_the_genomic_accession=126837020, orientation='plus', exon_count=12, OMIM=[150340], no_hdr0=''),
    4004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4004, CurrentID=0, Status='live', Symbol='LMO1', Aliases=['RBTN1', 'RHOM1', 'TTG1'], description='LIM domain only 1', other_designations='rhombotin-1|LIM domain only 1 (rhombotin 1)|LIM domain only protein 1|LMO-1|T-cell translocation gene 1|T-cell translocation protein 1|cysteine-rich protein TTG-1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8224304, end_position_on_the_genomic_accession=8268787, orientation='minus', exon_count=9, OMIM=[186921], no_hdr0=''),
    4005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4005, CurrentID=0, Status='live', Symbol='LMO2', Aliases=['LMO-2', 'RBTN2', 'RBTNL1', 'RHOM2', 'TTG2'], description='LIM domain only 2', other_designations='rhombotin-2|LIM domain only protein 2|T-cell translocation gene 2|T-cell translocation protein 2|cysteine-rich protein TTG-2|rhombotin-like 1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33858576, end_position_on_the_genomic_accession=33892076, orientation='minus', exon_count=9, OMIM=[180385], no_hdr0=''),
    4007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4007, CurrentID=0, Status='live', Symbol='PRICKLE3', Aliases=['LMO6', 'LOAM', 'Pk3'], description='prickle planar cell polarity protein 3', other_designations='prickle planar cell polarity protein 3|LIM domain only protein 6|LMO-6|prickle homolog 3|prickle-like protein 3|triple LIM domain protein 6', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49174802, end_position_on_the_genomic_accession=49186373, orientation='minus', exon_count=10, OMIM=[300111], no_hdr0=''),
    4008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4008, CurrentID=0, Status='live', Symbol='LMO7', Aliases=['FBX20', 'FBXO20b', 'LOMP', 'LMO7'], description='LIM domain 7', other_designations='LIM domain only protein 7|F-box only protein 20|F-box protein Fbx20|LIM domain only 7 protein|LMO-7|zinc-finger domain-containing protein', map_location='13q22.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=75620434, end_position_on_the_genomic_accession=75859870, orientation='plus', exon_count=39, OMIM=[604362], no_hdr0=''),
    4009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4009, CurrentID=0, Status='live', Symbol='LMX1A', Aliases=['DFNA7', 'LMX1', 'LMX1.1'], description='LIM homeobox transcription factor 1 alpha', other_designations='LIM homeobox transcription factor 1-alpha|LIM/homeobox protein 1.1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165201867, end_position_on_the_genomic_accession=165356715, orientation='minus', exon_count=12, OMIM=[600298], no_hdr0=''),
    4010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4010, CurrentID=0, Status='live', Symbol='LMX1B', Aliases=['FSGS10', 'LMX1.2', 'NPS1'], description='LIM homeobox transcription factor 1 beta', other_designations='LIM homeobox transcription factor 1-beta|LIM/homeobox protein 1.2|LMX-1.2', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=126613928, end_position_on_the_genomic_accession=126701032, orientation='plus', exon_count=8, OMIM=[602575], no_hdr0=''),
    4012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4012, CurrentID=0, Status='live', Symbol='LNPEP', Aliases=['CAP', 'IRAP', 'P-LAP', 'PLAP'], description='leucyl and cystinyl aminopeptidase', other_designations='leucyl-cystinyl aminopeptidase|AT (4) receptor|angiotensin IV receptor|cystinyl aminopeptidase|insulin-regulated aminopeptidase|insulin-regulated membrane aminopeptidase|insulin-responsive aminopeptidase|otase|oxytocinase|placental leucine aminopeptidase|vasopressinase', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=96934859, end_position_on_the_genomic_accession=97037513, orientation='plus', exon_count=20, OMIM=[151300], no_hdr0=''),
    4013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4013, CurrentID=0, Status='live', Symbol='VWA5A', Aliases=['BCSC-1', 'BCSC1', 'LOH11CR2A'], description='von Willebrand factor A domain containing 5A', other_designations='von Willebrand factor A domain-containing protein 5A|breast cancer suppressor candidate 1|loss of heterozygosity 11 chromosomal region 2 gene A protein|loss of heterozygosity, 11, chromosomal region 2, gene A|ortholog of mouse AW551984', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124115423, end_position_on_the_genomic_accession=124147721, orientation='plus', exon_count=19, OMIM=[602929], no_hdr0=''),
    4014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4014, CurrentID=0, Status='live', Symbol='LORICRIN', Aliases=['LOR'], description='loricrin cornified envelope precursor protein', other_designations='loricrin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153259635, end_position_on_the_genomic_accession=153262125, orientation='plus', exon_count=3, OMIM=[152445], no_hdr0=''),
    4015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4015, CurrentID=0, Status='live', Symbol='LOX', Aliases=['AAT10'], description='lysyl oxidase', other_designations='protein-lysine 6-oxidase', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122063195, end_position_on_the_genomic_accession=122078259, orientation='minus', exon_count=8, OMIM=[153455], no_hdr0=''),
    4016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4016, CurrentID=0, Status='live', Symbol='LOXL1', Aliases=['LOL', 'LOXL'], description='lysyl oxidase like 1', other_designations='lysyl oxidase homolog 1|lysyl oxidase-like protein 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73926462, end_position_on_the_genomic_accession=73952137, orientation='plus', exon_count=9, OMIM=[153456], no_hdr0=''),
    4017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4017, CurrentID=0, Status='live', Symbol='LOXL2', Aliases=['LOR', 'LOR2', 'WS9-14'], description='lysyl oxidase like 2', other_designations='lysyl oxidase homolog 2|lysyl oxidase related 2|lysyl oxidase-like 2 delta e13|lysyl oxidase-like 2 protein|lysyl oxidase-like protein 2|lysyl oxidase-related protein 2|lysyl oxidase-related protein WS9-14', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23296897, end_position_on_the_genomic_accession=23404120, orientation='minus', exon_count=14, OMIM=[606663], no_hdr0=''),
    4018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4018, CurrentID=0, Status='live', Symbol='LPA', Aliases=['AK38', 'APOA', 'LP'], description='lipoprotein(a)', other_designations='apolipoprotein(a)|antiangiogenic AK38 protein|apo(a)|lipoprotein, Lp(a)|lp(a)', map_location='6q25.3-q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160531482, end_position_on_the_genomic_accession=160664275, orientation='minus', exon_count=39, OMIM=[152200], no_hdr0=''),
    4019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4019, CurrentID=0, Status='live', Symbol='LPAL1', Aliases=[], description='lipoprotein(a) like 1', other_designations='lipoprotein(a) like 1|lipoprotein, Lp(a)-like 1', map_location='6q26-q27', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    4023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4023, CurrentID=0, Status='live', Symbol='LPL', Aliases=['HDLCQ11', 'LIPD'], description='lipoprotein lipase', other_designations='lipoprotein lipase|phospholipase A1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=19939253, end_position_on_the_genomic_accession=19967259, orientation='plus', exon_count=10, OMIM=[609708], no_hdr0=''),
    4025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4025, CurrentID=0, Status='live', Symbol='LPO', Aliases=['SPO'], description='lactoperoxidase', other_designations='lactoperoxidase|salivary peroxidase', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58238550, end_position_on_the_genomic_accession=58268518, orientation='plus', exon_count=14, OMIM=[150205], no_hdr0=''),
    4026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4026, CurrentID=0, Status='live', Symbol='LPP', Aliases=[], description='LIM domain containing preferred translocation partner in lipoma', other_designations='lipoma-preferred partner|LIM protein|lipoma preferred partner', map_location='3q27.3-q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=188152152, end_position_on_the_genomic_accession=188890671, orientation='plus', exon_count=25, OMIM=[600700], no_hdr0=''),
    4033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4033, CurrentID=0, Status='live', Symbol='IRAG2', Aliases=['JAW1', 'LRMP'], description='inositol 1,4,5-triphosphate receptor associated 2', other_designations='inositol 1,4,5-triphosphate receptor associated 2|lymphoid restricted membrane protein|protein Jaw1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=24997575, end_position_on_the_genomic_accession=25108335, orientation='plus', exon_count=42, OMIM=[602003], no_hdr0=''),
    4034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4034, CurrentID=0, Status='live', Symbol='LRCH4', Aliases=['LRN', 'LRRN1', 'LRRN4', 'PP14183'], description='leucine rich repeats and calponin homology domain containing 4', other_designations='leucine-rich repeat and calponin homology domain-containing protein 4|leucine rich repeat neuronal 4|leucine-rich neuronal protein|leucine-rich repeats and calponin homology (CH) domain containing 4', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100574011, end_position_on_the_genomic_accession=100586129, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    4035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4035, CurrentID=0, Status='live', Symbol='LRP1', Aliases=['A2MR', 'APOER', 'APR', 'CD91', 'IGFBP-3R', 'IGFBP3R', 'IGFBP3R1', 'KPA', 'LRPA', 'TGFBR5', 'LRP1'], description='LDL receptor related protein 1', other_designations='prolow-density lipoprotein receptor-related protein 1|TbetaR-V/LRP-1/IGFBP-3 receptor|alpha-2-macroglobulin receptor|apolipoprotein E receptor|low density lipoprotein receptor-related protein 1|type V tgf-beta receptor', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57128401, end_position_on_the_genomic_accession=57213377, orientation='plus', exon_count=90, OMIM=[107770], no_hdr0=''),
    4036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4036, CurrentID=0, Status='live', Symbol='LRP2', Aliases=['DBS', 'GP330', 'LRP-2'], description='LDL receptor related protein 2', other_designations='low-density lipoprotein receptor-related protein 2|Heymann nephritis antigen homolog|calcium sensor protein|glycoprotein 330|megalin', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169127109, end_position_on_the_genomic_accession=169362597, orientation='minus', exon_count=80, OMIM=[600073], no_hdr0=''),
    4037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4037, CurrentID=0, Status='live', Symbol='LRP3', Aliases=[], description='LDL receptor related protein 3', other_designations='low-density lipoprotein receptor-related protein 3|105 kDa low-density lipoprotein receptor-related protein|CTD-2540B15.13|LRP-3|hLRp105', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33194330, end_position_on_the_genomic_accession=33208864, orientation='plus', exon_count=7, OMIM=[603159], no_hdr0=''),
    4038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4038, CurrentID=0, Status='live', Symbol='LRP4', Aliases=['CLSS', 'CMS17', 'LRP-4', 'LRP10', 'MEGF7', 'SOST2'], description='LDL receptor related protein 4', other_designations='low-density lipoprotein receptor-related protein 4|multiple epidermal growth factor-like domains 7', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46854715, end_position_on_the_genomic_accession=46918550, orientation='minus', exon_count=41, OMIM=[604270], no_hdr0=''),
    4040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4040, CurrentID=0, Status='live', Symbol='LRP6', Aliases=['ADCAD2', 'STHAG7'], description='LDL receptor related protein 6', other_designations='low-density lipoprotein receptor-related protein 6|LRP-6', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12116025, end_position_on_the_genomic_accession=12267044, orientation='minus', exon_count=24, OMIM=[603507], no_hdr0=''),
    4041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4041, CurrentID=0, Status='live', Symbol='LRP5', Aliases=['BMND1', 'EVR1', 'EVR4', 'HBM', 'LR3', 'LRP-5', 'LRP-7', 'LRP7', 'OPPG', 'OPS', 'OPTA1', 'PCLD4', 'VBCH2'], description='LDL receptor related protein 5', other_designations='low-density lipoprotein receptor-related protein 5|low density lipoprotein receptor-related protein 5|low density lipoprotein receptor-related protein 7', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68298866, end_position_on_the_genomic_accession=68449275, orientation='plus', exon_count=28, OMIM=[603506], no_hdr0=''),
    4043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4043, CurrentID=0, Status='live', Symbol='LRPAP1', Aliases=['A2MRAP', 'A2RAP', 'HBP44', 'MRAP', 'MYP23', 'RAP', 'alpha-2-MRAP'], description='LDL receptor related protein associated protein 1', other_designations='alpha-2-macroglobulin receptor-associated protein|39 kDa receptor-associated protein|low density lipoprotein receptor-related protein associated protein 1|low density lipoprotein-related protein-associated protein 1 (alpha-2-macroglobulin receptor-associated protein 1)', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3503612, end_position_on_the_genomic_accession=3532497, orientation='minus', exon_count=9, OMIM=[104225], no_hdr0=''),
    4045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4045, CurrentID=0, Status='live', Symbol='LSAMP', Aliases=['IGLON3', 'LAMP'], description='limbic system associated membrane protein', other_designations='limbic system-associated membrane protein|IgLON family member 3', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=115802374, end_position_on_the_genomic_accession=116445487, orientation='minus', exon_count=13, OMIM=[603241], no_hdr0=''),
    4046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4046, CurrentID=0, Status='live', Symbol='LSP1', Aliases=['WP34', 'pp52'], description='lymphocyte specific protein 1', other_designations='lymphocyte-specific protein 1|47 kDa actin binding protein|52 kDa phosphoprotein|F-actin binding and cytoskeleton associated protein|leufactin (leukocyte F-actin binding protein)|leukocyte-specific protein 1|lymphocyte-specific antigen WP34', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1853084, end_position_on_the_genomic_accession=1892263, orientation='plus', exon_count=16, OMIM=[153432], no_hdr0=''),
    4047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4047, CurrentID=0, Status='live', Symbol='LSS', Aliases=['APMR4', 'CTRCT44', 'HYPT14', 'OSC'], description='lanosterol synthase', other_designations='lanosterol synthase|2,3-epoxysqualene-lanosterol cyclase|epididymis secretory sperm binding protein|hOSC|lanosterol synthase (2,3-oxidosqualene-lanosterol cyclase)|oxidosqualene--lanosterol cyclase', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46188446, end_position_on_the_genomic_accession=46228774, orientation='minus', exon_count=22, OMIM=[600909], no_hdr0=''),
    4048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4048, CurrentID=0, Status='live', Symbol='LTA4H', Aliases=[], description='leukotriene A4 hydrolase', other_designations='leukotriene A-4 hydrolase|LTA-4 hydrolase|testicular secretory protein Li 27|tripeptide aminopeptidase LTA4H', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=96000753, end_position_on_the_genomic_accession=96043520, orientation='minus', exon_count=20, OMIM=[151570], no_hdr0=''),
    4049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4049, CurrentID=0, Status='live', Symbol='LTA', Aliases=['LT', 'TNFB', 'TNFSF1', 'TNLG1E'], description='lymphotoxin alpha', other_designations='lymphotoxin-alpha|LT-alpha|TNF superfamily, member 1|TNF-beta|truncated lymphotoxin alpha|tumor necrosis factor beta|tumor necrosis factor ligand 1E|tumor necrosis factor ligand superfamily member 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31560550, end_position_on_the_genomic_accession=31574324, orientation='plus', exon_count=8, OMIM=[153440], no_hdr0=''),
    4050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4050, CurrentID=0, Status='live', Symbol='LTB', Aliases=['TNFC', 'TNFSF3', 'TNLG1C', 'p33'], description='lymphotoxin beta', other_designations='lymphotoxin-beta|LT-beta|TNF superfamily member 3|TNF-C|lymphotoxin beta (TNF superfamily, member 3)|tumor necrosis factor C|tumor necrosis factor ligand 1C|tumor necrosis factor ligand superfamily member 3', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31580558, end_position_on_the_genomic_accession=31582425, orientation='minus', exon_count=4, OMIM=[600978], no_hdr0=''),
    4051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4051, CurrentID=0, Status='live', Symbol='CYP4F3', Aliases=['CPF3', 'CYP4F', 'CYPIVF3', 'LTB4H'], description='cytochrome P450 family 4 subfamily F member 3', other_designations='cytochrome P450 4F3|20-HETE synthase|20-hydroxyeicosatetraenoic acid synthase|cytochrome P-450|cytochrome P450, family 4, subfamily F, polypeptide 3|cytochrome P450, subfamily IVF, polypeptide 3 (leukotriene B4 omega hydroxylase)|cytochrome P450-LTB-omega|docosahexaenoic acid omega-hydroxylase CYP4F3|leukotriene B4 omega hydroxylase|leukotriene-B(4) 20-monooxygenase 2|leukotriene-B(4) omega-hydroxylase 2|leukotriene-B4 20-monooxygenase', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15640897, end_position_on_the_genomic_accession=15662825, orientation='plus', exon_count=15, OMIM=[601270], no_hdr0=''),
    4052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4052, CurrentID=0, Status='live', Symbol='LTBP1', Aliases=[], description='latent transforming growth factor beta binding protein 1', other_designations='latent-transforming growth factor beta-binding protein 1|LTBP-1|TGF-beta1-BP-1|transforming growth factor beta-1-binding protein 1', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32902129, end_position_on_the_genomic_accession=33399509, orientation='plus', exon_count=39, OMIM=[150390], no_hdr0=''),
    4053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4053, CurrentID=0, Status='live', Symbol='LTBP2', Aliases=['C14orf141', 'GLC3D', 'LTBP3', 'MSPKA', 'MSTP031', 'WMS3'], description='latent transforming growth factor beta binding protein 2', other_designations='latent-transforming growth factor beta-binding protein 2|LTBP-2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74498183, end_position_on_the_genomic_accession=74612593, orientation='minus', exon_count=36, OMIM=[602091], no_hdr0=''),
    4054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4054, CurrentID=0, Status='live', Symbol='LTBP3', Aliases=['DASS', 'GPHYSD3', 'LTBP-3', 'LTBP2', 'STHAG6', 'pp6425'], description='latent transforming growth factor beta binding protein 3', other_designations='latent-transforming growth factor beta-binding protein 3|latent TGF beta binding protein 3', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65538559, end_position_on_the_genomic_accession=65558389, orientation='minus', exon_count=29, OMIM=[602090], no_hdr0=''),
    4055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4055, CurrentID=0, Status='live', Symbol='LTBR', Aliases=['D12S370', 'LT-BETA-R', 'TNF-R-III', 'TNFCR', 'TNFR-RP', 'TNFR2-RP', 'TNFR3', 'TNFRSF3'], description='lymphotoxin beta receptor', other_designations='tumor necrosis factor receptor superfamily member 3|lymphotoxin B receptor|lymphotoxin beta receptor (TNFR superfamily, member 3)|tumor necrosis factor C receptor|tumor necrosis factor receptor 2-related protein|tumor necrosis factor receptor type III', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6375160, end_position_on_the_genomic_accession=6391571, orientation='plus', exon_count=12, OMIM=[600979], no_hdr0=''),
    4056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4056, CurrentID=0, Status='live', Symbol='LTC4S', Aliases=[], description='leukotriene C4 synthase', other_designations='leukotriene C4 synthase|LTC4 synthase|glutathione S-transferase LTC4', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179793986, end_position_on_the_genomic_accession=179796647, orientation='plus', exon_count=5, OMIM=[246530], no_hdr0=''),
    4057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4057, CurrentID=0, Status='live', Symbol='LTF', Aliases=['GIG12', 'HEL110', 'HLF2', 'LF'], description='lactotransferrin', other_designations='lactotransferrin|epididymis luminal protein 110|growth-inhibiting protein 12|kaliocin-1|lactoferricin|lactoferroxin|neutrophil lactoferrin|talalactoferrin', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46435645, end_position_on_the_genomic_accession=46485234, orientation='minus', exon_count=22, OMIM=[150210], no_hdr0=''),
    4058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4058, CurrentID=0, Status='live', Symbol='LTK', Aliases=['TYK1'], description='leukocyte receptor tyrosine kinase', other_designations='leukocyte tyrosine kinase receptor|protein tyrosine kinase 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41503637, end_position_on_the_genomic_accession=41513887, orientation='minus', exon_count=20, OMIM=[151520], no_hdr0=''),
    4059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4059, CurrentID=0, Status='live', Symbol='BCAM', Aliases=['AU', 'CD239', 'LU', 'MSK19'], description='basal cell adhesion molecule (Lutheran blood group)', other_designations='basal cell adhesion molecule|Auberger b antigen|B-CAM cell surface glycoprotein|B-cell adhesion molecule|F8/G253 antigen|Lutheran blood group variant LUGA|basal cell adhesion molecule (Lu and Au blood groups)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44809059, end_position_on_the_genomic_accession=44821421, orientation='plus', exon_count=14, OMIM=[612773], no_hdr0=''),
    4060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4060, CurrentID=0, Status='live', Symbol='LUM', Aliases=['LDC', 'SLRR2D'], description='lumican', other_designations='lumican|KSPG lumican|epididymis secretory sperm binding protein|keratan sulfate proteoglycan lumican|lumican proteoglycan', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=91102629, end_position_on_the_genomic_accession=91111494, orientation='minus', exon_count=3, OMIM=[600616], no_hdr0=''),
    4061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4061, CurrentID=0, Status='live', Symbol='LY6E', Aliases=['RIG-E', 'RIGE', 'SCA-2', 'SCA2', 'TSA-1'], description='lymphocyte antigen 6 family member E', other_designations='lymphocyte antigen 6E|ly-6E|lymphocyte antigen 6 complex, locus E|retinoic acid induced gene E|retinoic acid-induced gene E protein|stem cell antigen 2|thymic shared antigen 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143018529, end_position_on_the_genomic_accession=143022409, orientation='plus', exon_count=4, OMIM=[601384], no_hdr0=''),
    4062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4062, CurrentID=0, Status='live', Symbol='LY6H', Aliases=['NMLY6'], description='lymphocyte antigen 6 family member H', other_designations='lymphocyte antigen 6H|ly-6H|lymphocyte antigen 6 complex, locus H', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143157916, end_position_on_the_genomic_accession=143160654, orientation='minus', exon_count=6, OMIM=[603625], no_hdr0=''),
    4063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4063, CurrentID=0, Status='live', Symbol='LY9', Aliases=['CD229', 'SLAMF3', 'hly9', 'mLY9'], description='lymphocyte antigen 9', other_designations='T-lymphocyte surface antigen Ly-9|SLAM family member 3|cell surface molecule Ly-9|signaling lymphocytic activation molecule 3', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160796112, end_position_on_the_genomic_accession=160828256, orientation='plus', exon_count=12, OMIM=[600684], no_hdr0=''),
    4064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4064, CurrentID=0, Status='live', Symbol='CD180', Aliases=['LY64', 'Ly78', 'RP105'], description='CD180 molecule', other_designations='CD180 antigen|lymphocyte antigen 64|lymphocyte antigen-64, radioprotective, 105kDa|radioprotective 105 kDa protein', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=67179613, end_position_on_the_genomic_accession=67196799, orientation='minus', exon_count=4, OMIM=[602226], no_hdr0=''),
    4065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4065, CurrentID=0, Status='live', Symbol='LY75', Aliases=['CD205', 'CLEC13B', 'DEC-205', 'GP200-MR6', 'LY-75'], description='lymphocyte antigen 75', other_designations='lymphocyte antigen 75|C-type lectin domain family 13 member B', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159803355, end_position_on_the_genomic_accession=159904756, orientation='minus', exon_count=35, OMIM=[604524], no_hdr0=''),
    4066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4066, CurrentID=0, Status='live', Symbol='LYL1', Aliases=['bHLHa18'], description='LYL1 basic helix-loop-helix family member', other_designations='protein lyl-1|class A basic helix-loop-helix protein 18|lymphoblastic leukemia associated hematopoiesis regulator 1|lymphoblastic leukemia derived sequence 1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13099033, end_position_on_the_genomic_accession=13102858, orientation='minus', exon_count=4, OMIM=[151440], no_hdr0=''),
    4067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4067, CurrentID=0, Status='live', Symbol='LYN', Aliases=['JTK8', 'p53Lyn', 'p56Lyn'], description='LYN proto-oncogene, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Lyn|lck/Yes-related novel protein tyrosine kinase|v-yes-1 Yamaguchi sarcoma viral related oncogene homolog', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=55876041, end_position_on_the_genomic_accession=56014169, orientation='plus', exon_count=15, OMIM=[165120], no_hdr0=''),
    4068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4068, CurrentID=0, Status='live', Symbol='SH2D1A', Aliases=['DSHP', 'EBVS', 'IMD5', 'LYP', 'MTCP1', 'SAP', 'SAP/SH2D1A', 'XLP', 'XLPD', 'XLPD1'], description='SH2 domain containing 1A', other_designations='SH2 domain-containing protein 1A|Duncan disease SH2-protein|SLAM associated protein/SH2 domain protein 1A|SLAM-associated protein|T cell signal transduction molecule SAP|signaling lymphocyte activation molecule-associated protein|signaling lymphocytic activation molecule-associated protein', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=124346563, end_position_on_the_genomic_accession=124373160, orientation='plus', exon_count=4, OMIM=[300490], no_hdr0=''),
    4069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4069, CurrentID=0, Status='live', Symbol='LYZ', Aliases=['LYZF1', 'LZM'], description='lysozyme', other_designations='lysozyme C|1,4-beta-N-acetylmuramidase C|c-type lysozyme|lysozyme F1', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69348381, end_position_on_the_genomic_accession=69354234, orientation='plus', exon_count=4, OMIM=[153450], no_hdr0=''),
    4070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4070, CurrentID=0, Status='live', Symbol='TACSTD2', Aliases=['EGP-1', 'EGP1', 'GA733-1', 'GA7331', 'GP50', 'M1S1', 'TROP2'], description='tumor associated calcium signal transducer 2', other_designations='tumor-associated calcium signal transducer 2|40kD glycoprotein, identified by monoclonal antibody GA733|cell surface glycoprotein TROP2|cell surface glycoprotein Trop-2|epithelial glycoprotein-1|gastrointestinal tumor-associated antigen GA7331|membrane component, chromosome 1, surface marker 1|pancreatic carcinoma marker protein GA733-1|pancreatic carcinoma marker protein GA7331|trophoblast cell surface antigen 2|truncated TACSTD2', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=58575433, end_position_on_the_genomic_accession=58577252, orientation='minus', exon_count=1, OMIM=[137290], no_hdr0=''),
    4071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4071, CurrentID=0, Status='live', Symbol='TM4SF1', Aliases=['H-L6', 'L6', 'M3S1', 'TAAL6'], description='transmembrane 4 L six family member 1', other_designations='transmembrane 4 L6 family member 1|membrane component, chromosome 3, surface marker 1|transmembrane 4 superfamily member 1|tumor-associated antigen L6', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149369022, end_position_on_the_genomic_accession=149377781, orientation='minus', exon_count=5, OMIM=[191155], no_hdr0=''),
    4072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4072, CurrentID=0, Status='live', Symbol='EPCAM', Aliases=['DIAR5', 'EGP-2', 'EGP314', 'EGP40', 'ESA', 'HNPCC8', 'KS1/4', 'KSA', 'M4S1', 'MIC18', 'MK-1', 'TACSTD1', 'TROP1'], description='epithelial cell adhesion molecule', other_designations='epithelial cell adhesion molecule|adenocarcinoma-associated antigen|cell surface glycoprotein Trop-1|epithelial glycoprotein 314|human epithelial glycoprotein-2|major gastrointestinal tumor-associated protein GA733-2|membrane component, chromosome 4, surface marker (35kD glycoprotein)|trophoblast cell surface antigen 1|tumor-associated calcium signal transducer 1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47369311, end_position_on_the_genomic_accession=47387020, orientation='plus', exon_count=9, OMIM=[185535], no_hdr0=''),
    4074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4074, CurrentID=0, Status='live', Symbol='M6PR', Aliases=['CD-M6PR', 'CD-MPR', 'MPR 46', 'MPR-46', 'MPR46', 'SMPR'], description='mannose-6-phosphate receptor, cation dependent', other_designations='cation-dependent mannose-6-phosphate receptor|46-kDa mannose 6-phosphate receptor|CD Man-6-P receptor|Mr 46,000 Man6PR|small mannose 6-phosphate receptor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8940361, end_position_on_the_genomic_accession=8949645, orientation='minus', exon_count=8, OMIM=[154540], no_hdr0=''),
    4076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4076, CurrentID=0, Status='live', Symbol='CAPRIN1', Aliases=['GPIAP1', 'GPIP137', 'GRIP137', 'M11S1', 'RNG105', 'p137GPI'], description='cell cycle associated protein 1', other_designations='caprin-1|GPI-anchored membrane protein 1|GPI-anchored protein p137|GPI-p137|RNA granule protein 105|activation/proliferation-associated protein 1|caprin 1|cytoplasmic activation- and proliferation-associated protein 1|cytoplasmic activation/proliferation-associated protein-1|membrane component chromosome 11 surface marker 1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34051663, end_position_on_the_genomic_accession=34102610, orientation='plus', exon_count=19, OMIM=[601178], no_hdr0=''),
    4077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4077, CurrentID=0, Status='live', Symbol='NBR1', Aliases=['1A1-3B', 'IAI3B', 'M17S2', 'MIG19'], description='NBR1 autophagy cargo receptor', other_designations='next to BRCA1 gene 1 protein|B-box protein|cell migration-inducing gene 19 protein|membrane component, chromosome 17, surface marker 2 (ovarian carcinoma antigen CA125)|migration-inducing protein 19|neighbor of BRCA1 gene 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43170310, end_position_on_the_genomic_accession=43211688, orientation='plus', exon_count=24, OMIM=[166945], no_hdr0=''),
    4081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4081, CurrentID=0, Status='live', Symbol='MAB21L1', Aliases=['CAGR1', 'COFG', 'Nbla00126'], description='mab-21 like 1', other_designations='putative nucleotidyltransferase MAB21L1|mab-21-like protein 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=35473789, end_position_on_the_genomic_accession=35476689, orientation='minus', exon_count=1, OMIM=[601280], no_hdr0=''),
    4082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4082, CurrentID=0, Status='live', Symbol='MARCKS', Aliases=['80K-L', 'MACS', 'PKCSL', 'PRKCSL'], description='myristoylated alanine rich protein kinase C substrate', other_designations='myristoylated alanine-rich C-kinase substrate|myristoylated alanine-rich protein kinase C substrate (MARCKS, 80K-L)|phosphomyristin|protein kinase C substrate, 80 kDa protein, light chain', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=113857345, end_position_on_the_genomic_accession=113863475, orientation='plus', exon_count=2, OMIM=[177061], no_hdr0=''),
    4084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4084, CurrentID=0, Status='live', Symbol='MXD1', Aliases=['BHLHC58', 'MAD', 'MAD1'], description='MAX dimerization protein 1', other_designations='max dimerization protein 1|MAX-binding protein|antagonizer of myc transcriptional activity|max dimerizer 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69915109, end_position_on_the_genomic_accession=69942945, orientation='plus', exon_count=6, OMIM=[600021], no_hdr0=''),
    4085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4085, CurrentID=0, Status='live', Symbol='MAD2L1', Aliases=['HSMAD2', 'MAD2'], description='mitotic arrest deficient 2 like 1', other_designations='mitotic spindle assembly checkpoint protein MAD2A|MAD2 (mitotic arrest deficient, yeast, homolog)-like 1|MAD2 mitotic arrest deficient-like 1|MAD2-like protein 1|mitotic arrest deficient 2-like protein 1|mitotic arrest deficient, yeast, homolog-like 1', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=120055623, end_position_on_the_genomic_accession=120066848, orientation='minus', exon_count=5, OMIM=[601467], no_hdr0=''),
    4086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4086, CurrentID=0, Status='live', Symbol='SMAD1', Aliases=['BSP-1', 'BSP1', 'JV4-1', 'JV41', 'MADH1', 'MADR1'], description='SMAD family member 1', other_designations='mothers against decapentaplegic homolog 1|MAD, mothers against decapentaplegic homolog 1|Mad-related protein 1|SMAD, mothers against DPP homolog 1|TGF-beta signaling protein 1|mothers against DPP homolog 1|transforming growth factor-beta signaling protein 1', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145481306, end_position_on_the_genomic_accession=145559176, orientation='plus', exon_count=12, OMIM=[601595], no_hdr0=''),
    4087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4087, CurrentID=0, Status='live', Symbol='SMAD2', Aliases=['JV18', 'JV18-1', 'MADH2', 'MADR2', 'hMAD-2', 'hSMAD2'], description='SMAD family member 2', other_designations='mothers against decapentaplegic homolog 2|MAD homolog 2|SMAD, mothers against DPP homolog 2|Sma- and Mad-related protein 2|mother against DPP homolog 2', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47808957, end_position_on_the_genomic_accession=47931188, orientation='minus', exon_count=18, OMIM=[601366], no_hdr0=''),
    4088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4088, CurrentID=0, Status='live', Symbol='SMAD3', Aliases=['HSPC193', 'HsT17436', 'JV15-2', 'LDS1C', 'LDS3', 'MADH3'], description='SMAD family member 3', other_designations='mothers against decapentaplegic homolog 3|MAD homolog 3|MAD, mothers against decapentaplegic homolog 3|SMA- and MAD-related protein 3|SMAD, mothers against DPP homolog 3|hMAD-3|hSMAD3|mad homolog JV15-2|mad protein homolog|mad3|mothers against DPP homolog 3', map_location='15q22.33', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67065602, end_position_on_the_genomic_accession=67195195, orientation='plus', exon_count=13, OMIM=[603109], no_hdr0=''),
    4089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4089, CurrentID=0, Status='live', Symbol='SMAD4', Aliases=['DPC4', 'JIP', 'MADH4', 'MYHRS'], description='SMAD family member 4', other_designations='mothers against decapentaplegic homolog 4|MAD homolog 4|SMAD, mothers against DPP homolog 4|deleted in pancreatic carcinoma locus 4|deletion target in pancreatic carcinoma 4|mothers against decapentaplegic, Drosophila, homolog of, 4', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=51030213, end_position_on_the_genomic_accession=51085042, orientation='plus', exon_count=12, OMIM=[600993], no_hdr0=''),
    4090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4090, CurrentID=0, Status='live', Symbol='SMAD5', Aliases=['DWFC', 'JV5-1', 'MADH5'], description='SMAD family member 5', other_designations='mothers against decapentaplegic homolog 5|MAD, mothers against decapentaplegic homolog 5|SMA- and MAD-related protein 5|SMAD, mothers against DPP homolog 5|mothers against decapentaplegic, drosophila, homolog of, 5', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=136132845, end_position_on_the_genomic_accession=136182733, orientation='plus', exon_count=10, OMIM=[603110], no_hdr0=''),
    4091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4091, CurrentID=0, Status='live', Symbol='SMAD6', Aliases=['AOVD2', 'HsT17432', 'MADH6', 'MADH7'], description='SMAD family member 6', other_designations='mothers against decapentaplegic homolog 6|MAD homolog 6|SMAD, mothers against DPP homolog 6|mothers against decapentaplegic, drosophila, homolog of, 6', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66702110, end_position_on_the_genomic_accession=66782849, orientation='plus', exon_count=7, OMIM=[602931], no_hdr0=''),
    4092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4092, CurrentID=0, Status='live', Symbol='SMAD7', Aliases=['CRCS3', 'MADH7', 'MADH8'], description='SMAD family member 7', other_designations='mothers against decapentaplegic homolog 7|MAD (mothers against decapentaplegic, Drosophila) homolog 7|MAD homolog 8|Mothers against decapentaplegic, drosophila, homolog of, 7|SMAD, mothers against DPP homolog 7|hSMAD7|mothers against DPP homolog 8', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=48919853, end_position_on_the_genomic_accession=48950965, orientation='minus', exon_count=5, OMIM=[602932], no_hdr0=''),
    4093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4093, CurrentID=0, Status='live', Symbol='SMAD9', Aliases=['MADH6', 'MADH9', 'PPH2', 'SMAD8', 'SMAD8/9', 'SMAD8A', 'SMAD8B'], description='SMAD family member 9', other_designations='mothers against decapentaplegic homolog 9|MAD homolog 9|Mothers against decapentaplegic, drosophila, homolog of, 9|SMAD, mothers against DPP homolog 9', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36844831, end_position_on_the_genomic_accession=36920721, orientation='minus', exon_count=10, OMIM=[603295], no_hdr0=''),
    4094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4094, CurrentID=0, Status='live', Symbol='MAF', Aliases=['AYGRP', 'CCA4', 'CTRCT21', 'c-MAF'], description='MAF bZIP transcription factor', other_designations='transcription factor Maf|Avian musculoaponeurotic fibrosarcoma (MAF) protooncogene|T lymphocyte c-maf long form|c-maf proto-oncogene|proto-oncogene c-Maf|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=79202624, end_position_on_the_genomic_accession=79601952, orientation='minus', exon_count=7, OMIM=[177075], no_hdr0=''),
    4097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4097, CurrentID=0, Status='live', Symbol='MAFG', Aliases=['hMAF'], description='MAF bZIP transcription factor G', other_designations='transcription factor MafG|basic leucine zipper transcription factor MafG|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog G', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81918270, end_position_on_the_genomic_accession=81927735, orientation='minus', exon_count=4, OMIM=[602020], no_hdr0=''),
    4099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4099, CurrentID=0, Status='live', Symbol='MAG', Aliases=['GMA', 'S-MAG', 'SIGLEC-4A', 'SIGLEC4A', 'SPG75'], description='myelin associated glycoprotein', other_designations='myelin-associated glycoprotein|sialic acid binding Ig-like lectin 4A|sialic acid-binding immunoglobulin-like lectin 4A', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35292161, end_position_on_the_genomic_accession=35313807, orientation='plus', exon_count=13, OMIM=[159460], no_hdr0=''),
    4100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4100, CurrentID=0, Status='live', Symbol='MAGEA1', Aliases=['CT1.1', 'MAGE1'], description='MAGE family member A1', other_designations='melanoma-associated antigen 1|MAGE-1 antigen|antigen MZ2-E|cancer/testis antigen 1.1|cancer/testis antigen family 1, member 1|melanoma antigen MAGE-1|melanoma antigen family A 1|melanoma antigen family A, 1 (directs expression of antigen MZ2-E)|melanoma antigen family A1|melanoma-associated antigen MZ2-E', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153179284, end_position_on_the_genomic_accession=153183880, orientation='plus', exon_count=3, OMIM=[300016], no_hdr0=''),
    4101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4101, CurrentID=0, Status='live', Symbol='MAGEA2', Aliases=['CT1.2', 'MAGE2A', 'MAGEA2'], description='MAGE family member A2', other_designations='melanoma-associated antigen 2|MAGE-2 antigen|cancer/testis antigen 1.2|cancer/testis antigen family 1, member 2|melanoma antigen 2|melanoma antigen family A, 2|melanoma antigen family A2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152749863, end_position_on_the_genomic_accession=152753884, orientation='minus', exon_count=7, OMIM=[300173], no_hdr0=''),
    4102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4102, CurrentID=0, Status='live', Symbol='MAGEA3', Aliases=['CT1.3', 'HIP8', 'HYPD', 'MAGE3', 'MAGEA6'], description='MAGE family member A3', other_designations='melanoma-associated antigen 3|MAGE-3 antigen|antigen MZ2-D|cancer/testis antigen 1.3|cancer/testis antigen family 1, member 3|melanoma antigen family A, 3|melanoma antigen family A3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152698742, end_position_on_the_genomic_accession=152702347, orientation='plus', exon_count=6, OMIM=[300174], no_hdr0=''),
    4103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4103, CurrentID=0, Status='live', Symbol='MAGEA4', Aliases=['CT1.4', 'MAGE-41', 'MAGE-X2', 'MAGE4', 'MAGE4A', 'MAGE4B'], description='MAGE family member A4', other_designations='melanoma-associated antigen 4|MAGE-4 antigen|MAGE-41 antigen|MAGE-X2 antigen|cancer/testis antigen 1.4|cancer/testis antigen family 1, member 4|melanoma antigen family A, 4|melanoma antigen family A4', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151912474, end_position_on_the_genomic_accession=151925170, orientation='plus', exon_count=11, OMIM=[300175], no_hdr0=''),
    4105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4105, CurrentID=0, Status='live', Symbol='MAGEA6', Aliases=['CT1.6', 'MAGE-3b', 'MAGE3B', 'MAGE6'], description='MAGE family member A6', other_designations='melanoma-associated antigen 6|MAGE-6 antigen|MAGE3B antigen|cancer/testis antigen 1.6|cancer/testis antigen family 1, member 6|melanoma antigen family A, 6|melanoma antigen family A6', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152766136, end_position_on_the_genomic_accession=152769689, orientation='minus', exon_count=3, OMIM=[300176], no_hdr0=''),
    4107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4107, CurrentID=0, Status='live', Symbol='MAGEA8', Aliases=['CT1.8', 'MAGE8'], description='MAGE family member A8', other_designations='melanoma-associated antigen 8|MAGE-8 antigen|cancer/testis antigen 1.8|cancer/testis antigen family 1, member 8|melanoma antigen family A, 8|melanoma antigen family A8', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149881183, end_position_on_the_genomic_accession=149885835, orientation='plus', exon_count=5, OMIM=[300341], no_hdr0=''),
    4108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4108, CurrentID=0, Status='live', Symbol='MAGEA9', Aliases=['CT1.9', 'MAGE9'], description='MAGE family member A9', other_designations='melanoma-associated antigen 9|MAGE-9 antigen|cancer/testis antigen 1.9|cancer/testis antigen family 1, member 9|melanoma antigen family A, 9|melanoma antigen family A9', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149781876, end_position_on_the_genomic_accession=149787737, orientation='plus', exon_count=5, OMIM=[300342], no_hdr0=''),
    4109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4109, CurrentID=0, Status='live', Symbol='MAGEA10', Aliases=['CT1.10', 'MAGE10'], description='MAGE family member A10', other_designations='melanoma-associated antigen 10|MAGE-10 antigen|cancer/testis antigen 1.10|cancer/testis antigen family 1, member 10|melanoma antigen family A, 10|melanoma antigen family A10', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152133310, end_position_on_the_genomic_accession=152138577, orientation='minus', exon_count=5, OMIM=[300343], no_hdr0=''),
    4110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4110, CurrentID=0, Status='live', Symbol='MAGEA11', Aliases=['CT1.11', 'MAGE-11', 'MAGE11', 'MAGEA-11'], description='MAGE family member A11', other_designations='melanoma-associated antigen 11|MAGE-11 antigen|cancer/testis antigen 1.11|cancer/testis antigen family 1, member 11|melanoma antigen family A, 11|melanoma antigen family A11', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149688193, end_position_on_the_genomic_accession=149717268, orientation='plus', exon_count=9, OMIM=[300344], no_hdr0=''),
    4111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4111, CurrentID=0, Status='live', Symbol='MAGEA12', Aliases=['CT1.12', 'MAGE12'], description='MAGE family member A12', other_designations='melanoma-associated antigen 12|MAGE12F antigen|cancer/testis antigen 1.12|cancer/testis antigen family 1, member 12|melanoma antigen family A, 12|melanoma antigen family A12', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152733757, end_position_on_the_genomic_accession=152737669, orientation='plus', exon_count=4, OMIM=[300177], no_hdr0=''),
    4112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4112, CurrentID=0, Status='live', Symbol='MAGEB1', Aliases=['CT3.1', 'DAM10', 'MAGE-Xp', 'MAGEL1'], description='MAGE family member B1', other_designations='melanoma-associated antigen B1|DSS/AHC critical interval MAGE superfamily 10|MAGE-B1 antigen|MAGE-XP antigen|cancer/testis antigen 3.1|cancer/testis antigen family 3, member 1|melanoma antigen family B, 1|melanoma antigen family B1', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30243731, end_position_on_the_genomic_accession=30252040, orientation='plus', exon_count=5, OMIM=[300097], no_hdr0=''),
    4113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4113, CurrentID=0, Status='live', Symbol='MAGEB2', Aliases=['CT3.2', 'DAM6', 'MAGE-XP-2'], description='MAGE family member B2', other_designations='melanoma-associated antigen B2|DSS/AHC critical interval MAGE superfamily 6|MAGE XP-2 antigen|MAGE-B2 antigen|cancer/testis antigen 3.2|cancer/testis antigen family 3, member 2|melanoma antigen family B, 2|melanoma antigen family B2', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30215563, end_position_on_the_genomic_accession=30220089, orientation='plus', exon_count=2, OMIM=[300098], no_hdr0=''),
    4114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4114, CurrentID=0, Status='live', Symbol='MAGEB3', Aliases=['CT3.5'], description='MAGE family member B3', other_designations='melanoma-associated antigen B3|MAGE-B3 antigen|cancer/testis antigen family 3, member 5|melanoma antigen family B, 3|melanoma antigen family B3', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30230657, end_position_on_the_genomic_accession=30237495, orientation='plus', exon_count=6, OMIM=[300152], no_hdr0=''),
    4115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4115, CurrentID=0, Status='live', Symbol='MAGEB4', Aliases=['CT3.6'], description='MAGE family member B4', other_designations='melanoma-associated antigen B4|MAGE-B4 antigen|cancer/testis antigen family 3, member 6|melanoma antigen family B, 4|melanoma antigen family B4', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30242000, end_position_on_the_genomic_accession=30244187, orientation='plus', exon_count=1, OMIM=[300153], no_hdr0=''),
    4116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4116, CurrentID=0, Status='live', Symbol='MAGOH', Aliases=['MAGOH1A', 'MAGOH'], description='mago homolog, exon junction complex subunit', other_designations='protein mago nashi homolog|mago homolog, exon junction complex core component|mago-nashi homolog, proliferation-associated', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53226900, end_position_on_the_genomic_accession=53238518, orientation='minus', exon_count=5, OMIM=[602603], no_hdr0=''),
    4117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4117, CurrentID=0, Status='live', Symbol='MAK', Aliases=['RP62'], description='male germ cell associated kinase', other_designations='serine/threonine-protein kinase MAK|serine/threonine protein kinase MAK|testicular secretory protein Li 28', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10762723, end_position_on_the_genomic_accession=10838954, orientation='minus', exon_count=20, OMIM=[154235], no_hdr0=''),
    4118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4118, CurrentID=0, Status='live', Symbol='MAL', Aliases=['MVP17', 'VIP17'], description='mal, T cell differentiation protein', other_designations='myelin and lymphocyte protein|T-lymphocyte maturation-associated protein', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95025708, end_position_on_the_genomic_accession=95053992, orientation='plus', exon_count=4, OMIM=[188860], no_hdr0=''),
    4121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4121, CurrentID=0, Status='live', Symbol='MAN1A1', Aliases=['HUMM3', 'HUMM9', 'MAN9'], description='mannosidase alpha class 1A member 1', other_designations='mannosyl-oligosaccharide 1,2-alpha-mannosidase IA|Man9-mannosidase|alpha-1,2-mannosidase IA|man(9)-alpha-mannosidase|processing alpha-1,2-mannosidase IA', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=119177204, end_position_on_the_genomic_accession=119350619, orientation='minus', exon_count=16, OMIM=[604344], no_hdr0=''),
    4122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4122, CurrentID=0, Status='live', Symbol='MAN2A2', Aliases=['MANA2X'], description='mannosidase alpha class 2A member 2', other_designations='alpha-mannosidase 2x|MAN IIx|alpha-mannosidase IIx|mannosidase, alpha type II-X|mannosyl-oligosaccharide 1,3-1,6-alpha-mannosidase|manosidase, alpha-, type II, isozyme X', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90902377, end_position_on_the_genomic_accession=90922585, orientation='plus', exon_count=27, OMIM=[600988], no_hdr0=''),
    4123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4123, CurrentID=0, Status='live', Symbol='MAN2C1', Aliases=['MAN6A8', 'MANA', 'MANA1'], description='mannosidase alpha class 2C member 1', other_designations='alpha-mannosidase 2C1|alpha mannosidase 6A8B|alpha-D-mannoside mannohydrolase|mannosidase, alpha 6A8|mannosidase, alpha A, cytoplasmic|testicular tissue protein Li 115', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75355792, end_position_on_the_genomic_accession=75368607, orientation='minus', exon_count=26, OMIM=[154580], no_hdr0=''),
    4124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4124, CurrentID=0, Status='live', Symbol='MAN2A1', Aliases=['AMan II', 'GOLIM7', 'MANA2', 'MANII'], description='mannosidase alpha class 2A member 1', other_designations='alpha-mannosidase 2|Golgi alpha-mannosidase II|golgi integral membrane protein 7|mannosidase, alpha type II|mannosyl-oligosaccharide 1,3-1,6-alpha-mannosidase', map_location='5q21.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=109689417, end_position_on_the_genomic_accession=109869625, orientation='plus', exon_count=25, OMIM=[154582], no_hdr0=''),
    4125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4125, CurrentID=0, Status='live', Symbol='MAN2B1', Aliases=['LAMAN', 'MANB'], description='mannosidase alpha class 2B member 1', other_designations='lysosomal alpha-mannosidase|lysosomal acid alpha-mannosidase|mannosidase alpha-B|mannosidase, alpha B, lysosomal', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12646511, end_position_on_the_genomic_accession=12666742, orientation='minus', exon_count=24, OMIM=[609458], no_hdr0=''),
    4126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4126, CurrentID=0, Status='live', Symbol='MANBA', Aliases=['MANB1'], description='mannosidase beta', other_designations='beta-mannosidase|beta-mannosidase A|lysosomal beta A mannosidase|mannanase|mannase|mannosidase, beta A, lysosomal', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102630770, end_position_on_the_genomic_accession=102760968, orientation='minus', exon_count=21, OMIM=[609489], no_hdr0=''),
    4128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4128, CurrentID=0, Status='live', Symbol='MAOA', Aliases=['BRNRS', 'MAO-A'], description='monoamine oxidase A', other_designations='amine oxidase [flavin-containing] A|monoamine oxidase type A', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=43655006, end_position_on_the_genomic_accession=43746817, orientation='plus', exon_count=16, OMIM=[309850], no_hdr0=''),
    4129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4129, CurrentID=0, Status='live', Symbol='MAOB', Aliases=[], description='monoamine oxidase B', other_designations='amine oxidase [flavin-containing] B|MAO, brain|MAO, platelet|MAO-B|adrenalin oxidase|monoamine oxidase type B|tyramine oxidase', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=43766610, end_position_on_the_genomic_accession=43882450, orientation='minus', exon_count=18, OMIM=[309860], no_hdr0=''),
    4130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4130, CurrentID=0, Status='live', Symbol='MAP1A', Aliases=['MAP1L', 'MTAP1A'], description='microtubule associated protein 1A', other_designations='microtubule-associated protein 1A|MAP-1A|proliferation-related protein p80', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43517608, end_position_on_the_genomic_accession=43531611, orientation='plus', exon_count=6, OMIM=[600178], no_hdr0=''),
    4131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4131, CurrentID=0, Status='live', Symbol='MAP1B', Aliases=['FUTSCH', 'MAP5', 'PPP1R102', 'PVNH9'], description='microtubule associated protein 1B', other_designations='microtubule-associated protein 1B|protein phosphatase 1, regulatory subunit 102', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72107475, end_position_on_the_genomic_accession=72209565, orientation='plus', exon_count=8, OMIM=[157129], no_hdr0=''),
    4133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4133, CurrentID=0, Status='live', Symbol='MAP2', Aliases=['MAP-2A', 'MAP2B', 'MAP2C', 'MAP2'], description='microtubule associated protein 2', other_designations='microtubule-associated protein 2', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=209424047, end_position_on_the_genomic_accession=209734118, orientation='plus', exon_count=25, OMIM=[157130], no_hdr0=''),
    4134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4134, CurrentID=0, Status='live', Symbol='MAP4', Aliases=[], description='microtubule associated protein 4', other_designations='microtubule-associated protein 4|MAP-4', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47850695, end_position_on_the_genomic_accession=48089272, orientation='minus', exon_count=29, OMIM=[157132], no_hdr0=''),
    4135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4135, CurrentID=0, Status='live', Symbol='MAP6', Aliases=['MAP6-N', 'MTAP6', 'N-STOP', 'STOP'], description='microtubule associated protein 6', other_designations='microtubule-associated protein 6|CTD-2530H12.7|MAP-6|stable tubule-only polypeptide', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75586914, end_position_on_the_genomic_accession=75669038, orientation='minus', exon_count=10, OMIM=[601783], no_hdr0=''),
    4137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4137, CurrentID=0, Status='live', Symbol='MAPT', Aliases=['DDPAC', 'FTDP-17L', 'MSTD', 'MTBT1', 'MTBT2', 'PPND', 'PPP1R103', 'TAU', 'tau-40', 'MAPT'], description='microtubule associated protein tau', other_designations='microtubule-associated protein tau|G protein beta1/gamma2 subunit-interacting factor 1|PHF-tau|neurofibrillary tangle protein|paired helical filament-tau|protein phosphatase 1, regulatory subunit 103', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45894538, end_position_on_the_genomic_accession=46028334, orientation='plus', exon_count=16, OMIM=[157140], no_hdr0=''),
    4139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4139, CurrentID=0, Status='live', Symbol='MARK1', Aliases=['MARK', 'Par-1c', 'Par1c'], description='microtubule affinity regulating kinase 1', other_designations='serine/threonine-protein kinase MARK1|MAP/microtubule affinity-regulating kinase 1|PAR1 homolog c', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220528136, end_position_on_the_genomic_accession=220664461, orientation='plus', exon_count=22, OMIM=[606511], no_hdr0=''),
    4140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4140, CurrentID=0, Status='live', Symbol='MARK3', Aliases=['CTAK1', 'KP78', 'PAR1A', 'Par-1a', 'VIPB'], description='microtubule affinity regulating kinase 3', other_designations='MAP/microtubule affinity-regulating kinase 3|C-TAK1|ELKL motif kinase 2|EMK-2|cdc25C-associated protein kinase 1|protein kinase STK10|ser/Thr protein kinase PAR-1|serine/threonine-protein kinase p78', map_location='14q32.32-q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103385394, end_position_on_the_genomic_accession=103503831, orientation='plus', exon_count=20, OMIM=[602678], no_hdr0=''),
    4141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4141, CurrentID=0, Status='live', Symbol='MARS1', Aliases=['CMT2U', 'ILFS2', 'ILLD', 'MARS', 'METRS', 'MRS', 'MTRNS', 'SPG70'], description='methionyl-tRNA synthetase 1', other_designations='methionine--tRNA ligase, cytoplasmic|cytosolic methionyl-tRNA synthetase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57488068, end_position_on_the_genomic_accession=57516655, orientation='plus', exon_count=20, OMIM=[156560], no_hdr0=''),
    4142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4142, CurrentID=0, Status='live', Symbol='MAS1', Aliases=['MAS', 'MGRA'], description='MAS1 proto-oncogene, G protein-coupled receptor', other_designations='proto-oncogene Mas|MAS1 oncogene|Mas-related G protein-coupled receptor A', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159890988, end_position_on_the_genomic_accession=159917447, orientation='plus', exon_count=3, OMIM=[165180], no_hdr0=''),
    4143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4143, CurrentID=0, Status='live', Symbol='MAT1A', Aliases=['MAT', 'MATA1', 'SAMS', 'SAMS1'], description='methionine adenosyltransferase 1A', other_designations='S-adenosylmethionine synthase isoform type-1|MAT 1|MAT-I/III|adoMet synthase 1|adoMet synthetase 1|methionine adenosyltransferase 1|methionine adenosyltransferase I, alpha|methionine adenosyltransferase I/III', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80271820, end_position_on_the_genomic_accession=80289658, orientation='minus', exon_count=9, OMIM=[610550], no_hdr0=''),
    4144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4144, CurrentID=0, Status='live', Symbol='MAT2A', Aliases=['MATA2', 'MATII', 'SAMS2'], description='methionine adenosyltransferase 2A', other_designations='S-adenosylmethionine synthase isoform type-2|MAT 2|MAT-II|adoMet synthase 2|adoMet synthetase 2|methionine adenosyltransferase 2|methionine adenosyltransferase II, alpha|testicular tissue protein Li 121', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85539168, end_position_on_the_genomic_accession=85545281, orientation='plus', exon_count=9, OMIM=[601468], no_hdr0=''),
    4145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4145, CurrentID=0, Status='live', Symbol='MATK', Aliases=['CHK', 'CTK', 'HHYLTK', 'HYL', 'HYLTK', 'Lsk'], description='megakaryocyte-associated tyrosine kinase', other_designations='megakaryocyte-associated tyrosine-protein kinase|CSK homologous kinase|Csk-homologous kinase|Csk-type protein tyrosine kinase|HYL tyrosine kinase|hematopoietic consensus tyrosine-lacking kinase|hydroxyaryl-protein kinase|leukocyte carboxyl-terminal src kinase related|protein kinase HYL|tyrosine kinase MATK|tyrosine-protein kinase CTK|tyrosylprotein kinase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3777973, end_position_on_the_genomic_accession=3801799, orientation='minus', exon_count=17, OMIM=[600038], no_hdr0=''),
    4146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4146, CurrentID=0, Status='live', Symbol='MATN1', Aliases=['CMP', 'CRTM'], description='matrilin 1', other_designations='cartilage matrix protein|matrilin 1, cartilage matrix protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=30711277, end_position_on_the_genomic_accession=30723585, orientation='minus', exon_count=8, OMIM=[115437], no_hdr0=''),
    4147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4147, CurrentID=0, Status='live', Symbol='MATN2', Aliases=[], description='matrilin 2', other_designations='matrilin-2|testis tissue sperm-binding protein Li 94mP', map_location='8q22.1-q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=97869064, end_position_on_the_genomic_accession=98036724, orientation='plus', exon_count=19, OMIM=[602108], no_hdr0=''),
    4148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4148, CurrentID=0, Status='live', Symbol='MATN3', Aliases=['DIPOA', 'EDM5', 'HOA', 'OADIP', 'OS2', 'SEMDBCD'], description='matrilin 3', other_designations='matrilin-3', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=19992052, end_position_on_the_genomic_accession=20012668, orientation='minus', exon_count=8, OMIM=[602109], no_hdr0=''),
    4149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4149, CurrentID=0, Status='live', Symbol='MAX', Aliases=['bHLHd4'], description='MYC associated factor X', other_designations='protein max|class D basic helix-loop-helix protein 4', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=65006101, end_position_on_the_genomic_accession=65102695, orientation='minus', exon_count=10, OMIM=[154950], no_hdr0=''),
    4150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4150, CurrentID=0, Status='live', Symbol='MAZ', Aliases=['PUR1', 'Pur-1', 'SAF-1', 'SAF-2', 'SAF-3', 'ZF87', 'ZNF801', 'Zif87'], description='MYC associated zinc finger protein', other_designations='myc-associated zinc finger protein|MAZI|purine-binding transcription factor|serum amyloid A activating factor 1|serum amyloid A activating factor 2|transcription factor Zif87|zinc finger protein 801|zinc-finger protein, 87 kilodaltons', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29806081, end_position_on_the_genomic_accession=29811171, orientation='plus', exon_count=7, OMIM=[600999], no_hdr0=''),
    4151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4151, CurrentID=0, Status='live', Symbol='MB', Aliases=['PVALB'], description='myoglobin', other_designations='myoglobin', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35606764, end_position_on_the_genomic_accession=35623354, orientation='minus', exon_count=8, OMIM=[160000], no_hdr0=''),
    4152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4152, CurrentID=0, Status='live', Symbol='MBD1', Aliases=['CXXC3', 'PCM1', 'RFT'], description='methyl-CpG binding domain protein 1', other_designations='methyl-CpG-binding domain protein 1|CXXC-type zinc finger protein 3|protein containing methyl-CpG-binding domain 1|the regulator of fibroblast growth factor 2 (FGF-2) transcription', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50266882, end_position_on_the_genomic_accession=50281767, orientation='minus', exon_count=20, OMIM=[156535], no_hdr0=''),
    4153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4153, CurrentID=0, Status='live', Symbol='MBL2', Aliases=['COLEC1', 'HSMBPC', 'MBLD', 'MBP', 'MBP-C', 'MBP1', 'MBPD', 'MBL2'], description='mannose binding lectin 2', other_designations='mannose-binding protein C|collectin-1|mannan-binding lectin|mannose-binding lectin (protein C) 2, soluble (opsonic defect)|mannose-binding lectin 2, soluble (opsonic defect)', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=52765380, end_position_on_the_genomic_accession=52772784, orientation='minus', exon_count=5, OMIM=[154545], no_hdr0=''),
    4154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4154, CurrentID=0, Status='live', Symbol='MBNL1', Aliases=['EXP', 'MBNL'], description='muscleblind like splicing regulator 1', other_designations='muscleblind-like protein 1|muscleblind-like|triplet-expansion RNA-binding protein', map_location='3q25.1-q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=152243632, end_position_on_the_genomic_accession=152465780, orientation='plus', exon_count=21, OMIM=[606516], no_hdr0=''),
    4155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4155, CurrentID=0, Status='live', Symbol='MBP', Aliases=[], description='myelin basic protein', other_designations='myelin basic protein|Golli-MBP|proline-rich proteoglycan 2|myelin A1 protein|myelin membrane encephalitogenic protein', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=76978833, end_position_on_the_genomic_accession=77133708, orientation='minus', exon_count=17, OMIM=[159430], no_hdr0=''),
    4157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4157, CurrentID=0, Status='live', Symbol='MC1R', Aliases=['CMM5', 'MSH-R', 'SHEP2'], description='melanocortin 1 receptor', other_designations='melanocyte-stimulating hormone receptor|MC1-R|alpha melanocyte stimulating hormone receptor|melanotropin receptor', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89918862, end_position_on_the_genomic_accession=89920972, orientation='plus', exon_count=1, OMIM=[155555], no_hdr0=''),
    4158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4158, CurrentID=0, Status='live', Symbol='MC2R', Aliases=['ACTHR'], description='melanocortin 2 receptor', other_designations='adrenocorticotropic hormone receptor|ACTH receptor|MC2 receptor|adrenocorticotropin receptor|corticotropin receptor|melanocortin 2 receptor (adrenocorticotropic hormone)', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=13882042, end_position_on_the_genomic_accession=13915707, orientation='minus', exon_count=4, OMIM=[607397], no_hdr0=''),
    4159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4159, CurrentID=0, Status='live', Symbol='MC3R', Aliases=['BMIQ9', 'MC3', 'MC3-R', 'OB20', 'OQTL'], description='melanocortin 3 receptor', other_designations='melanocortin receptor 3|obesity quantitative trait locus', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56248732, end_position_on_the_genomic_accession=56249815, orientation='plus', exon_count=1, OMIM=[155540], no_hdr0=''),
    4160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4160, CurrentID=0, Status='live', Symbol='MC4R', Aliases=['BMIQ20'], description='melanocortin 4 receptor', other_designations='melanocortin receptor 4|MC4-R', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=60371062, end_position_on_the_genomic_accession=60372775, orientation='minus', exon_count=1, OMIM=[155541], no_hdr0=''),
    4161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4161, CurrentID=0, Status='live', Symbol='MC5R', Aliases=['MC2'], description='melanocortin 5 receptor', other_designations='melanocortin receptor 5', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=13824149, end_position_on_the_genomic_accession=13827323, orientation='plus', exon_count=2, OMIM=[600042], no_hdr0=''),
    4162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4162, CurrentID=0, Status='live', Symbol='MCAM', Aliases=['CD146', 'HEMCAM', 'METCAM', 'MUC18', 'MelCAM'], description='melanoma cell adhesion molecule', other_designations='cell surface glycoprotein MUC18|Gicerin|S-endo 1 endothelial-associated antigen|cell surface glycoprotein P1H12|melanoma adhesion molecule|melanoma-associated antigen A32|melanoma-associated antigen MUC18', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119305759, end_position_on_the_genomic_accession=119317130, orientation='minus', exon_count=16, OMIM=[155735], no_hdr0=''),
    4163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4163, CurrentID=0, Status='live', Symbol='MCC', Aliases=['MCC1'], description='MCC regulator of WNT signaling pathway', other_designations='colorectal mutant cancer protein|MCC, WNT signaling pathway regulator|mutated in colorectal cancers', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=113022106, end_position_on_the_genomic_accession=113488453, orientation='minus', exon_count=20, OMIM=[159350], no_hdr0=''),
    4166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4166, CurrentID=0, Status='live', Symbol='CHST6', Aliases=['C-GlcNAc6ST', 'GST4-beta', 'MCDC1', 'glcNAc6ST-5', 'gn6st-5', 'hCGn6ST'], description='carbohydrate sulfotransferase 6', other_designations='carbohydrate sulfotransferase 6|N-acetylglucosamine 6-O-sulfotransferase 5|N-acetylglucosamine 6-sulfotransferase|carbohydrate (N-acetylglucosamine 6-O) sulfotransferase 6|corneal N-acetylglucosamine 6-sulfotransferase|corneal N-acetylglucosamine-6-O-sulfotransferase|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 4-beta', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75472042, end_position_on_the_genomic_accession=75495441, orientation='minus', exon_count=6, OMIM=[605294], no_hdr0=''),
    4168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4168, CurrentID=0, Status='live', Symbol='MCF2', Aliases=['ARHGEF21', 'DBL'], description='MCF.2 cell line derived transforming sequence', other_designations='proto-oncogene DBL|Oncogene MCF2 (oncogene DBL)|proto-oncogene MCF-2', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=139581768, end_position_on_the_genomic_accession=139708279, orientation='minus', exon_count=33, OMIM=[311030], no_hdr0=''),
    4170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4170, CurrentID=0, Status='live', Symbol='MCL1', Aliases=['BCL2L3', 'EAT-ES', 'MCL1L', 'MCL1S', 'Mcl-1', 'TM', 'bcl2-L-3', 'mcl1/EAT', 'MCL1'], description='MCL1 apoptosis regulator, BCL2 family member', other_designations='induced myeloid leukemia cell differentiation protein Mcl-1|BCL2 family apoptosis regulator|MCL1, BCL2 family apoptosis regulator|bcl-2-like protein 3|bcl-2-related protein EAT/mcl1|myeloid cell leukemia 1|myeloid cell leukemia ES|myeloid cell leukemia sequence 1 (BCL2-related)', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150574558, end_position_on_the_genomic_accession=150579610, orientation='minus', exon_count=4, OMIM=[159552], no_hdr0=''),
    4171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4171, CurrentID=0, Status='live', Symbol='MCM2', Aliases=['BM28', 'CCNL1', 'CDCL1', 'D3S3194', 'DFNA70', 'MITOTIN', 'cdc19'], description='minichromosome maintenance complex component 2', other_designations='DNA replication licensing factor MCM2|cell devision cycle-like 1|cyclin-like 1|minichromosome maintenance deficient 2 (mitotin)|minichromosome maintenance protein 2 homolog|nuclear protein BM28', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127598411, end_position_on_the_genomic_accession=127622436, orientation='plus', exon_count=17, OMIM=[116945], no_hdr0=''),
    4172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4172, CurrentID=0, Status='live', Symbol='MCM3', Aliases=['HCC5', 'P1-MCM3', 'P1.h', 'RLFB'], description='minichromosome maintenance complex component 3', other_designations='DNA replication licensing factor MCM3|DNA polymerase alpha holoenzyme-associated protein P1|DNA replication factor MCM3|MCM3 minichromosome maintenance deficient 3|RLF subunit beta|cervical cancer proto-oncogene 5|hRlf beta subunit|minichromosome maintenance deficient 3|p102|replication licensing factor, beta subunit', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52264015, end_position_on_the_genomic_accession=52284742, orientation='minus', exon_count=20, OMIM=[602693], no_hdr0=''),
    4173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4173, CurrentID=0, Status='live', Symbol='MCM4', Aliases=['CDC21', 'CDC54', 'IMD54', 'NKCD', 'NKGCD', 'P1-CDC21', 'hCdc21'], description='minichromosome maintenance complex component 4', other_designations='DNA replication licensing factor MCM4|homolog of S. pombe cell devision cycle 21|minichromosome maintenance deficient 4', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47960941, end_position_on_the_genomic_accession=47978160, orientation='plus', exon_count=16, OMIM=[602638], no_hdr0=''),
    4174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4174, CurrentID=0, Status='live', Symbol='MCM5', Aliases=['CDC46', 'MGORS8', 'P1-CDC46'], description='minichromosome maintenance complex component 5', other_designations='DNA replication licensing factor MCM5|CDC46 homolog|MCM5 minichromosome maintenance deficient 5, cell division cycle 46|minichromosome maintenance deficient 5 (cell division cycle 46)', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35400133, end_position_on_the_genomic_accession=35454942, orientation='plus', exon_count=19, OMIM=[602696], no_hdr0=''),
    4175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4175, CurrentID=0, Status='live', Symbol='MCM6', Aliases=['MCG40308', 'Mis5', 'P105MCM'], description='minichromosome maintenance complex component 6', other_designations='DNA replication licensing factor MCM6|MCM6 minichromosome maintenance deficient 6 (MIS5 homolog, S. pombe)|minichromosome maintenance deficient (mis5, S. pombe) 6', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135839626, end_position_on_the_genomic_accession=135876443, orientation='minus', exon_count=17, OMIM=[601806], no_hdr0=''),
    4176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4176, CurrentID=0, Status='live', Symbol='MCM7', Aliases=['CDC47', 'MCM2', 'P1.1-MCM3', 'P1CDC47', 'P85MCM', 'PNAS146', 'PPP1R104'], description='minichromosome maintenance complex component 7', other_designations='DNA replication licensing factor MCM7|CDC47 homolog|homolog of S. cerevisiae Cdc47|minichromosome maintenance deficient 7|protein phosphatase 1, regulatory subunit 104', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100092728, end_position_on_the_genomic_accession=100101397, orientation='minus', exon_count=16, OMIM=[600592], no_hdr0=''),
    4179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4179, CurrentID=0, Status='live', Symbol='CD46', Aliases=['AHUS2', 'MCP', 'MIC10', 'TLX', 'TRA2.10'], description='CD46 molecule', other_designations='membrane cofactor protein|CD46 antigen, complement regulatory protein|CD46 molecule, complement regulatory protein|antigen identified by monoclonal antibody TRA-2-10|complement membrane cofactor protein|measles virus receptor|membrane cofactor protein (CD46, trophoblast-lymphocyte cross-reactive antigen)|trophoblast leucocyte common antigen|trophoblast leukocyte common antigen|trophoblast-lymphocyte cross-reactive antigen', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207752038, end_position_on_the_genomic_accession=207795516, orientation='plus', exon_count=14, OMIM=[120920], no_hdr0=''),
    4184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4184, CurrentID=0, Status='live', Symbol='SMCP', Aliases=['HSMCSGEN1', 'MCS', 'MCSP'], description='sperm mitochondria associated cysteine rich protein', other_designations='sperm mitochondrial-associated cysteine-rich protein|testicular tissue protein Li 119|testicular tissue protein Li 161', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152878322, end_position_on_the_genomic_accession=152885047, orientation='plus', exon_count=2, OMIM=[601148], no_hdr0=''),
    4185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4185, CurrentID=0, Status='live', Symbol='ADAM11', Aliases=['MDC'], description='ADAM metallopeptidase domain 11', other_designations='disintegrin and metalloproteinase domain-containing protein 11|ADAM 11|metalloproteinase-like, disintegrin-like, and cysteine-rich protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44758988, end_position_on_the_genomic_accession=44781846, orientation='plus', exon_count=27, OMIM=[155120], no_hdr0=''),
    4188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4188, CurrentID=0, Status='live', Symbol='MDFI', Aliases=['I-MF', 'I-mfa'], description='MyoD family inhibitor', other_designations='myoD family inhibitor|inhibitor of MyoD family a|myogenic repressor I-mf', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41637018, end_position_on_the_genomic_accession=41654246, orientation='plus', exon_count=8, OMIM=[604971], no_hdr0=''),
    4189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4189, CurrentID=0, Status='live', Symbol='DNAJB9', Aliases=['ERdj4', 'MDG-1', 'MDG1', 'MST049', 'MSTP049'], description='DnaJ heat shock protein family (Hsp40) member B9', other_designations='dnaJ homolog subfamily B member 9|DnaJ (Hsp40) homolog, subfamily B, member 9|ER-resident protein ERdj4|endoplasmic reticulum DNA J domain-containing protein 4|endoplasmic reticulum DnaJ homolog 4|microvascular endothelial differentiation gene 1 protein', map_location='14q24.2-q24.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=108569874, end_position_on_the_genomic_accession=108574850, orientation='plus', exon_count=3, OMIM=[602634], no_hdr0=''),
    4190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4190, CurrentID=0, Status='live', Symbol='MDH1', Aliases=['DEE88', 'EIEE88', 'HEL-S-32', 'KAR', 'MDH-s', 'MDHA', 'MGC:1375', 'MOR2'], description='malate dehydrogenase 1', other_designations='malate dehydrogenase, cytoplasmic|malate dehydrogenase, peroxisomal|cytosolic malate dehydrogenase|diiodophenylpyruvate reductase|epididymis secretory protein Li 32|malate dehydrogenase 1, NAD (soluble)|soluble malate dehydrogenase', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=63588963, end_position_on_the_genomic_accession=63607197, orientation='plus', exon_count=10, OMIM=[154200], no_hdr0=''),
    4191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4191, CurrentID=0, Status='live', Symbol='MDH2', Aliases=['DEE51', 'EIEE51', 'M-MDH', 'MDH', 'MGC:3559', 'MOR1'], description='malate dehydrogenase 2', other_designations='malate dehydrogenase, mitochondrial|malate dehydrogenase 2, NAD (mitochondrial)|testicular tissue protein Li 120', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76048106, end_position_on_the_genomic_accession=76067508, orientation='plus', exon_count=10, OMIM=[154100], no_hdr0=''),
    4192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4192, CurrentID=0, Status='live', Symbol='MDK', Aliases=['ARAP', 'MK', 'NEGF2'], description='midkine', other_designations='midkine|amphiregulin-associated protein|midgestation and kidney protein|neurite growth-promoting factor 2|neurite outgrowth-promoting factor 2|retinoic acid inducible factor', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46380784, end_position_on_the_genomic_accession=46383837, orientation='plus', exon_count=6, OMIM=[162096], no_hdr0=''),
    4193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4193, CurrentID=0, Status='live', Symbol='MDM2', Aliases=['ACTFS', 'HDMX', 'LSKB', 'hdm2'], description='MDM2 proto-oncogene', other_designations='E3 ubiquitin-protein ligase Mdm2|MDM2 oncogene, E3 ubiquitin protein ligase|MDM2 proto-oncogene, E3 ubiquitin protein ligase|Mdm2, p53 E3 ubiquitin protein ligase homolog|Mdm2, transformed 3T3 cell double minute 2, p53 binding protein|double minute 2, human homolog of; p53-binding protein|oncoprotein Mdm2', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68808149, end_position_on_the_genomic_accession=68850686, orientation='plus', exon_count=13, OMIM=[164785], no_hdr0=''),
    4194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4194, CurrentID=0, Status='live', Symbol='MDM4', Aliases=['BMFS6', 'HDMX', 'MDMX', 'MRP1'], description='MDM4 regulator of p53', other_designations='protein Mdm4|MDM4 protein variant G|MDM4 protein variant Y|MDM4, p53 regulator|MDM4-related protein 1|Mdm4 p53 binding protein homolog|double minute 4, human homolog of; p53-binding protein|mdm2-like p53-binding protein|protein Mdmx', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204516377, end_position_on_the_genomic_accession=204558120, orientation='plus', exon_count=13, OMIM=[602704], no_hdr0=''),
    4199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4199, CurrentID=0, Status='live', Symbol='ME1', Aliases=['HUMNDME', 'MES'], description='malic enzyme 1', other_designations='NADP-dependent malic enzyme|Malic enzyme, cytoplasmic|NADP-ME|malate dehydrogenase (oxaloacetate-decarboxylating) (NADP(+))|malic enzyme 1, NADP(+)-dependent, cytosolic|malic enzyme 1, soluble|pyruvic-malic carboxylase', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83210402, end_position_on_the_genomic_accession=83431078, orientation='minus', exon_count=14, OMIM=[154250], no_hdr0=''),
    4200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4200, CurrentID=0, Status='live', Symbol='ME2', Aliases=['ODS1'], description='malic enzyme 2', other_designations='NAD-dependent malic enzyme, mitochondrial|NAD-ME|malate dehydrogenase (oxaloacetate-decarboxylating)|malic enzyme 2, NAD(+)-dependent, mitochondrial|pyruvic-malic carboxylase', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50878702, end_position_on_the_genomic_accession=50954257, orientation='plus', exon_count=16, OMIM=[154270], no_hdr0=''),
    4201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4201, CurrentID=0, Status='live', Symbol='MEA1', Aliases=['HYS', 'MEA'], description='male-enhanced antigen 1', other_designations='male-enhanced antigen 1|Male-enhanced antigen (H-Y structural gene)', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42980344, end_position_on_the_genomic_accession=43017086, orientation='minus', exon_count=7, OMIM=[143170], no_hdr0=''),
    4204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4204, CurrentID=0, Status='live', Symbol='MECP2', Aliases=['AUTSX3', 'MRX16', 'MRX79', 'MRXS13', 'MRXSL', 'PPMX', 'RS', 'RTS', 'RTT'], description='methyl-CpG binding protein 2', other_designations='methyl-CpG-binding protein 2|meCp-2 protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154021573, end_position_on_the_genomic_accession=154097717, orientation='minus', exon_count=11, OMIM=[300005], no_hdr0=''),
    4205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4205, CurrentID=0, Status='live', Symbol='MEF2A', Aliases=['ADCAD1', 'RSRFC4', 'RSRFC9', 'mef2'], description='myocyte enhancer factor 2A', other_designations='myocyte-specific enhancer factor 2A|MADS box transcription enhancer factor 2, polypeptide A (myocyte enhancer factor 2A)|serum response factor-like protein 1', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99565417, end_position_on_the_genomic_accession=99716488, orientation='plus', exon_count=23, OMIM=[600660], no_hdr0=''),
    4207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4207, CurrentID=0, Status='live', Symbol='BORCS8-MEF2B', Aliases=['LOC729991-MEF2B', 'MEF2B', 'MEF2BNB-MEF2B', 'RSRFR2'], description='BORCS8-MEF2B readthrough', other_designations='myocyte-specific enhancer factor 2B|LOC729991-MEF2B readthrough|MEF2BNB-MEF2B readthrough|myocyte enhancer factor 2B|serum response factor-like protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19145567, end_position_on_the_genomic_accession=19192152, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    4208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4208, CurrentID=0, Status='live', Symbol='MEF2C', Aliases=['C5DELq14.3', 'DEL5q14.3'], description='myocyte enhancer factor 2C', other_designations='myocyte-specific enhancer factor 2C|MADS box transcription enhancer factor 2, polypeptide C', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=88717117, end_position_on_the_genomic_accession=88904105, orientation='minus', exon_count=21, OMIM=[600662], no_hdr0=''),
    4209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4209, CurrentID=0, Status='live', Symbol='MEF2D', Aliases=[], description='myocyte enhancer factor 2D', other_designations='myocyte-specific enhancer factor 2D|MADS box transcription enhancer factor 2, polypeptide D', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156463727, end_position_on_the_genomic_accession=156500840, orientation='minus', exon_count=17, OMIM=[600663], no_hdr0=''),
    4210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4210, CurrentID=0, Status='live', Symbol='MEFV', Aliases=['FMF', 'MEF', 'PAAND', 'TRIM20'], description='MEFV innate immuity regulator, pyrin', other_designations='pyrin|MEFV, pyrin innate immunity regulator|Mediterranean fever|marenostrin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3242027, end_position_on_the_genomic_accession=3256776, orientation='minus', exon_count=10, OMIM=[608107], no_hdr0=''),
    4211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4211, CurrentID=0, Status='live', Symbol='MEIS1', Aliases=[], description='Meis homeobox 1', other_designations='homeobox protein Meis1|Meis1, myeloid ecotropic viral integration site 1 homolog|WUGSC:H_NH0444B04.1|leukemogenic homolog protein', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=66435125, end_position_on_the_genomic_accession=66573869, orientation='plus', exon_count=13, OMIM=[601739], no_hdr0=''),
    4212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4212, CurrentID=0, Status='live', Symbol='MEIS2', Aliases=['CPCMR', 'HsT18361', 'MRG1'], description='Meis homeobox 2', other_designations='homeobox protein Meis2|Meis homolog 2|Meis1, myeloid ecotropic viral integration site 1 homolog 2|Meis1-related gene 1|TALE homeobox protein Meis2|meis1-related protein 1', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=36889204, end_position_on_the_genomic_accession=37101311, orientation='minus', exon_count=16, OMIM=[601740], no_hdr0=''),
    4214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4214, CurrentID=0, Status='live', Symbol='MAP3K1', Aliases=['MAPKKK1', 'MEKK', 'MEKK 1', 'MEKK1', 'SRXY6'], description='mitogen-activated protein kinase kinase kinase 1', other_designations='mitogen-activated protein kinase kinase kinase 1|MAP/ERK kinase kinase 1|MAPK/ERK kinase kinase 1|MEK kinase 1|mitogen-activated protein kinase kinase kinase 1, E3 ubiquitin protein ligase', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=56815543, end_position_on_the_genomic_accession=56896152, orientation='plus', exon_count=22, OMIM=[600982], no_hdr0=''),
    4215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4215, CurrentID=0, Status='live', Symbol='MAP3K3', Aliases=['MAPKKK3', 'MEKK3'], description='mitogen-activated protein kinase kinase kinase 3', other_designations='mitogen-activated protein kinase kinase kinase 3|MAP/ERK kinase kinase 3|MAPK/ERK kinase kinase 3|MEK kinase 3|MEKK 3', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63622209, end_position_on_the_genomic_accession=63696305, orientation='plus', exon_count=17, OMIM=[602539], no_hdr0=''),
    4216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4216, CurrentID=0, Status='live', Symbol='MAP3K4', Aliases=['MAPKKK4', 'MEKK 4', 'MEKK4', 'MTK1', 'PRO0412'], description='mitogen-activated protein kinase kinase kinase 4', other_designations='mitogen-activated protein kinase kinase kinase 4|MAP three kinase 1|MAP/ERK kinase kinase 4|MAPK/ERK kinase kinase 4|MEK kinase 4|SSK2/SSK22 MAP kinase kinase kinase, yeast, homolog of|dJ473J16.1 (mitogen-activated protein kinase kinase kinase 4)|predicted protein of HQ0412', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160991521, end_position_on_the_genomic_accession=161117385, orientation='plus', exon_count=30, OMIM=[602425], no_hdr0=''),
    4217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4217, CurrentID=0, Status='live', Symbol='MAP3K5', Aliases=['ASK1', 'MAPKKK5', 'MEKK5'], description='mitogen-activated protein kinase kinase kinase 5', other_designations='mitogen-activated protein kinase kinase kinase 5|ASK-1|MAP/ERK kinase kinase 5|MAPK/ERK kinase kinase 5|MEK kinase 5|MEKK 5|apoptosis signal-regulating kinase 1', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136557046, end_position_on_the_genomic_accession=136793098, orientation='minus', exon_count=32, OMIM=[602448], no_hdr0=''),
    4218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4218, CurrentID=0, Status='live', Symbol='RAB8A', Aliases=['MEL', 'RAB8'], description='RAB8A, member RAS oncogene family', other_designations='ras-related protein Rab-8A|mel transforming oncogene (RAB8 homolog)|mel transforming oncogene (derived from cell line NK14)|mel transforming oncogene (derived from cell line NK14)- RAB8 homolog|oncogene c-mel|ras-associated protein RAB8', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16111889, end_position_on_the_genomic_accession=16134234, orientation='plus', exon_count=8, OMIM=[165040], no_hdr0=''),
    4221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4221, CurrentID=0, Status='live', Symbol='MEN1', Aliases=['MEAI', 'SCG2'], description='menin 1', other_designations='menin', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64803514, end_position_on_the_genomic_accession=64811294, orientation='minus', exon_count=14, OMIM=[613733], no_hdr0=''),
    4222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4222, CurrentID=0, Status='live', Symbol='MEOX1', Aliases=['KFS2', 'MOX1'], description='mesenchyme homeobox 1', other_designations='homeobox protein MOX-1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43640389, end_position_on_the_genomic_accession=43661977, orientation='minus', exon_count=4, OMIM=[600147], no_hdr0=''),
    4223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4223, CurrentID=0, Status='live', Symbol='MEOX2', Aliases=['GAX', 'MOX2'], description='mesenchyme homeobox 2', other_designations='homeobox protein MOX-2|growth arrest-specific homeobox', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=15611212, end_position_on_the_genomic_accession=15686683, orientation='minus', exon_count=3, OMIM=[600535], no_hdr0=''),
    4224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4224, CurrentID=0, Status='live', Symbol='MEP1A', Aliases=['PPHA'], description='meprin A subunit alpha', other_designations='meprin A subunit alpha|N-benzoyl-L-tyrosyl-P-amino-benzoic acid hydrolase subunit alpha|PABA peptide hydrolase|PPH alpha|bA268F1.1 (meprin A alpha (PABA peptide hydrolase))|endopeptidase-2|meprin A, alpha (PABA peptide hydrolase)', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46793384, end_position_on_the_genomic_accession=46845987, orientation='plus', exon_count=15, OMIM=[600388], no_hdr0=''),
    4225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4225, CurrentID=0, Status='live', Symbol='MEP1B', Aliases=[], description='meprin A subunit beta', other_designations='meprin A subunit beta|N-benzoyl-L-tyrosyl-P-amino-benzoic acid hydrolase subunit beta|N-benzoyl-L-tyrosyl-p-amino-benzoic acid hydrolase beta subunit|PABA peptide hydrolase|PPH beta|endopeptidase-2|meprin A, beta|meprin B', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32190039, end_position_on_the_genomic_accession=32222607, orientation='plus', exon_count=15, OMIM=[600389], no_hdr0=''),
    4232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4232, CurrentID=0, Status='live', Symbol='MEST', Aliases=['PEG1'], description='mesoderm specific transcript', other_designations='mesoderm-specific transcript homolog protein|paternally-expressed gene 1 protein', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130486175, end_position_on_the_genomic_accession=130506465, orientation='plus', exon_count=15, OMIM=[601029], no_hdr0=''),
    4233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4233, CurrentID=0, Status='live', Symbol='MET', Aliases=['AUTS9', 'DFNB97', 'HGFR', 'RCCP2', 'c-Met'], description='MET proto-oncogene, receptor tyrosine kinase', other_designations='hepatocyte growth factor receptor|HGF receptor|HGF/SF receptor|SF receptor|proto-oncogene c-Met|scatter factor receptor|tyrosine-protein kinase Met', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116672196, end_position_on_the_genomic_accession=116798386, orientation='plus', exon_count=24, OMIM=[164860], no_hdr0=''),
    4234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4234, CurrentID=0, Status='live', Symbol='METTL1', Aliases=['C12orf1', 'TRM8', 'TRMT8', 'YDL201w'], description='methyltransferase 1, tRNA methylguanosine', other_designations='tRNA (guanine-N(7)-)-methyltransferase|D1075-like gene product|mRNA (guanine-N(7)-)-methyltransferase|methyltransferase like 1|methyltransferase-like protein 1|miRNA (guanine-N(7)-)-methyltransferase|tRNA (guanine(46)-N(7))-methyltransferase|tRNA(m7G46)-methyltransferase', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57768471, end_position_on_the_genomic_accession=57772105, orientation='minus', exon_count=7, OMIM=[604466], no_hdr0=''),
    4236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4236, CurrentID=0, Status='live', Symbol='MFAP1', Aliases=['AMP'], description='microfibril associated protein 1', other_designations='microfibrillar-associated protein 1|microfibrillar associated protein 1|spliceosome B complex protein MFAP1', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43804492, end_position_on_the_genomic_accession=43824690, orientation='minus', exon_count=9, OMIM=[600215], no_hdr0=''),
    4237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4237, CurrentID=0, Status='live', Symbol='MFAP2', Aliases=['MAGP', 'MAGP-1', 'MAGP1'], description='microfibril associated protein 2', other_designations='microfibrillar-associated protein 2|microfibril-associated glycoprotein 1|microfibrillar associated protein 2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16974502, end_position_on_the_genomic_accession=16981583, orientation='minus', exon_count=10, OMIM=[156790], no_hdr0=''),
    4238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4238, CurrentID=0, Status='live', Symbol='MFAP3', Aliases=[], description='microfibril associated protein 3', other_designations='microfibril-associated glycoprotein 3|microfibrillar associated protein 3', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154038967, end_position_on_the_genomic_accession=154057450, orientation='plus', exon_count=3, OMIM=[600491], no_hdr0=''),
    4239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4239, CurrentID=0, Status='live', Symbol='MFAP4', Aliases=[], description='microfibril associated protein 4', other_designations='microfibril-associated glycoprotein 4|microfibrillar associated protein 4', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19383445, end_position_on_the_genomic_accession=19387190, orientation='minus', exon_count=6, OMIM=[600596], no_hdr0=''),
    4240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4240, CurrentID=0, Status='live', Symbol='MFGE8', Aliases=['BA46', 'EDIL1', 'HMFG', 'HsT19888', 'MFG-E8', 'MFGM', 'OAcGD3S', 'SED1', 'SPAG10', 'hP47'], description='milk fat globule EGF and factor V/VIII domain containing', other_designations='lactadherin|O-acetyl disialoganglioside synthase|breast epithelial antigen BA46|medin|milk fat globule-EGF factor 8 protein|sperm associated antigen 10|sperm surface protein hP47', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88898683, end_position_on_the_genomic_accession=88913405, orientation='minus', exon_count=12, OMIM=[602281], no_hdr0=''),
    4241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4241, CurrentID=0, Status='live', Symbol='MELTF', Aliases=['CD228', 'MAP97', 'MFI2', 'MTF1', 'MTf'], description='melanotransferrin', other_designations='melanotransferrin|antigen p97 (melanoma associated) identified by monoclonal antibodies 133.2 and 96.5|membrane-bound transferrin-like protein', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197001740, end_position_on_the_genomic_accession=197029817, orientation='minus', exon_count=18, OMIM=[155750], no_hdr0=''),
    4242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4242, CurrentID=0, Status='live', Symbol='MFNG', Aliases=[], description='MFNG O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase', other_designations='beta-1,3-N-acetylglucosaminyltransferase manic fringe|O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37469063, end_position_on_the_genomic_accession=37486384, orientation='minus', exon_count=8, OMIM=[602577], no_hdr0=''),
    4245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4245, CurrentID=0, Status='live', Symbol='MGAT1', Aliases=['GLCNAC-TI', 'GLCT1', 'GLYT1', 'GNT-1', 'GNT-I', 'GnTI', 'MGAT'], description='alpha-1,3-mannosyl-glycoprotein 2-beta-N-acetylglucosaminyltransferase', other_designations='alpha-1,3-mannosyl-glycoprotein 2-beta-N-acetylglucosaminyltransferase|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase I|glcNAc-T I|mannosyl (alpha-1,3-)-glycoprotein beta-1,2-N-acetylglucosaminyltransferase', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180784780, end_position_on_the_genomic_accession=180815616, orientation='minus', exon_count=11, OMIM=[160995], no_hdr0=''),
    4246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4246, CurrentID=0, Status='live', Symbol='SCGB2A1', Aliases=['LPHC', 'LPNC', 'MGB2', 'UGB3'], description='secretoglobin family 2A member 1', other_designations='mammaglobin-B|lacryglobin|lipophilin C|mammaglobin-2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62208673, end_position_on_the_genomic_accession=62213943, orientation='plus', exon_count=3, OMIM=[604398], no_hdr0=''),
    4247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4247, CurrentID=0, Status='live', Symbol='MGAT2', Aliases=['CDG2A', 'CDGS2', 'GLCNACTII', 'GNT-II', 'GNT2'], description='alpha-1,6-mannosyl-glycoprotein 2-beta-N-acetylglucosaminyltransferase', other_designations='alpha-1,6-mannosyl-glycoprotein 2-beta-N-acetylglucosaminyltransferase|Beta-1,2-N-acetylglucosaminyltransferase II|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase II|UDP-N-acetylglucosamine:alpha-6-D-mannoside beta-1,2-N-acetylglucosaminyltransferase II|glcNAc-T II|mannoside acetylglucosaminyltransferase 2|mannosyl (alpha-1,6-)-glycoprotein beta-1,2-N-acetylglucosaminyltransferase', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49620799, end_position_on_the_genomic_accession=49623481, orientation='plus', exon_count=1, OMIM=[602616], no_hdr0=''),
    4248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4248, CurrentID=0, Status='live', Symbol='MGAT3', Aliases=['GNT-III', 'GNT3'], description='beta-1,4-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase', other_designations='beta-1,4-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase|GlcNAc-T III|N-acetylglucosaminyltransferase III|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase III|mannosyl (beta-1,4-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39457012, end_position_on_the_genomic_accession=39492194, orientation='plus', exon_count=2, OMIM=[604621], no_hdr0=''),
    4249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4249, CurrentID=0, Status='live', Symbol='MGAT5', Aliases=['GNT-V', 'GNT-VAA', 'glcNAc-T V', 'MGAT5'], description='alpha-1,6-mannosylglycoprotein 6-beta-N-acetylglucosaminyltransferase', other_designations='alpha-1,6-mannosylglycoprotein 6-beta-N-acetylglucosaminyltransferase A|N-acetylglucosaminyl-transferase V|alpha-mannoside beta-1,6-N-acetylglucosaminyltransferase V|mannoside acetylglucosaminyltransferase 5|mannosyl (alpha-1,6-)-glycoprotein beta-1,6-N-acetyl-glucosaminyltransferase', map_location='2q21.2-q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=134119922, end_position_on_the_genomic_accession=134454621, orientation='plus', exon_count=24, OMIM=[601774], no_hdr0=''),
    4250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4250, CurrentID=0, Status='live', Symbol='SCGB2A2', Aliases=['MGB1', 'PSBP1', 'UGB2'], description='secretoglobin family 2A member 2', other_designations='mammaglobin-A|mammaglobin 1|prostatic steroid binding protein 1', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62270130, end_position_on_the_genomic_accession=62273160, orientation='plus', exon_count=3, OMIM=[605562], no_hdr0=''),
    4253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4253, CurrentID=0, Status='live', Symbol='MIA2', Aliases=['CTAGE5', 'MEA6', 'MGEA', 'MGEA11', 'MGEA6', 'TALI'], description='MIA SH3 domain ER export factor 2', other_designations='melanoma inhibitory activity protein 2|CTAGE family member 5, ER export factor|CTAGE family, member 5|MIA protein 2|TANGO1-like|cutaneous T-cell lymphoma-associated antigen 5|melanoma inhibitory activity 2|meningioma expressed antigen 6 (coiled-coil proline-rich)|meningioma-expressed antigen 6/11|protein cTAGE-5', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39233915, end_position_on_the_genomic_accession=39388522, orientation='plus', exon_count=39, OMIM=[602132], no_hdr0=''),
    4254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4254, CurrentID=0, Status='live', Symbol='KITLG', Aliases=['DCUA', 'DFNA69', 'FPH2', 'FPHH', 'KL-1', 'Kitl', 'MGF', 'SCF', 'SF', 'SHEP7', 'SLF'], description='KIT ligand', other_designations='kit ligand|c-Kit ligand|familial progressive hyperpigmentation 2|mast cell growth factor|steel factor|stem cell factor', map_location='12q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=88492793, end_position_on_the_genomic_accession=88580471, orientation='minus', exon_count=10, OMIM=[184745], no_hdr0=''),
    4255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4255, CurrentID=0, Status='live', Symbol='MGMT', Aliases=[], description='O-6-methylguanine-DNA methyltransferase', other_designations='methylated-DNA--protein-cysteine methyltransferase|6-O-methylguanine-DNA methyltransferase|O-6-methylguanine-DNA-alkyltransferase|O6-methylguanine-DNA methyltransferase|methylguanine-DNA methyltransferase', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=129467241, end_position_on_the_genomic_accession=129770983, orientation='plus', exon_count=6, OMIM=[156569], no_hdr0=''),
    4256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4256, CurrentID=0, Status='live', Symbol='MGP', Aliases=['GIG36', 'MGLAP', 'NTI'], description='matrix Gla protein', other_designations='matrix Gla protein|cell growth-inhibiting gene 36 protein', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14880864, end_position_on_the_genomic_accession=14885854, orientation='minus', exon_count=5, OMIM=[154870], no_hdr0=''),
    4257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4257, CurrentID=0, Status='live', Symbol='MGST1', Aliases=['GST12', 'MGST', 'MGST-I'], description='microsomal glutathione S-transferase 1', other_designations='microsomal glutathione S-transferase 1|glutathione S-transferase 12|microsomal GST-1|microsomal GST-I', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=16347115, end_position_on_the_genomic_accession=16377192, orientation='plus', exon_count=11, OMIM=[138330], no_hdr0=''),
    4258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4258, CurrentID=0, Status='live', Symbol='MGST2', Aliases=['GST2', 'MGST-II'], description='microsomal glutathione S-transferase 2', other_designations='microsomal glutathione S-transferase 2|glutathione peroxidase MGST2|leukotriene C4 synthase MGST2|microsomal GST-2|microsomal GST-II|microsomal glutathione S-transferase II', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139665725, end_position_on_the_genomic_accession=139754608, orientation='plus', exon_count=10, OMIM=[601733], no_hdr0=''),
    4259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4259, CurrentID=0, Status='live', Symbol='MGST3', Aliases=['GST-III'], description='microsomal glutathione S-transferase 3', other_designations='microsomal glutathione S-transferase 3|LTC4 synthase MGST3|glutathione peroxidase MGST3|microsomal GST-3|microsomal GST-III|microsomal glutathione S-transferase III', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165631234, end_position_on_the_genomic_accession=165656136, orientation='plus', exon_count=7, OMIM=[604564], no_hdr0=''),
    4261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4261, CurrentID=0, Status='live', Symbol='CIITA', Aliases=['C2TAIV', 'MHC2TA', 'NLRA', 'CIITA'], description='class II major histocompatibility complex transactivator', other_designations='MHC class II transactivator|MHC class II transactivator type I|MHC class II transactivator type III|NLR family, acid domain containing|nucleotide-binding oligomerization domain, leucine rich repeat and acid domain containing', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10866208, end_position_on_the_genomic_accession=10941562, orientation='plus', exon_count=27, OMIM=[600005], no_hdr0=''),
    4267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4267, CurrentID=0, Status='live', Symbol='CD99', Aliases=['HBA71', 'MIC2', 'MIC2X', 'MIC2Y', 'MSK5X'], description='CD99 molecule (Xg blood group)', other_designations='CD99 antigen|E2 antigen|MIC2 (monoclonal antibody 12E7)|T-cell surface glycoprotein E2|antigen identified by monoclonal 12E7, Y homolog|antigen identified by monoclonal antibodies 12E7, F21 and O13|cell surface antigen 12E7|cell surface antigen HBA-71|cell surface antigen O13|surface antigen MIC2', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2691295, end_position_on_the_genomic_accession=2741309, orientation='plus', exon_count=11, OMIM=[313470, 450000], no_hdr0=''),
    4277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4277, CurrentID=0, Status='live', Symbol='MICB', Aliases=['PERB11.2'], description='MHC class I polypeptide-related sequence B', other_designations='MHC class I polypeptide-related sequence B|MHC class I antigen-related protein B|MHC class I chain-related protein B|MHC class I mic-B antigen|MHC class I-like molecule PERB11.2-IMX|stress inducible class I homolog', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31494918, end_position_on_the_genomic_accession=31511124, orientation='plus', exon_count=7, OMIM=[602436], no_hdr0=''),
    4281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4281, CurrentID=0, Status='live', Symbol='MID1', Aliases=['BBBG1', 'FXY', 'GBBB1', 'MIDIN', 'OGS1', 'OS', 'OSX', 'RNF59', 'TRIM18', 'XPRF', 'ZNFXY'], description='midline 1', other_designations='E3 ubiquitin-protein ligase Midline-1|Opitz/BBB syndrome|RING finger protein 59|RING finger protein Midline-1|RING-type E3 ubiquitin transferase Midline-1|midline 1 RING finger protein|putative transcription factor XPRF|tripartite motif protein TRIM18|tripartite motif-containing protein 18|zinc finger on X and Y, mouse, homolog of', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=10445310, end_position_on_the_genomic_accession=10833683, orientation='minus', exon_count=15, OMIM=[300552], no_hdr0=''),
    4282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4282, CurrentID=0, Status='live', Symbol='MIF', Aliases=['GIF', 'GLIF', 'MMIF'], description='macrophage migration inhibitory factor', other_designations='macrophage migration inhibitory factor|L-dopachrome isomerase|L-dopachrome tautomerase|epididymis secretory sperm binding protein|macrophage migration inhibitory factor (glycosylation-inhibiting factor)|phenylpyruvate tautomerase', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23894383, end_position_on_the_genomic_accession=23895223, orientation='plus', exon_count=3, OMIM=[153620], no_hdr0=''),
    4283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4283, CurrentID=0, Status='live', Symbol='CXCL9', Aliases=['CMK', 'Humig', 'MIG', 'SCYB9', 'crg-10'], description='C-X-C motif chemokine ligand 9', other_designations='C-X-C motif chemokine 9|chemokine (C-X-C motif) ligand 9|gamma-interferon-induced monokine|monokine induced by gamma interferon|monokine induced by interferon-gamma|small-inducible cytokine B9', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76001275, end_position_on_the_genomic_accession=76007509, orientation='minus', exon_count=4, OMIM=[601704], no_hdr0=''),
    4284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4284, CurrentID=0, Status='live', Symbol='MIP', Aliases=['AQP0', 'CTRCT15', 'LIM126', 'MP26', 'MIP'], description='major intrinsic protein of lens fiber', other_designations='lens fiber major intrinsic protein|aquaporin 0', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56449502, end_position_on_the_genomic_accession=56456553, orientation='minus', exon_count=8, OMIM=[154050], no_hdr0=''),
    4285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4285, CurrentID=0, Status='live', Symbol='MIPEP', Aliases=['COXPD31', 'HMIP', 'MIP'], description='mitochondrial intermediate peptidase', other_designations='mitochondrial intermediate peptidase', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23730189, end_position_on_the_genomic_accession=23889448, orientation='minus', exon_count=21, OMIM=[602241], no_hdr0=''),
    4286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4286, CurrentID=0, Status='live', Symbol='MITF', Aliases=['CMM8', 'COMMAD', 'MI', 'WS2', 'WS2A', 'bHLHe32'], description='melanocyte inducing transcription factor', other_designations='microphthalmia-associated transcription factor|class E basic helix-loop-helix protein 32|melanogenesis associated transcription factor|microphtalmia-associated transcription factor', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69739464, end_position_on_the_genomic_accession=69968332, orientation='plus', exon_count=17, OMIM=[156845], no_hdr0=''),
    4287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4287, CurrentID=0, Status='live', Symbol='ATXN3', Aliases=['AT3', 'ATX3', 'JOS', 'MJD', 'MJD1', 'SCA3'], description='ataxin 3', other_designations='ataxin-3|Machado-Joseph disease protein 1|josephin|olivopontocerebellar ataxia 3|spinocerebellar ataxia type 3 protein', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92058552, end_position_on_the_genomic_accession=92106582, orientation='minus', exon_count=13, OMIM=[607047], no_hdr0=''),
    4288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4288, CurrentID=0, Status='live', Symbol='MKI67', Aliases=['KIA', 'MIB-', 'MIB-1', 'PPP1R105'], description='marker of proliferation Ki-67', other_designations='proliferation marker protein Ki-67|Molecular Immunology Borstel antibody 1|antigen Ki67|antigen identified by monoclonal antibody Ki-67|proliferation-related Ki-67 antigen|protein phosphatase 1, regulatory subunit 105', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=128096659, end_position_on_the_genomic_accession=128126423, orientation='minus', exon_count=16, OMIM=[176741], no_hdr0=''),
    4289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4289, CurrentID=0, Status='live', Symbol='MKLN1', Aliases=['TWA2'], description='muskelin 1', other_designations='muskelin|muskelin 1, intracellular mediator containing kelch motifs', map_location='7q32.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=131110094, end_position_on_the_genomic_accession=131496637, orientation='plus', exon_count=22, OMIM=[605623], no_hdr0=''),
    4291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4291, CurrentID=0, Status='live', Symbol='MLF1', Aliases=[], description='myeloid leukemia factor 1', other_designations='myeloid leukemia factor 1|myelodysplasia-myeloid leukemia factor 1|testis tissue sperm-binding protein Li 49e', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158571194, end_position_on_the_genomic_accession=158606456, orientation='plus', exon_count=11, OMIM=[601402], no_hdr0=''),
    4292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4292, CurrentID=0, Status='live', Symbol='MLH1', Aliases=['COCA2', 'FCC2', 'HNPCC', 'HNPCC2', 'MMRCS1', 'hMLH1'], description='mutL homolog 1', other_designations='DNA mismatch repair protein Mlh1|mutL homolog 1, colon cancer, nonpolyposis type 2', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=36993487, end_position_on_the_genomic_accession=37050846, orientation='plus', exon_count=21, OMIM=[120436], no_hdr0=''),
    4293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4293, CurrentID=0, Status='live', Symbol='MAP3K9', Aliases=['MEKK9', 'MLK1', 'PRKE1'], description='mitogen-activated protein kinase kinase kinase 9', other_designations='mitogen-activated protein kinase kinase kinase 9|mixed lineage kinase 1 (tyr and ser/thr specificity)', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70722526, end_position_on_the_genomic_accession=70809513, orientation='minus', exon_count=16, OMIM=[600136], no_hdr0=''),
    4294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4294, CurrentID=0, Status='live', Symbol='MAP3K10', Aliases=['MEKK10', 'MLK2', 'MST'], description='mitogen-activated protein kinase kinase kinase 10', other_designations='mitogen-activated protein kinase kinase kinase 10|MKN28 derived nonreceptor_type serine/threonine kinase|MKN28 kinase|mixed lineage kinase 2|protein kinase MST', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40191426, end_position_on_the_genomic_accession=40215575, orientation='plus', exon_count=12, OMIM=[600137], no_hdr0=''),
    4295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4295, CurrentID=0, Status='live', Symbol='MLN', Aliases=[], description='motilin', other_designations='promotilin|prepromotilin', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33794673, end_position_on_the_genomic_accession=33804003, orientation='minus', exon_count=5, OMIM=[158270], no_hdr0=''),
    4296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4296, CurrentID=0, Status='live', Symbol='MAP3K11', Aliases=['MEKK11', 'MLK-3', 'MLK3', 'PTK1', 'SPRK'], description='mitogen-activated protein kinase kinase kinase 11', other_designations='mitogen-activated protein kinase kinase kinase 11|SH3 domain-containing proline-rich kinase|mixed lineage kinase 3|protein-tyrosine kinase PTK1|src-homology 3 domain-containing proline-rich kinase', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65597755, end_position_on_the_genomic_accession=65614221, orientation='minus', exon_count=11, OMIM=[600050], no_hdr0=''),
    4297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4297, CurrentID=0, Status='live', Symbol='KMT2A', Aliases=['ALL-1', 'CXXC7', 'HRX', 'HTRX1', 'MLL', 'MLL1', 'MLL1A', 'TRX1', 'WDSTS'], description='lysine methyltransferase 2A', other_designations='histone-lysine N-methyltransferase 2A|CXXC-type zinc finger protein 7|lysine (K)-specific methyltransferase 2A|lysine N-methyltransferase 2A|mixed lineage leukemia 1|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila)|trithorax-like protein|zinc finger protein HRX', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118436492, end_position_on_the_genomic_accession=118526832, orientation='plus', exon_count=37, OMIM=[159555], no_hdr0=''),
    4298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4298, CurrentID=0, Status='live', Symbol='MLLT1', Aliases=['ENL', 'LTG19', 'YEATS1'], description='MLLT1 super elongation complex subunit', other_designations='protein ENL|CTC-503J8.6|ENL/MLL fusion|MLL/ENL fusion protein|MLLT1/MLL fusion|YEATS domain-containing protein 1|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog); translocated to, 1|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 1|myeloid/lymphoid or mixed-lineage leukemia; translocated to, 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6210381, end_position_on_the_genomic_accession=6279975, orientation='minus', exon_count=15, OMIM=[159556], no_hdr0=''),
    4299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4299, CurrentID=0, Status='live', Symbol='AFF1', Aliases=['AF4', 'MLLT2', 'PBM1'], description='AF4/FMR2 family member 1', other_designations='AF4/FMR2 family member 1|ALL1-fused gene from chromosome 4 protein|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 2|pre-B-cell monocytic leukemia partner 1|proto-oncogene AF4', map_location='4q21.3-q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=86934606, end_position_on_the_genomic_accession=87141039, orientation='plus', exon_count=25, OMIM=[159557], no_hdr0=''),
    4300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4300, CurrentID=0, Status='live', Symbol='MLLT3', Aliases=['AF9', 'YEATS3'], description='MLLT3 super elongation complex subunit', other_designations='protein AF-9|ALL1-fused gene from chromosome 9 protein|KMT2A/MLLT3 fusion protein|YEATS domain-containing protein 3|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog); translocated to, 3|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 3|myeloid/lymphoid or mixed-lineage leukemia translocated to chromosome 3 protein|myeloid/lymphoid or mixed-lineage leukemia; translocated to 3', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=20341669, end_position_on_the_genomic_accession=20622499, orientation='minus', exon_count=12, OMIM=[159558], no_hdr0=''),
    4301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4301, CurrentID=0, Status='live', Symbol='AFDN', Aliases=['AF6', 'MLL-AF6', 'MLLT4', 'l-afadin'], description='afadin, adherens junction formation factor', other_designations='afadin|ALL1-fused gene from chromosome 6 protein|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 4|myeloid/lymphoid or mixed-lineage leukemia; translocated to, 4|protein AF-6', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167826564, end_position_on_the_genomic_accession=167972023, orientation='plus', exon_count=36, OMIM=[159559], no_hdr0=''),
    4302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4302, CurrentID=0, Status='live', Symbol='MLLT6', Aliases=['AF17'], description='MLLT6, PHD finger containing', other_designations='protein AF-17|ALL1-fused gene from chromosome 17 protein|MLLT6, PHD finger domain containing|Myeloid/lymphoid or mixed-lineage leukemia, translocated to, 6|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog); translocated to, 6|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 6|myeloid/lymphoid or mixed-lineage leukemia; translocated to, 6|trithorax homolog', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38705273, end_position_on_the_genomic_accession=38729795, orientation='plus', exon_count=20, OMIM=[600328], no_hdr0=''),
    4303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4303, CurrentID=0, Status='live', Symbol='FOXO4', Aliases=['AFX', 'AFX1', 'MLLT7'], description='forkhead box O4', other_designations='forkhead box protein O4|fork head domain transcription factor AFX1|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 7', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71095851, end_position_on_the_genomic_accession=71103534, orientation='plus', exon_count=4, OMIM=[300033], no_hdr0=''),
    4306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4306, CurrentID=0, Status='live', Symbol='NR3C2', Aliases=['MCR', 'MLR', 'MRVIT', 'NR3C2'], description='nuclear receptor subfamily 3 group C member 2', other_designations='mineralocorticoid receptor|aldosterone receptor|mineralocorticoid receptor 1|mineralocorticoid receptor 2|mineralocorticoid receptor delta|nuclear receptor subfamily 3, group C, member 2 variant 3', map_location='4q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=148078764, end_position_on_the_genomic_accession=148444698, orientation='minus', exon_count=11, OMIM=[600983], no_hdr0=''),
    4308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4308, CurrentID=0, Status='live', Symbol='TRPM1', Aliases=['CSNB1C', 'LTRPC1', 'MLSN1'], description='transient receptor potential cation channel subfamily M member 1', other_designations='transient receptor potential cation channel subfamily M member 1|long transient receptor potential channel 1|melastatin-1|transient receptor potential melastatin family', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=31001065, end_position_on_the_genomic_accession=31161160, orientation='minus', exon_count=29, OMIM=[603576], no_hdr0=''),
    4311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4311, CurrentID=0, Status='live', Symbol='MME', Aliases=['CALLA', 'CD10', 'CMT2T', 'NEP', 'SCA43', 'SFE'], description='membrane metalloendopeptidase', other_designations='neprilysin|atriopeptidase|common acute lymphocytic leukemia antigen|membrane metallo-endopeptidase (neutral endopeptidase, enkephalinase, CALLA, CD10)|membrane metallo-endopeptidase variant 1|membrane metallo-endopeptidase variant 2|neprilysin-390|neprilysin-411|neutral endopeptidase 24.11|skin fibroblast elastase', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155024202, end_position_on_the_genomic_accession=155183729, orientation='plus', exon_count=30, OMIM=[120520], no_hdr0=''),
    4312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4312, CurrentID=0, Status='live', Symbol='MMP1', Aliases=['CLG', 'CLGN'], description='matrix metallopeptidase 1', other_designations='interstitial collagenase|fibroblast collagenase|matrix metallopeptidase 1 (interstitial collagenase)|matrix metalloprotease 1', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102789919, end_position_on_the_genomic_accession=102798160, orientation='minus', exon_count=10, OMIM=[120353], no_hdr0=''),
    4313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4313, CurrentID=0, Status='live', Symbol='MMP2', Aliases=['CLG4', 'CLG4A', 'MMP-2', 'MMP-II', 'MONA', 'TBE-1'], description='matrix metallopeptidase 2', other_designations='72 kDa type IV collagenase|collagenase type IV-A|matrix metallopeptidase 2 (gelatinase A, 72kDa gelatinase, 72kDa type IV collagenase)|matrix metalloproteinase-2|matrix metalloproteinase-II|neutrophil gelatinase', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55478830, end_position_on_the_genomic_accession=55506691, orientation='plus', exon_count=17, OMIM=[120360], no_hdr0=''),
    4314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4314, CurrentID=0, Status='live', Symbol='MMP3', Aliases=['CHDS6', 'MMP-3', 'SL-1', 'STMY', 'STMY1', 'STR1'], description='matrix metallopeptidase 3', other_designations='stromelysin-1|matrix metalloproteinase 3 (stromelysin 1, progelatinase)|proteoglycanase|transin-1', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102835801, end_position_on_the_genomic_accession=102843609, orientation='minus', exon_count=10, OMIM=[185250], no_hdr0=''),
    4316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4316, CurrentID=0, Status='live', Symbol='MMP7', Aliases=['MMP-7', 'MPSL1', 'PUMP-1'], description='matrix metallopeptidase 7', other_designations='matrilysin|matrin|matrix metallopeptidase 7 (matrilysin, uterine)|matrix metalloproteinase 7 (matrilysin, uterine)|matrix metalloproteinase-7|pump-1 protease|uterine matrilysin|uterine metalloproteinase', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102520508, end_position_on_the_genomic_accession=102530747, orientation='minus', exon_count=6, OMIM=[178990], no_hdr0=''),
    4317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4317, CurrentID=0, Status='live', Symbol='MMP8', Aliases=['CLG1', 'HNC', 'MMP-8', 'PMNL-CL'], description='matrix metallopeptidase 8', other_designations='neutrophil collagenase|PMN leukocyte collagenase|PMNL collagenase|collagenase 2|matrix metalloproteinase 8 (neutrophil collagenase)|matrix metalloproteinase-8', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102711796, end_position_on_the_genomic_accession=102724967, orientation='minus', exon_count=12, OMIM=[120355], no_hdr0=''),
    4318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4318, CurrentID=0, Status='live', Symbol='MMP9', Aliases=['CLG4B', 'GELB', 'MANDP2', 'MMP-9'], description='matrix metallopeptidase 9', other_designations='matrix metalloproteinase-9|macrophage gelatinase|matrix metallopeptidase 9 (gelatinase B, 92kDa gelatinase, 92kDa type IV collagenase)|matrix metalloproteinase 9 (gelatinase B, 92kDa gelatinase, 92kDa type IV collagenase)|type V collagenase', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46008908, end_position_on_the_genomic_accession=46016561, orientation='plus', exon_count=13, OMIM=[120361], no_hdr0=''),
    4319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4319, CurrentID=0, Status='live', Symbol='MMP10', Aliases=['SL-2', 'STMY2'], description='matrix metallopeptidase 10', other_designations='stromelysin-2|MMP-10|matrix metalloprotease 10|matrix metalloproteinase 10 (stromelysin 2)|matrix metalloproteinase-10|transin 2', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102770502, end_position_on_the_genomic_accession=102780628, orientation='minus', exon_count=10, OMIM=[185260], no_hdr0=''),
    4320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4320, CurrentID=0, Status='live', Symbol='MMP11', Aliases=['SL-3', 'ST3', 'STMY3'], description='matrix metallopeptidase 11', other_designations='stromelysin-3|matrix metallopeptidase 11 (stromelysin 3)|stromelysin III', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23772849, end_position_on_the_genomic_accession=23784316, orientation='plus', exon_count=8, OMIM=[185261], no_hdr0=''),
    4321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4321, CurrentID=0, Status='live', Symbol='MMP12', Aliases=['HME', 'ME', 'MME', 'MMP-12'], description='matrix metallopeptidase 12', other_designations='macrophage metalloelastase|matrix metallopeptidase 12 (macrophage elastase)|matrix metalloproteinase 12 (macrophage elastase)', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102862736, end_position_on_the_genomic_accession=102874982, orientation='minus', exon_count=10, OMIM=[601046], no_hdr0=''),
    4322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4322, CurrentID=0, Status='live', Symbol='MMP13', Aliases=['CLG3', 'MANDP1', 'MDST', 'MMP-13'], description='matrix metallopeptidase 13', other_designations='collagenase 3|matrix metalloproteinase 13 (collagenase 3)', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102942995, end_position_on_the_genomic_accession=102955732, orientation='minus', exon_count=10, OMIM=[600108], no_hdr0=''),
    4323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4323, CurrentID=0, Status='live', Symbol='MMP14', Aliases=['MMP-14', 'MMP-X1', 'MT-MMP', 'MT-MMP 1', 'MT1-MMP', 'MT1MMP', 'MTMMP1', 'WNCHRS'], description='matrix metallopeptidase 14', other_designations='matrix metalloproteinase-14|matrix metallopeptidase 14 (membrane-inserted)|membrane type 1 metalloprotease|membrane-type-1 matrix metalloproteinase', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22836585, end_position_on_the_genomic_accession=22847758, orientation='plus', exon_count=10, OMIM=[600754], no_hdr0=''),
    4324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4324, CurrentID=0, Status='live', Symbol='MMP15', Aliases=['MMP-15', 'MT2-MMP', 'MT2MMP', 'MTMMP2', 'SMCP-2'], description='matrix metallopeptidase 15', other_designations='matrix metalloproteinase-15|MT-MMP 2|matrix metallopeptidase 15 (membrane-inserted)|matrix metalloproteinase 15 (membrane-inserted)|membrane-type matrix metalloproteinase 2|membrane-type-2 matrix metalloproteinase', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58025754, end_position_on_the_genomic_accession=58046901, orientation='plus', exon_count=10, OMIM=[602261], no_hdr0=''),
    4325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4325, CurrentID=0, Status='live', Symbol='MMP16', Aliases=['C8orf57', 'MMP-X2', 'MT-MMP2', 'MT-MMP3', 'MT3-MMP'], description='matrix metallopeptidase 16', other_designations='matrix metalloproteinase-16|MMP-16|MT-MMP 3|MT3MMP|MTMMP3|Putative transmembrane protein C8orf57|matrix metallopeptidase 16 (membrane-inserted)|membrane-type matrix metalloproteinase 3|membrane-type-3 matrix metalloproteinase', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=88032009, end_position_on_the_genomic_accession=88327483, orientation='minus', exon_count=11, OMIM=[602262], no_hdr0=''),
    4326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4326, CurrentID=0, Status='live', Symbol='MMP17', Aliases=['MMP-17', 'MT4-MMP', 'MT4MMP', 'MTMMP4'], description='matrix metallopeptidase 17', other_designations='matrix metalloproteinase-17|MT-MMP 4|matrix metallopeptidase 17 (membrane-inserted)|matrix metalloproteinase 17 (membrane-inserted)|membrane-type matrix metalloproteinase 4|membrane-type-4 matrix metalloproteinase', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131828393, end_position_on_the_genomic_accession=131851771, orientation='plus', exon_count=14, OMIM=[602285], no_hdr0=''),
    4327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4327, CurrentID=0, Status='live', Symbol='MMP19', Aliases=['CODA', 'MMP18', 'RASI-1'], description='matrix metallopeptidase 19', other_designations='matrix metalloproteinase-19|matrix metalloproteinase RASI|matrix metalloproteinase-18|matrix metalloproteinase-beta19', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55835433, end_position_on_the_genomic_accession=55842971, orientation='minus', exon_count=9, OMIM=[601807], no_hdr0=''),
    4329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4329, CurrentID=0, Status='live', Symbol='ALDH6A1', Aliases=['MMSADHA', 'MMSDH'], description='aldehyde dehydrogenase 6 family member A1', other_designations='methylmalonate-semialdehyde dehydrogenase [acylating], mitochondrial|malonate-semialdehyde dehydrogenase (acetylating)|mitochondrial acylating methylmalonate-semialdehyde dehydrogenase|testicular tissue protein Li 122', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74056847, end_position_on_the_genomic_accession=74084453, orientation='minus', exon_count=12, OMIM=[603178], no_hdr0=''),
    4330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4330, CurrentID=0, Status='live', Symbol='MN1', Aliases=['CEBALID', 'MGCR', 'MGCR1', 'MGCR1-PEN', 'dJ353E16.2'], description='MN1 proto-oncogene, transcriptional regulator', other_designations='transcriptional activator MN1|meningioma (disrupted in balanced translocation) 1|meningioma (translocation balanced)|meningioma chromosome region 1|probable tumor suppressor protein MN1', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=27748277, end_position_on_the_genomic_accession=27801756, orientation='minus', exon_count=2, OMIM=[156100], no_hdr0=''),
    4331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4331, CurrentID=0, Status='live', Symbol='MNAT1', Aliases=['CAP35', 'MAT1', 'RNF66', 'TFB3'], description='MNAT1 component of CDK activating kinase', other_designations='CDK-activating kinase assembly factor MAT1|CDK7/cyclin-H assembly factor|MNAT CDK-activating kinase assembly factor 1|MNAT1, CDK activating kinase assembly factor|RING finger protein 66|RING finger protein MAT1|cyclin G1 interacting protein|menage a trois 1 (CAK assembly factor)|menage a trois homolog 1, cyclin H assembly factor|menage a trois-like protein 1 cyclin H assembly factor', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60734735, end_position_on_the_genomic_accession=60969965, orientation='plus', exon_count=12, OMIM=[602659], no_hdr0=''),
    4332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4332, CurrentID=0, Status='live', Symbol='MNDA', Aliases=['PYHIN3'], description='myeloid cell nuclear differentiation antigen', other_designations='myeloid cell nuclear differentiation antigen|epididymis secretory sperm binding protein', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158831351, end_position_on_the_genomic_accession=158849502, orientation='plus', exon_count=7, OMIM=[159553], no_hdr0=''),
    4335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4335, CurrentID=0, Status='live', Symbol='MNT', Aliases=['MAD6', 'MXD6', 'ROX', 'bHLHd3', 'lncRNA-HAL'], description='MAX network transcriptional repressor', other_designations='max-binding protein MNT|MAX binding protein|MNT, MAX dimerization protein|Max-interacting protein|class D basic helix-loop-helix protein 3|myc antagonist MNT', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2384073, end_position_on_the_genomic_accession=2401060, orientation='minus', exon_count=10, OMIM=[603039], no_hdr0=''),
    4336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4336, CurrentID=0, Status='live', Symbol='MOBP', Aliases=[], description='myelin associated oligodendrocyte basic protein', other_designations='myelin-associated oligodendrocyte basic protein', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39467680, end_position_on_the_genomic_accession=39529497, orientation='plus', exon_count=7, OMIM=[600948], no_hdr0=''),
    4337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4337, CurrentID=0, Status='live', Symbol='MOCS1', Aliases=['MIG11', 'MOCODA', 'MOCS1B', 'MOCS1'], description='molybdenum cofactor synthesis 1', other_designations='molybdenum cofactor biosynthesis protein 1|MOCS1A enzyme|cell migration-inducing gene 11 protein|molybdenum cofactor biosynthesis protein A|molybdenum cofactor synthesis-step 1 protein A-B', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39904170, end_position_on_the_genomic_accession=39934462, orientation='minus', exon_count=12, OMIM=[603707], no_hdr0=''),
    4338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4338, CurrentID=0, Status='live', Symbol='MOCS2', Aliases=['MCBPE', 'MOCO1', 'MOCODB', 'MPTS'], description='molybdenum cofactor synthesis 2', other_designations='molybdopterin synthase catalytic subunit|molybdopterin synthase sulfur carrier subunit|molybdenum cofactor biosynthesis protein E', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=53095679, end_position_on_the_genomic_accession=53109757, orientation='minus', exon_count=7, OMIM=[603708], no_hdr0=''),
    4340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4340, CurrentID=0, Status='live', Symbol='MOG', Aliases=['BTN6', 'BTNL11IG2', 'NRCLP7', 'MOG'], description='myelin oligodendrocyte glycoprotein', other_designations='myelin-oligodendrocyte glycoprotein|MOG AluA|MOG AluB|MOG Ig-AluB|MOG alpha-5', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29657092, end_position_on_the_genomic_accession=29672365, orientation='plus', exon_count=9, OMIM=[159465], no_hdr0=''),
    4342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4342, CurrentID=0, Status='live', Symbol='MOS', Aliases=['MSV'], description='MOS proto-oncogene, serine/threonine kinase', other_designations='proto-oncogene serine/threonine-protein kinase mos|c-mos|oncogene MOS, Moloney murine sarcoma virus|oocyte maturation factor mos|proto-oncogene c-Mos|v-mos Moloney murine sarcoma viral oncogene homolog', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56112942, end_position_on_the_genomic_accession=56113982, orientation='minus', exon_count=1, OMIM=[190060], no_hdr0=''),
    4343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4343, CurrentID=0, Status='live', Symbol='MOV10', Aliases=['fSAP113', 'gb110'], description='Mov10 RISC complex RNA helicase', other_designations='helicase MOV-10|Mov10, Moloney leukemia virus 10, homolog|armitage homolog|functional spliceosome-associated protein 113|moloney leukemia virus 10 protein|putative helicase MOV-10', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112674427, end_position_on_the_genomic_accession=112702377, orientation='plus', exon_count=23, OMIM=[610742], no_hdr0=''),
    4345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4345, CurrentID=0, Status='live', Symbol='CD200', Aliases=['MOX1', 'MOX2', 'MRC', 'OX-2'], description='CD200 molecule', other_designations='OX-2 membrane glycoprotein|CD200 antigen|antigen identified by monoclonal antibody MRC OX-2', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112332573, end_position_on_the_genomic_accession=112362812, orientation='plus', exon_count=8, OMIM=[155970], no_hdr0=''),
    4350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4350, CurrentID=0, Status='live', Symbol='MPG', Aliases=['AAG', 'ADPG', 'APNG', 'CRA36.1', 'MDG', 'Mid1', 'PIG11', 'PIG16', 'anpg'], description='N-methylpurine DNA glycosylase', other_designations="DNA-3-methyladenine glycosylase|3' end of the Mid1 gene, localized 68 kb upstream the humanzeta globin gene on 16p|3-alkyladenine DNA glycosylase|3-methyladenine DNA glycosidase|CRA36.1 (3-methyl-adenine DNA glycosylase)|N-methylpurine-DNA glycosylase, MPG|proliferation-inducing protein 11|proliferation-inducing protein 16", map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77007, end_position_on_the_genomic_accession=85846, orientation='plus', exon_count=6, OMIM=[156565], no_hdr0=''),
    4351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4351, CurrentID=0, Status='live', Symbol='MPI', Aliases=['CDG1B', 'PMI', 'PMI1'], description='mannose phosphate isomerase', other_designations='mannose-6-phosphate isomerase|phosphohexomutase|phosphomannose isomerase 1', map_location='15q24.1-q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74890042, end_position_on_the_genomic_accession=74902219, orientation='plus', exon_count=8, OMIM=[154550], no_hdr0=''),
    4352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4352, CurrentID=0, Status='live', Symbol='MPL', Aliases=['C-MPL', 'CD110V', 'THCYT2', 'THPOR', 'TPOR', 'MPL'], description='MPL proto-oncogene, thrombopoietin receptor', other_designations='thrombopoietin receptor|TPO-R|myeloproliferative leukemia protein|myeloproliferative leukemia virus oncogene|proto-oncogene c-Mpl', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43336875, end_position_on_the_genomic_accession=43354466, orientation='plus', exon_count=11, OMIM=[159530], no_hdr0=''),
    4353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4353, CurrentID=0, Status='live', Symbol='MPO', Aliases=[], description='myeloperoxidase', other_designations='myeloperoxidase', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58269855, end_position_on_the_genomic_accession=58280935, orientation='minus', exon_count=12, OMIM=[606989], no_hdr0=''),
    4354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4354, CurrentID=0, Status='live', Symbol='MPP1', Aliases=['AAG12', 'DXS552E', 'EMP55', 'MRG1', 'PEMP'], description='membrane palmitoylated protein 1', other_designations='55 kDa erythrocyte membrane protein|aging-associated gene 12|erythrocyte membrane protein p55|membrane protein, palmitoylated 1, 55kDa|migration-related gene 1|p55|palmitoylated erythrocyte membrane protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154778684, end_position_on_the_genomic_accession=154805485, orientation='minus', exon_count=13, OMIM=[305360], no_hdr0=''),
    4355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4355, CurrentID=0, Status='live', Symbol='MPP2', Aliases=['DLG2'], description='membrane palmitoylated protein 2', other_designations='MAGUK p55 subfamily member 2|discs large, homolog 2|membrane protein, palmitoylated 2 (MAGUK p55 subfamily member 2)', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43875357, end_position_on_the_genomic_accession=43909711, orientation='minus', exon_count=21, OMIM=[600723], no_hdr0=''),
    4356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4356, CurrentID=0, Status='live', Symbol='MPP3', Aliases=['DLG3'], description='membrane palmitoylated protein 3', other_designations='MAGUK p55 subfamily member 3|discs, large homolog 3|membrane protein palmitoylated 3|membrane protein, palmitoylated 3 (MAGUK p55 subfamily member 3)', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43800811, end_position_on_the_genomic_accession=43833192, orientation='minus', exon_count=22, OMIM=[601114], no_hdr0=''),
    4357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4357, CurrentID=0, Status='live', Symbol='MPST', Aliases=['MST', 'TST2', 'TUM1'], description='mercaptopyruvate sulfurtransferase', other_designations='3-mercaptopyruvate sulfurtransferase|human liver rhodanese|tRNA thiouridin modification protein 1|testicular tissue protein Li 200', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37019742, end_position_on_the_genomic_accession=37029815, orientation='plus', exon_count=5, OMIM=[602496], no_hdr0=''),
    4358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4358, CurrentID=0, Status='live', Symbol='MPV17', Aliases=['CMT2EE', 'MTDPS6', 'SYM1'], description='mitochondrial inner membrane protein MPV17', other_designations='protein Mpv17|MPV17, mitochondrial inner membrane protein|MpV17 mitochondrial inner membrane protein|Mpv17, human homolog of glomerulosclerosis and nephrotic syndrome', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27309492, end_position_on_the_genomic_accession=27323097, orientation='minus', exon_count=9, OMIM=[137960], no_hdr0=''),
    4359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4359, CurrentID=0, Status='live', Symbol='MPZ', Aliases=['CHM', 'CHN2', 'CMT1', 'CMT1B', 'CMT2I', 'CMT2J', 'CMT4E', 'CMTDI3', 'CMTDID', 'DSS', 'HMSNIB', 'MPP', 'P0'], description='myelin protein zero', other_designations='myelin protein P0|Charcot-Marie-Tooth neuropathy 1B|myelin peripheral protein', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161303594, end_position_on_the_genomic_accession=161309969, orientation='minus', exon_count=7, OMIM=[159440], no_hdr0=''),
    4360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4360, CurrentID=0, Status='live', Symbol='MRC1', Aliases=['CD206', 'CLEC13D', 'CLEC13DL', 'MMRL1', 'bA541I19.1', 'hMR', 'MRC1'], description='mannose receptor C-type 1', other_designations='macrophage mannose receptor 1|C-type lectin domain family 13 member D|human mannose receptor|macrophage mannose receptor 1-like protein 1|mannose receptor, C type 1-like 1', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17809348, end_position_on_the_genomic_accession=17911164, orientation='plus', exon_count=30, OMIM=[153618], no_hdr0=''),
    4361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4361, CurrentID=0, Status='live', Symbol='MRE11', Aliases=['ATLD', 'HNGS1A', 'MRE11B', 'MRE11'], description='MRE11 homolog, double strand break repair nuclease', other_designations='double-strand break repair protein MRE11|AT-like disease|DNA recombination and repair protein|MRE11 double strand break repair nuclease A|MRE11 homolog 1|MRE11 homolog A, double strand break repair nuclease|MRE11 homolog, double strand break repair nuclease A|MRE11 meiotic recombination 11 homolog A|MRE11 meiotic recombination 11-like protein A|double-strand break repair protein MRE11A|endo/exonuclease Mre11|meiotic recombination 11 homolog 1|meiotic recombination 11 homolog A', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94415570, end_position_on_the_genomic_accession=94512701, orientation='minus', exon_count=22, OMIM=[600814], no_hdr0=''),
    4363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4363, CurrentID=0, Status='live', Symbol='ABCC1', Aliases=['ABC29', 'ABCC', 'DFNA77', 'GS-X', 'MRP', 'MRP1'], description='ATP binding cassette subfamily C member 1', other_designations='multidrug resistance-associated protein 1|ATP-binding cassette transporter variant ABCC1delta-ex13|ATP-binding cassette transporter variant ABCC1delta-ex13&14|ATP-binding cassette transporter variant ABCC1delta-ex25|ATP-binding cassette transporter variant ABCC1delta-ex25&26|ATP-binding cassette, sub-family C (CFTR/MRP), member 1|LTC4 transporter|glutathione S-conjugate export pump|glutathione-S-conjugate-translocating ATPase ABCC1|leukotriene C(4) transporter', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15949616, end_position_on_the_genomic_accession=16143062, orientation='plus', exon_count=34, OMIM=[158343], no_hdr0=''),
    4430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4430, CurrentID=0, Status='live', Symbol='MYO1B', Aliases=['MMI-alpha', 'MMIa', 'MYH-1c', 'myr1'], description='myosin IB', other_designations='unconventional myosin-Ib|MYO1B variant protein|myosin-I alpha', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=191245400, end_position_on_the_genomic_accession=191425386, orientation='plus', exon_count=34, OMIM=[606537], no_hdr0=''),
    4431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4431, CurrentID=0, Status='live', Symbol='MSBP1', Aliases=[], description='minisatellite binding protein 1', other_designations='minisatellite binding protein 1', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    4432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4432, CurrentID=0, Status='live', Symbol='MSBP2', Aliases=[], description='minisatellite binding protein 2', other_designations='minisatellite binding protein 2|minisatellite binding protein 2, 77kDa', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    4435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4435, CurrentID=0, Status='live', Symbol='CITED1', Aliases=['MSG1'], description='Cbp/p300 interacting transactivator with Glu/Asp rich carboxy-terminal domain 1', other_designations='cbp/p300-interacting transactivator 1|melanocyte-specific gene 1|melanocyte-specific protein 1', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72301646, end_position_on_the_genomic_accession=72307157, orientation='minus', exon_count=6, OMIM=[300149], no_hdr0=''),
    4436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4436, CurrentID=0, Status='live', Symbol='MSH2', Aliases=['COCA1', 'FCC1', 'HNPCC', 'HNPCC1', 'LCFS2', 'MMRCS2', 'hMSH2'], description='mutS homolog 2', other_designations='DNA mismatch repair protein Msh2|DNA mismatch repair protein Msh2 transcript|mutS homolog 2, colon cancer, nonpolyposis type 1', map_location='2p21-p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47403067, end_position_on_the_genomic_accession=47634501, orientation='plus', exon_count=22, OMIM=[609309], no_hdr0=''),
    4437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4437, CurrentID=0, Status='live', Symbol='MSH3', Aliases=['DUP', 'FAP4', 'MRP1'], description='mutS homolog 3', other_designations='DNA mismatch repair protein Msh3|divergent upstream protein|epididymis secretory sperm binding protein|hMSH3|mismatch repair protein 1', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80654652, end_position_on_the_genomic_accession=80876815, orientation='plus', exon_count=24, OMIM=[600887], no_hdr0=''),
    4438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4438, CurrentID=0, Status='live', Symbol='MSH4', Aliases=[], description='mutS homolog 4', other_designations='mutS protein homolog 4|hMSH4', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75796882, end_position_on_the_genomic_accession=75913242, orientation='plus', exon_count=20, OMIM=[602105], no_hdr0=''),
    4439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4439, CurrentID=0, Status='live', Symbol='MSH5', Aliases=['G7', 'MUTSH5', 'NG23', 'POF13'], description='mutS homolog 5', other_designations='mutS protein homolog 5', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31740005, end_position_on_the_genomic_accession=31762676, orientation='plus', exon_count=25, OMIM=[603382], no_hdr0=''),
    4440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4440, CurrentID=0, Status='live', Symbol='MSI1', Aliases=[], description='musashi RNA binding protein 1', other_designations='RNA-binding protein Musashi homolog 1|musashi-1|musashi1', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120339662, end_position_on_the_genomic_accession=120369174, orientation='minus', exon_count=21, OMIM=[603328], no_hdr0=''),
    4477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4477, CurrentID=0, Status='live', Symbol='MSMB', Aliases=['HPC13', 'IGBF', 'MSP', 'MSPB', 'PN44', 'PRPS', 'PSP', 'PSP-94', 'PSP57', 'PSP94'], description='microseminoprotein beta', other_designations='beta-microseminoprotein|immunoglobulin binding factor|prostate secreted seminal plasma protein|prostate secretory protein of 94 amino acids|seminal plasma beta-inhibin', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46033313, end_position_on_the_genomic_accession=46046269, orientation='minus', exon_count=4, OMIM=[157145], no_hdr0=''),
    4478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4478, CurrentID=0, Status='live', Symbol='MSN', Aliases=['HEL70', 'IMD50'], description='moesin', other_designations='moesin|epididymis luminal protein 70|membrane-organizing extension spike protein', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=65588382, end_position_on_the_genomic_accession=65741931, orientation='plus', exon_count=18, OMIM=[309845], no_hdr0=''),
    4481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4481, CurrentID=0, Status='live', Symbol='MSR1', Aliases=['CD204', 'SCARA1', 'SR-A', 'SR-AI', 'SR-AII', 'SR-AIII', 'SRA', 'phSR1', 'phSR2'], description='macrophage scavenger receptor 1', other_designations='macrophage scavenger receptor types I and II|macrophage acetylated LDL receptor I and II|macrophage scavenger receptor type III|scavenger receptor class A member 1', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=16107881, end_position_on_the_genomic_accession=16192651, orientation='minus', exon_count=12, OMIM=[153622], no_hdr0=''),
    4482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4482, CurrentID=0, Status='live', Symbol='MSRA', Aliases=['PMSR'], description='methionine sulfoxide reductase A', other_designations='mitochondrial peptide methionine sulfoxide reductase|cytosolic methionine-S-sulfoxide reductase|peptide Met(O) reductase|peptide met (O) reductase|peptide-methionine (S)-S-oxide reductase', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10054224, end_position_on_the_genomic_accession=10428891, orientation='plus', exon_count=12, OMIM=[601250], no_hdr0=''),
    4485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4485, CurrentID=0, Status='live', Symbol='MST1', Aliases=['D3F15S2', 'DNF15S2', 'HGFL', 'MSP', 'NF15S2'], description='macrophage stimulating 1', other_designations='hepatocyte growth factor-like protein|hepatocyte growth factor-like protein homolog|macrophage stimulating 1 (hepatocyte growth factor-like)|macrophage-stimulating protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49683947, end_position_on_the_genomic_accession=49689523, orientation='minus', exon_count=18, OMIM=[142408], no_hdr0=''),
    4486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4486, CurrentID=0, Status='live', Symbol='MST1R', Aliases=['CD136', 'CDw136', 'NPCA3', 'PTK8', 'RON', 'SEA'], description='macrophage stimulating 1 receptor', other_designations='macrophage-stimulating protein receptor|MSP receptor|PTK8 protein tyrosine kinase 8|S13 avian erythroblastosis oncogene homolog|S13 erythroblastosis oncogene homolog|c-met-related tyrosine kinase|p185-Ron', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49886471, end_position_on_the_genomic_accession=49903873, orientation='minus', exon_count=21, OMIM=[600168], no_hdr0=''),
    4487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4487, CurrentID=0, Status='live', Symbol='MSX1', Aliases=['ECTD3', 'HOX7', 'HYD1', 'STHAG1'], description='msh homeobox 1', other_designations='homeobox protein MSX-1|homeobox 7|homeobox protein Hox-7|msh homeo box 1|msh homeobox 1-like protein|msh homeobox homolog 1', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4859665, end_position_on_the_genomic_accession=4863936, orientation='plus', exon_count=2, OMIM=[142983], no_hdr0=''),
    4488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4488, CurrentID=0, Status='live', Symbol='MSX2', Aliases=['CRS2', 'FPP', 'HOX8', 'MSH', 'PFM', 'PFM1'], description='msh homeobox 2', other_designations='homeobox protein MSX-2|homeobox protein Hox-8|msh homeo box 2|msh homeobox homolog 2', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=174724582, end_position_on_the_genomic_accession=174730896, orientation='plus', exon_count=2, OMIM=[123101], no_hdr0=''),
    4489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4489, CurrentID=0, Status='live', Symbol='MT1A', Aliases=['MT-1A', 'MT-IA', 'MT1', 'MT1S', 'MTC'], description='metallothionein 1A', other_designations='metallothionein-1A|metallothionein 1A (functional)|metallothionein 1S|metallothionein-IA', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56638666, end_position_on_the_genomic_accession=56640087, orientation='plus', exon_count=3, OMIM=[156350], no_hdr0=''),
    4490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4490, CurrentID=0, Status='live', Symbol='MT1B', Aliases=['MT-1B', 'MT-IB', 'MT1', 'MT1Q', 'MTP'], description='metallothionein 1B', other_designations='metallothionein-1B|metallothionein 1B (functional)|metallothionein 1Q|metallothionein-IB', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56651886, end_position_on_the_genomic_accession=56653204, orientation='plus', exon_count=3, OMIM=[156349], no_hdr0=''),
    4493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4493, CurrentID=0, Status='live', Symbol='MT1E', Aliases=['MT-1E', 'MT-IE', 'MT1', 'MTD'], description='metallothionein 1E', other_designations='metallothionein-1E|metallothionein 1E (functional)|metallothionein D|metallothionein-IE', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56625781, end_position_on_the_genomic_accession=56627112, orientation='plus', exon_count=2, OMIM=[156351], no_hdr0=''),
    4494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4494, CurrentID=0, Status='live', Symbol='MT1F', Aliases=['MT1'], description='metallothionein 1F', other_designations='metallothionein-1F|MT-1F|MT-IF|metallothionein 1F (functional)|metallothionein-IF', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56657959, end_position_on_the_genomic_accession=56659303, orientation='plus', exon_count=3, OMIM=[156352], no_hdr0=''),
    4495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4495, CurrentID=0, Status='live', Symbol='MT1G', Aliases=['MT1', 'MT1K'], description='metallothionein 1G', other_designations='metallothionein-1G|MT-1G|MT-1K|MT-IG|metallothionein-1K|metallothionein-IG', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56666730, end_position_on_the_genomic_accession=56668065, orientation='minus', exon_count=3, OMIM=[156353], no_hdr0=''),
    4496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4496, CurrentID=0, Status='live', Symbol='MT1H', Aliases=['MT-0', 'MT-1H', 'MT-IH', 'MT1'], description='metallothionein 1H', other_designations='metallothionein-1H|metallothionein-0|metallothionein-IH|testicular tissue protein Li 123', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56669814, end_position_on_the_genomic_accession=56671129, orientation='plus', exon_count=3, OMIM=[156354], no_hdr0=''),
    4499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4499, CurrentID=0, Status='live', Symbol='MT1M', Aliases=['MT-1M', 'MT-IM', 'MT1', 'MT1K'], description='metallothionein 1M', other_designations='metallothionein-1M|metallothionein 1K|metallothionein 1Y', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56632659, end_position_on_the_genomic_accession=56633981, orientation='plus', exon_count=3, OMIM=[156357], no_hdr0=''),
    4501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4501, CurrentID=0, Status='live', Symbol='MT1X', Aliases=['MT-1l', 'MT1'], description='metallothionein 1X', other_designations='metallothionein-1X|MT-1X|MT-IX|metallothionein-IX|testicular tissue protein Li 124', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56682470, end_position_on_the_genomic_accession=56684196, orientation='plus', exon_count=3, OMIM=[156359], no_hdr0=''),
    4502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4502, CurrentID=0, Status='live', Symbol='MT2A', Aliases=['MT-2', 'MT-II', 'MT2'], description='metallothionein 2A', other_designations='metallothionein-2|metallothionein-II', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56608584, end_position_on_the_genomic_accession=56609497, orientation='plus', exon_count=3, OMIM=[156360], no_hdr0=''),
    4504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4504, CurrentID=0, Status='live', Symbol='MT3', Aliases=['GIF', 'GIFB', 'GRIF', 'ZnMT3'], description='metallothionein 3', other_designations='metallothionein-3|growth inhibitory factor|metallothionein 3 (growth inhibitory factor (neurotrophic))|metallothionein-III', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56589528, end_position_on_the_genomic_accession=56591085, orientation='plus', exon_count=3, OMIM=[139255], no_hdr0=''),
    4507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4507, CurrentID=0, Status='live', Symbol='MTAP', Aliases=['BDMF', 'DMSFH', 'DMSMFH', 'HEL-249', 'LGMBF', 'MSAP', 'c86fus'], description='methylthioadenosine phosphorylase', other_designations="S-methyl-5'-thioadenosine phosphorylase|5'-methylthioadenosine phosphorylase|MTA phosphorylase|MTAPase|MeSAdo phosphorylase|epididymis luminal protein 249|epididymis secretory sperm binding protein", map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21802636, end_position_on_the_genomic_accession=21867081, orientation='plus', exon_count=8, OMIM=[156540], no_hdr0=''),
    4508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4508, CurrentID=0, Status='live', Symbol='MT-ATP6', Aliases=['ATPase6', 'MTATP6', 'ATP6'], description='mitochondrially encoded ATP synthase 6', other_designations='ATP synthase F0 subunit 6', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=8527, end_position_on_the_genomic_accession=9207, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4509, CurrentID=0, Status='live', Symbol='MT-ATP8', Aliases=['ATPase8', 'MTATP8', 'ATP8'], description='mitochondrially encoded ATP synthase 8', other_designations='ATP synthase F0 subunit 8', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=8366, end_position_on_the_genomic_accession=8572, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4512, CurrentID=0, Status='live', Symbol='MT-CO1', Aliases=['COI', 'MTCO1', 'COX1'], description='mitochondrially encoded cytochrome c oxidase I', other_designations='cytochrome c oxidase subunit I', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=5904, end_position_on_the_genomic_accession=7445, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4513, CurrentID=0, Status='live', Symbol='MT-CO2', Aliases=['COII', 'MTCO2', 'COX2'], description='mitochondrially encoded cytochrome c oxidase II', other_designations='cytochrome c oxidase subunit II', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=7586, end_position_on_the_genomic_accession=8269, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4514, CurrentID=0, Status='live', Symbol='MT-CO3', Aliases=['COIII', 'MTCO3', 'COX3'], description='mitochondrially encoded cytochrome c oxidase III', other_designations='cytochrome c oxidase subunit III', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=9207, end_position_on_the_genomic_accession=9990, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4515, CurrentID=0, Status='live', Symbol='MTCP1', Aliases=['P13MTCP1', 'TCL1C', 'p8MTCP1'], description='mature T cell proliferation 1', other_designations='protein p13 MTCP-1|MTCP-1 type B1|TCL1 family AKT coactivator C|mature T-cell proliferation-1 type B1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155064034, end_position_on_the_genomic_accession=155071136, orientation='minus', exon_count=5, OMIM=[300116], no_hdr0=''),
    4519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4519, CurrentID=0, Status='live', Symbol='MT-CYB', Aliases=['MTCYB', 'CYTB'], description='mitochondrially encoded cytochrome b', other_designations='cytochrome b', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=14747, end_position_on_the_genomic_accession=15887, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4520, CurrentID=0, Status='live', Symbol='MTF1', Aliases=['MTF-1', 'ZRF'], description='metal regulatory transcription factor 1', other_designations='metal regulatory transcription factor 1|MRE-binding transcription factor|MRE-binding transcription factor-1|metal-responsive transcription factor 1|transcription factor MTF-1|zinc regulatory factor', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37809570, end_position_on_the_genomic_accession=37859614, orientation='minus', exon_count=14, OMIM=[600172], no_hdr0=''),
    4521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4521, CurrentID=0, Status='live', Symbol='NUDT1', Aliases=['MTH1'], description='nudix hydrolase 1', other_designations='7,8-dihydro-8-oxoguanine triphosphatase|2-hydroxy-dATP diphosphatase|8-oxo-7,8-dihydrodeoxyguanosine triphosphatase|8-oxo-7,8-dihydroguanosine triphosphatase|8-oxo-dGTPase|mutT human homolog 1|nucleoside diphosphate-linked moiety X motif 1|nucleoside diphosphate-linked moiety X-type motif 1|nudix (nucleoside diphosphate linked moiety X)-type motif 1|nudix motif 1', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2242226, end_position_on_the_genomic_accession=2251145, orientation='plus', exon_count=7, OMIM=[600312], no_hdr0=''),
    4522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4522, CurrentID=0, Status='live', Symbol='MTHFD1', Aliases=['CIMAH', 'MTHFC', 'MTHFD'], description='methylenetetrahydrofolate dehydrogenase, cyclohydrolase and formyltetrahydrofolate synthetase 1', other_designations='C-1-tetrahydrofolate synthase, cytoplasmic|5,10-methylenetetrahydrofolate dehydrogenase, 5,10-methylenetetrahydrofolate cyclohydrolase, 10-formyltetrahydrofolate synthetase|C1-THF synthase|cytoplasmic C-1-tetrahydrofolate synthase|epididymis secretory sperm binding protein|methylenetetrahydrofolate dehydrogenase (NADP+ dependent) 1, methenyltetrahydrofolate cyclohydrolase, formyltetrahydrofolate synthetase', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64388353, end_position_on_the_genomic_accession=64460025, orientation='plus', exon_count=28, OMIM=[172460], no_hdr0=''),
    4524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4524, CurrentID=0, Status='live', Symbol='MTHFR', Aliases=[], description='methylenetetrahydrofolate reductase', other_designations='methylenetetrahydrofolate reductase|5,10-methylenetetrahydrofolate reductase (NADPH)|methylenetetrahydrofolate reductase (NAD(P)H)', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11785723, end_position_on_the_genomic_accession=11806103, orientation='minus', exon_count=12, OMIM=[607093], no_hdr0=''),
    4528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4528, CurrentID=0, Status='live', Symbol='MTIF2', Aliases=[], description='mitochondrial translational initiation factor 2', other_designations='translation initiation factor IF-2, mitochondrial|IF-2mt', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55235583, end_position_on_the_genomic_accession=55269314, orientation='minus', exon_count=19, OMIM=[603766], no_hdr0=''),
    4534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4534, CurrentID=0, Status='live', Symbol='MTM1', Aliases=['CNM', 'MTMX', 'XLMTM'], description='myotubularin 1', other_designations='myotubularin|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphate phosphatase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=150562658, end_position_on_the_genomic_accession=150673143, orientation='plus', exon_count=19, OMIM=[300415], no_hdr0=''),
    4535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4535, CurrentID=0, Status='live', Symbol='MT-ND1', Aliases=['MTND1', 'ND1'], description='mitochondrially encoded NADH dehydrogenase 1', other_designations='NADH dehydrogenase subunit 1', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=3307, end_position_on_the_genomic_accession=4262, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4536, CurrentID=0, Status='live', Symbol='MT-ND2', Aliases=['MTND2', 'ND2'], description='mitochondrially encoded NADH dehydrogenase 2', other_designations='NADH dehydrogenase subunit 2', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=4470, end_position_on_the_genomic_accession=5511, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4537, CurrentID=0, Status='live', Symbol='MT-ND3', Aliases=['MTND3', 'ND3'], description='mitochondrially encoded NADH dehydrogenase 3', other_designations='NADH dehydrogenase subunit 3', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=10059, end_position_on_the_genomic_accession=10404, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4538, CurrentID=0, Status='live', Symbol='MT-ND4', Aliases=['MTND4', 'ND4'], description='mitochondrially encoded NADH dehydrogenase 4', other_designations='NADH dehydrogenase subunit 4', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=10760, end_position_on_the_genomic_accession=12137, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4539, CurrentID=0, Status='live', Symbol='MT-ND4L', Aliases=['MTND4L', 'ND4L'], description='mitochondrially encoded NADH 4L dehydrogenase', other_designations='NADH dehydrogenase subunit 4L', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=10470, end_position_on_the_genomic_accession=10766, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4540, CurrentID=0, Status='live', Symbol='MT-ND5', Aliases=['MTND5', 'ND5'], description='mitochondrially encoded NADH dehydrogenase 5', other_designations='NADH dehydrogenase subunit 5', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=12337, end_position_on_the_genomic_accession=14148, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    4541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4541, CurrentID=0, Status='live', Symbol='MT-ND6', Aliases=['MTND6', 'ND6'], description='mitochondrially encoded NADH dehydrogenase 6', other_designations='NADH dehydrogenase subunit 6', map_location='', chromosome='MT', genomic_nucleotide_accession_version='NC_012920.1', start_position_on_the_genomic_accession=14149, end_position_on_the_genomic_accession=14673, orientation='minus', exon_count=0, OMIM=[], no_hdr0=''),
    4542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4542, CurrentID=0, Status='live', Symbol='MYO1F', Aliases=[], description='myosin IF', other_designations='unconventional myosin-If|myosin-ID|myosin-Ie', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8520778, end_position_on_the_genomic_accession=8577442, orientation='minus', exon_count=29, OMIM=[601480], no_hdr0=''),
    4543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4543, CurrentID=0, Status='live', Symbol='MTNR1A', Aliases=['MEL-1A-R', 'MT1'], description='melatonin receptor 1A', other_designations='melatonin receptor type 1A|mel1a receptor', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186532769, end_position_on_the_genomic_accession=186555567, orientation='minus', exon_count=3, OMIM=[600665], no_hdr0=''),
    4544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4544, CurrentID=0, Status='live', Symbol='MTNR1B', Aliases=['FGQTL2', 'MEL-1B-R', 'MT2'], description='melatonin receptor 1B', other_designations='melatonin receptor type 1B|mel1b receptor|melatonin receptor 1B variant b|melatonin receptor MEL1B', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=92969651, end_position_on_the_genomic_accession=92986241, orientation='plus', exon_count=4, OMIM=[600804], no_hdr0=''),
    4547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4547, CurrentID=0, Status='live', Symbol='MTTP', Aliases=['ABL', 'MTP'], description='microsomal triglyceride transfer protein', other_designations='microsomal triglyceride transfer protein large subunit|microsomal triglyceride transfer protein (large polypeptide, 88kDa)', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99564130, end_position_on_the_genomic_accession=99623997, orientation='plus', exon_count=19, OMIM=[157147], no_hdr0=''),
    4548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4548, CurrentID=0, Status='live', Symbol='MTR', Aliases=['HMAG', 'MS', 'cblG'], description='5-methyltetrahydrofolate-homocysteine methyltransferase', other_designations='methionine synthase|5-methyltetrahydrofolate-homocysteine methyltransferase 1|cobalamin-dependent methionine synthase|vitamin-B12 dependent methionine synthase', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236794304, end_position_on_the_genomic_accession=236903981, orientation='plus', exon_count=33, OMIM=[156570], no_hdr0=''),
    4552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4552, CurrentID=0, Status='live', Symbol='MTRR', Aliases=['MSR', 'cblE'], description='5-methyltetrahydrofolate-homocysteine methyltransferase reductase', other_designations='methionine synthase reductase|[methionine synthase]-cobalamin methyltransferase (cob(II)alamin reducing)|aqCbl reductase|aquacobalamin reductase|methionine synthase reductase, mitochondrial', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=7851186, end_position_on_the_genomic_accession=7901124, orientation='plus', exon_count=20, OMIM=[602568], no_hdr0=''),
    4580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4580, CurrentID=0, Status='live', Symbol='MTX1', Aliases=['MTX', 'MTXN'], description='metaxin 1', other_designations='metaxin-1|mitochondrial outer membrane import complex protein 1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155208695, end_position_on_the_genomic_accession=155213839, orientation='plus', exon_count=8, OMIM=[600605], no_hdr0=''),
    4582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4582, CurrentID=0, Status='live', Symbol='MUC1', Aliases=['ADMCKD', 'ADMCKD1', 'ADTKD2', 'CA 15-3', 'CD227', 'EMA', 'H23AG', 'KL-6', 'MAM6', 'MCD', 'MCKD', 'MCKD1', 'MUC-1', 'MUC-1/SEC', 'MUC-1/X/ZD', 'PEM', 'PEMT', 'PUM', 'MUC1'], description='mucin 1, cell surface associated', other_designations='mucin-1|H23 antigen|breast carcinoma-associated antigen DF3|cancer antigen 15-3|carcinoma-associated mucin|episialin|krebs von den Lungen-6|mucin 1, transmembrane|peanut-reactive urinary mucin|polymorphic epithelial mucin|tumor associated epithelial mucin|tumor-associated epithelial membrane antigen', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155185824, end_position_on_the_genomic_accession=155192915, orientation='minus', exon_count=11, OMIM=[158340], no_hdr0=''),
    4583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4583, CurrentID=0, Status='live', Symbol='MUC2', Aliases=['MLP', 'MUC-2', 'SMUC'], description='mucin 2, oligomeric mucus/gel-forming', other_designations='mucin-2|mucin 2, intestinal/tracheal', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1074875, end_position_on_the_genomic_accession=1110508, orientation='plus', exon_count=52, OMIM=[158370], no_hdr0=''),
    4584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4584, CurrentID=0, Status='live', Symbol='MUC3A', Aliases=['MUC-3A', 'MUC3'], description='mucin 3A, cell surface associated', other_designations='mucin-3A|intestinal mucin|mucin 3, intestinal', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100949534, end_position_on_the_genomic_accession=100968347, orientation='plus', exon_count=12, OMIM=[158371], no_hdr0=''),
    4585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4585, CurrentID=0, Status='live', Symbol='MUC4', Aliases=['ASGP', 'HSA276359', 'MUC-4'], description='mucin 4, cell surface associated', other_designations='mucin-4|ascites sialoglycoprotein|mucin 4, tracheobronchial|pancreatic adenocarcinoma mucin|testis mucin|tracheobronchial mucin', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195746771, end_position_on_the_genomic_accession=195811929, orientation='minus', exon_count=25, OMIM=[158372], no_hdr0=''),
    4586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4586, CurrentID=0, Status='live', Symbol='MUC5AC', Aliases=['MUC5', 'TBM', 'leB', 'mucin'], description='mucin 5AC, oligomeric mucus/gel-forming', other_designations='mucin-5AC|gastric mucin|lewis B blood group antigen|major airway glycoprotein|mucin 5, subtypes A and C, tracheobronchial/gastric|mucin 5AC, oligomeric mucus/gel-forming pseudogene|mucin-5 subtype AC, tracheobronchial|tracheobronchial mucin', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1157953, end_position_on_the_genomic_accession=1201138, orientation='plus', exon_count=49, OMIM=[158373], no_hdr0=''),
    4588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4588, CurrentID=0, Status='live', Symbol='MUC6', Aliases=['MUC-6'], description='mucin 6, oligomeric mucus/gel-forming', other_designations='mucin-6|gastric mucin-6', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1012823, end_position_on_the_genomic_accession=1036718, orientation='minus', exon_count=33, OMIM=[158374], no_hdr0=''),
    4589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4589, CurrentID=0, Status='live', Symbol='MUC7', Aliases=['MG2'], description='mucin 7, secreted', other_designations='mucin-7|MUC-7|apo-MG2|mucin 7, salivary|salivary mucin-7', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70430492, end_position_on_the_genomic_accession=70482997, orientation='plus', exon_count=5, OMIM=[158375], no_hdr0=''),
    4591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4591, CurrentID=0, Status='live', Symbol='TRIM37', Aliases=['MUL', 'POB1', 'TEF3'], description='tripartite motif containing 37', other_designations='E3 ubiquitin-protein ligase TRIM37|RING-B-box-coiled-coil protein|RING-type E3 ubiquitin transferase TRIM37|mulibrey nanism protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58968010, end_position_on_the_genomic_accession=59106880, orientation='minus', exon_count=28, OMIM=[605073], no_hdr0=''),
    4593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4593, CurrentID=0, Status='live', Symbol='MUSK', Aliases=['CMS9', 'FADS', 'FADS1'], description='muscle associated receptor tyrosine kinase', other_designations='muscle, skeletal receptor tyrosine-protein kinase|muscle, skeletal, receptor tyrosine kinase|muscle-specific kinase receptor|muscle-specific tyrosine-protein kinase receptor', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110668189, end_position_on_the_genomic_accession=110806633, orientation='plus', exon_count=17, OMIM=[601296], no_hdr0=''),
    4594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4594, CurrentID=0, Status='live', Symbol='MMUT', Aliases=['MCM', 'MUT'], description='methylmalonyl-CoA mutase', other_designations='methylmalonyl-CoA mutase, mitochondrial|methylmalonyl Coenzyme A mutase|methylmalonyl-CoA isomerase|methylmalonyl-CoA mutase c.*192delA|methylmalonyl-CoA mutase c.*51C>G|methylmalonyl-CoA mutase variant c.1495G>A|methylmalonyl-CoA mutase variant c.2011A>G|methylmalonyl-CoA mutase variant c.2150G>T|methylmalonyl-CoA mutase variant c.322C>T|methylmalonyl-CoA mutase variant c.613_615delGAA|methylmalonyl-CoA mutase variant c.636G>A|methylmalonyl-CoA mutase variant c.643G>A|mutant methylmalonyl CoA mutase|truncated methylmalonyl CoA mutase|truncated methylmalonyl-CoA mutase variant c.1420C>T|truncated methylmalonyl-CoA mutase variant c.2179C>T|truncated methylmalonyl-CoA mutase variant c.91C>T', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49430360, end_position_on_the_genomic_accession=49463298, orientation='minus', exon_count=13, OMIM=[609058], no_hdr0=''),
    4595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4595, CurrentID=0, Status='live', Symbol='MUTYH', Aliases=['MYH'], description='mutY DNA glycosylase', other_designations='adenine DNA glycosylase|A/G-specific adenine DNA glycosylase|mutY homolog|mutY-like protein', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45329242, end_position_on_the_genomic_accession=45340447, orientation='minus', exon_count=22, OMIM=[604933], no_hdr0=''),
    4597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4597, CurrentID=0, Status='live', Symbol='MVD', Aliases=['FP17780', 'MDDase', 'MPD', 'POROK7'], description='mevalonate diphosphate decarboxylase', other_designations='diphosphomevalonate decarboxylase|mevalonate (diphospho) decarboxylase|mevalonate pyrophosphate decarboxylase', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88651935, end_position_on_the_genomic_accession=88663153, orientation='minus', exon_count=13, OMIM=[603236], no_hdr0=''),
    4598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4598, CurrentID=0, Status='live', Symbol='MVK', Aliases=['LRBP', 'MK', 'MVLK', 'POROK3'], description='mevalonate kinase', other_designations='mevalonate kinase|LH receptor mRNA-binding protein|mevalonate kinase 1', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109573461, end_position_on_the_genomic_accession=109598125, orientation='plus', exon_count=13, OMIM=[251170], no_hdr0=''),
    4599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4599, CurrentID=0, Status='live', Symbol='MX1', Aliases=['IFI-78K', 'IFI78', 'MX', 'MxA', 'lncMX1-215'], description='MX dynamin like GTPase 1', other_designations='interferon-induced GTP-binding protein Mx1|interferon-induced protein p78|interferon-inducible protein p78|interferon-regulated resistance GTP-binding protein MxA|myxoma resistance protein 1|myxovirus (influenza virus) resistance 1, interferon-inducible protein p78', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41420329, end_position_on_the_genomic_accession=41459214, orientation='plus', exon_count=24, OMIM=[147150], no_hdr0=''),
    4600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4600, CurrentID=0, Status='live', Symbol='MX2', Aliases=['MXB'], description='MX dynamin like GTPase 2', other_designations='interferon-induced GTP-binding protein Mx2|interferon-regulated resistance GTP-binding protein MXB|myxovirus (influenza virus) resistance 2|myxovirus resistance protein 2|p78-related protein|second interferon-induced protein p78', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41361944, end_position_on_the_genomic_accession=41409393, orientation='plus', exon_count=18, OMIM=[147890], no_hdr0=''),
    4601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4601, CurrentID=0, Status='live', Symbol='MXI1', Aliases=['MAD2', 'MXD2', 'MXI', 'bHLHc11'], description='MAX interactor 1, dimerization protein', other_designations='max-interacting protein 1|MAX dimerization protein 2|Max-related transcription factor|class C basic helix-loop-helix protein 11', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110207605, end_position_on_the_genomic_accession=110287365, orientation='plus', exon_count=8, OMIM=[600020], no_hdr0=''),
    4602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4602, CurrentID=0, Status='live', Symbol='MYB', Aliases=['Cmyb', 'c-myb', 'c-myb_CDS', 'efg'], description='MYB proto-oncogene, transcription factor', other_designations='transcriptional activator Myb|oncogene AMV|proto-oncogene c-Myb|v-myb avian myeloblastosis viral oncogene homolog', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=135181308, end_position_on_the_genomic_accession=135219172, orientation='plus', exon_count=19, OMIM=[189990], no_hdr0=''),
    4603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4603, CurrentID=0, Status='live', Symbol='MYBL1', Aliases=['A-MYB', 'AMYB'], description='MYB proto-oncogene like 1', other_designations='myb-related protein A|myb-like protein 1|v-myb avian myeloblastosis viral oncogene homolog-like 1', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66562175, end_position_on_the_genomic_accession=66613218, orientation='minus', exon_count=18, OMIM=[159405], no_hdr0=''),
    4604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4604, CurrentID=0, Status='live', Symbol='MYBPC1', Aliases=['LCCS4', 'MYBPCC', 'MYBPCS', 'MYOTREM', 'ssMyBP-C'], description='myosin binding protein C1', other_designations='myosin-binding protein C, slow-type|myosin binding protein C, slow type|skeletal muscle C-protein|slow MyBP-C|slow skeletal-type muscle myosin-binding-protein C', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101594849, end_position_on_the_genomic_accession=101695841, orientation='plus', exon_count=34, OMIM=[160794], no_hdr0=''),
    4605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4605, CurrentID=0, Status='live', Symbol='MYBL2', Aliases=['B-MYB', 'BMYB'], description='MYB proto-oncogene like 2', other_designations='myb-related protein B|myb-like protein 2|v-myb avian myeloblastosis viral oncogene homolog-like 2|v-myb myeloblastosis viral oncogene homolog-like 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43667114, end_position_on_the_genomic_accession=43716482, orientation='plus', exon_count=14, OMIM=[601415], no_hdr0=''),
    4606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4606, CurrentID=0, Status='live', Symbol='MYBPC2', Aliases=['MYBPC', 'MYBPCF', 'fsMyBP-C'], description='myosin binding protein C2', other_designations='myosin-binding protein C, fast-type|fast MyBP-C|fast skeletal-type muscle myosin-binding-protein C|fast-type muscle myosin-binding-protein C|myosin binding protein C, fast type|testicular tissue protein Li 126', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50432892, end_position_on_the_genomic_accession=50466321, orientation='plus', exon_count=28, OMIM=[160793], no_hdr0=''),
    4607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4607, CurrentID=0, Status='live', Symbol='MYBPC3', Aliases=['CMD1MM', 'CMH4', 'FHC', 'LVNC10', 'MYBP-C', 'cMyBP-C'], description='myosin binding protein C3', other_designations='myosin-binding protein C, cardiac-type|myosin binding protein C, cardiac|truncated cardiac myosin-binding protein C', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47331406, end_position_on_the_genomic_accession=47352702, orientation='minus', exon_count=35, OMIM=[600958], no_hdr0=''),
    4608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4608, CurrentID=0, Status='live', Symbol='MYBPH', Aliases=[], description='myosin binding protein H', other_designations='myosin-binding protein H|H-protein|myBP-H', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203167811, end_position_on_the_genomic_accession=203175826, orientation='minus', exon_count=11, OMIM=[160795], no_hdr0=''),
    4609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4609, CurrentID=0, Status='live', Symbol='MYC', Aliases=['MRTLC', 'bHLHe39', 'c-Myc', 'MYC'], description='MYC proto-oncogene, bHLH transcription factor', other_designations='myc proto-oncogene protein|avian myelocytomatosis viral oncogene homolog|class E basic helix-loop-helix protein 39|myc-related translation/localization regulatory factor|proto-oncogene c-Myc|transcription factor p64|v-myc avian myelocytomatosis viral oncogene homolog|v-myc myelocytomatosis viral oncogene homolog', map_location='8q24.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=127735434, end_position_on_the_genomic_accession=127742951, orientation='plus', exon_count=3, OMIM=[190080], no_hdr0=''),
    4610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4610, CurrentID=0, Status='live', Symbol='MYCL', Aliases=['L-Myc', 'LMYC1', 'bHLHe38', 'MYCL'], description='MYCL proto-oncogene, bHLH transcription factor', other_designations='protein L-Myc|class E basic helix-loop-helix protein 38|l-myc-1 proto-oncogene|myc-related gene from lung cancer|protein L-Myc-1|v-myc avian myelocytomatosis viral oncogene lung carcinoma derived homolog|v-myc myelocytomatosis viral oncogene homolog 1, lung carcinoma derived', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39895428, end_position_on_the_genomic_accession=39901917, orientation='minus', exon_count=2, OMIM=[164850], no_hdr0=''),
    4613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4613, CurrentID=0, Status='live', Symbol='MYCN', Aliases=['MODED', 'N-myc', 'NMYC', 'ODED', 'bHLHe37'], description='MYCN proto-oncogene, bHLH transcription factor', other_designations='N-myc proto-oncogene protein|class E basic helix-loop-helix protein 37|neuroblastoma MYC oncogene|neuroblastoma-derived v-myc avian myelocytomatosis viral related oncogene|oncogene NMYC|v-myc avian myelocytomatosis viral oncogene neuroblastoma derived homolog', map_location='2p24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=15940550, end_position_on_the_genomic_accession=15947004, orientation='plus', exon_count=3, OMIM=[164840], no_hdr0=''),
    4615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4615, CurrentID=0, Status='live', Symbol='MYD88', Aliases=['IMD68D', 'MYD88'], description='MYD88 innate immune signal transduction adaptor', other_designations='myeloid differentiation primary response protein MyD88|mutant myeloid differentiation primary response 88|myeloid differentiation primary response 88|myeloid differentiation primary response gene (88)', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38138661, end_position_on_the_genomic_accession=38143022, orientation='plus', exon_count=6, OMIM=[602170], no_hdr0=''),
    4616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4616, CurrentID=0, Status='live', Symbol='GADD45B', Aliases=['GADD45BETA', 'MYD118'], description='growth arrest and DNA damage inducible beta', other_designations='growth arrest and DNA damage-inducible protein GADD45 beta|myeloid differentiation primary response protein MyD118|negative growth regulatory protein MyD118', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2476127, end_position_on_the_genomic_accession=2478259, orientation='plus', exon_count=4, OMIM=[604948], no_hdr0=''),
    4617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4617, CurrentID=0, Status='live', Symbol='MYF5', Aliases=['EORVA', 'bHLHc2'], description='myogenic factor 5', other_designations='myogenic factor 5|class C basic helix-loop-helix protein 2|myf-5', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80716912, end_position_on_the_genomic_accession=80719671, orientation='plus', exon_count=3, OMIM=[159990], no_hdr0=''),
    4618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4618, CurrentID=0, Status='live', Symbol='MYF6', Aliases=['CNM3', 'MRF4', 'bHLHc4', 'myf-6'], description='myogenic factor 6', other_designations='myogenic factor 6|class C basic helix-loop-helix protein 4|muscle-specific regulatory factor 4|myogenic factor 6 (herculin)', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80707634, end_position_on_the_genomic_accession=80709474, orientation='plus', exon_count=3, OMIM=[159991], no_hdr0=''),
    4619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4619, CurrentID=0, Status='live', Symbol='MYH1', Aliases=['HEL71', 'MYHSA1', 'MYHa', 'MyHC-2X/D', 'MyHC-2x'], description='myosin heavy chain 1', other_designations='myosin-1|epididymis luminal protein 71|myHC-IIx/d|myosin heavy chain 2x|myosin heavy chain IIx/d|myosin heavy chain, skeletal muscle, adult 1|myosin, heavy chain 1, skeletal muscle, adult|myosin, heavy polypeptide 1, skeletal muscle, adult', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10492307, end_position_on_the_genomic_accession=10518719, orientation='minus', exon_count=40, OMIM=[160730], no_hdr0=''),
    4620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4620, CurrentID=0, Status='live', Symbol='MYH2', Aliases=['IBM3A', 'MYHSA2', 'MYHas8', 'MYPOP', 'MyHC-2A', 'MyHC-IIa', 'MYH2'], description='myosin heavy chain 2', other_designations='myosin-2|fast 2a myosin heavy chain|inclusion body myopathy 3, autosomal dominant|myosin heavy chain 2a|myosin heavy chain IIa|myosin heavy chain, skeletal muscle, adult 2|myosin, heavy chain 2, skeletal muscle, adult|myosin, heavy polypeptide 2, skeletal muscle, adult|type IIA myosin heavy chain', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10521148, end_position_on_the_genomic_accession=10549658, orientation='minus', exon_count=40, OMIM=[160740], no_hdr0=''),
    4621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4621, CurrentID=0, Status='live', Symbol='MYH3', Aliases=['CPSFS1A', 'CPSFS1B', 'CPSKF1A', 'CPSKF1B', 'DA2A', 'DA2B', 'DA2B3', 'DA8', 'HEMHC', 'MYHC-EMB', 'MYHSE1', 'SMHCE'], description='myosin heavy chain 3', other_designations='myosin-3|myosin heavy chain, fast skeletal muscle, embryonic|myosin, heavy chain 3, skeletal muscle, embryonic|myosin, heavy polypeptide 3, skeletal muscle, embryonic|myosin, skeletal, heavy chain, embryonic 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10628527, end_position_on_the_genomic_accession=10678347, orientation='minus', exon_count=43, OMIM=[160720], no_hdr0=''),
    4622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4622, CurrentID=0, Status='live', Symbol='MYH4', Aliases=['MYH2B', 'MyHC-2B', 'MyHC-IIb'], description='myosin heavy chain 4', other_designations='myosin-4|myosin heavy chain 2b|myosin heavy chain IIb|myosin heavy chain, skeletal muscle, fetal|myosin, heavy chain 4, skeletal muscle|myosin, heavy polypeptide 4, skeletal muscle', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10443058, end_position_on_the_genomic_accession=10469559, orientation='minus', exon_count=40, OMIM=[160742], no_hdr0=''),
    4624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4624, CurrentID=0, Status='live', Symbol='MYH6', Aliases=['ASD3', 'CMD1EE', 'CMH14', 'MYHC', 'MYHCA', 'SSS3', 'alpha-MHC'], description='myosin heavy chain 6', other_designations='myosin-6|myHC-alpha|myosin, heavy polypeptide 6, cardiac muscle, alpha (cardiomyopathy, hypertrophic 1)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23381987, end_position_on_the_genomic_accession=23408273, orientation='minus', exon_count=39, OMIM=[160710], no_hdr0=''),
    4625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4625, CurrentID=0, Status='live', Symbol='MYH7', Aliases=['CMD1S', 'CMH1', 'MPD1', 'MYHCB', 'SPMD', 'SPMM'], description='myosin heavy chain 7', other_designations='myosin-7|cardiac muscle myosin heavy chain 7 beta|myHC-beta|myhc-slow|myopathy, distal 1|myosin 7|myosin heavy chain beta-subunit|myosin, heavy chain 7, cardiac muscle, beta|myosin, heavy polypeptide 7, cardiac muscle, beta|rhabdomyosarcoma antigen MU-RMS-40.7A', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23412740, end_position_on_the_genomic_accession=23435677, orientation='minus', exon_count=40, OMIM=[160760], no_hdr0=''),
    4626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4626, CurrentID=0, Status='live', Symbol='MYH8', Aliases=['DA7', 'MyHC-peri', 'MyHC-pn', 'gtMHC-F'], description='myosin heavy chain 8', other_designations='myosin-8|fetal-myosin heavy chain|myHC-perinatal|myosin heavy chain, skeletal muscle, perinatal|myosin, heavy chain 8, skeletal muscle, perinatal|myosin, heavy polypeptide 8, skeletal muscle, perinatal', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10390322, end_position_on_the_genomic_accession=10421950, orientation='minus', exon_count=40, OMIM=[160741], no_hdr0=''),
    4627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4627, CurrentID=0, Status='live', Symbol='MYH9', Aliases=['BDPLT6', 'DFNA17', 'EPSTS', 'FTNS', 'MATINS', 'MHA', 'NMHC-II-A', 'NMMHC-IIA', 'NMMHCA'], description='myosin heavy chain 9', other_designations='myosin-9|cellular myosin heavy chain, type A|myosin, heavy chain 9, non-muscle|non-muscle myosin heavy chain 9|non-muscle myosin heavy chain A|non-muscle myosin heavy chain IIa|non-muscle myosin heavy polypeptide 9|nonmuscle myosin heavy chain II-A', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36281280, end_position_on_the_genomic_accession=36387967, orientation='minus', exon_count=41, OMIM=[160775], no_hdr0=''),
    4628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4628, CurrentID=0, Status='live', Symbol='MYH10', Aliases=['NMMHC-IIB', 'NMMHCB'], description='myosin heavy chain 10', other_designations='myosin-10|myosin heavy chain, nonmuscle type B|myosin, heavy chain 10, non-muscle|myosin, heavy polypeptide 10, non-muscle|nonmuscle myosin II heavy chain-B|nonmuscle myosin heavy chain IIB', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8474212, end_position_on_the_genomic_accession=8631369, orientation='minus', exon_count=47, OMIM=[160776], no_hdr0=''),
    4629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4629, CurrentID=0, Status='live', Symbol='MYH11', Aliases=['AAT4', 'FAA4', 'SMHC', 'SMMHC', 'VSCM2'], description='myosin heavy chain 11', other_designations='myosin-11|epididymis secretory sperm binding protein|myosin, heavy chain 11, smooth muscle|myosin, heavy polypeptide 11, smooth muscle', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15703135, end_position_on_the_genomic_accession=15857032, orientation='minus', exon_count=43, OMIM=[160745], no_hdr0=''),
    4632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4632, CurrentID=0, Status='live', Symbol='MYL1', Aliases=['MLC1F', 'MLC3F', 'MYOFTA'], description='myosin light chain 1', other_designations='myosin light chain 1/3, skeletal muscle isoform|A1 catalytic|A2 catalytic|MLC1/MLC3|MLC1F/MLC3F|myosin light chain A1/A2|myosin light chain alkali 1/2|myosin, light chain 1, alkali; skeletal, fast|myosin, light polypeptide 1, alkali; skeletal, fast', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210290150, end_position_on_the_genomic_accession=210315174, orientation='minus', exon_count=9, OMIM=[160780], no_hdr0=''),
    4633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4633, CurrentID=0, Status='live', Symbol='MYL2', Aliases=['CMH10', 'MLC-2s/v', 'MLC2'], description='myosin light chain 2', other_designations='myosin regulatory light chain 2, ventricular/cardiac muscle isoform|MLC-2|MLC-2v|RLC of myosin|cardiac myosin light chain 2|cardiac ventricular myosin light chain 2|myosin, light chain 2, regulatory, cardiac, slow|myosin, light polypeptide 2, regulatory, cardiac, slow|regulatory light chain of myosin|slow cardiac myosin regulatory light chain 2|truncated myosin light chain 2|ventricular myosin light chain 2', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110910845, end_position_on_the_genomic_accession=110920579, orientation='minus', exon_count=7, OMIM=[160781], no_hdr0=''),
    4634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4634, CurrentID=0, Status='live', Symbol='MYL3', Aliases=['CMH8', 'MLC-lV/sb', 'MLC1SB', 'MLC1V', 'VLC1', 'VLCl'], description='myosin light chain 3', other_designations='myosin light chain 3|CMLC1|cardiac myosin light chain 1|myosin, light chain 3, alkali; ventricular, skeletal, slow|myosin, light polypeptide 3, alkali; ventricular, skeletal, slow|ventricular myosin alkali light chain|ventricular myosin light chain 1|ventricular/slow twitch myosin alkali light chain', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46857872, end_position_on_the_genomic_accession=46863444, orientation='minus', exon_count=7, OMIM=[160790], no_hdr0=''),
    4635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4635, CurrentID=0, Status='live', Symbol='MYL4', Aliases=['ALC1', 'AMLC', 'GT1', 'PRO1957'], description='myosin light chain 4', other_designations='myosin light chain 4|atrial myosin light chain 1|myosin, atrial/fetal muscle, light chain|myosin, light chain 4, alkali; atrial, embryonic|myosin, light polypeptide 4, alkali; atrial, embryonic', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47209017, end_position_on_the_genomic_accession=47227650, orientation='plus', exon_count=9, OMIM=[160770], no_hdr0=''),
    4636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4636, CurrentID=0, Status='live', Symbol='MYL5', Aliases=['MYLC2'], description='myosin light chain 5', other_designations='myosin light chain 5|myosin regulatory light chain 5|myosin, light chain 5, regulatory|myosin, light polypeptide 5, regulatory|superfast myosin regulatory light chain 2', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=674199, end_position_on_the_genomic_accession=682033, orientation='plus', exon_count=9, OMIM=[160782], no_hdr0=''),
    4637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4637, CurrentID=0, Status='live', Symbol='MYL6', Aliases=['ESMLC', 'LC17', 'LC17-GI', 'LC17-NM', 'LC17A', 'LC17B', 'MLC-3', 'MLC1SM', 'MLC3NM', 'MLC3SM'], description='myosin light chain 6', other_designations='myosin light polypeptide 6|17 kDa myosin light chain|myosin light chain A3|myosin light chain alkali 3|myosin, light chain 6, alkali, smooth muscle and non-muscle|myosin, light polypeptide 6, alkali, smooth muscle and non-muscle', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56158359, end_position_on_the_genomic_accession=56161579, orientation='plus', exon_count=7, OMIM=[609931], no_hdr0=''),
    4638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4638, CurrentID=0, Status='live', Symbol='MYLK', Aliases=['AAT7', 'KRP', 'MLCK', 'MLCK1', 'MLCK108', 'MLCK210', 'MMIHS', 'MMIHS1', 'MSTP0831', 'smMLCK', 'MYLK'], description='myosin light chain kinase', other_designations='myosin light chain kinase, smooth muscle|kinase-related protein|myosin, light polypeptide kinase|smooth muscle myosin light chain kinase|telokin', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123610049, end_position_on_the_genomic_accession=123884332, orientation='minus', exon_count=39, OMIM=[600922], no_hdr0=''),
    4640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4640, CurrentID=0, Status='live', Symbol='MYO1A', Aliases=['BBMI', 'DFNA48', 'MIHC', 'MYHL'], description='myosin IA', other_designations='unconventional myosin-Ia|brush border myosin I|myosin I heavy chain|myosin, heavy polypeptide-like (100kD)|myosin, heavy polypeptide-like 110kDa', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57028517, end_position_on_the_genomic_accession=57051198, orientation='minus', exon_count=30, OMIM=[601478], no_hdr0=''),
    4641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4641, CurrentID=0, Status='live', Symbol='MYO1C', Aliases=['MMI-beta', 'MMIb', 'NMI', 'myr2'], description='myosin IC', other_designations='unconventional myosin-Ic|myosin-I beta|myosin-Ic|nuclear myosin I', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1464186, end_position_on_the_genomic_accession=1492686, orientation='minus', exon_count=37, OMIM=[606538], no_hdr0=''),
    4642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4642, CurrentID=0, Status='live', Symbol='MYO1D', Aliases=['PPP1R108', 'myr4'], description='myosin ID', other_designations='unconventional myosin-Id|myosin-I gamma|protein phosphatase 1, regulatory subunit 108', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32492522, end_position_on_the_genomic_accession=32877172, orientation='minus', exon_count=27, OMIM=[606539], no_hdr0=''),
    4643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4643, CurrentID=0, Status='live', Symbol='MYO1E', Aliases=['FSGS6', 'HuncM-IC', 'MYO1C'], description='myosin IE', other_designations='unconventional myosin-Ie|MYO1E variant protein|myosin-IC|unconventional myosin 1E', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59132434, end_position_on_the_genomic_accession=59372871, orientation='minus', exon_count=28, OMIM=[601479], no_hdr0=''),
    4644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4644, CurrentID=0, Status='live', Symbol='MYO5A', Aliases=['GS1', 'MYH12', 'MYO5', 'MYR12'], description='myosin VA', other_designations='unconventional myosin-Va|dilute myosin heavy chain, non-muscle|myosin V|myosin VA (heavy chain 12, myoxin)|myosin, heavy polypeptide kinase|myosin-12|myosin-Va|myoxin', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52307283, end_position_on_the_genomic_accession=52529050, orientation='minus', exon_count=43, OMIM=[160777], no_hdr0=''),
    4645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4645, CurrentID=0, Status='live', Symbol='MYO5B', Aliases=[], description='myosin VB', other_designations='unconventional myosin-Vb|MYO5B variant protein|myosin-Vb', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49822789, end_position_on_the_genomic_accession=50195147, orientation='minus', exon_count=40, OMIM=[606540], no_hdr0=''),
    4646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4646, CurrentID=0, Status='live', Symbol='MYO6', Aliases=['DFNA22', 'DFNB37'], description='myosin VI', other_designations='unconventional myosin-VI|unconventional myosin-6', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75749203, end_position_on_the_genomic_accession=75919537, orientation='plus', exon_count=40, OMIM=[600970], no_hdr0=''),
    4647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4647, CurrentID=0, Status='live', Symbol='MYO7A', Aliases=['DFNA11', 'DFNB2', 'MYOVIIA', 'MYU7A', 'NSRD2', 'USH1B'], description='myosin VIIA', other_designations='unconventional myosin-VIIa|myosin VIIA (Usher syndrome 1B (autosomal recessive, severe))', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77128192, end_position_on_the_genomic_accession=77215241, orientation='plus', exon_count=56, OMIM=[276903], no_hdr0=''),
    4648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4648, CurrentID=0, Status='live', Symbol='MYO7B', Aliases=[], description='myosin VIIB', other_designations='unconventional myosin-VIIb', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127535683, end_position_on_the_genomic_accession=127637726, orientation='plus', exon_count=48, OMIM=[606541], no_hdr0=''),
    4649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4649, CurrentID=0, Status='live', Symbol='MYO9A', Aliases=['CMS24'], description='myosin IXA', other_designations='unconventional myosin-IXa|myosin-IXa|unconventional myosin-9a', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=71822291, end_position_on_the_genomic_accession=72118577, orientation='minus', exon_count=48, OMIM=[604875], no_hdr0=''),
    4650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4650, CurrentID=0, Status='live', Symbol='MYO9B', Aliases=['CELIAC4', 'MYR5'], description='myosin IXB', other_designations='unconventional myosin-IXb|myosin-IXb|unconventional myosin-9b', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17075777, end_position_on_the_genomic_accession=17213286, orientation='plus', exon_count=40, OMIM=[602129], no_hdr0=''),
    4651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4651, CurrentID=0, Status='live', Symbol='MYO10', Aliases=[], description='myosin X', other_designations='unconventional myosin-X|unconventional myosin-10|unconventionnal myosin-X', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=16661907, end_position_on_the_genomic_accession=16936288, orientation='minus', exon_count=44, OMIM=[601481], no_hdr0=''),
    4653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4653, CurrentID=0, Status='live', Symbol='MYOC', Aliases=['GLC1A', 'GPOA', 'JOAG', 'JOAG1', 'TIGR'], description='myocilin', other_designations='myocilin|juvenile-onset open-angle glaucoma 1|mutated trabecular meshwork-induced glucocorticoid response protein|myocilin 55 kDa subunit|myocilin trabecular meshwork inducible glucocorticoid response protein|trabecular meshwork inducible glucocorticoid response protein', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171635417, end_position_on_the_genomic_accession=171652688, orientation='minus', exon_count=3, OMIM=[601652], no_hdr0=''),
    4654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4654, CurrentID=0, Status='live', Symbol='MYOD1', Aliases=['MYF3', 'MYOD', 'MYODRIF', 'PUM', 'bHLHc1'], description='myogenic differentiation 1', other_designations='myoblast determination protein 1|class C basic helix-loop-helix protein 1|myf-3|myogenic factor 3', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17719571, end_position_on_the_genomic_accession=17722136, orientation='plus', exon_count=3, OMIM=[159970], no_hdr0=''),
    4656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4656, CurrentID=0, Status='live', Symbol='MYOG', Aliases=['MYF4', 'bHLHc3', 'myf-4'], description='myogenin', other_designations='myogenin|class C basic helix-loop-helix protein 3|myogenic factor 4', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203083129, end_position_on_the_genomic_accession=203086012, orientation='minus', exon_count=3, OMIM=[159980], no_hdr0=''),
    4659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4659, CurrentID=0, Status='live', Symbol='PPP1R12A', Aliases=['GUBS', 'M130', 'MBS', 'MYPT1'], description='protein phosphatase 1 regulatory subunit 12A', other_designations='protein phosphatase 1 regulatory subunit 12A|myosin binding subunit|myosin phosphatase, target subunit 1|myosin phosphatase-targeting subunit 1|protein phosphatase 1, regulatory (inhibitor) subunit 12A|protein phosphatase myosin-binding subunit', map_location='12q21.2-q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=79773563, end_position_on_the_genomic_accession=79935460, orientation='minus', exon_count=27, OMIM=[602021], no_hdr0=''),
    4660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4660, CurrentID=0, Status='live', Symbol='PPP1R12B', Aliases=['MYPT2', 'PP1bp55'], description='protein phosphatase 1 regulatory subunit 12B', other_designations='protein phosphatase 1 regulatory subunit 12B|myosin phosphatase target subunit 2|myosin phosphatase-targeting subunit 2|protein phosphatase 1, regulatory (inhibitor) subunit 12B', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202348699, end_position_on_the_genomic_accession=202592702, orientation='plus', exon_count=33, OMIM=[603768], no_hdr0=''),
    4661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4661, CurrentID=0, Status='live', Symbol='MYT1', Aliases=['C20orf36', 'MTF1', 'MYTI', 'NZF2', 'PLPB1', 'ZC2H2C1', 'ZC2HC4A'], description='myelin transcription factor 1', other_designations='myelin transcription factor 1|myelin transcription factor I|neural zinc finger transcription factor 2|proteolipid protein binding protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64164452, end_position_on_the_genomic_accession=64242253, orientation='plus', exon_count=23, OMIM=[600379], no_hdr0=''),
    4664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4664, CurrentID=0, Status='live', Symbol='NAB1', Aliases=[], description='NGFI-A binding protein 1', other_designations='NGFI-A-binding protein 1|EGR-1-binding protein 1|EGR1 binding protein 1|transcriptional regulatory protein p54', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190648860, end_position_on_the_genomic_accession=190692766, orientation='plus', exon_count=13, OMIM=[600800], no_hdr0=''),
    4665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4665, CurrentID=0, Status='live', Symbol='NAB2', Aliases=['MADER'], description='NGFI-A binding protein 2', other_designations='NGFI-A-binding protein 2|EGR1 binding protein 2|melanoma-associated delayed early response protein', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57089114, end_position_on_the_genomic_accession=57095476, orientation='plus', exon_count=7, OMIM=[602381], no_hdr0=''),
    4666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4666, CurrentID=0, Status='live', Symbol='NACA', Aliases=['HSD48', 'NAC-alpha1', 'skNAC', 'NACA'], description='nascent polypeptide associated complex subunit alpha', other_designations='nascent polypeptide-associated complex subunit alpha|alpha-NAC, muscle-specific form|nascent-polypeptide-associated complex alpha polypeptide', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56712427, end_position_on_the_genomic_accession=56725299, orientation='minus', exon_count=11, OMIM=[601234], no_hdr0=''),
    4668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4668, CurrentID=0, Status='live', Symbol='NAGA', Aliases=['D22S674', 'GALB'], description='alpha-N-acetylgalactosaminidase', other_designations='alpha-N-acetylgalactosaminidase|Acetylgalactosaminidase, alpha-N- (alpha-galactosidase B)|N-acetylgalactosaminidase, alpha-|alpha-galactosidase B', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42058334, end_position_on_the_genomic_accession=42070842, orientation='minus', exon_count=10, OMIM=[104170], no_hdr0=''),
    4669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4669, CurrentID=0, Status='live', Symbol='NAGLU', Aliases=['CMT2V', 'MPS-IIIB', 'MPS3B', 'NAG', 'UFHSD'], description='N-acetyl-alpha-glucosaminidase', other_designations='alpha-N-acetylglucosaminidase|N-acetylglucosaminidase, alpha|testicular tissue protein Li 18', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42534238, end_position_on_the_genomic_accession=42544449, orientation='plus', exon_count=7, OMIM=[609701], no_hdr0=''),
    4670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4670, CurrentID=0, Status='live', Symbol='HNRNPM', Aliases=['CEAR4', 'HNRPM', 'HNRPM4', 'HTGR1', 'NAGR1', 'hnRNP M', 'HNRNPM'], description='heterogeneous nuclear ribonucleoprotein M', other_designations='heterogeneous nuclear ribonucleoprotein M|CEA receptor|N-acetylglucosamine receptor 1|heterogenous nuclear ribonucleoprotein M4|hnRNA-binding protein M4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8444575, end_position_on_the_genomic_accession=8489114, orientation='plus', exon_count=16, OMIM=[160994], no_hdr0=''),
    4671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4671, CurrentID=0, Status='live', Symbol='NAIP', Aliases=['BIRC1', 'NLRB1', 'psiNAIP'], description='NLR family apoptosis inhibitory protein', other_designations='baculoviral IAP repeat-containing protein 1|neuronal apoptosis inhibitory protein|nucleotide-binding oligomerization domain, leucine rich repeat and BIR domain containing 1|psi neuronal apoptosis inhibitory protein', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=70968166, end_position_on_the_genomic_accession=71025339, orientation='minus', exon_count=19, OMIM=[600355], no_hdr0=''),
    4673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4673, CurrentID=0, Status='live', Symbol='NAP1L1', Aliases=['NAP1', 'NAP1L', 'NRP'], description='nucleosome assembly protein 1 like 1', other_designations='nucleosome assembly protein 1-like 1|HSP22-like protein interacting protein|NAP-1-related protein', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76036585, end_position_on_the_genomic_accession=76084687, orientation='minus', exon_count=17, OMIM=[164060], no_hdr0=''),
    4674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4674, CurrentID=0, Status='live', Symbol='NAP1L2', Aliases=['BPX'], description='nucleosome assembly protein 1 like 2', other_designations='nucleosome assembly protein 1-like 2|brain specific gene BPX|brain-specific protein, X-linked', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=73212299, end_position_on_the_genomic_accession=73214851, orientation='minus', exon_count=1, OMIM=[300026], no_hdr0=''),
    4675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4675, CurrentID=0, Status='live', Symbol='NAP1L3', Aliases=['MB20', 'NPL3'], description='nucleosome assembly protein 1 like 3', other_designations='nucleosome assembly protein 1-like 3', map_location='Xq21.32', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=93670930, end_position_on_the_genomic_accession=93673578, orientation='minus', exon_count=1, OMIM=[300117], no_hdr0=''),
    4676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4676, CurrentID=0, Status='live', Symbol='NAP1L4', Aliases=['NAP1L4b', 'NAP2', 'NAP2L', 'hNAP2'], description='nucleosome assembly protein 1 like 4', other_designations='nucleosome assembly protein 1-like 4|NAP-2|nucleosome assembly protein 1-like 4b|nucleosome assembly protein 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2944437, end_position_on_the_genomic_accession=2992329, orientation='minus', exon_count=21, OMIM=[601651], no_hdr0=''),
    4677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4677, CurrentID=0, Status='live', Symbol='NARS1', Aliases=['ASNRS', 'NARS', 'NEDMILEG', 'NEDMILG'], description='asparaginyl-tRNA synthetase 1', other_designations='asparagine--tRNA ligase, cytoplasmic|asparagine tRNA ligase 1, cytoplasmic|asparaginyl-tRNA synthetase, cytoplasmic', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57600656, end_position_on_the_genomic_accession=57621836, orientation='minus', exon_count=14, OMIM=[108410], no_hdr0=''),
    4678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4678, CurrentID=0, Status='live', Symbol='NASP', Aliases=['FLB7527', 'HMDRA1', 'PRO1999'], description='nuclear autoantigenic sperm protein', other_designations='nuclear autoantigenic sperm protein|NASP histone chaperone|histone H1-binding protein|nuclear autoantigenic sperm protein (histone-binding)', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45584041, end_position_on_the_genomic_accession=45618893, orientation='plus', exon_count=16, OMIM=[603185], no_hdr0=''),
    4680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4680, CurrentID=0, Status='live', Symbol='CEACAM6', Aliases=['CD66c', 'CEAL', 'NCA'], description='CEA cell adhesion molecule 6', other_designations='carcinoembryonic antigen-related cell adhesion molecule 6|Cluster of Differentiation 66c|carcinoembryonic antigen related cell adhesion molecule 6|carcinoembryonic antigen-related cell adhesion molecule 6 (non-specific cross reacting antigen)|normal cross-reacting antigen', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41755529, end_position_on_the_genomic_accession=41772211, orientation='plus', exon_count=6, OMIM=[163980], no_hdr0=''),
    4681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4681, CurrentID=0, Status='live', Symbol='NBL1', Aliases=['D1S1733E', 'DAN', 'DAND1', 'NB', 'NO3'], description='NBL1, DAN family BMP antagonist', other_designations='neuroblastoma suppressor of tumorigenicity 1|DAN domain family member 1|differential screening-selected gene aberrant in neuroblastoma|neuroblastoma 1, DAN family BMP antagonist|neuroblastoma candidate region, suppression of tumorigenicity 1', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19643229, end_position_on_the_genomic_accession=19658452, orientation='plus', exon_count=10, OMIM=[600613], no_hdr0=''),
    4682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4682, CurrentID=0, Status='live', Symbol='NUBP1', Aliases=['CIAO5', 'NBP', 'NBP1', 'NBP35'], description='nucleotide binding protein 1', other_designations='cytosolic Fe-S cluster assembly factor NUBP1|NBP 1|nucleotide binding protein (e.coli MinD like)|nucleotide binding protein 1 (E.coli MinD like)|nucleotide binding protein 1 (MinD homolog, E. coli)', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10743164, end_position_on_the_genomic_accession=10769351, orientation='plus', exon_count=11, OMIM=[600280], no_hdr0=''),
    4683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4683, CurrentID=0, Status='live', Symbol='NBN', Aliases=['AT-V1', 'AT-V2', 'ATV', 'NBS', 'NBS1', 'P95'], description='nibrin', other_designations='nibrin|Nijmegen breakage syndrome 1 (nibrin)|cell cycle regulatory protein p95|p95 protein of the MRE11/RAD50 complex', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=89933331, end_position_on_the_genomic_accession=89984698, orientation='minus', exon_count=20, OMIM=[602667], no_hdr0=''),
    4684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4684, CurrentID=0, Status='live', Symbol='NCAM1', Aliases=['CD56', 'MSK39', 'NCAM'], description='neural cell adhesion molecule 1', other_designations='neural cell adhesion molecule 1|antigen recognized by monoclonal antibody 5.1H11|neural cell adhesion molecule, NCAM', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112961420, end_position_on_the_genomic_accession=113278436, orientation='plus', exon_count=25, OMIM=[116930], no_hdr0=''),
    4685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4685, CurrentID=0, Status='live', Symbol='NCAM2', Aliases=['NCAM21'], description='neural cell adhesion molecule 2', other_designations='neural cell adhesion molecule 2|N-CAM-2|NCAM-2', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=20998339, end_position_on_the_genomic_accession=21543329, orientation='plus', exon_count=26, OMIM=[602040], no_hdr0=''),
    4686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4686, CurrentID=0, Status='live', Symbol='NCBP1', Aliases=['CBP80', 'NCBP', 'Sto1'], description='nuclear cap binding protein subunit 1', other_designations='nuclear cap-binding protein subunit 1|80 kDa nuclear cap-binding protein|NCBP 80 kDa subunit|nuclear cap binding protein subunit 1, 80kDa', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97633821, end_position_on_the_genomic_accession=97673748, orientation='plus', exon_count=23, OMIM=[600469], no_hdr0=''),
    4688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4688, CurrentID=0, Status='live', Symbol='NCF2', Aliases=['NCF-2', 'NOXA2', 'P67-PHOX', 'P67PHOX'], description='neutrophil cytosolic factor 2', other_designations='neutrophil cytosol factor 2|67 kDa neutrophil oxidase factor|NADPH oxidase activator 2|chronic granulomatous disease, autosomal 2|neutrophil NADPH oxidase factor 2|neutrophil cytosolic factor 2 (65kD, chronic granulomatous disease, autosomal 2)', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183555562, end_position_on_the_genomic_accession=183590914, orientation='minus', exon_count=18, OMIM=[608515], no_hdr0=''),
    4689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4689, CurrentID=0, Status='live', Symbol='NCF4', Aliases=['CGD3', 'NCF', 'P40PHOX', 'SH3PXD4'], description='neutrophil cytosolic factor 4', other_designations='neutrophil cytosol factor 4|NCF-4|SH3 and PX domain-containing protein 4|neutrophil NADPH oxidase factor 4|neutrophil cytosolic factor 4, 40kDa|p40-phox', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36861006, end_position_on_the_genomic_accession=36878015, orientation='plus', exon_count=10, OMIM=[601488], no_hdr0=''),
    4690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4690, CurrentID=0, Status='live', Symbol='NCK1', Aliases=['NCK', 'NCKalpha', 'nck-1'], description='NCK adaptor protein 1', other_designations='cytoplasmic protein NCK1|NCK tyrosine kinase|SH2/SH3 adaptor protein NCK-alpha|melanoma NCK protein|non-catalytic region of tyrosine kinase', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136862208, end_position_on_the_genomic_accession=136951606, orientation='plus', exon_count=6, OMIM=[600508], no_hdr0=''),
    4691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4691, CurrentID=0, Status='live', Symbol='NCL', Aliases=['C23', 'Nsr1'], description='nucleolin', other_designations='nucleolin', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231453531, end_position_on_the_genomic_accession=231464484, orientation='minus', exon_count=14, OMIM=[164035], no_hdr0=''),
    4692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4692, CurrentID=0, Status='live', Symbol='NDN', Aliases=['HsT16328', 'PWCR'], description='necdin, MAGE family member', other_designations='necdin|Prader-Willi syndrome chromosome region|necdin homolog|necdin, melanoma antigen (MAGE) family member|necdin-like protein', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23685400, end_position_on_the_genomic_accession=23687305, orientation='minus', exon_count=1, OMIM=[602117], no_hdr0=''),
    4693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4693, CurrentID=0, Status='live', Symbol='NDP', Aliases=['EVR2', 'FEVR', 'ND'], description='norrin cystine knot growth factor NDP', other_designations='norrin|NDP, norrin cystine knot growth factor|Norrie disease (pseudoglioma)|X-linked exudative vitreoretinopathy 2 protein|norrie disease protein', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=43948776, end_position_on_the_genomic_accession=43973390, orientation='minus', exon_count=3, OMIM=[300658], no_hdr0=''),
    4694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4694, CurrentID=0, Status='live', Symbol='NDUFA1', Aliases=['CI-MWFE', 'MC1DN12', 'MWFE', 'ZNF183'], description='NADH:ubiquinone oxidoreductase subunit A1', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 1|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 1, 7.5kDa|NADH-ubiquinone oxidoreductase MWFE subunit|NADH:ubiquinone oxidoreductase (complex 1)|complex I MWFE subunit|type I dehydrogenase', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119871832, end_position_on_the_genomic_accession=119876662, orientation='plus', exon_count=3, OMIM=[300078], no_hdr0=''),
    4695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4695, CurrentID=0, Status='live', Symbol='NDUFA2', Aliases=['B8', 'CD14', 'CIB8', 'MC1DN13'], description='NADH:ubiquinone oxidoreductase subunit A2', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 2|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 2, 8kDa|NADH-ubiquinone oxidoreductase subunit CI-B8|complex I B8 subunit', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140645285, end_position_on_the_genomic_accession=140647630, orientation='minus', exon_count=2, OMIM=[602137], no_hdr0=''),
    4696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4696, CurrentID=0, Status='live', Symbol='NDUFA3', Aliases=['B9', 'CI-B9'], description='NADH:ubiquinone oxidoreductase subunit A3', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 3|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 3, 9kDa|NADH-ubiquinone oxidoreductase B9 subunit|complex I B9 subunit|complex I-B9', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54102338, end_position_on_the_genomic_accession=54107568, orientation='plus', exon_count=5, OMIM=[603832], no_hdr0=''),
    4697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4697, CurrentID=0, Status='live', Symbol='NDUFA4', Aliases=['CI-9k', 'CI-MLRQ', 'COXFA4', 'MC4DN21', 'MISTR1', 'MLRQ', 'MRCAF1'], description='NDUFA4 mitochondrial complex associated', other_designations='cytochrome c oxidase subunit NDUFA4|Complex I 9kDa subunit|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 4, 9kDa|NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 4|NADH-ubiquinone oxidoreductase MLRQ subunit|complex I-MLRQ|cytochrome c oxidase subunit FA4|mitochondrial respiratory chain associated factor 1|mitochondrial stress response 1', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=10931943, end_position_on_the_genomic_accession=10940153, orientation='minus', exon_count=4, OMIM=[603833], no_hdr0=''),
    4698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4698, CurrentID=0, Status='live', Symbol='NDUFA5', Aliases=['B13', 'CI-13KD-B', 'CI-13kB', 'NUFM', 'UQOR13'], description='NADH:ubiquinone oxidoreductase subunit A5', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 5|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 5, 13kDa|NADH-ubiquinone oxidoreductase 13 kDa-B subunit|complex I 13kDa subunit B|complex I subunit B13|type I dehydrogenase|ubiquinone reductase', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123536997, end_position_on_the_genomic_accession=123601651, orientation='minus', exon_count=12, OMIM=[601677], no_hdr0=''),
    4700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4700, CurrentID=0, Status='live', Symbol='NDUFA6', Aliases=['B14', 'CI-B14', 'LYRM6', 'MC1DN33', 'NADHB14'], description='NADH:ubiquinone oxidoreductase subunit A6', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 6|Complex I-B14|LYR motif-containing protein 6|NADH-ubiquinone oxidoreductase 1 alpha subcomplex, 6|NADH-ubiquinone oxidoreductase B14 subunit', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42085526, end_position_on_the_genomic_accession=42090772, orientation='minus', exon_count=3, OMIM=[602138], no_hdr0=''),
    4701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4701, CurrentID=0, Status='live', Symbol='NDUFA7', Aliases=['B14.5a', 'CI-B14.5a'], description='NADH:ubiquinone oxidoreductase subunit A7', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 7|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 7, 14.5kDa|NADH-ubiquinone oxidoreductase subunit B14.5a|complex I B14.5a subunit', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8308595, end_position_on_the_genomic_accession=8321375, orientation='minus', exon_count=5, OMIM=[602139], no_hdr0=''),
    4702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4702, CurrentID=0, Status='live', Symbol='NDUFA8', Aliases=['CI-19KD', 'CI-PGIV', 'MC1DN37', 'PGIV'], description='NADH:ubiquinone oxidoreductase subunit A8', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 8|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 8, 19kDa|NADH-ubiquinone oxidoreductase 19 kDa subunit|NADH:ubiquinone oxidoreductase PGIV subunit|complex I-19kD|complex I-PGIV', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122132466, end_position_on_the_genomic_accession=122159779, orientation='minus', exon_count=5, OMIM=[603359], no_hdr0=''),
    4703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4703, CurrentID=0, Status='live', Symbol='NEB', Aliases=['AMC6177D', 'NEM2', 'NEB'], description='nebulin', other_designations='nebulin|nemaline myopathy type 2', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151485334, end_position_on_the_genomic_accession=151734476, orientation='minus', exon_count=183, OMIM=[161650], no_hdr0=''),
    4704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4704, CurrentID=0, Status='live', Symbol='NDUFA9', Aliases=['CC6', 'CI-39k', 'CI39k', 'COQ11', 'MC1DN26', 'NDUFS2L', 'SDR22E1'], description='NADH:ubiquinone oxidoreductase subunit A9', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 9, mitochondrial|CI-39kD|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 9, 39kDa|NADH dehydrogenase (ubiquinone) Fe-S protein 2-like (NADH-coenzyme Q reductase)|NADH-ubiquinone oxidoreductase 39 kDa subunit|complex I 39kDa subunit|short chain dehydrogenase/reductase family 22E, member 1', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4649114, end_position_on_the_genomic_accession=4694317, orientation='plus', exon_count=11, OMIM=[603834], no_hdr0=''),
    4705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4705, CurrentID=0, Status='live', Symbol='NDUFA10', Aliases=['CI-42KD', 'CI-42k', 'MC1DN22'], description='NADH:ubiquinone oxidoreductase subunit A10', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 10, mitochondrial|NADH-ubiquinone oxidoreductase 42 kDa subunit|complex I 42kDa subunit', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=239892442, end_position_on_the_genomic_accession=240025343, orientation='minus', exon_count=16, OMIM=[603835], no_hdr0=''),
    4706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4706, CurrentID=0, Status='live', Symbol='NDUFAB1', Aliases=['ACP', 'ACP1', 'FASN2A', 'SDAP'], description='NADH:ubiquinone oxidoreductase subunit AB1', other_designations='acyl carrier protein, mitochondrial|CI-SDAP|NADH dehydrogenase (ubiquinone) 1, alpha/beta subcomplex, 1, 8kDa|NADH-ubiquinone oxidoreductase 9.6 kDa subunit|NADH:ubiquinone oxidoreductase SDAP subunit|complex I SDAP subunit|mitochondrial acyl carrier protein', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23581012, end_position_on_the_genomic_accession=23596329, orientation='minus', exon_count=6, OMIM=[603836], no_hdr0=''),
    4707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4707, CurrentID=0, Status='live', Symbol='NDUFB1', Aliases=['CI-MNLL', 'CI-SGDH', 'MNLL'], description='NADH:ubiquinone oxidoreductase subunit B1', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 1|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 1, 7kDa|NADH-ubiquinone oxidoreductase MNLL subunit|complex I MNLL subunit|complex I-MNLL', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92116123, end_position_on_the_genomic_accession=92121706, orientation='minus', exon_count=3, OMIM=[603837], no_hdr0=''),
    4708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4708, CurrentID=0, Status='live', Symbol='NDUFB2', Aliases=['AGGG', 'CI-AGGG'], description='NADH:ubiquinone oxidoreductase subunit B2', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 2, mitochondrial|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 2, 8kDa|NADH-ubiquinone oxidoreductase AGGG subunit|complex I AGGG subunit|complex I-AGGG', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140696708, end_position_on_the_genomic_accession=140706643, orientation='plus', exon_count=4, OMIM=[603838], no_hdr0=''),
    4709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4709, CurrentID=0, Status='live', Symbol='NDUFB3', Aliases=['B12', 'CI-B12', 'MC1DN25'], description='NADH:ubiquinone oxidoreductase subunit B3', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 3|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 3, 12kDa|NADH-ubiquinone oxidoreductase B12 subunit|complex I-B12', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201071784, end_position_on_the_genomic_accession=201085750, orientation='plus', exon_count=4, OMIM=[603839], no_hdr0=''),
    4710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4710, CurrentID=0, Status='live', Symbol='NDUFB4', Aliases=['B15', 'CI-B15'], description='NADH:ubiquinone oxidoreductase subunit B4', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 4|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 4, 15kDa|NADH-ubiquinone oxidoreductase B15 subunit|complex I B15 subunit|complex I-B15', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120596336, end_position_on_the_genomic_accession=120602507, orientation='plus', exon_count=2, OMIM=[603840], no_hdr0=''),
    4711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4711, CurrentID=0, Status='live', Symbol='NDUFB5', Aliases=['CISGDH', 'SGDH'], description='NADH:ubiquinone oxidoreductase subunit B5', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 5, mitochondrial|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 5, 16kDa|NADH-ubiquinone oxidoreductase SGDH subunit|complex I SGDH subunit|complex I-SGDH', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179604794, end_position_on_the_genomic_accession=179627647, orientation='plus', exon_count=6, OMIM=[603841], no_hdr0=''),
    4712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4712, CurrentID=0, Status='live', Symbol='NDUFB6', Aliases=['B17', 'CI'], description='NADH:ubiquinone oxidoreductase subunit B6', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 6|CI-B17|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 6, 17kDa|NADH-ubiquinone oxidoreductase B17 subunit|NADH-ubiquinone oxidoreductase beta subunit, 6|complex I, mitochondrial respiratory chain, B17 subunit|complex I-B17', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32553001, end_position_on_the_genomic_accession=32573159, orientation='minus', exon_count=4, OMIM=[603322], no_hdr0=''),
    4713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4713, CurrentID=0, Status='live', Symbol='NDUFB7', Aliases=['B18', 'CI-B18'], description='NADH:ubiquinone oxidoreductase subunit B7', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 7|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 7, 18kDa|NADH-ubiquinone oxidoreductase B18 subunit|cell adhesion protein SQM1|complex I B18 subunit|complex I-B18', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14566078, end_position_on_the_genomic_accession=14572066, orientation='minus', exon_count=4, OMIM=[603842], no_hdr0=''),
    4714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4714, CurrentID=0, Status='live', Symbol='NDUFB8', Aliases=['ASHI', 'CI-ASHI', 'MC1DN32'], description='NADH:ubiquinone oxidoreductase subunit B8', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 8, mitochondrial|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 8, 19kDa|NADH:ubiquinone oxidoreductase ASHI subunit|complex I ASHI subunit|complex I-ASHI', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100523729, end_position_on_the_genomic_accession=100529923, orientation='minus', exon_count=5, OMIM=[602140], no_hdr0=''),
    4715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4715, CurrentID=0, Status='live', Symbol='NDUFB9', Aliases=['B22', 'CI-B22', 'LYRM3', 'MC1DN24', 'UQOR22'], description='NADH:ubiquinone oxidoreductase subunit B9', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 9|LYR motif-containing protein 3|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 9, 22kDa|NADH-ubiquinone oxidoreductase B22 subunit|complex I B22 subunit', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124539123, end_position_on_the_genomic_accession=124549979, orientation='plus', exon_count=4, OMIM=[601445], no_hdr0=''),
    4716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4716, CurrentID=0, Status='live', Symbol='NDUFB10', Aliases=['MC1DN35', 'PDSW'], description='NADH:ubiquinone oxidoreductase subunit B10', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 10|CI-PDSW|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 10, 22kDa|NADH ubiquinone oxidoreductase PDSW subunit (RH 16p13.3)|NADH-ubiquinone oxidoreductase PDSW subunit|complex I PDSW subunit|complex I-PDSW', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1959538, end_position_on_the_genomic_accession=1961975, orientation='plus', exon_count=4, OMIM=[603843], no_hdr0=''),
    4717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4717, CurrentID=0, Status='live', Symbol='NDUFC1', Aliases=['KFYI'], description='NADH:ubiquinone oxidoreductase subunit C1', other_designations='NADH dehydrogenase [ubiquinone] 1 subunit C1, mitochondrial|CI-KFYI|NADH dehydrogenase (ubiquinone) 1, subcomplex unknown, 1, 6kDa|NADH-ubiquinone oxidoreductase KFYI subunit|complex I KFYI subunit|complex I-KFYI', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139289917, end_position_on_the_genomic_accession=139302551, orientation='minus', exon_count=8, OMIM=[603844], no_hdr0=''),
    4718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4718, CurrentID=0, Status='live', Symbol='NDUFC2', Aliases=['B14.5b', 'CI-B14.5b', 'HLC-1', 'MC1DN36', 'NADHDH2'], description='NADH:ubiquinone oxidoreductase subunit C2', other_designations='NADH dehydrogenase [ubiquinone] 1 subunit C2|NADH dehydrogenase (ubiquinone) 1, subcomplex unknown, 2, 14.5kDa|NADH-ubiquinone oxidoreductase subunit B14.5b|complex I subunit B14.5b|complex I-B14.5b|human lung cancer oncogene 1 protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78068297, end_position_on_the_genomic_accession=78079862, orientation='minus', exon_count=4, OMIM=[603845], no_hdr0=''),
    4719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4719, CurrentID=0, Status='live', Symbol='NDUFS1', Aliases=['CI-75Kd', 'CI-75k', 'MC1DN5', 'PRO1304'], description='NADH:ubiquinone oxidoreductase core subunit S1', other_designations='NADH-ubiquinone oxidoreductase 75 kDa subunit, mitochondrial|NADH dehydrogenase (ubiquinone) Fe-S protein 1, 75kDa (NADH-coenzyme Q reductase)|complex I 75kDa subunit|complex I, mitochondrial respiratory chain, 75-kD subunit|mitochondrial NADH-ubiquinone oxidoreductase 75 kDa subunit', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206114817, end_position_on_the_genomic_accession=206159444, orientation='minus', exon_count=20, OMIM=[157655], no_hdr0=''),
    4720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4720, CurrentID=0, Status='live', Symbol='NDUFS2', Aliases=['CI-49', 'MC1DN6'], description='NADH:ubiquinone oxidoreductase core subunit S2', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 2, mitochondrial|CI-49kD|NADH dehydrogenase (ubiquinone) Fe-S protein 2, 49kDa (NADH-coenzyme Q reductase)|NADH-ubiquinone oxidoreductase 49 kDa subunit|NADH-ubiquinone oxidoreductase NDUFS2 subunit|complex 1, mitochondrial respiratory chain, 49-KD subunit|complex I 49kDa subunit', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161197417, end_position_on_the_genomic_accession=161214395, orientation='plus', exon_count=15, OMIM=[602985], no_hdr0=''),
    4722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4722, CurrentID=0, Status='live', Symbol='NDUFS3', Aliases=['CI-30', 'MC1DN8'], description='NADH:ubiquinone oxidoreductase core subunit S3', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 3, mitochondrial|CI-30kD|NADH dehydrogenase (ubiquinone) Fe-S protein 3, 30kDa (NADH-coenzyme Q reductase)|NADH dehydrogenase-ubiquinone 30 kDa subunit|NADH-ubiquinone oxidoreductase 30 kDa subunit|complex I 30kDa subunit|complex I-30kD', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47579074, end_position_on_the_genomic_accession=47584562, orientation='plus', exon_count=7, OMIM=[603846], no_hdr0=''),
    4723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4723, CurrentID=0, Status='live', Symbol='NDUFV1', Aliases=['CI-51K', 'CI51KD', 'MC1DN4', 'UQOR1'], description='NADH:ubiquinone oxidoreductase core subunit V1', other_designations='NADH dehydrogenase [ubiquinone] flavoprotein 1, mitochondrial|NADH dehydrogenase (ubiquinone) flavoprotein 1, 51kDa|NADH-ubiquinone oxidoreductase 51 kDa subunit|complex I 51 kda subunit|complex I 51kDa subunit|complex I, mitochondrial respiratory chain|mitochondrial NADH dehydrogenase ubiquinone flavoprotein 1|mitochondrial NADH:ubiquinone oxidoreductase 51 kda subunit', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67606936, end_position_on_the_genomic_accession=67612554, orientation='plus', exon_count=10, OMIM=[161015], no_hdr0=''),
    4724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4724, CurrentID=0, Status='live', Symbol='NDUFS4', Aliases=['AQDQ', 'CI-18', 'CI-18 kDa', 'CI-AQDQ', 'MC1DN1'], description='NADH:ubiquinone oxidoreductase subunit S4', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 4, mitochondrial|NADH dehydrogenase (ubiquinone) Fe-S protein 4, 18kDa (NADH-coenzyme Q reductase)|NADH-ubiquinone oxidoreductase 18 kDa subunit|complex I 18kDa subunit|complex I-AQDQ|mitochondrial respiratory chain complex I (18-KD subunit)', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=53560610, end_position_on_the_genomic_accession=53683338, orientation='plus', exon_count=8, OMIM=[602694], no_hdr0=''),
    4725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4725, CurrentID=0, Status='live', Symbol='NDUFS5', Aliases=['CI-15k', 'CI15K'], description='NADH:ubiquinone oxidoreductase subunit S5', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 5|CI-15 kDa|NADH dehydrogenase (ubiquinone) Fe-S protein 5, 15kDa (NADH-coenzyme Q reductase)|NADH:ubiquinone oxidoreductase 15 kDa IP subunit|complex I-15 kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39026350, end_position_on_the_genomic_accession=39034615, orientation='plus', exon_count=3, OMIM=[603847], no_hdr0=''),
    4726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4726, CurrentID=0, Status='live', Symbol='NDUFS6', Aliases=['CI-13kA', 'CI-13kD-A', 'CI13KDA', 'MC1DN9'], description='NADH:ubiquinone oxidoreductase subunit S6', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 6, mitochondrial|NADH dehydrogenase (ubiquinone) Fe-S protein 6, 13kDa (NADH-coenzyme Q reductase)|NADH-ubiquinone oxidoreductase 13 kDa-A subunit|NADH:ubiquinone oxidoreductase NDUFS6 subunit|complex I 13kDa subunit A|complex I, mitochondrial respiratory chain, 13-kD subunit', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1801407, end_position_on_the_genomic_accession=1816048, orientation='plus', exon_count=4, OMIM=[603848], no_hdr0=''),
    4728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4728, CurrentID=0, Status='live', Symbol='NDUFS8', Aliases=['CI-23k', 'CI23KD', 'MC1DN2', 'TYKY'], description='NADH:ubiquinone oxidoreductase core subunit S8', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 8, mitochondrial|NADH dehydrogenase (ubiquinone) Fe-S protein 8, 23kDa (NADH-coenzyme Q reductase)|NADH-ubiquinone oxidoreductase 23 kDa subunit|complex I 23kDa subunit|complex I-23kD', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68030681, end_position_on_the_genomic_accession=68036644, orientation='plus', exon_count=7, OMIM=[602141], no_hdr0=''),
    4729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4729, CurrentID=0, Status='live', Symbol='NDUFV2', Aliases=['CI-24k', 'MC1DN7'], description='NADH:ubiquinone oxidoreductase core subunit V2', other_designations='NADH dehydrogenase [ubiquinone] flavoprotein 2, mitochondrial|NADH dehydrogenase (ubiquinone) flavoprotein 2, 24kDa|NADH dehydrogenase ubiquinone flavoprotein 2, mitochondrial|NADH-ubiquinone oxidoreductase 24 kDa subunit|NADH-ubiquinone oxidoreductase flavoprotein 2|complex I 24kDa subunit|complex I, mitochondrial respitory chain, 24 kD subunit|nuclear-encoded mitochondrial NADH-ubiquinone reductase 24Kd subunit', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9102642, end_position_on_the_genomic_accession=9134341, orientation='plus', exon_count=8, OMIM=[600532], no_hdr0=''),
    4731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4731, CurrentID=0, Status='live', Symbol='NDUFV3', Aliases=['CI-10k', 'CI-9KD'], description='NADH:ubiquinone oxidoreductase subunit V3', other_designations='NADH dehydrogenase [ubiquinone] flavoprotein 3, mitochondrial|NADH dehydrogenase (ubiquinone) flavoprotein 3, 10kDa|NADH-ubiquinone oxidoreductase 9 kD subunit|NADH-ubiquinone oxidoreductase 9 kDa subunit|NADH-ubiquinone oxidoreductase flavoprotein 3, 10kD|complex I 10kDa subunit|complex I, mitochondrial respiratory chain, 10-kD subunit|complex I-9kD|mitochondrial NADH oxidoreductase-like protein|renal carcinoma antigen NY-REN-4', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42893271, end_position_on_the_genomic_accession=42913299, orientation='plus', exon_count=5, OMIM=[602184], no_hdr0=''),
    4733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4733, CurrentID=0, Status='live', Symbol='DRG1', Aliases=['NEDD3'], description='developmentally regulated GTP binding protein 1', other_designations='developmentally-regulated GTP-binding protein 1|DRG-1|NEDD-3|TRAFAC GTPase DRG1|neural precursor cell expressed developmentally down-regulated protein 3|neural precursor cell expressed, developmentally down-regulated 3|translation factor GTPase DRG1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31399604, end_position_on_the_genomic_accession=31434452, orientation='plus', exon_count=9, OMIM=[603952], no_hdr0=''),
    4734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4734, CurrentID=0, Status='live', Symbol='NEDD4', Aliases=['NEDD4-1', 'RPF1'], description='NEDD4 E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase NEDD4|HECT-type E3 ubiquitin transferase NEDD4|cell proliferation-inducing gene 53 protein|neural precursor cell expressed, developmentally down-regulated 4, E3 ubiquitin protein ligase|receptor-potentiating factor 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55826917, end_position_on_the_genomic_accession=55993612, orientation='minus', exon_count=33, OMIM=[602278], no_hdr0=''),
    4735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4735, CurrentID=0, Status='live', Symbol='SEPTIN2', Aliases=['DIFF6', 'NEDD-5', 'NEDD5', 'Pnutl3', 'SEPT2', 'hNedd5'], description='septin 2', other_designations='septin-2|epididymis secretory sperm binding protein|neural precursor cell expressed, developmentally down-regulated 5', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241315270, end_position_on_the_genomic_accession=241354027, orientation='plus', exon_count=21, OMIM=[601506], no_hdr0=''),
    4736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4736, CurrentID=0, Status='live', Symbol='RPL10A', Aliases=['CSA19', 'Csa-19', 'L10A', 'NEDD6'], description='ribosomal protein L10a', other_designations='60S ribosomal protein L10a|NEDD-6|large ribosomal subunit protein uL1|neural precursor cell expressed developmentally down-regulated protein 6', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35468401, end_position_on_the_genomic_accession=35470781, orientation='plus', exon_count=6, OMIM=[615660], no_hdr0=''),
    4738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4738, CurrentID=0, Status='live', Symbol='NEDD8', Aliases=['NEDD-8'], description='NEDD8 ubiquitin like modifier', other_designations='NEDD8|neddylin|neural precursor cell expressed, developmentally down-regulated 8|ubiquitin-like protein Nedd8', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24216857, end_position_on_the_genomic_accession=24232367, orientation='minus', exon_count=4, OMIM=[603171], no_hdr0=''),
    4739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4739, CurrentID=0, Status='live', Symbol='NEDD9', Aliases=['CAS-L', 'CAS2', 'CASL', 'CASS2', 'HEF1'], description='neural precursor cell expressed, developmentally down-regulated 9', other_designations='enhancer of filamentation 1|Cas scaffolding protein family member 2|Crk-associated substrate related protein Cas-L|Enhancer of filamentation 1 p55|cas-like docking|neural precursor cell expressed developmentally down-regulated protein 9|p130Cas-related protein|renal carcinoma antigen NY-REN-12', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=11183298, end_position_on_the_genomic_accession=11382348, orientation='minus', exon_count=11, OMIM=[602265], no_hdr0=''),
    4741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4741, CurrentID=0, Status='live', Symbol='NEFM', Aliases=['NEF3', 'NF-M', 'NFM'], description='neurofilament medium chain', other_designations='neurofilament medium polypeptide|160 kDa neurofilament protein|neurofilament 3|neurofilament triplet M protein|neurofilament, medium polypeptide 150kDa|neurofilament-3 (150 kD medium)', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=24913761, end_position_on_the_genomic_accession=24919093, orientation='plus', exon_count=4, OMIM=[162250], no_hdr0=''),
    4744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4744, CurrentID=0, Status='live', Symbol='NEFH', Aliases=['CMT2CC', 'NFH'], description='neurofilament heavy chain', other_designations='neurofilament heavy polypeptide|200 kDa neurofilament protein|NF-H|neurofilament triplet H protein|neurofilament, heavy polypeptide 200kDa', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29480218, end_position_on_the_genomic_accession=29491390, orientation='plus', exon_count=4, OMIM=[162230], no_hdr0=''),
    4745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4745, CurrentID=0, Status='live', Symbol='NELL1', Aliases=['IDH3GL', 'NRP1'], description='neural EGFL like 1', other_designations='protein kinase C-binding protein NELL1|nel-related protein 1|neural epidermal growth factor-like 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=20669551, end_position_on_the_genomic_accession=21575686, orientation='plus', exon_count=21, OMIM=[602319], no_hdr0=''),
    4747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4747, CurrentID=0, Status='live', Symbol='NEFL', Aliases=['CMT1F', 'CMT2E', 'CMTDIG', 'NF-L', 'NF68', 'NFL', 'PPP1R110'], description='neurofilament light chain', other_designations='neurofilament light polypeptide|light molecular weight neurofilament protein|neurofilament protein, light chain|neurofilament subunit NF-L|neurofilament triplet L protein|neurofilament, light polypeptide 68kDa|protein phosphatase 1, regulatory subunit 110', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=24950955, end_position_on_the_genomic_accession=24956612, orientation='minus', exon_count=4, OMIM=[162280], no_hdr0=''),
    4750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4750, CurrentID=0, Status='live', Symbol='NEK1', Aliases=['ALS24', 'NY-REN-55', 'SRPS2', 'SRPS2A', 'SRTD6'], description='NIMA related kinase 1', other_designations='serine/threonine-protein kinase Nek1|NIMA (never in mitosis gene a)-related kinase 1|never in mitosis A-related kinase 1|nimA-related protein kinase 1|protein-serine/threonine kinase|renal carcinoma antigen NY-REN-55', map_location='4q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=169392809, end_position_on_the_genomic_accession=169612629, orientation='minus', exon_count=38, OMIM=[604588], no_hdr0=''),
    4751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4751, CurrentID=0, Status='live', Symbol='NEK2', Aliases=['HsPK21A', 'NLK1', 'PPP1R111', 'RP67', 'NEK2'], description='NIMA related kinase 2', other_designations='serine/threonine-protein kinase Nek2|NIMA (never in mitosis gene a)-related kinase 2|nimA-like protein kinase 1|nimA-related protein kinase 2|protein phosphatase 1, regulatory subunit 111', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211658256, end_position_on_the_genomic_accession=211675621, orientation='minus', exon_count=9, OMIM=[604043], no_hdr0=''),
    4752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4752, CurrentID=0, Status='live', Symbol='NEK3', Aliases=['HSPK36'], description='NIMA related kinase 3', other_designations='serine/threonine-protein kinase Nek3|HSPK 36|NIMA (never in mitosis gene a)-related kinase 3|glycogen synthase A kinase|hydroxyalkyl-protein kinase|never in mitosis A-related kinase 3|nimA-related protein kinase 3|phosphorylase B kinase kinase', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52132647, end_position_on_the_genomic_accession=52159597, orientation='minus', exon_count=17, OMIM=[604044], no_hdr0=''),
    4753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4753, CurrentID=0, Status='live', Symbol='NELL2', Aliases=['NRP2'], description='neural EGFL like 2', other_designations='protein kinase C-binding protein NELL2|NEL-like protein 2|NEL-related protein 2|neural epidermal growth factor-like 2', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=44508275, end_position_on_the_genomic_accession=44921848, orientation='minus', exon_count=26, OMIM=[602320], no_hdr0=''),
    4756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4756, CurrentID=0, Status='live', Symbol='NEO1', Aliases=['IGDCC2', 'NGN', 'NTN1R2'], description='neogenin 1', other_designations='neogenin|immunoglobulin superfamily DCC subclass member 2|neogenin homolog 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73051715, end_position_on_the_genomic_accession=73305206, orientation='plus', exon_count=30, OMIM=[601907], no_hdr0=''),
    4758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4758, CurrentID=0, Status='live', Symbol='NEU1', Aliases=['NANH', 'NEU', 'SIAL1'], description='neuraminidase 1', other_designations='sialidase-1|G9 sialidase|N-acetyl-alpha-neuraminidase 1|acetylneuraminyl hydrolase|exo-alpha-sialidase|lysosomal sialidase|sialidase 1 (lysosomal sialidase)', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31857659, end_position_on_the_genomic_accession=31862821, orientation='minus', exon_count=6, OMIM=[608272], no_hdr0=''),
    4759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4759, CurrentID=0, Status='live', Symbol='NEU2', Aliases=['SIAL2'], description='neuraminidase 2', other_designations='sialidase-2|N-acetyl-alpha-neuraminidase 2|cytosolic sialidase|sialidase 2 (cytosolic sialidase)', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233032672, end_position_on_the_genomic_accession=233035057, orientation='plus', exon_count=2, OMIM=[605528], no_hdr0=''),
    4760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4760, CurrentID=0, Status='live', Symbol='NEUROD1', Aliases=['BETA2', 'BHF-1', 'MODY6', 'NEUROD', 'T2D', 'bHLHa3'], description='neuronal differentiation 1', other_designations='neurogenic differentiation factor 1|basic helix-loop-helix transcription factor|beta-cell E-box transactivator 2|class A basic helix-loop-helix protein 3|neurogenic helix-loop-helix protein NEUROD', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=181668295, end_position_on_the_genomic_accession=181680517, orientation='minus', exon_count=4, OMIM=[601724], no_hdr0=''),
    4761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4761, CurrentID=0, Status='live', Symbol='NEUROD2', Aliases=['DEE72', 'EIEE72', 'NDRF', 'bHLHa1'], description='neuronal differentiation 2', other_designations='neurogenic differentiation factor 2|class A basic helix-loop-helix protein 1|neuroD-related factor|neurogenic basic-helix-loop-helix protein|neurogenic differentiation 2', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39603768, end_position_on_the_genomic_accession=39607920, orientation='minus', exon_count=2, OMIM=[601725], no_hdr0=''),
    4762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4762, CurrentID=0, Status='live', Symbol='NEUROG1', Aliases=['AKA', 'Math4C', 'NEUROD3', 'bHLHa6', 'ngn1'], description='neurogenin 1', other_designations='neurogenin-1|NGN-1|class A basic helix-loop-helix protein 6|neurogenic basic-helix-loop-helix protein|neurogenic differentiation 3|neurogenic differentiation factor 3', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135534282, end_position_on_the_genomic_accession=135535964, orientation='minus', exon_count=1, OMIM=[601726], no_hdr0=''),
    4763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4763, CurrentID=0, Status='live', Symbol='NF1', Aliases=['NFNS', 'VRNF', 'WSS'], description='neurofibromin 1', other_designations='neurofibromin|neurofibromatosis 1|neurofibromatosis-related protein NF-1|truncated neurofibromin 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31094927, end_position_on_the_genomic_accession=31377677, orientation='plus', exon_count=58, OMIM=[613113], no_hdr0=''),
    4771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4771, CurrentID=0, Status='live', Symbol='NF2', Aliases=['ACN', 'BANF', 'SCH', 'merlin-1'], description='neurofibromin 2', other_designations='merlin|bilateral acoustic neurofibromatosis|moesin-ezrin-radixin like|moesin-ezrin-radixin-like protein|moesin-ezrin-radizin-like protein|neurofibromin 2 (bilateral acoustic neuroma)|schwannomerlin|schwannomin', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29603556, end_position_on_the_genomic_accession=29698600, orientation='plus', exon_count=19, OMIM=[607379], no_hdr0=''),
    4772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4772, CurrentID=0, Status='live', Symbol='NFATC1', Aliases=['NF-ATC', 'NF-ATc1.2', 'NFAT2', 'NFATc'], description='nuclear factor of activated T cells 1', other_designations="nuclear factor of activated T-cells, cytoplasmic 1|NFAT transcription complex cytosolic component|nuclear factor of activated T-cells 'c'|nuclear factor of activated T-cells, cytoplasmic, calcineurin-dependent 1", map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79395930, end_position_on_the_genomic_accession=79529323, orientation='plus', exon_count=11, OMIM=[600489], no_hdr0=''),
    4773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4773, CurrentID=0, Status='live', Symbol='NFATC2', Aliases=['NFAT1', 'NFATP'], description='nuclear factor of activated T cells 2', other_designations='nuclear factor of activated T-cells, cytoplasmic 2|NF-ATc2|NFAT pre-existing subunit|NFAT transcription complex, preexisting component|T cell transcription factor NFAT1|nuclear factor of activated T-cells, cytoplasmic, calcineurin-dependent 2|nuclear factor of activated T-cells, preexisting component|preexisting nuclear factor of activated T-cells 2', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=51386963, end_position_on_the_genomic_accession=51562857, orientation='minus', exon_count=13, OMIM=[600490], no_hdr0=''),
    4774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4774, CurrentID=0, Status='live', Symbol='NFIA', Aliases=['BRMUTD', 'CTF', 'NF-I/A', 'NF1-A', 'NFI-A', 'NFI-L'], description='nuclear factor I A', other_designations='nuclear factor 1 A-type|CCAAT-box-binding transcription factor|TGGCA-binding protein', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=61077227, end_position_on_the_genomic_accession=61462788, orientation='plus', exon_count=15, OMIM=[600727], no_hdr0=''),
    4775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4775, CurrentID=0, Status='live', Symbol='NFATC3', Aliases=['NF-AT4c', 'NFAT4', 'NFATX'], description='nuclear factor of activated T cells 3', other_designations='nuclear factor of activated T-cells, cytoplasmic 3|NF-ATc3|T cell transcription factor NFAT4|nuclear factor of activated T-cells, cytoplasmic, calcineurin-dependent 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68085370, end_position_on_the_genomic_accession=68229259, orientation='plus', exon_count=12, OMIM=[602698], no_hdr0=''),
    4776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4776, CurrentID=0, Status='live', Symbol='NFATC4', Aliases=['NF-AT3', 'NF-ATC4', 'NFAT3'], description='nuclear factor of activated T cells 4', other_designations='nuclear factor of activated T-cells, cytoplasmic 4|T-cell transcription factor NFAT3|nuclear factor of activated T-cells, cytoplasmic, calcineurin-dependent 4', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24366911, end_position_on_the_genomic_accession=24379604, orientation='plus', exon_count=12, OMIM=[602699], no_hdr0=''),
    4778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4778, CurrentID=0, Status='live', Symbol='NFE2', Aliases=['NF-E2', 'p45'], description='nuclear factor, erythroid 2', other_designations='transcription factor NF-E2 45 kDa subunit|leucine zipper protein NF-E2|nuclear factor (erythroid-derived 2), 45kD|nuclear factor (erythroid-derived 2), 45kDa|nuclear factor, erythroid-derived 2 45 kDa subunit|p45 NF-E2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54292111, end_position_on_the_genomic_accession=54301015, orientation='minus', exon_count=5, OMIM=[601490], no_hdr0=''),
    4779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4779, CurrentID=0, Status='live', Symbol='NFE2L1', Aliases=['LCR-F1', 'NRF1', 'TCF11'], description='nuclear factor, erythroid 2 like 1', other_designations='endoplasmic reticulum membrane sensor NFE2L1|NF-E2-related factor 1|NFE2-related factor 1|TCF-11|locus control region-factor 1|nuclear factor erythroid 2-related factor 1|nuclear factor, erythroid derived 2, like 1|protein NRF1, p120 form|transcription factor 11 (basic leucine zipper type)|transcription factor HBZ17|transcription factor LCR-F1', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48048359, end_position_on_the_genomic_accession=48061545, orientation='plus', exon_count=7, OMIM=[163260], no_hdr0=''),
    4780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4780, CurrentID=0, Status='live', Symbol='NFE2L2', Aliases=['HEBP1', 'IMDDHH', 'NRF2', 'Nrf-2'], description='nuclear factor, erythroid 2 like 2', other_designations='nuclear factor erythroid 2-related factor 2|nuclear factor erythroid-derived 2-like 2', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177230303, end_position_on_the_genomic_accession=177265131, orientation='minus', exon_count=6, OMIM=[600492], no_hdr0=''),
    4781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4781, CurrentID=0, Status='live', Symbol='NFIB', Aliases=['CTF', 'HMGIC/NFIB', 'MACID', 'NF-I/B', 'NF1-B', 'NFI-B', 'NFI-RED2', 'NFIB3', 'NFIB'], description='nuclear factor I B', other_designations='nuclear factor 1 B-type|CCAAT-box-binding transcription factor|TGGCA-binding protein|nuclear factor 1/B', map_location='9p23-p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=14081843, end_position_on_the_genomic_accession=14532077, orientation='minus', exon_count=22, OMIM=[600728], no_hdr0=''),
    4782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4782, CurrentID=0, Status='live', Symbol='NFIC', Aliases=['CTF', 'CTF5', 'NF-I', 'NFI'], description='nuclear factor I C', other_designations='nuclear factor 1 C-type|CCAAT-box-binding transcription factor|NF-I/C|NF1-C|TGGCA-binding protein|nuclear factor I/C (CCAAT-binding transcription factor)', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3359630, end_position_on_the_genomic_accession=3469217, orientation='plus', exon_count=13, OMIM=[600729], no_hdr0=''),
    4783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4783, CurrentID=0, Status='live', Symbol='NFIL3', Aliases=['E4BP4', 'IL3BP1', 'NF-IL3AA', 'NFIL3'], description='nuclear factor, interleukin 3 regulated', other_designations='nuclear factor interleukin-3-regulated protein|E4 promoter-binding protein 4|adenovirus E4 promoter region binding protein|interleukin-3 promoter transcriptional activator|interleukin-3-binding protein 1|transcriptional activator NF-IL3A', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=91409045, end_position_on_the_genomic_accession=91425063, orientation='minus', exon_count=5, OMIM=[605327], no_hdr0=''),
    4784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4784, CurrentID=0, Status='live', Symbol='NFIX', Aliases=['CTF', 'MRSHSS', 'NF-I/X', 'NF1-X', 'NF1A', 'SOTOS2'], description='nuclear factor I X', other_designations='nuclear factor 1 X-type|CCAAT-box-binding transcription factor|TGGCA-binding protein|nuclear factor 1/X', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12995475, end_position_on_the_genomic_accession=13098796, orientation='plus', exon_count=13, OMIM=[164005], no_hdr0=''),
    4790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4790, CurrentID=0, Status='live', Symbol='NFKB1', Aliases=['CVID12', 'EBP-1', 'KBF1', 'NF-kB', 'NF-kB1', 'NF-kappa-B1', 'NF-kappaB', 'NF-kappabeta', 'NFKB-p105', 'NFKB-p50', 'NFkappaB'], description='nuclear factor kappa B subunit 1', other_designations='nuclear factor NF-kappa-B p105 subunit|DNA-binding factor KBF1|nuclear factor NF-kappa-B p50 subunit|nuclear factor kappa-B DNA binding subunit|nuclear factor of kappa light polypeptide gene enhancer in B-cells 1', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102501266, end_position_on_the_genomic_accession=102617302, orientation='plus', exon_count=27, OMIM=[164011], no_hdr0=''),
    4791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4791, CurrentID=0, Status='live', Symbol='NFKB2', Aliases=['CVID10', 'H2TF1', 'LYT-10', 'LYT10', 'NF-kB2', 'p100', 'p49/p100', 'p52'], description='nuclear factor kappa B subunit 2', other_designations='nuclear factor NF-kappa-B p100 subunit|DNA-binding factor KBF2|NFKB, p52/p100 subunit|lymphocyte translocation chromosome 10 protein|nuclear factor Kappa-B, subunit 2|nuclear factor NF-kappa-B p52 subunit|nuclear factor of Kappa light chain gene enhancer in B cells 2|nuclear factor of kappa light polypeptide gene enhancer in B-cells 2 (p49/p100)|oncogene Lyt-10|transcription factor NFKB2', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102394110, end_position_on_the_genomic_accession=102402529, orientation='plus', exon_count=25, OMIM=[164012], no_hdr0=''),
    4792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4792, CurrentID=0, Status='live', Symbol='NFKBIA', Aliases=['EDAID2', 'IKBA', 'MAD-3', 'NFKBI'], description='NFKB inhibitor alpha', other_designations='NF-kappa-B inhibitor alpha|I-kappa-B-alpha|IkappaBalpha|ikB-alpha|major histocompatibility complex enhancer-binding protein MAD3|nuclear factor of kappa light chain gene enhancer in B-cells|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor, alpha', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35401513, end_position_on_the_genomic_accession=35404749, orientation='minus', exon_count=6, OMIM=[164008], no_hdr0=''),
    4793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4793, CurrentID=0, Status='live', Symbol='NFKBIB', Aliases=['IKBB', 'TRIP9'], description='NFKB inhibitor beta', other_designations='NF-kappa-B inhibitor beta|I-kappa-B-beta|NF-kappa-BIB|TR-interacting protein 9|TRIP-9|ikB-B|ikB-beta|ikappaBbeta|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor, beta|thyroid receptor-interacting protein 9', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38899503, end_position_on_the_genomic_accession=38908894, orientation='plus', exon_count=7, OMIM=[604495], no_hdr0=''),
    4794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4794, CurrentID=0, Status='live', Symbol='NFKBIE', Aliases=['IKBE'], description='NFKB inhibitor epsilon', other_designations='NF-kappa-B inhibitor epsilon|I-kappa-B-epsilon|NF-kappa-BIE|ikB-E|ikB-epsilon|ikappaBepsilon|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor, epsilon', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44258166, end_position_on_the_genomic_accession=44265551, orientation='minus', exon_count=6, OMIM=[604548], no_hdr0=''),
    4795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4795, CurrentID=0, Status='live', Symbol='NFKBIL1', Aliases=['IKBL', 'NFKBIL'], description='NFKB inhibitor like 1', other_designations='NF-kappa-B inhibitor-like protein 1|I-kappa-B-like protein|ikappaBL|inhibitor of kappa B-like protein|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor-like 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31546851, end_position_on_the_genomic_accession=31558829, orientation='plus', exon_count=5, OMIM=[601022], no_hdr0=''),
    4796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4796, CurrentID=0, Status='live', Symbol='TONSL', Aliases=['IKBR', 'NFKBIL2', 'SEMDSP'], description='tonsoku like, DNA repair protein', other_designations='tonsoku-like protein|I-kappa-B-related protein|NF-kappa-B inhibitor-like protein 2|ikappaBR|inhibitor of kappa B-related protein|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor-like 2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144428775, end_position_on_the_genomic_accession=144444488, orientation='minus', exon_count=26, OMIM=[604546], no_hdr0=''),
    4798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4798, CurrentID=0, Status='live', Symbol='NFRKB', Aliases=['INO80G'], description='nuclear factor related to kappaB binding protein', other_designations='nuclear factor related to kappa-B-binding protein|DNA-binding protein R kappa B|INO80 complex subunit G', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=129863636, end_position_on_the_genomic_accession=129895596, orientation='minus', exon_count=31, OMIM=[164013], no_hdr0=''),
    4799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4799, CurrentID=0, Status='live', Symbol='NFX1', Aliases=['NFX2', 'TEG-42', 'Tex42'], description='nuclear transcription factor, X-box binding 1', other_designations='transcriptional repressor NF-X1|nuclear transcription factor, X box-binding protein 1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33290475, end_position_on_the_genomic_accession=33371157, orientation='plus', exon_count=24, OMIM=[603255], no_hdr0=''),
    4800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4800, CurrentID=0, Status='live', Symbol='NFYA', Aliases=['CBF-A', 'CBF-B', 'HAP2', 'NF-YA'], description='nuclear transcription factor Y subunit alpha', other_designations='nuclear transcription factor Y subunit alpha|CAAT-box DNA binding protein subunit A|CCAAT-binding transcription factor subunit B|HAP2 CCAAT-binding protein|Transcription factor NF-Y, A subunit|nuclear transcription factor Y subunit A|nuclear transcription factor Y, alpha', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41072974, end_position_on_the_genomic_accession=41102403, orientation='plus', exon_count=10, OMIM=[189903], no_hdr0=''),
    4801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4801, CurrentID=0, Status='live', Symbol='NFYB', Aliases=['CBF-A', 'CBF-B', 'HAP3', 'NF-YB'], description='nuclear transcription factor Y subunit beta', other_designations='nuclear transcription factor Y subunit beta|CAAT box DNA-binding protein subunit B|CCAAT-binding transcription factor subunit A|Transcription factor NF-Y, B subunit|nuclear transcription factor Y subunit B|nuclear transcription factor Y, beta', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104117086, end_position_on_the_genomic_accession=104138241, orientation='minus', exon_count=10, OMIM=[189904], no_hdr0=''),
    4802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4802, CurrentID=0, Status='live', Symbol='NFYC', Aliases=['CBF-C', 'CBFC', 'H1TF2A', 'HAP5', 'HSM', 'NF-YC'], description='nuclear transcription factor Y subunit gamma', other_designations='nuclear transcription factor Y subunit gamma|CAAT box DNA-binding protein subunit C|CCAAT binding factor subunit C|CCAAT transcription binding factor subunit gamma|histone H1 transcription factor large subunit 2A|nuclear transcription factor Y subunit C|nuclear transcription factor Y, gamma|transactivator HSM-1|transactivator HSM-1/2|transcription factor NF-Y, C subunit', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40691699, end_position_on_the_genomic_accession=40771603, orientation='plus', exon_count=22, OMIM=[605344], no_hdr0=''),
    4803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4803, CurrentID=0, Status='live', Symbol='NGF', Aliases=['Beta-NGF', 'HSAN5B', 'NGF'], description='nerve growth factor', other_designations='beta-nerve growth factor|nerve growth factor (beta polypeptide)|nerve growth factor, beta subunit|pro-nerve growth factor long', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115285915, end_position_on_the_genomic_accession=115338253, orientation='minus', exon_count=4, OMIM=[162030], no_hdr0=''),
    4804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4804, CurrentID=0, Status='live', Symbol='NGFR', Aliases=['CD271', 'Gp80-LNGFR', 'TNFRSF16', 'p75(NTR)', 'p75NTR'], description='nerve growth factor receptor', other_designations='tumor necrosis factor receptor superfamily member 16|NGF receptor|TNFR superfamily, member 16|low affinity neurotrophin receptor p75NTR|low-affinity nerve growth factor receptor|p75 ICD', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49495293, end_position_on_the_genomic_accession=49515008, orientation='plus', exon_count=6, OMIM=[162010], no_hdr0=''),
    4807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4807, CurrentID=0, Status='live', Symbol='NHLH1', Aliases=['HEN1', 'NSCL', 'NSCL1', 'bHLHa35'], description='nescient helix-loop-helix 1', other_designations='helix-loop-helix protein 1|HEN-1|NSCL-1|class A basic helix-loop-helix protein 35', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160367071, end_position_on_the_genomic_accession=160372846, orientation='plus', exon_count=2, OMIM=[162360], no_hdr0=''),
    4808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4808, CurrentID=0, Status='live', Symbol='NHLH2', Aliases=['HEN2', 'NSCL2', 'bHLHa34'], description='nescient helix-loop-helix 2', other_designations='helix-loop-helix protein 2|HEN-2|NSCL-2|class A basic helix-loop-helix protein 34', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115830777, end_position_on_the_genomic_accession=115841126, orientation='minus', exon_count=5, OMIM=[162361], no_hdr0=''),
    4809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4809, CurrentID=0, Status='live', Symbol='SNU13', Aliases=['15.5K', 'FA-1', 'FA1', 'NHP2L1', 'NHPX', 'OTK27', 'SNRNP15-5', 'SPAG12', 'SSFA1'], description='small nuclear ribonucleoprotein 13', other_designations='NHP2-like protein 1|NHP2 non-histone chromosome protein 2-like 1|SNU13 homolog, small nuclear ribonucleoprotein (U4/U6.U5)|U4/U6.U5 tri-snRNP 15.5 kDa protein|[U4/U6.U5] tri-snRNP 15.5 kD RNA binding protein|high mobility group-like nuclear protein 2 homolog 1|non-histone chromosome protein 2-like 1|sperm specific antigen 1', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41673933, end_position_on_the_genomic_accession=41690492, orientation='minus', exon_count=6, OMIM=[601304], no_hdr0=''),
    4810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4810, CurrentID=0, Status='live', Symbol='NHS', Aliases=['CTRCT40', 'CXN', 'SCML1'], description='NHS actin remodeling regulator', other_designations='Nance-Horan syndrome protein|Nance-Horan syndrome (congenital cataracts and dental anomalies)|congenital cataracts and dental anomalies protein', map_location='Xp22.2-p22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=17375200, end_position_on_the_genomic_accession=17735994, orientation='plus', exon_count=11, OMIM=[300457], no_hdr0=''),
    4811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4811, CurrentID=0, Status='live', Symbol='NID1', Aliases=['NID'], description='nidogen 1', other_designations='nidogen-1|NID-1|enactin|entactin|epididymis secretory sperm binding protein', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235975830, end_position_on_the_genomic_accession=236065092, orientation='minus', exon_count=20, OMIM=[131390], no_hdr0=''),
    4814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4814, CurrentID=0, Status='live', Symbol='NINJ1', Aliases=['NIN1', 'NINJURIN'], description='ninjurin 1', other_designations='ninjurin-1|nerve injury-induced protein-1', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93121496, end_position_on_the_genomic_accession=93134304, orientation='minus', exon_count=5, OMIM=[602062], no_hdr0=''),
    4815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4815, CurrentID=0, Status='live', Symbol='NINJ2', Aliases=[], description='ninjurin 2', other_designations='ninjurin-2|nerve injury-induced protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=564296, end_position_on_the_genomic_accession=663445, orientation='minus', exon_count=7, OMIM=[607297], no_hdr0=''),
    4817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4817, CurrentID=0, Status='live', Symbol='NIT1', Aliases=[], description='nitrilase 1', other_designations='deaminated glutathione amidase|dGSH amidase', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161118092, end_position_on_the_genomic_accession=161125446, orientation='plus', exon_count=8, OMIM=[604618], no_hdr0=''),
    4818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4818, CurrentID=0, Status='live', Symbol='NKG7', Aliases=['GIG1', 'GMP-17', 'p15-TIA-1'], description='natural killer cell granule protein 7', other_designations='protein NKG7|G-CSF-induced gene 1 protein|GIG-1 protein|granule membrane protein 17|granule membrane protein of 17 kDa|natural killer cell group 7 sequence|natural killer cell protein 7', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51371616, end_position_on_the_genomic_accession=51372688, orientation='minus', exon_count=4, OMIM=[606008], no_hdr0=''),
    4820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4820, CurrentID=0, Status='live', Symbol='NKTR', Aliases=['p104'], description='natural killer cell triggering receptor', other_designations='NK-tumor recognition protein|NK-TR protein|PPIase|natural killer triggering receptor|natural killer-tumor recognition sequence|natural-killer cells cyclophilin-related protein|peptidyl-prolyl cis-trans isomerase NKTR|rotamase', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42600007, end_position_on_the_genomic_accession=42648735, orientation='plus', exon_count=19, OMIM=[161565], no_hdr0=''),
    4821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4821, CurrentID=0, Status='live', Symbol='NKX2-2', Aliases=['NKX2.2', 'NKX2B'], description='NK2 homeobox 2', other_designations='homeobox protein Nkx-2.2|NK2 transcription factor related, locus 2|NK2 transcription factor-like protein B|homeobox protein NK-2 homolog B', map_location='20p11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=21511010, end_position_on_the_genomic_accession=21514064, orientation='minus', exon_count=3, OMIM=[604612], no_hdr0=''),
    4824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4824, CurrentID=0, Status='live', Symbol='NKX3-1', Aliases=['BAPX2', 'NKX3', 'NKX3.1', 'NKX3A'], description='NK3 homeobox 1', other_designations='homeobox protein Nkx-3.1|NK homeobox, family 3, A|NK3 transcription factor homolog A|NK3 transcription factor related, locus 1|homeobox protein NK-3 homolog A', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23678693, end_position_on_the_genomic_accession=23682938, orientation='minus', exon_count=4, OMIM=[602041], no_hdr0=''),
    4825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4825, CurrentID=0, Status='live', Symbol='NKX6-1', Aliases=['NKX6.1', 'NKX6A'], description='NK6 homeobox 1', other_designations='homeobox protein Nkx-6.1|NK homeo box, family 6, member A|NK homeobox, family 6, A|NK6 transcription factor homolog A|NK6 transcription factor related, locus 1|homeobox protein NK-6 homolog A', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=84491985, end_position_on_the_genomic_accession=84499292, orientation='minus', exon_count=3, OMIM=[602563], no_hdr0=''),
    4826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4826, CurrentID=0, Status='live', Symbol='NNAT', Aliases=['Peg5'], description='neuronatin', other_designations='neuronatin', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37521250, end_position_on_the_genomic_accession=37523690, orientation='plus', exon_count=3, OMIM=[603106], no_hdr0=''),
    4828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4828, CurrentID=0, Status='live', Symbol='NMB', Aliases=[], description='neuromedin B', other_designations='neuromedin-B|Neuromedin-B-32|neuromedin-beta', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84655132, end_position_on_the_genomic_accession=84658611, orientation='minus', exon_count=4, OMIM=[162340], no_hdr0=''),
    4829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4829, CurrentID=0, Status='live', Symbol='NMBR', Aliases=['BB1', 'BB1R', 'BRS1', 'NMB-R'], description='neuromedin B receptor', other_designations='neuromedin-B receptor|bombesin receptor 1|epididymis secretory sperm binding protein Li 185a|epididymis tissue protein Li 185a|neuromedin-B-preferring bombesin receptor', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=142074484, end_position_on_the_genomic_accession=142147122, orientation='minus', exon_count=5, OMIM=[162341], no_hdr0=''),
    4830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4830, CurrentID=0, Status='live', Symbol='NME1', Aliases=['AWD', 'GAAD', 'NB', 'NBS', 'NDKA', 'NDPK-A', 'NDPKA', 'NM23', 'NM23-H1'], description='NME/NM23 nucleoside diphosphate kinase 1', other_designations='nucleoside diphosphate kinase A|NDP kinase A|epididymis secretory sperm binding protein|granzyme A-activated DNase|metastasis inhibition factor nm23|non-metastatic cells 1, protein (NM23A) expressed in|tumor metastatic process-associated protein', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51153559, end_position_on_the_genomic_accession=51162168, orientation='plus', exon_count=6, OMIM=[156490], no_hdr0=''),
    4831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4831, CurrentID=0, Status='live', Symbol='NME2', Aliases=['NDKB', 'NDPK-B', 'NDPKB', 'NM23-H2', 'NM23B', 'PUF'], description='NME/NM23 nucleoside diphosphate kinase 2', other_designations='nucleoside diphosphate kinase B|HEL-S-155an|NDP kinase B|c-myc purine-binding transcription factor PUF|c-myc transcription factor|epididymis secretory sperm binding protein Li 155an|histidine protein kinase NDKB|non-metastatic cells 2, protein (NM23) expressed in|non-metastatic cells 2, protein (NM23B) expressed in|nucleotide diphosphate kinase B', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51165536, end_position_on_the_genomic_accession=51171744, orientation='plus', exon_count=7, OMIM=[156491], no_hdr0=''),
    4832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4832, CurrentID=0, Status='live', Symbol='NME3', Aliases=['DR-nm23', 'NDPK-C', 'NDPKC', 'NM23-H3', 'NM23H3', 'c371H6.2'], description='NME/NM23 nucleoside diphosphate kinase 3', other_designations='nucleoside diphosphate kinase 3|NDK 3|NDP kinase 3|NDP kinase C|non-metastatic cells 3, protein expressed in|nucleoside diphosphate kinase C', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1770320, end_position_on_the_genomic_accession=1771750, orientation='minus', exon_count=5, OMIM=[601817], no_hdr0=''),
    4833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4833, CurrentID=0, Status='live', Symbol='NME4', Aliases=['NDPK-D', 'NM23H4', 'nm23-H4'], description='NME/NM23 nucleoside diphosphate kinase 4', other_designations='nucleoside diphosphate kinase, mitochondrial|NDK|NDP kinase D|NDP kinase, mitochondrial|NDPKD|non-metastatic cells 4, protein expressed in|nucleoside diphosphate kinase D', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=396729, end_position_on_the_genomic_accession=400754, orientation='plus', exon_count=8, OMIM=[601818], no_hdr0=''),
    4835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4835, CurrentID=0, Status='live', Symbol='NQO2', Aliases=['DHQV', 'DIA6', 'NMOR2', 'QR2'], description='N-ribosyldihydronicotinamide:quinone reductase 2', other_designations='ribosyldihydronicotinamide dehydrogenase [quinone]|NAD(P)H dehydrogenase, quinone 2|NAD(P)H menadione oxidoreductase-1, dioxin-inducible-2|NAD(P)H quinone dehydrogenase 2|NRH:quinone oxidoreductase 2|quinone reductase 2|ribosyldihydronicotinamide dehydrogenase', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2999894, end_position_on_the_genomic_accession=3019755, orientation='plus', exon_count=10, OMIM=[160998], no_hdr0=''),
    4836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4836, CurrentID=0, Status='live', Symbol='NMT1', Aliases=['NMT'], description='N-myristoyltransferase 1', other_designations='glycylpeptide N-tetradecanoyltransferase 1|alternative, short form NMT-S|long form, NMT-L|myristoyl-CoA:protein N-myristoyltransferase 1|type I N-myristoyltransferase', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45061317, end_position_on_the_genomic_accession=45109016, orientation='plus', exon_count=12, OMIM=[160993], no_hdr0=''),
    4837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4837, CurrentID=0, Status='live', Symbol='NNMT', Aliases=[], description='nicotinamide N-methyltransferase', other_designations='nicotinamide N-methyltransferase', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114257806, end_position_on_the_genomic_accession=114313536, orientation='plus', exon_count=8, OMIM=[600008], no_hdr0=''),
    4838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4838, CurrentID=0, Status='live', Symbol='NODAL', Aliases=['HTX5'], description='nodal growth differentiation factor', other_designations='nodal homolog', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70431936, end_position_on_the_genomic_accession=70447951, orientation='minus', exon_count=5, OMIM=[601265], no_hdr0=''),
    4839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4839, CurrentID=0, Status='live', Symbol='NOP2', Aliases=['NOL1', 'NOP120', 'NSUN1', 'p120'], description='NOP2 nucleolar protein', other_designations='probable 28S rRNA (cytosine(4447)-C(5))-methyltransferase|NOL1/NOP2/Sun domain family, member 1|NOP2 nucleolar protein homolog|nucleolar protein 1, 120kDa|nucleolar protein 2 homolog|proliferating-cell nucleolar antigen p120|proliferation-associated nucleolar protein p120|putative ribosomal RNA methyltransferase NOP2', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6556871, end_position_on_the_genomic_accession=6568291, orientation='minus', exon_count=18, OMIM=[164031], no_hdr0=''),
    4841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4841, CurrentID=0, Status='live', Symbol='NONO', Aliases=['MRXS34', 'NMT55', 'NRB54', 'P54', 'P54NRB', 'PPP1R114'], description='non-POU domain containing octamer binding', other_designations='non-POU domain-containing octamer-binding protein|54 kDa nuclear RNA- and DNA-binding protein|55 kDa nuclear protein|DNA-binding p52/p100 complex, 52 kDa subunit|non-POU domain-containing octamer (ATGCAAAT) binding protein|p54(nrb)|protein phosphatase 1, regulatory subunit 114', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71283635, end_position_on_the_genomic_accession=71301168, orientation='plus', exon_count=13, OMIM=[300084], no_hdr0=''),
    4842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4842, CurrentID=0, Status='live', Symbol='NOS1', Aliases=['IHPS1', 'N-NOS', 'NC-NOS', 'NOS', 'bNOS', 'nNOS'], description='nitric oxide synthase 1', other_designations='nitric oxide synthase, brain|NOS type I|constitutive NOS|neuronal NOS|nitric oxide synthase 1 (neuronal)|peptidyl-cysteine S-nitrosylase NOS1', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=117208142, end_position_on_the_genomic_accession=117361626, orientation='minus', exon_count=33, OMIM=[163731], no_hdr0=''),
    4843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4843, CurrentID=0, Status='live', Symbol='NOS2', Aliases=['HEP-NOS', 'INOS', 'NOSA', 'NOS2'], description='nitric oxide synthase 2', other_designations='nitric oxide synthase, inducible|NOS, type II|hepatocyte NOS|inducible NO synthase|inducible NOS|nitric oxide synthase 2, inducible|nitric oxide synthase 2A (inducible, hepatocytes)|nitric oxide synthase, macrophage|peptidyl-cysteine S-nitrosylase NOS2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=27756766, end_position_on_the_genomic_accession=27800529, orientation='minus', exon_count=27, OMIM=[163730], no_hdr0=''),
    4846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4846, CurrentID=0, Status='live', Symbol='NOS3', Aliases=['ECNOS', 'eNOS'], description='nitric oxide synthase 3', other_designations='nitric oxide synthase, endothelial|EC-NOS|NOS type III|NOSIII|cNOS|constitutive NOS|endothelial NOS|nitric oxide synthase 3 (endothelial cell)|nitric oxide synthase 3 transcript variant eNOS-delta20|nitric oxide synthase 3 transcript variant eNOS-delta20-21|nitric oxide synthase 3 transcript variant eNOS-delta21', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150991017, end_position_on_the_genomic_accession=151014588, orientation='plus', exon_count=28, OMIM=[163729], no_hdr0=''),
    4848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4848, CurrentID=0, Status='live', Symbol='CNOT2', Aliases=['CDC36', 'HSPC131', 'IDNADFS', 'NOT2', 'NOT2H'], description='CCR4-NOT transcription complex subunit 2', other_designations='CCR4-NOT transcription complex subunit 2|CCR4-associated factor 2|negative regulator of transcription 2', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=70242993, end_position_on_the_genomic_accession=70354993, orientation='plus', exon_count=21, OMIM=[604909], no_hdr0=''),
    4849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4849, CurrentID=0, Status='live', Symbol='CNOT3', Aliases=['IDDSADF', 'LENG2', 'NOT3', 'NOT3H'], description='CCR4-NOT transcription complex subunit 3', other_designations='CCR4-NOT transcription complex subunit 3|CCR4-associated factor 3|NOT3 (negative regulator of transcription 3, yeast) homolog|leukocyte receptor cluster member 2', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54137689, end_position_on_the_genomic_accession=54155690, orientation='plus', exon_count=20, OMIM=[604910], no_hdr0=''),
    4850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4850, CurrentID=0, Status='live', Symbol='CNOT4', Aliases=['CLONE243', 'NOT4', 'NOT4H'], description='CCR4-NOT transcription complex subunit 4', other_designations='CCR4-NOT transcription complex subunit 4|CCR4-associated factor 4|E3 ubiquitin-protein ligase CNOT4|NOT4 (negative regulator of transcription 4, yeast) homolog|RING-type E3 ubiquitin transferase CNOT4|potential transcriptional repressor NOT4Hp', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135361795, end_position_on_the_genomic_accession=135510102, orientation='minus', exon_count=14, OMIM=[604911], no_hdr0=''),
    4851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4851, CurrentID=0, Status='live', Symbol='NOTCH1', Aliases=['AOS5', 'AOVD1', 'TAN1', 'hN1'], description='notch receptor 1', other_designations='neurogenic locus notch homolog protein 1|Notch homolog 1, translocation-associated|notch 1|translocation-associated notch protein TAN-1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136494433, end_position_on_the_genomic_accession=136546048, orientation='minus', exon_count=34, OMIM=[190198], no_hdr0=''),
    4852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4852, CurrentID=0, Status='live', Symbol='NPY', Aliases=['PYY4'], description='neuropeptide Y', other_designations='pro-neuropeptide Y|prepro-neuropeptide Y', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=24284190, end_position_on_the_genomic_accession=24291862, orientation='plus', exon_count=4, OMIM=[162640], no_hdr0=''),
    4853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4853, CurrentID=0, Status='live', Symbol='NOTCH2', Aliases=['AGS2', 'HJCYS', 'hN2'], description='notch receptor 2', other_designations='neurogenic locus notch homolog protein 2|Notch homolog 2|notch 2', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119911553, end_position_on_the_genomic_accession=120069662, orientation='minus', exon_count=34, OMIM=[600275], no_hdr0=''),
    4854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4854, CurrentID=0, Status='live', Symbol='NOTCH3', Aliases=['CADASIL', 'CADASIL1', 'CASIL', 'IMF2', 'LMNS'], description='notch receptor 3', other_designations='neurogenic locus notch homolog protein 3|Notch homolog 3|notch 3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15159038, end_position_on_the_genomic_accession=15200995, orientation='minus', exon_count=33, OMIM=[600276], no_hdr0=''),
    4855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4855, CurrentID=0, Status='live', Symbol='NOTCH4', Aliases=['INT3'], description='notch receptor 4', other_designations='neurogenic locus notch homolog protein 4|Notch homolog 4|notch 4', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32194843, end_position_on_the_genomic_accession=32224067, orientation='minus', exon_count=31, OMIM=[164951], no_hdr0=''),
    4856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4856, CurrentID=0, Status='live', Symbol='CCN3', Aliases=['IBP-9', 'IGFBP-9', 'IGFBP9', 'NOV', 'NOVh'], description='cellular communication network factor 3', other_designations='CCN family member 3|IGF-binding protein 9|insulin-like growth factor-binding protein 9|nephro blastoma-overexpressed gene protein homolog|nephroblastoma overexpressed|nephroblastoma-overexpressed gene protein homolog|protein NOV homolog', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119416446, end_position_on_the_genomic_accession=119424434, orientation='plus', exon_count=5, OMIM=[164958], no_hdr0=''),
    4857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4857, CurrentID=0, Status='live', Symbol='NOVA1', Aliases=['Nova-1'], description='NOVA alternative splicing regulator 1', other_designations='RNA-binding protein Nova-1|neuro-oncological ventral antigen 1|onconeural ventral antigen 1|paraneoplastic Ri antigen|ventral neuron-specific protein 1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=26443090, end_position_on_the_genomic_accession=26598033, orientation='minus', exon_count=10, OMIM=[602157], no_hdr0=''),
    4858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4858, CurrentID=0, Status='live', Symbol='NOVA2', Aliases=['ANOVA', 'NEDASB', 'NOVA-2', 'NOVA3'], description='NOVA alternative splicing regulator 2', other_designations='RNA-binding protein Nova-2|astrocytic NOVA1-like RNA-binding protein|neuro-oncological ventral antigen 2|neuro-oncological ventral antigen 3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45933734, end_position_on_the_genomic_accession=45973865, orientation='minus', exon_count=7, OMIM=[601991], no_hdr0=''),
    4860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4860, CurrentID=0, Status='live', Symbol='PNP', Aliases=['NP', 'PRO1837', 'PUNP'], description='purine nucleoside phosphorylase', other_designations='purine nucleoside phosphorylase|HEL-S-156an|epididymis secretory sperm binding protein Li 156an|inosine phosphorylase|inosine-guanosine phosphorylase|purine-nucleoside:orthophosphate ribosyltransferase', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20469406, end_position_on_the_genomic_accession=20477089, orientation='plus', exon_count=6, OMIM=[164050], no_hdr0=''),
    4861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4861, CurrentID=0, Status='live', Symbol='NPAS1', Aliases=['MOP5', 'PASD5', 'bHLHe11'], description='neuronal PAS domain protein 1', other_designations='neuronal PAS domain-containing protein 1|PAS domain-containing protein 5|basic-helix-loop-helix-PAS protein MOP5|class E basic helix-loop-helix protein 11|member of PAS protein 5|member of PAS superfamily 5|neuronal PAS1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47019837, end_position_on_the_genomic_accession=47045775, orientation='plus', exon_count=13, OMIM=[603346], no_hdr0=''),
    4862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4862, CurrentID=0, Status='live', Symbol='NPAS2', Aliases=['MOP4', 'PASD4', 'bHLHe9'], description='neuronal PAS domain protein 2', other_designations='neuronal PAS domain-containing protein 2|PAS domain-containing protein 4|basic-helix-loop-helix-PAS protein MOP4|class E basic helix-loop-helix protein 9|member of PAS protein 4|member of PAS superfamily 4|neuronal PAS2', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=100820139, end_position_on_the_genomic_accession=100996829, orientation='plus', exon_count=25, OMIM=[603347], no_hdr0=''),
    4863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4863, CurrentID=0, Status='live', Symbol='NPAT', Aliases=['E14', 'E14/NPAT', 'p220'], description='nuclear protein, coactivator of histone transcription', other_designations='protein NPAT|nuclear protein of the ATM locus|nuclear protein of the ataxia telangiectasia mutated locus|nuclear protein, ataxia-telangiectasia locus|nuclear protein, co-activator of histone transcription', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108155280, end_position_on_the_genomic_accession=108222638, orientation='minus', exon_count=20, OMIM=[601448], no_hdr0=''),
    4864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4864, CurrentID=0, Status='live', Symbol='NPC1', Aliases=['NPC', 'POGZ', 'SLC65A1'], description='NPC intracellular cholesterol transporter 1', other_designations='NPC intracellular cholesterol transporter 1|Niemann-Pick C1 protein|truncated Niemann-Pick C1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23506184, end_position_on_the_genomic_accession=23586506, orientation='minus', exon_count=28, OMIM=[607623], no_hdr0=''),
    4867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4867, CurrentID=0, Status='live', Symbol='NPHP1', Aliases=['JBTS4', 'NPH1', 'SLSN1'], description='nephrocystin 1', other_designations='nephrocystin-1|juvenile nephronophthisis 1 protein|nephronophthisis 1 (juvenile)', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110123348, end_position_on_the_genomic_accession=110205013, orientation='minus', exon_count=23, OMIM=[607100], no_hdr0=''),
    4868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4868, CurrentID=0, Status='live', Symbol='NPHS1', Aliases=['CNF', 'NPHN', 'nephrin'], description='NPHS1 adhesion molecule, nephrin', other_designations='nephrin|NPHS1, nephrin|nephrosis 1, congenital, Finnish type (nephrin)|renal glomerulus-specific cell adhesion receptor|truncated NPHS1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35825372, end_position_on_the_genomic_accession=35852504, orientation='minus', exon_count=29, OMIM=[602716], no_hdr0=''),
    4869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4869, CurrentID=0, Status='live', Symbol='NPM1', Aliases=['B23', 'NPM'], description='nucleophosmin 1', other_designations='nucleophosmin|nucleolar protein NO38|nucleophosmin (nucleolar phosphoprotein B23, numatrin)|nucleophosmin/nucleoplasmin family, member 1|testicular tissue protein Li 128', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=171387116, end_position_on_the_genomic_accession=171410900, orientation='plus', exon_count=13, OMIM=[164040], no_hdr0=''),
    4878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4878, CurrentID=0, Status='live', Symbol='NPPA', Aliases=['ANF', 'ANP', 'ATFB6', 'ATRST2', 'CDD', 'CDD-ANF', 'CDP', 'PND'], description='natriuretic peptide A', other_designations='natriuretic peptides A|atrial natriuretic factor prohormone|atrial natriuretic peptide prohormone|atriopeptigen|atriopeptin|cardiodilatin-related peptide|cardionatrin|natriuretic peptide precursor A variant 1|preproANP|preproCDD-ANF|prepronatriodilatin|proANF|proANP', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11845709, end_position_on_the_genomic_accession=11847783, orientation='minus', exon_count=3, OMIM=[108780], no_hdr0=''),
    4879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4879, CurrentID=0, Status='live', Symbol='NPPB', Aliases=['BNP', 'Iso-ANP'], description='natriuretic peptide B', other_designations='natriuretic peptides B|brain natriuretic factor prohormone|brain type natriuretic peptide|gamma-brain natriuretic peptide|natriuretic peptide precursor B|natriuretic protein|preproBNP|proBNP', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11857464, end_position_on_the_genomic_accession=11858945, orientation='minus', exon_count=3, OMIM=[600295], no_hdr0=''),
    4880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4880, CurrentID=0, Status='live', Symbol='NPPC', Aliases=['CNP', 'CNP2'], description='natriuretic peptide C', other_designations='C-type natriuretic peptide|natriuretic peptide precursor type C', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231921809, end_position_on_the_genomic_accession=231926405, orientation='minus', exon_count=4, OMIM=[600296], no_hdr0=''),
    4881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4881, CurrentID=0, Status='live', Symbol='NPR1', Aliases=['ANPRA', 'ANPa', 'GUC2A', 'GUCY2A', 'NPRA'], description='natriuretic peptide receptor 1', other_designations='atrial natriuretic peptide receptor 1|ANP-A|ANPR-A|GC-A|NPR-A|atrial natriuretic peptide receptor type A|atrionatriuretic peptide receptor A|guanylate cyclase A|natriuretic peptide A type receptor|natriuretic peptide receptor A|natriuretic peptide receptor A/guanylate cyclase A (atrionatriuretic peptide receptor A)|testicular tissue protein Li 20', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153678649, end_position_on_the_genomic_accession=153693992, orientation='plus', exon_count=22, OMIM=[108960], no_hdr0=''),
    4882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4882, CurrentID=0, Status='live', Symbol='NPR2', Aliases=['AMDM', 'ANPRB', 'ANPb', 'ECDM', 'GC-B', 'GCB', 'GUC2B', 'GUCY2B', 'NPRB', 'NPRBi', 'SNSK'], description='natriuretic peptide receptor 2', other_designations='atrial natriuretic peptide receptor 2|atrial natriuretic peptide B-type receptor|atrial natriuretic peptide receptor type B|guanylate cyclase 2B|guanylate cyclase B|guanylyl cyclase B|natriuretic peptide receptor B/guanylate cyclase B (atrionatriuretic peptide receptor B)', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35782086, end_position_on_the_genomic_accession=35809731, orientation='plus', exon_count=24, OMIM=[108961], no_hdr0=''),
    4883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4883, CurrentID=0, Status='live', Symbol='NPR3', Aliases=['ANP-C', 'ANPR-C', 'ANPRC', 'C5orf23', 'GUCY2B', 'NPR-C', 'NPRC'], description='natriuretic peptide receptor 3', other_designations='atrial natriuretic peptide receptor 3|atrial natriuretic peptide clearance receptor|atrial natriuretic peptide receptor type C|atrionatriuretic peptide receptor C|guanylate cyclase C|natriuretic peptide receptor C/guanylate cyclase C (atrionatriuretic peptide receptor C)', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=32689076, end_position_on_the_genomic_accession=32791720, orientation='plus', exon_count=13, OMIM=[108962], no_hdr0=''),
    4884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4884, CurrentID=0, Status='live', Symbol='NPTX1', Aliases=['NP1'], description='neuronal pentraxin 1', other_designations='neuronal pentraxin-1|NP-I|neuronal pentraxin I', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80466834, end_position_on_the_genomic_accession=80476607, orientation='minus', exon_count=5, OMIM=[602367], no_hdr0=''),
    4885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4885, CurrentID=0, Status='live', Symbol='NPTX2', Aliases=['NARP', 'NP-II', 'NP2'], description='neuronal pentraxin 2', other_designations='neuronal pentraxin-2|apexin|neuronal activity-regulated pentaxin|neuronal pentraxin II', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98617285, end_position_on_the_genomic_accession=98629869, orientation='plus', exon_count=5, OMIM=[600750], no_hdr0=''),
    4886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4886, CurrentID=0, Status='live', Symbol='NPY1R', Aliases=['NPY1-R', 'NPYR'], description='neuropeptide Y receptor Y1', other_designations='neuropeptide Y receptor type 1', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163323962, end_position_on_the_genomic_accession=163344832, orientation='minus', exon_count=5, OMIM=[162641], no_hdr0=''),
    4887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4887, CurrentID=0, Status='live', Symbol='NPY2R', Aliases=['NPY2-R'], description='neuropeptide Y receptor Y2', other_designations='neuropeptide Y receptor type 2|NPY-Y2 receptor', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155173723, end_position_on_the_genomic_accession=155217076, orientation='plus', exon_count=3, OMIM=[162642], no_hdr0=''),
    4889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4889, CurrentID=0, Status='live', Symbol='NPY5R', Aliases=['NPY5-R', 'NPYR5', 'NPYY5-R'], description='neuropeptide Y receptor Y5', other_designations='neuropeptide Y receptor type 5|NPY-Y5 receptor|Y5 receptor', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163336968, end_position_on_the_genomic_accession=163352277, orientation='plus', exon_count=7, OMIM=[602001], no_hdr0=''),
    4891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4891, CurrentID=0, Status='live', Symbol='SLC11A2', Aliases=['AHMIO1', 'DCT1', 'DMT1', 'NRAMP2'], description='solute carrier family 11 member 2', other_designations='natural resistance-associated macrophage protein 2|DMT-1|NRAMP 2|divalent cation transporter 1|solute carrier family 11 (proton-coupled divalent metal ion transporter), member 2|solute carrier family 11 (proton-coupled divalent metal ion transporters), member 2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50952263, end_position_on_the_genomic_accession=51028886, orientation='minus', exon_count=25, OMIM=[600523], no_hdr0=''),
    4892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4892, CurrentID=0, Status='live', Symbol='NRAP', Aliases=['N-RAP'], description='nebulin related anchoring protein', other_designations='nebulin-related-anchoring protein', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113588714, end_position_on_the_genomic_accession=113664046, orientation='minus', exon_count=42, OMIM=[602873], no_hdr0=''),
    4893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4893, CurrentID=0, Status='live', Symbol='NRAS', Aliases=['ALPS4', 'CMNS', 'N-ras', 'NCMS1', 'NS6', 'NRAS'], description='NRAS proto-oncogene, GTPase', other_designations='GTPase NRas|N-ras protein part 4|neuroblastoma RAS viral (v-ras) oncogene homolog|neuroblastoma RAS viral oncogene homolog|transforming protein N-Ras|v-ras neuroblastoma RAS viral oncogene homolog', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114704469, end_position_on_the_genomic_accession=114716771, orientation='minus', exon_count=7, OMIM=[164790], no_hdr0=''),
    4897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4897, CurrentID=0, Status='live', Symbol='NRCAM', Aliases=[], description='neuronal cell adhesion molecule', other_designations='neuronal cell adhesion molecule|NgCAM-related cell adhesion molecule|neuronal surface protein Bravo', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=108147649, end_position_on_the_genomic_accession=108456720, orientation='minus', exon_count=47, OMIM=[601581], no_hdr0=''),
    4898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4898, CurrentID=0, Status='live', Symbol='NRDC', Aliases=['NRD1', 'hNRD1', 'hNRD2'], description='nardilysin convertase', other_designations='nardilysin|NRD convertase|nardilysin (N-arginine dibasic convertase)', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51789210, end_position_on_the_genomic_accession=51878727, orientation='minus', exon_count=34, OMIM=[602651], no_hdr0=''),
    4899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4899, CurrentID=0, Status='live', Symbol='NRF1', Aliases=['ALPHA-PAL'], description='nuclear respiratory factor 1', other_designations='nuclear respiratory factor 1|alpha palindromic-binding protein', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129611720, end_position_on_the_genomic_accession=129757076, orientation='plus', exon_count=13, OMIM=[600879], no_hdr0=''),
    4900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4900, CurrentID=0, Status='live', Symbol='NRGN', Aliases=['RC3', 'hng'], description='neurogranin', other_designations='neurogranin|calmodulin-binding protein|neurogranin (protein kinase C substrate, RC3)|protein kinase C substrate', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124739942, end_position_on_the_genomic_accession=124747210, orientation='plus', exon_count=4, OMIM=[602350], no_hdr0=''),
    4901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4901, CurrentID=0, Status='live', Symbol='NRL', Aliases=['D14S46E-MAF', 'RP27', 'NRL'], description='neural retina leucine zipper', other_designations='neural retina-specific leucine zipper protein|neural retinal-specific leucine zipper', map_location='14q11.2-q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24078662, end_position_on_the_genomic_accession=24114949, orientation='minus', exon_count=7, OMIM=[162080], no_hdr0=''),
    4902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4902, CurrentID=0, Status='live', Symbol='NRTN', Aliases=['NTN'], description='neurturin', other_designations='neurturin|prepro-neurturin', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5805067, end_position_on_the_genomic_accession=5828324, orientation='plus', exon_count=3, OMIM=[602018], no_hdr0=''),
    4904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4904, CurrentID=0, Status='live', Symbol='YBX1', Aliases=['BP-8', 'CBF-A', 'CSDA2', 'CSDB', 'DBPB', 'EFI-A', 'MDR-NF1', 'NSEP-1', 'NSEP1', 'YB-1', 'YB1'], description='Y-box binding protein 1', other_designations='Y-box-binding protein 1|CCAAT-binding transcription factor I subunit A|DNA-binding protein B|Y-box transcription factor|enhancer factor I subunit A|major histocompatibility complex, class II, Y box-binding protein I|nuclease-sensitive element-binding protein 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42682418, end_position_on_the_genomic_accession=42703805, orientation='plus', exon_count=9, OMIM=[154030], no_hdr0=''),
    4905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4905, CurrentID=0, Status='live', Symbol='NSF', Aliases=['DEE96', 'SEC18', 'SKD2'], description='N-ethylmaleimide sensitive factor, vesicle fusing ATPase', other_designations='vesicle-fusing ATPase|N-ethylmaleimide-sensitive factor-like protein|N-ethylmaleimide-sensitive fusion protein|NEM-sensitive fusion protein|epididymis secretory sperm binding protein|vesicular-fusion protein NSF', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46590669, end_position_on_the_genomic_accession=46757464, orientation='plus', exon_count=21, OMIM=[601633], no_hdr0=''),
    4907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4907, CurrentID=0, Status='live', Symbol='NT5E', Aliases=['CALJA', 'CD73', 'E5NT', 'NT', 'NT5', 'NTE', 'eN', 'eNT'], description="5'-nucleotidase ecto", other_designations="5'-nucleotidase|5'-NT|Purine 5-Prime-Nucleotidase|ecto-5'-nucleotidase", map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=85450083, end_position_on_the_genomic_accession=85495784, orientation='plus', exon_count=9, OMIM=[129190], no_hdr0=''),
    4908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4908, CurrentID=0, Status='live', Symbol='NTF3', Aliases=['HDNF', 'NGF-2', 'NGF2', 'NT-3', 'NT3'], description='neurotrophin 3', other_designations='neurotrophin-3|nerve growth factor 2|neurotrophic factor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=5432108, end_position_on_the_genomic_accession=5495299, orientation='plus', exon_count=3, OMIM=[162660], no_hdr0=''),
    4909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4909, CurrentID=0, Status='live', Symbol='NTF4', Aliases=['GLC10', 'GLC1O', 'NT-4', 'NT-4/5', 'NT-5', 'NT4', 'NT5', 'NTF5'], description='neurotrophin 4', other_designations='neurotrophin-4|neurotrophic factor 4|neurotrophic factor 5|neurotrophin 5 (neurotrophin 4/5)|neurotrophin-5|neutrophic factor 4', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49058284, end_position_on_the_genomic_accession=49065076, orientation='minus', exon_count=7, OMIM=[162662], no_hdr0=''),
    4913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4913, CurrentID=0, Status='live', Symbol='NTHL1', Aliases=['FAP3', 'NTH1', 'OCTS3', 'hNTH1'], description='nth like DNA glycosylase 1', other_designations='endonuclease III-like protein 1|DNA glycoslyase/AP lyase|DNA glycosylase/AP lyase|bifunctional DNA N-glycoslyase/DNA-(apurinic or apyrimidinic site) lyase|bifunctional DNA N-glycosylase/DNA-(apurinic or apyrimidinic site) lyase|nth endonuclease III-like 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2039820, end_position_on_the_genomic_accession=2047834, orientation='minus', exon_count=6, OMIM=[602656], no_hdr0=''),
    4914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4914, CurrentID=0, Status='live', Symbol='NTRK1', Aliases=['MTC', 'TRK', 'TRK1', 'TRKA', 'Trk-A', 'p140-TrkA'], description='neurotrophic receptor tyrosine kinase 1', other_designations='high affinity nerve growth factor receptor|Oncogene TRK|TRK1-transforming tyrosine kinase protein|gp140trk|neurotrophic tyrosine kinase, receptor, type 1|tropomyosin-related kinase A|tyrosine kinase receptor A', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156815750, end_position_on_the_genomic_accession=156881850, orientation='plus', exon_count=19, OMIM=[191315], no_hdr0=''),
    4915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4915, CurrentID=0, Status='live', Symbol='NTRK2', Aliases=['DEE58', 'EIEE58', 'GP145-TrkB', 'OBHD', 'TRKB', 'trk-B'], description='neurotrophic receptor tyrosine kinase 2', other_designations='BDNF/NT-3 growth factors receptor|BDNF-tropomyosine receptor kinase B|neurotrophic tyrosine kinase receptor type 2|tropomyosin-related kinase B|tyrosine kinase receptor B', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=84668458, end_position_on_the_genomic_accession=85027070, orientation='plus', exon_count=28, OMIM=[600456], no_hdr0=''),
    4916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4916, CurrentID=0, Status='live', Symbol='NTRK3', Aliases=['GP145-TrkC', 'TRKC', 'gp145(trkC)'], description='neurotrophic receptor tyrosine kinase 3', other_designations='NT-3 growth factor receptor|ETS related protein-neurotrophic receptor tyrosine kinase fusion protein|ETV6-NTRK3 fusion|neurotrophic tyrosine kinase, receptor, type 3|tyrosine kinase receptor C', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=87859749, end_position_on_the_genomic_accession=88256796, orientation='minus', exon_count=35, OMIM=[191316], no_hdr0=''),
    4917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4917, CurrentID=0, Status='live', Symbol='NTN3', Aliases=['NTN2L'], description='netrin 3', other_designations='netrin-3|Netrin-2, chicken, homolog of, like|netrin-2-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2471297, end_position_on_the_genomic_accession=2474145, orientation='plus', exon_count=6, OMIM=[602349], no_hdr0=''),
    4919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4919, CurrentID=0, Status='live', Symbol='ROR1', Aliases=['NTRKR1', 'dJ537F10.1'], description='receptor tyrosine kinase like orphan receptor 1', other_designations='inactive tyrosine-protein kinase transmembrane receptor ROR1|neurotrophic tyrosine kinase, receptor-related 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63774017, end_position_on_the_genomic_accession=64181498, orientation='plus', exon_count=12, OMIM=[602336], no_hdr0=''),
    4920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4920, CurrentID=0, Status='live', Symbol='ROR2', Aliases=['BDB', 'BDB1', 'NTRKR2'], description='receptor tyrosine kinase like orphan receptor 2', other_designations='tyrosine-protein kinase transmembrane receptor ROR2|neurotrophic tyrosine kinase receptor-related 2', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=91722598, end_position_on_the_genomic_accession=91950228, orientation='minus', exon_count=13, OMIM=[602337], no_hdr0=''),
    4921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4921, CurrentID=0, Status='live', Symbol='DDR2', Aliases=['MIG20a', 'NTRKR3', 'TKT', 'TYRO10', 'WRCN'], description='discoidin domain receptor tyrosine kinase 2', other_designations='discoidin domain-containing receptor 2|CD167 antigen-like family member B|cell migration-inducing protein 20|discoidin domain receptor 2|discoidin domain receptor family, member 2|discoidin domain-containing receptor tyrosine kinase 2|hydroxyaryl-protein kinase|migration-inducing gene 16 protein|neurotrophic tyrosine kinase receptor related 3|receptor protein-tyrosine kinase TKT|tyrosine-protein kinase TYRO10', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162630863, end_position_on_the_genomic_accession=162787405, orientation='plus', exon_count=22, OMIM=[191311], no_hdr0=''),
    4922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4922, CurrentID=0, Status='live', Symbol='NTS', Aliases=['NMN-125', 'NN', 'NT', 'NT/N1', 'NTS'], description='neurotensin', other_designations='neurotensin/neuromedin N|pro-neurotensin/neuromedin', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85874295, end_position_on_the_genomic_accession=85882992, orientation='plus', exon_count=4, OMIM=[162650], no_hdr0=''),
    4923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4923, CurrentID=0, Status='live', Symbol='NTSR1', Aliases=['NTR'], description='neurotensin receptor 1', other_designations='neurotensin receptor type 1|NT-R-1|NTR1|NTRH|high-affinity levocabastine-insensitive neurotensin receptor|neurotensin receptor 1 (high affinity)', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62708770, end_position_on_the_genomic_accession=62762771, orientation='plus', exon_count=4, OMIM=[162651], no_hdr0=''),
    4924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4924, CurrentID=0, Status='live', Symbol='NUCB1', Aliases=['CALNUC', 'NUC'], description='nucleobindin 1', other_designations='nucleobindin-1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48900312, end_position_on_the_genomic_accession=48923372, orientation='plus', exon_count=13, OMIM=[601323], no_hdr0=''),
    4925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4925, CurrentID=0, Status='live', Symbol='NUCB2', Aliases=['HEL-S-109', 'NEFA'], description='nucleobindin 2', other_designations='nucleobindin-2|DNA-binding protein NEFA|epididymis secretory protein Li 109|gastric cancer antigen Zg4|nesfatin 1|novel DNA binding/EF-hand/leucine zipper protein|nucleobinding 2|prepronesfatin', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17260337, end_position_on_the_genomic_accession=17349980, orientation='plus', exon_count=23, OMIM=[608020], no_hdr0=''),
    4926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4926, CurrentID=0, Status='live', Symbol='NUMA1', Aliases=['NMP-22', 'NUMA'], description='nuclear mitotic apparatus protein 1', other_designations='nuclear mitotic apparatus protein 1|SP-H antigen|centrophilin stabilizes mitotic spindle in mitotic cells|nuclear matrix protein-22|structural nuclear protein', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72002864, end_position_on_the_genomic_accession=72080686, orientation='minus', exon_count=38, OMIM=[164009], no_hdr0=''),
    4927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4927, CurrentID=0, Status='live', Symbol='NUP88', Aliases=['FADS4'], description='nucleoporin 88', other_designations='nuclear pore complex protein Nup88|karyoporin|nuclear pore complex protein 88|nucleoporin 88kDa|nucleoporin Nup88', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5384833, end_position_on_the_genomic_accession=5419662, orientation='minus', exon_count=18, OMIM=[602552], no_hdr0=''),
    4928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4928, CurrentID=0, Status='live', Symbol='NUP98', Aliases=['ADIR2', 'NUP196', 'NUP96', 'Nup98-96'], description='nucleoporin 98 and 96 precursor', other_designations='nuclear pore complex protein Nup98-Nup96|nuclear pore complex protein Nup98|GLFG-repeat containing nucleoporin|NUP98/PHF23 fusion 2 protein|Nup98-Nup96|nucleoporin 96|nucleoporin 98kD|nucleoporin 98kDa', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3675010, end_position_on_the_genomic_accession=3797554, orientation='minus', exon_count=34, OMIM=[601021], no_hdr0=''),
    4929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4929, CurrentID=0, Status='live', Symbol='NR4A2', Aliases=['HZF-3', 'NOT', 'NURR1', 'RNR1', 'TINUR'], description='nuclear receptor subfamily 4 group A member 2', other_designations='nuclear receptor subfamily 4 group A member 2|NGFI-B/nur77 beta-type transcription factor homolog|T-cell nuclear receptor NOT|immediate-early response protein NOT|intermediate-early receptor protein|nuclear receptor related 1|nur related protein-1, human homolog of|orphan nuclear receptor NR4A2|orphan nuclear receptor NURR1|transcriptionally inducible nuclear receptor related 1|transcriptionally-inducible nuclear receptor', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=156324432, end_position_on_the_genomic_accession=156332724, orientation='minus', exon_count=8, OMIM=[601828], no_hdr0=''),
    4931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4931, CurrentID=0, Status='live', Symbol='NVL', Aliases=['NVL2'], description='nuclear VCP like', other_designations='nuclear valosin-containing protein-like|NVLp', map_location='1q42.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224227345, end_position_on_the_genomic_accession=224330187, orientation='minus', exon_count=28, OMIM=[602426], no_hdr0=''),
    4935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4935, CurrentID=0, Status='live', Symbol='GPR143', Aliases=['NYS6', 'OA1'], description='G protein-coupled receptor 143', other_designations='G-protein coupled receptor 143|ocular albinism 1|ocular albinism type 1 protein', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=9725346, end_position_on_the_genomic_accession=9786260, orientation='minus', exon_count=12, OMIM=[300808], no_hdr0=''),
    4938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4938, CurrentID=0, Status='live', Symbol='OAS1', Aliases=['E18/E16', 'IFI-4', 'OIAS', 'OIASI'], description="2'-5'-oligoadenylate synthetase 1", other_designations="2'-5'-oligoadenylate synthase 1|(2-5')oligo(A) synthase 1|2',5'-oligo A synthetase 1|2'-5'-oligoadenylate synthetase 1, 40/46kDa|2'-5'-oligoisoadenylate synthetase 1|2-5A synthase 1|2-5A synthetase 1|E16 (2'-5') oligo A synthetase", map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112906956, end_position_on_the_genomic_accession=112933219, orientation='plus', exon_count=8, OMIM=[164350], no_hdr0=''),
    4939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4939, CurrentID=0, Status='live', Symbol='OAS2', Aliases=[], description="2'-5'-oligoadenylate synthetase 2", other_designations="2'-5'-oligoadenylate synthase 2|(2'-5')oligo(A) synthetase 2|2'-5'-oligoadenylate synthetase 2, 69/71kDa|2-5A synthase 2|p69 OAS / p71 OAS", map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112978466, end_position_on_the_genomic_accession=113011723, orientation='plus', exon_count=10, OMIM=[603350], no_hdr0=''),
    4940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4940, CurrentID=0, Status='live', Symbol='OAS3', Aliases=['p100', 'p100OAS'], description="2'-5'-oligoadenylate synthetase 3", other_designations="2'-5'-oligoadenylate synthase 3|(2-5')oligo(A) synthase 3|(2-5')oligo(A) synthetase 3|2'-5'-oligoadenylate synthetase 3, 100kDa|2'-5'oligoadenylate synthetase p100|2-5A synthase 3|2-5A synthetase 3|p100 OAS", map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112938463, end_position_on_the_genomic_accession=112973251, orientation='plus', exon_count=16, OMIM=[603351], no_hdr0=''),
    4942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4942, CurrentID=0, Status='live', Symbol='OAT', Aliases=['GACR', 'HOGAASE', 'OKT', 'OAT'], description='ornithine aminotransferase', other_designations='ornithine aminotransferase, mitochondrial|gyrate atrophy|ornithine delta-aminotransferase|ornithine-oxo-acid aminotransferase|testicular tissue protein Li 130', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124397303, end_position_on_the_genomic_accession=124418923, orientation='minus', exon_count=13, OMIM=[613349], no_hdr0=''),
    4943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4943, CurrentID=0, Status='live', Symbol='TBC1D25', Aliases=['MG81', 'OATL1'], description='TBC1 domain family member 25', other_designations='TBC1 domain family member 25|5SN3 snoRNA|ornithine aminotransferase-like 1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48539714, end_position_on_the_genomic_accession=48562609, orientation='plus', exon_count=7, OMIM=[311240], no_hdr0=''),
    4946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4946, CurrentID=0, Status='live', Symbol='OAZ1', Aliases=['AZ1', 'AZI', 'OAZ'], description='ornithine decarboxylase antizyme 1', other_designations='ornithine decarboxylase antizyme 1|ODC-Az|antizyme 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2269486, end_position_on_the_genomic_accession=2273488, orientation='plus', exon_count=5, OMIM=[601579], no_hdr0=''),
    4947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4947, CurrentID=0, Status='live', Symbol='OAZ2', Aliases=['AZ2'], description='ornithine decarboxylase antizyme 2', other_designations='ornithine decarboxylase antizyme 2|ODC-Az 2', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64687574, end_position_on_the_genomic_accession=64703281, orientation='minus', exon_count=5, OMIM=[604152], no_hdr0=''),
    4948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4948, CurrentID=0, Status='live', Symbol='OCA2', Aliases=['BEY', 'BEY1', 'BEY2', 'BOCA', 'D15S12', 'EYCL', 'EYCL2', 'EYCL3', 'HCL3', 'P', 'PED', 'SHEP1'], description='OCA2 melanosomal transmembrane protein', other_designations='P protein|P-protein|eye color 2 (central brown)|eye color 3 (brown)|hair color 3 (brown)|melanocyte-specific transporter protein|oculocutaneous albinism II (pink-eye dilution homolog, mouse)|pink-eyed dilution protein homolog|total brown iris pigmentation', map_location='15q12-q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=27719008, end_position_on_the_genomic_accession=28099342, orientation='minus', exon_count=30, OMIM=[611409], no_hdr0=''),
    4951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4951, CurrentID=0, Status='live', Symbol='OCM2', Aliases=['OCM', 'OM'], description='oncomodulin 2', other_designations='putative oncomodulin-2|parvalbumin beta', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97984700, end_position_on_the_genomic_accession=97990104, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    4952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4952, CurrentID=0, Status='live', Symbol='OCRL', Aliases=['DENT2', 'Dent-2', 'INPP5F', 'LOCR', 'NPHL2-1', 'OCRL1', 'OCRL'], description='OCRL inositol polyphosphate-5-phosphatase', other_designations='inositol polyphosphate 5-phosphatase OCRL|Lowe oculocerebrorenal syndrome protein|inositol polyphosphate 5-phosphatase OCRL-1|oculocerebrorenal syndrome of Lowe|phosphatidylinositol 3,4,5-triphosphate 5-phosphatase|phosphatidylinositol polyphosphate 5-phosphatase', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129540259, end_position_on_the_genomic_accession=129592556, orientation='plus', exon_count=24, OMIM=[300535], no_hdr0=''),
    4953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4953, CurrentID=0, Status='live', Symbol='ODC1', Aliases=['BABS', 'NEDBA', 'NEDBIA', 'ODC'], description='ornithine decarboxylase 1', other_designations='ornithine decarboxylase', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10439968, end_position_on_the_genomic_accession=10448327, orientation='minus', exon_count=13, OMIM=[165640], no_hdr0=''),
    4956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4956, CurrentID=0, Status='live', Symbol='ODF1', Aliases=['CT133', 'HSPB10', 'ODF', 'ODF2', 'ODF27', 'ODFP', 'ODFPG', 'ODFPGA', 'ODFPGB', 'RT7', 'SODF'], description='outer dense fiber of sperm tails 1', other_designations='outer dense fiber protein 1|cancer/testis antigen 133|heat shock protein beta-10|outer dense fiber of sperm tails, 27-kD', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=102551589, end_position_on_the_genomic_accession=102561018, orientation='plus', exon_count=2, OMIM=[182878], no_hdr0=''),
    4957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4957, CurrentID=0, Status='live', Symbol='ODF2', Aliases=['CT134/1', 'ODF2/2', 'ODF84', 'ODF2'], description='outer dense fiber of sperm tails 2', other_designations='outer dense fiber protein 2|cancer/testis antigen 134|cenexin 1|outer dense fiber of sperm tails, 84-kD|sperm tail structural protein|testis tissue sperm-binding protein Li 51e', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128455185, end_position_on_the_genomic_accession=128501292, orientation='plus', exon_count=26, OMIM=[602015], no_hdr0=''),
    4958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4958, CurrentID=0, Status='live', Symbol='OMD', Aliases=['OSAD', 'SLRR2C'], description='osteomodulin', other_designations='osteomodulin|KSPG osteomodulin|keratan sulfate proteoglycan osteomodulin|osteoadherin proteoglycan', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92412380, end_position_on_the_genomic_accession=92424471, orientation='minus', exon_count=3, OMIM=[618926], no_hdr0=''),
    4967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4967, CurrentID=0, Status='live', Symbol='OGDH', Aliases=['AKGDH', 'E1k', 'KGD1', 'OGDC2', 'OGDH'], description='oxoglutarate dehydrogenase', other_designations='2-oxoglutarate dehydrogenase, mitochondrial|2-oxoglutarate dehydrogenase complex component E1|OGDC-E1|oxoglutarate (alpha-ketoglutarate) dehydrogenase (lipoamide)|oxoglutarate decarboxylase|oxoglutarate dehydrogenase (succinyl-transferring)|testicular tissue protein Li 131', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44606572, end_position_on_the_genomic_accession=44709066, orientation='plus', exon_count=26, OMIM=[613022], no_hdr0=''),
    4968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4968, CurrentID=0, Status='live', Symbol='OGG1', Aliases=['HMMH', 'HOGG1', 'MUTM', 'OGH1'], description='8-oxoguanine DNA glycosylase', other_designations='N-glycosylase/DNA lyase|8-hydroxyguanine DNA glycosylase|AP lyase|DNA-apurinic or apyrimidinic site lyase|OGG1 type 1f', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9749952, end_position_on_the_genomic_accession=9788246, orientation='plus', exon_count=11, OMIM=[601982], no_hdr0=''),
    4969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4969, CurrentID=0, Status='live', Symbol='OGN', Aliases=['OG', 'OIF', 'SLRR3A'], description='osteoglycin', other_designations='mimecan|corneal keratan sulfate proteoglycan|mimecan proteoglycan|osteoinductive factor', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92383268, end_position_on_the_genomic_accession=92404699, orientation='minus', exon_count=7, OMIM=[602383], no_hdr0=''),
    4973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4973, CurrentID=0, Status='live', Symbol='OLR1', Aliases=['CLEC8A', 'LOX1', 'LOXIN', 'SCARE1', 'SLOX1'], description='oxidized low density lipoprotein receptor 1', other_designations='oxidized low-density lipoprotein receptor 1|C-type lectin domain family 8 member A|hLOX-1|lectin-type oxidized LDL receptor 1|ox LDL receptor 1|oxidized low density lipoprotein (lectin-like) receptor 1|oxidized low-density lipoprotein receptor 1, soluble form|scavenger receptor class E, member 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10158301, end_position_on_the_genomic_accession=10172132, orientation='minus', exon_count=6, OMIM=[602601], no_hdr0=''),
    4974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4974, CurrentID=0, Status='live', Symbol='OMG', Aliases=['OMGP'], description='oligodendrocyte myelin glycoprotein', other_designations='oligodendrocyte-myelin glycoprotein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31294647, end_position_on_the_genomic_accession=31297239, orientation='minus', exon_count=2, OMIM=[164345], no_hdr0=''),
    4975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4975, CurrentID=0, Status='live', Symbol='OMP', Aliases=[], description='olfactory marker protein', other_designations='olfactory marker protein|olfactory neuronal-specific protein', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77102840, end_position_on_the_genomic_accession=77103331, orientation='plus', exon_count=1, OMIM=[164340], no_hdr0=''),
    4976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4976, CurrentID=0, Status='live', Symbol='OPA1', Aliases=['BERHS', 'MGM1', 'MTDPS14', 'NPG', 'NTG', 'largeG'], description='OPA1 mitochondrial dynamin like GTPase', other_designations='dynamin-like 120 kDa protein, mitochondrial|dynamin-like guanosine triphosphatase|mitochondrial dynamin-like GTPase|optic atrophy 1 (autosomal dominant)|optic atrophy protein 1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=193593149, end_position_on_the_genomic_accession=193697811, orientation='plus', exon_count=32, OMIM=[605290], no_hdr0=''),
    4978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4978, CurrentID=0, Status='live', Symbol='OPCML', Aliases=['IGLON1', 'OBCAM', 'OPCM'], description='opioid binding protein/cell adhesion molecule like', other_designations='opioid-binding protein/cell adhesion molecule|IgLON family member 1|opioid binding protein/cell adhesion molecule-like preprotein', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=132403361, end_position_on_the_genomic_accession=133532534, orientation='minus', exon_count=11, OMIM=[600632], no_hdr0=''),
    4982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4982, CurrentID=0, Status='live', Symbol='TNFRSF11B', Aliases=['OCIF', 'OPG', 'PDB5', 'TR1'], description='TNF receptor superfamily member 11b', other_designations='tumor necrosis factor receptor superfamily member 11B|osteoclastogenesis inhibitory factor|osteoprotegerin|tumor necrosis factor receptor superfamily, member 11b', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=118923557, end_position_on_the_genomic_accession=118951885, orientation='minus', exon_count=5, OMIM=[602643], no_hdr0=''),
    4983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4983, CurrentID=0, Status='live', Symbol='OPHN1', Aliases=['ARHGAP41', 'MRX60', 'OPN1'], description='oligophrenin 1', other_designations='oligophrenin-1|mental retardation, X-linked 60|oligophrenin-1, Rho-GTPase activating protein', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=68042344, end_position_on_the_genomic_accession=68433841, orientation='minus', exon_count=27, OMIM=[300127], no_hdr0=''),
    4985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4985, CurrentID=0, Status='live', Symbol='OPRD1', Aliases=['DOP', 'DOR', 'DOR1', 'OPRD'], description='opioid receptor delta 1', other_designations='delta-type opioid receptor|D-OR-1|DOR-1|delta opioid receptor 1', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28812170, end_position_on_the_genomic_accession=28871267, orientation='plus', exon_count=3, OMIM=[165195], no_hdr0=''),
    4986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4986, CurrentID=0, Status='live', Symbol='OPRK1', Aliases=['K-OR-1', 'KOP', 'KOR', 'KOR-1', 'KOR1', 'OPRK'], description='opioid receptor kappa 1', other_designations='kappa-type opioid receptor|Opiate receptor, kappa-1|kappa opioid receptor', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=53225724, end_position_on_the_genomic_accession=53251637, orientation='minus', exon_count=5, OMIM=[165196], no_hdr0=''),
    4987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4987, CurrentID=0, Status='live', Symbol='OPRL1', Aliases=['KOR-3', 'KOR3', 'NOCIR', 'NOP', 'NOPr', 'OOR', 'OPRL', 'ORL1', 'PNOCR'], description='opioid related nociceptin receptor 1', other_designations='nociceptin receptor|kappa-type 3 opioid receptor|kappa3-related opioid receptor|nociceptin/orphanin FQ receptor|opiate receptor-like 1|orphanin FQ receptor', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64080082, end_position_on_the_genomic_accession=64100643, orientation='plus', exon_count=8, OMIM=[602548], no_hdr0=''),
    4988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4988, CurrentID=0, Status='live', Symbol='OPRM1', Aliases=['LMOR', 'M-OR-1', 'MOP', 'MOR', 'MOR1', 'OPRM'], description='opioid receptor mu 1', other_designations='mu-type opioid receptor|mu opiate receptor|mu opioid receptor hMOR-1a', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=154010496, end_position_on_the_genomic_accession=154246867, orientation='plus', exon_count=17, OMIM=[600018], no_hdr0=''),
    4990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4990, CurrentID=0, Status='live', Symbol='SIX6', Aliases=['MCOPCT2', 'ODRMD', 'OPTX2', 'Six9'], description='SIX homeobox 6', other_designations='homeobox protein SIX6|homeodomain protein OPTX2|optic homeobox 2|sine oculis homeobox homolog 6|sine oculis homeobox protein 6|sine oculis homeobox-like protein 6', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60509146, end_position_on_the_genomic_accession=60512850, orientation='plus', exon_count=2, OMIM=[606326], no_hdr0=''),
    4991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4991, CurrentID=0, Status='live', Symbol='OR1D2', Aliases=['OLFR1', 'OR17-4'], description='olfactory receptor family 1 subfamily D member 2', other_designations='olfactory receptor 1D2|olfactory receptor 17-4|olfactory receptor OR17-6|olfactory receptor-like protein HGMP07E', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3088484, end_position_on_the_genomic_accession=3104422, orientation='minus', exon_count=2, OMIM=[164342], no_hdr0=''),
    4992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4992, CurrentID=0, Status='live', Symbol='OR1F1', Aliases=['OLFMF', 'OR16-36', 'OR16-37', 'OR16-88', 'OR16-89', 'OR16-900', 'OR1F13P', 'OR1F4', 'OR1F5', 'OR1F6', 'OR1F7', 'OR1F8', 'OR1F9', 'OR3-145', 'ORL1023', 'OR1F1'], description='olfactory receptor family 1 subfamily F member 1', other_designations='olfactory receptor 1F1|olfactory receptor, family 1, subfamily F, member 10|olfactory receptor, family 1, subfamily F, member 13 pseudogene|olfactory receptor, family 1, subfamily F, member 4|olfactory receptor, family 1, subfamily F, member 5|olfactory receptor, family 1, subfamily F, member 6|olfactory receptor, family 1, subfamily F, member 7|olfactory receptor, family 1, subfamily F, member 9', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3188204, end_position_on_the_genomic_accession=3206556, orientation='plus', exon_count=6, OMIM=[603232], no_hdr0=''),
    4993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4993, CurrentID=0, Status='live', Symbol='OR2C1', Aliases=['OLFmf3', 'OR2C2P'], description='olfactory receptor family 2 subfamily C member 1', other_designations='olfactory receptor 2C1|olfactory receptor 2C2|olfactory receptor OR16-1|olfactory receptor OR16-2|olfactory receptor, family 2, subfamily C, member 2 pseudogene', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3355889, end_position_on_the_genomic_accession=3357306, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    4994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4994, CurrentID=0, Status='live', Symbol='OR3A1', Aliases=['OLFRA03', 'OR17-40', 'OR17-82', 'OR40'], description='olfactory receptor family 3 subfamily A member 1', other_designations='olfactory receptor 3A1|Olfactory receptor-like protein OR17-82|olfactory receptor 17-40|olfactory receptor OR17-15', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3288318, end_position_on_the_genomic_accession=3299190, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    4995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4995, CurrentID=0, Status='live', Symbol='OR3A2', Aliases=['OLFRA04', 'OR17-14', 'OR17-228', 'OR228'], description='olfactory receptor family 3 subfamily A member 2', other_designations='olfactory receptor 3A2|olfactory receptor 17-228|olfactory receptor OR17-14', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3276113, end_position_on_the_genomic_accession=3386311, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    4998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4998, CurrentID=0, Status='live', Symbol='ORC1', Aliases=['HSORC1L', 'PARC1', 'ORC1'], description='origin recognition complex subunit 1', other_designations='origin recognition complex subunit 1|origin recognition complex, subunit 1 homolog|replication control protein 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52372829, end_position_on_the_genomic_accession=52404446, orientation='minus', exon_count=18, OMIM=[601902], no_hdr0=''),
    4999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=4999, CurrentID=0, Status='live', Symbol='ORC2', Aliases=['ORC2L'], description='origin recognition complex subunit 2', other_designations='origin recognition complex subunit 2|origin recognition complex protein 2 homolog|origin recognition complex, subunit 2 homolog', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200908977, end_position_on_the_genomic_accession=200963701, orientation='minus', exon_count=19, OMIM=[601182], no_hdr0=''),
    5000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5000, CurrentID=0, Status='live', Symbol='ORC4', Aliases=['ORC4LP', 'ORC4'], description='origin recognition complex subunit 4', other_designations='origin recognition complex subunit 4|origin recognition complex, subunit 4 homolog', map_location='2q23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=147930396, end_position_on_the_genomic_accession=148021551, orientation='minus', exon_count=18, OMIM=[603056], no_hdr0=''),
    5001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5001, CurrentID=0, Status='live', Symbol='ORC5', Aliases=['ORC5LP', 'ORC5T', 'PPP1R117', 'ORC5'], description='origin recognition complex subunit 5', other_designations='origin recognition complex subunit 5|protein phosphatase 1, regulatory subunit 117', map_location='7q22.1-q22.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=104126341, end_position_on_the_genomic_accession=104208013, orientation='minus', exon_count=15, OMIM=[602331], no_hdr0=''),
    5002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5002, CurrentID=0, Status='live', Symbol='SLC22A18', Aliases=['BWR1A', 'BWSCR1A', 'HET', 'IMPT1', 'ITM', 'ORCTL2', 'SLC22A1L', 'TSSC5', 'p45-BWR1A'], description='solute carrier family 22 member 18', other_designations='solute carrier family 22 member 18|beckwith-Wiedemann syndrome chromosomal region 1 candidate gene A protein|efflux transporter-like protein|imprinted multi-membrane-spanning polyspecific transporter-related protein 1|organic cation transporter-like protein 2|p45 Beckwith-Wiedemann region 1A|tumor-suppressing STF cDNA 5 protein|tumor-suppressing subchromosomal transferable fragment candidate gene 5 protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2899691, end_position_on_the_genomic_accession=2925246, orientation='plus', exon_count=14, OMIM=[602631], no_hdr0=''),
    5004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5004, CurrentID=0, Status='live', Symbol='ORM1', Aliases=['AGP-A', 'AGP1', 'HEL-S-153w', 'ORM'], description='orosomucoid 1', other_designations='alpha-1-acid glycoprotein 1|AGP 1|OMD 1|epididymis secretory sperm binding protein Li 153w', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114323098, end_position_on_the_genomic_accession=114326479, orientation='plus', exon_count=6, OMIM=[138600], no_hdr0=''),
    5005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5005, CurrentID=0, Status='live', Symbol='ORM2', Aliases=['AGP-B', "AGP-B'", 'AGP2'], description='orosomucoid 2', other_designations='alpha-1-acid glycoprotein 2|AGP 2|OMD 2|alpha-1-acid glycoprotein, type 2', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114329869, end_position_on_the_genomic_accession=114333251, orientation='plus', exon_count=6, OMIM=[138610], no_hdr0=''),
    5007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5007, CurrentID=0, Status='live', Symbol='OSBP', Aliases=['OSBP1'], description='oxysterol binding protein', other_designations='oxysterol-binding protein 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59574398, end_position_on_the_genomic_accession=59615774, orientation='minus', exon_count=14, OMIM=[167040], no_hdr0=''),
    5008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5008, CurrentID=0, Status='live', Symbol='OSM', Aliases=[], description='oncostatin M', other_designations='oncostatin-M', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30262829, end_position_on_the_genomic_accession=30266851, orientation='minus', exon_count=4, OMIM=[165095], no_hdr0=''),
    5009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5009, CurrentID=0, Status='live', Symbol='OTC', Aliases=['OCTDD', 'OTC'], description='ornithine transcarbamylase', other_designations='ornithine transcarbamylase, mitochondrial|OTCase|ornithine carbamoyltransferase, mitochondrial', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=38352528, end_position_on_the_genomic_accession=38421446, orientation='plus', exon_count=10, OMIM=[300461], no_hdr0=''),
    5010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5010, CurrentID=0, Status='live', Symbol='CLDN11', Aliases=['HLD22', 'OSP', 'OTM'], description='claudin 11', other_designations='claudin-11|oligodendrocyte transmembrane protein|oligodendrocyte-specific protein', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170418868, end_position_on_the_genomic_accession=170434691, orientation='plus', exon_count=4, OMIM=[601326], no_hdr0=''),
    5013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5013, CurrentID=0, Status='live', Symbol='OTX1', Aliases=[], description='orthodenticle homeobox 1', other_designations='homeobox protein OTX1|orthodenticle homolog 1', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=63049735, end_position_on_the_genomic_accession=63057831, orientation='plus', exon_count=6, OMIM=[600036], no_hdr0=''),
    5015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5015, CurrentID=0, Status='live', Symbol='OTX2', Aliases=['CPHD6', 'MCOPS5'], description='orthodenticle homeobox 2', other_designations='homeobox protein OTX2|orthodenticle homolog 2', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=56799905, end_position_on_the_genomic_accession=56810479, orientation='minus', exon_count=5, OMIM=[600037], no_hdr0=''),
    5016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5016, CurrentID=0, Status='live', Symbol='OVGP1', Aliases=['CHIT5', 'EGP', 'MUC9', 'OGP'], description='oviductal glycoprotein 1', other_designations='oviduct-specific glycoprotein|estrogen-dependent oviduct protein|mucin 9|oviduct glycoprotein|oviductal glycoprotein 1, 120kDa|oviductin', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111414319, end_position_on_the_genomic_accession=111427735, orientation='minus', exon_count=11, OMIM=[603578], no_hdr0=''),
    5017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5017, CurrentID=0, Status='live', Symbol='OVOL1', Aliases=['HOVO1'], description='ovo like transcriptional repressor 1', other_designations='putative transcription factor Ovo-like 1|ovo homolog-like 1|ovo like zinc finger 1|ovo-like 1(Drosophila)', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65787063, end_position_on_the_genomic_accession=65797219, orientation='plus', exon_count=9, OMIM=[602313], no_hdr0=''),
    5018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5018, CurrentID=0, Status='live', Symbol='OXA1L', Aliases=['OXA1'], description='OXA1L mitochondrial inner membrane protein', other_designations='mitochondrial inner membrane protein OXA1L|OXA1-like protein|epididymis secretory sperm binding protein|oxidase (cytochrome c) assembly 1-like', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22766688, end_position_on_the_genomic_accession=22773042, orientation='plus', exon_count=10, OMIM=[601066], no_hdr0=''),
    5019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5019, CurrentID=0, Status='live', Symbol='OXCT1', Aliases=['OXCT', 'SCOT'], description='3-oxoacid CoA-transferase 1', other_designations='succinyl-CoA:3-ketoacid coenzyme A transferase 1, mitochondrial|3-oxoacid CoA transferase|SCOT-s|epididymis secretory sperm binding protein|somatic-type succinyl-CoA:3-oxoacid CoA-transferase|succinyl CoA:3-oxoacid CoA transferase|succinyl-CoA:3-ketoacid-CoA transferase', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=41730065, end_position_on_the_genomic_accession=41870535, orientation='minus', exon_count=19, OMIM=[601424], no_hdr0=''),
    5020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5020, CurrentID=0, Status='live', Symbol='OXT', Aliases=['OT', 'OT-NPI-NPI', 'OXT'], description='oxytocin/neurophysin I prepropeptide', other_designations='oxytocin-neurophysin 1|neurophysin I|oxytocin, prepro- (neurophysin I)|oxytocin, prepropeptide|oxytocin-neurophysin I, preproprotein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3068871, end_position_on_the_genomic_accession=3072517, orientation='plus', exon_count=4, OMIM=[167050], no_hdr0=''),
    5021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5021, CurrentID=0, Status='live', Symbol='OXTR', Aliases=['OT-R', 'OTR'], description='oxytocin receptor', other_designations='oxytocin receptor', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8750381, end_position_on_the_genomic_accession=8769613, orientation='minus', exon_count=6, OMIM=[167055], no_hdr0=''),
    5023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5023, CurrentID=0, Status='live', Symbol='P2RX1', Aliases=['P2X1'], description='purinergic receptor P2X 1', other_designations='P2X purinoceptor 1|ATP receptor|P2X receptor, subunit 1|P2X1 receptor|purinergic receptor P2X, ligand gated ion channel, 1|purinergic receptor P2X1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3896591, end_position_on_the_genomic_accession=3916506, orientation='minus', exon_count=12, OMIM=[600845], no_hdr0=''),
    5024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5024, CurrentID=0, Status='live', Symbol='P2RX3', Aliases=['P2X3'], description='purinergic receptor P2X 3', other_designations='P2X purinoceptor 3|ATP receptor|P2X receptor, subunit 3|purinergic receptor P2X, ligand gated ion channel, 3|purinergic receptor P2X3|purinoceptor P2X3', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57335943, end_position_on_the_genomic_accession=57372399, orientation='plus', exon_count=16, OMIM=[600843], no_hdr0=''),
    5025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5025, CurrentID=0, Status='live', Symbol='P2RX4', Aliases=['P2X4', 'P2X4R'], description='purinergic receptor P2X 4', other_designations='P2X purinoceptor 4|ATP receptor|ATP-gated cation channel protein|P2X receptor, subunit 4|purinergic receptor P2X, ligand gated ion channel, 4|purinergic receptor P2X4|purinoceptor P2X4', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121210096, end_position_on_the_genomic_accession=121234106, orientation='plus', exon_count=14, OMIM=[600846], no_hdr0=''),
    5026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5026, CurrentID=0, Status='live', Symbol='P2RX5', Aliases=['LRH-1', 'P2X5', 'P2X5R'], description='purinergic receptor P2X 5', other_designations='P2X purinoceptor 5|ATP receptor subunit|ionotropic ATP receptor P2X5|lymphoid-restricted histocompatibility antigen-1|purinergic receptor P2X, ligand gated ion channel, 5', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3673227, end_position_on_the_genomic_accession=3696155, orientation='minus', exon_count=12, OMIM=[602836], no_hdr0=''),
    5027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5027, CurrentID=0, Status='live', Symbol='P2RX7', Aliases=['P2X7'], description='purinergic receptor P2X 7', other_designations='P2X purinoceptor 7|ATP receptor|P2X7 receptor|P2Z receptor|purinergic receptor P2X, ligand gated ion channel, 7|purinergic receptor P2X7 variant A|purnergic receptor P2X 7', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121132819, end_position_on_the_genomic_accession=121188032, orientation='plus', exon_count=13, OMIM=[602566], no_hdr0=''),
    5028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5028, CurrentID=0, Status='live', Symbol='P2RY1', Aliases=['P2Y1', 'SARCC'], description='purinergic receptor P2Y1', other_designations='P2Y purinoceptor 1|ADP receptor|ATP receptor|P2 purinoceptor subtype Y1|platelet ADP receptor|purinergic receptor P2Y, G-protein coupled, 1|suppressing androgen receptor in renal cell carcinoma', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=152835131, end_position_on_the_genomic_accession=152841439, orientation='plus', exon_count=1, OMIM=[601167], no_hdr0=''),
    5029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5029, CurrentID=0, Status='live', Symbol='P2RY2', Aliases=['HP2U', 'P2RU1', 'P2U', 'P2U1', 'P2UR', 'P2Y2', 'P2Y2R'], description='purinergic receptor P2Y2', other_designations='P2Y purinoceptor 2|ATP receptor|P2U nucleotide receptor|P2U purinoceptor 1|P2U receptor 1|purinergic receptor P2Y, G-protein coupled, 2|purinoceptor P2Y2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73218281, end_position_on_the_genomic_accession=73242427, orientation='plus', exon_count=4, OMIM=[600041], no_hdr0=''),
    5030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5030, CurrentID=0, Status='live', Symbol='P2RY4', Aliases=['NRU', 'P2P', 'P2Y4', 'UNR'], description='pyrimidinergic receptor P2Y4', other_designations='P2Y purinoceptor 4|pyrimidinergic receptor P2Y, G-protein coupled, 4|uridine nucleotide receptor', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70258166, end_position_on_the_genomic_accession=70260204, orientation='minus', exon_count=1, OMIM=[300038], no_hdr0=''),
    5031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5031, CurrentID=0, Status='live', Symbol='P2RY6', Aliases=['P2Y6'], description='pyrimidinergic receptor P2Y6', other_designations='P2Y purinoceptor 6|G-coupled nucleotide receptor|P2 purinoceptor|P2Y6 receptor|pyrimidinergic receptor P2Y, G-protein coupled, 6', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73264503, end_position_on_the_genomic_accession=73298625, orientation='plus', exon_count=7, OMIM=[602451], no_hdr0=''),
    5032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5032, CurrentID=0, Status='live', Symbol='P2RY11', Aliases=['P2Y11'], description='purinergic receptor P2Y11', other_designations='P2Y purinoceptor 11|purinergic receptor P2Y, G-protein coupled, 11', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10111693, end_position_on_the_genomic_accession=10115372, orientation='plus', exon_count=2, OMIM=[602697], no_hdr0=''),
    5033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5033, CurrentID=0, Status='live', Symbol='P4HA1', Aliases=['P4HA'], description='prolyl 4-hydroxylase subunit alpha 1', other_designations='prolyl 4-hydroxylase subunit alpha-1|C-P4Halpha(I)|collagen prolyl 4-hydroxylase alpha(I)|procollagen-proline, 2-oxoglutarate 4-dioxygenase (proline 4-hydroxylase), alpha polypeptide I|procollagen-proline,2-oxoglutarate-4-dioxygenase subunit alpha-1|prolyl 4-hydroxylase, alpha polypeptide I', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73007217, end_position_on_the_genomic_accession=73096866, orientation='minus', exon_count=17, OMIM=[176710], no_hdr0=''),
    5034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5034, CurrentID=0, Status='live', Symbol='P4HB', Aliases=['CLCRP1', 'DSI', 'ERBA2L', 'GIT', 'P4Hbeta', 'PDI', 'PDIA1', 'PHDB', 'PO4DB', 'PO4HB', 'PROHB'], description='prolyl 4-hydroxylase subunit beta', other_designations='protein disulfide-isomerase|cellular thyroid hormone-binding protein|collagen prolyl 4-hydroxylase beta|glutathione-insulin transhydrogenase|p55|procollagen-proline, 2-oxoglutarate 4-dioxygenase (proline 4-hydroxylase), beta polypeptide|prolyl 4-hydroxylase, beta polypeptide|protein disulfide isomerase family A, member 1|protein disulfide isomerase-associated 1|protein disulfide isomerase/oxidoreductase|protocollagen hydroxylase|testicular secretory protein Li 32|thyroid hormone-binding protein p55', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81843159, end_position_on_the_genomic_accession=81860535, orientation='minus', exon_count=10, OMIM=[176790], no_hdr0=''),
    5036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5036, CurrentID=0, Status='live', Symbol='PA2G4', Aliases=['EBP1', 'HG4-1', 'p38-2G4'], description='proliferation-associated 2G4', other_designations='proliferation-associated protein 2G4|ErbB-3 binding protein 1|ErbB3-binding protein Ebp1|cell cycle protein p38-2G4 homolog|erbB3-binding protein 1|proliferation-associated 2G4, 38kD|proliferation-associated 2G4, 38kDa', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56104559, end_position_on_the_genomic_accession=56113910, orientation='plus', exon_count=13, OMIM=[602145], no_hdr0=''),
    5037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5037, CurrentID=0, Status='live', Symbol='PEBP1', Aliases=['HCNP', 'HCNPpp', 'HEL-210', 'HEL-S-34', 'HEL-S-96', 'PBP', 'PEBP', 'PEBP-1', 'RKIP'], description='phosphatidylethanolamine binding protein 1', other_designations='phosphatidylethanolamine-binding protein 1|Raf kinase inhibitory protein|epididymis luminal protein 210|epididymis secretory protein Li 34|epididymis secretory protein Li 96|hippocampal cholinergic neurostimulating peptide|neuropolypeptide h3|prostatic binding protein|raf kinase inhibitor protein', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118136124, end_position_on_the_genomic_accession=118145584, orientation='plus', exon_count=4, OMIM=[604591], no_hdr0=''),
    5042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5042, CurrentID=0, Status='live', Symbol='PABPC3', Aliases=['PABP3', 'PABPL3', 'tPABP'], description='poly(A) binding protein cytoplasmic 3', other_designations='polyadenylate-binding protein 3|PABP-3|poly(A)-binding protein 3|poly(A)-binding protein-like 3|testis PABP|testis-specific poly(A)-binding protein (PABP)|testis-specific poly(A)-binding protein 3', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=25096136, end_position_on_the_genomic_accession=25099254, orientation='plus', exon_count=1, OMIM=[604680], no_hdr0=''),
    5045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5045, CurrentID=0, Status='live', Symbol='FURIN', Aliases=['FUR', 'PACE', 'PCSK3', 'SPC1'], description='furin, paired basic amino acid cleaving enzyme', other_designations='furin|FES upstream region|dibasic processing enzyme|furin, membrane associated receptor protein|paired basic amino acid residue-cleaving enzyme|proprotein convertase subtilisin/kexin 3|proprotein convertase subtilisin/kexin type 3|subtilisin-like proprotein convertase 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90868588, end_position_on_the_genomic_accession=90883457, orientation='plus', exon_count=20, OMIM=[136950], no_hdr0=''),
    5046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5046, CurrentID=0, Status='live', Symbol='PCSK6', Aliases=['PACE4', 'SPC4'], description='proprotein convertase subtilisin/kexin type 6', other_designations='proprotein convertase subtilisin/kexin type 6|paired basic amino acid cleaving enzyme 4|paired basic amino acid cleaving system 4|subtilisin-like proprotein convertase 4|subtilisin/kexin-like protease PACE4', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101303933, end_position_on_the_genomic_accession=101489707, orientation='minus', exon_count=24, OMIM=[167405], no_hdr0=''),
    5047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5047, CurrentID=0, Status='live', Symbol='PAEP', Aliases=['GD', 'GdA', 'GdF', 'GdS', 'PAEG', 'PEP', 'PP14', 'ZIF-1'], description='progestagen associated endometrial protein', other_designations='glycodelin|PEG|PP14 protein (placental protein 14)|alpha uterine protein|glycodelin-A|glycodelin-F|glycodelin-S|placental protein 14|pregnancy-associated endometrial alpha-2 globulin|progestagen-associated endometrial protein (placental protein 14, pregnancy-associated endometrial a|progesterone-associated endometrial protein|zona-binding inhibitory factor-1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135561627, end_position_on_the_genomic_accession=135566955, orientation='plus', exon_count=7, OMIM=[173310], no_hdr0=''),
    5048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5048, CurrentID=0, Status='live', Symbol='PAFAH1B1', Aliases=['LIS1', 'LIS2', 'MDCR', 'MDS', 'NudF', 'PAFAH'], description='platelet activating factor acetylhydrolase 1b regulatory subunit 1', other_designations='platelet-activating factor acetylhydrolase IB subunit beta|lissencephaly 1 protein|platelet-activating factor acetylhydrolase 1b, regulatory subunit 1 (45kDa)', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2593210, end_position_on_the_genomic_accession=2685617, orientation='plus', exon_count=16, OMIM=[601545], no_hdr0=''),
    5049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5049, CurrentID=0, Status='live', Symbol='PAFAH1B2', Aliases=['HEL-S-303'], description='platelet activating factor acetylhydrolase 1b catalytic subunit 2', other_designations='platelet-activating factor acetylhydrolase IB subunit alpha2|PAF acetylhydrolase 30 kDa subunit|PAF-AH 30 kDa subunit|PAF-AH subunit beta|PAF-AH1b alpha 2 subunit|PAFAH subunit beta|epididymis secretory protein Li 303|epididymis secretory sperm binding protein|intracellular platelet-activating factor acetylhydrolase alpha 2 subunit|platelet-activating factor acetylhydrolase 1b, catalytic subunit 2 (30kDa)|platelet-activating factor acetylhydrolase IB subunit beta', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117144287, end_position_on_the_genomic_accession=117178173, orientation='plus', exon_count=10, OMIM=[602508], no_hdr0=''),
    5050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5050, CurrentID=0, Status='live', Symbol='PAFAH1B3', Aliases=['PAFAHG'], description='platelet activating factor acetylhydrolase 1b catalytic subunit 3', other_designations='platelet-activating factor acetylhydrolase IB subunit alpha1|PAF acetylhydrolase 29 kDa subunit|PAF-AH 29 kDa subunit|PAF-AH subunit gamma|PAF-AH1b alpha 1 subunit|PAFAH subunit gamma|epididymis secretory sperm binding protein|platelet-activating factor acetylhydrolase 1b, catalytic subunit 3 (29kDa)|platelet-activating factor acetylhydrolase IB subunit gamma', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42297033, end_position_on_the_genomic_accession=42302800, orientation='minus', exon_count=7, OMIM=[603074], no_hdr0=''),
    5051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5051, CurrentID=0, Status='live', Symbol='PAFAH2', Aliases=['HSD-PLA2'], description='platelet activating factor acetylhydrolase 2', other_designations='platelet-activating factor acetylhydrolase 2, cytoplasmic|PAF:lysophospholipid transacetylase|PAF:sphingosine transacetylase|SD-PLA2|platelet-activating factor acetylhydrolase 2, 40kDa|platelet-activating factor acetyltransferase PAFAH2|serine-dependent phospholipase A2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25959764, end_position_on_the_genomic_accession=25998164, orientation='minus', exon_count=13, OMIM=[602344], no_hdr0=''),
    5052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5052, CurrentID=0, Status='live', Symbol='PRDX1', Aliases=['MSP23', 'NKEF-A', 'NKEFA', 'PAG', 'PAGA', 'PAGB', 'PRX1', 'PRXI', 'TDPX2'], description='peroxiredoxin 1', other_designations='peroxiredoxin-1|epididymis secretory sperm binding protein|natural killer cell-enhancing factor A|natural killer-enhancing factor A|proliferation-associated gene A|proliferation-associated gene protein|thioredoxin peroxidase 2|thioredoxin-dependent peroxide reductase 2|thioredoxin-dependent peroxiredoxin 1', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45511051, end_position_on_the_genomic_accession=45522890, orientation='minus', exon_count=7, OMIM=[176763], no_hdr0=''),
    5053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5053, CurrentID=0, Status='live', Symbol='PAH', Aliases=['PH', 'PKU', 'PKU1'], description='phenylalanine hydroxylase', other_designations='phenylalanine-4-hydroxylase|phe-4-monooxygenase|phenylalanine 4-monooxygenase', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102836889, end_position_on_the_genomic_accession=102958441, orientation='minus', exon_count=15, OMIM=[612349], no_hdr0=''),
    5054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5054, CurrentID=0, Status='live', Symbol='SERPINE1', Aliases=['PAI', 'PAI-1', 'PAI1', 'PLANH1'], description='serpin family E member 1', other_designations='plasminogen activator inhibitor 1|endothelial plasminogen activator inhibitor|serine (or cysteine) proteinase inhibitor, clade E (nexin, plasminogen activator inhibitor type 1), member 1|serpin E1|serpin peptidase inhibitor, clade E (nexin, plasminogen activator inhibitor type 1), member 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101127104, end_position_on_the_genomic_accession=101139247, orientation='plus', exon_count=9, OMIM=[173360], no_hdr0=''),
    5055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5055, CurrentID=0, Status='live', Symbol='SERPINB2', Aliases=['HsT1201', 'PAI', 'PAI-2', 'PAI2', 'PLANH2'], description='serpin family B member 2', other_designations='plasminogen activator inhibitor 2|monocyte Arg-serpin|placental plasminogen activator inhibitor|plasminogen activator inhibitor, type II (arginine-serpin)|plasminogen-activator inhibitor|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 2|serpin B2|serpin peptidase inhibitor, clade B (ovalbumin), member 2|urokinase inhibitor', map_location='18q21.33-q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63887705, end_position_on_the_genomic_accession=63903890, orientation='plus', exon_count=10, OMIM=[173390], no_hdr0=''),
    5058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5058, CurrentID=0, Status='live', Symbol='PAK1', Aliases=['IDDMSSD', 'PAKalpha', 'alpha-PAK', 'p65-PAK'], description='p21 (RAC1) activated kinase 1', other_designations='serine/threonine-protein kinase PAK 1|STE20 homolog, yeast|p21 protein (Cdc42/Rac)-activated kinase 1|p21/Cdc42/Rac1-activated kinase 1 (STE20 homolog, yeast)|p21/Cdc42/Rac1-activated kinase 1 (yeast Ste20-related)', map_location='11q13.5-q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77322017, end_position_on_the_genomic_accession=77514957, orientation='minus', exon_count=26, OMIM=[602590], no_hdr0=''),
    5062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5062, CurrentID=0, Status='live', Symbol='PAK2', Aliases=['PAK65', 'PAKgamma'], description='p21 (RAC1) activated kinase 2', other_designations='serine/threonine-protein kinase PAK 2|PAK-2|S6/H4 kinase|gamma-PAK|p21 (CDKN1A)-activated kinase 2|p21 protein (Cdc42/Rac)-activated kinase 2|p21-activated kinase 2|p58', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196739857, end_position_on_the_genomic_accession=196832647, orientation='plus', exon_count=16, OMIM=[605022], no_hdr0=''),
    5063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5063, CurrentID=0, Status='live', Symbol='PAK3', Aliases=['ARA', 'MRX30', 'MRX47', 'OPHN3', 'PAK-3beta', 'bPAK', 'beta-PAK', 'PAK3'], description='p21 (RAC1) activated kinase 3', other_designations='serine/threonine-protein kinase PAK 3|adriamycin resistance-associated|oligophrenin-3|p21 (CDKN1A)-activated kinase 3|p21 protein (Cdc42/Rac)-activated kinase 3', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=110944324, end_position_on_the_genomic_accession=111227361, orientation='plus', exon_count=29, OMIM=[300142], no_hdr0=''),
    5064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5064, CurrentID=0, Status='live', Symbol='PALM', Aliases=['PALM1'], description='paralemmin', other_designations='paralemmin-1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=708935, end_position_on_the_genomic_accession=748329, orientation='plus', exon_count=11, OMIM=[608134], no_hdr0=''),
    5066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5066, CurrentID=0, Status='live', Symbol='PAM', Aliases=['PAL', 'PHM'], description='peptidylglycine alpha-amidating monooxygenase', other_designations='peptidyl-glycine alpha-amidating monooxygenase|pancreatic peptidylglycine alpha-amidating monooxygenase|peptidyl alpha-amidating enzyme|peptidyl-alpha-hydroxyglycine alpha-amidating lyase|peptidylamidoglycolate lyase|peptidylglycine 2-hydroxylase|peptidylglycine alpha-hydroxylating monooxygenase', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=102754783, end_position_on_the_genomic_accession=103031105, orientation='plus', exon_count=29, OMIM=[170270], no_hdr0=''),
    5067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5067, CurrentID=0, Status='live', Symbol='CNTN3', Aliases=['BIG-1', 'PANG', 'PCS'], description='contactin 3', other_designations='contactin-3|brain-derived immunoglobulin superfamily protein 1|contactin 3 (plasmacytoma associated)|plasmacytoma-associated neuronal glycoprotein', map_location='3p12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=74262568, end_position_on_the_genomic_accession=74614659, orientation='minus', exon_count=26, OMIM=[601325], no_hdr0=''),
    5068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5068, CurrentID=0, Status='live', Symbol='REG3A', Aliases=['HIP', 'HIP/PAP', 'INGAP', 'PAP', 'PAP-H', 'PAP1', 'PBCGF', 'REG-III', 'REG3'], description='regenerating family member 3 alpha', other_designations='regenerating islet-derived protein 3-alpha|PAP homologous protein|REG-3-alpha|hepatocarcinoma-intestine-pancreas|hepatointestinal pancreatic protein|human proislet peptide|pancreatic beta cell growth factor|pancreatitis-associated protein 1|proliferation-inducing protein 34|proliferation-inducing protein 42|reg III-alpha|regenerating islet-derived 3 alpha|regenerating islet-derived protein III-alpha', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=79157006, end_position_on_the_genomic_accession=79159753, orientation='minus', exon_count=6, OMIM=[167805], no_hdr0=''),
    5069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5069, CurrentID=0, Status='live', Symbol='PAPPA', Aliases=['ASBABP2', 'DIPLA1', 'IGFBP-4ase', 'PAPA', 'PAPP-A1', 'PAPPA'], description='pappalysin 1', other_designations='pappalysin-1|IGF-dependent IGFBP-4 protease|aspecific BCL2 ARE-binding protein 2|differentially placenta 1 expressed protein|insulin-like growth factor-dependent IGF binding protein-4 protease|pregnancy-associated plasma protein A, pappalysin 1', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=116153752, end_position_on_the_genomic_accession=116402321, orientation='plus', exon_count=22, OMIM=[176385], no_hdr0=''),
    5071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5071, CurrentID=0, Status='live', Symbol='PRKN', Aliases=['AR-JP', 'LPRS2', 'PARK2', 'PDJ'], description='parkin RBR E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase parkin|Parkinson disease (autosomal recessive, juvenile) 2, parkin|parkinson juvenile disease protein 2|parkinson protein 2 E3 ubiquitin protein ligase|parkinson protein 2, E3 ubiquitin protein ligase (parkin)', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=161347417, end_position_on_the_genomic_accession=162727802, orientation='minus', exon_count=14, OMIM=[602544], no_hdr0=''),
    5073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5073, CurrentID=0, Status='live', Symbol='PARN', Aliases=['DAN', 'DKCB6', 'PFBMFT4'], description='poly(A)-specific ribonuclease', other_designations='poly(A)-specific ribonuclease PARN|deadenylating nuclease|deadenylation nuclease|polyadenylate-specific ribonuclease', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14435701, end_position_on_the_genomic_accession=14630286, orientation='minus', exon_count=27, OMIM=[604212], no_hdr0=''),
    5074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5074, CurrentID=0, Status='live', Symbol='PAWR', Aliases=['PAR4', 'Par-4'], description='pro-apoptotic WT1 regulator', other_designations='PRKC apoptosis WT1 regulator protein|PRKC, apoptosis, WT1, regulator|WT1-interacting protein|prostate apoptosis response protein 4|prostate apoptosis response protein PAR-4|prostate apoptosis response-4|transcriptional repressor PAR4', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=79584879, end_position_on_the_genomic_accession=79691097, orientation='minus', exon_count=13, OMIM=[601936], no_hdr0=''),
    5075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5075, CurrentID=0, Status='live', Symbol='PAX1', Aliases=['HUP48', 'OFC2'], description='paired box 1', other_designations='paired box protein Pax-1|paired box gene 1|paired domain gene HuP48', map_location='20p11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=21705664, end_position_on_the_genomic_accession=21718481, orientation='plus', exon_count=5, OMIM=[167411], no_hdr0=''),
    5076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5076, CurrentID=0, Status='live', Symbol='PAX2', Aliases=['FSGS7', 'PAPRS'], description='paired box 2', other_designations='paired box protein Pax-2|paired box homeotic gene 2', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100735396, end_position_on_the_genomic_accession=100829944, orientation='plus', exon_count=14, OMIM=[167409], no_hdr0=''),
    5077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5077, CurrentID=0, Status='live', Symbol='PAX3', Aliases=['CDHS', 'HUP2', 'WS1', 'WS3'], description='paired box 3', other_designations='paired box protein Pax-3|paired box homeotic gene 3|paired domain gene 3|paired domain gene HuP2|transcriptional factor PAX3', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=222199887, end_position_on_the_genomic_accession=222298998, orientation='minus', exon_count=10, OMIM=[606597], no_hdr0=''),
    5078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5078, CurrentID=0, Status='live', Symbol='PAX4', Aliases=['KPD', 'MODY9'], description='paired box 4', other_designations='paired box protein Pax-4|paired box gene 4|paired domain gene 4', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127610292, end_position_on_the_genomic_accession=127618142, orientation='minus', exon_count=12, OMIM=[167413], no_hdr0=''),
    5079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5079, CurrentID=0, Status='live', Symbol='PAX5', Aliases=['ALL3', 'BSAP'], description='paired box 5', other_designations='paired box protein Pax-5|B-cell lineage specific activator|paired box homeotic gene 5|paired domain gene 5|transcription factor PAX 5', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36833269, end_position_on_the_genomic_accession=37034268, orientation='minus', exon_count=11, OMIM=[167414], no_hdr0=''),
    5080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5080, CurrentID=0, Status='live', Symbol='PAX6', Aliases=['AN', 'AN1', 'AN2', 'ASGD5', 'D11S812E', 'FVH1', 'MGDA', 'WAGR'], description='paired box 6', other_designations='paired box protein Pax-6|Aniridia 1|Aniridia 2|aniridia type II protein|oculorhombin|paired box homeotic gene-6', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=31789026, end_position_on_the_genomic_accession=31817961, orientation='minus', exon_count=25, OMIM=[607108], no_hdr0=''),
    5081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5081, CurrentID=0, Status='live', Symbol='PAX7', Aliases=['HUP1', 'MYOSCOB', 'RMS2', 'PAX7'], description='paired box 7', other_designations='paired box protein Pax-7|PAX7 transcriptional factor|paired box homeotic gene 7|paired domain gene 7', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18630846, end_position_on_the_genomic_accession=18748866, orientation='plus', exon_count=9, OMIM=[167410], no_hdr0=''),
    5082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5082, CurrentID=0, Status='live', Symbol='PDCL', Aliases=['PhLP'], description='phosducin like', other_designations='phosducin-like protein', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122818097, end_position_on_the_genomic_accession=122828588, orientation='minus', exon_count=4, OMIM=[604421], no_hdr0=''),
    5083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5083, CurrentID=0, Status='live', Symbol='PAX9', Aliases=['STHAG3'], description='paired box 9', other_designations='paired box protein Pax-9|paired domain gene 9', map_location='14q13.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=36657568, end_position_on_the_genomic_accession=36679362, orientation='plus', exon_count=5, OMIM=[167416], no_hdr0=''),
    5087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5087, CurrentID=0, Status='live', Symbol='PBX1', Aliases=['CAKUHED'], description='PBX homeobox 1', other_designations='pre-B-cell leukemia transcription factor 1|homeobox protein PBX1|homeobox protein PRL|pre-B-cell leukemia homeobox 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=164559184, end_position_on_the_genomic_accession=164886047, orientation='plus', exon_count=11, OMIM=[176310], no_hdr0=''),
    5089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5089, CurrentID=0, Status='live', Symbol='PBX2', Aliases=['G17', 'HOX12MHC', 'PBX2'], description='PBX homeobox 2', other_designations='pre-B-cell leukemia transcription factor 2|XXbac-BPG300A18.13|homeobox 12|homeobox protein PBX2|pre-B-cell leukemia homeobox 2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32184733, end_position_on_the_genomic_accession=32190202, orientation='minus', exon_count=9, OMIM=[176311], no_hdr0=''),
    5090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5090, CurrentID=0, Status='live', Symbol='PBX3', Aliases=[], description='PBX homeobox 3', other_designations='pre-B-cell leukemia transcription factor 3|homeobox protein PBX3|pre-B-cell leukemia homeobox 3', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125747372, end_position_on_the_genomic_accession=125967377, orientation='plus', exon_count=11, OMIM=[176312], no_hdr0=''),
    5091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5091, CurrentID=0, Status='live', Symbol='PC', Aliases=['PCB'], description='pyruvate carboxylase', other_designations='pyruvate carboxylase, mitochondrial|pyruvic carboxylase', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66848420, end_position_on_the_genomic_accession=66958418, orientation='minus', exon_count=32, OMIM=[608786], no_hdr0=''),
    5092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5092, CurrentID=0, Status='live', Symbol='PCBD1', Aliases=['DCOH', 'PCBD', 'PCD', 'PHS'], description='pterin-4 alpha-carbinolamine dehydratase 1', other_designations='pterin-4-alpha-carbinolamine dehydratase|4-alpha-hydroxy-tetrahydropterin dehydratase|6-pyruvoyl-tetrahydropterin synthase/dimerization cofactor of hepatocyte nuclear factor 1 alpha (TCF1)|dimerizing cofactor for HNF1|phenylalanine hydroxylase-stimulating protein|pterin-4 alpha-carbinolamine dehydratase/dimerization cofactor of hepatocyte nuclear factor 1 alpha', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70882280, end_position_on_the_genomic_accession=70888565, orientation='minus', exon_count=6, OMIM=[126090], no_hdr0=''),
    5093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5093, CurrentID=0, Status='live', Symbol='PCBP1', Aliases=['HEL-S-85', 'HNRPE1', 'HNRPX', 'hnRNP-E1', 'hnRNP-X'], description='poly(rC) binding protein 1', other_designations='poly(rC)-binding protein 1|alpha-CP1|epididymis secretory protein Li 85|heterogeneous nuclear ribonucleoprotein E1|heterogenous nuclear ribonucleoprotein E1|heterogenous nuclear ribonucleoprotein X|nucleic acid-binding protein SUB2.3', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70087477, end_position_on_the_genomic_accession=70089203, orientation='plus', exon_count=1, OMIM=[601209], no_hdr0=''),
    5094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5094, CurrentID=0, Status='live', Symbol='PCBP2', Aliases=['HNRNPE2', 'HNRPE2', 'hnRNP-E2'], description='poly(rC) binding protein 2', other_designations='poly(rC)-binding protein 2|alpha-CP2|epididymis secretory sperm binding protein|heterogeneous nuclear ribonucleoprotein E2|heterogenous nuclear ribonucleoprotein E2|hnRNP E2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53452102, end_position_on_the_genomic_accession=53481162, orientation='plus', exon_count=15, OMIM=[601210], no_hdr0=''),
    5095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5095, CurrentID=0, Status='live', Symbol='PCCA', Aliases=[], description='propionyl-CoA carboxylase subunit alpha', other_designations='propionyl-CoA carboxylase alpha chain, mitochondrial|PCCase alpha subunit|pccA complementation group|propanoyl-CoA:carbon dioxide ligase alpha subunit|propionyl CoA carboxylase, alpha polypeptide|propionyl Coenzyme A carboxylase, alpha polypeptide|propionyl-CoA carboxylase alpha subunit', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=100089020, end_position_on_the_genomic_accession=100530435, orientation='plus', exon_count=32, OMIM=[232000], no_hdr0=''),
    5096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5096, CurrentID=0, Status='live', Symbol='PCCB', Aliases=[], description='propionyl-CoA carboxylase subunit beta', other_designations='propionyl-CoA carboxylase beta chain, mitochondrial|PCCase subunit beta|propanoyl-CoA:carbon dioxide ligase subunit beta|propionyl CoA carboxylase, beta polypeptide|propionyl Coenzyme A carboxylase, beta polypeptide|propionyl-CoA carboxylase beta subunit', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136250340, end_position_on_the_genomic_accession=136330169, orientation='plus', exon_count=17, OMIM=[232050], no_hdr0=''),
    5097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5097, CurrentID=0, Status='live', Symbol='PCDH1', Aliases=['PC42', 'PCDH42'], description='protocadherin 1', other_designations='protocadherin-1|cadherin-like 1|cadherin-like protein 1|protocadherin 42', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141850393, end_position_on_the_genomic_accession=141878410, orientation='minus', exon_count=9, OMIM=[603626], no_hdr0=''),
    5098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5098, CurrentID=0, Status='live', Symbol='PCDHGC3', Aliases=['PC43', 'PCDH-GAMMA-C3', 'PCDH2'], description='protocadherin gamma subfamily C, 3', other_designations='protocadherin gamma-C3|cadherin-like 2|protocadherin 43|protocadherin-2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141475966, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[603627], no_hdr0=''),
    5099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5099, CurrentID=0, Status='live', Symbol='PCDH7', Aliases=['BH-Pcdh', 'BHPCDH', 'PPP1R120'], description='protocadherin 7', other_designations='protocadherin-7|BH-protocadherin (brain-heart)|brain-heart protocadherin|protein phosphatase 1, regulatory subunit 120', map_location='4p15.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=30719861, end_position_on_the_genomic_accession=31146800, orientation='plus', exon_count=10, OMIM=[602988], no_hdr0=''),
    5100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5100, CurrentID=0, Status='live', Symbol='PCDH8', Aliases=['ARCADLIN', 'PAPC'], description='protocadherin 8', other_designations='protocadherin-8', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52842889, end_position_on_the_genomic_accession=52848640, orientation='minus', exon_count=3, OMIM=[603580], no_hdr0=''),
    5101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5101, CurrentID=0, Status='live', Symbol='PCDH9', Aliases=[], description='protocadherin 9', other_designations='protocadherin-9|cadherin superfamily protein VR4-11', map_location='13q21.32', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=66302834, end_position_on_the_genomic_accession=67230336, orientation='minus', exon_count=8, OMIM=[603581], no_hdr0=''),
    5104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5104, CurrentID=0, Status='live', Symbol='SERPINA5', Aliases=['PAI-3', 'PAI3', 'PCI', 'PCI-B', 'PLANH3', 'PROCI'], description='serpin family A member 5', other_designations='plasma serine protease inhibitor|acrosomal serine protease inhibitor|plasminogen activator inhibitor III|plasminogen activator inhibitor-3|protein C inhibitor|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 5|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 5', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94581426, end_position_on_the_genomic_accession=94593118, orientation='plus', exon_count=6, OMIM=[601841], no_hdr0=''),
    5105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5105, CurrentID=0, Status='live', Symbol='PCK1', Aliases=['PCKDC', 'PEPCK-C', 'PEPCK1', 'PEPCKC'], description='phosphoenolpyruvate carboxykinase 1', other_designations='phosphoenolpyruvate carboxykinase, cytosolic [GTP]|PEP carboxykinase|phosphoenolpyruvate carboxykinase 1 (soluble)|phosphoenolpyruvate carboxykinase, cytosolic|phosphoenolpyruvate carboxylase|phosphopyruvate carboxylase|serine-protein kinase PCK1', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57561110, end_position_on_the_genomic_accession=57568121, orientation='plus', exon_count=10, OMIM=[614168], no_hdr0=''),
    5106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5106, CurrentID=0, Status='live', Symbol='PCK2', Aliases=['PEPCK', 'PEPCK-M', 'PEPCK2'], description='phosphoenolpyruvate carboxykinase 2, mitochondrial', other_designations='phosphoenolpyruvate carboxykinase [GTP], mitochondrial|PEP carboxykinase|epididymis secretory sperm binding protein|phosphopyruvate carboxylase', map_location='14q11.2-q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24094311, end_position_on_the_genomic_accession=24104125, orientation='plus', exon_count=10, OMIM=[614095], no_hdr0=''),
    5108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5108, CurrentID=0, Status='live', Symbol='PCM1', Aliases=['PTC4', 'RET/PCM-1'], description='pericentriolar material 1', other_designations='pericentriolar material 1 protein|PCM-1|hPCM-1|pericentriolar material 1, PCM1', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17922784, end_position_on_the_genomic_accession=18029948, orientation='plus', exon_count=46, OMIM=[600299], no_hdr0=''),
    5110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5110, CurrentID=0, Status='live', Symbol='PCMT1', Aliases=['PIMT'], description='protein-L-isoaspartate (D-aspartate) O-methyltransferase', other_designations='protein-L-isoaspartate(D-aspartate) O-methyltransferase|L-isoaspartyl protein carboxyl methyltransferase|epididymis secretory sperm binding protein|protein L-isoaspartyl/D-aspartyl methyltransferase|protein-beta-aspartate methyltransferase', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149749695, end_position_on_the_genomic_accession=149811421, orientation='plus', exon_count=9, OMIM=[176851], no_hdr0=''),
    5111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5111, CurrentID=0, Status='live', Symbol='PCNA', Aliases=['ATLD2'], description='proliferating cell nuclear antigen', other_designations='proliferating cell nuclear antigen|DNA polymerase delta auxiliary protein|cyclin', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5114953, end_position_on_the_genomic_accession=5126622, orientation='minus', exon_count=7, OMIM=[176740], no_hdr0=''),
    5116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5116, CurrentID=0, Status='live', Symbol='PCNT', Aliases=['KEN', 'MOPD2', 'PCN2', 'PCNTB', 'PCTN2', 'SCKL4', 'PCNT'], description='pericentrin', other_designations='pericentrin|kendrin|pericentrin-2|pericentrin-380|pericentrin-B', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46324122, end_position_on_the_genomic_accession=46445769, orientation='plus', exon_count=51, OMIM=[605925], no_hdr0=''),
    5118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5118, CurrentID=0, Status='live', Symbol='PCOLCE', Aliases=['PCPE', 'PCPE-1', 'PCPE1'], description='procollagen C-endopeptidase enhancer', other_designations='procollagen C-endopeptidase enhancer 1|procollagen C-proteinase enhancer 1|procollagen COOH-terminal proteinase enhancer 1|procollagen, type 1, COOH-terminal proteinase enhancer|type 1 procollagen C-proteinase enhancer protein|type I procollagen COOH-terminal proteinase enhancer', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100602363, end_position_on_the_genomic_accession=100608175, orientation='plus', exon_count=10, OMIM=[600270], no_hdr0=''),
    5119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5119, CurrentID=0, Status='live', Symbol='CHMP1A', Aliases=['CHMP1', 'PCH8', 'PCOLN3', 'PRSM1', 'VPS46-1', 'VPS46A'], description='charged multivesicular body protein 1A', other_designations='charged multivesicular body protein 1a|charged multivesicular body protein 1/chromatin modifying protein 1|chromatin modifying protein 1A|procollagen (type III) N-endopeptidase|protease, metallo, 1, 33kD|vacuolar protein sorting-associated protein 46-1', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89644435, end_position_on_the_genomic_accession=89657708, orientation='minus', exon_count=8, OMIM=[164010], no_hdr0=''),
    5121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5121, CurrentID=0, Status='live', Symbol='PCP4', Aliases=['PEP-19'], description='Purkinje cell protein 4', other_designations='calmodulin regulator protein PCP4|brain specific polypeptide PEP19|brain-specific antigen PCP-4|brain-specific polypeptide PEP-19', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39867438, end_position_on_the_genomic_accession=39929392, orientation='plus', exon_count=3, OMIM=[601629], no_hdr0=''),
    5122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5122, CurrentID=0, Status='live', Symbol='PCSK1', Aliases=['BMIQ12', 'NEC1', 'PC1', 'PC3', 'SPC3'], description='proprotein convertase subtilisin/kexin type 1', other_designations='neuroendocrine convertase 1|prohormone convertase 1|prohormone convertase 3', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=96390333, end_position_on_the_genomic_accession=96433248, orientation='minus', exon_count=15, OMIM=[162150], no_hdr0=''),
    5125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5125, CurrentID=0, Status='live', Symbol='PCSK5', Aliases=['PC5', 'PC6', 'PC6A', 'SPC6'], description='proprotein convertase subtilisin/kexin type 5', other_designations='proprotein convertase subtilisin/kexin type 5|prohormone convertase 5|proprotein convertase 6|protease PC6|subtilase|subtilisin/kexin-like protease PC5', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=75890646, end_position_on_the_genomic_accession=76362975, orientation='plus', exon_count=40, OMIM=[600488], no_hdr0=''),
    5126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5126, CurrentID=0, Status='live', Symbol='PCSK2', Aliases=['NEC 2', 'NEC-2', 'NEC2', 'PC2', 'SPC2'], description='proprotein convertase subtilisin/kexin type 2', other_designations='neuroendocrine convertase 2|KEX2-like endoprotease 2|prohormone convertase 2', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17226107, end_position_on_the_genomic_accession=17484578, orientation='plus', exon_count=13, OMIM=[162151], no_hdr0=''),
    5127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5127, CurrentID=0, Status='live', Symbol='CDK16', Aliases=['PCTAIRE', 'PCTAIRE1', 'PCTGAIRE', 'PCTK1'], description='cyclin dependent kinase 16', other_designations='cyclin-dependent kinase 16|PCTAIRE-motif protein kinase 1|cell division protein kinase 16|serine/threonine-protein kinase PCTAIRE-1|testis secretory sperm-binding protein Li 224n', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47217881, end_position_on_the_genomic_accession=47229997, orientation='plus', exon_count=19, OMIM=[311550], no_hdr0=''),
    5128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5128, CurrentID=0, Status='live', Symbol='CDK17', Aliases=['PCTAIRE2', 'PCTK2'], description='cyclin dependent kinase 17', other_designations='cyclin-dependent kinase 17|PCTAIRE-motif protein kinase 2|cell division protein kinase 17|protein kinase cdc2-related PCTAIRE-2|serine/threonine-protein kinase PCTAIRE-2', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=96278225, end_position_on_the_genomic_accession=96400439, orientation='minus', exon_count=18, OMIM=[603440], no_hdr0=''),
    5129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5129, CurrentID=0, Status='live', Symbol='CDK18', Aliases=['PCTAIRE', 'PCTAIRE3', 'PCTK3'], description='cyclin dependent kinase 18', other_designations='cyclin-dependent kinase 18|PCTAIRE protein kinase 3|PCTAIRE-motif protein kinase 3|cell division protein kinase 18|serine/threonine-protein kinase PCTAIRE-3', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205504593, end_position_on_the_genomic_accession=205532793, orientation='plus', exon_count=16, OMIM=[169190], no_hdr0=''),
    5130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5130, CurrentID=0, Status='live', Symbol='PCYT1A', Aliases=['CCTA', 'CCTalpha', 'CT', 'CTA', 'CTPCT', 'PCYT1', 'SMDCRD'], description='phosphate cytidylyltransferase 1A, choline', other_designations='choline-phosphate cytidylyltransferase A|CCT A|CCT-alpha|CT A|CTP:phosphocholine cytidylyltransferase A|CTP:phosphocholine cytidylyltransferase-alpha|choline-phosphate cytidylyltransferase alpha|phosphate cytidylyltransferase 1, choline, alpha|phosphorylcholine transferase A|phosphorylcholine transferase alpha', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196234368, end_position_on_the_genomic_accession=196287726, orientation='minus', exon_count=10, OMIM=[123695], no_hdr0=''),
    5132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5132, CurrentID=0, Status='live', Symbol='PDC', Aliases=['MEKA', 'PHD', 'PhLOP', 'PhLP'], description='phosducin', other_designations='phosducin|33 kDa phototransducing protein|G beta gamma binding protein|phosducin-like orphan protein', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186443566, end_position_on_the_genomic_accession=186461114, orientation='minus', exon_count=5, OMIM=[171490], no_hdr0=''),
    5133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5133, CurrentID=0, Status='live', Symbol='PDCD1', Aliases=['CD279', 'PD-1', 'PD1', 'SLEB2', 'hPD-1', 'hPD-l', 'hSLE1'], description='programmed cell death 1', other_designations='programmed cell death protein 1|programmed cell death 1 protein|protein PD-1|systemic lupus erythematosus susceptibility 2', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241849881, end_position_on_the_genomic_accession=241858908, orientation='minus', exon_count=6, OMIM=[600244], no_hdr0=''),
    5134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5134, CurrentID=0, Status='live', Symbol='PDCD2', Aliases=['RP8', 'ZMYND7'], description='programmed cell death 2', other_designations='programmed cell death protein 2|zinc finger MYND domain-containing protein 7|zinc finger protein Rp-8', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=170575295, end_position_on_the_genomic_accession=170584655, orientation='minus', exon_count=9, OMIM=[600866], no_hdr0=''),
    5136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5136, CurrentID=0, Status='live', Symbol='PDE1A', Aliases=['CAM-PDE 1A', 'CAM-PDE-1A', 'HCAM-1', 'HCAM1', 'HSPDE1A'], description='phosphodiesterase 1A', other_designations="calcium/calmodulin-dependent 3',5'-cyclic nucleotide phosphodiesterase 1A|61 kDa Cam-PDE|calcium/calmodulin-stimulated cyclic nucleotide phosphodiesterase|phosphodiesterase 1A, calmodulin-dependent", map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=182136453, end_position_on_the_genomic_accession=182523375, orientation='minus', exon_count=24, OMIM=[171890], no_hdr0=''),
    5137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5137, CurrentID=0, Status='live', Symbol='PDE1C', Aliases=['DFNA74', 'Hcam3', 'cam-PDE 1C', 'hCam-3'], description='phosphodiesterase 1C', other_designations="calcium/calmodulin-dependent 3',5'-cyclic nucleotide phosphodiesterase 1C|3',5'-cyclic-AMP phosphodiesterase|3',5'-cyclic-GMP phosphodiesterase|Human 3',5' cyclic nucleotide phosphodiesterase (HSPDE1C1A)|phosphodiesterase 1C, calmodulin-dependent 70kDa", map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31616777, end_position_on_the_genomic_accession=32428224, orientation='minus', exon_count=33, OMIM=[602987], no_hdr0=''),
    5138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5138, CurrentID=0, Status='live', Symbol='PDE2A', Aliases=['CGS-PDE', 'IDDPADS1', 'PED2A4', 'cGSPDE', 'PDE2A'], description='phosphodiesterase 2A', other_designations="cGMP-dependent 3',5'-cyclic phosphodiesterase|cGMP-stimulated phosphodiesterase 1|cGMP-stimulated phosphodiesterase 2|cGMP-stimulated phosphodiesterase 4|cyclic GMP-stimulated phosphodiesterase|phosphodiesterase 2A, cGMP-stimulated", map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72576141, end_position_on_the_genomic_accession=72674422, orientation='minus', exon_count=35, OMIM=[602658], no_hdr0=''),
    5139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5139, CurrentID=0, Status='live', Symbol='PDE3A', Aliases=['CGI-PDE', 'CGI-PDE A', 'CGI-PDE-A', 'HTNB'], description='phosphodiesterase 3A', other_designations="cGMP-inhibited 3',5'-cyclic phosphodiesterase A|cAMP phosphodiesterase, myocardial cGMP-inhibited|cyclic GMP-inhibited phosphodiesterase A|phosphodiesterase 3A, cGMP-inhibited", map_location='12p12.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=20368537, end_position_on_the_genomic_accession=20688583, orientation='plus', exon_count=20, OMIM=[123805], no_hdr0=''),
    5140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5140, CurrentID=0, Status='live', Symbol='PDE3B', Aliases=['HcGIP1', 'cGIPDE1'], description='phosphodiesterase 3B', other_designations="cGMP-inhibited 3',5'-cyclic phosphodiesterase B|CGI-PDE B|CGIP1|cyclic GMP-inhibited phosphodiesterase B|cyclic nucleotide phosphodiesterase|phosphodiesterase 3B, cGMP-inhibited", map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14643691, end_position_on_the_genomic_accession=14874139, orientation='plus', exon_count=18, OMIM=[602047], no_hdr0=''),
    5141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5141, CurrentID=0, Status='live', Symbol='PDE4A', Aliases=['DPDE2', 'PDE4', 'PDE46'], description='phosphodiesterase 4A', other_designations="cAMP-specific 3',5'-cyclic phosphodiesterase 4A|phosphodiesterase 4A, cAMP-specific (dunce|phosphodiesterase E2 dunce homolog, Drosophila|phosphodiesterase isozyme 4", map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10416773, end_position_on_the_genomic_accession=10469631, orientation='plus', exon_count=22, OMIM=[600126], no_hdr0=''),
    5142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5142, CurrentID=0, Status='live', Symbol='PDE4B', Aliases=['DPDE4', 'PDEIVB'], description='phosphodiesterase 4B', other_designations="cAMP-specific 3',5'-cyclic phosphodiesterase 4B|dunce-like phosphodiesterase E4|phosphodiesterase 4B, cAMP-specific (phosphodiesterase E4 dunce homolog, Drosophila)", map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65792510, end_position_on_the_genomic_accession=66374579, orientation='plus', exon_count=25, OMIM=[600127], no_hdr0=''),
    5143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5143, CurrentID=0, Status='live', Symbol='PDE4C', Aliases=['DPDE1', 'PDE21'], description='phosphodiesterase 4C', other_designations="cAMP-specific 3',5'-cyclic phosphodiesterase 4C|dunce-like phosphodiesterase E1|phosphodiesterase 4C, cAMP-specific (phosphodiesterase E1 dunce homolog, Drosophila)", map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18207965, end_position_on_the_genomic_accession=18248200, orientation='minus', exon_count=20, OMIM=[600128], no_hdr0=''),
    5144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5144, CurrentID=0, Status='live', Symbol='PDE4D', Aliases=['ACRDYS2', 'DPDE3', 'HSPDE4D', 'PDE43N2', 'STRK1', 'PDE4D'], description='phosphodiesterase 4D', other_designations="cAMP-specific 3',5'-cyclic phosphodiesterase 4D|cAMP-specific phosphodiesterase PDE4D6|phosphodiesterase 4D, cAMP-specific (phosphodiesterase E3 dunce homolog, Drosophila)|testicular tissue protein Li 136", map_location='5q11.2-q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=58969038, end_position_on_the_genomic_accession=60524329, orientation='minus', exon_count=39, OMIM=[600129], no_hdr0=''),
    5145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5145, CurrentID=0, Status='live', Symbol='PDE6A', Aliases=['CGPR-A', 'PDEA', 'RP43'], description='phosphodiesterase 6A', other_designations="rod cGMP-specific 3',5'-cyclic phosphodiesterase subunit alpha|GMP-PDE alpha|PDE V-B1|cGMP phosphodiesterase alpha subunit|phosphodiesterase 6A, cGMP-specific, rod, alpha|retinitis pigmentosa type 43|rod photoreceptor cGMP phosphodiesterase alpha subunit", map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149857953, end_position_on_the_genomic_accession=149944793, orientation='minus', exon_count=24, OMIM=[180071], no_hdr0=''),
    5146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5146, CurrentID=0, Status='live', Symbol='PDE6C', Aliases=['ACHM5', 'COD4', 'PDEA2'], description='phosphodiesterase 6C', other_designations="cone cGMP-specific 3',5'-cyclic phosphodiesterase subunit alpha'|cGMP phosphodiesterase 6C|phosphodiesterase 6C, cGMP-specific, cone, alpha prime", map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93612537, end_position_on_the_genomic_accession=93666010, orientation='plus', exon_count=22, OMIM=[600827], no_hdr0=''),
    5147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5147, CurrentID=0, Status='live', Symbol='PDE6D', Aliases=['JBTS22', 'PDED'], description='phosphodiesterase 6D', other_designations="retinal rod rhodopsin-sensitive cGMP 3',5'-cyclic phosphodiesterase subunit delta|GMP-PDE delta|phosphodiesterase 6D, cGMP-specific, rod, delta|protein p17", map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231732428, end_position_on_the_genomic_accession=231781282, orientation='minus', exon_count=6, OMIM=[602676], no_hdr0=''),
    5148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5148, CurrentID=0, Status='live', Symbol='PDE6G', Aliases=['PDEG', 'RP57'], description='phosphodiesterase 6G', other_designations="retinal rod rhodopsin-sensitive cGMP 3',5'-cyclic phosphodiesterase subunit gamma|GMP-PDE gamma|phosphodiesterase 6G, cGMP-specific, rod, gamma|rod cG-PDE G", map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81650459, end_position_on_the_genomic_accession=81663127, orientation='minus', exon_count=6, OMIM=[180073], no_hdr0=''),
    5149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5149, CurrentID=0, Status='live', Symbol='PDE6H', Aliases=['ACHM6', 'RCD3'], description='phosphodiesterase 6H', other_designations="retinal cone rhodopsin-sensitive cGMP 3',5'-cyclic phosphodiesterase subunit gamma|GMP-PDE gamma|phosphodiesterase 6H, cGMP-specific, cone, gamma", map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14973042, end_position_on_the_genomic_accession=14981865, orientation='plus', exon_count=4, OMIM=[601190], no_hdr0=''),
    5150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5150, CurrentID=0, Status='live', Symbol='PDE7A', Aliases=['HCP1', 'PDE7'], description='phosphodiesterase 7A', other_designations="high affinity cAMP-specific 3',5'-cyclic phosphodiesterase 7A|TM22|phosphodiesterase isozyme 7", map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=65714334, end_position_on_the_genomic_accession=65842064, orientation='minus', exon_count=15, OMIM=[171885], no_hdr0=''),
    5151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5151, CurrentID=0, Status='live', Symbol='PDE8A', Aliases=['HsT19550'], description='phosphodiesterase 8A', other_designations="high affinity cAMP-specific and IBMX-insensitive 3',5'-cyclic phosphodiesterase 8A|cAMP-specific cyclic nucleotide phosphodiesterase 8A", map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84980467, end_position_on_the_genomic_accession=85139142, orientation='plus', exon_count=28, OMIM=[602972], no_hdr0=''),
    5152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5152, CurrentID=0, Status='live', Symbol='PDE9A', Aliases=['HSPDE9A2'], description='phosphodiesterase 9A', other_designations="high affinity cGMP-specific 3',5'-cyclic phosphodiesterase 9A|CGMP-specific 3',5'-cyclic phosphodiesterase type 9|phosphodiesterase PDE9A21", map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42653621, end_position_on_the_genomic_accession=42775509, orientation='plus', exon_count=25, OMIM=[602973], no_hdr0=''),
    5153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5153, CurrentID=0, Status='live', Symbol='PDE1B', Aliases=['HEL-S-79p1', 'PDES1B', 'PDE1B'], description='phosphodiesterase 1B', other_designations="calcium/calmodulin-dependent 3',5'-cyclic nucleotide phosphodiesterase 1B|63 kDa Cam-PDE|calcium/calmodulin-stimulated cyclic nucleotide phosphodiesterase|calmodulin-stimulated phosphodiesterase PDE1B1|cam-PDE 1B|epididymis secretory sperm binding protein Li 79p|phosphodiesterase 1B, calmodulin-dependent|presumed 63kDa form of the type 1 cyclic nucleotide phosphodiesterase family known as PDE1B", map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54549601, end_position_on_the_genomic_accession=54579239, orientation='plus', exon_count=21, OMIM=[171891], no_hdr0=''),
    5154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5154, CurrentID=0, Status='live', Symbol='PDGFA', Aliases=['PDGF-A', 'PDGF1'], description='platelet derived growth factor subunit A', other_designations='platelet-derived growth factor subunit A|PDGF A-chain|PDGF subunit A|platelet-derived growth factor A-chain|platelet-derived growth factor alpha chain|platelet-derived growth factor alpha polypeptide', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=497245, end_position_on_the_genomic_accession=520668, orientation='minus', exon_count=10, OMIM=[173430], no_hdr0=''),
    5155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5155, CurrentID=0, Status='live', Symbol='PDGFB', Aliases=['IBGC5', 'PDGF-2', 'PDGF2', 'SIS', 'SSV', 'c-sis'], description='platelet derived growth factor subunit B', other_designations='platelet-derived growth factor subunit B|PDGF subunit B|PDGF, B chain|becaplermin|epididymis secretory sperm binding protein|platelet-derived growth factor 2|platelet-derived growth factor B chain|platelet-derived growth factor beta polypeptide (simian sarcoma viral (v-sis) oncogene homolog)|platelet-derived growth factor, beta polypeptide (oncogene SIS)|proto-oncogene c-Sis', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39223359, end_position_on_the_genomic_accession=39244982, orientation='minus', exon_count=8, OMIM=[190040], no_hdr0=''),
    5156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5156, CurrentID=0, Status='live', Symbol='PDGFRA', Aliases=['CD140A', 'PDGFR-2', 'PDGFR2'], description='platelet derived growth factor receptor alpha', other_designations='platelet-derived growth factor receptor alpha|CD140 antigen-like family member A|CD140a antigen|PDGF-R-alpha|alpha-type platelet-derived growth factor receptor|platelet-derived growth factor receptor 2|platelet-derived growth factor receptor, alpha polypeptide', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=54229127, end_position_on_the_genomic_accession=54298245, orientation='plus', exon_count=28, OMIM=[173490], no_hdr0=''),
    5157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5157, CurrentID=0, Status='live', Symbol='PDGFRL', Aliases=['PDGRL', 'PRLTS'], description='platelet derived growth factor receptor like', other_designations='platelet-derived growth factor receptor-like protein|PDGF receptor beta-like tumor suppressor|PDGFR-like protein|platelet-derived growth factor-beta-like tumor suppressor', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17576433, end_position_on_the_genomic_accession=17643144, orientation='plus', exon_count=7, OMIM=[604584], no_hdr0=''),
    5158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5158, CurrentID=0, Status='live', Symbol='PDE6B', Aliases=['CSNB3', 'CSNBAD2', 'GMP-PDEbeta', 'PDEB', 'RP40', 'rd1'], description='phosphodiesterase 6B', other_designations="rod cGMP-specific 3',5'-cyclic phosphodiesterase subunit beta|GMP-PDE beta|phosphodiesterase 6B, cGMP-specific, rod, beta|rod cGMP-phosphodiesterase beta-subunit", map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=587325, end_position_on_the_genomic_accession=670892, orientation='plus', exon_count=28, OMIM=[180072], no_hdr0=''),
    5159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5159, CurrentID=0, Status='live', Symbol='PDGFRB', Aliases=['CD140B', 'IBGC4', 'IMF1', 'JTK12', 'KOGS', 'PDGFR', 'PDGFR-1', 'PDGFR1', 'PENTT'], description='platelet derived growth factor receptor beta', other_designations='platelet-derived growth factor receptor beta|Activated tyrosine kinase PDGFRB|CD140 antigen-like family member B|NDEL1-PDGFRB|PDGF-R-beta|PDGFR-beta|beta-type platelet-derived growth factor receptor|platelet-derived growth factor receptor 1|platelet-derived growth factor receptor, beta polypeptide', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150113839, end_position_on_the_genomic_accession=150155845, orientation='minus', exon_count=24, OMIM=[173410], no_hdr0=''),
    5160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5160, CurrentID=0, Status='live', Symbol='PDHA1', Aliases=['PDHA', 'PDHAD', 'PDHCE1A', 'PHE1A'], description='pyruvate dehydrogenase E1 subunit alpha 1', other_designations='pyruvate dehydrogenase E1 component subunit alpha, somatic form, mitochondrial|PDHE1-A type I|pyruvate dehydrogenase (lipoamide) alpha 1|pyruvate dehydrogenase E1 alpha 1 subunit|pyruvate dehydrogenase alpha 1|pyruvate dehydrogenase complex, E1-alpha polypeptide 1', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=19343906, end_position_on_the_genomic_accession=19361718, orientation='plus', exon_count=12, OMIM=[300502], no_hdr0=''),
    5161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5161, CurrentID=0, Status='live', Symbol='PDHA2', Aliases=['PDHAL'], description='pyruvate dehydrogenase E1 subunit alpha 2', other_designations='pyruvate dehydrogenase E1 component subunit alpha, testis-specific form, mitochondrial|PDHE1-A type II|pyruvate dehydrogenase (lipoamide) alpha 2|pyruvate dehydrogenase E1 alpha 2 subunit|pyruvate dehydrogenase alpha 2|pyruvate dehydrogenase, E1-alpha polypeptide, testis specific', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=95840093, end_position_on_the_genomic_accession=95841464, orientation='plus', exon_count=1, OMIM=[179061], no_hdr0=''),
    5162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5162, CurrentID=0, Status='live', Symbol='PDHB', Aliases=['PDHBD', 'PDHE1-B', 'PDHE1B', 'PHE1B'], description='pyruvate dehydrogenase E1 subunit beta', other_designations='pyruvate dehydrogenase E1 component subunit beta, mitochondrial|epididymis secretory sperm binding protein|pyruvate dehydrogenase (lipoamide) beta|pyruvate dehydrogenase E1 beta subunit|pyruvate dehydrogenase, E1 beta polypeptide', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58427630, end_position_on_the_genomic_accession=58433832, orientation='minus', exon_count=9, OMIM=[179060], no_hdr0=''),
    5163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5163, CurrentID=0, Status='live', Symbol='PDK1', Aliases=[], description='pyruvate dehydrogenase kinase 1', other_designations='[Pyruvate dehydrogenase (acetyl-transferring)] kinase isozyme 1, mitochondrial|pyruvate dehydrogenase (acetyl-transferring) kinase isozyme 1, mitochondrial|PDH kinase 1|mitochondrial pyruvate dehydrogenase, lipoamide, kinase isoenzyme 1|pyruvate dehydrogenase kinase, isoenzyme 1', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=172555373, end_position_on_the_genomic_accession=172672698, orientation='plus', exon_count=24, OMIM=[602524], no_hdr0=''),
    5164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5164, CurrentID=0, Status='live', Symbol='PDK2', Aliases=['PDHK2', 'PDKII'], description='pyruvate dehydrogenase kinase 2', other_designations='pyruvate dehydrogenase kinase, isozyme 2|PDH kinase 2|[Pyruvate dehydrogenase (acetyl-transferring)] kinase isozyme 2, mitochondrial|pyruvate dehydrogenase kinase, isoenzyme 2|pyruvate dehydrogenase, lipoamide, kinase isozyme 2, mitochondrial', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50094737, end_position_on_the_genomic_accession=50112152, orientation='plus', exon_count=14, OMIM=[602525], no_hdr0=''),
    5165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5165, CurrentID=0, Status='live', Symbol='PDK3', Aliases=['CMTX6', 'GS1-358P8.4'], description='pyruvate dehydrogenase kinase 3', other_designations='pyruvate dehydrogenase kinase, isozyme 3|[Pyruvate dehydrogenase (acetyl-transferring)] kinase isozyme 3, mitochondrial|pyruvate dehydrogenase kinase, isoenzyme 3|pyruvate dehydrogenase, lipoamide, kinase isozyme 3, mitochondrial', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24465286, end_position_on_the_genomic_accession=24550466, orientation='plus', exon_count=12, OMIM=[300906], no_hdr0=''),
    5166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5166, CurrentID=0, Status='live', Symbol='PDK4', Aliases=[], description='pyruvate dehydrogenase kinase 4', other_designations='pyruvate dehydrogenase kinase, isozyme 4|[Pyruvate dehydrogenase (acetyl-transferring)] kinase isozyme 4, mitochondrial|[Pyruvate dehydrogenase [lipoamide]] kinase isozyme 4, mitochondrial|pyruvate dehydrogenase kinase, isoenzyme 4|pyruvate dehydrogenase, lipoamide, kinase isozyme 4, mitochondrial', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95583499, end_position_on_the_genomic_accession=95596516, orientation='minus', exon_count=11, OMIM=[602527], no_hdr0=''),
    5167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5167, CurrentID=0, Status='live', Symbol='ENPP1', Aliases=['ARHR2', 'COLED', 'M6S1', 'NPP1', 'NPPS', 'PC-1', 'PCA1', 'PDNP1'], description='ectonucleotide pyrophosphatase/phosphodiesterase 1', other_designations='ectonucleotide pyrophosphatase/phosphodiesterase family member 1|E-NPP 1|Ly-41 antigen|alkaline phosphodiesterase 1|membrane component, chromosome 6, surface marker 1|phosphodiesterase I/nucleotide pyrophosphatase 1|plasma-cell membrane glycoprotein 1|plasma-cell membrane glycoprotein PC-1', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131808020, end_position_on_the_genomic_accession=131895155, orientation='plus', exon_count=25, OMIM=[173335], no_hdr0=''),
    5168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5168, CurrentID=0, Status='live', Symbol='ENPP2', Aliases=['ATX', 'ATX-X', 'AUTOTAXIN', 'LysoPLD', 'NPP2', 'PD-IALPHA', 'PDNP2'], description='ectonucleotide pyrophosphatase/phosphodiesterase 2', other_designations='ectonucleotide pyrophosphatase/phosphodiesterase family member 2|E-NPP 2|autotaxin-t|extracellular lysophospholipase D|phosphodiesterase I/nucleotide pyrophosphatase 2|plasma lysophospholipase D', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119557085, end_position_on_the_genomic_accession=119673404, orientation='minus', exon_count=29, OMIM=[601060], no_hdr0=''),
    5169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5169, CurrentID=0, Status='live', Symbol='ENPP3', Aliases=['B10', 'CD203c', 'NPP3', 'PD-IBETA', 'PDNP3'], description='ectonucleotide pyrophosphatase/phosphodiesterase 3', other_designations='ectonucleotide pyrophosphatase/phosphodiesterase family member 3|dJ1005H11.3 (phosphodiesterase I/nucleotide pyrophosphatase 3)|dJ914N13.3 (phosphodiesterase I/nucleotide pyrophosphatase 3)|gp130RB13-6|phosphodiesterase I/nucleotide pyrophosphatase 3|phosphodiesterase-I beta', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131637302, end_position_on_the_genomic_accession=131747413, orientation='plus', exon_count=27, OMIM=[602182], no_hdr0=''),
    5170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5170, CurrentID=0, Status='live', Symbol='PDPK1', Aliases=['PDK1', 'PDPK2', 'PDPK2P', 'PRO0461'], description='3-phosphoinositide dependent protein kinase 1', other_designations='3-phosphoinositide-dependent protein kinase 1|3-phosphoinositide-dependent protein kinase 2 pseudogene|PkB kinase like gene 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2538014, end_position_on_the_genomic_accession=2603190, orientation='plus', exon_count=17, OMIM=[605213], no_hdr0=''),
    5172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5172, CurrentID=0, Status='live', Symbol='SLC26A4', Aliases=['DFNB4', 'EVA', 'PDS', 'TDH2B'], description='solute carrier family 26 member 4', other_designations='pendrin|sodium-independent chloride/iodide transporter|solute carrier family 26 (anion exchanger), member 4|truncated solute carrier family 26', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107660828, end_position_on_the_genomic_accession=107717809, orientation='plus', exon_count=23, OMIM=[605646], no_hdr0=''),
    5173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5173, CurrentID=0, Status='live', Symbol='PDYN', Aliases=['ADCA', 'PENKB', 'SCA23'], description='prodynorphin', other_designations='proenkephalin-B|beta-neoendorphin-dynorphin|leu-enkephalin|leumorphin|neoendorphin-dynorphin-enkephalin prepropeptide|preprodynorphin|preproenkephalin B|rimorphin', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1978756, end_position_on_the_genomic_accession=1994285, orientation='minus', exon_count=10, OMIM=[131340], no_hdr0=''),
    5174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5174, CurrentID=0, Status='live', Symbol='PDZK1', Aliases=['CAP70', 'CLAMP', 'NHERF-3', 'NHERF3', 'PDZD1'], description='PDZ domain containing 1', other_designations='Na(+)/H(+) exchange regulatory cofactor NHE-RF3|CFTR-associated protein of 70 kDa|PDZ-containing kidney protein 1|na/Pi cotransporter C-terminal-associated protein 1|naPi-Cap1|sodium-hydrogen exchanger regulatory factor 3', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145670852, end_position_on_the_genomic_accession=145708201, orientation='minus', exon_count=15, OMIM=[603831], no_hdr0=''),
    5175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5175, CurrentID=0, Status='live', Symbol='PECAM1', Aliases=['CD31', 'CD31/EndoCAM', "GPIIA'", 'PECA1', 'PECAM-1', 'endoCAM'], description='platelet and endothelial cell adhesion molecule 1', other_designations='platelet endothelial cell adhesion molecule|CD31 antigen|platelet endothelial cell adhesion molecule-1', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64319415, end_position_on_the_genomic_accession=64413844, orientation='minus', exon_count=19, OMIM=[173445], no_hdr0=''),
    5176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5176, CurrentID=0, Status='live', Symbol='SERPINF1', Aliases=['EPC-1', 'OI12', 'OI6', 'PEDF', 'PIG35'], description='serpin family F member 1', other_designations='pigment epithelium-derived factor|alpha-2 antiplasmin|cell proliferation-inducing gene 35 protein|serine (or cysteine) proteinase inhibitor, clade F (alpha-2 antiplasmin, pigment epithelium derived factor), member 1|serpin peptidase inhibitor, clade F (alpha-2 antiplasmin, pigment epithelium derived factor), member 1|testis tissue sperm-binding protein Li 70n', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1762060, end_position_on_the_genomic_accession=1777565, orientation='plus', exon_count=9, OMIM=[172860], no_hdr0=''),
    5178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5178, CurrentID=0, Status='live', Symbol='PEG3', Aliases=['PW1', 'ZKSCAN22', 'ZNF904', 'ZSCAN24'], description='paternally expressed 3', other_designations='paternally-expressed gene 3 protein|Kruppel-type zinc finger protein|zinc finger and SCAN domain-containing protein 24', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56810082, end_position_on_the_genomic_accession=56840726, orientation='minus', exon_count=15, OMIM=[601483], no_hdr0=''),
    5179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5179, CurrentID=0, Status='live', Symbol='PENK', Aliases=['PE-A', 'PENK'], description='proenkephalin', other_designations='proenkephalin-A|enkephalin A|peptide F|preproenkephalin', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56440957, end_position_on_the_genomic_accession=56446641, orientation='minus', exon_count=4, OMIM=[131330], no_hdr0=''),
    5182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5182, CurrentID=0, Status='live', Symbol='PEPB', Aliases=[], description='peptidase B', other_designations='peptidase B', map_location='12q21', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[169900], no_hdr0=''),
    5183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5183, CurrentID=0, Status='live', Symbol='PEPC', Aliases=[], description='peptidase C', other_designations='peptidase C', map_location='1q25', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[170000], no_hdr0=''),
    5184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5184, CurrentID=0, Status='live', Symbol='PEPD', Aliases=['PROLIDASE'], description='peptidase D', other_designations='xaa-Pro dipeptidase|X-Pro dipeptidase|aminoacyl-L-proline hydrolase|imidodipeptidase|proline dipeptidase|testicular tissue protein Li 138', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33386950, end_position_on_the_genomic_accession=33521791, orientation='minus', exon_count=15, OMIM=[613230], no_hdr0=''),
    5185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5185, CurrentID=0, Status='live', Symbol='PEPE', Aliases=[], description='peptidase E', other_designations='peptidase E', map_location='17q23-qter', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[170200], no_hdr0=''),
    5187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5187, CurrentID=0, Status='live', Symbol='PER1', Aliases=['PER', 'RIGUI', 'hPER'], description='period circadian regulator 1', other_designations='period circadian protein homolog 1|Period, drosophila, homolog of|circadian clock protein PERIOD 1|circadian pacemaker protein RIGUI|hPER1|period circadian clock 1|period homolog 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8140470, end_position_on_the_genomic_accession=8156360, orientation='minus', exon_count=24, OMIM=[602260], no_hdr0=''),
    5188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5188, CurrentID=0, Status='live', Symbol='GATB', Aliases=['COXPD41', 'HSPC199', 'PET112', 'PET112L'], description='glutamyl-tRNA amidotransferase subunit B', other_designations='glutamyl-tRNA(Gln) amidotransferase subunit B, mitochondrial|PET112 homolog|cytochrome c oxidase assembly factor PET112 homolog|cytochrome oxidase assembly factor PET112 homolog|glutamyl-tRNA(Gln) amidotransferase, subunit B', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=151670504, end_position_on_the_genomic_accession=151761007, orientation='minus', exon_count=13, OMIM=[603645], no_hdr0=''),
    5189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5189, CurrentID=0, Status='live', Symbol='PEX1', Aliases=['HMLR1', 'PBD1A', 'PBD1B', 'ZWS', 'ZWS1'], description='peroxisomal biogenesis factor 1', other_designations='peroxisome biogenesis factor 1|Zellweger syndrome|peroxin-1|peroxisome biogenesis disorder protein 1', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92487023, end_position_on_the_genomic_accession=92528520, orientation='minus', exon_count=24, OMIM=[602136], no_hdr0=''),
    5190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5190, CurrentID=0, Status='live', Symbol='PEX6', Aliases=['HMLR2', 'PAF-2', 'PAF2', 'PBD4A', 'PDB4B', 'PXAAA1'], description='peroxisomal biogenesis factor 6', other_designations='peroxisome biogenesis factor 6|peroxin-6|peroxisomal AAA-type ATPase 1|peroxisomal-type ATPase 1|peroxisome assembly factor 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42963865, end_position_on_the_genomic_accession=42980224, orientation='minus', exon_count=17, OMIM=[601498], no_hdr0=''),
    5191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5191, CurrentID=0, Status='live', Symbol='PEX7', Aliases=['PBD9B', 'PTS2R', 'RCDP1', 'RD'], description='peroxisomal biogenesis factor 7', other_designations='peroxisomal biogenesis factor 7|PTS2 receptor|peroxin-7|peroxisomal PTS2 receptor|peroxisomal targeting signal 2 receptor|peroxisome targeting signal 2 receptor', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136821683, end_position_on_the_genomic_accession=136913934, orientation='plus', exon_count=11, OMIM=[601757], no_hdr0=''),
    5192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5192, CurrentID=0, Status='live', Symbol='PEX10', Aliases=['NALD', 'PBD6A', 'PBD6B', 'RNF69'], description='peroxisomal biogenesis factor 10', other_designations='peroxisome biogenesis factor 10|RING finger protein 69|peroxin 10|peroxisome assembly protein 10', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2403974, end_position_on_the_genomic_accession=2413827, orientation='minus', exon_count=8, OMIM=[602859], no_hdr0=''),
    5193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5193, CurrentID=0, Status='live', Symbol='PEX12', Aliases=['PAF-3', 'PBD3A'], description='peroxisomal biogenesis factor 12', other_designations='peroxisome assembly protein 12|peroxin 12|peroxisome assembly factor 3', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35574795, end_position_on_the_genomic_accession=35578571, orientation='minus', exon_count=3, OMIM=[601758], no_hdr0=''),
    5194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5194, CurrentID=0, Status='live', Symbol='PEX13', Aliases=['NALD', 'PBD11A', 'PBD11B', 'ZWS'], description='peroxisomal biogenesis factor 13', other_designations='peroxisome biogenesis factor 13|peroxin-13|peroxisomal membrane protein PEX13', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61017720, end_position_on_the_genomic_accession=61051990, orientation='plus', exon_count=4, OMIM=[601789], no_hdr0=''),
    5195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5195, CurrentID=0, Status='live', Symbol='PEX14', Aliases=['NAPP2', 'PBD13A', 'Pex14p', 'dJ734G22.2'], description='peroxisomal biogenesis factor 14', other_designations='peroxisomal membrane protein PEX14|NF-E2 associated polypeptide 2|PTS1 receptor docking protein|peroxin-14|peroxisomal membrane anchor protein PEX14|peroxisomal membrane anchor protein Pex14p', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10474946, end_position_on_the_genomic_accession=10630758, orientation='plus', exon_count=14, OMIM=[601791], no_hdr0=''),
    5196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5196, CurrentID=0, Status='live', Symbol='PF4', Aliases=['CXCL4', 'PF-4', 'SCYB4'], description='platelet factor 4', other_designations='platelet factor 4|C-X-C motif chemokine 4|chemokine (C-X-C motif) ligand 4|iroplact|oncostatin-A', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73980811, end_position_on_the_genomic_accession=73982124, orientation='minus', exon_count=3, OMIM=[173460], no_hdr0=''),
    5197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5197, CurrentID=0, Status='live', Symbol='PF4V1', Aliases=['CXCL4L1', 'CXCL4V1', 'PF4-ALT', 'PF4A', 'SCYB4V1'], description='platelet factor 4 variant 1', other_designations='platelet factor 4 variant|C-X-C motif chemokine 4|PF4alt|PF4var1|platelet factor 4, variant 1 (PF4-like)', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73853296, end_position_on_the_genomic_accession=73854483, orientation='plus', exon_count=3, OMIM=[173461], no_hdr0=''),
    5198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5198, CurrentID=0, Status='live', Symbol='PFAS', Aliases=['FGAMS', 'FGAR-AT', 'FGARAT', 'GATD8', 'PURL'], description='phosphoribosylformylglycinamidine synthase', other_designations='phosphoribosylformylglycinamidine synthase|FGAM synthase|FGAR amidotransferase|IKZF1/PFAS fusion|formylglycinamide ribonucleotide amidotransferase|formylglycinamide ribotide amidotransferase|formylglycinamide ribotide synthetase', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8247596, end_position_on_the_genomic_accession=8270491, orientation='plus', exon_count=30, OMIM=[602133], no_hdr0=''),
    5199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5199, CurrentID=0, Status='live', Symbol='CFP', Aliases=['BFD', 'PFC', 'PFD', 'PROPERDIN'], description='complement factor properdin', other_designations='properdin|complement factor P|properdin P factor, complement', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47623282, end_position_on_the_genomic_accession=47630305, orientation='minus', exon_count=11, OMIM=[300383], no_hdr0=''),
    5201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5201, CurrentID=0, Status='live', Symbol='PFDN1', Aliases=['PDF', 'PFD1'], description='prefoldin subunit 1', other_designations='prefoldin subunit 1|prefoldin 1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140245035, end_position_on_the_genomic_accession=140303101, orientation='minus', exon_count=5, OMIM=[604897], no_hdr0=''),
    5202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5202, CurrentID=0, Status='live', Symbol='PFDN2', Aliases=['PFD2'], description='prefoldin subunit 2', other_designations='prefoldin subunit 2|prefoldin 2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161100556, end_position_on_the_genomic_accession=161118043, orientation='minus', exon_count=5, OMIM=[613466], no_hdr0=''),
    5203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5203, CurrentID=0, Status='live', Symbol='PFDN4', Aliases=['C1', 'PFD4'], description='prefoldin subunit 4', other_designations='prefoldin subunit 4|prefoldin 4|protein C-1', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=54208087, end_position_on_the_genomic_accession=54219961, orientation='plus', exon_count=5, OMIM=[604898], no_hdr0=''),
    5204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5204, CurrentID=0, Status='live', Symbol='PFDN5', Aliases=['MM-1', 'MM1', 'PFD5'], description='prefoldin subunit 5', other_designations='prefoldin subunit 5|c-myc binding protein|myc modulator-1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53295542, end_position_on_the_genomic_accession=53299450, orientation='plus', exon_count=6, OMIM=[604899], no_hdr0=''),
    5205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5205, CurrentID=0, Status='live', Symbol='ATP8B1', Aliases=['ATPIC', 'BRIC', 'FIC1', 'ICP1', 'PFIC', 'PFIC1'], description='ATPase phospholipid transporting 8B1', other_designations='phospholipid-transporting ATPase IC|ATPase, aminophospholipid transporter, class I, type 8B, member 1|ATPase, class I, type 8B, member 1|E1-E2 ATPase|P4-ATPase flippase complex alpha subunit ATP8B1|familial intrahepatic cholestasis type 1|probable phospholipid-transporting ATPase IC', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57646426, end_position_on_the_genomic_accession=57803822, orientation='minus', exon_count=28, OMIM=[602397], no_hdr0=''),
    5207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5207, CurrentID=0, Status='live', Symbol='PFKFB1', Aliases=['F6PK', 'HL2K', 'PFRX'], description='6-phosphofructo-2-kinase/fructose-2,6-biphosphatase 1', other_designations='6-phosphofructo-2-kinase/fructose-2,6-bisphosphatase 1|6PF-2-K/Fru-2,6-P2ASE liver isozyme|6PF-2-K/Fru-2,6-P2ase 1|PFK/FBPase 1|fructose-6-phosphate,2-kinase:fructose-2,6-bisphosphatase', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54932961, end_position_on_the_genomic_accession=55000052, orientation='minus', exon_count=17, OMIM=[311790], no_hdr0=''),
    5208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5208, CurrentID=0, Status='live', Symbol='PFKFB2', Aliases=['PFK-2/FBPase-2'], description='6-phosphofructo-2-kinase/fructose-2,6-biphosphatase 2', other_designations='6-phosphofructo-2-kinase/fructose-2,6-bisphosphatase 2|6PF-2-K/Fru-2,6-P2ASE heart-type isozyme|6PF-2-K/Fru-2,6-P2ase 2|PFK/FBPase 2|PFKFB, cardiac|fructose-2,6-bisphosphatase, cardiac isozyme', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207053063, end_position_on_the_genomic_accession=207081027, orientation='plus', exon_count=19, OMIM=[171835], no_hdr0=''),
    5209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5209, CurrentID=0, Status='live', Symbol='PFKFB3', Aliases=['IPFK2', 'PFK2', 'iPFK-2'], description='6-phosphofructo-2-kinase/fructose-2,6-biphosphatase 3', other_designations='6-phosphofructo-2-kinase/fructose-2,6-bisphosphatase 3|6-phosphofructo-2-kinase/ fructose-2,6-bisphosphatase|6PF-2-K/Fru-2,6-P2ase 3|6PF-2-K/Fru-2,6-P2ase brain/placenta-type isozyme|PFK/FBPase 3|fructose-6-phosphate,2-kinase/fructose-2, 6-bisphosphatase|inducible 6-phosphofructo-2-kinase/fructose-2,6-bisphosphatase|renal carcinoma antigen NY-REN-56', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=6144918, end_position_on_the_genomic_accession=6254648, orientation='plus', exon_count=20, OMIM=[605319], no_hdr0=''),
    5210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5210, CurrentID=0, Status='live', Symbol='PFKFB4', Aliases=[], description='6-phosphofructo-2-kinase/fructose-2,6-biphosphatase 4', other_designations='6-phosphofructo-2-kinase/fructose-2,6-bisphosphatase 4|6PF-2-K/Fru-2,6-P2ase 4|6PF-2-K/Fru-2,6-P2ase testis-type isozyme|PFK/FBPase 4|bifunctional enzyme with kinase and biphosphatase activities', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48517684, end_position_on_the_genomic_accession=48562383, orientation='minus', exon_count=20, OMIM=[605320], no_hdr0=''),
    5211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5211, CurrentID=0, Status='live', Symbol='PFKL', Aliases=['ATP-PFK', 'PFK-B', 'PFK-L'], description='phosphofructokinase, liver type', other_designations='ATP-dependent 6-phosphofructokinase, liver type|6-phosphofructokinase type B|6-phosphofructokinase, liver type|liver-type 1-phosphofructokinase|phosphofructo-1-kinase isozyme B|phosphohexokinase', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44300040, end_position_on_the_genomic_accession=44327373, orientation='plus', exon_count=27, OMIM=[171860], no_hdr0=''),
    5212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5212, CurrentID=0, Status='live', Symbol='VIT', Aliases=['VIT1'], description='vitrin', other_designations='vitrin', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=36696707, end_position_on_the_genomic_accession=36814794, orientation='plus', exon_count=18, OMIM=[617693], no_hdr0=''),
    5213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5213, CurrentID=0, Status='live', Symbol='PFKM', Aliases=['ATP-PFK', 'GSD7', 'PFK-1', 'PFK-A', 'PFK1', 'PFKA', 'PFKX', 'PPP1R122'], description='phosphofructokinase, muscle', other_designations='ATP-dependent 6-phosphofructokinase, muscle type|6-phosphofructo-1-kinase|6-phosphofructokinase type A|6-phosphofructokinase, muscle type|phosphofructo-1-kinase isozyme A|phosphofructokinase 1|phosphofructokinase, polypeptide X|phosphofructokinase-M|phosphohexokinase|protein phosphatase 1, regulatory subunit 122', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48105353, end_position_on_the_genomic_accession=48146404, orientation='plus', exon_count=33, OMIM=[610681], no_hdr0=''),
    5214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5214, CurrentID=0, Status='live', Symbol='PFKP', Aliases=['ATP-PFK', 'PFK-C', 'PFK-P', 'PFKF'], description='phosphofructokinase, platelet', other_designations='ATP-dependent 6-phosphofructokinase, platelet type|6-phosphofructokinase type C|6-phosphofructokinase, platelet type|phosphofructo-1-kinase isozyme C|phosphofructokinase 1|phosphohexokinase', map_location='10p15.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=3067475, end_position_on_the_genomic_accession=3136805, orientation='plus', exon_count=28, OMIM=[171840], no_hdr0=''),
    5216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5216, CurrentID=0, Status='live', Symbol='PFN1', Aliases=['ALS18'], description='profilin 1', other_designations='profilin-1|epididymis tissue protein Li 184a|profilin I', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4945652, end_position_on_the_genomic_accession=4948530, orientation='minus', exon_count=3, OMIM=[176610], no_hdr0=''),
    5217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5217, CurrentID=0, Status='live', Symbol='PFN2', Aliases=['D3S1319E', 'PFL'], description='profilin 2', other_designations='profilin-2|profilin II', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149964904, end_position_on_the_genomic_accession=149970895, orientation='minus', exon_count=3, OMIM=[176590], no_hdr0=''),
    5218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5218, CurrentID=0, Status='live', Symbol='CDK14', Aliases=['PFTAIRE1', 'PFTK1'], description='cyclin dependent kinase 14', other_designations='cyclin-dependent kinase 14|PFTAIRE protein kinase 1|cell division protein kinase 14|serine/threonine-protein kinase PFTAIRE-1', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90596321, end_position_on_the_genomic_accession=91210590, orientation='plus', exon_count=17, OMIM=[610679], no_hdr0=''),
    5222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5222, CurrentID=0, Status='live', Symbol='PGA5', Aliases=['Pg5'], description='pepsinogen A5', other_designations='pepsin A-5|Pepsin A-4|Pepsinogen-4|pepsin A|pepsinogen 5, group I (pepsinogen A)|pepsinogen-5', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61241175, end_position_on_the_genomic_accession=61251444, orientation='plus', exon_count=9, OMIM=[169730], no_hdr0=''),
    5223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5223, CurrentID=0, Status='live', Symbol='PGAM1', Aliases=['HEL-S-35', 'PGAM-B', 'PGAMA'], description='phosphoglycerate mutase 1', other_designations='phosphoglycerate mutase 1|BPG-dependent PGAM 1|epididymis secretory protein Li 35|phosphoglycerate mutase 1 (brain)|phosphoglycerate mutase A, nonmuscle form|phosphoglycerate mutase isozyme B', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97426191, end_position_on_the_genomic_accession=97433444, orientation='plus', exon_count=5, OMIM=[172250], no_hdr0=''),
    5224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5224, CurrentID=0, Status='live', Symbol='PGAM2', Aliases=['GSD10', 'PGAM-M', 'PGAMM'], description='phosphoglycerate mutase 2', other_designations='phosphoglycerate mutase 2|BPG-dependent PGAM 2|muscle-specific phosphoglycerate mutase|phosphoglycerate mutase 2 (muscle)|phosphoglycerate mutase isozyme M', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44062727, end_position_on_the_genomic_accession=44065567, orientation='minus', exon_count=3, OMIM=[612931], no_hdr0=''),
    5225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5225, CurrentID=0, Status='live', Symbol='PGC', Aliases=['PEPC', 'PGII'], description='progastricsin', other_designations='gastricsin|pepsin C|pepsinogen C|pepsinogen group II|preprogastricsin', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41736711, end_position_on_the_genomic_accession=41747397, orientation='minus', exon_count=11, OMIM=[169740], no_hdr0=''),
    5226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5226, CurrentID=0, Status='live', Symbol='PGD', Aliases=['6PGD'], description='phosphogluconate dehydrogenase', other_designations='6-phosphogluconate dehydrogenase, decarboxylating', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10399064, end_position_on_the_genomic_accession=10420511, orientation='plus', exon_count=13, OMIM=[172200], no_hdr0=''),
    5228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5228, CurrentID=0, Status='live', Symbol='PGF', Aliases=['D12S1900L', 'PIGF', 'PLGF', 'PlGF-2', 'SHGC-10760', 'PGF'], description='placental growth factor', other_designations='placenta growth factor|placental growth factor, vascular endothelial growth factor-related protein', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74941830, end_position_on_the_genomic_accession=74955764, orientation='minus', exon_count=7, OMIM=[601121], no_hdr0=''),
    5229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5229, CurrentID=0, Status='live', Symbol='PGGT1B', Aliases=['BGGI', 'GGTI'], description='protein geranylgeranyltransferase type I subunit beta', other_designations='geranylgeranyl transferase type-1 subunit beta|CTC-428G20.3|GGTase-I-beta|geranylgeranyl transferase type I subunit beta|geranylgeranyltransferase type I beta subunit|protein geranylgeranyltransferase type I, beta subunit|type I protein geranyl-geranyltransferase subunit beta', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115200247, end_position_on_the_genomic_accession=115262887, orientation='minus', exon_count=9, OMIM=[602031], no_hdr0=''),
    5230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5230, CurrentID=0, Status='live', Symbol='PGK1', Aliases=['HEL-S-68p', 'MIG10', 'PGKA'], description='phosphoglycerate kinase 1', other_designations='phosphoglycerate kinase 1|PRP 2|cell migration-inducing gene 10 protein|epididymis secretory sperm binding protein Li 68p|primer recognition protein 2', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78104248, end_position_on_the_genomic_accession=78129295, orientation='plus', exon_count=11, OMIM=[311800], no_hdr0=''),
    5232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5232, CurrentID=0, Status='live', Symbol='PGK2', Aliases=['HEL-S-272', 'PGKB', 'PGKPS', 'dJ417L20.2'], description='phosphoglycerate kinase 2', other_designations='phosphoglycerate kinase 2|epididymis secretory protein Li 272|phosphoglycerate kinase autosomal pseudogene|phosphoglycerate kinase, testis specific|testicular tissue protein Li 139', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49785660, end_position_on_the_genomic_accession=49787285, orientation='minus', exon_count=1, OMIM=[172270], no_hdr0=''),
    5236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5236, CurrentID=0, Status='live', Symbol='PGM1', Aliases=['CDG1T', 'GSD14'], description='phosphoglucomutase 1', other_designations='phosphoglucomutase-1|PGM 1|glucose phosphomutase 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63593411, end_position_on_the_genomic_accession=63660245, orientation='plus', exon_count=13, OMIM=[171900], no_hdr0=''),
    5238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5238, CurrentID=0, Status='live', Symbol='PGM3', Aliases=['AGM1', 'IMD23', 'PAGM', 'PGM 3'], description='phosphoglucomutase 3', other_designations='phosphoacetylglucosamine mutase|N-acetylglucosamine-phosphate mutase 1|acetylglucosamine phosphomutase', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83150728, end_position_on_the_genomic_accession=83193900, orientation='minus', exon_count=19, OMIM=[172100], no_hdr0=''),
    5239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5239, CurrentID=0, Status='live', Symbol='PGM5', Aliases=['PGMRP'], description='phosphoglucomutase 5', other_designations='phosphoglucomutase-like protein 5|PGM-RP|aciculin|phosphoglucomutase-related protein', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68356584, end_position_on_the_genomic_accession=68531061, orientation='plus', exon_count=14, OMIM=[600981], no_hdr0=''),
    5241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5241, CurrentID=0, Status='live', Symbol='PGR', Aliases=['NR3C3', 'PR'], description='progesterone receptor', other_designations='progesterone receptor|nuclear receptor subfamily 3 group C member 3', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=101029624, end_position_on_the_genomic_accession=101130681, orientation='minus', exon_count=10, OMIM=[607311], no_hdr0=''),
    5243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5243, CurrentID=0, Status='live', Symbol='ABCB1', Aliases=['ABC20', 'CD243', 'CLCS', 'GP170', 'MDR1', 'P-GP', 'PGY1', 'p-170'], description='ATP binding cassette subfamily B member 1', other_designations='ATP-dependent translocase ABCB1|ATP-binding cassette, sub-family B (MDR/TAP), member 1|P-glycoprotein 1|colchicin sensitivity|doxorubicin resistance|multidrug resistance protein 1|phospholipid transporter ABCB1', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87503017, end_position_on_the_genomic_accession=87713295, orientation='minus', exon_count=32, OMIM=[171050], no_hdr0=''),
    5244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5244, CurrentID=0, Status='live', Symbol='ABCB4', Aliases=['ABC21', 'GBD1', 'ICP3', 'MDR2', 'MDR2/3', 'MDR3', 'PFIC-3', 'PGY3'], description='ATP binding cassette subfamily B member 4', other_designations='phosphatidylcholine translocator ABCB4|ATP-binding cassette sub-family B member 4|ATP-binding cassette, sub-family B (MDR/TAP), member 4|P-glycoprotein 3|P-glycoprotein-3/multiple drug resistance-3|multidrug resistance protein 3|multiple drug resistance 3', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87398988, end_position_on_the_genomic_accession=87476722, orientation='minus', exon_count=31, OMIM=[171060], no_hdr0=''),
    5245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5245, CurrentID=0, Status='live', Symbol='PHB', Aliases=['HEL-215', 'HEL-S-54e1', 'PHB'], description='prohibitin', other_designations='prohibitin|epididymis luminal protein 215|epididymis secretory sperm binding protein Li 54e', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49404052, end_position_on_the_genomic_accession=49414882, orientation='minus', exon_count=8, OMIM=[176705], no_hdr0=''),
    5250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5250, CurrentID=0, Status='live', Symbol='SLC25A3', Aliases=['OK/SW-cl.48', 'PHC', 'PTP'], description='solute carrier family 25 member 3', other_designations='phosphate carrier protein, mitochondrial|phosphate transport protein|solute carrier family 25 (mitochondrial carrier; phosphate carrier), member 3', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=98593686, end_position_on_the_genomic_accession=98606367, orientation='plus', exon_count=8, OMIM=[600370], no_hdr0=''),
    5251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5251, CurrentID=0, Status='live', Symbol='PHEX', Aliases=['HPDR', 'HPDR1', 'HYP', 'HYP1', 'LXHR', 'PEX', 'XLH'], description='phosphate regulating endopeptidase homolog X-linked', other_designations='phosphate-regulating neutral endopeptidase PHEX|X-linked hypophosphatemia protein|metalloendopeptidase homolog PEX|phosphate regulating gene with homologies to endopeptidases on the X chromosome (hypophosphatemia, vitamin D resistant rickets)|vitamin D-resistant hypophosphatemic rickets protein', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=22032325, end_position_on_the_genomic_accession=22251310, orientation='plus', exon_count=26, OMIM=[300550], no_hdr0=''),
    5252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5252, CurrentID=0, Status='live', Symbol='PHF1', Aliases=['MTF2L2', 'PCL1', 'PHF2', 'TDRD19C', 'hPHF1'], description='PHD finger protein 1', other_designations='PHD finger protein 1|hPCl1|polycomb-like 1|polycomb-like protein 1|testicular tissue protein Li 140|tudor domain containing 19C', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33410751, end_position_on_the_genomic_accession=33416443, orientation='plus', exon_count=16, OMIM=[602881], no_hdr0=''),
    5253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5253, CurrentID=0, Status='live', Symbol='PHF2', Aliases=['CENP-35', 'GRC5', 'JHDM1E', 'KDM7C'], description='PHD finger protein 2', other_designations='lysine-specific demethylase PHF2|centromere protein 35|jumonji C domain-containing histone demethylase 1E', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93576584, end_position_on_the_genomic_accession=93679587, orientation='plus', exon_count=22, OMIM=[604351], no_hdr0=''),
    5255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5255, CurrentID=0, Status='live', Symbol='PHKA1', Aliases=['PHKA'], description='phosphorylase kinase regulatory subunit alpha 1', other_designations='phosphorylase b kinase regulatory subunit alpha, skeletal muscle isoform|phosphorylase kinase alpha M subunit|phosphorylase kinase, alpha 1 (muscle), muscle glycogenosis', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72578814, end_position_on_the_genomic_accession=72714306, orientation='minus', exon_count=32, OMIM=[311870], no_hdr0=''),
    5256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5256, CurrentID=0, Status='live', Symbol='PHKA2', Aliases=['GSD9A', 'PHK', 'PYK', 'PYKL', 'XLG', 'XLG2'], description='phosphorylase kinase regulatory subunit alpha 2', other_designations='phosphorylase b kinase regulatory subunit alpha, liver isoform|phosphorylase kinase alpha L subunit|phosphorylase kinase alpha-subunit', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18892298, end_position_on_the_genomic_accession=18984114, orientation='minus', exon_count=33, OMIM=[300798], no_hdr0=''),
    5257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5257, CurrentID=0, Status='live', Symbol='PHKB', Aliases=[], description='phosphorylase kinase regulatory subunit beta', other_designations='phosphorylase b kinase regulatory subunit beta|phosphorylase kinase beta-subunit|phosphorylase kinase subunit beta|phosphorylase kinase, beta', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=47461299, end_position_on_the_genomic_accession=47701523, orientation='plus', exon_count=33, OMIM=[172490], no_hdr0=''),
    5260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5260, CurrentID=0, Status='live', Symbol='PHKG1', Aliases=['PHKG'], description='phosphorylase kinase catalytic subunit gamma 1', other_designations='phosphorylase b kinase gamma catalytic chain, skeletal muscle/heart isoform|PHK-gamma-M|phosphorylase kinase gamma subunit 1|phosphorylase kinase subunit gamma-1|phosphorylase kinase, gamma 1 (muscle)|serine/threonine-protein kinase PHKG1', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56079927, end_position_on_the_genomic_accession=56093450, orientation='minus', exon_count=13, OMIM=[172470], no_hdr0=''),
    5261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5261, CurrentID=0, Status='live', Symbol='PHKG2', Aliases=['GSD9C'], description='phosphorylase kinase catalytic subunit gamma 2', other_designations='phosphorylase b kinase gamma catalytic chain, liver/testis isoform|PHK-gamma-LT|PHK-gamma-T|PSK-C3|Phosphorylase kinase, gamma 2 (testis/liver)|phosphorylase kinase gamma subunit 2|phosphorylase kinase subunit gamma-2|phosphorylase kinase, gamma 2 (testis)|serine/threonine-protein kinase PHKG2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30748425, end_position_on_the_genomic_accession=30761176, orientation='plus', exon_count=10, OMIM=[172471], no_hdr0=''),
    5264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5264, CurrentID=0, Status='live', Symbol='PHYH', Aliases=['LN1', 'LNAP1', 'PAHX1', 'RD', 'PHYH'], description='phytanoyl-CoA 2-hydroxylase', other_designations='phytanoyl-CoA dioxygenase, peroxisomal|phytanic acid oxidase|phytanoil-CoA alpha hydroxylase|phytanoyl-CoA 2 oxoglutarate dioxygenase|phytanoyl-CoA alpha-hydroxylase', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13277799, end_position_on_the_genomic_accession=13300064, orientation='minus', exon_count=10, OMIM=[602026], no_hdr0=''),
    5265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5265, CurrentID=0, Status='live', Symbol='SERPINA1', Aliases=['A1A', 'A1AT', 'AAT', 'PI', 'PI1', 'PRO2275', 'alpha1AT', 'nNIF'], description='serpin family A member 1', other_designations='alpha-1-antitrypsin|alpha-1 antitrypsin|alpha-1 protease inhibitor|alpha-1 proteinase inhibitor|alpha-1-antiproteinase|alpha-1-antitrypsin short transcript variant 1C4|alpha-1-antitrypsin short transcript variant 1C5|anti-elastase|epididymis secretory sperm binding protein|protease inhibitor 1 (anti-elastase), alpha-1-antitrypsin|serine (or cysteine) proteinase inhibitor, clade A, member 1|serpin A1|serpin peptidase inhibitor clade A (alpha-1antiproteinase, antitrypsin) member 1|serpin peptidase inhibitor clade A member 1|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 1', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94376747, end_position_on_the_genomic_accession=94390654, orientation='minus', exon_count=7, OMIM=[107400], no_hdr0=''),
    5266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5266, CurrentID=0, Status='live', Symbol='PI3', Aliases=['ESI', 'SKALP', 'WAP3', 'WFDC14', 'cementoin'], description='peptidase inhibitor 3', other_designations='elafin|PI-3|WAP four-disulfide core domain 14|WAP four-disulfide core domain protein 14|elastase-specific inhibitor|peptidase inhibitor 3, skin-derived|pre-elafin|protease inhibitor 3, skin-derived (SKALP)|protease inhibitor WAP3|skin-derived antileukoproteinase|trappin-2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45174902, end_position_on_the_genomic_accession=45176544, orientation='plus', exon_count=3, OMIM=[182257], no_hdr0=''),
    5267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5267, CurrentID=0, Status='live', Symbol='SERPINA4', Aliases=['KAL', 'KLST', 'KST', 'PI-4', 'PI4', 'kallistatin'], description='serpin family A member 4', other_designations='kallistatin|kallikrein inhibitor|peptidase inhibitor 4|protease inhibitor 4 (kallistatin)|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 4|serpin A4|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 4|sserpin family A member 4|testicular secretory protein Li 22', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94561442, end_position_on_the_genomic_accession=94569906, orientation='plus', exon_count=5, OMIM=[147935], no_hdr0=''),
    5268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5268, CurrentID=0, Status='live', Symbol='SERPINB5', Aliases=['PI5', 'maspin'], description='serpin family B member 5', other_designations='serpin B5|PI-5|peptidase inhibitor 5|protease inhibitor 5 (maspin)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 5|serpin peptidase inhibitor, clade B (ovalbumin), member 5', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63476958, end_position_on_the_genomic_accession=63505085, orientation='plus', exon_count=8, OMIM=[154790], no_hdr0=''),
    5269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5269, CurrentID=0, Status='live', Symbol='SERPINB6', Aliases=['CAP', 'DFNB91', 'MSTP057', 'PI-6', 'PI6', 'PTI', 'SPI3'], description='serpin family B member 6', other_designations='serpin B6|cytoplasmic antiproteinase|protease inhibitor 6 (placental thrombin inhibitor)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 6|serpin peptidase inhibitor, clade B (ovalbumin), member 6', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2948159, end_position_on_the_genomic_accession=2971793, orientation='minus', exon_count=13, OMIM=[173321], no_hdr0=''),
    5270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5270, CurrentID=0, Status='live', Symbol='SERPINE2', Aliases=['GDN', 'GDNPF', 'PI-7', 'PI7', 'PN-1', 'PN1', 'PNI'], description='serpin family E member 2', other_designations='glia-derived nexin|glial-derived neurite promoting factor|peptidase inhibitor 7|protease nexin I|serpin E2|serpin peptidase inhibitor, clade E (nexin, plasminogen activator inhibitor type 1), member 2', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223975045, end_position_on_the_genomic_accession=224039286, orientation='minus', exon_count=13, OMIM=[177010], no_hdr0=''),
    5271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5271, CurrentID=0, Status='live', Symbol='SERPINB8', Aliases=['C18orf53', 'CAP2', 'PI-8', 'PI8', 'PSS5'], description='serpin family B member 8', other_designations='serpin B8|cytoplasmic antiproteinase 2|peptidase inhibitor 8|protease inhibitor 8 (ovalbumin type)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 8|serpin peptidase inhibitor, clade B (ovalbumin), member 8', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63970081, end_position_on_the_genomic_accession=64019779, orientation='plus', exon_count=10, OMIM=[601697], no_hdr0=''),
    5272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5272, CurrentID=0, Status='live', Symbol='SERPINB9', Aliases=['CAP-3', 'CAP3', 'PI-9', 'PI9'], description='serpin family B member 9', other_designations='serpin B9|cytoplasmic antiproteinase 3|peptidase inhibitor 9|protease inhibitor 9 (ovalbumin type)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 9|serpin peptidase inhibitor, clade B (ovalbumin), member 9|serpin peptidase inhibitor, clade B, member 9|testicular tissue protein Li 180', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2887270, end_position_on_the_genomic_accession=2903318, orientation='minus', exon_count=9, OMIM=[601799], no_hdr0=''),
    5273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5273, CurrentID=0, Status='live', Symbol='SERPINB10', Aliases=['PI-10', 'PI10'], description='serpin family B member 10', other_designations='serpin B10|bomapin|peptidase inhibitor 10|protease inhibitor 10 (ovalbumin type)|protease inhibitor 10 (ovalbumin type, bomapin)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 10|serpin peptidase inhibitor, clade B (ovalbumin), member 10', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63907958, end_position_on_the_genomic_accession=63936111, orientation='plus', exon_count=10, OMIM=[602058], no_hdr0=''),
    5274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5274, CurrentID=0, Status='live', Symbol='SERPINI1', Aliases=['HNS-S1', 'HNS-S2', 'PI12', 'neuroserpin'], description='serpin family I member 1', other_designations='neuroserpin|PI-12|peptidase inhibitor 12|serine (or cysteine) proteinase inhibitor, clade I (neuroserpin), member 1|serpin I1|serpin peptidase inhibitor clade I member 1|serpin peptidase inhibitor, clade I (neuroserpin), member 1|truncated HNS-T', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=167735721, end_position_on_the_genomic_accession=167825569, orientation='plus', exon_count=9, OMIM=[602445], no_hdr0=''),
    5275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5275, CurrentID=0, Status='live', Symbol='SERPINB13', Aliases=['HSHUR7SEQ', 'HUR7', 'PI13', 'headpin'], description='serpin family B member 13', other_designations='serpin B13|HURPIN|PI-13|UV-B repressed sequence, HUR 7|haCaT UV-repressible serpin|peptidase inhibitor 13|protease inhibitor 13 (hurpin, headpin)|proteinase inhibitor 13|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 13|serpin peptidase inhibitor, clade B (ovalbumin), member 13', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63586654, end_position_on_the_genomic_accession=63599192, orientation='plus', exon_count=9, OMIM=[604445], no_hdr0=''),
    5276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5276, CurrentID=0, Status='live', Symbol='SERPINI2', Aliases=['MEPI', 'PANCPIN', 'PI14', 'TSA2004'], description='serpin family I member 2', other_designations='serpin I2|myoepithelium-derived serine protease inhibitor|myoepithelium-derived serine proteinase inhibitor|pancreas-specific protein TSA2004|peptidase inhibitor 14|protease inhibitor 14|serine (or cysteine) proteinase inhibitor, clade I (neuroserpin), member 2|serine (or cysteine) proteinase inhibitor, clade I (pancpin), member 2|serpin peptidase inhibitor, clade I (pancpin), member 2', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=167441933, end_position_on_the_genomic_accession=167476963, orientation='minus', exon_count=11, OMIM=[605587], no_hdr0=''),
    5277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5277, CurrentID=0, Status='live', Symbol='PIGA', Aliases=['GPI3', 'MCAHS2', 'PIG-A', 'PNH1'], description='phosphatidylinositol glycan anchor biosynthesis class A', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit A|GLCNAC-PI synthesis protein|GPI anchor biosynthesis|class A GlcNAc-inositol phospholipid assembly protein|phosphatidylinositol-glycan biosynthesis, class A protein', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15319451, end_position_on_the_genomic_accession=15335554, orientation='minus', exon_count=7, OMIM=[311770], no_hdr0=''),
    5279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5279, CurrentID=0, Status='live', Symbol='PIGC', Aliases=['GPI2', 'GPIBD16', 'MRT62'], description='phosphatidylinositol glycan anchor biosynthesis class C', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit C|PIG-C|phosphatidylinositol-glycan biosynthesis, class C protein', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=172441457, end_position_on_the_genomic_accession=172444069, orientation='minus', exon_count=2, OMIM=[601730], no_hdr0=''),
    5281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5281, CurrentID=0, Status='live', Symbol='PIGF', Aliases=['OORS'], description='phosphatidylinositol glycan anchor biosynthesis class F', other_designations='phosphatidylinositol-glycan biosynthesis class F protein|GPI11 homolog|PIG-F', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46580937, end_position_on_the_genomic_accession=46617057, orientation='minus', exon_count=8, OMIM=[600153], no_hdr0=''),
    5283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5283, CurrentID=0, Status='live', Symbol='PIGH', Aliases=['GPI-H'], description='phosphatidylinositol glycan anchor biosynthesis class H', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit H|phosphatidylinositol-glycan biosynthesis, class H protein', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67589306, end_position_on_the_genomic_accession=67600302, orientation='minus', exon_count=5, OMIM=[600154], no_hdr0=''),
    5284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5284, CurrentID=0, Status='live', Symbol='PIGR', Aliases=[], description='polymeric immunoglobulin receptor', other_designations='polymeric immunoglobulin receptor|hepatocellular carcinoma associated protein TB6|poly-Ig receptor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206928522, end_position_on_the_genomic_accession=206946466, orientation='minus', exon_count=12, OMIM=[173880], no_hdr0=''),
    5286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5286, CurrentID=0, Status='live', Symbol='PIK3C2A', Aliases=['CPK', 'OCSKD', 'PI3-K-C2(ALPHA)', 'PI3-K-C2A', 'PI3K-C2-alpha', 'PI3K-C2alpha'], description='phosphatidylinositol-4-phosphate 3-kinase catalytic subunit type 2 alpha', other_designations='phosphatidylinositol 4-phosphate 3-kinase C2 domain-containing subunit alpha|C2-containing phosphatidylinositol kinase|phosphatidylinositol-4-phosphate 3-kinase C2 domain-containing subunit alpha|phosphoinositide 3-kinase-C2-alpha|phosphoinositide-3-kinase, class 2, alpha polypeptide|ptdIns-3-kinase C2 subunit alpha', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17086575, end_position_on_the_genomic_accession=17207986, orientation='minus', exon_count=35, OMIM=[603601], no_hdr0=''),
    5287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5287, CurrentID=0, Status='live', Symbol='PIK3C2B', Aliases=['C2-PI3K'], description='phosphatidylinositol-4-phosphate 3-kinase catalytic subunit type 2 beta', other_designations='phosphatidylinositol 4-phosphate 3-kinase C2 domain-containing subunit beta|PI3K-C2-beta|PI3K-C2beta|PTDINS-3-kinase C2 beta|phosphatidylinositol 3-kinase C2 domain-containing beta polypeptide|phosphoinositide 3-kinase-C2-beta|phosphoinositide-3-kinase, class 2, beta polypeptide|ptdIns-3-kinase C2 subunit beta', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204422633, end_position_on_the_genomic_accession=204494815, orientation='minus', exon_count=36, OMIM=[602838], no_hdr0=''),
    5288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5288, CurrentID=0, Status='live', Symbol='PIK3C2G', Aliases=['PI3K-C2-gamma', 'PI3K-C2GAMMA'], description='phosphatidylinositol-4-phosphate 3-kinase catalytic subunit type 2 gamma', other_designations='phosphatidylinositol 4-phosphate 3-kinase C2 domain-containing subunit gamma|PTDINS-3-kinase C2 gamma|phosphatidylinositol-4-phosphate 3-kinase C2 domain-containing gamma polypeptide|phosphatidylinositol-4-phosphate 3-kinase C2 domain-containing subunit gamma|phosphoinositide-3-kinase, class 2, gamma polypeptide', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=18242946, end_position_on_the_genomic_accession=18716861, orientation='plus', exon_count=45, OMIM=[609001], no_hdr0=''),
    5289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5289, CurrentID=0, Status='live', Symbol='PIK3C3', Aliases=['VPS34', 'Vps34', 'hVps34'], description='phosphatidylinositol 3-kinase catalytic subunit type 3', other_designations='phosphatidylinositol 3-kinase catalytic subunit type 3|PI3-kinase type 3|PI3K type 3|PtdIns-3-kinase type 3|phosphatidylinositol 3-kinase p100 subunit|phosphoinositide-3-kinase, class 3', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=41955226, end_position_on_the_genomic_accession=42087830, orientation='plus', exon_count=27, OMIM=[602609], no_hdr0=''),
    5290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5290, CurrentID=0, Status='live', Symbol='PIK3CA', Aliases=['CLAPO', 'CLOVE', 'CWS5', 'MCAP', 'MCM', 'MCMTC', 'PI3K', 'PI3K-alpha', 'p110-alpha'], description='phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit alpha', other_designations='phosphatidylinositol 4,5-bisphosphate 3-kinase catalytic subunit alpha isoform|PI3-kinase p110 subunit alpha|mutant phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit alpha|phosphatidylinositol 3-kinase, catalytic, 110-KD, alpha|phosphatidylinositol 3-kinase, catalytic, alpha polypeptide|phosphatidylinositol-4,5-bisphosphate 3-kinase 110 kDa catalytic subunit alpha|phosphoinositide 3-kinase alpha|phosphoinositide-3-kinase, catalytic, alpha polypeptide|ptdIns-3-kinase subunit p110-alpha|serine/threonine protein kinase PIK3CA', map_location='3q26.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179148114, end_position_on_the_genomic_accession=179240093, orientation='plus', exon_count=23, OMIM=[171834], no_hdr0=''),
    5291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5291, CurrentID=0, Status='live', Symbol='PIK3CB', Aliases=['P110BETA', 'PI3K', 'PI3KBETA', 'PIK3C1'], description='phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit beta', other_designations='phosphatidylinositol 4,5-bisphosphate 3-kinase catalytic subunit beta isoform|PI3-kinase p110 subunit beta|PI3-kinase subunit beta|PI3K-beta|PtdIns-3-kinase p110|phosphatidylinositol 4,5-bisphosphate 3-kinase 110 kDa catalytic subunit beta|phosphoinositide-3-kinase, catalytic, beta polypeptide|ptdIns-3-kinase subunit beta|ptdIns-3-kinase subunit p110-beta', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138652698, end_position_on_the_genomic_accession=138834928, orientation='minus', exon_count=27, OMIM=[602925], no_hdr0=''),
    5292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5292, CurrentID=0, Status='live', Symbol='PIM1', Aliases=['PIM'], description='Pim-1 proto-oncogene, serine/threonine kinase', other_designations='serine/threonine-protein kinase pim-1|Oncogene PIM1|pim-1 oncogene (proviral integration site 1)|proto-oncogene serine/threonine-protein kinase pim-1', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37170152, end_position_on_the_genomic_accession=37175428, orientation='plus', exon_count=6, OMIM=[164960], no_hdr0=''),
    5293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5293, CurrentID=0, Status='live', Symbol='PIK3CD', Aliases=['APDS', 'IMD14', 'IMD14A', 'IMD14B', 'P110DELTA', 'PI3K', 'ROCHIS', 'p110D'], description='phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit delta', other_designations='phosphatidylinositol 4,5-bisphosphate 3-kinase catalytic subunit delta isoform|PI3-kinase p110 subunit delta|PI3Kdelta|phosphatidylinositol-4,5-bisphosphate 3-kinase 110 kDa catalytic subunit delta|phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit delta short variant 20|phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit delta short variant 8|phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit delta short variant 8/20|phosphoinositide-3-kinase C|phosphoinositide-3-kinase, catalytic, delta polypeptide variant p37delta|ptdIns-3-kinase subunit p110-delta', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9629889, end_position_on_the_genomic_accession=9729114, orientation='plus', exon_count=30, OMIM=[602839], no_hdr0=''),
    5294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5294, CurrentID=0, Status='live', Symbol='PIK3CG', Aliases=['PI3CG', 'PI3K', 'PI3Kgamma', 'PIK3', 'p110gamma', 'p120-PI3K'], description='phosphatidylinositol-4,5-bisphosphate 3-kinase catalytic subunit gamma', other_designations='phosphatidylinositol 4,5-bisphosphate 3-kinase catalytic subunit gamma isoform|1-phosphatidylinositol 3-kinase|PI3-kinase subunit gamma|phosphatidylinositol 3 kinase gamma, p110 gamma|phosphatidylinositol 3-kinase catalytic 110-kD gamma|phosphatidylinositol-4,5-bisphosphate 3-kinase 110 kDa catalytic subunit gamma|phosphoinositide-3-kinase gamma catalytic subunit|ptdIns-3-kinase subunit gamma|ptdIns-3-kinase subunit p110-gamma|serine/threonine protein kinase PIK3CG', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=106865282, end_position_on_the_genomic_accession=106908980, orientation='plus', exon_count=15, OMIM=[601232], no_hdr0=''),
    5295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5295, CurrentID=0, Status='live', Symbol='PIK3R1', Aliases=['AGM7', 'GRB1', 'IMD36', 'p85', 'p85-ALPHA'], description='phosphoinositide-3-kinase regulatory subunit 1', other_designations='phosphatidylinositol 3-kinase regulatory subunit alpha|PI3-kinase subunit p85-alpha|PI3K regulatory subunit alpha|phosphatidylinositol 3-kinase 85 kDa regulatory subunit alpha|phosphatidylinositol 3-kinase, regulatory subunit, polypeptide 1 (p85 alpha)|phosphatidylinositol 3-kinase-associated p-85 alpha|phosphoinositide-3-kinase regulatory subunit alpha|phosphoinositide-3-kinase, regulatory subunit 1 (alpha)|ptdIns-3-kinase regulatory subunit alpha', map_location='5q13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=68215737, end_position_on_the_genomic_accession=68301821, orientation='plus', exon_count=22, OMIM=[171833], no_hdr0=''),
    5296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5296, CurrentID=0, Status='live', Symbol='PIK3R2', Aliases=['MPPH', 'MPPH1', 'P85B', 'p85', 'p85-BETA'], description='phosphoinositide-3-kinase regulatory subunit 2', other_designations='phosphatidylinositol 3-kinase regulatory subunit beta|PI3-kinase subunit p85-beta|PI3K regulatory subunit beta|phosphatidylinositol 3-kinase 85 kDa regulatory subunit beta|phosphatidylinositol 3-kinase, regulatory subunit, polypeptide 2 (p85 beta)|phosphoinositide-3-kinase regulatory subunit beta|phosphoinositide-3-kinase, regulatory subunit 2 (beta)|ptdIns-3-kinase regulatory subunit p85-beta', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18153163, end_position_on_the_genomic_accession=18170532, orientation='plus', exon_count=16, OMIM=[603157], no_hdr0=''),
    5297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5297, CurrentID=0, Status='live', Symbol='PI4KA', Aliases=['PI4K-ALPHA', 'PIK4CA', 'PMGYCHA', 'pi4K230'], description='phosphatidylinositol 4-kinase alpha', other_designations='phosphatidylinositol 4-kinase alpha|PI4-kinase alpha|phosphatidylinositol 4-kinase 230|phosphatidylinositol 4-kinase III alpha|phosphatidylinositol 4-kinase IIII+/-|phosphatidylinositol 4-kinase, catalytic, alpha|phosphatidylinositol 4-kinase, type III, alpha|ptdIns-4-kinase alpha|testicular secretory protein Li 35', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20707691, end_position_on_the_genomic_accession=20858812, orientation='minus', exon_count=59, OMIM=[600286], no_hdr0=''),
    5298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5298, CurrentID=0, Status='live', Symbol='PI4KB', Aliases=['NPIK', 'PI4K-BETA', 'PI4K92ETA', 'PI4KIII', 'PI4KIIIBETA', 'PIK4CB', 'PI4KB'], description='phosphatidylinositol 4-kinase beta', other_designations='phosphatidylinositol 4-kinase beta|PtdIns 4-kinase beta|phosphatidylinositol 4-kinase, catalytic, beta|phosphatidylinositol 4-kinase, wortmannin-sensitive|type III phosphatidylinositol 4-kinase beta', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151291797, end_position_on_the_genomic_accession=151327715, orientation='minus', exon_count=15, OMIM=[602758], no_hdr0=''),
    5300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5300, CurrentID=0, Status='live', Symbol='PIN1', Aliases=['DOD', 'UBL5'], description='peptidylprolyl cis/trans isomerase, NIMA-interacting 1', other_designations='peptidyl-prolyl cis-trans isomerase NIMA-interacting 1|PPIase Pin1|protein (peptidyl-prolyl cis/trans isomerase) NIMA-interacting 1|protein interacting with never in mitosis A1|rotamase Pin1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9835318, end_position_on_the_genomic_accession=9849689, orientation='plus', exon_count=6, OMIM=[601052], no_hdr0=''),
    5303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5303, CurrentID=0, Status='live', Symbol='PIN4', Aliases=['EPVH', 'PAR14', 'PAR17'], description='peptidylprolyl cis/trans isomerase, NIMA-interacting 4', other_designations='peptidyl-prolyl cis-trans isomerase NIMA-interacting 4|PPIase PIN4|eukaryotic parvulin homolog|hEPVH|hPar14|hPar17|parvulin|parvulin-14|parvulin-17|peptidyl-prolyl cis-trans isomerase Pin4|peptidyl-prolyl cis/trans isomerase EPVH|protein (peptidylprolyl cis/trans isomerase) NIMA-interacting, 4 (parvulin)|rotamase PIN4', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72181676, end_position_on_the_genomic_accession=72263964, orientation='plus', exon_count=5, OMIM=[300252], no_hdr0=''),
    5304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5304, CurrentID=0, Status='live', Symbol='PIP', Aliases=['GCDFP-15', 'GCDFP15', 'GPIP4'], description='prolactin induced protein', other_designations='prolactin-inducible protein|SABP|gross cystic disease fluid protein 15|secretory actin-binding protein', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143132077, end_position_on_the_genomic_accession=143139739, orientation='plus', exon_count=4, OMIM=[176720], no_hdr0=''),
    5305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5305, CurrentID=0, Status='live', Symbol='PIP4K2A', Aliases=['PI5P4KA', 'PIP5K2A', 'PIP5KII-alpha', 'PIP5KIIA', 'PIPK'], description='phosphatidylinositol-5-phosphate 4-kinase type 2 alpha', other_designations='phosphatidylinositol 5-phosphate 4-kinase type-2 alpha|1-phosphatidylinositol 5-phosphate 4-kinase 2-alpha|1-phosphatidylinositol-4-phosphate kinase|1-phosphatidylinositol-4-phosphate-5-kinase|PI(5)P 4-kinase type II alpha|PI5P4Kalpha|PIP4KII-alpha|PIP5KIII|PIP5KIIalpha|diphosphoinositide kinase 2-alpha|phosphatidylinositol 5-phosphate 4-kinase type II alpha|phosphatidylinositol-4-phosphate 5-kinase, type II, alpha', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22534854, end_position_on_the_genomic_accession=22714578, orientation='minus', exon_count=13, OMIM=[603140], no_hdr0=''),
    5306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5306, CurrentID=0, Status='live', Symbol='PITPNA', Aliases=['HEL-S-36', 'PI-TPalpha', 'PITPN', 'VIB1A'], description='phosphatidylinositol transfer protein alpha', other_designations='phosphatidylinositol transfer protein alpha isoform|PI-TP-alpha|epididymis secretory protein Li 36|ptdIns transfer protein alpha|ptdInsTP alpha', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1517718, end_position_on_the_genomic_accession=1562803, orientation='minus', exon_count=12, OMIM=[600174], no_hdr0=''),
    5307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5307, CurrentID=0, Status='live', Symbol='PITX1', Aliases=['BFT', 'CCF', 'LBNBG', 'POTX', 'PTX1'], description='paired like homeodomain 1', other_designations='pituitary homeobox 1|hindlimb expressed homeobox protein backfoot|homeobox protein PITX1|paired-like homeodomain transcription factor 1|pituitary homeo box 1|pituitary otx-related factor', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135027734, end_position_on_the_genomic_accession=135034228, orientation='minus', exon_count=3, OMIM=[602149], no_hdr0=''),
    5308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5308, CurrentID=0, Status='live', Symbol='PITX2', Aliases=['ARP1', 'ASGD4', 'Brx1', 'IDG2', 'IGDS', 'IGDS2', 'IHG2', 'IRID2', 'Otlx2', 'PTX2', 'RGS', 'RIEG', 'RIEG1', 'RS'], description='paired like homeodomain 2', other_designations='pituitary homeobox 2|ALL1-responsive protein ARP1|all1-responsive gene 1|homeobox protein PITX2|paired-like homeodomain transcription factor 2|rieg bicoid-related homeobox transcription factor 1|solurshin', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=110617423, end_position_on_the_genomic_accession=110642123, orientation='minus', exon_count=9, OMIM=[601542], no_hdr0=''),
    5309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5309, CurrentID=0, Status='live', Symbol='PITX3', Aliases=['ASGD1', 'ASMD', 'ASOD', 'CTPP4', 'CTRCT11', 'PTX3'], description='paired like homeodomain 3', other_designations='pituitary homeobox 3|homeobox protein PITX3', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102230189, end_position_on_the_genomic_accession=102241512, orientation='minus', exon_count=4, OMIM=[602669], no_hdr0=''),
    5310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5310, CurrentID=0, Status='live', Symbol='PKD1', Aliases=['PBP', 'PC1', 'Pc-1', 'TRPP1'], description='polycystin 1, transient receptor potential channel interacting', other_designations='polycystin-1|autosomal dominant polycystic kidney disease 1 protein|polycystic kidney disease 1 (autosomal dominant)|polycystic kidney disease-associated protein|transient receptor potential cation channel, subfamily P, member 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2088708, end_position_on_the_genomic_accession=2135898, orientation='minus', exon_count=51, OMIM=[601313], no_hdr0=''),
    5311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5311, CurrentID=0, Status='live', Symbol='PKD2', Aliases=['APKD2', 'PC2', 'PKD4', 'Pc-2', 'TRPP2'], description='polycystin 2, transient receptor potential cation channel', other_designations='polycystin-2|autosomal dominant polycystic kidney disease type II protein|polycystic kidney disease 2 (autosomal dominant)|transient receptor potential cation channel subfamily P member 2', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88007635, end_position_on_the_genomic_accession=88077779, orientation='plus', exon_count=16, OMIM=[173910], no_hdr0=''),
    5313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5313, CurrentID=0, Status='live', Symbol='PKLR', Aliases=['PK1', 'PKL', 'PKRL', 'RPK'], description='pyruvate kinase L/R', other_designations='pyruvate kinase PKLR|R-type/L-type pyruvate kinase|pyruvate kinase 1|pyruvate kinase isozyme R/L|pyruvate kinase isozymes L/R|pyruvate kinase isozymes R/L|pyruvate kinase type L|pyruvate kinase, liver and RBC|pyruvate kinase, liver and blood cell|red cell/liver pyruvate kinase', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155289293, end_position_on_the_genomic_accession=155301438, orientation='minus', exon_count=12, OMIM=[609712], no_hdr0=''),
    5314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5314, CurrentID=0, Status='live', Symbol='PKHD1', Aliases=['ARPKD', 'FCYT', 'FPC', 'PKD4', 'TIGM1'], description='PKHD1 ciliary IPT domain containing fibrocystin/polyductin', other_designations='fibrocystin|PKHD1, fibrocystin/polyductin|TIG multiple domains 1|fibrocystin/polyductin complex|polycystic kidney and hepatic disease 1 (autosomal recessive)|polycystic kidney and hepatic disease 1 protein|polyductin|tigmin', map_location='6p12.3-p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=51614685, end_position_on_the_genomic_accession=52087625, orientation='minus', exon_count=75, OMIM=[606702], no_hdr0=''),
    5315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5315, CurrentID=0, Status='live', Symbol='PKM', Aliases=['CTHBP', 'HEL-S-30', 'OIP3', 'PK32', 'TCB', 'THBP1', 'p58', 'PKM'], description='pyruvate kinase M1/2', other_designations='pyruvate kinase PKM|OPA-interacting protein 3|PK, muscle type|cytosolic thyroid hormone-binding protein|epididymis secretory protein Li 30|pyruvate kinase 2/3|pyruvate kinase isozymes M1/M2|pyruvate kinase muscle isozyme|pyruvate kinase, muscle|thyroid hormone-binding protein 1|thyroid hormone-binding protein, cytosolic|tumor M2-PK', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72199029, end_position_on_the_genomic_accession=72231389, orientation='minus', exon_count=16, OMIM=[179050], no_hdr0=''),
    5316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5316, CurrentID=0, Status='live', Symbol='PKNOX1', Aliases=['PREP1', 'pkonx1c'], description='PBX/knotted 1 homeobox 1', other_designations='homeobox protein PKNOX1|PBX/knotted homeobox 1|Pbx regulating protein-1|homeobox protein PREP-1|human homeobox-containing protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42974562, end_position_on_the_genomic_accession=43033931, orientation='plus', exon_count=11, OMIM=[602100], no_hdr0=''),
    5317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5317, CurrentID=0, Status='live', Symbol='PKP1', Aliases=['B6P', 'EDSFS'], description='plakophilin 1', other_designations='plakophilin-1|band 6 protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201283506, end_position_on_the_genomic_accession=201332989, orientation='plus', exon_count=15, OMIM=[601975], no_hdr0=''),
    5318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5318, CurrentID=0, Status='live', Symbol='PKP2', Aliases=['ARVD9'], description='plakophilin 2', other_designations='plakophilin-2', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=32790755, end_position_on_the_genomic_accession=32896777, orientation='minus', exon_count=14, OMIM=[602861], no_hdr0=''),
    5319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5319, CurrentID=0, Status='live', Symbol='PLA2G1B', Aliases=['PLA2', 'PLA2A', 'PPLA2'], description='phospholipase A2 group IB', other_designations='phospholipase A2|phosphatidylcholine 2-acylhydrolase 1B|phospholipase A2, group IB (pancreas)', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120322115, end_position_on_the_genomic_accession=120327779, orientation='minus', exon_count=4, OMIM=[172410], no_hdr0=''),
    5320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5320, CurrentID=0, Status='live', Symbol='PLA2G2A', Aliases=['MOM1', 'PLA2', 'PLA2B', 'PLA2L', 'PLA2S', 'PLAS1', 'sPLA2'], description='phospholipase A2 group IIA', other_designations='phospholipase A2, membrane associated|GIIC sPLA2|NPS-PLA2|group IIA phospholipase A2|non-pancreatic secretory phospholipase A2|phosphatidylcholine 2-acylhydrolase 2A|phospholipase A2, group IIA (platelets, synovial fluid)', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19975431, end_position_on_the_genomic_accession=19980434, orientation='minus', exon_count=6, OMIM=[172411], no_hdr0=''),
    5321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5321, CurrentID=0, Status='live', Symbol='PLA2G4A', Aliases=['GURDP', 'PLA2G4', 'cPLA2', 'cPLA2-alpha'], description='phospholipase A2 group IVA', other_designations='cytosolic phospholipase A2|calcium-dependent phospholipid-binding protein|lysophospholipase|phosphatidylcholine 2-acylhydrolase|phospholipase A2, group IVA (cytosolic, calcium-dependent)', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186828949, end_position_on_the_genomic_accession=186988981, orientation='plus', exon_count=19, OMIM=[600522], no_hdr0=''),
    5322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5322, CurrentID=0, Status='live', Symbol='PLA2G5', Aliases=['FRFB', 'GV-PLA2', 'PLA2-10', 'hVPLA(2)'], description='phospholipase A2 group V', other_designations='phospholipase A2 group V|Ca2+-dependent phospholipase A2|calcium-dependent phospholipase A2|phosphatidylcholine 2-acylhydrolase 5', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20028349, end_position_on_the_genomic_accession=20091911, orientation='plus', exon_count=13, OMIM=[601192], no_hdr0=''),
    5324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5324, CurrentID=0, Status='live', Symbol='PLAG1', Aliases=['PSA', 'SGPA', 'SRS4', 'ZNF912'], description='PLAG1 zinc finger', other_designations='zinc finger protein PLAG1|COL1A2/PLAG1 fusion|HAS2/PLAG1 fusion|pleiomorphic adenoma gene 1', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56160909, end_position_on_the_genomic_accession=56211327, orientation='minus', exon_count=6, OMIM=[603026], no_hdr0=''),
    5325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5325, CurrentID=0, Status='live', Symbol='PLAGL1', Aliases=['LOT1', 'ZAC', 'ZAC1'], description='PLAG1 like zinc finger 1', other_designations='zinc finger protein PLAGL1|PLAG-like 1|lost on transformation 1|pleiomorphic adenoma gene-like 1|tumor suppressor ZAC', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143940300, end_position_on_the_genomic_accession=144064599, orientation='minus', exon_count=12, OMIM=[603044], no_hdr0=''),
    5326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5326, CurrentID=0, Status='live', Symbol='PLAGL2', Aliases=['ZNF900'], description='PLAG1 like zinc finger 2', other_designations='zinc finger protein PLAGL2|C2H2-type zinc finger protein|pleiomorphic adenoma gene-like 2|pleiomorphic adenoma-like protein 2', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32192504, end_position_on_the_genomic_accession=32207743, orientation='minus', exon_count=5, OMIM=[604866], no_hdr0=''),
    5327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5327, CurrentID=0, Status='live', Symbol='PLAT', Aliases=['T-PA', 'TPA'], description='plasminogen activator, tissue type', other_designations='tissue-type plasminogen activator|alteplase|plasminogen/activator kringle|reteplase|t-plasminogen activator', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42174718, end_position_on_the_genomic_accession=42207565, orientation='minus', exon_count=14, OMIM=[173370], no_hdr0=''),
    5328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5328, CurrentID=0, Status='live', Symbol='PLAU', Aliases=['ATF', 'BDPLT5', 'QPD', 'UPA', 'URK', 'u-PA'], description='plasminogen activator, urokinase', other_designations='urokinase-type plasminogen activator|U-plasminogen activator|plasminogen activator, urinary', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73909182, end_position_on_the_genomic_accession=73917497, orientation='plus', exon_count=12, OMIM=[191840], no_hdr0=''),
    5329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5329, CurrentID=0, Status='live', Symbol='PLAUR', Aliases=['CD87', 'U-PAR', 'UPAR', 'URKR'], description='plasminogen activator, urokinase receptor', other_designations='urokinase plasminogen activator surface receptor|monocyte activation antigen Mo3|u-plasminogen activator receptor form 2|urokinase-type plasminogen activator (uPA) receptor', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43646095, end_position_on_the_genomic_accession=43670197, orientation='minus', exon_count=11, OMIM=[173391], no_hdr0=''),
    5330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5330, CurrentID=0, Status='live', Symbol='PLCB2', Aliases=['PLC-beta-2'], description='phospholipase C beta 2', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase beta-2|phosphoinositide phospholipase C-beta-2', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40285496, end_position_on_the_genomic_accession=40307945, orientation='minus', exon_count=35, OMIM=[604114], no_hdr0=''),
    5331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5331, CurrentID=0, Status='live', Symbol='PLCB3', Aliases=['SMDCD'], description='phospholipase C beta 3', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase beta-3|PLC beta 3|phosphoinositide phospholipase C-beta-3|phospholipase C, beta 3 (phosphatidylinositol-specific)', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64251530, end_position_on_the_genomic_accession=64269452, orientation='plus', exon_count=33, OMIM=[600230], no_hdr0=''),
    5332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5332, CurrentID=0, Status='live', Symbol='PLCB4', Aliases=['ARCND2', 'PI-PLC'], description='phospholipase C beta 4', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase beta-4|1-phosphatidyl-D-myo-inositol-4,5-bisphosphate|PLC-beta-4|dJ1119D9.2 (Phopholipase C, beta 4 (1-Phosphatidylinositol-4,5-Bisphosphate Phosphodiesterase Beta 4))|inositoltrisphosphohydrolase|monophosphatidylinositol phosphodiesterase|phosphoinositidase C|phosphoinositide phospholipase C-beta-4|triphosphoinositide phosphodiesterase', map_location='20p12.3-p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=9068678, end_position_on_the_genomic_accession=9480808, orientation='plus', exon_count=46, OMIM=[600810], no_hdr0=''),
    5333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5333, CurrentID=0, Status='live', Symbol='PLCD1', Aliases=['NDNC3', 'PLC-III'], description='phospholipase C delta 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase delta-1|PLC-delta-1|Phospholipase C I 1|epididymis secretory sperm binding protein|phosphoinositide phospholipase C-delta-1|phospholipase C-III', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38007496, end_position_on_the_genomic_accession=38029642, orientation='minus', exon_count=16, OMIM=[602142], no_hdr0=''),
    5334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5334, CurrentID=0, Status='live', Symbol='PLCL1', Aliases=['PLCE', 'PLCL', 'PLDL1', 'PPP1R127', 'PRIP'], description='phospholipase C like 1 (inactive)', other_designations='inactive phospholipase C-like protein 1|PLC-L1|phospholipase C, epsilon|phospholipase C-deleted in lung carcinoma|phospholipase C-like 1|phospholipase C-related but catalytically inactive protein|protein phosphatase 1, regulatory subunit 127', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197804593, end_position_on_the_genomic_accession=198149873, orientation='plus', exon_count=10, OMIM=[600597], no_hdr0=''),
    5335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5335, CurrentID=0, Status='live', Symbol='PLCG1', Aliases=['NCKAP3', 'PLC-II', 'PLC1', 'PLC148', 'PLCgamma1'], description='phospholipase C gamma 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase gamma-1|1-phosphatidyl-D-myo-inositol-4,5-bisphosphate|PLC-148|PLC-gamma-1|inositoltrisphosphohydrolase|monophosphatidylinositol phosphodiesterase|phosphatidylinositol phospholipase C|phosphoinositidase C|phosphoinositide phospholipase C|phosphoinositide phospholipase C-gamma-1|phospholipase C, gamma 1 (formerly subtype 148)|phospholipase C-148|phospholipase C-II|triphosphoinositide phosphodiesterase', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41137519, end_position_on_the_genomic_accession=41177626, orientation='plus', exon_count=32, OMIM=[172420], no_hdr0=''),
    5336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5336, CurrentID=0, Status='live', Symbol='PLCG2', Aliases=['APLAID', 'FCAS3', 'PLC-IV', 'PLC-gamma-2'], description='phospholipase C gamma 2', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase gamma-2|phosphoinositide phospholipase C-gamma-2|phospholipase C, gamma 2 (phosphatidylinositol-specific)|phospholipase C-IV', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81779291, end_position_on_the_genomic_accession=81962685, orientation='plus', exon_count=33, OMIM=[600220], no_hdr0=''),
    5337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5337, CurrentID=0, Status='live', Symbol='PLD1', Aliases=['CVDD'], description='phospholipase D1', other_designations='phospholipase D1|choline phosphatase 1|phosphatidylcholine-hydrolyzing phospholipase D1|phospholipase D1, phosphatidylcholine-specific', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=171600404, end_position_on_the_genomic_accession=171810483, orientation='minus', exon_count=33, OMIM=[602382], no_hdr0=''),
    5338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5338, CurrentID=0, Status='live', Symbol='PLD2', Aliases=['PLD1C'], description='phospholipase D2', other_designations='phospholipase D2|choline phosphatase 2|phosphatidylcholine-hydrolyzing phospholipase D2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4807152, end_position_on_the_genomic_accession=4823432, orientation='plus', exon_count=25, OMIM=[602384], no_hdr0=''),
    5339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5339, CurrentID=0, Status='live', Symbol='PLEC', Aliases=['EBS1', 'EBSMD', 'EBSND', 'EBSO', 'EBSOG', 'EBSPA', 'HD1', 'LGMD2Q', 'LGMDR17', 'PCN1', 'PLEC1b', 'PLTN', 'PLEC'], description='plectin', other_designations='plectin|hemidesmosomal protein 1|plectin 1, intermediate filament binding protein 500kDa', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143915153, end_position_on_the_genomic_accession=143976800, orientation='minus', exon_count=43, OMIM=[601282], no_hdr0=''),
    5340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5340, CurrentID=0, Status='live', Symbol='PLG', Aliases=['HAE4'], description='plasminogen', other_designations='plasminogen|plasmin', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160702193, end_position_on_the_genomic_accession=160754097, orientation='plus', exon_count=19, OMIM=[173350], no_hdr0=''),
    5341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5341, CurrentID=0, Status='live', Symbol='PLEK', Aliases=['P47'], description='pleckstrin', other_designations='pleckstrin|platelet 47 kDa protein', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68365282, end_position_on_the_genomic_accession=68397453, orientation='plus', exon_count=9, OMIM=[173570], no_hdr0=''),
    5342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5342, CurrentID=0, Status='live', Symbol='PLGLB2', Aliases=['PLGLA', 'PLGLA1', 'PLGP1', 'PLGP2', 'PRGA'], description='plasminogen like B2', other_designations='plasminogen-like protein B|Plasminogen-like protein A|Plasminogen-like protein A1|plasminogen pseudogene 1|plasminogen-related protein A|plasminogen-related protein B|type B plasminogen related', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=87748087, end_position_on_the_genomic_accession=87759476, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    5343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5343, CurrentID=0, Status='live', Symbol='PLGLB1', Aliases=['PLGL', 'PLGP1', 'PRGB', 'PRP-B'], description='plasminogen like B1', other_designations='plasminogen-like protein B|plasminogen-related protein B|type B plasminogen related', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=87010224, end_position_on_the_genomic_accession=87021844, orientation='minus', exon_count=4, OMIM=[173340], no_hdr0=''),
    5345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5345, CurrentID=0, Status='live', Symbol='SERPINF2', Aliases=['A2AP', 'AAP', 'ALPHA-2-PI', 'API', 'PLI', 'alpha2AP'], description='serpin family F member 2', other_designations='alpha-2-antiplasmin|alpha-2-AP|alpha-2-plasmin inhibitor|plasmin inhibitor|serine (or cysteine) proteinase inhibitor, clade F (alpha-2 antiplasmin, pigment epithelium derived factor), member 2|serpin F2|serpin peptidase inhibitor, clade F (alpha-2 antiplasmin, pigment epithelium derived factor), member 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1742808, end_position_on_the_genomic_accession=1755265, orientation='plus', exon_count=12, OMIM=[613168], no_hdr0=''),
    5346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5346, CurrentID=0, Status='live', Symbol='PLIN1', Aliases=['FPLD4', 'PERI', 'PLIN'], description='perilipin 1', other_designations='perilipin-1|lipid droplet-associated protein', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89664365, end_position_on_the_genomic_accession=89679367, orientation='minus', exon_count=10, OMIM=[170290], no_hdr0=''),
    5347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5347, CurrentID=0, Status='live', Symbol='PLK1', Aliases=['PLK', 'STPK13'], description='polo like kinase 1', other_designations='serine/threonine-protein kinase PLK1|PLK-1|cell cycle regulated protein kinase|polo (Drosophia)-like kinase|serine/threonine-protein kinase 13', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23678889, end_position_on_the_genomic_accession=23690367, orientation='plus', exon_count=10, OMIM=[602098], no_hdr0=''),
    5348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5348, CurrentID=0, Status='live', Symbol='FXYD1', Aliases=['PLM'], description='FXYD domain containing ion transport regulator 1', other_designations='phospholemman|sodium/potassium-transporting ATPase subunit FXYD1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35137206, end_position_on_the_genomic_accession=35143109, orientation='plus', exon_count=12, OMIM=[602359], no_hdr0=''),
    5349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5349, CurrentID=0, Status='live', Symbol='FXYD3', Aliases=['MAT8', 'PLML'], description='FXYD domain containing ion transport regulator 3', other_designations='FXYD domain-containing ion transport regulator 3|chloride conductance inducer protein Mat-8|mammary tumor 8 kDa protein|phospholemman-like protein|sodium/potassium-transporting ATPase subunit FXYD3', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35115823, end_position_on_the_genomic_accession=35124324, orientation='plus', exon_count=13, OMIM=[604996], no_hdr0=''),
    5350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5350, CurrentID=0, Status='live', Symbol='PLN', Aliases=['CMD1P', 'CMH18', 'PLB'], description='phospholamban', other_designations='cardiac phospholamban', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=118548296, end_position_on_the_genomic_accession=118561716, orientation='plus', exon_count=2, OMIM=[172405], no_hdr0=''),
    5351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5351, CurrentID=0, Status='live', Symbol='PLOD1', Aliases=['EDS6', 'EDSKCL1', 'LH', 'LH1', 'LLH', 'PLOD'], description='procollagen-lysine,2-oxoglutarate 5-dioxygenase 1', other_designations='procollagen-lysine,2-oxoglutarate 5-dioxygenase 1|lysine hydroxylase|lysyl hydroxlase 1|procollagen-lysine 1, 2-oxoglutarate 5-dioxygenase 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11934717, end_position_on_the_genomic_accession=11975537, orientation='plus', exon_count=20, OMIM=[153454], no_hdr0=''),
    5352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5352, CurrentID=0, Status='live', Symbol='PLOD2', Aliases=['BRKS2', 'LH2', 'TLH'], description='procollagen-lysine,2-oxoglutarate 5-dioxygenase 2', other_designations='procollagen-lysine,2-oxoglutarate 5-dioxygenase 2|lysine hydroxylase 2|lysyl hydroxlase 2|lysyl hydroxylase 2|procollagen-lysine 5-dioxygenase|telopeptide lysyl hydroxylase', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=146069437, end_position_on_the_genomic_accession=146161184, orientation='minus', exon_count=23, OMIM=[601865], no_hdr0=''),
    5354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5354, CurrentID=0, Status='live', Symbol='PLP1', Aliases=['GPM6C', 'HLD1', 'MMPL', 'PLP', 'PLP/DM20', 'PMD', 'SPG2'], description='proteolipid protein 1', other_designations='myelin proteolipid protein|lipophilin|major myelin proteolipid protein', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103776506, end_position_on_the_genomic_accession=103792619, orientation='plus', exon_count=8, OMIM=[300401], no_hdr0=''),
    5355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5355, CurrentID=0, Status='live', Symbol='PLP2', Aliases=['A4', 'A4LSB'], description='proteolipid protein 2', other_designations='proteolipid protein 2|A4 differentiation-dependent protein|differentiation-dependent protein A4|intestinal membrane A4 protein|proteolipid protein 2 (colonic epithelium-enriched)', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49171898, end_position_on_the_genomic_accession=49175235, orientation='plus', exon_count=5, OMIM=[300112], no_hdr0=''),
    5356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5356, CurrentID=0, Status='live', Symbol='PLRG1', Aliases=['Cwc1', 'PRL1', 'PRP46', 'PRPF46', 'TANGO4'], description='pleiotropic regulator 1', other_designations='pleiotropic regulator 1|pleiotropic regulator 1 (PRL1 homolog, Arabidopsis)|transport and golgi organization 4 homolog', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154535005, end_position_on_the_genomic_accession=154550400, orientation='minus', exon_count=15, OMIM=[605961], no_hdr0=''),
    5357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5357, CurrentID=0, Status='live', Symbol='PLS1', Aliases=['DFNA76'], description='plastin 1', other_designations='plastin-1|I plastin|fimbrin|intestine specific plastin', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142596393, end_position_on_the_genomic_accession=142713664, orientation='plus', exon_count=22, OMIM=[602734], no_hdr0=''),
    5358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5358, CurrentID=0, Status='live', Symbol='PLS3', Aliases=['BMND18', 'T-plastin'], description='plastin 3', other_designations='plastin-3|T fimbrin|T plastin', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=115561174, end_position_on_the_genomic_accession=115650861, orientation='plus', exon_count=20, OMIM=[300131], no_hdr0=''),
    5359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5359, CurrentID=0, Status='live', Symbol='PLSCR1', Aliases=['MMTRA1B'], description='phospholipid scramblase 1', other_designations='phospholipid scramblase 1|PL scramblase 1|ca(2+)-dependent phospholipid scramblase 1|erythrocyte phospholipid scramblase|mg(2+)-dependent nuclease', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=146515178, end_position_on_the_genomic_accession=146544805, orientation='minus', exon_count=11, OMIM=[604170], no_hdr0=''),
    5360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5360, CurrentID=0, Status='live', Symbol='PLTP', Aliases=['BPIFE', 'HDLCQ9'], description='phospholipid transfer protein', other_designations='phospholipid transfer protein|BPI fold containing family E|lipid transfer protein II', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45898620, end_position_on_the_genomic_accession=45912155, orientation='minus', exon_count=17, OMIM=[172425], no_hdr0=''),
    5361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5361, CurrentID=0, Status='live', Symbol='PLXNA1', Aliases=['NOV', 'NOVP', 'PLEXIN-A1', 'PLXN1'], description='plexin A1', other_designations='plexin-A1|plexin 1|semaphorin receptor NOV', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126983115, end_position_on_the_genomic_accession=127037389, orientation='plus', exon_count=32, OMIM=[601055], no_hdr0=''),
    5362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5362, CurrentID=0, Status='live', Symbol='PLXNA2', Aliases=['OCT', 'PLXN2'], description='plexin A2', other_designations='plexin-A2|plexin 2|semaphorin receptor OCT|transmembrane protein OCT', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=208022242, end_position_on_the_genomic_accession=208244384, orientation='minus', exon_count=34, OMIM=[601054], no_hdr0=''),
    5364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5364, CurrentID=0, Status='live', Symbol='PLXNB1', Aliases=['PLEXIN-B1', 'PLXN5', 'SEP'], description='plexin B1', other_designations='plexin-B1|plexin 5|semaphorin receptor SEP', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48403854, end_position_on_the_genomic_accession=48430324, orientation='minus', exon_count=44, OMIM=[601053], no_hdr0=''),
    5365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5365, CurrentID=0, Status='live', Symbol='PLXNB3', Aliases=['PLEXB3', 'PLEXR', 'PLXN6'], description='plexin B3', other_designations='plexin-B3|plexin 6', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153764249, end_position_on_the_genomic_accession=153779341, orientation='plus', exon_count=37, OMIM=[300214], no_hdr0=''),
    5366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5366, CurrentID=0, Status='live', Symbol='PMAIP1', Aliases=['APR', 'NOXA'], description='phorbol-12-myristate-13-acetate-induced protein 1', other_designations='phorbol-12-myristate-13-acetate-induced protein 1|PMA-induced protein 1|adult T cell leukemia-derived PMA-responsive|immediate-early-response protein APR|protein Noxa', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59899996, end_position_on_the_genomic_accession=59904305, orientation='plus', exon_count=2, OMIM=[604959], no_hdr0=''),
    5367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5367, CurrentID=0, Status='live', Symbol='PMCH', Aliases=['MCH', 'ppMCH'], description='pro-melanin concentrating hormone', other_designations='pro-MCH|prepro-MCH|prepro-melanin-concentrating hormone', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102196459, end_position_on_the_genomic_accession=102199540, orientation='minus', exon_count=3, OMIM=[176795], no_hdr0=''),
    5368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5368, CurrentID=0, Status='live', Symbol='PNOC', Aliases=['N/OFQ', 'NOP', 'OFQ', 'PPNOC', 'ppN/OFQ'], description='prepronociceptin', other_designations='prepronociceptin|nociceptin|nocistatin|orphanin FQ|pre-pro-N/OFQ|pronociceptin', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28316979, end_position_on_the_genomic_accession=28343355, orientation='plus', exon_count=5, OMIM=[601459], no_hdr0=''),
    5371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5371, CurrentID=0, Status='live', Symbol='PML', Aliases=['MYL', 'PP8675', 'RNF71', 'TRIM19'], description='PML nuclear body scaffold', other_designations='protein PML|E3 SUMO-protein ligase PML|PML/RARA fusion|RING finger protein 71|RING-type E3 SUMO transferase PML|probable transcription factor PML|promyelocytic leukemia protein|promyelocytic leukemia, inducer of|tripartite motif protein TRIM19|tripartite motif-containing protein 19', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73994716, end_position_on_the_genomic_accession=74047827, orientation='plus', exon_count=10, OMIM=[102578], no_hdr0=''),
    5372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5372, CurrentID=0, Status='live', Symbol='PMM1', Aliases=['PMM 1', 'PMMH-22', 'Sec53'], description='phosphomannomutase 1', other_designations='phosphomannomutase 1|brain glucose-1,6-bisphosphatase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41576895, end_position_on_the_genomic_accession=41589866, orientation='minus', exon_count=10, OMIM=[601786], no_hdr0=''),
    5373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5373, CurrentID=0, Status='live', Symbol='PMM2', Aliases=['CDG1', 'CDG1a', 'CDGS', 'PMI', 'PMI1', 'PMM 2'], description='phosphomannomutase 2', other_designations='phosphomannomutase 2|mannose-6-phosphate isomerase|phosphomannose isomerase 1', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8797813, end_position_on_the_genomic_accession=8849326, orientation='plus', exon_count=8, OMIM=[601785], no_hdr0=''),
    5375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5375, CurrentID=0, Status='live', Symbol='PMP2', Aliases=['CMT1G', 'FABP8', 'M-FABP', 'MP2', 'P2'], description='peripheral myelin protein 2', other_designations='myelin P2 protein', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81440326, end_position_on_the_genomic_accession=81447439, orientation='minus', exon_count=4, OMIM=[170715], no_hdr0=''),
    5376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5376, CurrentID=0, Status='live', Symbol='PMP22', Aliases=['CIDP', 'CMT1A', 'CMT1E', 'DSS', 'GAS-3', 'GAS3', 'HMSNIA', 'HNPP', 'Sp110'], description='peripheral myelin protein 22', other_designations='peripheral myelin protein 22|Charcot-Marie-Tooth neuropathy 1A (greatly reduced nerve conduction velocity, hereditary motor sensory neuropathy Ia)|growth arrest-specific protein 3|peripheral myelin protein 22 kDa', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15229779, end_position_on_the_genomic_accession=15265326, orientation='minus', exon_count=7, OMIM=[601097], no_hdr0=''),
    5378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5378, CurrentID=0, Status='live', Symbol='PMS1', Aliases=['HNPCC3', 'MLH2', 'PMSL1', 'hPMS1'], description='PMS1 homolog 1, mismatch repair system component', other_designations='PMS1 protein homolog 1|DNA mismatch repair protein PMS1|PMS1 postmeiotic segregation increased 1|human homolog of yeast mutL|mismatch repair gene PMSL1|rhabdomyosarcoma antigen MU-RMS-40.10B|rhabdomyosarcoma antigen MU-RMS-40.10E', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189784142, end_position_on_the_genomic_accession=189877629, orientation='plus', exon_count=18, OMIM=[600258], no_hdr0=''),
    5393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5393, CurrentID=0, Status='live', Symbol='EXOSC9', Aliases=['PCH1D', 'PM/Scl-75', 'PMSCL1', 'RRP45', 'Rrp45p', 'p5', 'p6'], description='exosome component 9', other_designations='exosome complex component RRP45|P75 polymyositis-scleroderma overlap syndrome associated autoantigen|PMSCL autoantigen, 75kD|autoantigen PM/Scl 1|exosome complex exonuclease RRP45|polymyositis/scleroderma autoantigen 1, 75kDa', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121801323, end_position_on_the_genomic_accession=121817021, orientation='plus', exon_count=14, OMIM=[606180], no_hdr0=''),
    5394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5394, CurrentID=0, Status='live', Symbol='EXOSC10', Aliases=['PM-Scl', 'PM/Scl-100', 'PMSCL', 'PMSCL2', 'RRP6', 'Rrp6p', 'p2', 'p3', 'p4'], description='exosome component 10', other_designations='exosome component 10|P100 polymyositis-scleroderma overlap syndrome-associated autoantigen|autoantigen PM-SCL|polymyositis/scleroderma autoantigen 100 kDa|polymyositis/scleroderma autoantigen 2', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11066613, end_position_on_the_genomic_accession=11099869, orientation='minus', exon_count=24, OMIM=[605960], no_hdr0=''),
    5395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5395, CurrentID=0, Status='live', Symbol='PMS2', Aliases=['HNPCC4', 'MLH4', 'MMRCS4CL', 'PMSL2', 'PMS2'], description='PMS1 homolog 2, mismatch repair system component', other_designations='mismatch repair endonuclease PMS2|DNA mismatch repair protein PMS2|PMS1 homolog 2, mismatch repair protein|PMS1 protein homolog 2|PMS2 postmeiotic segregation increased 2|postmeiotic segregation increased 2 nirs variant 6', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5970925, end_position_on_the_genomic_accession=6009106, orientation='minus', exon_count=16, OMIM=[600259], no_hdr0=''),
    5396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5396, CurrentID=0, Status='live', Symbol='PRRX1', Aliases=['AGOTC', 'PHOX1', 'PMX1', 'PRX-1', 'PRX1'], description='paired related homeobox 1', other_designations='paired mesoderm homeobox protein 1|homeobox protein PHOX1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=170662728, end_position_on_the_genomic_accession=170739421, orientation='plus', exon_count=6, OMIM=[167420], no_hdr0=''),
    5406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5406, CurrentID=0, Status='live', Symbol='PNLIP', Aliases=['PLD', 'PTL', 'PNLIP'], description='pancreatic lipase', other_designations='pancreatic triacylglycerol lipase|triacylglycerol acylhydrolase|triacylglycerol lipase', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116545931, end_position_on_the_genomic_accession=116567855, orientation='plus', exon_count=13, OMIM=[246600], no_hdr0=''),
    5407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5407, CurrentID=0, Status='live', Symbol='PNLIPRP1', Aliases=['PLRP1'], description='pancreatic lipase related protein 1', other_designations='inactive pancreatic lipase-related protein 1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116590959, end_position_on_the_genomic_accession=116609175, orientation='plus', exon_count=14, OMIM=[604422], no_hdr0=''),
    5408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5408, CurrentID=0, Status='live', Symbol='PNLIPRP2', Aliases=['PLRP2'], description='pancreatic lipase related protein 2 (gene/pseudogene)', other_designations='pancreatic lipase-related protein 2|PL-RP2|cytotoxic T lymphocyte lipase|galactolipase|triacylglycerol lipase', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116620953, end_position_on_the_genomic_accession=116645143, orientation='plus', exon_count=13, OMIM=[604423], no_hdr0=''),
    5409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5409, CurrentID=0, Status='live', Symbol='PNMT', Aliases=['PENTase', 'PNMT'], description='phenylethanolamine N-methyltransferase', other_designations='phenylethanolamine N-methyltransferase|noradrenaline N-methyltransferase|phenylethanolamine N-methylase', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39668019, end_position_on_the_genomic_accession=39670475, orientation='plus', exon_count=5, OMIM=[171190], no_hdr0=''),
    5411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5411, CurrentID=0, Status='live', Symbol='PNN', Aliases=['DRS', 'DRSP', 'SDK3', 'memA'], description='pinin, desmosome associated protein', other_designations='pinin|140 kDa nuclear and cell adhesion-related phosphoprotein|SR-like protein|desmosome-associated protein|domain-rich serine protein|melanoma metastasis clone A protein|neutrophil protein|nuclear protein SDK3', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39175254, end_position_on_the_genomic_accession=39183220, orientation='plus', exon_count=9, OMIM=[603154], no_hdr0=''),
    5412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5412, CurrentID=0, Status='live', Symbol='UBL3', Aliases=['HCG-1', 'PNSC1'], description='ubiquitin like 3', other_designations='ubiquitin-like protein 3|MUB|hsMUB|membrane-anchored ubiquitin-fold protein|protein HCG-1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=29764371, end_position_on_the_genomic_accession=29850617, orientation='minus', exon_count=5, OMIM=[604711], no_hdr0=''),
    5413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5413, CurrentID=0, Status='live', Symbol='SEPTIN5', Aliases=['CDCREL', 'CDCREL-1', 'CDCREL1', 'H5', 'HCDCREL-1', 'PNUTL1', 'SEPT5'], description='septin 5', other_designations='septin-5|cell division control related protein 1|peanut-like 1|platelet glycoprotein Ib beta chain', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19714503, end_position_on_the_genomic_accession=19723319, orientation='plus', exon_count=13, OMIM=[602724], no_hdr0=''),
    5414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5414, CurrentID=0, Status='live', Symbol='SEPTIN4', Aliases=['ARTS', 'BRADEION', 'C17orf47', 'CE5B3', 'H5', 'MART', 'PNUTL2', 'SEP4', 'SEPT4', 'hCDCREL-2', 'hucep-7'], description='septin 4', other_designations='septin-4|CE5B3 beta|apoptosis-related protein in the TGF-beta signaling pathway|bradeion beta|brain protein H5|cell division control-related protein 2|cerebral protein 7|peanut-like protein 2|septin-M|uncharacterized protein C17orf47', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58520255, end_position_on_the_genomic_accession=58544372, orientation='minus', exon_count=19, OMIM=[603696], no_hdr0=''),
    5420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5420, CurrentID=0, Status='live', Symbol='PODXL', Aliases=['Gp200', 'PC', 'PCLP', 'PCLP-1', 'PDX1', 'gp135', 'PODXL'], description='podocalyxin like', other_designations='podocalyxin|GCTM-2 antigen|podocalyxin-like protein 1', map_location='7q32.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=131500271, end_position_on_the_genomic_accession=131556628, orientation='minus', exon_count=9, OMIM=[602632], no_hdr0=''),
    5422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5422, CurrentID=0, Status='live', Symbol='POLA1', Aliases=['NSX', 'POLA', 'VEODS', 'p180'], description='DNA polymerase alpha 1, catalytic subunit', other_designations='DNA polymerase alpha catalytic subunit|DNA polymerase alpha catalytic subunit p180|polymerase (DNA directed), alpha 1, catalytic subunit|polymerase (DNA) alpha 1, catalytic subunit|polymerase (DNA-directed), alpha (70kD)', map_location='Xp22.11-p21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24693877, end_position_on_the_genomic_accession=24996986, orientation='plus', exon_count=43, OMIM=[312040], no_hdr0=''),
    5423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5423, CurrentID=0, Status='live', Symbol='POLB', Aliases=[], description='DNA polymerase beta', other_designations='DNA polymerase beta|DNA pol beta|DNA polymerase beta subunit|polymerase (DNA directed), beta|polymerase (DNA) beta', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42338452, end_position_on_the_genomic_accession=42371810, orientation='plus', exon_count=16, OMIM=[174760], no_hdr0=''),
    5424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5424, CurrentID=0, Status='live', Symbol='POLD1', Aliases=['CDC2', 'CRCS10', 'MDPL', 'POLD'], description='DNA polymerase delta 1, catalytic subunit', other_designations="DNA polymerase delta catalytic subunit|3'-5' exodeoxyribonuclease|CDC2 homolog|DNA polymerase subunit delta p125|polymerase (DNA directed), delta 1, catalytic subunit 125kDa|polymerase (DNA) delta 1, catalytic subunit", map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50384291, end_position_on_the_genomic_accession=50418018, orientation='plus', exon_count=30, OMIM=[174761], no_hdr0=''),
    5425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5425, CurrentID=0, Status='live', Symbol='POLD2', Aliases=[], description='DNA polymerase delta 2, accessory subunit', other_designations='DNA polymerase delta subunit 2|DAN polymerase delta 2, accessory subunit|DNA polymerase delta subunit p50|Pol delta B subunit (p50)|polymerase (DNA directed), delta 2, accessory subunit|polymerase (DNA directed), delta 2, regulatory subunit 50kDa|polymerase (DNA) delta 2, accessory subunit', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44114680, end_position_on_the_genomic_accession=44123668, orientation='minus', exon_count=14, OMIM=[600815], no_hdr0=''),
    5426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5426, CurrentID=0, Status='live', Symbol='POLE', Aliases=['CRCS12', 'FILS', 'IMAGEI1', 'POLE'], description='DNA polymerase epsilon, catalytic subunit', other_designations="DNA polymerase epsilon catalytic subunit A|3'-5' exodeoxyribonuclease|DNA polymerase II subunit A|DNA polymerase epsilon catalytic subunit protein|polymerase (DNA directed), epsilon, catalytic subunit|polymerase (DNA) epsilon, catalytic subunit", map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132623758, end_position_on_the_genomic_accession=132687519, orientation='minus', exon_count=51, OMIM=[174762], no_hdr0=''),
    5427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5427, CurrentID=0, Status='live', Symbol='POLE2', Aliases=['DPE2'], description='DNA polymerase epsilon 2, accessory subunit', other_designations='DNA polymerase epsilon subunit 2|DNA polymerase II subunit 2|DNA polymerase epsilon subunit B|polymerase (DNA directed), epsilon 2 (p59 subunit)|polymerase (DNA directed), epsilon 2, accessory subunit|polymerase (DNA) epsilon 2, accessory subunit', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49643555, end_position_on_the_genomic_accession=49688417, orientation='minus', exon_count=20, OMIM=[602670], no_hdr0=''),
    5428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5428, CurrentID=0, Status='live', Symbol='POLG', Aliases=['MDP1', 'MIRAS', 'MTDPS4A', 'MTDPS4B', 'PEO1', 'POLGA', 'SANDO', 'SCAE', 'POLG'], description='DNA polymerase gamma, catalytic subunit', other_designations='DNA polymerase subunit gamma-1|PolG-alpha|mitochondrial DNA polymerase catalytic subunit|mitochondrial polymerase gamma catalytic subunit|polymerase (DNA directed), gamma|polymerase (DNA) gamma, catalytic subunit|truncated mitochondrial DNA polymerase gamma catalytic subunit|truncated mitochondrial polymerase gamma catalytic subunit', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89316320, end_position_on_the_genomic_accession=89334824, orientation='minus', exon_count=23, OMIM=[174763], no_hdr0=''),
    5429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5429, CurrentID=0, Status='live', Symbol='POLH', Aliases=['RAD30', 'RAD30A', 'XP-V', 'XPV'], description='DNA polymerase eta', other_designations='DNA polymerase eta|RAD30 homolog A|polymerase (DNA directed), eta|polymerase (DNA) eta|xeroderma pigmentosum variant type protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43576147, end_position_on_the_genomic_accession=43620523, orientation='plus', exon_count=11, OMIM=[603968], no_hdr0=''),
    5430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5430, CurrentID=0, Status='live', Symbol='POLR2A', Aliases=['NEDHIB', 'POLR2', 'POLRA', 'RPB1', 'RPBh1', 'RPO2', 'RPOL2', 'RpIILS', 'hRPB220', 'hsRPB1'], description='RNA polymerase II subunit A', other_designations='DNA-directed RNA polymerase II subunit RPB1|DNA-directed RNA polymerase II largest subunit, RNA polymerase II 220 kd subunit|DNA-directed RNA polymerase II subunit A|DNA-directed RNA polymerase III largest subunit|RNA polymerase II subunit B1|RNA-directed RNA polymerase II subunit RPB1|polymerase (RNA) II (DNA directed) polypeptide A, 220kDa|polymerase (RNA) II subunit A', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7484366, end_position_on_the_genomic_accession=7514616, orientation='plus', exon_count=29, OMIM=[180660], no_hdr0=''),
    5431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5431, CurrentID=0, Status='live', Symbol='POLR2B', Aliases=['POL2RB', 'RPB2', 'hRPB140'], description='RNA polymerase II subunit B', other_designations='DNA-directed RNA polymerase II subunit RPB2|DNA-directed RNA polymerase II 140 kDa polypeptide|DNA-directed RNA polymerase II subunit B|RNA polymerase II second largest subunit|RNA polymerase II subunit 2|RNA polymerase II subunit B2|polymerase (RNA) II (DNA directed) polypeptide B, 140kDa|polymerase (RNA) II subunit B', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56978896, end_position_on_the_genomic_accession=57031158, orientation='plus', exon_count=26, OMIM=[180661], no_hdr0=''),
    5432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5432, CurrentID=0, Status='live', Symbol='POLR2C', Aliases=['RPB3', 'RPB31', 'hRPB33', 'hsRPB3'], description='RNA polymerase II subunit C', other_designations='DNA-directed RNA polymerase II subunit RPB3|DNA-directed RNA polymerase II 33 kDa polypeptide|DNA-directed RNA polymerase II subunit C|RNA polymerase II subunit 3|RNA polymerase II subunit B3|RPB33|polymerase (RNA) II (DNA directed) polypeptide C, 33kDa|polymerase (RNA) II subunit C', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57462679, end_position_on_the_genomic_accession=57472009, orientation='plus', exon_count=9, OMIM=[180663], no_hdr0=''),
    5433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5433, CurrentID=0, Status='live', Symbol='POLR2D', Aliases=['HSRBP4', 'HSRPB4', 'RBP4', 'RPB16', 'RPB4'], description='RNA polymerase II subunit D', other_designations='DNA-directed RNA polymerase II subunit RPB4|DNA-directed RNA polymerase II 16 kDa polypeptide|DNA-directed RNA polymerase II subunit D|RNA polymerase II 16 kDa subunit|RNA polymerase II subunit B4|RNA polymerase II subunit hsRBP4|RNA polymerase II subunit hsRPB4|polymerase (RNA) II (DNA directed) polypeptide D|polymerase (RNA) II subunit D', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127843553, end_position_on_the_genomic_accession=127858155, orientation='minus', exon_count=4, OMIM=[606017], no_hdr0=''),
    5434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5434, CurrentID=0, Status='live', Symbol='POLR2E', Aliases=['RPABC1', 'RPB5', 'XAP4', 'hRPB25', 'hsRPB5'], description='RNA polymerase II, I and III subunit E', other_designations='DNA-directed RNA polymerases I, II, and III subunit RPABC1|DNA directed RNA polymerase II 23 kda polypeptide|DNA-directed RNA polymerase II 23 kDa polypeptide|DNA-directed RNA polymerase II subunit E|DNA-directed RNA polymerase subunit RPABC1|RNA polymerase II subunit E|RNA polymerases I, II, and III subunit ABC1|RPB5 homolog|polymerase (RNA) II (DNA directed) polypeptide E, 25kDa|polymerase (RNA) II subunit E', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1086574, end_position_on_the_genomic_accession=1095387, orientation='minus', exon_count=9, OMIM=[180664], no_hdr0=''),
    5435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5435, CurrentID=0, Status='live', Symbol='POLR2F', Aliases=['HRBP14.4', 'POLRF', 'RPABC14.4', 'RPABC2', 'RPB14.4', 'RPB6', 'RPC15'], description='RNA polymerase II, I and III subunit F', other_designations='DNA-directed RNA polymerases I, II, and III subunit RPABC2|DNA-directed RNA polymerase II subunit F|DNA-directed RNA polymerases I, II, and III 14.4 kDa polypeptide|RNA Polymerase II subunit 14.4 kD|RNA polymerase II subunit F|RNA polymerases I, II, and III subunit ABC2|polymerase (RNA) II (DNA directed) polypeptide F|polymerase (RNA) II subunit F', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37953663, end_position_on_the_genomic_accession=38041915, orientation='plus', exon_count=9, OMIM=[604414], no_hdr0=''),
    5436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5436, CurrentID=0, Status='live', Symbol='POLR2G', Aliases=['RPB19', 'RPB7', 'hRPB19', 'hsRPB7'], description='RNA polymerase II subunit G', other_designations='DNA-directed RNA polymerase II subunit RPB7|DNA directed RNA polymerase II 19 kda polypeptide|DNA-directed RNA polymerase II 19 kDa polypeptide|DNA-directed RNA polymerase II subunit G|RNA polymerase II 19 kDa subunit|RNA polymerase II seventh subunit|RNA polymerase II subunit B7|polymerase (RNA) II (DNA directed) polypeptide G|polymerase (RNA) II subunit G', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62761580, end_position_on_the_genomic_accession=62766710, orientation='plus', exon_count=8, OMIM=[602013], no_hdr0=''),
    5437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5437, CurrentID=0, Status='live', Symbol='POLR2H', Aliases=['RPABC3', 'RPB17', 'RPB8'], description='RNA polymerase II, I and III subunit H', other_designations='DNA-directed RNA polymerases I, II, and III subunit RPABC3|DNA-directed RNA polymerase II subunit H|DNA-directed RNA polymerases I, II, and III 17.1 kDa polypeptide|RNA polymerase II subunit H|RPB8 homolog|polymerase (RNA) II (DNA directed) polypeptide H|polymerase (RNA) II subunit H', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184361710, end_position_on_the_genomic_accession=184368594, orientation='plus', exon_count=8, OMIM=[606023], no_hdr0=''),
    5438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5438, CurrentID=0, Status='live', Symbol='POLR2I', Aliases=['RPB9', 'hRPB14.5'], description='RNA polymerase II subunit I', other_designations='DNA-directed RNA polymerase II subunit RPB9|DNA-directed RNA polymerase II 14.5 kDa polypeptide|DNA-directed RNA polymerase II subunit I|RNA polymerase II 14.5 kDa subunit|RNA polymerase II subunit B9|RPB14.5|polymerase (RNA) II (DNA directed) polypeptide I, 14.5kDa|polymerase (RNA) II subunit I', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36113709, end_position_on_the_genomic_accession=36114875, orientation='minus', exon_count=6, OMIM=[180662], no_hdr0=''),
    5439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5439, CurrentID=0, Status='live', Symbol='POLR2J', Aliases=['POLR2J1', 'RPB11', 'RPB11A', 'RPB11m', 'hRPB14'], description='RNA polymerase II subunit J', other_designations='DNA-directed RNA polymerase II subunit RPB11-a|DNA-directed RNA polymerase II subunit J-1|RNA polymerase II 13.3 kDa subunit|RNA polymerase II subunit B11-a|polymerase (RNA) II (DNA directed) polypeptide J, 13.3kDa|polymerase (RNA) II subunit J', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102473128, end_position_on_the_genomic_accession=102478934, orientation='minus', exon_count=4, OMIM=[604150], no_hdr0=''),
    5440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5440, CurrentID=0, Status='live', Symbol='POLR2K', Aliases=['ABC10-alpha', 'RPABC4', 'RPB10alpha', 'RPB12', 'RPB7.0', 'hRPB7.0', 'hsRPB10a'], description='RNA polymerase II, I and III subunit K', other_designations='DNA-directed RNA polymerases I, II, and III subunit RPABC4|DNA directed RNA polymerases I, II, and III 7.0 kda polypeptide|DNA-directed RNA polymerase II subunit K|RNA polymerase II 7.0 kDa subunit|RNA polymerase II subunit K|RNA polymerases I, II, and III subunit ABC4|polymerase (RNA) II (DNA directed) polypeptide K, 7.0kDa|polymerase (RNA) II subunit K', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100150636, end_position_on_the_genomic_accession=100154003, orientation='plus', exon_count=4, OMIM=[606033], no_hdr0=''),
    5441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5441, CurrentID=0, Status='live', Symbol='POLR2L', Aliases=['RBP10', 'RPABC5', 'RPB10', 'RPB10beta', 'RPB7.6', 'hRPB7.6'], description='RNA polymerase II, I and III subunit L', other_designations='DNA-directed RNA polymerases I, II, and III subunit RPABC5|DNA-directed RNA polymerase III subunit L|RNA polymerase II 7.6 kDa subunit|RNA polymerase II subunit L|RNA polymerases I, II, and III subunit ABC5|RPB10 homolog|polymerase (RNA) II (DNA directed) polypeptide L, 7.6kDa|polymerase (RNA) II subunit L', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=839721, end_position_on_the_genomic_accession=842529, orientation='minus', exon_count=2, OMIM=[601189], no_hdr0=''),
    5442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5442, CurrentID=0, Status='live', Symbol='POLRMT', Aliases=['APOLMT', 'MTRNAP', 'MTRPOL', 'h-mtRPOL'], description='RNA polymerase mitochondrial', other_designations='DNA-directed RNA polymerase, mitochondrial|polymerase (RNA) mitochondrial (DNA directed)', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=617221, end_position_on_the_genomic_accession=633557, orientation='minus', exon_count=21, OMIM=[601778], no_hdr0=''),
    5443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5443, CurrentID=0, Status='live', Symbol='POMC', Aliases=['ACTH', 'CLIP', 'LPH', 'MSH', 'NPP', 'OBAIRH', 'POC'], description='proopiomelanocortin', other_designations='pro-opiomelanocortin|adrenocorticotropic hormone|adrenocorticotropin|alpha-MSH|alpha-melanocyte-stimulating hormone|beta-LPH|beta-MSH|beta-endorphin|beta-melanocyte-stimulating hormone|corticotropin-like intermediary peptide|corticotropin-lipotropin|gamma-LPH|gamma-MSH|lipotropin beta|lipotropin gamma|melanotropin alpha|melanotropin beta|melanotropin gamma|met-enkephalin|opiomelanocortin prepropeptide|pro-ACTH-endorphin|proopiomelanocortin preproprotein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25160860, end_position_on_the_genomic_accession=25168580, orientation='minus', exon_count=4, OMIM=[176830], no_hdr0=''),
    5444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5444, CurrentID=0, Status='live', Symbol='PON1', Aliases=['ESA', 'MVCD5', 'PON'], description='paraoxonase 1', other_designations='serum paraoxonase/arylesterase 1|A-esterase 1|K-45|PON 1|aromatic esterase 1|arylesterase 1|arylesterase B-type|esterase A|paraoxonase B-type|serum aryldiakylphosphatase|serum aryldialkylphosphatase 1', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95297676, end_position_on_the_genomic_accession=95324532, orientation='minus', exon_count=9, OMIM=[168820], no_hdr0=''),
    5445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5445, CurrentID=0, Status='live', Symbol='PON2', Aliases=[], description='paraoxonase 2', other_designations='serum paraoxonase/arylesterase 2|A-esterase 2|PON 2|aromatic esterase 2|arylesterase 2|paraoxonase nirs|serum aryldialkylphosphatase 2', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95404862, end_position_on_the_genomic_accession=95435028, orientation='minus', exon_count=9, OMIM=[602447], no_hdr0=''),
    5446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5446, CurrentID=0, Status='live', Symbol='PON3', Aliases=[], description='paraoxonase 3', other_designations='serum paraoxonase/lactonase 3|arylesterase 3|paraoxanase-3', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95359872, end_position_on_the_genomic_accession=95396375, orientation='minus', exon_count=9, OMIM=[602720], no_hdr0=''),
    5447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5447, CurrentID=0, Status='live', Symbol='POR', Aliases=['CPR', 'CYPOR', 'P450R'], description='cytochrome p450 oxidoreductase', other_designations='NADPH--cytochrome P450 reductase|NADPH--hemoprotein reductase|NADPH-dependent cytochrome P450 reductase|P450 (cytochrome) oxidoreductase', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75915155, end_position_on_the_genomic_accession=75986855, orientation='plus', exon_count=19, OMIM=[124015], no_hdr0=''),
    5449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5449, CurrentID=0, Status='live', Symbol='POU1F1', Aliases=['CPHD1', 'GHF-1', 'PIT1a', 'Pit-1', 'POU1F1'], description='POU class 1 homeobox 1', other_designations='pituitary-specific positive transcription factor 1|POU domain, class 1, transcription factor 1|growth hormone factor 1|pituitary transcript factor 1', map_location='3p11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=87259404, end_position_on_the_genomic_accession=87276584, orientation='minus', exon_count=6, OMIM=[173110], no_hdr0=''),
    5450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5450, CurrentID=0, Status='live', Symbol='POU2AF1', Aliases=['BOB1', 'OBF-1', 'OBF1', 'OCAB'], description='POU class 2 homeobox associating factor 1', other_designations='POU domain class 2-associating factor 1|B-cell-specific coactivator OBF-1|BOB-1|OCA-B|OCT-binding factor 1|POU class 2 associating factor 1', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111352251, end_position_on_the_genomic_accession=111379671, orientation='minus', exon_count=8, OMIM=[601206], no_hdr0=''),
    5451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5451, CurrentID=0, Status='live', Symbol='POU2F1', Aliases=['OCT1', 'OTF1', 'Oct1Z', 'oct-1B'], description='POU class 2 homeobox 1', other_designations='POU domain, class 2, transcription factor 1|NF-A1|OTF-1|Octamer-binding transcription factor-1|oct-1|octamer-binding protein 1|octamer-binding transcription factor 1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167220878, end_position_on_the_genomic_accession=167427345, orientation='plus', exon_count=23, OMIM=[164175], no_hdr0=''),
    5452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5452, CurrentID=0, Status='live', Symbol='POU2F2', Aliases=['OCT2', 'OTF2', 'Oct-2'], description='POU class 2 homeobox 2', other_designations='POU domain, class 2, transcription factor 2|homeobox protein|lymphoid-restricted immunoglobulin octamer-binding protein NF-A2|octamer-binding protein 2|octamer-binding transcription factor 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42086110, end_position_on_the_genomic_accession=42197931, orientation='minus', exon_count=21, OMIM=[164176], no_hdr0=''),
    5453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5453, CurrentID=0, Status='live', Symbol='POU3F1', Aliases=['OCT6', 'OTF6', 'SCIP'], description='POU class 3 homeobox 1', other_designations='POU domain, class 3, transcription factor 1|OTF-6|POU domain transcription factor SCIP|octamer-binding protein 6|octamer-binding transcription factor 6', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38043829, end_position_on_the_genomic_accession=38046793, orientation='minus', exon_count=1, OMIM=[602479], no_hdr0=''),
    5454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5454, CurrentID=0, Status='live', Symbol='POU3F2', Aliases=['BRN2', 'N-Oct3', 'OCT7', 'OTF-7', 'OTF7', 'POUF3', 'brn-2', 'oct-7'], description='POU class 3 homeobox 2', other_designations='POU domain, class 3, transcription factor 2|brain-2|brain-specific homeobox/POU domain protein 2|nervous system-specific octamer-binding transcription factor N-Oct-3|octamer-binding protein 7|octamer-binding transcription factor 7', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=98834574, end_position_on_the_genomic_accession=98839458, orientation='plus', exon_count=1, OMIM=[600494], no_hdr0=''),
    5455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5455, CurrentID=0, Status='live', Symbol='POU3F3', Aliases=['BRN1', 'OTF8', 'SNIBFIS', 'brain-1', 'oct-8'], description='POU class 3 homeobox 3', other_designations='POU domain, class 3, transcription factor 3|brain-specific homeobox/POU domain protein 1|octamer-binding protein 8|octamer-binding transcription factor 8', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=104854115, end_position_on_the_genomic_accession=104858574, orientation='plus', exon_count=1, OMIM=[602480], no_hdr0=''),
    5456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5456, CurrentID=0, Status='live', Symbol='POU3F4', Aliases=['BRAIN-4', 'BRN-4', 'BRN4', 'DFN3', 'DFNX2', 'OCT-9', 'OTF-9', 'OTF9'], description='POU class 3 homeobox 4', other_designations='POU domain, class 3, transcription factor 4|brain-specific homeobox/POU domain protein 4|octamer-binding transcription factor 9', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=83508290, end_position_on_the_genomic_accession=83512127, orientation='plus', exon_count=1, OMIM=[300039], no_hdr0=''),
    5457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5457, CurrentID=0, Status='live', Symbol='POU4F1', Aliases=['ATITHS', 'BRN3A', 'Oct-T1', 'RDC-1', 'brn-3A'], description='POU class 4 homeobox 1', other_designations='POU domain, class 4, transcription factor 1|brain-specific homeobox/POU domain protein 3A|homeobox/POU domain protein RDC-1', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=78598362, end_position_on_the_genomic_accession=78603552, orientation='minus', exon_count=2, OMIM=[601632], no_hdr0=''),
    5458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5458, CurrentID=0, Status='live', Symbol='POU4F2', Aliases=['BRN3.2', 'BRN3B', 'Brn-3b'], description='POU class 4 homeobox 2', other_designations='POU domain, class 4, transcription factor 2|Brn3b POU domain transcription factor|POU domain protein|brain-3B|brain-specific homeobox/POU domain protein 3B', map_location='4q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=146638893, end_position_on_the_genomic_accession=146642474, orientation='plus', exon_count=2, OMIM=[113725], no_hdr0=''),
    5459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5459, CurrentID=0, Status='live', Symbol='POU4F3', Aliases=['BRN3C', 'DFNA15', 'DFNA42', 'DFNA52'], description='POU class 4 homeobox 3', other_designations='POU domain, class 4, transcription factor 3|brain-3C|brain-specific homeobox/POU domain protein 3C|brn-3C|deafness, autosomal dominant 42', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146338839, end_position_on_the_genomic_accession=146341728, orientation='plus', exon_count=2, OMIM=[602460], no_hdr0=''),
    5460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5460, CurrentID=0, Status='live', Symbol='POU5F1', Aliases=['OCT3', 'OCT4', 'OTF-3', 'OTF3', 'OTF4', 'Oct-3', 'Oct-4'], description='POU class 5 homeobox 1', other_designations='POU domain, class 5, transcription factor 1|POU domain transcription factor OCT4|POU-type homeodomain-containing DNA-binding protein|octamer-binding protein 3|octamer-binding protein 4|octamer-binding transcription factor 3', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31164337, end_position_on_the_genomic_accession=31170682, orientation='minus', exon_count=6, OMIM=[164177], no_hdr0=''),
    5462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5462, CurrentID=0, Status='live', Symbol='POU5F1B', Aliases=['OCT4-PG1', 'OCT4PG1', 'OTF3C', 'OTF3P1', 'POU5F1P1', 'POU5F1P4', 'POU5FLC20', 'POU5FLC8'], description='POU class 5 homeobox 1B', other_designations='putative POU domain, class 5, transcription factor 1B|POU 5 domain protein|POU class 5 homeobox 1 pseudogene 1|POU domain transcription factor OCT4-pg1|POU domain transcription factor Oct-4|POU domain, class 5, transcription factor 1 pseudogene 1|octamer binding protein 3_like sequence', map_location='8q24.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=127415825, end_position_on_the_genomic_accession=127417210, orientation='plus', exon_count=1, OMIM=[615739], no_hdr0=''),
    5463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5463, CurrentID=0, Status='live', Symbol='POU6F1', Aliases=['BRN5', 'MPOU', 'TCFB1'], description='POU class 6 homeobox 1', other_designations='POU domain, class 6, transcription factor 1|brain-5|brain-specific homeobox/POU domain protein 5|mPOU homeobox protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51186936, end_position_on_the_genomic_accession=51219875, orientation='minus', exon_count=15, OMIM=[618043], no_hdr0=''),
    5464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5464, CurrentID=0, Status='live', Symbol='PPA1', Aliases=['HEL-S-66p', 'IOPPP', 'PP', 'PP1', 'SID6-8061'], description='inorganic pyrophosphatase 1', other_designations='inorganic pyrophosphatase|PPase|cytosolic inorganic pyrophosphatase|diphosphate phosphohydrolase|epididymis secretory sperm binding protein Li 66p|inorganic diphosphatase 1|pyrophosphatase (inorganic) 1|pyrophosphatase 1|pyrophosphate phospho-hydrolase', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70202831, end_position_on_the_genomic_accession=70233429, orientation='minus', exon_count=11, OMIM=[179030], no_hdr0=''),
    5465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5465, CurrentID=0, Status='live', Symbol='PPARA', Aliases=['NR1C1', 'PPAR', 'PPAR-alpha', 'PPARalpha', 'hPPAR'], description='peroxisome proliferator activated receptor alpha', other_designations='peroxisome proliferator-activated receptor alpha|nuclear receptor subfamily 1 group C member 1|peroxisome proliferative activated receptor, alpha|peroxisome proliferator-activated nuclear receptor alpha variant 3', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46150526, end_position_on_the_genomic_accession=46243756, orientation='plus', exon_count=14, OMIM=[170998], no_hdr0=''),
    5467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5467, CurrentID=0, Status='live', Symbol='PPARD', Aliases=['FAAR', 'NR1C2', 'NUC1', 'NUCI', 'NUCII', 'PPARB'], description='peroxisome proliferator activated receptor delta', other_designations='peroxisome proliferator-activated receptor delta|PPAR-beta|PPAR-delta|PPARD/MYO1D fusion|nuclear hormone receptor 1|nuclear receptor subfamily 1 group C member 2|peroxisome proliferator-activated receptor beta', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35342558, end_position_on_the_genomic_accession=35428180, orientation='plus', exon_count=13, OMIM=[600409], no_hdr0=''),
    5468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5468, CurrentID=0, Status='live', Symbol='PPARG', Aliases=['CIMT1', 'GLM1', 'NR1C31', 'PPARG2', 'PPARG5', 'PPARgamma', 'PPARG'], description='peroxisome proliferator activated receptor gamma', other_designations='peroxisome proliferator-activated receptor gamma|PPAR-gamma|nuclear receptor subfamily 1 group C member 3|peroxisome proliferator-activated nuclear receptor gamma variant 1|peroxisome proliferator-activated receptor-gamma 5|peroxisome proliferator-activated receptor-gamma splicing', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12287368, end_position_on_the_genomic_accession=12434344, orientation='plus', exon_count=14, OMIM=[601487], no_hdr0=''),
    5469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5469, CurrentID=0, Status='live', Symbol='MED1', Aliases=['CRSP1', 'CRSP200', 'DRIP205', 'DRIP230', 'PBP', 'PPARBP', 'PPARGBP', 'RB18A', 'TRAP220', 'TRIP2'], description='mediator complex subunit 1', other_designations='mediator of RNA polymerase II transcription subunit 1|ARC205|PPAR-binding protein|PPARG binding protein|TR-interacting protein 2|TRIP-2|activator-recruited cofactor 205 kDa component|p53 regulatory protein RB18A|peroxisome proliferator-activated receptor-binding protein|thyroid hormone receptor-associated protein complex 220 kDa component|thyroid hormone receptor-associated protein complex component TRAP220|thyroid receptor interacting protein 2|vitamin D receptor-interacting protein 230 kD|vitamin D receptor-interacting protein complex component DRIP205', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39404285, end_position_on_the_genomic_accession=39451281, orientation='minus', exon_count=17, OMIM=[604311], no_hdr0=''),
    5470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5470, CurrentID=0, Status='live', Symbol='PPEF2', Aliases=['PPP7CB'], description='protein phosphatase with EF-hand domain 2', other_designations='serine/threonine-protein phosphatase with EF-hands 2|protein phosphatase 7, catalytic subunit, beta isozyme|protein phosphatase with EF hands 2|protein phosphatase, EF-hand calcium binding domain 2', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75859867, end_position_on_the_genomic_accession=75902452, orientation='minus', exon_count=17, OMIM=[602256], no_hdr0=''),
    5471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5471, CurrentID=0, Status='live', Symbol='PPAT', Aliases=['ATASE', 'GPAT', 'PRAT'], description='phosphoribosyl pyrophosphate amidotransferase', other_designations='amidophosphoribosyltransferase|glutamine PRPP amidotransferase|glutamine phosphoribosylpyrophosphatate amidotransferase|glutamine phosphoribosylpyrophosphate amidotransferase', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56393362, end_position_on_the_genomic_accession=56435615, orientation='minus', exon_count=11, OMIM=[172450], no_hdr0=''),
    5473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5473, CurrentID=0, Status='live', Symbol='PPBP', Aliases=['B-TG1', 'Beta-TG', 'CTAP-III', 'CTAP3', 'CTAPIII', 'CXCL7', 'LA-PF4', 'LDGF', 'MDGF', 'NAP-2', 'PBP', 'SCYB7', 'TC1', 'TC2', 'TGB', 'TGB1', 'THBGB', 'THBGB1'], description='pro-platelet basic protein', other_designations='platelet basic protein|C-X-C motif chemokine 7|CXC chemokine ligand 7|beta-thromboglobulin|chemokine (C-X-C motif) ligand 7|connective tissue-activating peptide III|leukocyte-derived growth factor|low-affinity platelet factor IV|macrophage-derived growth factor|neutrophil-activating peptide 2|small inducible cytokine B7|small inducible cytokine subfamily B, member 7|thrombocidin 1|thrombocidin 2|thromboglobulin, beta-1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73986439, end_position_on_the_genomic_accession=73988190, orientation='minus', exon_count=3, OMIM=[121010], no_hdr0=''),
    5475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5475, CurrentID=0, Status='live', Symbol='PPEF1', Aliases=['PP7', 'PPEF', 'PPP7C', 'PPP7CA'], description='protein phosphatase with EF-hand domain 1', other_designations='serine/threonine-protein phosphatase with EF-hands 1|protein phosphatase 7, catalytic subunit, alpha isozyme|protein phosphatase with EF calcium-binding domain|protein phosphatase, EF-hand calcium binding domain 1|protein phosphatase, serine/threonine type, with EF-hands|serine/threonine protein phosphatase 7', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18675067, end_position_on_the_genomic_accession=18827921, orientation='plus', exon_count=25, OMIM=[300109], no_hdr0=''),
    5476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5476, CurrentID=0, Status='live', Symbol='CTSA', Aliases=['GLB2', 'GSL', 'NGBE', 'PPCA', 'PPGB'], description='cathepsin A', other_designations='lysosomal protective protein|beta-galactosidase 2|beta-galactosidase protective protein|carboxypeptidase C|carboxypeptidase Y-like kininase|carboxypeptidase-L|deamidase|lysosomal carboxypeptidase A|protective protein cathepsin A|urinary kininase', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45890144, end_position_on_the_genomic_accession=45898820, orientation='plus', exon_count=15, OMIM=[613111], no_hdr0=''),
    5478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5478, CurrentID=0, Status='live', Symbol='PPIA', Aliases=['CYPA', 'CYPH', 'HEL-S-69p'], description='peptidylprolyl isomerase A', other_designations='peptidyl-prolyl cis-trans isomerase A|PPIase A|T cell cyclophilin|cyclosporin A-binding protein|epididymis secretory sperm binding protein Li 69p|peptidylprolyl isomerase A (cyclophilin A)|rotamase A', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44795960, end_position_on_the_genomic_accession=44803117, orientation='plus', exon_count=5, OMIM=[123840], no_hdr0=''),
    5479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5479, CurrentID=0, Status='live', Symbol='PPIB', Aliases=['B', 'CYP-S1', 'CYPB', 'HEL-S-39', 'OI9', 'SCYLP'], description='peptidylprolyl isomerase B', other_designations='peptidyl-prolyl cis-trans isomerase B|PPIase B|S-cyclophilin|cyclophilin-like protein|epididymis secretory protein Li 39|peptidylprolyl isomerase B (cyclophilin B)|rotamase B', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64155817, end_position_on_the_genomic_accession=64163022, orientation='minus', exon_count=5, OMIM=[123841], no_hdr0=''),
    5480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5480, CurrentID=0, Status='live', Symbol='PPIC', Aliases=['CYPC'], description='peptidylprolyl isomerase C', other_designations='peptidyl-prolyl cis-trans isomerase C|PPIase C|cyclophilin C|parvulin|rotamase C', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=123023250, end_position_on_the_genomic_accession=123036725, orientation='minus', exon_count=5, OMIM=[123842], no_hdr0=''),
    5481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5481, CurrentID=0, Status='live', Symbol='PPID', Aliases=['CYP-40', 'CYPD'], description='peptidylprolyl isomerase D', other_designations='peptidyl-prolyl cis-trans isomerase D|40 kDa peptidyl-prolyl cis-trans isomerase D|PPIase D|cyclophilin 40|cyclophilin D|cyclophilin-related protein|rotamase D|testicular tissue protein Li 147', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158709127, end_position_on_the_genomic_accession=158723396, orientation='minus', exon_count=10, OMIM=[601753], no_hdr0=''),
    5493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5493, CurrentID=0, Status='live', Symbol='PPL', Aliases=[], description='periplakin', other_designations='periplakin|190 kDa paraneoplastic pemphigus antigen|195 kDa cornified envelope precursor protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4882507, end_position_on_the_genomic_accession=4937148, orientation='minus', exon_count=23, OMIM=[602871], no_hdr0=''),
    5494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5494, CurrentID=0, Status='live', Symbol='PPM1A', Aliases=['PP2C-ALPHA', 'PP2CA', 'PP2Calpha'], description='protein phosphatase, Mg2+/Mn2+ dependent 1A', other_designations='protein phosphatase 1A', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60245750, end_position_on_the_genomic_accession=60299087, orientation='plus', exon_count=17, OMIM=[606108], no_hdr0=''),
    5495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5495, CurrentID=0, Status='live', Symbol='PPM1B', Aliases=['PP2C-beta', 'PP2C-beta-X', 'PP2CB', 'PP2CBETA', 'PPC2BETAX'], description='protein phosphatase, Mg2+/Mn2+ dependent 1B', other_designations='protein phosphatase 1B|protein phosphatase 2C-like protein', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=44168853, end_position_on_the_genomic_accession=44247330, orientation='plus', exon_count=9, OMIM=[603770], no_hdr0=''),
    5496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5496, CurrentID=0, Status='live', Symbol='PPM1G', Aliases=['PP2CG', 'PP2CGAMMA', 'PPP2CG'], description='protein phosphatase, Mg2+/Mn2+ dependent 1G', other_designations='protein phosphatase 1G|PP2C-gamma|protein phosphatase 1C|protein phosphatase magnesium-dependent 1 gamma', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27381199, end_position_on_the_genomic_accession=27409591, orientation='minus', exon_count=10, OMIM=[605119], no_hdr0=''),
    5498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5498, CurrentID=0, Status='live', Symbol='PPOX', Aliases=['PPO', 'V290M', 'VP'], description='protoporphyrinogen oxidase', other_designations='protoporphyrinogen oxidase', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161165824, end_position_on_the_genomic_accession=161178277, orientation='plus', exon_count=18, OMIM=[600923], no_hdr0=''),
    5499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5499, CurrentID=0, Status='live', Symbol='PPP1CA', Aliases=['PP-1A', 'PP1A', 'PP1alpha', 'PPP1A'], description='protein phosphatase 1 catalytic subunit alpha', other_designations='serine/threonine-protein phosphatase PP1-alpha catalytic subunit|protein phosphatase 1, catalytic subunit, alpha isozyme|serine/threonine protein phosphatase PP1-alpha 1 catalytic subunit|testicular tissue protein Li 155', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67398183, end_position_on_the_genomic_accession=67401858, orientation='minus', exon_count=7, OMIM=[176875], no_hdr0=''),
    5500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5500, CurrentID=0, Status='live', Symbol='PPP1CB', Aliases=['HEL-S-80p', 'MP', 'NSLH2', 'PP-1B', 'PP1B', 'PP1beta', 'PP1c', 'PPP1CD', 'PPP1beta'], description='protein phosphatase 1 catalytic subunit beta', other_designations='serine/threonine-protein phosphatase PP1-beta catalytic subunit|epididymis secretory sperm binding protein Li 80p|myosin phosphatase|protein phosphatase 1, catalytic subunit, beta isozyme|protein phosphatase 1-beta|protein phosphatase 1-delta', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28751604, end_position_on_the_genomic_accession=28802940, orientation='plus', exon_count=9, OMIM=[600590], no_hdr0=''),
    5501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5501, CurrentID=0, Status='live', Symbol='PPP1CC', Aliases=['PP-1G', 'PP1C', 'PPP1G'], description='protein phosphatase 1 catalytic subunit gamma', other_designations='serine/threonine-protein phosphatase PP1-gamma catalytic subunit|protein phosphatase 1, catalytic subunit, gamma isozyme|protein phosphatase 1C catalytic subunit|serine/threonine phosphatase 1 gamma', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110708369, end_position_on_the_genomic_accession=110742914, orientation='minus', exon_count=10, OMIM=[176914], no_hdr0=''),
    5502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5502, CurrentID=0, Status='live', Symbol='PPP1R1A', Aliases=['I1', 'IPP1'], description='protein phosphatase 1 regulatory inhibitor subunit 1A', other_designations='protein phosphatase 1 regulatory subunit 1A|I-1|IPP-1|inhibitor-1|protein phosphatase inhibitor-1', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54579246, end_position_on_the_genomic_accession=54588659, orientation='minus', exon_count=7, OMIM=[613246], no_hdr0=''),
    5504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5504, CurrentID=0, Status='live', Symbol='PPP1R2', Aliases=['IPP-2', 'IPP2A', 'PPP1R2'], description='protein phosphatase 1 regulatory inhibitor subunit 2', other_designations='protein phosphatase inhibitor 2|phosphoprotein phosphatase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195514428, end_position_on_the_genomic_accession=195543348, orientation='minus', exon_count=8, OMIM=[601792], no_hdr0=''),
    5506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5506, CurrentID=0, Status='live', Symbol='PPP1R3A', Aliases=['GM', 'PP1G', 'PPP1R3'], description='protein phosphatase 1 regulatory subunit 3A', other_designations='protein phosphatase 1 regulatory subunit 3A|RG1|glycogen and sarcoplasmic reticulum binding subunit, skeletal muscle|glycogen-associated regulatory subunit of protein phosphatase-1|protein phosphatase 1 glycogen- associated regulatory subunit|protein phosphatase 1 regulatory subunit GM|protein phosphatase 1, regulatory (inhibitor) subunit 3A|protein phosphatase type-1 glycogen targeting subunit|serine /threonine specific protein phosphatase|type-1 protein phosphatase skeletal muscle glycogen targeting subunit', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=113876777, end_position_on_the_genomic_accession=113919094, orientation='minus', exon_count=4, OMIM=[600917], no_hdr0=''),
    5507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5507, CurrentID=0, Status='live', Symbol='PPP1R3C', Aliases=['PPP1R5', 'PTG'], description='protein phosphatase 1 regulatory subunit 3C', other_designations='protein phosphatase 1 regulatory subunit 3C|PP1 subunit R5|Phosphatase 1, regulatory inhibitor subunit 5|protein phosphatase 1 regulatory subunit 5|protein phosphatase 1, regulatory (inhibitor) subunit 3C|protein targeting to glycogen', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91628442, end_position_on_the_genomic_accession=91633071, orientation='minus', exon_count=2, OMIM=[602999], no_hdr0=''),
    5509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5509, CurrentID=0, Status='live', Symbol='PPP1R3D', Aliases=['PPP1R6'], description='protein phosphatase 1 regulatory subunit 3D', other_designations='protein phosphatase 1 regulatory subunit 3D|PP1 subunit R6|protein phosphatase 1 regulatory subunit 6|protein phosphatase 1, regulatory (inhibitor) subunit 3D|protein phosphatase 1, regulatory subunit 6, spinophilin|protein phosphatase 1-binding subunit R6', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59936663, end_position_on_the_genomic_accession=59940305, orientation='minus', exon_count=1, OMIM=[603326], no_hdr0=''),
    5510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5510, CurrentID=0, Status='live', Symbol='PPP1R7', Aliases=['SDS22'], description='protein phosphatase 1 regulatory subunit 7', other_designations='protein phosphatase 1 regulatory subunit 7|protein phosphatase 1 regulatory subunit 22|protein phosphatase 1, regulatory (inhibitor) subunit 7|testis secretory sperm-binding protein Li 210a', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241149573, end_position_on_the_genomic_accession=241183652, orientation='plus', exon_count=13, OMIM=[602877], no_hdr0=''),
    5511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5511, CurrentID=0, Status='live', Symbol='PPP1R8', Aliases=['ARD-1', 'ARD1', 'NIPP-1', 'NIPP1', 'PRO2047'], description='protein phosphatase 1 regulatory subunit 8', other_designations='nuclear inhibitor of protein phosphatase 1|RNase E|activator of RNA decay|nuclear inhibitor of protein phosphatase-1 alpha|nuclear inhibitor of protein phosphatase-1 beta|nuclear subunit of PP-1|protein phosphatase 1, regulatory (inhibitor) subunit 8', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27830782, end_position_on_the_genomic_accession=27851676, orientation='plus', exon_count=7, OMIM=[602636], no_hdr0=''),
    5514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5514, CurrentID=0, Status='live', Symbol='PPP1R10', Aliases=['CAT53', 'FB19', 'PNUTS', 'PP1R10', 'R111', 'p99'], description='protein phosphatase 1 regulatory subunit 10', other_designations='serine/threonine-protein phosphatase 1 regulatory subunit 10|HLA-C associated transcript 53|MHC class I region proline-rich protein CAT53|PP1-binding protein of 114 kDa|phosphatase 1 nuclear targeting subunit|protein phosphatase 1, regulatory (inhibitor) subunit 10|testis tissue sperm-binding protein Li 67n', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30600400, end_position_on_the_genomic_accession=30618607, orientation='minus', exon_count=22, OMIM=[603771], no_hdr0=''),
    5515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5515, CurrentID=0, Status='live', Symbol='PPP2CA', Aliases=['NEDLBA', 'PP2Ac', 'PP2CA', 'PP2Calpha', 'RP-C'], description='protein phosphatase 2 catalytic subunit alpha', other_designations='serine/threonine-protein phosphatase 2A catalytic subunit alpha isoform|PP2A-alpha|protein phosphatase 2, catalytic subunit, alpha isozyme|replication protein C', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134194332, end_position_on_the_genomic_accession=134226073, orientation='minus', exon_count=8, OMIM=[176915], no_hdr0=''),
    5516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5516, CurrentID=0, Status='live', Symbol='PPP2CB', Aliases=['PP2Abeta', 'PP2CB'], description='protein phosphatase 2 catalytic subunit beta', other_designations='serine/threonine-protein phosphatase 2A catalytic subunit beta isoform|PP2A-beta|protein phosphatase 2, catalytic subunit, beta isozyme|protein phosphatase type 2A catalytic subunit|testicular tissue protein Li 146', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30785616, end_position_on_the_genomic_accession=30812818, orientation='minus', exon_count=7, OMIM=[176916], no_hdr0=''),
    5518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5518, CurrentID=0, Status='live', Symbol='PPP2R1A', Aliases=['MRD36', 'PP2A-Aalpha', 'PP2AA', 'PP2AAALPHA', 'PR65A'], description='protein phosphatase 2 scaffold subunit Aalpha', other_designations='serine/threonine-protein phosphatase 2A 65 kDa regulatory subunit A alpha isoform|medium tumor antigen-associated 61 KDA protein|protein phosphatase 2, regulatory subunit A, alpha|testicular secretory protein Li 1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52190052, end_position_on_the_genomic_accession=52229518, orientation='plus', exon_count=16, OMIM=[605983], no_hdr0=''),
    5519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5519, CurrentID=0, Status='live', Symbol='PPP2R1B', Aliases=['PP2A-Abeta', 'PR65B'], description='protein phosphatase 2 scaffold subunit Abeta', other_designations='serine/threonine-protein phosphatase 2A 65 kDa regulatory subunit A beta isoform|protein phosphatase 2, regulatory subunit A, beta|protein phosphatase 2, structural/regulatory subunit A, beta', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111690273, end_position_on_the_genomic_accession=111766389, orientation='minus', exon_count=21, OMIM=[603113], no_hdr0=''),
    5520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5520, CurrentID=0, Status='live', Symbol='PPP2R2A', Aliases=['B55A', 'B55ALPHA', 'PR52A', 'PR55A', 'PR55alpha'], description='protein phosphatase 2 regulatory subunit Balpha', other_designations='serine/threonine-protein phosphatase 2A 55 kDa regulatory subunit B alpha isoform|protein phosphatase 2, regulatory subunit B, alpha', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=26291508, end_position_on_the_genomic_accession=26372680, orientation='plus', exon_count=15, OMIM=[604941], no_hdr0=''),
    5521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5521, CurrentID=0, Status='live', Symbol='PPP2R2B', Aliases=['B55BETA', 'PP2AB55BETA', 'PP2ABBETA', 'PP2APR55B', 'PP2APR55BETA', 'PR2AB55BETA', 'PR2ABBETA', 'PR2APR55BETA', 'PR52B', 'PR55-BETA', 'PR55BETA', 'SCA12'], description='protein phosphatase 2 regulatory subunit Bbeta', other_designations='serine/threonine-protein phosphatase 2A 55 kDa regulatory subunit B beta isoform|protein phosphatase 2, regulatory subunit B, beta', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146580742, end_position_on_the_genomic_accession=147081520, orientation='minus', exon_count=15, OMIM=[604325], no_hdr0=''),
    5522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5522, CurrentID=0, Status='live', Symbol='PPP2R2C', Aliases=['B55-GAMMA', 'B55gamma', 'IMYPNO', 'IMYPNO1', 'PR52', 'PR55G'], description='protein phosphatase 2 regulatory subunit Bgamma', other_designations='protein phosphatase 2, regulatory subunit B, gamma|phosphoprotein phosphatase 2A BR gamma regulatory chain|protein phosphatase 2A1 B gamma subunit', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6320578, end_position_on_the_genomic_accession=6563799, orientation='minus', exon_count=16, OMIM=[605997], no_hdr0=''),
    5523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5523, CurrentID=0, Status='live', Symbol='PPP2R3A', Aliases=['PPP2R3', 'PR130', 'PR72'], description="protein phosphatase 2 regulatory subunit B''alpha", other_designations="serine/threonine-protein phosphatase 2A regulatory subunit B'' subunit alpha|PR130/B''alpha1 subunit|PR72/B''alpha2 subuit|protein phosphatase 2, regulatory subunit B'', alpha|serine/threonine-protein phosphatase 2A 72/130 kDa regulatory subunit B", map_location='3q22.2-q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=135965673, end_position_on_the_genomic_accession=136149615, orientation='plus', exon_count=17, OMIM=[604944], no_hdr0=''),
    5524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5524, CurrentID=0, Status='live', Symbol='PTPA', Aliases=['PP2A', 'PPP2R4', 'PR53'], description='protein phosphatase 2 phosphatase activator', other_designations="serine/threonine-protein phosphatase 2A activator|PP2A phosphatase activator|phosphotyrosyl phosphatase activator|protein phosphatase 2 regulatory subunit 4|protein phosphatase 2A activator, regulatory subunit 4|protein phosphatase 2A regulatory subunit 4|protein phosphatase 2A, regulatory subunit B' (PR 53)|serine/threonine-protein phosphatase 2A regulatory subunit B'", map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129110949, end_position_on_the_genomic_accession=129148946, orientation='plus', exon_count=13, OMIM=[600756], no_hdr0=''),
    5525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5525, CurrentID=0, Status='live', Symbol='PPP2R5A', Aliases=['B56A', 'B56alpha', 'PR61A'], description="protein phosphatase 2 regulatory subunit B'alpha", other_designations="serine/threonine-protein phosphatase 2A 56 kDa regulatory subunit alpha isoform|PR61alpha|protein phosphatase 2 regulatory subunit B', alpha", map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212285410, end_position_on_the_genomic_accession=212361853, orientation='plus', exon_count=14, OMIM=[601643], no_hdr0=''),
    5526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5526, CurrentID=0, Status='live', Symbol='PPP2R5B', Aliases=['B56B', 'B56beta', 'PR61B'], description="protein phosphatase 2 regulatory subunit B'beta", other_designations="serine/threonine-protein phosphatase 2A 56 kDa regulatory subunit beta isoform|protein phosphatase 2 regulatory subunit B', beta", map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64917553, end_position_on_the_genomic_accession=64934478, orientation='plus', exon_count=17, OMIM=[601644], no_hdr0=''),
    5527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5527, CurrentID=0, Status='live', Symbol='PPP2R5C', Aliases=['B56G', 'B56gamma', 'PR61G'], description="protein phosphatase 2 regulatory subunit B'gamma", other_designations="serine/threonine-protein phosphatase 2A 56 kDa regulatory subunit gamma isoform|B' alpha regulatory subunit|protein phosphatase 2 regulatory subunit B', gamma|renal carcinoma antigen NY-REN-29", map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=101760573, end_position_on_the_genomic_accession=101927992, orientation='plus', exon_count=26, OMIM=[601645], no_hdr0=''),
    5528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5528, CurrentID=0, Status='live', Symbol='PPP2R5D', Aliases=['B56D', 'B56delta', 'MRD35'], description="protein phosphatase 2 regulatory subunit B'delta", other_designations='serine/threonine-protein phosphatase 2A 56 kDa regulatory subunit delta isoform', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42984570, end_position_on_the_genomic_accession=43012342, orientation='plus', exon_count=16, OMIM=[601646], no_hdr0=''),
    5529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5529, CurrentID=0, Status='live', Symbol='PPP2R5E', Aliases=['B56E', 'B56epsilon'], description="protein phosphatase 2 regulatory subunit B'epsilon", other_designations="serine/threonine-protein phosphatase 2A 56 kDa regulatory subunit epsilon isoform|PP2A, B subunit, B' epsilon|PP2A, B subunit, B56 epsilon|PP2A, B subunit, PR61 epsilon|PP2A, B subunit, R5 epsilon|protein phosphatase 2 regulatory subunit B', epsilon|serine/threonine protein phosphatase 2A, 56 kDa regulatory subunit, epsilon", map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63371364, end_position_on_the_genomic_accession=63543377, orientation='minus', exon_count=15, OMIM=[601647], no_hdr0=''),
    5530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5530, CurrentID=0, Status='live', Symbol='PPP3CA', Aliases=['ACCIID', 'CALN', 'CALNA', 'CALNA1', 'CCN1', 'CNA1', 'DEE91', 'IECEE', 'IECEE1', 'PPP2B'], description='protein phosphatase 3 catalytic subunit alpha', other_designations='serine/threonine-protein phosphatase 2B catalytic subunit alpha isoform|CAM-PRP catalytic subunit|calcineurin A alpha|protein phosphatase 3 catalytic subunit alpha isozyme', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=101023418, end_position_on_the_genomic_accession=101348295, orientation='minus', exon_count=16, OMIM=[114105], no_hdr0=''),
    5531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5531, CurrentID=0, Status='live', Symbol='PPP4C', Aliases=['PP-X', 'PP4', 'PP4C', 'PPH3', 'PPP4', 'PPX'], description='protein phosphatase 4 catalytic subunit', other_designations='serine/threonine-protein phosphatase 4 catalytic subunit|epididymis secretory sperm binding protein|protein phosphatase 4 (formerly X), catalytic subunit|protein phosphatase X, catalytic subunit', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30075994, end_position_on_the_genomic_accession=30085377, orientation='plus', exon_count=9, OMIM=[602035], no_hdr0=''),
    5532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5532, CurrentID=0, Status='live', Symbol='PPP3CB', Aliases=['CALNA2', 'CALNB', 'CNA2', 'PP2Bbeta'], description='protein phosphatase 3 catalytic subunit beta', other_designations='serine/threonine-protein phosphatase 2B catalytic subunit beta isoform|CAM-PRP catalytic subunit|CNA beta|calcineurin A beta|calcineurin A2|protein phosphatase 3, catalytic subunit, beta isozyme|protein phosphatase from PCR fragment H32', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73436433, end_position_on_the_genomic_accession=73496024, orientation='minus', exon_count=16, OMIM=[114106], no_hdr0=''),
    5533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5533, CurrentID=0, Status='live', Symbol='PPP3CC', Aliases=['CALNA3', 'CNA3', 'PP2Bgamma'], description='protein phosphatase 3 catalytic subunit gamma', other_designations='serine/threonine-protein phosphatase 2B catalytic subunit gamma isoform|CAM-PRP catalytic subunit|calcineurin, testis-specific catalytic subunit|protein phosphatase 3, catalytic subunit, gamma isozyme', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22441053, end_position_on_the_genomic_accession=22541466, orientation='plus', exon_count=18, OMIM=[114107], no_hdr0=''),
    5534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5534, CurrentID=0, Status='live', Symbol='PPP3R1', Aliases=['CALNB1', 'CNB', 'CNB1'], description='protein phosphatase 3 regulatory subunit B, alpha', other_designations='calcineurin subunit B type 1|calcineurin B, type I (19kDa)|protein phosphatase 2B regulatory subunit 1|protein phosphatase 2B regulatory subunit B alpha', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68178857, end_position_on_the_genomic_accession=68252532, orientation='minus', exon_count=6, OMIM=[601302], no_hdr0=''),
    5535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5535, CurrentID=0, Status='live', Symbol='PPP3R2', Aliases=['PPP3RL'], description='protein phosphatase 3 regulatory subunit B, beta', other_designations='calcineurin subunit B type 2|CBLP|CNBII|calcineurin B, type II (19kDa)|calcineurin B-like protein|calcineurin BII|protein phosphatase 2B regulatory subunit 2', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101591604, end_position_on_the_genomic_accession=101594969, orientation='minus', exon_count=1, OMIM=[613821], no_hdr0=''),
    5536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5536, CurrentID=0, Status='live', Symbol='PPP5C', Aliases=['PP5', 'PPP5', 'PPT'], description='protein phosphatase 5 catalytic subunit', other_designations='serine/threonine-protein phosphatase 5|PP-T|protein phosphatase T', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46347069, end_position_on_the_genomic_accession=46390975, orientation='plus', exon_count=12, OMIM=[600658], no_hdr0=''),
    5537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5537, CurrentID=0, Status='live', Symbol='PPP6C', Aliases=['PP6', 'PP6C'], description='protein phosphatase 6 catalytic subunit', other_designations='serine/threonine-protein phosphatase 6 catalytic subunit|serine/threonine protein phosphatase catalytic subunit', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125146573, end_position_on_the_genomic_accession=125189803, orientation='minus', exon_count=10, OMIM=[612725], no_hdr0=''),
    5538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5538, CurrentID=0, Status='live', Symbol='PPT1', Aliases=['CLN1', 'INCL', 'PPT'], description='palmitoyl-protein thioesterase 1', other_designations='palmitoyl-protein thioesterase 1|ceroid-palmitoyl-palmitoyl-protein thioesterase 1|palmitoyl-protein hydrolase 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40071461, end_position_on_the_genomic_accession=40097252, orientation='minus', exon_count=9, OMIM=[600722], no_hdr0=''),
    5539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5539, CurrentID=0, Status='live', Symbol='PPY', Aliases=['PNP', 'PP'], description='pancreatic polypeptide', other_designations='pancreatic prohormone|pancreatic polypeptide Y|prepro-PP (prepropancreatic polypeptide)', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43940802, end_position_on_the_genomic_accession=43944212, orientation='minus', exon_count=6, OMIM=[167780], no_hdr0=''),
    5540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5540, CurrentID=0, Status='live', Symbol='NPY4R', Aliases=['NPY4-R', 'PP1', 'PPYR1', 'Y4'], description='neuropeptide Y receptor Y4', other_designations='neuropeptide Y receptor type 4|pancreatic polypeptide receptor 1', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46458548, end_position_on_the_genomic_accession=46470694, orientation='minus', exon_count=5, OMIM=[601790], no_hdr0=''),
    5542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5542, CurrentID=0, Status='live', Symbol='PRB1', Aliases=['PM', 'PMF', 'PMSL', 'PRB1M', 'PRB1'], description='proline rich protein BstNI subfamily 1', other_designations='basic salivary proline-rich protein 1|BstNI type basic salivary proline-rich protein 1|parotid middle band protein|salivary protein Pe', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11351821, end_position_on_the_genomic_accession=11355591, orientation='minus', exon_count=4, OMIM=[180989], no_hdr0=''),
    5544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5544, CurrentID=0, Status='live', Symbol='PRB3', Aliases=['G1', 'PRG'], description='proline rich protein BstNI subfamily 3', other_designations='basic salivary proline-rich protein 3|BstNI type basic salivary proline-rich protein 3|G1 parotid salivary glycoprotein|parotid salivary glycoprotein G1|proline-rich protein G1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11265914, end_position_on_the_genomic_accession=11269707, orientation='minus', exon_count=5, OMIM=[168840], no_hdr0=''),
    5545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5545, CurrentID=0, Status='live', Symbol='PRB4', Aliases=['Po'], description='proline rich protein BstNI subfamily 4', other_designations='basic salivary proline-rich protein 4|BstNI type basic salivary proline-rich protein 4|parotid o protein|salivary proline-rich protein II-1|salivary proline-rich protein Po', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11307077, end_position_on_the_genomic_accession=11310436, orientation='minus', exon_count=5, OMIM=[180990], no_hdr0=''),
    5546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5546, CurrentID=0, Status='live', Symbol='PRCC', Aliases=['RCCP1', 'TPRC'], description='proline rich mitotic checkpoint control factor', other_designations='proline-rich protein PRCC|PRCC, proline rich mitotic checkpoint control factor|papillary renal cell carcinoma (translocation-associated)|papillary renal cell carcinoma translocation-associated gene protein', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156767535, end_position_on_the_genomic_accession=156800815, orientation='plus', exon_count=7, OMIM=[179755], no_hdr0=''),
    5547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5547, CurrentID=0, Status='live', Symbol='PRCP', Aliases=['HUMPCP', 'PCP'], description='prolylcarboxypeptidase', other_designations='lysosomal Pro-X carboxypeptidase|angiotensinase C|lysosomal carboxypeptidase C|proline carboxypeptidase', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=82822936, end_position_on_the_genomic_accession=82901691, orientation='minus', exon_count=11, OMIM=[176785], no_hdr0=''),
    5549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5549, CurrentID=0, Status='live', Symbol='PRELP', Aliases=['MST161', 'MSTP161', 'SLRR2A'], description='proline and arginine rich end leucine rich repeat protein', other_designations='prolargin|55 kDa leucine-rich repeat protein of articular cartilage|prolargin proteoglycan|proline-arginine-rich end leucine-rich repeat protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203475806, end_position_on_the_genomic_accession=203491352, orientation='plus', exon_count=3, OMIM=[601914], no_hdr0=''),
    5550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5550, CurrentID=0, Status='live', Symbol='PREP', Aliases=['PE', 'PEP'], description='prolyl endopeptidase', other_designations='prolyl endopeptidase|dJ355L5.1 (prolyl endopeptidase)|post-proline cleaving enzyme|prolyl oligopeptidase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=105273218, end_position_on_the_genomic_accession=105403102, orientation='minus', exon_count=17, OMIM=[600400], no_hdr0=''),
    5551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5551, CurrentID=0, Status='live', Symbol='PRF1', Aliases=['HPLH2', 'P1', 'PFP'], description='perforin 1', other_designations='perforin-1|cytolysin|lymphocyte pore-forming protein|perforin 1 (pore forming protein)', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70597348, end_position_on_the_genomic_accession=70602741, orientation='minus', exon_count=3, OMIM=[170280], no_hdr0=''),
    5552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5552, CurrentID=0, Status='live', Symbol='SRGN', Aliases=['PPG', 'PRG', 'PRG1'], description='serglycin', other_designations='serglycin|hematopoetic proteoglycan core peptide|hematopoetic proteoglycan core protein|hematopoietic proteoglycan core protein|p.PG|platelet proteoglycan core protein|proteoglycan 1, secretory granule|proteoglycan protein core for mast cell secretory granule|secretory granule proteoglycan core peptide|secretory granule proteoglycan core protein|serglycin proteoglycan', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69057533, end_position_on_the_genomic_accession=69104811, orientation='plus', exon_count=8, OMIM=[177040], no_hdr0=''),
    5553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5553, CurrentID=0, Status='live', Symbol='PRG2', Aliases=['BMPG', 'MBP', 'MBP1', 'proMBP'], description='proteoglycan 2, pro eosinophil major basic protein', other_designations='bone marrow proteoglycan|eosinophil granule major basic protein|eosinophil major basic protein|natural killer cell activator|proteoglycan 2 preproprotein|proteoglycan 2, bone marrow (natural killer cell activator, eosinophil granule major basic protein)', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57386780, end_position_on_the_genomic_accession=57390650, orientation='minus', exon_count=6, OMIM=[605601], no_hdr0=''),
    5554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5554, CurrentID=0, Status='live', Symbol='PRH1', Aliases=['Db-s', 'PA', 'PIF-S', 'PRH2', 'PRP-1/PRP-2', 'Pr1/Pr2'], description='proline rich protein HaeIII subfamily 1', other_designations='salivary acidic proline-rich phosphoprotein 1/2|parotid acidic protein|parotid double-band protein|parotid isoelectric focusing variant protein|parotid proline-rich protein 1/2|protein C', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10880965, end_position_on_the_genomic_accession=11171611, orientation='minus', exon_count=8, OMIM=[168730], no_hdr0=''),
    5555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5555, CurrentID=0, Status='live', Symbol='PRH2', Aliases=['PRP-1/PRP-2', 'Pr', 'pr1/Pr2'], description='proline rich protein HaeIII subfamily 2', other_designations='salivary acidic proline-rich phosphoprotein 1/2|acidic salivary proline-rich protein, HaeIII type, 2|parotid acidic protein|parotid double-band protein|parotid proline-rich protein 1/2|protein C', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10929236, end_position_on_the_genomic_accession=10934845, orientation='plus', exon_count=4, OMIM=[168790], no_hdr0=''),
    5557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5557, CurrentID=0, Status='live', Symbol='PRIM1', Aliases=['p49'], description='DNA primase subunit 1', other_designations='DNA primase small subunit|DNA primase 1|DNA primase 49 kDa subunit|DNA primase subunit 48|primase (DNA) subunit 1|primase p49 subunit|primase polypeptide 1, 49kDa|primase, DNA, polypeptide 1 (49kDa)', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56731580, end_position_on_the_genomic_accession=56752323, orientation='minus', exon_count=13, OMIM=[176635], no_hdr0=''),
    5558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5558, CurrentID=0, Status='live', Symbol='PRIM2', Aliases=['PRIM2A', 'p58'], description='DNA primase subunit 2', other_designations='DNA primase large subunit|DNA primase 58 kDa subunit|primase (DNA) subunit 2|primase, DNA, polypeptide 2 (58kDa)', map_location='6p11.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=57314805, end_position_on_the_genomic_accession=57646852, orientation='plus', exon_count=19, OMIM=[176636], no_hdr0=''),
    5562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5562, CurrentID=0, Status='live', Symbol='PRKAA1', Aliases=['AMPK', 'AMPK alpha 1', 'AMPKa1'], description='protein kinase AMP-activated catalytic subunit alpha 1', other_designations="5'-AMP-activated protein kinase catalytic subunit alpha-1|5'-AMP-activated protein kinase, catalytic alpha-1 chain|ACACA kinase|AMP -activate kinase alpha 1 subunit|AMP-activated protein kinase, catalytic, alpha-1|AMPK subunit alpha-1|AMPK, alpha, 1|HMGCR kinase|acetyl-CoA carboxylase kinase|hydroxymethylglutaryl-CoA reductase kinase|protein kinase, AMP-activated, alpha 1 catalytic subunit|tau-protein kinase PRKAA1", map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40759389, end_position_on_the_genomic_accession=40798374, orientation='minus', exon_count=12, OMIM=[602739], no_hdr0=''),
    5563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5563, CurrentID=0, Status='live', Symbol='PRKAA2', Aliases=['AMPK', 'AMPK2', 'AMPKa2', 'PRKAA'], description='protein kinase AMP-activated catalytic subunit alpha 2', other_designations="5'-AMP-activated protein kinase catalytic subunit alpha-2|5'-AMP-activated protein kinase, catalytic alpha-2 chain|ACACA kinase|AMP-activated protein kinase alpha-2 subunit variant 2|AMP-activated protein kinase alpha-2 subunit variant 3|AMPK alpha 2|AMPK subunit alpha-2|AMPK-alpha-2 chain|HMGCR kinase|acetyl-CoA carboxylase kinase|hydroxymethylglutaryl-CoA reductase kinase|protein kinase, AMP-activated, alpha 2 catalytic subunit", map_location='1p32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56645314, end_position_on_the_genomic_accession=56715335, orientation='plus', exon_count=12, OMIM=[600497], no_hdr0=''),
    5564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5564, CurrentID=0, Status='live', Symbol='PRKAB1', Aliases=['AMPK', 'HAMPKb'], description='protein kinase AMP-activated non-catalytic subunit beta 1', other_designations="5'-AMP-activated protein kinase subunit beta-1|5'-AMP-activated protein kinase beta-1 subunit|AMP-activated protein kinase beta subunit|AMPK beta -1 chain|AMPK beta 1|AMPK subunit beta-1|AMPKb|protein kinase, AMP-activated, beta 1 non-catalytic subunit|protein kinase, AMP-activated, noncatalytic, beta-1", map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119667864, end_position_on_the_genomic_accession=119681624, orientation='plus', exon_count=8, OMIM=[602740], no_hdr0=''),
    5565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5565, CurrentID=0, Status='live', Symbol='PRKAB2', Aliases=[], description='protein kinase AMP-activated non-catalytic subunit beta 2', other_designations="5'-AMP-activated protein kinase subunit beta-2|5'-AMP-activated protein kinase, beta-2 subunit|AMP-activated protein kinase beta 2 non-catalytic subunit|AMPK beta 2|AMPK beta-2 chain|AMPK subunit beta-2|protein kinase, AMP-activated, beta 2 non-catalytic subunit", map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147155106, end_position_on_the_genomic_accession=147173366, orientation='minus', exon_count=9, OMIM=[602741], no_hdr0=''),
    5566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5566, CurrentID=0, Status='live', Symbol='PRKACA', Aliases=['CAFD1', 'PKACA', 'PPNAD4'], description='protein kinase cAMP-activated catalytic subunit alpha', other_designations='cAMP-dependent protein kinase catalytic subunit alpha|PKA C-alpha|protein kinase A catalytic subunit|protein kinase, cAMP-dependent, alpha catalytic subunit|protein kinase, cAMP-dependent, catalytic, alpha', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14091688, end_position_on_the_genomic_accession=14117762, orientation='minus', exon_count=12, OMIM=[601639], no_hdr0=''),
    5567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5567, CurrentID=0, Status='live', Symbol='PRKACB', Aliases=['CAFD2', 'PKA C-beta', 'PKACB'], description='protein kinase cAMP-activated catalytic subunit beta', other_designations='cAMP-dependent protein kinase catalytic subunit beta|protein kinase A catalytic subunit beta|protein kinase, cAMP-dependent, beta catalytic subunit|protein kinase, cAMP-dependent, catalytic, beta', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84078079, end_position_on_the_genomic_accession=84238498, orientation='plus', exon_count=18, OMIM=[176892], no_hdr0=''),
    5568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5568, CurrentID=0, Status='live', Symbol='PRKACG', Aliases=['BDPLT19', 'KAPG', 'PKACg'], description='protein kinase cAMP-activated catalytic subunit gamma', other_designations='cAMP-dependent protein kinase catalytic subunit gamma|PKA C-gamma|protein kinase, cAMP-dependent, catalytic, gamma|protein kinase, cAMP-dependent, gamma catalytic subunit|serine(threonine) protein kinase', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69012504, end_position_on_the_genomic_accession=69014113, orientation='minus', exon_count=1, OMIM=[176893], no_hdr0=''),
    5569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5569, CurrentID=0, Status='live', Symbol='PKIA', Aliases=['PRKACN1'], description='cAMP-dependent protein kinase inhibitor alpha', other_designations='cAMP-dependent protein kinase inhibitor alpha|PKI-alpha|protein kinase (cAMP-dependent, catalytic) inhibitor alpha', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=78516340, end_position_on_the_genomic_accession=78605267, orientation='plus', exon_count=7, OMIM=[606059], no_hdr0=''),
    5570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5570, CurrentID=0, Status='live', Symbol='PKIB', Aliases=['PRKACN2'], description='cAMP-dependent protein kinase inhibitor beta', other_designations='cAMP-dependent protein kinase inhibitor beta|PKI-beta|cAMP-dependent protein kinase inhibitor 2|protein kinase (cAMP-dependent, catalytic) inhibitor beta', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122471921, end_position_on_the_genomic_accession=122726373, orientation='plus', exon_count=16, OMIM=[606914], no_hdr0=''),
    5571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5571, CurrentID=0, Status='live', Symbol='PRKAG1', Aliases=['AMPKG'], description='protein kinase AMP-activated non-catalytic subunit gamma 1', other_designations="5'-AMP-activated protein kinase subunit gamma-1|5'-AMP-activated protein kinase, gamma-1 subunit|AMPK gamma-1 chain|AMPK gamma1|protein kinase, AMP-activated, gamma 1 non-catalytic subunit", map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49002272, end_position_on_the_genomic_accession=49018975, orientation='minus', exon_count=14, OMIM=[602742], no_hdr0=''),
    5573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5573, CurrentID=0, Status='live', Symbol='PRKAR1A', Aliases=['ACRDYS1', 'ADOHR', 'CAR', 'CNC', 'CNC1', 'PKR1', 'PPNAD1', 'PRKAR1', 'TSE1'], description='protein kinase cAMP-dependent type I regulatory subunit alpha', other_designations='cAMP-dependent protein kinase type I-alpha regulatory subunit|Carney complex type 1|cAMP-dependent protein kinase regulatory subunit RIalpha|cAMP-dependent protein kinase type I-alpha regulatory chain|epididymis secretory sperm binding protein|protein kinase A type 1a regulatory subunit|protein kinase, cAMP-dependent, regulatory subunit type I alpha|protein kinase, cAMP-dependent, regulatory, type I, alpha|tissue-specific extinguisher 1', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68413623, end_position_on_the_genomic_accession=68551316, orientation='plus', exon_count=16, OMIM=[188830], no_hdr0=''),
    5575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5575, CurrentID=0, Status='live', Symbol='PRKAR1B', Aliases=['PRKAR1'], description='protein kinase cAMP-dependent type I regulatory subunit beta', other_designations='cAMP-dependent protein kinase type I-beta regulatory subunit|protein kinase, cAMP-dependent, regulatory subunit type I beta|protein kinase, cAMP-dependent, regulatory, type I, beta', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=549185, end_position_on_the_genomic_accession=727676, orientation='minus', exon_count=17, OMIM=[176911], no_hdr0=''),
    5576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5576, CurrentID=0, Status='live', Symbol='PRKAR2A', Aliases=['PKR2', 'PRKAR2'], description='protein kinase cAMP-dependent type II regulatory subunit alpha', other_designations='cAMP-dependent protein kinase type II-alpha regulatory subunit|cAMP-dependent protein kinase regulatory subunit RII alpha|protein kinase A, RII-alpha subunit|protein kinase, cAMP-dependent, regulatory subunit type II alpha', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48744601, end_position_on_the_genomic_accession=48847874, orientation='minus', exon_count=15, OMIM=[176910], no_hdr0=''),
    5577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5577, CurrentID=0, Status='live', Symbol='PRKAR2B', Aliases=['PRKAR2', 'RII-BETA'], description='protein kinase cAMP-dependent type II regulatory subunit beta', other_designations='cAMP-dependent protein kinase type II-beta regulatory subunit|H_RG363E19.2|WUGSC:H_RG363E19.2|cAMP-dependent protein kinase type II-beta regulatory chain|protein kinase, cAMP-dependent, regulatory subunit type II beta|protein kinase, cAMP-dependent, regulatory, type II, beta', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107044705, end_position_on_the_genomic_accession=107161811, orientation='plus', exon_count=12, OMIM=[176912], no_hdr0=''),
    5578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5578, CurrentID=0, Status='live', Symbol='PRKCA', Aliases=['AAG6', 'PKC-alpha', 'PKCA', 'PKCI+/-', 'PKCalpha', 'PRKACA'], description='protein kinase C alpha', other_designations='protein kinase C alpha type|PKC-A|aging-associated gene 6', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=66302613, end_position_on_the_genomic_accession=66810743, orientation='plus', exon_count=24, OMIM=[176960], no_hdr0=''),
    5579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5579, CurrentID=0, Status='live', Symbol='PRKCB', Aliases=['PKC-beta', 'PKCB', 'PKCI(2)', 'PKCbeta1', 'PRKCB2', 'PRKCB'], description='protein kinase C beta', other_designations='protein kinase C beta type|PKC-B|protein kinase C, beta 1 polypeptide', map_location='16p12.2-p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23835983, end_position_on_the_genomic_accession=24220611, orientation='plus', exon_count=17, OMIM=[176970], no_hdr0=''),
    5580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5580, CurrentID=0, Status='live', Symbol='PRKCD', Aliases=['ALPS3', 'CVID9', 'MAY1', 'PKCD', 'nPKC-delta'], description='protein kinase C delta', other_designations='protein kinase C delta type|protein kinase C delta VIII|tyrosine-protein kinase PRKCD', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53161209, end_position_on_the_genomic_accession=53192717, orientation='plus', exon_count=22, OMIM=[176977], no_hdr0=''),
    5581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5581, CurrentID=0, Status='live', Symbol='PRKCE', Aliases=['PKCE', 'nPKC-epsilon'], description='protein kinase C epsilon', other_designations='protein kinase C epsilon type', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=45651315, end_position_on_the_genomic_accession=46187990, orientation='plus', exon_count=32, OMIM=[176975], no_hdr0=''),
    5582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5582, CurrentID=0, Status='live', Symbol='PRKCG', Aliases=['PKC-gamma', 'PKCC', 'PKCG', 'PKCI(3)', 'PKCgamma', 'SCA14'], description='protein kinase C gamma', other_designations='protein kinase C gamma type', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53882197, end_position_on_the_genomic_accession=53907652, orientation='plus', exon_count=18, OMIM=[176980], no_hdr0=''),
    5583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5583, CurrentID=0, Status='live', Symbol='PRKCH', Aliases=['PKC-L', 'PKCL', 'PRKCL', 'nPKC-eta'], description='protein kinase C eta', other_designations='protein kinase C eta type', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=61187305, end_position_on_the_genomic_accession=61550980, orientation='plus', exon_count=23, OMIM=[605437], no_hdr0=''),
    5584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5584, CurrentID=0, Status='live', Symbol='PRKCI', Aliases=['DXS1179E', 'PKCI', 'nPKC-iota'], description='protein kinase C iota', other_designations='protein kinase C iota type|PRKC-lambda/iota|aPKC-lambda/iota|atypical protein kinase C-lambda/iota', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170222424, end_position_on_the_genomic_accession=170305981, orientation='plus', exon_count=18, OMIM=[600539], no_hdr0=''),
    5585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5585, CurrentID=0, Status='live', Symbol='PKN1', Aliases=['DBK', 'PAK-1', 'PAK1', 'PKN', 'PKN-ALPHA', 'PRK1', 'PRKCL1'], description='protein kinase N1', other_designations='serine/threonine-protein kinase N1|protease-activated kinase 1|protein kinase C-like 1|protein kinase C-like PKN|protein kinase C-related kinase 1|protein kinase PKN-alpha|serine-threonine kinase N|serine/threonine protein kinase N', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14433306, end_position_on_the_genomic_accession=14471859, orientation='plus', exon_count=23, OMIM=[601032], no_hdr0=''),
    5586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5586, CurrentID=0, Status='live', Symbol='PKN2', Aliases=['PAK2', 'PRK2', 'PRKCL2', 'PRO2042', 'Pak-2', 'STK7'], description='protein kinase N2', other_designations='serine/threonine-protein kinase N2|PKN gamma|cardiolipin-activated protein kinase Pak2|protein kinase C-like 2|protein-kinase C-related kinase 2', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=88684239, end_position_on_the_genomic_accession=88836255, orientation='plus', exon_count=23, OMIM=[602549], no_hdr0=''),
    5587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5587, CurrentID=0, Status='live', Symbol='PRKD1', Aliases=['CHDED', 'PKC-MU', 'PKCM', 'PKD', 'PRKCM'], description='protein kinase D1', other_designations='serine/threonine-protein kinase D1|nPKC-D1|nPKC-mu|protein kinase C mu type|protein kinase C, mu|protein kinase D', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=29576479, end_position_on_the_genomic_accession=29927847, orientation='minus', exon_count=23, OMIM=[605435], no_hdr0=''),
    5588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5588, CurrentID=0, Status='live', Symbol='PRKCQ', Aliases=['PRKCT', 'nPKC-theta'], description='protein kinase C theta', other_designations='protein kinase C theta type', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=6393038, end_position_on_the_genomic_accession=6580646, orientation='minus', exon_count=23, OMIM=[600448], no_hdr0=''),
    5589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5589, CurrentID=0, Status='live', Symbol='PRKCSH', Aliases=['AGE-R2', 'G19P1', 'GIIB', 'PCLD', 'PCLD1', 'PKCSH', 'PLD1', 'VASAP-60'], description='protein kinase C substrate 80K-H', other_designations='glucosidase 2 subunit beta|AGE-binding receptor 2|advanced glycation end-product receptor 2|glucosidase II subunit beta|hepatocystin|protein kinase C substrate 60.1 kDa protein heavy chain|protein kinase C substrate, 80 Kda protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11435290, end_position_on_the_genomic_accession=11450968, orientation='plus', exon_count=19, OMIM=[177060], no_hdr0=''),
    5590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5590, CurrentID=0, Status='live', Symbol='PRKCZ', Aliases=['PKC-ZETA', 'PKC2'], description='protein kinase C zeta', other_designations='protein kinase C zeta type|nPKC-zeta', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2050411, end_position_on_the_genomic_accession=2185395, orientation='plus', exon_count=29, OMIM=[176982], no_hdr0=''),
    5591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5591, CurrentID=0, Status='live', Symbol='PRKDC', Aliases=['DNA-PKC', 'DNA-PKcs', 'DNAPK', 'DNAPKc', 'DNPK1', 'HYRC', 'HYRC1', 'IMD26', 'XRCC7', 'p350'], description='protein kinase, DNA-activated, catalytic subunit', other_designations='DNA-dependent protein kinase catalytic subunit|DNA-PK catalytic subunit|hyper-radiosensitivity of murine scid mutation, complementing 1|p460|protein kinase, DNA-activated, catalytic polypeptide', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47773111, end_position_on_the_genomic_accession=47960136, orientation='minus', exon_count=86, OMIM=[600899], no_hdr0=''),
    5592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5592, CurrentID=0, Status='live', Symbol='PRKG1', Aliases=['AAT8', 'PKG', 'PKG1B', 'PRKGR1B', 'cGK', 'cGK 1', 'cGK1', 'cGKI', 'cGKI-BETA', 'cGKI-alpha', 'PRKG1'], description='protein kinase cGMP-dependent 1', other_designations='cGMP-dependent protein kinase 1|protein kinase, cGMP-dependent, regulatory, type I, beta|protein kinase, cGMP-dependent, type I', map_location='10q11.23-q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50990888, end_position_on_the_genomic_accession=52298350, orientation='plus', exon_count=23, OMIM=[176894], no_hdr0=''),
    5593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5593, CurrentID=0, Status='live', Symbol='PRKG2', Aliases=['PKG2', 'PRKGR2', 'cGK2', 'cGKII'], description='protein kinase cGMP-dependent 2', other_designations='cGMP-dependent protein kinase 2|cGMP-dependent protein kinase II|protein kinase, cGMP-dependent, type II|testicular tissue protein Li 99', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=81087370, end_position_on_the_genomic_accession=81217837, orientation='minus', exon_count=23, OMIM=[601591], no_hdr0=''),
    5594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5594, CurrentID=0, Status='live', Symbol='MAPK1', Aliases=['ERK', 'ERK-2', 'ERK2', 'ERT1', 'MAPK2', 'NS13', 'P42MAPK', 'PRKM1', 'PRKM2', 'p38', 'p40', 'p41', 'p41mapk', 'p42-MAPK'], description='mitogen-activated protein kinase 1', other_designations='mitogen-activated protein kinase 1|MAP kinase 1|MAP kinase 2|MAPK 2|extracellular signal-regulated kinase 2|mitogen-activated protein kinase 2|protein tyrosine kinase ERK2', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21759657, end_position_on_the_genomic_accession=21867680, orientation='minus', exon_count=9, OMIM=[176948], no_hdr0=''),
    5595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5595, CurrentID=0, Status='live', Symbol='MAPK3', Aliases=['ERK-1', 'ERK1', 'ERT2', 'HS44KDAP', 'HUMKER1A', 'P44ERK1', 'P44MAPK', 'PRKM3', 'p44-ERK1', 'p44-MAPK'], description='mitogen-activated protein kinase 3', other_designations='mitogen-activated protein kinase 3|MAPK 1|extracellular signal-regulated kinase 1|extracellular signal-related kinase 1|insulin-stimulated MAP2 kinase|microtubule-associated protein 2 kinase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30114105, end_position_on_the_genomic_accession=30123309, orientation='minus', exon_count=10, OMIM=[601795], no_hdr0=''),
    5596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5596, CurrentID=0, Status='live', Symbol='MAPK4', Aliases=['ERK-4', 'ERK4', 'PRKM4', 'p63-MAPK', 'p63MAPK'], description='mitogen-activated protein kinase 4', other_designations='mitogen-activated protein kinase 4|Erk3-related|MAPK 4|extracellular signal-regulated kinase 4', map_location='18q21.1-q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50559772, end_position_on_the_genomic_accession=50731826, orientation='plus', exon_count=14, OMIM=[176949], no_hdr0=''),
    5597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5597, CurrentID=0, Status='live', Symbol='MAPK6', Aliases=['ERK3', 'HsT17250', 'PRKM6', 'p97MAPK'], description='mitogen-activated protein kinase 6', other_designations='mitogen-activated protein kinase 6|ERK-3|MAP kinase 6|MAPK 6|extracellular signal-regulated kinase 3|extracellular signal-regulated kinase, p97|p97-MAPK|protein kinase, mitogen-activated 5|protein kinase, mitogen-activated 6', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52019219, end_position_on_the_genomic_accession=52067375, orientation='plus', exon_count=8, OMIM=[602904], no_hdr0=''),
    5598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5598, CurrentID=0, Status='live', Symbol='MAPK7', Aliases=['BMK1', 'ERK4', 'ERK5', 'PRKM7'], description='mitogen-activated protein kinase 7', other_designations='mitogen-activated protein kinase 7|BMK-1|BMK1 kinase|ERK-5|MAP kinase 7|MAPK 7|big MAP kinase 1|extracellular-signal-regulated kinase 5', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19377721, end_position_on_the_genomic_accession=19383544, orientation='plus', exon_count=9, OMIM=[602521], no_hdr0=''),
    5599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5599, CurrentID=0, Status='live', Symbol='MAPK8', Aliases=['JNK', 'JNK-46', 'JNK1', 'JNK1A2', 'JNK21B1/2', 'PRKM8', 'SAPK1', 'SAPK1c'], description='mitogen-activated protein kinase 8', other_designations='mitogen-activated protein kinase 8|JUN N-terminal kinase|MAP kinase 8|c-Jun N-terminal kinase 1|stress-activated protein kinase 1|stress-activated protein kinase 1c', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=48306673, end_position_on_the_genomic_accession=48439360, orientation='plus', exon_count=16, OMIM=[601158], no_hdr0=''),
    5600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5600, CurrentID=0, Status='live', Symbol='MAPK11', Aliases=['P38B', 'P38BETA2', 'PRKM11', 'SAPK2', 'SAPK2B', 'p38-2', 'p38Beta'], description='mitogen-activated protein kinase 11', other_designations='mitogen-activated protein kinase 11|MAP kinase 11|MAP kinase p38 beta|mitogen-activated protein kinase p38 beta|mitogen-activated protein kinase p38-2|stress-activated protein kinase-2|stress-activated protein kinase-2b', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50263713, end_position_on_the_genomic_accession=50270380, orientation='minus', exon_count=13, OMIM=[602898], no_hdr0=''),
    5601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5601, CurrentID=0, Status='live', Symbol='MAPK9', Aliases=['JNK-55', 'JNK2', 'JNK2A', 'JNK2ALPHA', 'JNK2B', 'JNK2BETA', 'PRKM9', 'SAPK', 'SAPK1a', 'p54a', 'p54aSAPK'], description='mitogen-activated protein kinase 9', other_designations='mitogen-activated protein kinase 9|Jun kinase|MAP kinase 9|MAPK 9|c-Jun N-terminal kinase 2|c-Jun kinase 2|stress-activated protein kinase 1a|stress-activated protein kinase JNK2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180233143, end_position_on_the_genomic_accession=180292083, orientation='minus', exon_count=17, OMIM=[602896], no_hdr0=''),
    5602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5602, CurrentID=0, Status='live', Symbol='MAPK10', Aliases=['JNK3', 'JNK3A', 'PRKM10', 'SAPK1b', 'p493F12', 'p54bSAPK'], description='mitogen-activated protein kinase 10', other_designations='mitogen-activated protein kinase 10|JNK3 alpha protein kinase|MAP kinase 10|MAP kinase p49 3F12|c-Jun N-terminal kinase 3|stress activated protein kinase beta|stress-activated protein kinase 1b|stress-activated protein kinase JNK3', map_location='4q21.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=86010405, end_position_on_the_genomic_accession=86594625, orientation='minus', exon_count=27, OMIM=[602897], no_hdr0=''),
    5603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5603, CurrentID=0, Status='live', Symbol='MAPK13', Aliases=['MAPK 13', 'MAPK-13', 'PRKM13', 'SAPK4', 'p38delta'], description='mitogen-activated protein kinase 13', other_designations='mitogen-activated protein kinase 13|MAP kinase 13|MAP kinase p38 delta|mitogen-activated protein kinase p38 delta|stress-activated protein kinase 4', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36130513, end_position_on_the_genomic_accession=36144521, orientation='plus', exon_count=13, OMIM=[602899], no_hdr0=''),
    5604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5604, CurrentID=0, Status='live', Symbol='MAP2K1', Aliases=['CFC3', 'MAPKK1', 'MEK1', 'MEL', 'MKK1', 'PRKMK1'], description='mitogen-activated protein kinase kinase 1', other_designations='dual specificity mitogen-activated protein kinase kinase 1|ERK activator kinase 1|MAPK/ERK kinase 1|MAPKK 1|MEK 1|protein kinase, mitogen-activated, kinase 1 (MAP kinase kinase 1)', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66386912, end_position_on_the_genomic_accession=66491544, orientation='plus', exon_count=13, OMIM=[176872], no_hdr0=''),
    5605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5605, CurrentID=0, Status='live', Symbol='MAP2K2', Aliases=['CFC4', 'MAPKK2', 'MEK2', 'MKK2', 'PRKMK2'], description='mitogen-activated protein kinase kinase 2', other_designations='dual specificity mitogen-activated protein kinase kinase 2|ERK activator kinase 2|MAP kinase kinase 2|MAPK/ERK kinase 2|mitogen-activated protein kinase kinase 2, p45', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4090321, end_position_on_the_genomic_accession=4124184, orientation='minus', exon_count=13, OMIM=[601263], no_hdr0=''),
    5606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5606, CurrentID=0, Status='live', Symbol='MAP2K3', Aliases=['MAPKK3', 'MEK3', 'MKK3', 'PRKMK3', 'SAPKK-2', 'SAPKK2'], description='mitogen-activated protein kinase kinase 3', other_designations='dual specificity mitogen-activated protein kinase kinase 3|MAP kinase kinase 3|MAPK/ERK kinase 3|MAPKK 3|MEK 3|SAPK kinase 2|stress-activated protein kinase kinase 2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21284679, end_position_on_the_genomic_accession=21315240, orientation='plus', exon_count=16, OMIM=[602315], no_hdr0=''),
    5607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5607, CurrentID=0, Status='live', Symbol='MAP2K5', Aliases=['HsT17454', 'MAPKK5', 'MEK5', 'PRKMK5'], description='mitogen-activated protein kinase kinase 5', other_designations='dual specificity mitogen-activated protein kinase kinase 5|MAP kinase kinase 5|MAP kinase kinase MEK5b|MAPK/ERK kinase 5|MAPKK 5|MEK 5', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67542685, end_position_on_the_genomic_accession=67807114, orientation='plus', exon_count=27, OMIM=[602520], no_hdr0=''),
    5608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5608, CurrentID=0, Status='live', Symbol='MAP2K6', Aliases=['MAPKK6', 'MEK6', 'MKK6', 'PRKMK6', 'SAPKK-3', 'SAPKK3'], description='mitogen-activated protein kinase kinase 6', other_designations='dual specificity mitogen-activated protein kinase kinase 6|MAPK/ERK kinase 6|MAPKK 6|MEK 6|SAPK kinase 3|protein kinase, mitogen-activated, kinase 6 (MAP kinase kinase 6)|stress-activated protein kinase kinase 3', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=69414697, end_position_on_the_genomic_accession=69553865, orientation='plus', exon_count=15, OMIM=[601254], no_hdr0=''),
    5609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5609, CurrentID=0, Status='live', Symbol='MAP2K7', Aliases=['JNKK2', 'MAPKK7', 'MEK', 'MEK 7', 'MKK7', 'PRKMK7', 'SAPKK-4', 'SAPKK4'], description='mitogen-activated protein kinase kinase 7', other_designations='dual specificity mitogen-activated protein kinase kinase 7|JNK-activating kinase 2|MAP kinase kinase 7|MAPK/ERK kinase 7|SAPK kinase 4|c-Jun N-terminal kinase kinase 2|stress-activated protein kinase kinase 4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7903785, end_position_on_the_genomic_accession=7914478, orientation='plus', exon_count=12, OMIM=[603014], no_hdr0=''),
    5610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5610, CurrentID=0, Status='live', Symbol='EIF2AK2', Aliases=['EIF2AK1', 'LEUDEN', 'PKR', 'PPP1R83', 'PRKR'], description='eukaryotic translation initiation factor 2 alpha kinase 2', other_designations='interferon-induced, double-stranded RNA-activated protein kinase|P1/eIF-2A protein kinase|double stranded RNA activated protein kinase|eIF-2A protein kinase 2|interferon-inducible elF2alpha kinase|p68 kinase|protein kinase R|protein kinase, interferon-inducible double stranded RNA dependent|protein phosphatase 1, regulatory subunit 83|tyrosine-protein kinase EIF2AK2', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37099210, end_position_on_the_genomic_accession=37157065, orientation='minus', exon_count=17, OMIM=[176871], no_hdr0=''),
    5611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5611, CurrentID=0, Status='live', Symbol='DNAJC3', Aliases=['ACPHD', 'ERdj6', 'HP58', 'P58', 'P58IPK', 'PRKRI', 'p58(IPK)'], description='DnaJ heat shock protein family (Hsp40) member C3', other_designations='dnaJ homolog subfamily C member 3|DnaJ (Hsp40) homolog, subfamily C, member 3|ER-resident protein ERdj6|endoplasmic reticulum DNA J domain-containing protein 6|interferon-induced, double-stranded RNA-activated protein kinase inhibitor|protein kinase inhibitor of 58 kDa|protein kinase inhibitor p58|protein-kinase, interferon-inducible double stranded RNA dependent inhibitor', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=95677139, end_position_on_the_genomic_accession=95794988, orientation='plus', exon_count=16, OMIM=[601184], no_hdr0=''),
    5612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5612, CurrentID=0, Status='live', Symbol='THAP12', Aliases=['DAP4', 'P52rIPK', 'PRKRIR', 'THAP0'], description='THAP domain containing 12', other_designations='52 kDa repressor of the inhibitor of the protein kinase|58 kDa interferon-induced protein kinase-interacting protein|P58IPK-regulatory protein|THAP domain-containing protein 0|THAP domain-containing protein 12|death-associated protein 4|inhibitor of protein kinase PKR|p58IPK-interacting protein|protein-kinase, interferon-inducible double stranded RNA dependent inhibitor, repressor of (P58 repressor)|testicular tissue protein Li 133', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76349956, end_position_on_the_genomic_accession=76381132, orientation='minus', exon_count=6, OMIM=[607374], no_hdr0=''),
    5613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5613, CurrentID=0, Status='live', Symbol='PRKX', Aliases=['PKX1'], description='protein kinase X-linked', other_designations='cAMP-dependent protein kinase catalytic subunit PRKX|protein kinase PKX1|protein kinase X|serine/threonine-protein kinase PRKX', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=3604340, end_position_on_the_genomic_accession=3713649, orientation='minus', exon_count=9, OMIM=[300083], no_hdr0=''),
    5617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5617, CurrentID=0, Status='live', Symbol='PRL', Aliases=['GHA1'], description='prolactin', other_designations='prolactin|decidual prolactin|growth hormone A1', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=22287246, end_position_on_the_genomic_accession=22302897, orientation='minus', exon_count=7, OMIM=[176760], no_hdr0=''),
    5618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5618, CurrentID=0, Status='live', Symbol='PRLR', Aliases=['HPRL', 'MFAB', 'RI-PRLR', 'hPRLrI'], description='prolactin receptor', other_designations='prolactin receptor|hPRL receptor|secreted prolactin binding protein', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=35048756, end_position_on_the_genomic_accession=35230724, orientation='minus', exon_count=16, OMIM=[176761], no_hdr0=''),
    5619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5619, CurrentID=0, Status='live', Symbol='PRM1', Aliases=['CT94.1', 'P1'], description='protamine 1', other_designations='sperm protamine P1|cancer/testis antigen family 94, member 1|cysteine-rich protamine|testicular tissue protein Li 91|testis specific protamine 1', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11280841, end_position_on_the_genomic_accession=11281330, orientation='minus', exon_count=2, OMIM=[182880], no_hdr0=''),
    5620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5620, CurrentID=0, Status='live', Symbol='PRM2', Aliases=['CT94.2'], description='protamine 2', other_designations='protamine-2|cancer/testis antigen family 94, member 2|sperm histone P2|sperm protamine P2|testicular secretory protein Li 40', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11275639, end_position_on_the_genomic_accession=11276480, orientation='minus', exon_count=2, OMIM=[182890], no_hdr0=''),
    5621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5621, CurrentID=0, Status='live', Symbol='PRNP', Aliases=['ASCR', 'AltPrP', 'CD230', 'CJD', 'GSS', 'KURU', 'PRIP', 'PrP', 'PrP27-30', 'PrP33-35C', 'PrPc', 'p27-30'], description='prion protein', other_designations='major prion protein|alternative prion protein|CD230 antigen|prion-related protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4686456, end_position_on_the_genomic_accession=4701588, orientation='plus', exon_count=2, OMIM=[176640], no_hdr0=''),
    5623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5623, CurrentID=0, Status='live', Symbol='PSPN', Aliases=['PSP'], description='persephin', other_designations='persephin', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6375148, end_position_on_the_genomic_accession=6375933, orientation='minus', exon_count=2, OMIM=[602921], no_hdr0=''),
    5624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5624, CurrentID=0, Status='live', Symbol='PROC', Aliases=['APC', 'PC1', 'THPH3', 'THPH4', 'PROC'], description='protein C, inactivator of coagulation factors Va and VIIIa', other_designations='vitamin K-dependent protein C|Protein C-Nagoya|activated protein C|anticoagulant protein C|autoprothrombin IIA|blood coagulation factor XIV|prepro-protein C|type I protein C', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127418143, end_position_on_the_genomic_accession=127429246, orientation='plus', exon_count=8, OMIM=[612283], no_hdr0=''),
    5625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5625, CurrentID=0, Status='live', Symbol='PRODH', Aliases=['HSPOX2', 'PIG6', 'POX1', 'PRODH2', 'TP53I6', 'PRODH'], description='proline dehydrogenase 1', other_designations='proline dehydrogenase 1, mitochondrial|p53-induced gene 6 protein|proline dehydrogenase (oxidase) 1|proline oxidase 2|proline oxidase, mitochondrial|tumor protein p53 inducible protein 6', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18912781, end_position_on_the_genomic_accession=18936553, orientation='minus', exon_count=15, OMIM=[606810], no_hdr0=''),
    5626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5626, CurrentID=0, Status='live', Symbol='PROP1', Aliases=['CPHD2', 'PROP-1'], description='PROP paired-like homeobox 1', other_designations='homeobox protein prophet of Pit-1|pituitary-specific homeodomain factor|prophet of Pit1, paired-like homeodomain transcription factor', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177992235, end_position_on_the_genomic_accession=177996242, orientation='minus', exon_count=3, OMIM=[601538], no_hdr0=''),
    5627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5627, CurrentID=0, Status='live', Symbol='PROS1', Aliases=['PROS', 'PS21', 'PS22', 'PS23', 'PS24', 'PS25', 'PSA', 'THPH5', 'THPH6'], description='protein S', other_designations='vitamin K-dependent protein S|protein S (alpha)|protein Sa|vitamin K-dependent plasma protein S', map_location='3q11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=93873051, end_position_on_the_genomic_accession=93973896, orientation='minus', exon_count=16, OMIM=[176880], no_hdr0=''),
    5629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5629, CurrentID=0, Status='live', Symbol='PROX1', Aliases=[], description='prospero homeobox 1', other_designations='prospero homeobox protein 1|homeobox prospero-like protein PROX1|prospero-related homeobox 1', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=213983239, end_position_on_the_genomic_accession=214041510, orientation='plus', exon_count=9, OMIM=[601546], no_hdr0=''),
    5630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5630, CurrentID=0, Status='live', Symbol='PRPH', Aliases=['NEF41', 'PRPH'], description='peripherin', other_designations='peripherin|neurofilament 4 (57kD)', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49295144, end_position_on_the_genomic_accession=49298698, orientation='plus', exon_count=9, OMIM=[170710], no_hdr0=''),
    5631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5631, CurrentID=0, Status='live', Symbol='PRPS1', Aliases=['ARTS', 'CMTX5', 'DFN2', 'DFNX1', 'PPRibP', 'PRS-I', 'PRSI'], description='phosphoribosyl pyrophosphate synthetase 1', other_designations='ribose-phosphate pyrophosphokinase 1|dJ1070B1.2 (phosphoribosyl pyrophosphate synthetase 1)|deafness 2, perceptive, congenital|deafness, X-linked 2, perceptive, congenital|phosphoribosyl pyrophosphate synthase I|ribose-phosphate diphosphokinase 1', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107628510, end_position_on_the_genomic_accession=107651026, orientation='plus', exon_count=7, OMIM=[311850], no_hdr0=''),
    5634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5634, CurrentID=0, Status='live', Symbol='PRPS2', Aliases=['PRSII'], description='phosphoribosyl pyrophosphate synthetase 2', other_designations='ribose-phosphate pyrophosphokinase 2|PPRibP synthetase|PRS-II|phosphoribosyl pyrophosphate synthase II|ribose-phosphate diphosphokinase 2|testicular secretory protein Li 41', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=12791412, end_position_on_the_genomic_accession=12824222, orientation='plus', exon_count=7, OMIM=[311860], no_hdr0=''),
    5635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5635, CurrentID=0, Status='live', Symbol='PRPSAP1', Aliases=['PAP39'], description='phosphoribosyl pyrophosphate synthetase associated protein 1', other_designations='phosphoribosyl pyrophosphate synthase-associated protein 1|39 kDa phosphoribosypyrophosphate synthase-associated protein|PRPP synthase-associated protein 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76309478, end_position_on_the_genomic_accession=76354198, orientation='minus', exon_count=11, OMIM=[601249], no_hdr0=''),
    5636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5636, CurrentID=0, Status='live', Symbol='PRPSAP2', Aliases=['PAP41'], description='phosphoribosyl pyrophosphate synthetase associated protein 2', other_designations='phosphoribosyl pyrophosphate synthase-associated protein 2|41 kDa phosphoribosypyrophosphate synthetase-associated protein|PRPP synthase-associated protein 2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18856299, end_position_on_the_genomic_accession=18931287, orientation='plus', exon_count=18, OMIM=[603762], no_hdr0=''),
    5638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5638, CurrentID=0, Status='live', Symbol='PRRG1', Aliases=['PRGP1'], description='proline rich and Gla domain 1', other_designations='transmembrane gamma-carboxyglutamic acid protein 1|proline rich Gla (G-carboxyglutamic acid) 1|proline-rich Gla (G-carboxyglutamic acid) polypeptide 1', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37349364, end_position_on_the_genomic_accession=37457291, orientation='plus', exon_count=6, OMIM=[300935], no_hdr0=''),
    5639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5639, CurrentID=0, Status='live', Symbol='PRRG2', Aliases=['PRGP2'], description='proline rich and Gla domain 2', other_designations='transmembrane gamma-carboxyglutamic acid protein 2|proline rich Gla (G-carboxyglutamic acid) 2|proline-rich Gla (G-carboxglutamic acid) polypeptide 2|proline-rich Gla (G-carboxyglutamic acid) polypeptide 2|proline-rich Gla protein 2|proline-rich gamma-carboxyglutamic acid protein 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49580617, end_position_on_the_genomic_accession=49591008, orientation='plus', exon_count=8, OMIM=[604429], no_hdr0=''),
    5641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5641, CurrentID=0, Status='live', Symbol='LGMN', Aliases=['AEP1', 'PRSC1', 'LGMN'], description='legumain', other_designations='legumain|asparaginyl endopeptidase|cysteine protease 1|protease, cysteine 1|protease, cysteine, 1 (legumain)', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92703809, end_position_on_the_genomic_accession=92748627, orientation='minus', exon_count=18, OMIM=[602620], no_hdr0=''),
    5644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5644, CurrentID=0, Status='live', Symbol='PRSS1', Aliases=['TRP1', 'TRY1', 'TRY4', 'TRYP1'], description='serine protease 1', other_designations='trypsin-1|TCR V beta 4.1|beta-trypsin|cationic trypsinogen|digestive zymogen|nonfunctional trypsin 1|protease, serine 1|trypsinogen 1|trypsinogen A', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142740235, end_position_on_the_genomic_accession=142753076, orientation='plus', exon_count=7, OMIM=[276000], no_hdr0=''),
    5645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5645, CurrentID=0, Status='live', Symbol='PRSS2', Aliases=['TRY2', 'TRY8', 'TRYP2'], description='serine protease 2', other_designations='trypsin-2|anionic trypsinogen|protease serine 2 preproprotein|protease, serine 2|protease, serine, 2 (trypsin 2)|trypsin II|trypsinogen 2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142770970, end_position_on_the_genomic_accession=142774560, orientation='plus', exon_count=6, OMIM=[601564], no_hdr0=''),
    5646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5646, CurrentID=0, Status='live', Symbol='PRSS3', Aliases=['MTG', 'PRSS4', 'T9', 'TRY3', 'TRY4'], description='serine protease 3', other_designations='trypsin-3|brain trypsinogen|mesotrypsin|mesotrypsinogen|pancreatic trypsinogen III|protease, serine 3|protease, serine, 4 (trypsin 4, brain)|trypsin III|trypsin IV|trypsinogen 4|trypsinogen 5|trypsinogen IV', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33750522, end_position_on_the_genomic_accession=33799231, orientation='plus', exon_count=9, OMIM=[613578], no_hdr0=''),
    5648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5648, CurrentID=0, Status='live', Symbol='MASP1', Aliases=['3MC1', 'CRARF', 'CRARF1', 'MAP-1', 'MAP1', 'MASP', 'MASP-3', 'MASP3', 'MAp44', 'PRSS5', 'RaRF'], description='MBL associated serine protease 1', other_designations='mannan-binding lectin serine protease 1|C4/C2 activating component of Ra-reactive factor|Ra-reactive factor serine protease p100|complement factor MASP-3|complement-activating component of Ra-reactive factor|mannan binding lectin serine peptidase 1|mannose-associated serine protease 1|mannose-binding lectin-associated serine protease 1|mannose-binding protein-associated serine protease|serine protease 5', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187217282, end_position_on_the_genomic_accession=187293529, orientation='minus', exon_count=20, OMIM=[600521], no_hdr0=''),
    5649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5649, CurrentID=0, Status='live', Symbol='RELN', Aliases=['ETL7', 'LIS2', 'PRO1598', 'RL'], description='reelin', other_designations='reelin', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103471789, end_position_on_the_genomic_accession=103989658, orientation='minus', exon_count=65, OMIM=[600514], no_hdr0=''),
    5650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5650, CurrentID=0, Status='live', Symbol='KLK7', Aliases=['PRSS6', 'SCCE', 'hK7'], description='kallikrein related peptidase 7', other_designations='kallikrein-7|kallikrein 7 (chymotryptic, stratum corneum)|serine protease 6|signal protein|stratum corneum chymotryptic enzyme', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50976468, end_position_on_the_genomic_accession=50984064, orientation='minus', exon_count=7, OMIM=[604438], no_hdr0=''),
    5651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5651, CurrentID=0, Status='live', Symbol='TMPRSS15', Aliases=['ENTK', 'PRSS7'], description='transmembrane serine protease 15', other_designations='enteropeptidase|enterokinase catalytic subunit|protease, serine, 7 (enterokinase)|serine protease 7|transmembrane protease, serine 15', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=18269107, end_position_on_the_genomic_accession=18403806, orientation='minus', exon_count=28, OMIM=[606635], no_hdr0=''),
    5652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5652, CurrentID=0, Status='live', Symbol='PRSS8', Aliases=['CAP1', 'PROSTASIN'], description='serine protease 8', other_designations='prostasin|channel-activating protease 1|channel-activating serine protease 1|protease, serine 8', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31131433, end_position_on_the_genomic_accession=31135727, orientation='minus', exon_count=6, OMIM=[600823], no_hdr0=''),
    5653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5653, CurrentID=0, Status='live', Symbol='KLK6', Aliases=['Bssp', 'Klk7', 'PRSS18', 'PRSS9', 'SP59', 'hK6'], description='kallikrein related peptidase 6', other_designations='kallikrein-6|neurosin|protease M|serine protease 18|serine protease 9|zyme', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50958631, end_position_on_the_genomic_accession=50969598, orientation='minus', exon_count=7, OMIM=[602652], no_hdr0=''),
    5654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5654, CurrentID=0, Status='live', Symbol='HTRA1', Aliases=['ARMD7', 'CADASIL2', 'CARASIL', 'HtrA', 'L56', 'ORF480', 'PRSS11'], description='HtrA serine peptidase 1', other_designations='serine protease HTRA1|IGFBP5-protease|high-temperature requirement A serine peptidase 1|protease, serine, 11 (IGF binding)', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122461553, end_position_on_the_genomic_accession=122514907, orientation='plus', exon_count=9, OMIM=[602194], no_hdr0=''),
    5655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5655, CurrentID=0, Status='live', Symbol='KLK10', Aliases=['NES1', 'PRSSL1'], description='kallikrein related peptidase 10', other_designations='kallikrein-10|breast normal epithelial cell associated serine protease|kallikrein 10 protein 1|kallikrein 10 protein 12|kallikrein 10 protein 13|kallikrein 10 protein 2|kallikrein 10 protein 3|kallikrein 10 protein 4|kallikrein 10 protein 5|kallikrein 10 protein 7|kallikrein 10 protein 8|kallikrein 10 protein 9|normal epithelial cell-specific 1|protease serine-like 1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51012739, end_position_on_the_genomic_accession=51020097, orientation='minus', exon_count=9, OMIM=[602673], no_hdr0=''),
    5657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5657, CurrentID=0, Status='live', Symbol='PRTN3', Aliases=['ACPA', 'AGP7', 'C-ANCA', 'CANCA', 'MBN', 'MBT', 'NP-4', 'NP4', 'P29', 'PR-3', 'PR3'], description='proteinase 3', other_designations='myeloblastin|C-ANCA antigen|Wegener granulomatosis autoantigen|azurophil granule protein 7|leukocyte proteinase 3|neutrophil proteinase 4|serine proteinase, neutrophil|wegener autoantigen', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=840965, end_position_on_the_genomic_accession=848175, orientation='plus', exon_count=5, OMIM=[177020], no_hdr0=''),
    5660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5660, CurrentID=0, Status='live', Symbol='PSAP', Aliases=['GLBA', 'SAP1', 'SAP2'], description='prosaposin', other_designations='prosaposin|proactivator polypeptide|saposin-A|saposin-B|saposin-C|saposin-D|sphingolipid activator protein-1|sphingolipid activator protein-2', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71816298, end_position_on_the_genomic_accession=71851251, orientation='minus', exon_count=15, OMIM=[176801], no_hdr0=''),
    5662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5662, CurrentID=0, Status='live', Symbol='PSD', Aliases=['EFA6', 'EFA6A1', 'TYL', 'PSD'], description='pleckstrin and Sec7 domain containing', other_designations='PH and SEC7 domain-containing protein 1|exchange factor for ADP-ribosylation factor guanine nucleotide factor 6|exchange factor for ARF6 A|pleckstrin homology and SEC7 domain-containing protein 1|pleckstrin-Sec7 domains-containing', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102402619, end_position_on_the_genomic_accession=102420164, orientation='minus', exon_count=22, OMIM=[602327], no_hdr0=''),
    5663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5663, CurrentID=0, Status='live', Symbol='PSEN1', Aliases=['ACNINV3', 'AD3', 'FAD', 'PS-1', 'PS1', 'S182'], description='presenilin 1', other_designations='presenilin-1', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73136436, end_position_on_the_genomic_accession=73223691, orientation='plus', exon_count=14, OMIM=[104311], no_hdr0=''),
    5664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5664, CurrentID=0, Status='live', Symbol='PSEN2', Aliases=['AD3L', 'AD4', 'CMD1V', 'PS2', 'STM2'], description='presenilin 2', other_designations='presenilin-2|AD3LP|AD5|Alzheimer disease 4|E5-1|PS-2|STM-2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226870594, end_position_on_the_genomic_accession=226903829, orientation='plus', exon_count=16, OMIM=[600759], no_hdr0=''),
    5669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5669, CurrentID=0, Status='live', Symbol='PSG1', Aliases=['B1G1', 'CD66f', 'DHFRP2', 'FL-NCA-1/2', 'PBG1', 'PS-beta-C/D', 'PS-beta-G-1', 'PSBG-1', 'PSBG1', 'PSG95', 'PSGGA', 'PSGIIA', 'SP1'], description='pregnancy specific beta-1-glycoprotein 1', other_designations='pregnancy-specific beta-1-glycoprotein 1|CD66 antigen-like family member F|fetal liver non-specific cross-reactive antigen 1/2|pregnancy-specific B-1 glycoprotein|pregnancy-specific beta-1 glycoprotein C/D', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42866464, end_position_on_the_genomic_accession=42879713, orientation='minus', exon_count=7, OMIM=[176390], no_hdr0=''),
    5670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5670, CurrentID=0, Status='live', Symbol='PSG2', Aliases=['CEA', 'PSBG2', 'PSG1'], description='pregnancy specific beta-1-glycoprotein 2', other_designations='pregnancy-specific beta-1-glycoprotein 2|PS-beta-E|PS-beta-G-2|PSBG-2|carcinoembryonic antigen SG8|pregnancy-specific beta-1 glycoprotein E|pregnancy-specific beta-1-glycoprotein 7|pregnancy-specific glycoprotein 2', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43064209, end_position_on_the_genomic_accession=43082701, orientation='minus', exon_count=6, OMIM=[176391], no_hdr0=''),
    5671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5671, CurrentID=0, Status='live', Symbol='PSG3', Aliases=[], description='pregnancy specific beta-1-glycoprotein 3', other_designations='pregnancy-specific beta-1-glycoprotein 3|PS-beta-G-3|PSBG-3|carcinoembryonic antigen SG5|pregnancy-specific glycoprotein 3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42721642, end_position_on_the_genomic_accession=42740486, orientation='minus', exon_count=7, OMIM=[176392], no_hdr0=''),
    5672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5672, CurrentID=0, Status='live', Symbol='PSG4', Aliases=['PSBG-4', 'PSBG-9', 'PSG9'], description='pregnancy specific beta-1-glycoprotein 4', other_designations='pregnancy-specific beta-1-glycoprotein 4|PS-beta-G-4|PS-beta-G-9|Pregnancy-specific beta-1-glycoprotein-4|pregnancy-specific beta-1-glycoprotein 9|pregnancy-specific glycoprotein 4|pregnancy-specific glycoprotein 9', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43192702, end_position_on_the_genomic_accession=43205638, orientation='minus', exon_count=6, OMIM=[176393], no_hdr0=''),
    5673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5673, CurrentID=0, Status='live', Symbol='PSG5', Aliases=['FL-NCA-3', 'PSG'], description='pregnancy specific beta-1-glycoprotein 5', other_designations='pregnancy-specific beta-1-glycoprotein 5|PS-beta-G-5|PSBG-5|Pregnancy-specific beta-1-glycoprotein-5|fetal liver non-specific cross-reactive antigen 3|pregnancy-specific beta 1 glycoprotein|pregnancy-specific glycoprotein 5', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43167743, end_position_on_the_genomic_accession=43186536, orientation='minus', exon_count=7, OMIM=[176394], no_hdr0=''),
    5675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5675, CurrentID=0, Status='live', Symbol='PSG6', Aliases=['PSBG-10', 'PSBG-12', 'PSBG-6', 'PSG10', 'PSGGB'], description='pregnancy specific beta-1-glycoprotein 6', other_designations='pregnancy-specific beta-1-glycoprotein 6|PS-beta-G-10|PS-beta-G-12|PS-beta-G-6|pregnancy-specific beta-1-glycoprotein 10|pregnancy-specific beta-1-glycoprotein 12', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42902086, end_position_on_the_genomic_accession=42917894, orientation='minus', exon_count=7, OMIM=[176395], no_hdr0=''),
    5676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5676, CurrentID=0, Status='live', Symbol='PSG7', Aliases=['PSBG-7', 'PSG1', 'PSGGA'], description='pregnancy specific beta-1-glycoprotein 7', other_designations='putative pregnancy-specific beta-1-glycoprotein 7|PS-beta-G-7|pregnancy-specific glycoprotein 7', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42924132, end_position_on_the_genomic_accession=42937207, orientation='minus', exon_count=6, OMIM=[176396], no_hdr0=''),
    5678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5678, CurrentID=0, Status='live', Symbol='PSG9', Aliases=['PS34', 'PSBG-11', 'PSBG-9', 'PSG11', 'PSGII'], description='pregnancy specific beta-1-glycoprotein 9', other_designations='pregnancy-specific beta-1-glycoprotein 9|PS-beta-B|PS-beta-G-11|PS-beta-G-9|pregnancy specific beta-1-glycoprotein 11|pregnancy-specific beta-1 glycoprotein B|pregnancy-specific beta-1-glycoprotein 11 C-R domain', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43253282, end_position_on_the_genomic_accession=43269530, orientation='minus', exon_count=7, OMIM=[176398], no_hdr0=''),
    5680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5680, CurrentID=0, Status='live', Symbol='PSG11', Aliases=['PSBG-11', 'PSBG-13', 'PSG13', 'PSG14'], description='pregnancy specific beta-1-glycoprotein 11', other_designations='pregnancy-specific beta-1-glycoprotein 11|PS-beta-G-11|PS-beta-G-13|pregnancy-specific beta-1-glycoprotein 13', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43007656, end_position_on_the_genomic_accession=43026469, orientation='minus', exon_count=6, OMIM=[176401], no_hdr0=''),
    5681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5681, CurrentID=0, Status='live', Symbol='PSKH1', Aliases=[], description='protein serine kinase H1', other_designations='serine/threonine-protein kinase H1|PSK-H1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67893254, end_position_on_the_genomic_accession=67929676, orientation='plus', exon_count=3, OMIM=[177015], no_hdr0=''),
    5682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5682, CurrentID=0, Status='live', Symbol='PSMA1', Aliases=['HC2', 'HEL-S-275', 'NU', 'PROS30'], description='proteasome 20S subunit alpha 1', other_designations='proteasome subunit alpha type-1|30 kDa prosomal protein|PROS-30|epididymis secretory protein Li 275|macropain subunit C2|macropain subunit nu|multicatalytic endopeptidase complex subunit C2|proteasome (prosome, macropain) subunit, alpha type, 1|proteasome component C2|proteasome nu chain|proteasome subunit alpha 1|proteasome subunit alpha 6|proteasome subunit nu|proteasome subunit, alpha-type, 1|protein P30-33K|testicular tissue protein Li 150', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14504876, end_position_on_the_genomic_accession=14643662, orientation='minus', exon_count=12, OMIM=[602854], no_hdr0=''),
    5683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5683, CurrentID=0, Status='live', Symbol='PSMA2', Aliases=['HC3', 'MU', 'PMSA2', 'PSC2'], description='proteasome 20S subunit alpha 2', other_designations='proteasome subunit alpha type-2|macropain subunit C3|multicatalytic endopeptidase complex subunit C3|proteasome (prosome, macropain) subunit, alpha type, 2|proteasome component C3|proteasome subunit HC3|proteasome subunit alpha 2', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=42916861, end_position_on_the_genomic_accession=42932174, orientation='minus', exon_count=8, OMIM=[176842], no_hdr0=''),
    5684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5684, CurrentID=0, Status='live', Symbol='PSMA3', Aliases=['HC8', 'PSC3'], description='proteasome 20S subunit alpha 3', other_designations='proteasome subunit alpha type-3|macropain subunit C8|multicatalytic endopeptidase complex subunit C8|proteasome (prosome, macropain) subunit, alpha type, 3|proteasome component C8|proteasome subunit C8|proteasome subunit alpha 3|proteasome subunit alpha7|testicular secretory protein Li 43', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58244843, end_position_on_the_genomic_accession=58272004, orientation='plus', exon_count=11, OMIM=[176843], no_hdr0=''),
    5685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5685, CurrentID=0, Status='live', Symbol='PSMA4', Aliases=['HC9', 'HsT17706', 'PSC9'], description='proteasome 20S subunit alpha 4', other_designations='proteasome subunit alpha type-4|macropain subunit C9|multicatalytic endopeptidase complex subunit C9|proteasome (prosome, macropain) subunit, alpha type, 4|proteasome component C9|proteasome subunit HC9|proteasome subunit L|proteasome subunit alpha 4|proteasome subunit alpha3', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78540405, end_position_on_the_genomic_accession=78552417, orientation='plus', exon_count=10, OMIM=[176846], no_hdr0=''),
    5686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5686, CurrentID=0, Status='live', Symbol='PSMA5', Aliases=['PSC5', 'ZETA'], description='proteasome 20S subunit alpha 5', other_designations='proteasome subunit alpha type-5|epididymis tissue sperm binding protein Li 11n|macropain subunit zeta|macropain zeta chain|multicatalytic endopeptidase complex zeta chain|proteasome (prosome, macropain) subunit, alpha type, 5|proteasome alpha 5 subunit|proteasome component 5|proteasome subunit alpha 5|proteasome subunit zeta|proteasome zeta chain', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109399042, end_position_on_the_genomic_accession=109426448, orientation='minus', exon_count=9, OMIM=[176844], no_hdr0=''),
    5687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5687, CurrentID=0, Status='live', Symbol='PSMA6', Aliases=['IOTA', 'PROS27', 'p27K'], description='proteasome 20S subunit alpha 6', other_designations='proteasome subunit alpha type-6|27 kDa prosomal protein|PROS-27|macropain iota chain|macropain subunit iota|multicatalytic endopeptidase complex iota chain|prosomal P27K protein|proteasome (prosome, macropain) subunit, alpha type, 6|proteasome iota chain|proteasome subunit alpha 6|proteasome subunit alpha1|proteasome subunit iota|testicular secretory protein Li 44', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35278558, end_position_on_the_genomic_accession=35317493, orientation='plus', exon_count=9, OMIM=[602855], no_hdr0=''),
    5688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5688, CurrentID=0, Status='live', Symbol='PSMA7', Aliases=['C6', 'HEL-S-276', 'HSPC', 'RC6-1', 'XAPC7'], description='proteasome 20S subunit alpha 7', other_designations='proteasome subunit alpha type-7|epididymis secretory protein Li 276|proteasome (prosome, macropain) subunit, alpha type, 7|proteasome subunit RC6-1|proteasome subunit XAPC7|proteasome subunit alpha 4|proteasome subunit alpha 7|testicular tissue protein Li 151', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62136733, end_position_on_the_genomic_accession=62143394, orientation='minus', exon_count=7, OMIM=[606607], no_hdr0=''),
    5689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5689, CurrentID=0, Status='live', Symbol='PSMB1', Aliases=['HC5', 'PMSB1', 'PSC5'], description='proteasome 20S subunit beta 1', other_designations='proteasome subunit beta type-1|macropain subunit C5|multicatalytic endopeptidase complex subunit C5|proteasome (prosome, macropain) subunit, beta type, 1|proteasome beta 1 subunit|proteasome component C5|proteasome gamma chain|proteasome subunit HC5|proteasome subunit beta 1|proteasome subunit beta6|testicular secretory protein Li 45', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=170535120, end_position_on_the_genomic_accession=170553307, orientation='minus', exon_count=6, OMIM=[602017], no_hdr0=''),
    5690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5690, CurrentID=0, Status='live', Symbol='PSMB2', Aliases=['HC7-I'], description='proteasome 20S subunit beta 2', other_designations='proteasome subunit beta type-2|macropain subunit C7-I|multicatalytic endopeptidase complex subunit C7-1|multicatalytic endopeptidase complex subunit C7-I|proteasome (prosome, macropain) subunit, beta type, 2|proteasome beta 2 subunit|proteasome component C7-I|proteasome subunit beta 2|proteasome subunit beta4|proteasome subunit, beta type, 2|testicular tissue protein Li 152', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35599541, end_position_on_the_genomic_accession=35641526, orientation='minus', exon_count=7, OMIM=[602175], no_hdr0=''),
    5691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5691, CurrentID=0, Status='live', Symbol='PSMB3', Aliases=['HC10-II'], description='proteasome 20S subunit beta 3', other_designations='proteasome subunit beta type-3|epididymis secretory sperm binding protein|proteasome (prosome, macropain) subunit, beta type, 3|proteasome chain 13|proteasome component C10-II|proteasome subunit beta 3|proteasome theta chain', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38752741, end_position_on_the_genomic_accession=38764225, orientation='plus', exon_count=6, OMIM=[602176], no_hdr0=''),
    5692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5692, CurrentID=0, Status='live', Symbol='PSMB4', Aliases=['HN3', 'HsN3', 'PRAAS3', 'PROS-26', 'PROS26'], description='proteasome 20S subunit beta 4', other_designations='proteasome subunit beta type-4|26 kDa prosomal protein|hsBPROS26|macropain beta chain|multicatalytic endopeptidase complex beta chain|proteasome (prosome, macropain) subunit, beta type, 4|proteasome beta chain|proteasome chain 3|proteasome subunit HsN3|proteasome subunit beta 4|proteasome subunit beta7|proteasome subunit, beta type, 4|testis tissue sperm-binding protein Li 79P', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151399573, end_position_on_the_genomic_accession=151401937, orientation='plus', exon_count=7, OMIM=[602177], no_hdr0=''),
    5693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5693, CurrentID=0, Status='live', Symbol='PSMB5', Aliases=['LMPX', 'MB1', 'X'], description='proteasome 20S subunit beta 5', other_designations='proteasome subunit beta type-5|PSX large multifunctional protease X|macropain epsilon chain|multicatalytic endopeptidase complex epsilon chain|proteasome (prosome, macropain) subunit, beta type, 5|proteasome beta 5 subunit|proteasome catalytic subunit 3|proteasome chain 6|proteasome epsilon chain|proteasome subunit MB1|proteasome subunit X|proteasome subunit beta 5|proteasome subunit, beta type, 5|testicular tissue protein Li 153', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23025851, end_position_on_the_genomic_accession=23035220, orientation='minus', exon_count=5, OMIM=[600306], no_hdr0=''),
    5694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5694, CurrentID=0, Status='live', Symbol='PSMB6', Aliases=['DELTA', 'LMPY', 'Y'], description='proteasome 20S subunit beta 6', other_designations='proteasome subunit beta type-6|PSY large multifunctional protease Y|macropain delta chain|multicatalytic endopeptidase complex delta chain|proteasome (prosome, macropain) subunit, beta type, 6|proteasome catalytic subunit 1|proteasome delta chain|proteasome subunit Y|proteasome subunit beta 6|proteasome subunit beta1|proteasome subunit delta', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4796164, end_position_on_the_genomic_accession=4798495, orientation='plus', exon_count=6, OMIM=[600307], no_hdr0=''),
    5695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5695, CurrentID=0, Status='live', Symbol='PSMB7', Aliases=['Z'], description='proteasome 20S subunit beta 7', other_designations='proteasome subunit beta type-7|epididymis secretory sperm binding protein|macropain chain Z|multicatalytic endopeptidase complex chain Z|proteasome (prosome, macropain) subunit, beta type, 7|proteasome catalytic subunit 2|proteasome subunit Z|proteasome subunit alpha|proteasome subunit beta 7|proteasome subunit beta2|protein serine kinase c17', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124353465, end_position_on_the_genomic_accession=124415442, orientation='minus', exon_count=8, OMIM=[604030], no_hdr0=''),
    5696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5696, CurrentID=0, Status='live', Symbol='PSMB8', Aliases=['ALDD', 'D6S216', 'D6S216E', 'JMP', 'LMP7', 'NKJO', 'PRAAS1', 'PSMB5i', 'RING10'], description='proteasome 20S subunit beta 8', other_designations='proteasome subunit beta type-8|low molecular mass protein 7|low molecular weight protein 7|macropain subunit C13|multicatalytic endopeptidase complex subunit C13|protease component C13|proteasome (prosome, macropain) subunit, beta type, 8 (large multifunctional peptidase 7)|proteasome catalytic subunit 3i|proteasome component C13|proteasome subunit Y2|proteasome subunit beta 5i|proteasome subunit beta 8|proteasome-related gene 7|really interesting new gene 10 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32840717, end_position_on_the_genomic_accession=32844679, orientation='minus', exon_count=7, OMIM=[177046], no_hdr0=''),
    5697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5697, CurrentID=0, Status='live', Symbol='PYY', Aliases=['PYY-I1', 'PYY'], description='peptide YY', other_designations='peptide YY|peptide tyrosine tyrosine|prepro-PYY', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43952733, end_position_on_the_genomic_accession=44004445, orientation='minus', exon_count=7, OMIM=[600781], no_hdr0=''),
    5698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5698, CurrentID=0, Status='live', Symbol='PSMB9', Aliases=['LMP2', 'PRAAS3', 'PSMB6i', 'RING12', 'beta1i'], description='proteasome 20S subunit beta 9', other_designations='proteasome subunit beta type-9|large multifunctional peptidase 2|low molecular mass protein 2|macropain chain 7|multicatalytic endopeptidase complex chain 7|proteasome (prosome, macropain) subunit, beta type, 9 (large multifunctional peptidase 2)|proteasome catalytic subunit 1i|proteasome chain 7|proteasome subunit beta 6i|proteasome subunit beta 9|proteasome subunit beta-1i|proteasome subunit beta1i|proteasome-related gene 2|really interesting new gene 12 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32854192, end_position_on_the_genomic_accession=32859851, orientation='plus', exon_count=6, OMIM=[177045], no_hdr0=''),
    5699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5699, CurrentID=0, Status='live', Symbol='PSMB10', Aliases=['LMP10', 'MECL1', 'PRAAS5', 'beta2i'], description='proteasome 20S subunit beta 10', other_designations='proteasome subunit beta type-10|low molecular mass protein 10|macropain subunit MECl-1|multicatalytic endopeptidase complex subunit MECl-1|proteasome (prosome, macropain) subunit, beta type, 10|proteasome MECl-1|proteasome catalytic subunit 2i|proteasome subunit MECL1|proteasome subunit beta 10|proteasome subunit beta 7i|proteasome subunit beta-2i|proteasome subunit beta2i', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67934506, end_position_on_the_genomic_accession=67936850, orientation='minus', exon_count=8, OMIM=[176847], no_hdr0=''),
    5700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5700, CurrentID=0, Status='live', Symbol='PSMC1', Aliases=['P26S4', 'RPT2', 'S4', 'p56'], description='proteasome 26S subunit, ATPase 1', other_designations='26S proteasome regulatory subunit 4|26S protease regulatory subunit 4|26S proteasome AAA-ATPase subunit RPT2|proteasome (prosome, macropain) 26S subunit, ATPase, 1|proteasome 26S ATPase subunit 1', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90256553, end_position_on_the_genomic_accession=90275429, orientation='plus', exon_count=13, OMIM=[602706], no_hdr0=''),
    5701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5701, CurrentID=0, Status='live', Symbol='PSMC2', Aliases=['MSS1', 'Nbla10058', 'RPT1', 'S7'], description='proteasome 26S subunit, ATPase 2', other_designations='26S proteasome regulatory subunit 7|26S protease regulatory subunit 7|26S proteasome AAA-ATPase subunit RPT1|mammalian suppressor of sgv-1 of yeast|protease 26S subunit 7|proteasome (prosome, macropain) 26S subunit, ATPase, 2|putative protein product of Nbla10058|testis secretory sperm-binding protein Li 197a', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103344405, end_position_on_the_genomic_accession=103369395, orientation='plus', exon_count=12, OMIM=[154365], no_hdr0=''),
    5702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5702, CurrentID=0, Status='live', Symbol='PSMC3', Aliases=['DCIDP', 'RPT5', 'TBP1'], description='proteasome 26S subunit, ATPase 3', other_designations='26S proteasome regulatory subunit 6A|26S protease regulatory subunit 6A|26S proteasome AAA-ATPase subunit RPT5|Tat-binding protein 1|human immunodeficiency virus tat transactivator binding protein-1|proteasome (prosome, macropain) 26S subunit, ATPase, 3|proteasome subunit P50|testicular secretory protein Li 42', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47418775, end_position_on_the_genomic_accession=47426473, orientation='minus', exon_count=11, OMIM=[186852], no_hdr0=''),
    5704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5704, CurrentID=0, Status='live', Symbol='PSMC4', Aliases=['MIP224', 'RPT3', 'S6', 'TBP-7', 'TBP7'], description='proteasome 26S subunit, ATPase 4', other_designations='26S proteasome regulatory subunit 6B|26S protease regulatory subunit 6B|26S proteasome AAA-ATPase subunit RPT3|MB67-interacting protein|Tat-binding protein 7|protease 26S subunit 6|proteasome (prosome, macropain) 26S subunit, ATPase, 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39971150, end_position_on_the_genomic_accession=39981764, orientation='plus', exon_count=11, OMIM=[602707], no_hdr0=''),
    5705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5705, CurrentID=0, Status='live', Symbol='PSMC5', Aliases=['RPT6', 'S8', 'SUG-1', 'SUG1', 'TBP10', 'TRIP1', 'p45', 'p45/SUG'], description='proteasome 26S subunit, ATPase 5', other_designations='26S proteasome regulatory subunit 8|26S protease regulatory subunit 8|26S proteasome AAA-ATPase subunit RPT6|MSUG1 protein|Tat-binding protein homolog 10|proteasome (prosome, macropain) 26S subunit, ATPase, 5|proteasome 26S ATPase subunit 5|proteasome subunit p45|testicular tissue protein Li 149|thyroid hormone receptor-interacting protein 1|thyroid receptor interactor 1', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63827431, end_position_on_the_genomic_accession=63832019, orientation='plus', exon_count=13, OMIM=[601681], no_hdr0=''),
    5706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5706, CurrentID=0, Status='live', Symbol='PSMC6', Aliases=['RPT5', 'SUG2', 'p42'], description='proteasome 26S subunit, ATPase 6', other_designations='26S proteasome regulatory subunit 10B|26S proteasome AAA-ATPase subunit RPT4|proteasome (prosome, macropain) 26S subunit, ATPase, 6|proteasome subunit p42', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52707163, end_position_on_the_genomic_accession=52728590, orientation='plus', exon_count=15, OMIM=[602708], no_hdr0=''),
    5707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5707, CurrentID=0, Status='live', Symbol='PSMD1', Aliases=['P112', 'Rpn2', 'S1'], description='proteasome 26S subunit, non-ATPase 1', other_designations='26S proteasome non-ATPase regulatory subunit 1|26S proteasome regulatory subunit RPN2|26S proteasome regulatory subunit S1|26S proteasome subunit p112|proteasome (prosome, macropain) 26S subunit, non-ATPase, 1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231056867, end_position_on_the_genomic_accession=231172827, orientation='plus', exon_count=27, OMIM=[617842], no_hdr0=''),
    5708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5708, CurrentID=0, Status='live', Symbol='PSMD2', Aliases=['P97', 'RPN1', 'S2', 'TRAP2'], description='proteasome 26S subunit ubiquitin receptor, non-ATPase 2', other_designations='26S proteasome non-ATPase regulatory subunit 2|55.11 protein|TNFR-associated protein 2|proteasome (prosome, macropain) 26S subunit, non-ATPase, 2|proteasome 26S subunit, non-ATPase 2|protein 55.11|tumor necrosis factor type 1 receptor-associated protein 2', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184299241, end_position_on_the_genomic_accession=184309050, orientation='plus', exon_count=22, OMIM=[606223], no_hdr0=''),
    5709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5709, CurrentID=0, Status='live', Symbol='PSMD3', Aliases=['P58', 'RPN3', 'S3', 'TSTA2'], description='proteasome 26S subunit, non-ATPase 3', other_designations='26S proteasome non-ATPase regulatory subunit 3|26S proteasome regulatory subunit RPN3|26S proteasome regulatory subunit S3|proteasome (prosome, macropain) 26S subunit, non-ATPase, 3|proteasome subunit p58|tissue specific transplantation antigen 2', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39980807, end_position_on_the_genomic_accession=39997959, orientation='plus', exon_count=12, OMIM=[617676], no_hdr0=''),
    5710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5710, CurrentID=0, Status='live', Symbol='PSMD4', Aliases=['AF', 'AF-1', 'ASF', 'MCB1', 'Rpn10', 'S5A', 'pUB-R5'], description='proteasome 26S subunit ubiquitin receptor, non-ATPase 4', other_designations='26S proteasome non-ATPase regulatory subunit 4|26S proteasome regulatory subunit S5A|S5a/antisecretory factor protein|angiocidin|antisecretory factor 1|multiubiquitin chain-binding protein|proteasome (prosome, macropain) 26S subunit, non-ATPase, 4|proteasome 26S subunit, non-ATPase 4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151254734, end_position_on_the_genomic_accession=151267479, orientation='plus', exon_count=10, OMIM=[601648], no_hdr0=''),
    5711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5711, CurrentID=0, Status='live', Symbol='PSMD5', Aliases=['S5B'], description='proteasome 26S subunit, non-ATPase 5', other_designations='26S proteasome non-ATPase regulatory subunit 5|26S protease subunit S5 basic|26S proteasome subunit S5B|proteasome (prosome, macropain) 26S subunit, non-ATPase, 5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120816053, end_position_on_the_genomic_accession=120842922, orientation='minus', exon_count=10, OMIM=[604452], no_hdr0=''),
    5713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5713, CurrentID=0, Status='live', Symbol='PSMD7', Aliases=['MOV34', 'P40', 'Rpn8', 'S12'], description='proteasome 26S subunit, non-ATPase 7', other_designations='26S proteasome non-ATPase regulatory subunit 7|26S proteasome regulatory subunit S12|26S proteasome regulatory subunit rpn8|Moloney leukemia virus-34 proviral integration|Mov34 homolog|proteasome (prosome, macropain) 26S subunit, non-ATPase, 7 (Mov34 homolog)|proteasome subunit p40', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74296814, end_position_on_the_genomic_accession=74306288, orientation='plus', exon_count=7, OMIM=[157970], no_hdr0=''),
    5714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5714, CurrentID=0, Status='live', Symbol='PSMD8', Aliases=['HEL-S-91n', 'HIP6', 'HYPF', 'Nin1p', 'Rpn12', 'S14', 'p31'], description='proteasome 26S subunit, non-ATPase 8', other_designations='26S proteasome non-ATPase regulatory subunit 8|26S proteasome regulatory subunit RPN12|26S proteasome regulatory subunit S14|26S proteasome regulatory subunit p31|epididymis secretory sperm binding protein Li 91n|proteasome (prosome, macropain) 26S subunit, non-ATPase, 8', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38374571, end_position_on_the_genomic_accession=38383824, orientation='plus', exon_count=7, OMIM=[617844], no_hdr0=''),
    5715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5715, CurrentID=0, Status='live', Symbol='PSMD9', Aliases=['Rpn4', 'p27'], description='proteasome 26S subunit, non-ATPase 9', other_designations='26S proteasome non-ATPase regulatory subunit 9|26S proteasome regulatory subunit p27|homolog of rat Bridge 1|proteasome (prosome, macropain) 26S subunit, non-ATPase, 9|proteasome 26S non-ATPase regulatory subunit 9', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121888790, end_position_on_the_genomic_accession=121918297, orientation='plus', exon_count=6, OMIM=[603146], no_hdr0=''),
    5716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5716, CurrentID=0, Status='live', Symbol='PSMD10', Aliases=['dJ889N15.2', 'p28', 'p28(GANK)'], description='proteasome 26S subunit, non-ATPase 10', other_designations='26S proteasome non-ATPase regulatory subunit 10|26S proteasome regulatory subunit p28|ankyrin repeat protein|gankyrin|hepatocellular carcinoma-associated protein p28-II|proteasome (prosome, macropain) 26S subunit, non-ATPase, 10', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108084207, end_position_on_the_genomic_accession=108091542, orientation='minus', exon_count=5, OMIM=[300880], no_hdr0=''),
    5717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5717, CurrentID=0, Status='live', Symbol='PSMD11', Aliases=['Rpn6', 'S9', 'p44.5'], description='proteasome 26S subunit, non-ATPase 11', other_designations='26S proteasome non-ATPase regulatory subunit 11|26S proteasome regulatory subunit 9|26S proteasome regulatory subunit RPN6|26S proteasome regulatory subunit S9|26S proteasome regulatory subunit p44.5|proteasome (prosome, macropain) 26S subunit, non-ATPase, 11', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32444510, end_position_on_the_genomic_accession=32483319, orientation='plus', exon_count=14, OMIM=[604449], no_hdr0=''),
    5718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5718, CurrentID=0, Status='live', Symbol='PSMD12', Aliases=['Rpn5', 'STISS', 'p55'], description='proteasome 26S subunit, non-ATPase 12', other_designations='26S proteasome non-ATPase regulatory subunit 12|26S proteasome regulatory subunit RPN5|26S proteasome regulatory subunit p55|proteasome (prosome, macropain) 26S subunit, non-ATPase, 12', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67337916, end_position_on_the_genomic_accession=67366598, orientation='minus', exon_count=12, OMIM=[604450], no_hdr0=''),
    5719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5719, CurrentID=0, Status='live', Symbol='PSMD13', Aliases=['HSPC027', 'Rpn9', 'S11', 'p40.5'], description='proteasome 26S subunit, non-ATPase 13', other_designations='26S proteasome non-ATPase regulatory subunit 13|26S proteasome regulatory subunit RPN9|26S proteasome regulatory subunit S11|26S proteasome regulatory subunit p40.5|26S proteasome subunit p40.5|proteasome (prosome, macropain) 26S subunit, non-ATPase, 13', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=236972, end_position_on_the_genomic_accession=252984, orientation='plus', exon_count=13, OMIM=[603481], no_hdr0=''),
    5720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5720, CurrentID=0, Status='live', Symbol='PSME1', Aliases=['HEL-S-129m', 'IFI5111', 'PA28A', 'PA28alpha', 'REGalpha'], description='proteasome activator subunit 1', other_designations='proteasome activator complex subunit 1|11S regulator complex subunit alpha|29-kD MCP activator subunit|IGUP I-5111|activator of multicatalytic protease subunit 1|epididymis secretory sperm binding protein Li 129m|interferon gamma up-regulated I-5111 protein|interferon-gamma IEF SSP 5111|interferon-gamma-inducible protein 5111|proteasome (prosome, macropain) activator subunit 1 (PA28 alpha)', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24136194, end_position_on_the_genomic_accession=24138962, orientation='plus', exon_count=11, OMIM=[600654], no_hdr0=''),
    5721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5721, CurrentID=0, Status='live', Symbol='PSME2', Aliases=['PA28B', 'PA28beta', 'REGbeta'], description='proteasome activator subunit 2', other_designations='proteasome activator complex subunit 2|11S regulator complex beta subunit|11S regulator complex subunit beta|MCP activator, 31-kD subunit|REG-beta|activator of multicatalytic protease subunit 2|cell migration-inducing protein 22|proteasome (prosome, macropain) activator subunit 2 (PA28 beta)|proteasome activator 28 subunit beta|proteasome activator 28-beta|proteasome activator hPA28 subunit beta', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24143365, end_position_on_the_genomic_accession=24146646, orientation='minus', exon_count=11, OMIM=[602161], no_hdr0=''),
    5723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5723, CurrentID=0, Status='live', Symbol='PSPH', Aliases=['PSPD', 'PSPH'], description='phosphoserine phosphatase', other_designations='phosphoserine phosphatase|L-3-phosphoserine phosphatase|O-phosphoserine phosphohydrolase|PSPase', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56010487, end_position_on_the_genomic_accession=56051604, orientation='minus', exon_count=12, OMIM=[172480], no_hdr0=''),
    5724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5724, CurrentID=0, Status='live', Symbol='PTAFR', Aliases=['PAFR'], description='platelet activating factor receptor', other_designations='platelet-activating factor receptor|PAF-R', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28147166, end_position_on_the_genomic_accession=28193856, orientation='minus', exon_count=4, OMIM=[173393], no_hdr0=''),
    5725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5725, CurrentID=0, Status='live', Symbol='PTBP1', Aliases=['HNRNP-I', 'HNRNPI', 'HNRPI', 'PTB', 'PTB-1', 'PTB-T', 'PTB2', 'PTB3', 'PTB4', 'pPTB'], description='polypyrimidine tract binding protein 1', other_designations='polypyrimidine tract-binding protein 1|57 kDa RNA-binding protein PPTB-1|RNA-binding protein|heterogeneous nuclear ribonucleoprotein I|heterogeneous nuclear ribonucleoprotein polypeptide I|hnRNP I|polypyrimidine tract binding protein (heterogeneous nuclear ribonucleoprotein I)', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=797452, end_position_on_the_genomic_accession=812316, orientation='plus', exon_count=16, OMIM=[600693], no_hdr0=''),
    5726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5726, CurrentID=0, Status='live', Symbol='TAS2R38', Aliases=['PTC', 'T2R38', 'T2R61', 'THIOT'], description='taste 2 receptor member 38', other_designations='taste receptor type 2 member 38|PTC bitter taste receptor|taste receptor type 2 member 61|taste receptor, type 2, member 38', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141972631, end_position_on_the_genomic_accession=141973773, orientation='minus', exon_count=1, OMIM=[607751], no_hdr0=''),
    5727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5727, CurrentID=0, Status='live', Symbol='PTCH1', Aliases=['BCNS', 'NBCCS', 'PTC', 'PTC1', 'PTCH'], description='patched 1', other_designations='protein patched homolog 1', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=95442980, end_position_on_the_genomic_accession=95516971, orientation='minus', exon_count=28, OMIM=[601309], no_hdr0=''),
    5728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5728, CurrentID=0, Status='live', Symbol='PTEN', Aliases=['10q23del', 'BZS', 'CWS1', 'DEC', 'GLM2', 'MHAM', 'MMAC11', 'PTENbeta', 'TEP1', 'PTEN'], description='phosphatase and tensin homolog', other_designations='phosphatidylinositol 3,4,5-trisphosphate 3-phosphatase and dual-specificity protein phosphatase PTEN|MMAC1 phosphatase and tensin homolog deleted on chromosome 10|PTENepsilon|mitochondrial PTENalpha|mitochondrial phosphatase and tensin protein alpha|mutated in multiple advanced cancers 1|phosphatase and tensin-like protein|phosphatidylinositol-3,4,5-trisphosphate 3-phosphatase and dual-specificity protein phosphatase PTEN|protein tyrosine phosphatase', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87863625, end_position_on_the_genomic_accession=87971930, orientation='plus', exon_count=10, OMIM=[601728], no_hdr0=''),
    5729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5729, CurrentID=0, Status='live', Symbol='PTGDR', Aliases=['AS1', 'ASRT1', 'DP', 'DP11', 'PTGDR'], description='prostaglandin D2 receptor', other_designations='prostaglandin D2 receptor|PGD2 receptor', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52267256, end_position_on_the_genomic_accession=52276724, orientation='plus', exon_count=4, OMIM=[604687], no_hdr0=''),
    5730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5730, CurrentID=0, Status='live', Symbol='PTGDS', Aliases=['L-PGDS', 'LPGDS', 'PDS', 'PGD2', 'PGDS', 'PGDS2'], description='prostaglandin D2 synthase', other_designations='prostaglandin-H2 D-isomerase|PGD2 synthase|beta-trace protein|cerebrin-28|glutathione-independent PGD synthase|glutathione-independent PGD synthetase|lipocalin-type prostaglandin D synthase|prostaglandin D synthase|prostaglandin D2 synthase 21kDa (brain)|testis tissue sperm-binding protein Li 63n', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136977504, end_position_on_the_genomic_accession=136981742, orientation='plus', exon_count=7, OMIM=[176803], no_hdr0=''),
    5731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5731, CurrentID=0, Status='live', Symbol='PTGER1', Aliases=['EP1'], description='prostaglandin E receptor 1', other_designations='prostaglandin E2 receptor EP1 subtype|PGE receptor, EP1 subtype|PGE2 receptor EP1 subtype|prostaglandin E receptor 1 (subtype EP1), 42kD|prostaglandin E receptor 1 (subtype EP1), 42kDa|prostaglandin E receptor 1, subtype EP1|prostanoid EP1 receptor', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14472466, end_position_on_the_genomic_accession=14475354, orientation='minus', exon_count=3, OMIM=[176802], no_hdr0=''),
    5732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5732, CurrentID=0, Status='live', Symbol='PTGER2', Aliases=['EP2'], description='prostaglandin E receptor 2', other_designations='prostaglandin E2 receptor EP2 subtype|PGE receptor EP2 subtype|PGE2 receptor EP2 subtype|prostaglandin E receptor 2 (subtype EP2), 53kD|prostaglandin E receptor 2 (subtype EP2), 53kDa|prostanoid EP2 receptor', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52314312, end_position_on_the_genomic_accession=52328598, orientation='plus', exon_count=2, OMIM=[176804], no_hdr0=''),
    5733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5733, CurrentID=0, Status='live', Symbol='PTGER3', Aliases=['EP3', 'EP3-I', 'EP3-II', 'EP3-III', 'EP3-IV', 'EP3-VI', 'EP3e', 'PGE2-R', 'lnc003875'], description='prostaglandin E receptor 3', other_designations='prostaglandin E2 receptor EP3 subtype|PGE receptor, EP3 subtype|PGE2 receptor EP3 subtype|prostaglandin E receptor 3 (subtype EP3)|prostaglandin receptor (PGE-2)|prostanoid EP3 receptor', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=70852358, end_position_on_the_genomic_accession=71047816, orientation='minus', exon_count=10, OMIM=[176806], no_hdr0=''),
    5734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5734, CurrentID=0, Status='live', Symbol='PTGER4', Aliases=['EP4', 'EP4R'], description='prostaglandin E receptor 4', other_designations='prostaglandin E2 receptor EP4 subtype|PGE receptor, EP4 subtype|PGE2 receptor EP4 subtype|prostaglandin E receptor 4 (subtype EP4)|prostanoid EP4 receptor', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40679915, end_position_on_the_genomic_accession=40740936, orientation='plus', exon_count=7, OMIM=[601586], no_hdr0=''),
    5737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5737, CurrentID=0, Status='live', Symbol='PTGFR', Aliases=['FP'], description='prostaglandin F receptor', other_designations='prostaglandin F2-alpha receptor|FP prostanoid receptor|PGF receptor|PGF2 alpha receptor|prostaglandin receptor (2-alpha)|prostanoid FP receptor', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=78490974, end_position_on_the_genomic_accession=78540701, orientation='plus', exon_count=7, OMIM=[600563], no_hdr0=''),
    5738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5738, CurrentID=0, Status='live', Symbol='PTGFRN', Aliases=['CD315', 'CD9P-1', 'EWI-F', 'FPRP', 'SMAP-6'], description='prostaglandin F2 receptor inhibitor', other_designations='prostaglandin F2 receptor negative regulator|CD9 partner 1|glu-Trp-Ile EWI motif-containing protein F|prostaglandin F2-alpha receptor regulatory protein|prostaglandin F2-alpha receptor-associated protein', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116909916, end_position_on_the_genomic_accession=116990358, orientation='plus', exon_count=10, OMIM=[601204], no_hdr0=''),
    5739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5739, CurrentID=0, Status='live', Symbol='PTGIR', Aliases=['IP', 'PRIPR'], description='prostaglandin I2 receptor', other_designations='prostacyclin receptor|PGI receptor|PGI2 receptor|prostaglandin I2 (prostacyclin) receptor (IP)|prostanoid IP receptor', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46610040, end_position_on_the_genomic_accession=46625097, orientation='minus', exon_count=6, OMIM=[600022], no_hdr0=''),
    5740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5740, CurrentID=0, Status='live', Symbol='PTGIS', Aliases=['CYP8', 'CYP8A1', 'PGIS', 'PTGI'], description='prostaglandin I2 synthase', other_designations='prostacyclin synthase|cytochrome P450, family 8, subfamily A, polypeptide 1|hydroperoxy icosatetraenoate dehydratase|prostaglandin I2 (prostacyclin) synthase', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49503874, end_position_on_the_genomic_accession=49568137, orientation='minus', exon_count=10, OMIM=[601699], no_hdr0=''),
    5741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5741, CurrentID=0, Status='live', Symbol='PTH', Aliases=['FIH11', 'PTH'], description='parathyroid hormone', other_designations='parathyroid hormone|parathormone|parathyrin|parathyroid hormone 1|prepro-PTH|preproparathyroid hormone', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13492054, end_position_on_the_genomic_accession=13496181, orientation='minus', exon_count=4, OMIM=[168450], no_hdr0=''),
    5742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5742, CurrentID=0, Status='live', Symbol='PTGS1', Aliases=['COX1', 'COX3', 'PCOX1', 'PES-1', 'PGG/HS', 'PGHS-1', 'PGHS1', 'PHS1', 'PTGHS'], description='prostaglandin-endoperoxide synthase 1', other_designations='prostaglandin G/H synthase 1|PGH synthase 1|cyclooxygenase-1|prostaglandin H2 synthase 1|prostaglandin-endoperoxide synthase 1 (prostaglandin G/H synthase and cyclooxygenase)', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122369906, end_position_on_the_genomic_accession=122395703, orientation='plus', exon_count=15, OMIM=[176805], no_hdr0=''),
    5743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5743, CurrentID=0, Status='live', Symbol='PTGS2', Aliases=['COX-2', 'COX2', 'GRIPGHS', 'PGG/HS', 'PGHS-2', 'PHS-2', 'hCox-2'], description='prostaglandin-endoperoxide synthase 2', other_designations='prostaglandin G/H synthase 2|PGH synthase 2|PHS II|cyclooxygenase 2|cyclooxygenase 2b|prostaglandin H2 synthase 2|prostaglandin-endoperoxide synthase 2 (prostaglandin G/H synthase and cyclooxygenase)', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186671791, end_position_on_the_genomic_accession=186680423, orientation='minus', exon_count=10, OMIM=[600262], no_hdr0=''),
    5744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5744, CurrentID=0, Status='live', Symbol='PTHLH', Aliases=['BDE2', 'HHM', 'PLP', 'PTHR', 'PTHRP'], description='parathyroid hormone like hormone', other_designations='parathyroid hormone-related protein|PTH-rP|PTH-related protein|osteostatin|parathyroid hormone-like hormone preproprotein|parathyroid hormone-like related protein', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27958084, end_position_on_the_genomic_accession=27972864, orientation='minus', exon_count=8, OMIM=[168470], no_hdr0=''),
    5745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5745, CurrentID=0, Status='live', Symbol='PTH1R', Aliases=['EKNS', 'PFE', 'PTHR', 'PTHR1'], description='parathyroid hormone 1 receptor', other_designations='parathyroid hormone/parathyroid hormone-related peptide receptor|PTH/PTHr receptor|PTH/PTHrP type I receptor|PTH1 receptor|parathyroid hormone receptor 1|parathyroid hormone/parathyroid hormone-related protein receptor|seven transmembrane helix receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46877689, end_position_on_the_genomic_accession=46903799, orientation='plus', exon_count=20, OMIM=[168468], no_hdr0=''),
    5746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5746, CurrentID=0, Status='live', Symbol='PTH2R', Aliases=['PTHR2'], description='parathyroid hormone 2 receptor', other_designations='parathyroid hormone 2 receptor|PTH2 receptor|parathyroid hormone receptor 2', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208359692, end_position_on_the_genomic_accession=208494506, orientation='plus', exon_count=18, OMIM=[601469], no_hdr0=''),
    5747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5747, CurrentID=0, Status='live', Symbol='PTK2', Aliases=['FADK', 'FADK 1', 'FAK', 'FAK1', 'FRNK', 'PPP1R71', 'p125FAK', 'pp125FAK'], description='protein tyrosine kinase 2', other_designations='focal adhesion kinase 1|FAK-related non-kinase polypeptide|PTK2 protein tyrosine kinase 2|focal adhesion kinase-related nonkinase|protein phosphatase 1 regulatory subunit 71', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=140657900, end_position_on_the_genomic_accession=141002079, orientation='minus', exon_count=47, OMIM=[600758], no_hdr0=''),
    5753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5753, CurrentID=0, Status='live', Symbol='PTK6', Aliases=['BRK'], description='protein tyrosine kinase 6', other_designations='protein-tyrosine kinase 6|PTK6 protein tyrosine kinase 6|breast tumor kinase|protein-tyrosine kinase BRK|tyrosine-protein kinase BRK', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63528001, end_position_on_the_genomic_accession=63537376, orientation='minus', exon_count=8, OMIM=[602004], no_hdr0=''),
    5754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5754, CurrentID=0, Status='live', Symbol='PTK7', Aliases=['CCK-4', 'CCK4'], description='protein tyrosine kinase 7 (inactive)', other_designations='inactive tyrosine-protein kinase 7|PTK7 protein tyrosine kinase 7|colon carcinoma kinase 4|pseudo tyrosine kinase receptor 7|tyrosine-protein kinase-like 7', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43076314, end_position_on_the_genomic_accession=43161717, orientation='plus', exon_count=21, OMIM=[601890], no_hdr0=''),
    5756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5756, CurrentID=0, Status='live', Symbol='TWF1', Aliases=['A6', 'PTK9'], description='twinfilin actin binding protein 1', other_designations='twinfilin-1|A6 protein tyrosine kinase|PTK9 protein tyrosine kinase 9|protein A6|protein tyrosine kinase 9|twinfilin, actin-binding protein, homolog 1', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=43793723, end_position_on_the_genomic_accession=43806317, orientation='minus', exon_count=11, OMIM=[610932], no_hdr0=''),
    5757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5757, CurrentID=0, Status='live', Symbol='PTMA', Aliases=['TMSA'], description='prothymosin alpha', other_designations='prothymosin alpha|gene sequence 28|prothymosin alpha protein|prothymosin-I+/-', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231708525, end_position_on_the_genomic_accession=231713551, orientation='plus', exon_count=5, OMIM=[188390], no_hdr0=''),
    5763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5763, CurrentID=0, Status='live', Symbol='PTMS', Aliases=['ParaT'], description='parathymosin', other_designations='parathymosin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6766363, end_position_on_the_genomic_accession=6770952, orientation='plus', exon_count=5, OMIM=[168440], no_hdr0=''),
    5764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5764, CurrentID=0, Status='live', Symbol='PTN', Aliases=['HARP', 'HB-GAM', 'HBBM', 'HBGF-8', 'HBGF8', 'HBNF', 'HBNF-1', 'NEGF1', 'OSF-1'], description='pleiotrophin', other_designations='pleiotrophin|heparin affin regulatory protein|heparin-binding brain mitogen|heparin-binding growth factor 8|heparin-binding growth-associated molecule|heparin-binding neurite outgrowth promoting factor|heparin-binding neurite outgrowth-promoting factor 1|osteoblast-specific factor 1|pleiotrophin (heparin binding growth factor 8, neurite growth-promoting factor 1)', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=137227341, end_position_on_the_genomic_accession=137343733, orientation='minus', exon_count=6, OMIM=[162095], no_hdr0=''),
    5768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5768, CurrentID=0, Status='live', Symbol='QSOX1', Aliases=['Q6', 'QSCN6'], description='quiescin sulfhydryl oxidase 1', other_designations='sulfhydryl oxidase 1|quiescin Q6 sulfhydryl oxidase 1|testis tissue sperm-binding protein Li 62n|thiol oxidase 1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180154869, end_position_on_the_genomic_accession=180204030, orientation='plus', exon_count=12, OMIM=[603120], no_hdr0=''),
    5770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5770, CurrentID=0, Status='live', Symbol='PTPN1', Aliases=['PTP1B'], description='protein tyrosine phosphatase non-receptor type 1', other_designations='tyrosine-protein phosphatase non-receptor type 1|protein tyrosine phosphatase, placental|protein-tyrosine phosphatase 1B', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50510383, end_position_on_the_genomic_accession=50585241, orientation='plus', exon_count=10, OMIM=[176885], no_hdr0=''),
    5771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5771, CurrentID=0, Status='live', Symbol='PTPN2', Aliases=['PTN2', 'PTPT', 'TC-PTP', 'TCELLPTP', 'TCPTP'], description='protein tyrosine phosphatase non-receptor type 2', other_designations='tyrosine-protein phosphatase non-receptor type 2|T-cell protein tyrosine phosphatase', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12785478, end_position_on_the_genomic_accession=12884351, orientation='minus', exon_count=16, OMIM=[176887], no_hdr0=''),
    5774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5774, CurrentID=0, Status='live', Symbol='PTPN3', Aliases=['PTP-H1', 'PTPH1'], description='protein tyrosine phosphatase non-receptor type 3', other_designations='tyrosine-protein phosphatase non-receptor type 3|cytoskeletal-associated protein tyrosine phosphatase|protein-tyrosine phosphatase H1', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=109375694, end_position_on_the_genomic_accession=109538395, orientation='minus', exon_count=32, OMIM=[176877], no_hdr0=''),
    5775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5775, CurrentID=0, Status='live', Symbol='PTPN4', Aliases=['MEG', 'PTPMEG', 'PTPMEG1'], description='protein tyrosine phosphatase non-receptor type 4', other_designations='tyrosine-protein phosphatase non-receptor type 4|PTPase-MEG1|megakaryocyte phosphatase|megakaryocyte protein-tyrosine phosphatase|protein tyrosine phosphatase MEG1|protein tyrosine phosphatase, non-receptor type 4 (megakaryocyte)', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119759922, end_position_on_the_genomic_accession=119984899, orientation='plus', exon_count=27, OMIM=[176878], no_hdr0=''),
    5777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5777, CurrentID=0, Status='live', Symbol='PTPN6', Aliases=['HCP', 'HCPH', 'HPTP1C', 'PTP-1C', 'SH-PTP1', 'SHP-1', 'SHP-1L', 'SHP1'], description='protein tyrosine phosphatase non-receptor type 6', other_designations='tyrosine-protein phosphatase non-receptor type 6|hematopoietic cell phosphatase|hematopoietic cell protein-tyrosine phosphatase|protein-tyrosine phosphatase 1C|protein-tyrosine phosphatase SHP-1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6946577, end_position_on_the_genomic_accession=6961316, orientation='plus', exon_count=17, OMIM=[176883], no_hdr0=''),
    5778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5778, CurrentID=0, Status='live', Symbol='PTPN7', Aliases=['BPTP-4', 'HEPTP', 'LC-PTP', 'LPTP', 'PTPNI'], description='protein tyrosine phosphatase non-receptor type 7', other_designations='tyrosine-protein phosphatase non-receptor type 7|dual specificity phosphatase 1|hematopoietic protein-tyrosine phosphatase|protein-tyrosine phosphatase LC-PTP|protein-tyrosine phosphatase, nonreceptor-type, stress induced', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202147012, end_position_on_the_genomic_accession=202161588, orientation='minus', exon_count=13, OMIM=[176889], no_hdr0=''),
    5780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5780, CurrentID=0, Status='live', Symbol='PTPN9', Aliases=['MEG2', 'PTPMEG2'], description='protein tyrosine phosphatase non-receptor type 9', other_designations='tyrosine-protein phosphatase non-receptor type 9|PTPase-MEG2|protein-tyrosine phosphatase MEG2', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75463251, end_position_on_the_genomic_accession=75579315, orientation='minus', exon_count=13, OMIM=[600768], no_hdr0=''),
    5781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5781, CurrentID=0, Status='live', Symbol='PTPN11', Aliases=['BPTP3', 'CFC', 'JMML', 'METCDS', 'NS1', 'PTP-1D', 'PTP2C', 'SH-PTP2', 'SH-PTP3', 'SHP2'], description='protein tyrosine phosphatase non-receptor type 11', other_designations='tyrosine-protein phosphatase non-receptor type 11|SH2 domain-containing protein tyrosine phosphatase 2|protein-tyrosine phosphatase 1D|protein-tyrosine phosphatase 2C', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112418915, end_position_on_the_genomic_accession=112509918, orientation='plus', exon_count=16, OMIM=[176876], no_hdr0=''),
    5782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5782, CurrentID=0, Status='live', Symbol='PTPN12', Aliases=['PTP-PEST', 'PTPG1'], description='protein tyrosine phosphatase non-receptor type 12', other_designations='tyrosine-protein phosphatase non-receptor type 12|protein-tyrosine phosphatase G1', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77537190, end_position_on_the_genomic_accession=77640069, orientation='plus', exon_count=19, OMIM=[600079], no_hdr0=''),
    5783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5783, CurrentID=0, Status='live', Symbol='PTPN13', Aliases=['FAP-1', 'PNP1', 'PTP-BAS', 'PTP-BL', 'PTP1E', 'PTPL1', 'PTPLE', 'hPTP1E'], description='protein tyrosine phosphatase non-receptor type 13', other_designations='tyrosine-protein phosphatase non-receptor type 13|fas-associated protein-tyrosine phosphatase 1|hPTPE1|protein tyrosine phosphatase, non-receptor type 13 (APO-1/CD95 (Fas)-associated phosphatase)|protein-tyrosine phosphatase 1E|protein-tyrosine phosphatase PTPL1', map_location='4q21.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=86594307, end_position_on_the_genomic_accession=86815172, orientation='plus', exon_count=48, OMIM=[600267], no_hdr0=''),
    5784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5784, CurrentID=0, Status='live', Symbol='PTPN14', Aliases=['CATLPH', 'PEZ', 'PTP36', 'PTPD2'], description='protein tyrosine phosphatase non-receptor type 14', other_designations='tyrosine-protein phosphatase non-receptor type 14|cytoskeletal-associated protein tyrosine phosphatase|protein-tyrosine phosphatase pez', map_location='1q32.3-q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=214348700, end_position_on_the_genomic_accession=214551677, orientation='minus', exon_count=21, OMIM=[603155], no_hdr0=''),
    5786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5786, CurrentID=0, Status='live', Symbol='PTPRA', Aliases=['HEPTP', 'HLPR', 'HPTPA', 'HPTPalpha', 'LRP', 'PTPA', 'PTPRL2', 'R-PTP-alpha', 'RPTPA'], description='protein tyrosine phosphatase receptor type A', other_designations='receptor-type tyrosine-protein phosphatase alpha|Leukocyte common antigen-related peptide (protein tyrosine phosphate)|PTPLCA-related phosphatase|PTPase-alpha|protein tyrosine phosphatase, receptor type, alpha polypeptide|protein-tyrosine phosphatase alpha|tyrosine phosphatase alpha', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2864184, end_position_on_the_genomic_accession=3038669, orientation='plus', exon_count=34, OMIM=[176884], no_hdr0=''),
    5787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5787, CurrentID=0, Status='live', Symbol='PTPRB', Aliases=['HPTP-BETA', 'HPTPB', 'PTPB', 'R-PTP-BETA', 'VEPTP'], description='protein tyrosine phosphatase receptor type B', other_designations='receptor-type tyrosine-protein phosphatase beta|VE-PTP|protein tyrosine phosphatase, receptor type, beta polypeptide|vascular endothelial protein tyrosine phosphatase', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=70515870, end_position_on_the_genomic_accession=70637440, orientation='minus', exon_count=37, OMIM=[176882], no_hdr0=''),
    5788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5788, CurrentID=0, Status='live', Symbol='PTPRC', Aliases=['B220', 'CD45', 'CD45R', 'GP180', 'L-CA', 'LCA', 'LY5', 'T200'], description='protein tyrosine phosphatase receptor type C', other_designations='receptor-type tyrosine-protein phosphatase C|CD45 antigen|T200 glycoprotein|T200 leukocyte common antigen|protein tyrosine phosphatase, receptor type, c polypeptide', map_location='1q31.3-q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=198639025, end_position_on_the_genomic_accession=198757476, orientation='plus', exon_count=34, OMIM=[151460], no_hdr0=''),
    5789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5789, CurrentID=0, Status='live', Symbol='PTPRD', Aliases=['HPTP', 'HPTPD', 'HPTPDELTA', 'PTPD', 'R-PTP-delta', 'RPTPDELTA'], description='protein tyrosine phosphatase receptor type D', other_designations='receptor-type tyrosine-protein phosphatase delta|protein tyrosine phosphatase, receptor type, delta polypeptide|rceptor-type tyrosine-protein phosphatase delta', map_location='9p24.1-p23', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=8314246, end_position_on_the_genomic_accession=10613002, orientation='minus', exon_count=50, OMIM=[601598], no_hdr0=''),
    5790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5790, CurrentID=0, Status='live', Symbol='PTPRCAP', Aliases=['CD45-AP', 'LPAP'], description='protein tyrosine phosphatase receptor type C associated protein', other_designations='protein tyrosine phosphatase receptor type C-associated protein|CD45 associated protein|PTPRC-associated protein|lymphocyte phosphatase-associated phosphoprotein|protein tyrosine phosphatase, receptor type, c polypeptide-associated protein', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67435510, end_position_on_the_genomic_accession=67437682, orientation='minus', exon_count=2, OMIM=[601577], no_hdr0=''),
    5791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5791, CurrentID=0, Status='live', Symbol='PTPRE', Aliases=['HPTPE', 'PTPE', 'R-PTP-EPSILON'], description='protein tyrosine phosphatase receptor type E', other_designations='receptor-type tyrosine-protein phosphatase epsilon|protein tyrosine phosphatase, receptor type, epsilon polypeptide', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=127907053, end_position_on_the_genomic_accession=128085855, orientation='plus', exon_count=27, OMIM=[600926], no_hdr0=''),
    5792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5792, CurrentID=0, Status='live', Symbol='PTPRF', Aliases=['BNAH2', 'LAR'], description='protein tyrosine phosphatase receptor type F', other_designations='receptor-type tyrosine-protein phosphatase F|LCA-homolog|leukocyte antigen-related (LAR) PTP receptor|leukocyte antigen-related tyrosine phosphatase|leukocyte common antigen related|protein tyrosine phosphatase, receptor type, F polypeptide|receptor-linked protein-tyrosine phosphatase LAR', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43522238, end_position_on_the_genomic_accession=43623666, orientation='plus', exon_count=43, OMIM=[179590], no_hdr0=''),
    5793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5793, CurrentID=0, Status='live', Symbol='PTPRG', Aliases=['HPTPG', 'PTPG', 'R-PTP-GAMMA', 'RPTPG'], description='protein tyrosine phosphatase receptor type G', other_designations='receptor-type tyrosine-protein phosphatase gamma|H_RG317H01.1|protein tyrosine phosphatase gamma|protein tyrosine phosphatase, receptor type, gamma polypeptide|receptor type protein tyrosine phosphatase gamma|receptor tyrosine phosphatase gamma|receptor-type protein phosphatase gamma', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=61561571, end_position_on_the_genomic_accession=62297609, orientation='plus', exon_count=33, OMIM=[176886], no_hdr0=''),
    5794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5794, CurrentID=0, Status='live', Symbol='PTPRH', Aliases=['R-PTP-H', 'SAP1'], description='protein tyrosine phosphatase receptor type H', other_designations='receptor-type tyrosine-protein phosphatase H|stomach cancer-associated protein tyrosine phosphatase 1|transmembrane-type protein-tyrosine phosphatase type H', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55181247, end_position_on_the_genomic_accession=55209506, orientation='minus', exon_count=23, OMIM=[602510], no_hdr0=''),
    5795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5795, CurrentID=0, Status='live', Symbol='PTPRJ', Aliases=['CD148', 'DEP1', 'HPTPeta', 'R-PTP-ETA', 'SCC1'], description='protein tyrosine phosphatase receptor type J', other_designations='receptor-type tyrosine-protein phosphatase eta|CD148 antigen|DEP-1|HPTP eta|R-PTP-J|density-enhanced phosphatase 1|human density enhanced phosphatase-1|protein tyrosine phosphatase, receptor type, J polypeptide|protein-tyrosine phosphatase eta|susceptibility to colon cancer 1, mouse, homolog of', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47980504, end_position_on_the_genomic_accession=48170839, orientation='plus', exon_count=27, OMIM=[600925], no_hdr0=''),
    5796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5796, CurrentID=0, Status='live', Symbol='PTPRK', Aliases=['R-PTP-kappa'], description='protein tyrosine phosphatase receptor type K', other_designations='receptor-type tyrosine-protein phosphatase kappa|dJ480J14.2.1 (protein tyrosine phosphatase, receptor type, K (R-PTP-KAPPA, protein tyrosine phosphatase kappa , protein tyrosine phosphatase kappa|protein-tyrosine phosphatase kappa|protein-tyrosine phosphatase, receptor type, kappa', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127968785, end_position_on_the_genomic_accession=128520603, orientation='minus', exon_count=40, OMIM=[602545], no_hdr0=''),
    5797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5797, CurrentID=0, Status='live', Symbol='PTPRM', Aliases=['PTPRL1', 'R-PTP-MU', 'RPTPM', 'RPTPU', 'hR-PTPu'], description='protein tyrosine phosphatase receptor type M', other_designations='receptor-type tyrosine-protein phosphatase mu|protein tyrosine phosphatase mu|protein tyrosine phosphatase, receptor type, mu polypeptide', map_location='18p11.23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=7567316, end_position_on_the_genomic_accession=8406859, orientation='plus', exon_count=41, OMIM=[176888], no_hdr0=''),
    5798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5798, CurrentID=0, Status='live', Symbol='PTPRN', Aliases=['IA-2', 'IA-2/PTP', 'IA2', 'ICA512', 'R-PTP-N'], description='protein tyrosine phosphatase receptor type N', other_designations='receptor-type tyrosine-protein phosphatase-like N|ICA 512|PTP IA-2|insulinoma-associated tyrosine-phosphatase-like protein|islet cell antigen 2|islet cell antigen 512|islet cell autoantigen 3|protein tyrosine phosphatase-like N', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219289623, end_position_on_the_genomic_accession=219309401, orientation='minus', exon_count=24, OMIM=[601773], no_hdr0=''),
    5799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5799, CurrentID=0, Status='live', Symbol='PTPRN2', Aliases=['IA-2beta', 'IAR', 'ICAAR', 'PTPRP', 'R-PTP-N2'], description='protein tyrosine phosphatase receptor type N2', other_designations='receptor-type tyrosine-protein phosphatase N2|IAR/receptor-like protein-tyrosine phosphatase|islet cell autoantigen-related protein|phogrin|protein tyrosine phosphatase receptor pi|protein tyrosine phosphatase, receptor type, N polypeptide 2|tyrosine phosphatase IA-2 beta', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=157539056, end_position_on_the_genomic_accession=158587823, orientation='minus', exon_count=29, OMIM=[601698], no_hdr0=''),
    5800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5800, CurrentID=0, Status='live', Symbol='PTPRO', Aliases=['GLEPP1', 'NPHS6', 'PTP-OC', 'PTP-U2T', 'PTPU2', 'R-PTP-O', 'PTPRO'], description='protein tyrosine phosphatase receptor type O', other_designations='receptor-type tyrosine-protein phosphatase O|PTP phi|PTPase U2|glomerular epithelial protein 1|osteoclastic transmembrane protein-tyrosine phosphatase|phosphotyrosine phosphatase U2|protein tyrosine phosphatase PTP-U2', map_location='12p13-p12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=15322334, end_position_on_the_genomic_accession=15598331, orientation='plus', exon_count=28, OMIM=[600579], no_hdr0=''),
    5801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5801, CurrentID=0, Status='live', Symbol='PTPRR', Aliases=['EC-PTP', 'PCPTP1', 'PTP-SL', 'PTPBR7', 'PTPRQ'], description='protein tyrosine phosphatase receptor type R', other_designations='receptor-type tyrosine-protein phosphatase R|Ch-1 PTPase|NC-PTPCOM1|R-PTP-R|ch-1PTPase|protein tyrosine phosphatase Cr1PTPase|protein-tyrosine phosphatase NC-PTPCOM1|protein-tyrosine phosphatase PCPTP1', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=70638073, end_position_on_the_genomic_accession=70920738, orientation='minus', exon_count=18, OMIM=[602853], no_hdr0=''),
    5802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5802, CurrentID=0, Status='live', Symbol='PTPRS', Aliases=['PTPSIGMA', 'R-PTP-S', 'R-PTP-sigma'], description='protein tyrosine phosphatase receptor type S', other_designations='receptor-type tyrosine-protein phosphatase S|protein tyrosine phosphatase PTPsigma|receptor-type tyrosine-protein phosphatase sigma', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5205503, end_position_on_the_genomic_accession=5340812, orientation='minus', exon_count=41, OMIM=[601576], no_hdr0=''),
    5803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5803, CurrentID=0, Status='live', Symbol='PTPRZ1', Aliases=['HPTPZ', 'HPTPzeta', 'PTP-ZETA', 'PTP18', 'PTPRZ', 'PTPZ', 'R-PTP-zeta-2', 'RPTPB', 'RPTPbeta', 'phosphacan'], description='protein tyrosine phosphatase receptor type Z1', other_designations='receptor-type tyrosine-protein phosphatase zeta|protein tyrosine phosphatase, receptor-type, Z polypeptide 1|protein tyrosine phosphatase, receptor-type, zeta polypeptide 1|protein-tyrosine phosphatase receptor type Z polypeptide 2|receptor-type tyrosine phosphatase beta/zeta', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=121873161, end_position_on_the_genomic_accession=122062036, orientation='plus', exon_count=31, OMIM=[176891], no_hdr0=''),
    5804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5804, CurrentID=0, Status='live', Symbol='PTPRZ2', Aliases=['HTPZP2', 'PTPRZ'], description='protein tyrosine phosphatase receptor type Z2', other_designations='protein tyrosine phosphatase receptor type Z2|protein tyrosine phosphatase, receptor-type, Z polypeptide 2|protein tyrosine phosphatase, receptor-type, zeta polypeptide 2', map_location='1p36.3', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604008], no_hdr0=''),
    5805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5805, CurrentID=0, Status='live', Symbol='PTS', Aliases=['PTPS'], description='6-pyruvoyltetrahydropterin synthase', other_designations='6-pyruvoyl tetrahydrobiopterin synthase|PTP synthase|truncated 6-pyruvoyltetrahydropterin synthase', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112226428, end_position_on_the_genomic_accession=112233973, orientation='plus', exon_count=6, OMIM=[612719], no_hdr0=''),
    5806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5806, CurrentID=0, Status='live', Symbol='PTX3', Aliases=['TNFAIP5', 'TSG-14'], description='pentraxin 3', other_designations='pentraxin-related protein PTX3|TNF alpha-induced protein 5|long pentraxin 3|tumor necrosis factor alpha-induced protein 5|tumor necrosis factor-inducible gene 14 protein|tumor necrosis factor-inducible protein TSG-14', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=157436850, end_position_on_the_genomic_accession=157443633, orientation='plus', exon_count=3, OMIM=[602492], no_hdr0=''),
    5810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5810, CurrentID=0, Status='live', Symbol='RAD1', Aliases=['HRAD1', 'REC1'], description='RAD1 checkpoint DNA exonuclease', other_designations='cell cycle checkpoint protein RAD1|DNA repair exonuclease REC1|DNA repair exonuclease rad1 homolog|RAD1 checkpoint clamp component|RAD1 homolog|cell cycle checkpoint protein Hrad1|checkpoint control protein HRAD1|exonuclease homolog RAD1|rad1-like DNA damage checkpoint protein', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34905260, end_position_on_the_genomic_accession=34915504, orientation='minus', exon_count=6, OMIM=[603153], no_hdr0=''),
    5813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5813, CurrentID=0, Status='live', Symbol='PURA', Aliases=['MRD31', 'PUR-ALPHA', 'PUR1LPHA', 'PURA'], description='purine rich element binding protein A', other_designations='transcriptional activator protein Pur-alpha|purine-rich single-stranded DNA-binding protein alpha', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140114109, end_position_on_the_genomic_accession=140125619, orientation='plus', exon_count=1, OMIM=[600473], no_hdr0=''),
    5814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5814, CurrentID=0, Status='live', Symbol='PURB', Aliases=['PURBETA'], description='purine rich element binding protein B', other_designations='transcriptional activator protein Pur-beta', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44876299, end_position_on_the_genomic_accession=44885530, orientation='minus', exon_count=1, OMIM=[608887], no_hdr0=''),
    5816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5816, CurrentID=0, Status='live', Symbol='PVALB', Aliases=['D22S749'], description='parvalbumin', other_designations='parvalbumin alpha', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36800703, end_position_on_the_genomic_accession=36819499, orientation='minus', exon_count=5, OMIM=[168890], no_hdr0=''),
    5817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5817, CurrentID=0, Status='live', Symbol='PVR', Aliases=['CD155', 'HVED', 'NECL5', 'Necl-5', 'PVS', 'TAGE4'], description='PVR cell adhesion molecule', other_designations='poliovirus receptor|nectin-like protein 5', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44643910, end_position_on_the_genomic_accession=44666162, orientation='plus', exon_count=8, OMIM=[173850], no_hdr0=''),
    5818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5818, CurrentID=0, Status='live', Symbol='NECTIN1', Aliases=['CD111', 'CLPED1', 'ED4', 'HIgR', 'HV1S', 'HVEC', 'OFC7', 'PRR', 'PRR1', 'PVRL1', 'PVRR', 'PVRR1', 'SK-12', 'nectin-1'], description='nectin cell adhesion molecule 1', other_designations='nectin-1|ectodermal dysplasia 4 (Margarita Island type)|herpes simplex virus type 1 sensitivity|herpes virus entry mediator C|herpesvirus Ig-like receptor|nectin 1|poliovirus receptor-like 1|poliovirus receptor-related 1 (herpesvirus entry mediator C)|poliovirus receptor-related protein 1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119638098, end_position_on_the_genomic_accession=119729200, orientation='minus', exon_count=10, OMIM=[600644], no_hdr0=''),
    5819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5819, CurrentID=0, Status='live', Symbol='NECTIN2', Aliases=['CD112', 'HVEB', 'PRR2', 'PVRL2', 'PVRR2'], description='nectin cell adhesion molecule 2', other_designations='nectin-2|herpesvirus entry protein B|poliovirus receptor-like 2|poliovirus receptor-related 2 (herpesvirus entry mediator B)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44846297, end_position_on_the_genomic_accession=44889223, orientation='plus', exon_count=10, OMIM=[600798], no_hdr0=''),
    5822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5822, CurrentID=0, Status='live', Symbol='PWP2', Aliases=['EHOC-17H', 'UTP1', 'PWP2'], description='PWP2 small subunit processome component', other_designations='periodic tryptophan protein 2 homolog|PWP2 periodic tryptophan protein homolog|PWP2, UTPB SSU processome subunit', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44107323, end_position_on_the_genomic_accession=44131181, orientation='plus', exon_count=22, OMIM=[601475], no_hdr0=''),
    5824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5824, CurrentID=0, Status='live', Symbol='PEX19', Aliases=['D1S2223E', 'HK33', 'PBD12A', 'PMP1', 'PMPI', 'PXF', 'PXMP1'], description='peroxisomal biogenesis factor 19', other_designations='peroxisomal biogenesis factor 19|33 kDa housekeeping protein|housekeeping gene, 33kD|peroxin-19|peroxisomal farnesylated protein', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160276807, end_position_on_the_genomic_accession=160285151, orientation='minus', exon_count=8, OMIM=[600279], no_hdr0=''),
    5825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5825, CurrentID=0, Status='live', Symbol='ABCD3', Aliases=['ABC43', 'CBAS5', 'PMP70', 'PXMP1', 'ZWS2'], description='ATP binding cassette subfamily D member 3', other_designations='ATP-binding cassette sub-family D member 3|70 kDa peroxisomal membrane protein|ATP-binding cassette, sub-family D (ALD), member 3|Peroxisomal membrane protein-1 (70kD)|dJ824O18.1 (ATP-binding cassette, sub-family D (ALD), member 3 (PMP70, PXMP1))|peroxisomal membrane protein 1 (70kD, Zellweger syndrome)|peroxisomal membrane protein 70 kDa', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94418086, end_position_on_the_genomic_accession=94518663, orientation='plus', exon_count=26, OMIM=[170995], no_hdr0=''),
    5826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5826, CurrentID=0, Status='live', Symbol='ABCD4', Aliases=['ABC41', 'EST352188', 'MAHCJ', 'P70R', 'P79R', 'PMP69', 'PXMP1L'], description='ATP binding cassette subfamily D member 4', other_designations='lysosomal cobalamin transporter ABCD4|69 kDa peroxisomal ABC-transporter|ATP-binding cassette sub-family D member 4|ATP-binding cassette, sub-family D (ALD), member 4|PMP70-related protein|PXMP1-L|peroxisomal membrane protein 69', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74285269, end_position_on_the_genomic_accession=74303062, orientation='minus', exon_count=20, OMIM=[603214], no_hdr0=''),
    5827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5827, CurrentID=0, Status='live', Symbol='PXMP2', Aliases=['MPV17L3', 'PMP22'], description='peroxisomal membrane protein 2', other_designations='peroxisomal membrane protein 2|22 kDa peroxisomal membrane protein|peroxisomal membrane protein 2, 22kDa', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132687587, end_position_on_the_genomic_accession=132704985, orientation='plus', exon_count=5, OMIM=[617399], no_hdr0=''),
    5828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5828, CurrentID=0, Status='live', Symbol='PEX2', Aliases=['PAF1', 'PBD5A', 'PBD5B', 'PMP3', 'PMP35', 'PXMP3', 'RNF72', 'ZWS3'], description='peroxisomal biogenesis factor 2', other_designations='peroxisome biogenesis factor 2|35 kDa peroxisomal membrane protein|RING finger protein 72|peroxisomal membrane protein 3, 35kDa|peroxisome assembly factor 1', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=76980258, end_position_on_the_genomic_accession=77001044, orientation='minus', exon_count=5, OMIM=[170993], no_hdr0=''),
    5829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5829, CurrentID=0, Status='live', Symbol='PXN', Aliases=[], description='paxillin', other_designations='paxillin|testicular tissue protein Li 134', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120210447, end_position_on_the_genomic_accession=120265737, orientation='minus', exon_count=21, OMIM=[602505], no_hdr0=''),
    5830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5830, CurrentID=0, Status='live', Symbol='PEX5', Aliases=['PBD2A', 'PBD2B', 'PTS1-BP', 'PTS1R', 'PXR1', 'RCDP5'], description='peroxisomal biogenesis factor 5', other_designations='peroxisomal biogenesis factor 5|PTS1 receptor|peroxin-5|peroxisomal C-terminal targeting signal import receptor|peroxisomal import receptor 5|peroxisomal targeting signal 1 (SKL type) receptor|peroxisomal targeting signal 1 receptor|peroxisomal targeting signal import receptor|peroxisomal targeting signal receptor 1|peroxisome receptor 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7188653, end_position_on_the_genomic_accession=7218574, orientation='plus', exon_count=23, OMIM=[600414], no_hdr0=''),
    5831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5831, CurrentID=0, Status='live', Symbol='PYCR1', Aliases=['ARCL2B', 'ARCL3B', 'P5C', 'P5CR', 'PIG45', 'PP222', 'PRO3', 'PYCR'], description='pyrroline-5-carboxylate reductase 1', other_designations='pyrroline-5-carboxylate reductase 1, mitochondrial|P5C reductase 1|proliferation-inducing protein 45', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81932391, end_position_on_the_genomic_accession=81937300, orientation='minus', exon_count=10, OMIM=[179035], no_hdr0=''),
    5832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5832, CurrentID=0, Status='live', Symbol='ALDH18A1', Aliases=['ADCL3', 'ARCL3A', 'GSAS', 'P5CS', 'PYCS', 'SPG9', 'SPG9A', 'SPG9B'], description='aldehyde dehydrogenase 18 family member A1', other_designations='delta-1-pyrroline-5-carboxylate synthase|Spastic paraplegia-9 (spastic paraparesis with amyotrophy, cataracts and gastroesophageal reflux)|aldehyde dehydrogenase family 18 member A1|delta-1-pyrroline-5-carboxylate synthetase|delta1-pyrroline-5-carboxlate synthetase|pyrroline-5-carboxylate synthetase (glutamate gamma-semialdehyde synthetase)|spastic paraplegia 9 (autosomal dominant)', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95605938, end_position_on_the_genomic_accession=95656901, orientation='minus', exon_count=17, OMIM=[138250], no_hdr0=''),
    5833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5833, CurrentID=0, Status='live', Symbol='PCYT2', Aliases=['ET', 'SPG82'], description='phosphate cytidylyltransferase 2, ethanolamine', other_designations='ethanolamine-phosphate cytidylyltransferase|CTP:phosphoethanolamine cytidylyltransferase|phosphorylethanolamine transferase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81900958, end_position_on_the_genomic_accession=81911432, orientation='minus', exon_count=15, OMIM=[602679], no_hdr0=''),
    5834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5834, CurrentID=0, Status='live', Symbol='PYGB', Aliases=['GPBB'], description='glycogen phosphorylase B', other_designations='glycogen phosphorylase, brain form|phosphorylase, glycogen; brain', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25248039, end_position_on_the_genomic_accession=25298012, orientation='plus', exon_count=20, OMIM=[138550], no_hdr0=''),
    5836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5836, CurrentID=0, Status='live', Symbol='PYGL', Aliases=['GSD6'], description='glycogen phosphorylase L', other_designations='glycogen phosphorylase, liver form|phosphorylase, glycogen, liver', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50905217, end_position_on_the_genomic_accession=50944483, orientation='minus', exon_count=20, OMIM=[613741], no_hdr0=''),
    5837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5837, CurrentID=0, Status='live', Symbol='PYGM', Aliases=['GSD5'], description='glycogen phosphorylase, muscle associated', other_designations='glycogen phosphorylase, muscle form|myophosphorylase|phosphorylase, glycogen, muscle', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64746389, end_position_on_the_genomic_accession=64760715, orientation='minus', exon_count=20, OMIM=[608455], no_hdr0=''),
    5858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5858, CurrentID=0, Status='live', Symbol='PZP', Aliases=['CPAMD6'], description='PZP alpha-2-macroglobulin like', other_designations='pregnancy zone protein|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 6|Pregnancy zone protein|pregnancy-zone protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9140730, end_position_on_the_genomic_accession=9208395, orientation='minus', exon_count=38, OMIM=[176420], no_hdr0=''),
    5859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5859, CurrentID=0, Status='live', Symbol='QARS1', Aliases=['GLNRS', 'MSCCA', 'PRO2195', 'QARS'], description='glutaminyl-tRNA synthetase 1', other_designations='glutamine--tRNA ligase|glutamine-tRNA synthetase', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49095932, end_position_on_the_genomic_accession=49104758, orientation='minus', exon_count=24, OMIM=[603727], no_hdr0=''),
    5860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5860, CurrentID=0, Status='live', Symbol='QDPR', Aliases=['DHPR', 'HDHPR', 'PKU2', 'SDR33C1'], description='quinoid dihydropteridine reductase', other_designations='dihydropteridine reductase|6,7-dihydropteridine reductase|short chain dehydrogenase/reductase family 33C member 1|testis secretory sperm-binding protein Li 236P', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17486395, end_position_on_the_genomic_accession=17512090, orientation='minus', exon_count=7, OMIM=[612676], no_hdr0=''),
    5861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5861, CurrentID=0, Status='live', Symbol='RAB1A', Aliases=['RAB1', 'YPT1'], description='RAB1A, member RAS oncogene family', other_designations='ras-related protein Rab-1A|GTP binding protein Rab1a|RAB1, member RAS oncogene family|Rab GTPase YPT1 homolog|YPT1-related protein', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=65086854, end_position_on_the_genomic_accession=65130132, orientation='minus', exon_count=6, OMIM=[179508], no_hdr0=''),
    5862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5862, CurrentID=0, Status='live', Symbol='RAB2A', Aliases=['LHX', 'RAB2'], description='RAB2A, member RAS oncogene family', other_designations='ras-related protein Rab-2A|RAB2, member RAS oncogene family|small GTP binding protein RAB2A', map_location='8q12.1-q12.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=60516910, end_position_on_the_genomic_accession=60623644, orientation='plus', exon_count=8, OMIM=[179509], no_hdr0=''),
    5863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5863, CurrentID=0, Status='live', Symbol='RGL2', Aliases=['HKE1.5', 'KE1.5', 'RAB2L'], description='ral guanine nucleotide dissociation stimulator like 2', other_designations='ral guanine nucleotide dissociation stimulator-like 2|GDS-related protein|ralGDS-like 2|ralGDS-like factor|ras-associated protein RAB2L', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33291654, end_position_on_the_genomic_accession=33299365, orientation='minus', exon_count=17, OMIM=[602306], no_hdr0=''),
    5864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5864, CurrentID=0, Status='live', Symbol='RAB3A', Aliases=[], description='RAB3A, member RAS oncogene family', other_designations='ras-related protein Rab-3A|RAS-associated protein RAB3A', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18196784, end_position_on_the_genomic_accession=18204042, orientation='minus', exon_count=6, OMIM=[179490], no_hdr0=''),
    5865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5865, CurrentID=0, Status='live', Symbol='RAB3B', Aliases=[], description='RAB3B, member RAS oncogene family', other_designations='ras-related protein Rab-3B|brain antigen RAB3B', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51907956, end_position_on_the_genomic_accession=51990700, orientation='minus', exon_count=6, OMIM=[179510], no_hdr0=''),
    5866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5866, CurrentID=0, Status='live', Symbol='RAB3IL1', Aliases=['GRAB'], description='RAB3A interacting protein like 1', other_designations='guanine nucleotide exchange factor for Rab-3A|RAB3A interacting protein (rabin3)-like 1|rab3A-interacting-like protein 1|rabin3-like 1', map_location='11q12.2-q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61897299, end_position_on_the_genomic_accession=61946312, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    5867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5867, CurrentID=0, Status='live', Symbol='RAB4A', Aliases=['HRES-1', 'HRES-1/RAB4', 'HRES1', 'RAB4'], description='RAB4A, member RAS oncogene family', other_designations='ras-related protein Rab-4A|HTLV-1 related endogenous sequence', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229271111, end_position_on_the_genomic_accession=229305894, orientation='plus', exon_count=8, OMIM=[179511], no_hdr0=''),
    5868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5868, CurrentID=0, Status='live', Symbol='RAB5A', Aliases=['RAB5'], description='RAB5A, member RAS oncogene family', other_designations='ras-related protein Rab-5A|RAS-associated protein RAB5A', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=19947097, end_position_on_the_genomic_accession=19985175, orientation='plus', exon_count=6, OMIM=[179512], no_hdr0=''),
    5869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5869, CurrentID=0, Status='live', Symbol='RAB5B', Aliases=[], description='RAB5B, member RAS oncogene family', other_designations='ras-related protein Rab-5B', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55973949, end_position_on_the_genomic_accession=55996683, orientation='plus', exon_count=8, OMIM=[179514], no_hdr0=''),
    5870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5870, CurrentID=0, Status='live', Symbol='RAB6A', Aliases=['RAB6'], description='RAB6A, member RAS oncogene family', other_designations='ras-related protein Rab-6A|RAB6, member RAS oncogene family|Rab GTPase', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73675638, end_position_on_the_genomic_accession=73761074, orientation='minus', exon_count=10, OMIM=[179513], no_hdr0=''),
    5871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5871, CurrentID=0, Status='live', Symbol='MAP4K2', Aliases=['BL44', 'GCK', 'RAB8IP'], description='mitogen-activated protein kinase kinase kinase kinase 2', other_designations='mitogen-activated protein kinase kinase kinase kinase 2|B lymphocyte serine/threonine protein kinase|MAPK/ERK kinase kinase kinase 2|MEK kinase kinase 2|MEKKK 2|Rab8 interacting protein|germinal centre kinase (GC kinase)', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64784918, end_position_on_the_genomic_accession=64803248, orientation='minus', exon_count=32, OMIM=[603166], no_hdr0=''),
    5872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5872, CurrentID=0, Status='live', Symbol='RAB13', Aliases=['GIG4'], description='RAB13, member RAS oncogene family', other_designations='ras-related protein Rab-13|RAS-associated protein RAB13|cell growth-inhibiting gene 4 protein|growth-inhibiting gene 4 protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153981650, end_position_on_the_genomic_accession=153990644, orientation='minus', exon_count=10, OMIM=[602672], no_hdr0=''),
    5873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5873, CurrentID=0, Status='live', Symbol='RAB27A', Aliases=['GS2', 'HsT18676', 'RAB27', 'RAM'], description='RAB27A, member RAS oncogene family', other_designations='ras-related protein Rab-27A|GTP-binding protein Ram|mutant Ras-related protein Rab-27A|rab-27', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55202966, end_position_on_the_genomic_accession=55291338, orientation='minus', exon_count=12, OMIM=[603868], no_hdr0=''),
    5874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5874, CurrentID=0, Status='live', Symbol='RAB27B', Aliases=['C25KG'], description='RAB27B, member RAS oncogene family', other_designations='ras-related protein Rab-27B', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54717842, end_position_on_the_genomic_accession=54895516, orientation='plus', exon_count=11, OMIM=[603869], no_hdr0=''),
    5875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5875, CurrentID=0, Status='live', Symbol='RABGGTA', Aliases=['PTAR3'], description='Rab geranylgeranyltransferase subunit alpha', other_designations='geranylgeranyl transferase type-2 subunit alpha|Rab GG transferase alpha|Rab GGTase alpha|Rab geranylgeranyltransferase alpha subunit|geranylgeranyl transferase type II subunit alpha|protein prenyltransferase alpha subunit repeat containing 3|rab geranyl-geranyltransferase subunit alpha', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24265538, end_position_on_the_genomic_accession=24271627, orientation='minus', exon_count=17, OMIM=[601905], no_hdr0=''),
    5876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5876, CurrentID=0, Status='live', Symbol='RABGGTB', Aliases=['GGTB'], description='Rab geranylgeranyltransferase subunit beta', other_designations='geranylgeranyl transferase type-2 subunit beta|GGTase-II-beta|Rab geranylgeranyltransferase beta subunit|rab GG transferase beta|rab GGTase beta|type II protein geranyl-geranyltransferase subunit beta', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75786194, end_position_on_the_genomic_accession=75795090, orientation='plus', exon_count=11, OMIM=[179080], no_hdr0=''),
    5877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5877, CurrentID=0, Status='live', Symbol='RABIF', Aliases=['MSS4', 'RASGFR3', 'RASGRF3'], description='RAB interacting factor', other_designations='guanine nucleotide exchange factor MSS4|Ras-specific guanine-releasing factor 3|mammalian suppressor of SEC4|rab-interacting factor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202878282, end_position_on_the_genomic_accession=202889149, orientation='minus', exon_count=2, OMIM=[603417], no_hdr0=''),
    5878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5878, CurrentID=0, Status='live', Symbol='RAB5C', Aliases=['L1880L', 'RAB5L', 'RABL', 'RAB5C'], description='RAB5C, member RAS oncogene family', other_designations='ras-related protein Rab-5C|RAB5C, member of RAS oncogene family', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42124979, end_position_on_the_genomic_accession=42154989, orientation='minus', exon_count=8, OMIM=[604037], no_hdr0=''),
    5879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5879, CurrentID=0, Status='live', Symbol='RAC1', Aliases=['MIG5', 'MRD48', 'Rac-1', 'TC-25', 'p21-Rac1'], description='Rac family small GTPase 1', other_designations='ras-related C3 botulinum toxin substrate 1|cell migration-inducing gene 5 protein|ras-like protein TC25|ras-related C3 botulinum toxin substrate 1 (rho family, small GTP binding protein Rac1)', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6374527, end_position_on_the_genomic_accession=6403967, orientation='plus', exon_count=7, OMIM=[602048], no_hdr0=''),
    5880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5880, CurrentID=0, Status='live', Symbol='RAC2', Aliases=['EN-7', 'Gx', 'HSPC022', 'IMD73A', 'IMD73B', 'IMD73C', 'p21-Rac2'], description='Rac family small GTPase 2', other_designations='ras-related C3 botulinum toxin substrate 2|Ras-related C3 botulinum toxin substrate 3 (rho family, small GTP-binding protein Rac2)|ras-related C3 botulinum toxin substrate 2 (rho family, small GTP binding protein Rac2)|small G protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37225270, end_position_on_the_genomic_accession=37244269, orientation='minus', exon_count=8, OMIM=[602049], no_hdr0=''),
    5881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5881, CurrentID=0, Status='live', Symbol='RAC3', Aliases=[], description='Rac family small GTPase 3', other_designations='ras-related C3 botulinum toxin substrate 3|p21-Rac3|ras-related C3 botulinum toxin substrate 3 (rho family, small GTP binding protein Rac3)|rho family, small GTP binding protein Rac3', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82031678, end_position_on_the_genomic_accession=82034204, orientation='plus', exon_count=6, OMIM=[602050], no_hdr0=''),
    5883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5883, CurrentID=0, Status='live', Symbol='RAD9A', Aliases=['RAD9'], description='RAD9 checkpoint clamp component A', other_designations='cell cycle checkpoint control protein RAD9A|DNA repair exonuclease rad9 homolog A|RAD9 homolog A|hRAD9', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67391976, end_position_on_the_genomic_accession=67398412, orientation='plus', exon_count=11, OMIM=[603761], no_hdr0=''),
    5884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5884, CurrentID=0, Status='live', Symbol='RAD17', Aliases=['CCYC', 'HRAD17', 'R24LSP', 'RAD24', 'RAD17'], description='RAD17 checkpoint clamp loader component', other_designations='cell cycle checkpoint protein RAD17|RAD1 homolog|RAD17 homolog|RF-C activator 1 homolog|Rad17-like protein|cell cycle checkpoint protein (RAD17)', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69369293, end_position_on_the_genomic_accession=69414801, orientation='plus', exon_count=21, OMIM=[603139], no_hdr0=''),
    5885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5885, CurrentID=0, Status='live', Symbol='RAD21', Aliases=['CDLS4', 'HR21', 'HRAD21', 'MCD1', 'MGS', 'NXP1', 'SCC1', 'hHR21'], description='RAD21 cohesin complex component', other_designations='double-strand-break repair protein rad21 homolog|NXP-1|RAD21 homolog|SCC1 homolog|kleisin|nuclear matrix protein 1|protein involved in DNA double-strand break repair|sister chromatid cohesion 1', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=116845934, end_position_on_the_genomic_accession=116874776, orientation='minus', exon_count=14, OMIM=[606462], no_hdr0=''),
    5886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5886, CurrentID=0, Status='live', Symbol='RAD23A', Aliases=['HHR23A', 'HR23A'], description='RAD23 homolog A, nucleotide excision repair protein', other_designations='UV excision repair protein RAD23 homolog A|RAD23, yeast homolog, A', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12945846, end_position_on_the_genomic_accession=12953642, orientation='plus', exon_count=8, OMIM=[600061], no_hdr0=''),
    5887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5887, CurrentID=0, Status='live', Symbol='RAD23B', Aliases=['HHR23B', 'HR23B', 'P58'], description='RAD23 homolog B, nucleotide excision repair protein', other_designations='UV excision repair protein RAD23 homolog B|RAD23, yeast homolog of, B|XP-C repair complementing complex 58 kDa|XP-C repair complementing protein|XP-C repair-complementing complex 58 kDa protein', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=107283279, end_position_on_the_genomic_accession=107332194, orientation='plus', exon_count=12, OMIM=[600062], no_hdr0=''),
    5888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5888, CurrentID=0, Status='live', Symbol='RAD51', Aliases=['BRCC5', 'FANCR', 'HRAD51', 'HsRad51', 'HsT16930', 'MRMV2A', 'RECA', 'RAD51'], description='RAD51 recombinase', other_designations='DNA repair protein RAD51 homolog 1|BRCA1/BRCA2-containing complex, subunit 5|RAD51 homolog A|RecA, E. coli, homolog of|RecA-like protein|recombination protein A', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40694774, end_position_on_the_genomic_accession=40732340, orientation='plus', exon_count=13, OMIM=[179617], no_hdr0=''),
    5889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5889, CurrentID=0, Status='live', Symbol='RAD51C', Aliases=['BROVCA3', 'FANCO', 'R51H3', 'RAD51L2'], description='RAD51 paralog C', other_designations='DNA repair protein RAD51 homolog 3|RAD51-like protein 2|yeast RAD51 homolog 3', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58692140, end_position_on_the_genomic_accession=58735611, orientation='plus', exon_count=12, OMIM=[602774], no_hdr0=''),
    5890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5890, CurrentID=0, Status='live', Symbol='RAD51B', Aliases=['R51H2', 'RAD51L1', 'REC2'], description='RAD51 paralog B', other_designations='DNA repair protein RAD51 homolog 2|RAD51 homolog B|RecA-like protein|recombination repair protein', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67819779, end_position_on_the_genomic_accession=68683096, orientation='plus', exon_count=19, OMIM=[602948], no_hdr0=''),
    5891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5891, CurrentID=0, Status='live', Symbol='MOK', Aliases=['RAGE', 'RAGE-1', 'RAGE1', 'STK30'], description='MOK protein kinase', other_designations='MAPK/MAK/MRK overlapping kinase|renal cell carcinoma antigen|renal tumor antigen 1', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102224441, end_position_on_the_genomic_accession=102305191, orientation='minus', exon_count=23, OMIM=[605762], no_hdr0=''),
    5892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5892, CurrentID=0, Status='live', Symbol='RAD51D', Aliases=['BROVCA4', 'R51H3', 'RAD51L3', 'TRAD'], description='RAD51 paralog D', other_designations='DNA repair protein RAD51 homolog 4|RAD51 homolog D|RAD51-like protein 3|recombination repair protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35092221, end_position_on_the_genomic_accession=35119860, orientation='minus', exon_count=11, OMIM=[602954], no_hdr0=''),
    5893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5893, CurrentID=0, Status='live', Symbol='RAD52', Aliases=[], description='RAD52 homolog, DNA repair protein', other_designations='DNA repair protein RAD52 homolog|recombination protein RAD52|rhabdomyosarcoma antigen MU-RMS-40.23', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=911028, end_position_on_the_genomic_accession=991195, orientation='minus', exon_count=18, OMIM=[600392], no_hdr0=''),
    5894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5894, CurrentID=0, Status='live', Symbol='RAF1', Aliases=['CMD1NN', 'CRAF', 'NS5', 'Raf-1', 'c-Raf'], description='Raf-1 proto-oncogene, serine/threonine kinase', other_designations='RAF proto-oncogene serine/threonine-protein kinase|C-Raf proto-oncogene, serine/threonine kinase|Oncogene RAF1|proto-oncogene c-RAF|raf proto-oncogene serine/threonine protein kinase|v-raf-1 murine leukemia viral oncogene homolog 1|v-raf-1 murine leukemia viral oncogene-like protein 1', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12583601, end_position_on_the_genomic_accession=12664117, orientation='minus', exon_count=22, OMIM=[164760], no_hdr0=''),
    5896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5896, CurrentID=0, Status='live', Symbol='RAG1', Aliases=['RAG-1', 'RNF74'], description='recombination activating 1', other_designations='V(D)J recombination-activating protein 1|RING finger protein 74|recombination activating gene 1|recombination activating protein 1', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36510353, end_position_on_the_genomic_accession=36579762, orientation='plus', exon_count=6, OMIM=[179615], no_hdr0=''),
    5897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5897, CurrentID=0, Status='live', Symbol='RAG2', Aliases=['RAG-2'], description='recombination activating 2', other_designations='V(D)J recombination-activating protein 2|recombination activating gene 2', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36591943, end_position_on_the_genomic_accession=36598236, orientation='minus', exon_count=3, OMIM=[179616], no_hdr0=''),
    5898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5898, CurrentID=0, Status='live', Symbol='RALA', Aliases=['HINCONS', 'RAL'], description='RAS like proto-oncogene A', other_designations='ras-related protein Ral-A|RALA Ras like proto-oncogene A|RAS-like protein A|Ras family small GTP binding protein RALA|ras related GTP binding protein A|v-ral simian leukemia viral oncogene homolog A (ras related)', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=39622955, end_position_on_the_genomic_accession=39708124, orientation='plus', exon_count=8, OMIM=[179550], no_hdr0=''),
    5899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5899, CurrentID=0, Status='live', Symbol='RALB', Aliases=[], description='RAS like proto-oncogene B', other_designations='ras-related protein Ral-B|RALB Ras like proto-oncogene B|RAS-like protein B|ras related GTP binding protein B|v-ral simian leukemia viral oncogene homolog B (ras related; GTP binding protein)', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120252850, end_position_on_the_genomic_accession=120294711, orientation='plus', exon_count=7, OMIM=[179551], no_hdr0=''),
    5900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5900, CurrentID=0, Status='live', Symbol='RALGDS', Aliases=['RGDS', 'RGF', 'RalGEF'], description='ral guanine nucleotide dissociation stimulator', other_designations='ral guanine nucleotide dissociation stimulator|ral guanine nucleotide exchange factor', map_location='9q34.13-q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133097722, end_position_on_the_genomic_accession=133149210, orientation='minus', exon_count=21, OMIM=[601619], no_hdr0=''),
    5901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5901, CurrentID=0, Status='live', Symbol='RAN', Aliases=['ARA24', 'Gsp1', 'TC4'], description='RAN, member RAS oncogene family', other_designations='GTP-binding nuclear protein Ran|GTPase Ran|RanGTPase|androgen receptor-associated protein 24|guanosine triphosphatase Ran|member RAS oncogene family|ras-like protein TC4|ras-related nuclear protein', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130871879, end_position_on_the_genomic_accession=130877678, orientation='plus', exon_count=7, OMIM=[601179], no_hdr0=''),
    5902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5902, CurrentID=0, Status='live', Symbol='RANBP1', Aliases=['HTF9A'], description='RAN binding protein 1', other_designations='ran-specific GTPase-activating protein|HpaII tiny fragments locus 9A|testis secretory sperm-binding protein Li 221n', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20116104, end_position_on_the_genomic_accession=20127355, orientation='plus', exon_count=9, OMIM=[601180], no_hdr0=''),
    5903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5903, CurrentID=0, Status='live', Symbol='RANBP2', Aliases=['ADANE', 'ANE1', 'IIAE3', 'NUP358', 'TRP1', 'TRP2'], description='RAN binding protein 2', other_designations='E3 SUMO-protein ligase RanBP2|358 kDa nucleoporin|E3 SUMO-protein transferase RanBP2|P270|acute necrotizing encephalopathy 1 (autosomal dominant)|nuclear pore complex protein Nup358|nucleoporin 358|nucleoporin Nup358|ran-binding protein 2|transformation-related protein 2', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108719446, end_position_on_the_genomic_accession=108785809, orientation='plus', exon_count=32, OMIM=[601181], no_hdr0=''),
    5905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5905, CurrentID=0, Status='live', Symbol='RANGAP1', Aliases=['Fug1', 'RANGAP', 'SD'], description='Ran GTPase activating protein 1', other_designations='ran GTPase-activating protein 1|segregation distorter homolog', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41244779, end_position_on_the_genomic_accession=41302369, orientation='minus', exon_count=25, OMIM=[602362], no_hdr0=''),
    5906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5906, CurrentID=0, Status='live', Symbol='RAP1A', Aliases=['C21KG', 'G-22K', 'KREV-1', 'KREV1', 'RAP1', 'SMGP21'], description='RAP1A, member of RAS oncogene family', other_designations='ras-related protein Rap-1A|GTP-binding protein smg p21A|Ras-related protein Krev-1', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111542009, end_position_on_the_genomic_accession=111716691, orientation='plus', exon_count=11, OMIM=[179520], no_hdr0=''),
    5908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5908, CurrentID=0, Status='live', Symbol='RAP1B', Aliases=['K-REV', 'RAL1B'], description='RAP1B, member of RAS oncogene family', other_designations='ras-related protein Rap-1b|GTP-binding protein smg p21B|RAS-related protein RAP1B|Ras family small GTP binding protein RAP1B|small GTP binding protein', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68610899, end_position_on_the_genomic_accession=68671901, orientation='plus', exon_count=8, OMIM=[179530], no_hdr0=''),
    5909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5909, CurrentID=0, Status='live', Symbol='RAP1GAP', Aliases=['RAP1GA11', 'RAP1GAPII', 'RAPGAP', 'RAP1GAP'], description='RAP1 GTPase activating protein', other_designations='rap1 GTPase-activating protein 1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21596221, end_position_on_the_genomic_accession=21669413, orientation='minus', exon_count=32, OMIM=[600278], no_hdr0=''),
    5910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5910, CurrentID=0, Status='live', Symbol='RAP1GDS1', Aliases=['GDS1', 'SmgGDS'], description='Rap1 GTPase-GDP dissociation stimulator 1', other_designations='rap1 GTPase-GDP dissociation stimulator 1|RAP1, GTP-GDP dissociation stimulator 1|SMG GDS protein|SMG P21 stimulatory GDP/GTP exchange protein|exchange factor smgGDS', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=98261381, end_position_on_the_genomic_accession=98443858, orientation='plus', exon_count=18, OMIM=[179502], no_hdr0=''),
    5911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5911, CurrentID=0, Status='live', Symbol='RAP2A', Aliases=['K-REV', 'KREV', 'RAP2', 'RbBP-30'], description='RAP2A, member of RAS oncogene family', other_designations='ras-related protein Rap-2a|RAP2, member of RAS oncogene family (K-rev)', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=97434169, end_position_on_the_genomic_accession=97469128, orientation='plus', exon_count=2, OMIM=[179540], no_hdr0=''),
    5912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5912, CurrentID=0, Status='live', Symbol='RAP2B', Aliases=[], description='RAP2B, member of RAS oncogene family', other_designations='ras-related protein Rap-2b|small GTP binding protein', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=153162226, end_position_on_the_genomic_accession=153170627, orientation='plus', exon_count=1, OMIM=[179541], no_hdr0=''),
    5913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5913, CurrentID=0, Status='live', Symbol='RAPSN', Aliases=['CMS11', 'CMS4C', 'FADS', 'FADS2', 'RAPSYN', 'RNF205'], description='receptor associated protein of the synapse', other_designations='43 kDa receptor-associated protein of the synapse|43 kda postsynaptic protein|RING finger protein 205|acetylcholine receptor-associated 43 kda protein', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47437764, end_position_on_the_genomic_accession=47449136, orientation='minus', exon_count=8, OMIM=[601592], no_hdr0=''),
    5914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5914, CurrentID=0, Status='live', Symbol='RARA', Aliases=['NR1B1', 'RAR'], description='retinoic acid receptor alpha', other_designations='retinoic acid receptor alpha|PML-DDX5-RARA fusion|PML-DDX5-RARA fusion protein|RAR-alpha|nuclear receptor subfamily 1 group B member 1|nucleophosmin-retinoic acid receptor alpha fusion protein NPM-RAR long form|retinoic acid nuclear receptor alpha variant 1|retinoic acid nuclear receptor alpha variant 2|retinoic acid receptor, alpha polypeptide', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40309180, end_position_on_the_genomic_accession=40357643, orientation='plus', exon_count=17, OMIM=[180240], no_hdr0=''),
    5915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5915, CurrentID=0, Status='live', Symbol='RARB', Aliases=['HAP', 'MCOPS12', 'NR1B2', 'RARbeta1', 'RRB2'], description='retinoic acid receptor beta', other_designations='retinoic acid receptor beta|HBV-activated protein|RAR-beta|RAR-epsilon|hepatitis B virus activated protein|nuclear receptor subfamily 1 group B member 2|retinoic acid receptor, beta polypeptide', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=24829321, end_position_on_the_genomic_accession=25597932, orientation='plus', exon_count=14, OMIM=[180220], no_hdr0=''),
    5916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5916, CurrentID=0, Status='live', Symbol='RARG', Aliases=['NR1B3', 'RARC'], description='retinoic acid receptor gamma', other_designations='retinoic acid receptor gamma|RAR-gamma|nuclear receptor subfamily 1 group B member 3|retinoic acid nuclear receptor gamma variant 1|retinoic acid nuclear receptor gamma variant 2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53210569, end_position_on_the_genomic_accession=53232231, orientation='minus', exon_count=12, OMIM=[180190], no_hdr0=''),
    5917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5917, CurrentID=0, Status='live', Symbol='RARS1', Aliases=['ArgRS', 'DALRD1', 'HLD9', 'RARS'], description='arginyl-tRNA synthetase 1', other_designations='arginine--tRNA ligase, cytoplasmic|arginine tRNA ligase 1, cytoplasmic|arginyl-tRNA synthetase, cytoplasmic', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=168486471, end_position_on_the_genomic_accession=168519301, orientation='plus', exon_count=15, OMIM=[107820], no_hdr0=''),
    5918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5918, CurrentID=0, Status='live', Symbol='RARRES1', Aliases=['LXNL', 'PERG-1', 'TIG1'], description='retinoic acid receptor responder 1', other_designations='retinoic acid receptor responder protein 1|RAR-responsive protein TIG1|latexin-like|phorbol ester-induced gene 1 protein|retinoic acid receptor responder (tazarotene induced) 1|tazarotene-induced gene 1 protein', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158696892, end_position_on_the_genomic_accession=158732944, orientation='minus', exon_count=6, OMIM=[605090], no_hdr0=''),
    5919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5919, CurrentID=0, Status='live', Symbol='RARRES2', Aliases=['HP10433', 'TIG2'], description='retinoic acid receptor responder 2', other_designations='retinoic acid receptor responder protein 2|RAR-responsive protein TIG2|chemerin|retinoic acid receptor responder (tazarotene induced) 2|tazarotene-induced gene 2 protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150338329, end_position_on_the_genomic_accession=150341685, orientation='minus', exon_count=6, OMIM=[601973], no_hdr0=''),
    5920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5920, CurrentID=0, Status='live', Symbol='PLAAT4', Aliases=['HRASLS4', 'HRSL4', 'PLA1/2-3', 'PLAAT-4', 'RARRES3', 'RIG1', 'TIG3'], description='phospholipase A and acyltransferase 4', other_designations='phospholipase A and acyltransferase 4|HRAS-like suppressor 4|RAR-responsive protein TIG3|phospholipase A/acyltransferase-4|retinoic acid receptor responder (tazarotene induced) 3|retinoic acid receptor responder 3|retinoic acid receptor responder protein 3|retinoic acid-inducible gene 1|retinoid-inducible gene 1 protein|tazarotene-induced gene 3 protein', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63536808, end_position_on_the_genomic_accession=63546458, orientation='plus', exon_count=4, OMIM=[605092], no_hdr0=''),
    5921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5921, CurrentID=0, Status='live', Symbol='RASA1', Aliases=['CM-AVM', 'CMAVM', 'CMAVM1', 'GAP', 'PKWS', 'RASA', 'RASGAP', 'p120', 'p120GAP', 'p120RASGAP'], description='RAS p21 protein activator 1', other_designations='ras GTPase-activating protein 1|RAS p21 protein activator (GTPase activating protein) 1|p120 RAS GTPase activating protein|triphosphatase-activating protein', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=87267845, end_position_on_the_genomic_accession=87391916, orientation='plus', exon_count=26, OMIM=[139150], no_hdr0=''),
    5922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5922, CurrentID=0, Status='live', Symbol='RASA2', Aliases=['GAP1M'], description='RAS p21 protein activator 2', other_designations='ras GTPase-activating protein 2|GTPase-activating protein 1m|GTPase-activating protein of RAS', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141487027, end_position_on_the_genomic_accession=141615344, orientation='plus', exon_count=30, OMIM=[601589], no_hdr0=''),
    5923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5923, CurrentID=0, Status='live', Symbol='RASGRF1', Aliases=['CDC25', 'CDC25L', 'GNRP', 'GRF1', 'GRF55', 'H-GRF55', 'PP13187', 'ras-GRF1'], description='Ras protein specific guanine nucleotide releasing factor 1', other_designations='ras-specific guanine nucleotide-releasing factor 1|CDC25 like|Ras-specific guanine nucleotide-releasing factor, CDC25 homolog|Ras-specific nucleotide exchange factor CDC25|guanine nucleotide exchange factor|guanine nucleotide-releasing factor 1|guanine nucleotide-releasing factor, 55 kD|guanine nucleotide-releasing protein', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78959906, end_position_on_the_genomic_accession=79090780, orientation='minus', exon_count=30, OMIM=[606600], no_hdr0=''),
    5924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5924, CurrentID=0, Status='live', Symbol='RASGRF2', Aliases=['GRF2', 'RAS-GRF2'], description='Ras protein specific guanine nucleotide releasing factor 2', other_designations='ras-specific guanine nucleotide-releasing factor 2|ras guanine nucleotide exchange factor 2', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80960363, end_position_on_the_genomic_accession=81230162, orientation='plus', exon_count=31, OMIM=[606614], no_hdr0=''),
    5925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5925, CurrentID=0, Status='live', Symbol='RB1', Aliases=['OSRC', 'PPP1R130', 'RB', 'p105-Rb', 'p110-RB1', 'pRb', 'pp110'], description='RB transcriptional corepressor 1', other_designations='retinoblastoma-associated protein|GOS563 exon 17 substitution mutation causes premature stop|exon 17 tumor GOS561 substitution mutation causes premature stop|prepro-retinoblastoma-associated protein|protein phosphatase 1, regulatory subunit 130|retinoblastoma 1|retinoblastoma suspectibility protein', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48303751, end_position_on_the_genomic_accession=48481890, orientation='plus', exon_count=28, OMIM=[614041], no_hdr0=''),
    5926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5926, CurrentID=0, Status='live', Symbol='ARID4A', Aliases=['RBBP-1', 'RBBP1', 'RBP-1', 'RBP1'], description='AT-rich interaction domain 4A', other_designations='AT-rich interactive domain-containing protein 4A|ARID domain-containing protein 4A|AT rich interactive domain 4A (RBP1-like)|retinoblastoma-binding protein 1', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58298385, end_position_on_the_genomic_accession=58373876, orientation='plus', exon_count=28, OMIM=[180201], no_hdr0=''),
    5927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5927, CurrentID=0, Status='live', Symbol='KDM5A', Aliases=['RBBP-2', 'RBBP2', 'RBP2'], description='lysine demethylase 5A', other_designations='lysine-specific demethylase 5A|Jumonji, AT rich interactive domain 1A (RBP2-like)|[histone H3]-trimethyl-L-lysine(4) demethylase 5A|histone demethylase JARID1A|jumonji/ARID domain-containing protein 1A|lysine (K)-specific demethylase 5A|retinoblastoma binding protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=280057, end_position_on_the_genomic_accession=389320, orientation='minus', exon_count=28, OMIM=[180202], no_hdr0=''),
    5928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5928, CurrentID=0, Status='live', Symbol='RBBP4', Aliases=['NURF55', 'RBAP48', 'lin-53'], description='RB binding protein 4, chromatin remodeling factor', other_designations='histone-binding protein RBBP4|CAF-1 subunit C|CAF-I 48 kDa subunit|CAF-I p48|MSI1 protein homolog|RBBP-4|chromatin assembly factor 1 subunit C|chromatin assembly factor I p48 subunit|chromatin assembly factor/CAF-1 p48 subunit|nucleosome-remodeling factor subunit RBAP48|retinoblastoma-binding protein 4|retinoblastoma-binding protein p48', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32651208, end_position_on_the_genomic_accession=32686211, orientation='plus', exon_count=13, OMIM=[602923], no_hdr0=''),
    5929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5929, CurrentID=0, Status='live', Symbol='RBBP5', Aliases=['RBQ3', 'SWD1'], description='RB binding protein 5, histone lysine methyltransferase complex subunit', other_designations='retinoblastoma-binding protein 5|RBBP-5|SWD1, Set1c WD40 repeat protein, homolog|retinoblastoma-binding protein RBQ-3', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205086142, end_position_on_the_genomic_accession=205122015, orientation='minus', exon_count=14, OMIM=[600697], no_hdr0=''),
    5930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5930, CurrentID=0, Status='live', Symbol='RBBP6', Aliases=['MY038', 'P2P-R', 'PACT', 'RBQ-1', 'SNAMA'], description='RB binding protein 6, ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase RBBP6|RB-binding Q-protein 1|RING-type E3 ubiquitin transferase RBBP6|p53-associated cellular protein of testis|proliferation potential-related protein|protein P2P-R|retinoblastoma binding protein 6|retinoblastoma-binding Q protein 1', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=24539566, end_position_on_the_genomic_accession=24572863, orientation='plus', exon_count=18, OMIM=[600938], no_hdr0=''),
    5931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5931, CurrentID=0, Status='live', Symbol='RBBP7', Aliases=['RbAp46'], description='RB binding protein 7, chromatin remodeling factor', other_designations='histone-binding protein RBBP7|G1/S transition control protein-binding protein RbAp46|RBBP-7|histone acetyltransferase type B subunit 2|nucleosome-remodeling factor subunit RBAP46|retinoblastoma-binding protein 7|retinoblastoma-binding protein RbAp46|retinoblastoma-binding protein p46', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16844341, end_position_on_the_genomic_accession=16870362, orientation='minus', exon_count=13, OMIM=[300825], no_hdr0=''),
    5932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5932, CurrentID=0, Status='live', Symbol='RBBP8', Aliases=['COM1', 'CTIP', 'JWDS', 'RIM', 'SAE2', 'SCKL2'], description='RB binding protein 8, endonuclease', other_designations='DNA endonuclease RBBP8|CTBP-interacting protein|RBBP-8|retinoblastoma binding protein 8|sporulation in the absence of SPO11 protein 2 homolog', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=22914121, end_position_on_the_genomic_accession=23026486, orientation='plus', exon_count=24, OMIM=[604124], no_hdr0=''),
    5933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5933, CurrentID=0, Status='live', Symbol='RBL1', Aliases=['CP107', 'PRB1', 'p107'], description='RB transcriptional corepressor like 1', other_designations='retinoblastoma-like protein 1|107 kDa retinoblastoma-associated protein|retinoblastoma-like 1', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36996349, end_position_on_the_genomic_accession=37096029, orientation='minus', exon_count=22, OMIM=[116957], no_hdr0=''),
    5934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5934, CurrentID=0, Status='live', Symbol='RBL2', Aliases=['P130', 'Rb2'], description='RB transcriptional corepressor like 2', other_designations='retinoblastoma-like protein 2|130 kDa retinoblastoma-associated protein|PRB2|RBR-2|retinoblastoma-like 2|retinoblastoma-related protein 2', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53434471, end_position_on_the_genomic_accession=53491648, orientation='plus', exon_count=26, OMIM=[180203], no_hdr0=''),
    5935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5935, CurrentID=0, Status='live', Symbol='RBM3', Aliases=['IS1-RNPL', 'RNPL'], description='RNA binding motif protein 3', other_designations='RNA-binding protein 3|RNA binding motif (RNP1, RRM) protein 3', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48574484, end_position_on_the_genomic_accession=48581162, orientation='plus', exon_count=7, OMIM=[300027], no_hdr0=''),
    5936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5936, CurrentID=0, Status='live', Symbol='RBM4', Aliases=['LARKA', 'ZCCHC21', 'ZCRB3A', 'RBM4'], description='RNA binding motif protein 4', other_designations='RNA-binding protein 4|RNA-binding motif protein 4a|lark homolog|transcriptional coactivator CoAZ|zinc finger CCHC-type and RNA binding motif 3A', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66638703, end_position_on_the_genomic_accession=66668380, orientation='plus', exon_count=5, OMIM=[602571], no_hdr0=''),
    5937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5937, CurrentID=0, Status='live', Symbol='RBMS1', Aliases=['C2orf12', 'HCC-4', 'MSSP', 'MSSP-1', 'MSSP-2', 'MSSP-3', 'SCR2', 'YC1'], description='RNA binding motif single stranded interacting protein 1', other_designations='RNA-binding motif, single-stranded-interacting protein 1|c-myc gene single strand binding protein 2|cervical cancer oncogene 4|single-stranded DNA-binding protein MSSP-1|suppressor of CDC2 with RNA-binding motif 2|suppressor of cdc 2 (cdc13) with RNA binding motif 2', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=160272151, end_position_on_the_genomic_accession=160493983, orientation='minus', exon_count=16, OMIM=[602310], no_hdr0=''),
    5939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5939, CurrentID=0, Status='live', Symbol='RBMS2', Aliases=['SCR3'], description='RNA binding motif single stranded interacting protein 2', other_designations='RNA-binding motif, single-stranded-interacting protein 2|suppressor of CDC2 with RNA-binding motif 3', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56520406, end_position_on_the_genomic_accession=56596193, orientation='plus', exon_count=23, OMIM=[602387], no_hdr0=''),
    5940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5940, CurrentID=0, Status='live', Symbol='RBMY1A1', Aliases=['RBM', 'RBM1', 'RBM2', 'RBMY', 'RBMY1C', 'YRRM1', 'YRRM2'], description='RNA binding motif protein Y-linked family 1 member A1', other_designations='RNA-binding motif protein, Y chromosome, family 1 member A1|RNA-binding motif protein 2|RNA-binding motif protein, Y chromosome, family 1 member A1/C|Y chromosome RNA recognition motif 1|Y chromosome RNA recognition motif 2', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=21534879, end_position_on_the_genomic_accession=21559683, orientation='plus', exon_count=13, OMIM=[400006], no_hdr0=''),
    5942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5942, CurrentID=0, Status='live', Symbol='RBMY1C', Aliases=[], description='RNA binding motif protein Y-linked family 1 member C', other_designations='RNA-binding motif protein, Y chromosome, family 1 member C', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    5947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5947, CurrentID=0, Status='live', Symbol='RBP1', Aliases=['CRABP-I', 'CRBP', 'CRBP1', 'CRBPI', 'RBPC'], description='retinol binding protein 1', other_designations='retinol-binding protein 1|cellular retinol binding protein 1|cellular retinol-binding protein I|retinol-binding protein 1, cellular', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139517438, end_position_on_the_genomic_accession=139539742, orientation='minus', exon_count=6, OMIM=[180260], no_hdr0=''),
    5948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5948, CurrentID=0, Status='live', Symbol='RBP2', Aliases=['CRABP-II', 'CRBP2', 'CRBPII', 'RBPC2'], description='retinol binding protein 2', other_designations='retinol-binding protein 2|CRBP-II|cellular retinol-binding protein II|retinol binding protein 2, cellular', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139452884, end_position_on_the_genomic_accession=139476516, orientation='minus', exon_count=4, OMIM=[180280], no_hdr0=''),
    5949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5949, CurrentID=0, Status='live', Symbol='RBP3', Aliases=['D10S64', 'D10S65', 'D10S66', 'IRBP', 'RBPI', 'RP66'], description='retinol binding protein 3', other_designations='retinol-binding protein 3|interphotoreceptor retinoid-binding protein|interstitial retinol binding protein 3|retinol binding protein 3, interstitial', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47348363, end_position_on_the_genomic_accession=47357881, orientation='plus', exon_count=4, OMIM=[180290], no_hdr0=''),
    5950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5950, CurrentID=0, Status='live', Symbol='RBP4', Aliases=['MCOPCB10', 'RDCCAS'], description='retinol binding protein 4', other_designations='retinol-binding protein 4|PRBP|RBP|plasma retinol-binding protein|retinol binding protein 4, plasma|retinol-binding protein 4, interstitial', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93591694, end_position_on_the_genomic_accession=93601744, orientation='minus', exon_count=8, OMIM=[180250], no_hdr0=''),
    5954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5954, CurrentID=0, Status='live', Symbol='RCN1', Aliases=['HEL-S-84', 'PIG20', 'RCAL', 'RCN'], description='reticulocalbin 1', other_designations='reticulocalbin-1|epididymis secretory protein Li 84|proliferation-inducing gene 20|reticulocalbin 1, EF-hand calcium binding domain', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32091074, end_position_on_the_genomic_accession=32105722, orientation='plus', exon_count=6, OMIM=[602735], no_hdr0=''),
    5955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5955, CurrentID=0, Status='live', Symbol='RCN2', Aliases=['E6BP', 'ERC-55', 'ERC55', 'TCBP49'], description='reticulocalbin 2', other_designations='reticulocalbin-2|E6-binding protein|calcium-binding protein ERC-55|reticulocalbin 2, EF-hand calcium binding domain (endoplasmic reticulum calcium-binding protein, 55kD)', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76931749, end_position_on_the_genomic_accession=76954393, orientation='plus', exon_count=8, OMIM=[602584], no_hdr0=''),
    5956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5956, CurrentID=0, Status='live', Symbol='OPN1LW', Aliases=['CBBM', 'CBP', 'COD5', 'RCP', 'ROP'], description='opsin 1, long wave sensitive', other_designations='long-wave-sensitive opsin 1|cone dystrophy 5 (X-linked)|opsin 1 (cone pigments), long-wave-sensitive|red cone opsin|red cone photoreceptor pigment|red-sensitive opsin', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154144243, end_position_on_the_genomic_accession=154159032, orientation='plus', exon_count=6, OMIM=[300822], no_hdr0=''),
    5957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5957, CurrentID=0, Status='live', Symbol='RCVRN', Aliases=['RCV1'], description='recoverin', other_designations='recoverin|cancer associated retinopathy antigen|cancer-associated retinopathy protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9896320, end_position_on_the_genomic_accession=9905271, orientation='minus', exon_count=3, OMIM=[179618], no_hdr0=''),
    5959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5959, CurrentID=0, Status='live', Symbol='RDH5', Aliases=['9cRDH', 'HSD17B9', 'RDH1', 'SDR9C5'], description='retinol dehydrogenase 5', other_designations='retinol dehydrogenase 5|11-cis RDH|11-cis RoDH|9-cis retinol dehydrogenase|9-cis-retinol specific dehydrogenase|retinol dehydrogenase 1|retinol dehydrogenase 5 (11-cis and 9-cis)|retinol dehydrogenase 5 (11-cis/9-cis)|short chain dehydrogenase/reductase family 9C member 5', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55720393, end_position_on_the_genomic_accession=55724705, orientation='plus', exon_count=5, OMIM=[601617], no_hdr0=''),
    5961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5961, CurrentID=0, Status='live', Symbol='PRPH2', Aliases=['AOFMD', 'AVMD', 'CACD2', 'DS', 'MDBS1', 'PRPH', 'RDS', 'RP7', 'TSPAN22', 'rd2'], description='peripherin 2', other_designations='peripherin-2|peripherin 2 (retinal degeneration, slow)|peripherin 2, homolog of mouse|peripherin, photoreceptor type|retinal degeneration slow protein|retinal peripherin|tetraspanin-22|tspan-22', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42694509, end_position_on_the_genomic_accession=42723039, orientation='minus', exon_count=5, OMIM=[179605], no_hdr0=''),
    5962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5962, CurrentID=0, Status='live', Symbol='RDX', Aliases=['DFNB24'], description='radixin', other_designations='radixin', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=110174922, end_position_on_the_genomic_accession=110296614, orientation='minus', exon_count=17, OMIM=[179410], no_hdr0=''),
    5965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5965, CurrentID=0, Status='live', Symbol='RECQL', Aliases=['RECQL1', 'RecQ1'], description='RecQ like helicase', other_designations='ATP-dependent DNA helicase Q1|DNA helicase, RecQ-like type 1|DNA-dependent ATPase Q1|RecQ helicase-like|RecQ protein-like (DNA helicase Q1-like)|recQ protein-like 1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21468910, end_position_on_the_genomic_accession=21501635, orientation='minus', exon_count=15, OMIM=[600537], no_hdr0=''),
    5966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5966, CurrentID=0, Status='live', Symbol='REL', Aliases=['C-Rel', 'HIVEN86A'], description='REL proto-oncogene, NF-kB subunit', other_designations='proto-oncogene c-Rel|oncogene REL, avian reticuloendotheliosis|v-rel avian reticuloendotheliosis viral oncogene homolog', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=60881521, end_position_on_the_genomic_accession=60931612, orientation='plus', exon_count=12, OMIM=[164910], no_hdr0=''),
    5967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5967, CurrentID=0, Status='live', Symbol='REG1A', Aliases=['ICRF', 'P19', 'PSP', 'PSPS', 'PSPS1', 'PTP', 'REG'], description='regenerating family member 1 alpha', other_designations='lithostathine-1-alpha|REG-1-alpha|islet cells regeneration factor|islet of langerhans regenerating protein|pancreatic stone protein, secretory|pancreatic thread protein|protein-X|regenerating islet-derived protein 1-alpha|regenerating protein I alpha', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=79120488, end_position_on_the_genomic_accession=79123409, orientation='plus', exon_count=6, OMIM=[167770], no_hdr0=''),
    5968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5968, CurrentID=0, Status='live', Symbol='REG1B', Aliases=['PSPS2', 'REGH', 'REGI-BETA', 'REGL'], description='regenerating family member 1 beta', other_designations='lithostathine-1-beta|PSP-2|REG-1-beta|pancreatic stone protein 2|regenerating islet-derived 1 beta (pancreatic stone protein, pancreatic thread protein)|regenerating islet-derived protein 1-beta|regenerating protein I beta|secretory pancreatic stone protein 2', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=79085023, end_position_on_the_genomic_accession=79087993, orientation='minus', exon_count=6, OMIM=[167771], no_hdr0=''),
    5970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5970, CurrentID=0, Status='live', Symbol='RELA', Aliases=['CMCU', 'NFKB3', 'p65'], description='RELA proto-oncogene, NF-kB subunit', other_designations='transcription factor p65|NF-kappa-B p65delta3|NF-kappa-B transcription factor p65|nuclear factor NF-kappa-B p65 subunit|nuclear factor of kappa light polypeptide gene enhancer in B-cells 3|v-rel avian reticuloendotheliosis viral oncogene homolog A', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65653601, end_position_on_the_genomic_accession=65662946, orientation='minus', exon_count=11, OMIM=[164014], no_hdr0=''),
    5971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5971, CurrentID=0, Status='live', Symbol='RELB', Aliases=['I-REL', 'IMD53', 'IREL', 'REL-B'], description='RELB proto-oncogene, NF-kB subunit', other_designations='transcription factor RelB|v-rel avian reticuloendotheliosis viral oncogene homolog B (nuclear factor of kappa light polypeptide gene enhancer in B-cells 3)|v-rel reticuloendotheliosis viral oncogene homolog B, nuclear factor of kappa light polypeptide gene enhancer in B-cells 3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45001449, end_position_on_the_genomic_accession=45038194, orientation='plus', exon_count=12, OMIM=[604758], no_hdr0=''),
    5972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5972, CurrentID=0, Status='live', Symbol='REN', Aliases=['ADTKD4', 'HNFJ2', 'RTD'], description='renin', other_designations='renin|angiotensin-forming enzyme|angiotensinogenase|renin precursor, renal', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204154819, end_position_on_the_genomic_accession=204166337, orientation='minus', exon_count=10, OMIM=[179820], no_hdr0=''),
    5973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5973, CurrentID=0, Status='live', Symbol='RENBP', Aliases=['RBP', 'RNBP'], description='renin binding protein', other_designations='N-acylglucosamine 2-epimerase|AGE|GlcNAc 2-epimerase|N-acetyl-D-glucosamine 2-epimerase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153935263, end_position_on_the_genomic_accession=153944643, orientation='minus', exon_count=11, OMIM=[312420], no_hdr0=''),
    5976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5976, CurrentID=0, Status='live', Symbol='UPF1', Aliases=['HUPF1', 'NORF1', 'RENT1', 'UTF', 'pNORF1', 'smg-2'], description='UPF1 RNA helicase and ATPase', other_designations='regulator of nonsense transcripts 1|ATP-dependent helicase RENT1|UPF1 regulator of nonsense transcripts homolog|delta helicase|nonsense mRNA reducing factor 1|smg-2 homolog, nonsense mediated mRNA decay factor|up-frameshift mutation 1 homolog|up-frameshift suppressor 1 homolog|yeast Upf1p homolog', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18831405, end_position_on_the_genomic_accession=18868230, orientation='plus', exon_count=24, OMIM=[601430], no_hdr0=''),
    5977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5977, CurrentID=0, Status='live', Symbol='DPF2', Aliases=['CSS7', 'REQ', 'UBID4', 'ubi-d4'], description='double PHD fingers 2', other_designations='zinc finger protein ubi-d4|BAF45D|BRG1-associated factor 45D|D4, zinc and double PHD fingers family 2|apoptosis response zinc finger protein|protein requiem|requiem, apoptosis response zinc finger', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65333840, end_position_on_the_genomic_accession=65354262, orientation='plus', exon_count=12, OMIM=[601671], no_hdr0=''),
    5978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5978, CurrentID=0, Status='live', Symbol='REST', Aliases=['DFNA27', 'GINGF5', 'HGF5', 'NRSF', 'WT6', 'XBR'], description='RE1 silencing transcription factor', other_designations='RE1-silencing transcription factor|neural-restrictive silencer factor|neuron restrictive silencer factor|repressor binding to the X2 box', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56907900, end_position_on_the_genomic_accession=56935847, orientation='plus', exon_count=5, OMIM=[600571], no_hdr0=''),
    5979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5979, CurrentID=0, Status='live', Symbol='RET', Aliases=['CDHF12', 'CDHR16', 'HSCR1', 'MEN2A', 'MEN2B', 'MTC1', 'PTC-ELE1', 'RET'], description='ret proto-oncogene', other_designations='proto-oncogene tyrosine-protein kinase receptor Ret|RET receptor tyrosine kinase|cadherin family member 12|cadherin-related family member 16|proto-oncogene c-Ret|rearranged during transfection|ret proto-oncogene (multiple endocrine neoplasia and medullary thyroid carcinoma 1, Hirschsprung disease)', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43077069, end_position_on_the_genomic_accession=43130351, orientation='plus', exon_count=20, OMIM=[164761], no_hdr0=''),
    5980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5980, CurrentID=0, Status='live', Symbol='REV3L', Aliases=['POLZ', 'REV3'], description='REV3 like, DNA directed polymerase zeta catalytic subunit', other_designations='DNA polymerase zeta catalytic subunit|REV3-like, polymerase (DNA directed), zeta, catalytic subunit|Rev-3, yeast, homolog-like (polymerase, DNA, zeta)', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=111299033, end_position_on_the_genomic_accession=111483711, orientation='minus', exon_count=41, OMIM=[602776], no_hdr0=''),
    5981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5981, CurrentID=0, Status='live', Symbol='RFC1', Aliases=['A1', 'CANVAS', 'MHCBFB', 'PO-GA', 'RECC1', 'RFC40', 'RFC1'], description='replication factor C subunit 1', other_designations='replication factor C subunit 1|A1 140 kDa subunit|DNA-binding protein PO-GA|MHC binding factor, beta|RF-C 140 kDa subunit|activator 1 140 kDa subunit|activator 1 large subunit|activator 1 subunit 1|replication factor C (activator 1) 1, 145kDa|replication factor C 140 kDa subunit|replication factor C large subunit|replication factor C1', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39287456, end_position_on_the_genomic_accession=39366381, orientation='minus', exon_count=25, OMIM=[102579], no_hdr0=''),
    5982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5982, CurrentID=0, Status='live', Symbol='RFC2', Aliases=['RFC40'], description='replication factor C subunit 2', other_designations='replication factor C subunit 2|A1 40 kDa subunit|RF-C 40 kDa subunit|activator 1 subunit 2|replication factor C (activator 1) 2, 40kDa', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74231502, end_position_on_the_genomic_accession=74254452, orientation='minus', exon_count=11, OMIM=[600404], no_hdr0=''),
    5983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5983, CurrentID=0, Status='live', Symbol='RFC3', Aliases=['RFC38'], description='replication factor C subunit 3', other_designations='replication factor C subunit 3|A1 38 kDa subunit|RF-C 38 kDa subunit|RFC, 38 kD subunit|activator 1 38 kDa subunit|activator 1 subunit 3|replication factor C (activator 1) 3, 38kDa|replication factor C 38 kDa subunit', map_location='13q13.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=33818075, end_position_on_the_genomic_accession=33973946, orientation='plus', exon_count=15, OMIM=[600405], no_hdr0=''),
    5984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5984, CurrentID=0, Status='live', Symbol='RFC4', Aliases=['A1', 'RFC37'], description='replication factor C subunit 4', other_designations='replication factor C subunit 4|A1 37 kDa subunit|RF-C 37 kDa subunit|RFC 37 kDa subunit|activator 1 37 kDa subunit|activator 1 subunit 4|replication factor C (activator 1) 4, 37kDa|replication factor C 37 kDa subunit', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186789900, end_position_on_the_genomic_accession=186806482, orientation='minus', exon_count=11, OMIM=[102577], no_hdr0=''),
    5985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5985, CurrentID=0, Status='live', Symbol='RFC5', Aliases=['RFC36'], description='replication factor C subunit 5', other_designations='replication factor C subunit 5|A1 36 kDa subunit|RF-C 36 kDa subunit|RFC, 36.5 kD subunit|replication factor C (activator 1) 5, 36.5kDa|replication factor C, 36-kDa subunit', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118016661, end_position_on_the_genomic_accession=118033564, orientation='plus', exon_count=13, OMIM=[600407], no_hdr0=''),
    5986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5986, CurrentID=0, Status='live', Symbol='RFNG', Aliases=[], description='RFNG O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase', other_designations='beta-1,3-N-acetylglucosaminyltransferase radical fringe|O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase|radical fringe homolog', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82047902, end_position_on_the_genomic_accession=82051811, orientation='minus', exon_count=9, OMIM=[602578], no_hdr0=''),
    5987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5987, CurrentID=0, Status='live', Symbol='TRIM27', Aliases=['RFP', 'RNF76'], description='tripartite motif containing 27', other_designations='zinc finger protein RFP|RFP transforming protein|RING finger protein 76|RING-type E3 ubiquitin transferase TRIM27|ret finger protein|tripartite motif protein TRIM27|tripartite motif-containing protein 27', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28903002, end_position_on_the_genomic_accession=28923985, orientation='minus', exon_count=8, OMIM=[602165], no_hdr0=''),
    5988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5988, CurrentID=0, Status='live', Symbol='RFPL1', Aliases=['RNF78'], description='ret finger protein like 1', other_designations='ret finger protein-like 1|RING finger protein 78', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29387909, end_position_on_the_genomic_accession=29442455, orientation='plus', exon_count=10, OMIM=[605968], no_hdr0=''),
    5989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5989, CurrentID=0, Status='live', Symbol='RFX1', Aliases=['EFC', 'RFX'], description='regulatory factor X1', other_designations='MHC class II regulatory factor RFX1|MHC class II regulatory factor RFX|enhancer factor C|regulatory factor X, 1 (influences HLA class II expression)|trans-acting regulatory factor 1|transcription factor RFX1', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13961530, end_position_on_the_genomic_accession=14007514, orientation='minus', exon_count=24, OMIM=[600006], no_hdr0=''),
    5990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5990, CurrentID=0, Status='live', Symbol='RFX2', Aliases=[], description='regulatory factor X2', other_designations='DNA-binding protein RFX2|HLA class II regulatory factor RFX2|regulatory factor X 2|regulatory factor X, 2 (influences HLA class II expression)|trans-acting regulatory factor 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5993164, end_position_on_the_genomic_accession=6110601, orientation='minus', exon_count=18, OMIM=[142765], no_hdr0=''),
    5991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5991, CurrentID=0, Status='live', Symbol='RFX3', Aliases=[], description='regulatory factor X3', other_designations='transcription factor RFX3|DNA binding protein RFX3|regulatory factor X, 3 (influences HLA class II expression)', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=3218297, end_position_on_the_genomic_accession=3526529, orientation='minus', exon_count=27, OMIM=[601337], no_hdr0=''),
    5992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5992, CurrentID=0, Status='live', Symbol='RFX4', Aliases=['NYD-SP10'], description='regulatory factor X4', other_designations='transcription factor RFX4|regulatory factor X, 4 (influences HLA class II expression)|testis development protein NYD-SP10|winged-helix transcription factor RFX4', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106583004, end_position_on_the_genomic_accession=106762803, orientation='plus', exon_count=20, OMIM=[603958], no_hdr0=''),
    5993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5993, CurrentID=0, Status='live', Symbol='RFX5', Aliases=[], description='regulatory factor X5', other_designations='DNA-binding protein RFX5|regulatory factor X 5|regulatory factor X, 5 (influences HLA class II expression)', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151340640, end_position_on_the_genomic_accession=151347319, orientation='minus', exon_count=13, OMIM=[601863], no_hdr0=''),
    5994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5994, CurrentID=0, Status='live', Symbol='RFXAP', Aliases=[], description='regulatory factor X associated protein', other_designations='regulatory factor X-associated protein|RFX DNA-binding complex 36 kDa subunit|RFX-associated protein', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36819222, end_position_on_the_genomic_accession=36829104, orientation='plus', exon_count=3, OMIM=[601861], no_hdr0=''),
    5995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5995, CurrentID=0, Status='live', Symbol='RGR', Aliases=['RP44'], description='retinal G protein coupled receptor', other_designations='RPE-retinal G protein-coupled receptor|RGR-opsin', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84243741, end_position_on_the_genomic_accession=84259960, orientation='plus', exon_count=9, OMIM=[600342], no_hdr0=''),
    5996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5996, CurrentID=0, Status='live', Symbol='RGS1', Aliases=['1R20', 'BL34', 'HEL-S-87', 'IER1', 'IR20'], description='regulator of G protein signaling 1', other_designations='regulator of G-protein signaling 1|B-cell activation protein BL34|early response protein 1R20|epididymis secretory protein Li 87|immediate-early response 1, B-cell specific|regulator of G-protein signalling 1', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=192575773, end_position_on_the_genomic_accession=192580024, orientation='plus', exon_count=5, OMIM=[600323], no_hdr0=''),
    5997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5997, CurrentID=0, Status='live', Symbol='RGS2', Aliases=['G0S8'], description='regulator of G protein signaling 2', other_designations='regulator of G-protein signaling 2|G0 to G1 switch regulatory 8, 24kD|G0/G1 switch regulatory protein 8|cell growth-inhibiting gene 31 protein|cell growth-inhibiting protein 31|regulator of G-protein signaling 2, 24kDa', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=192809039, end_position_on_the_genomic_accession=192812275, orientation='plus', exon_count=5, OMIM=[600861], no_hdr0=''),
    5998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5998, CurrentID=0, Status='live', Symbol='RGS3', Aliases=['C2PA', 'RGP3'], description='regulator of G protein signaling 3', other_designations='regulator of G-protein signaling 3|regulator of G-protein signalling 3', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113444730, end_position_on_the_genomic_accession=113597738, orientation='plus', exon_count=34, OMIM=[602189], no_hdr0=''),
    5999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=5999, CurrentID=0, Status='live', Symbol='RGS4', Aliases=['RGP4', 'SCZD9'], description='regulator of G protein signaling 4', other_designations='regulator of G-protein signaling 4|schizophrenia disorder 9', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=163068871, end_position_on_the_genomic_accession=163076802, orientation='plus', exon_count=7, OMIM=[602516], no_hdr0=''),
    6000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6000, CurrentID=0, Status='live', Symbol='RGS7', Aliases=[], description='regulator of G protein signaling 7', other_designations='regulator of G-protein signaling 7|regulator of G-protein signaling RGS7|regulator of G-protein signalling 7', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=240774742, end_position_on_the_genomic_accession=241357230, orientation='minus', exon_count=25, OMIM=[602517], no_hdr0=''),
    6001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6001, CurrentID=0, Status='live', Symbol='RGS10', Aliases=[], description='regulator of G protein signaling 10', other_designations='regulator of G-protein signaling 10|regulator of G-protein signalling 10', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119499817, end_position_on_the_genomic_accession=119542719, orientation='minus', exon_count=6, OMIM=[602856], no_hdr0=''),
    6002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6002, CurrentID=0, Status='live', Symbol='RGS12', Aliases=[], description='regulator of G protein signaling 12', other_designations='regulator of G-protein signaling 12|regulator of G-protein signalling 12', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3285891, end_position_on_the_genomic_accession=3439913, orientation='plus', exon_count=26, OMIM=[602512], no_hdr0=''),
    6003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6003, CurrentID=0, Status='live', Symbol='RGS13', Aliases=[], description='regulator of G protein signaling 13', other_designations='regulator of G-protein signaling 13|regulator of G-protein signalling 13', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=192636147, end_position_on_the_genomic_accession=192660311, orientation='plus', exon_count=7, OMIM=[607190], no_hdr0=''),
    6004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6004, CurrentID=0, Status='live', Symbol='RGS16', Aliases=['A28-RGS14', 'A28-RGS14P', 'RGS-R'], description='regulator of G protein signaling 16', other_designations='regulator of G-protein signaling 16|hRGS-r|regulator of G-protein signalling 16|retinal-specific RGS|retinally abundant regulator of G-protein signaling', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182598623, end_position_on_the_genomic_accession=182604389, orientation='minus', exon_count=5, OMIM=[602514], no_hdr0=''),
    6005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6005, CurrentID=0, Status='live', Symbol='RHAG', Aliases=['CD241', 'OHS', 'OHST', 'RH2', 'RH50A', 'RHNR', 'Rh50', 'Rh50GP', 'SLC42A1'], description='Rh associated glycoprotein', other_designations='ammonium transporter Rh type A|Rh 50 glycoprotein|Rhesus associated polypeptide, 50-KD|Rhesus blood group-associated glycoprotein|erythrocyte membrane glycoprotein Rh50|erythrocyte plasma membrane 50 kDa glycoprotein|mutant Rh associated glycoprotein|rh family type A glycoprotein|rh type A glycoprotein|rhesus blood group family type A glycoprotein|rhesus blood group-associated ammonia channel|truncated Rh-associated glycoprotein|truncated RhAG glycoprotein', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49605175, end_position_on_the_genomic_accession=49636874, orientation='minus', exon_count=11, OMIM=[180297], no_hdr0=''),
    6006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6006, CurrentID=0, Status='live', Symbol='RHCE', Aliases=['CD240CE', 'RH', 'RH30A', 'RHC', 'RHCe(152N)', 'RHE', 'RHIXB', 'RHNA', 'RHPI', 'Rh4', 'RhIVb(J)', 'RhVI', 'RhVIII'], description='Rh blood group CcEe antigens', other_designations='blood group Rh(CE) polypeptide|(C)ces type 1 Rhesus blood group D antigen|RHCE blood group variant Crawford antigen Rh43|Rh blood group C antigen|Rh blood group CE antigen|Rh blood group CcEe antigen|Rh blood group D antigen|Rh blood group antigen Evans|Rh blood group protein|Rh polypeptide I|RhCE blood group antigens|Rhesus blood group CE protein|Rhesus blood group CcEe antigen|Rhesus blood group E antigen|Rhesus blood group Rhce antigen|Rhesus blood group antigen CE|Rhesus system C and E polypeptides|blood group RhCE polypeptide|blood group RhCcEe antigen|blood group protein RHCE|rh polypeptide 1|rhesus C/E antigens|rhesus blood group antigen, RhC antigen|rhesus blood group little e antigen|silenced Rh blood group CcEe antigen|truncated RHCE|truncated RhCcEe antigen|truncated RhD antigen|truncated blood group protein RHCE', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25360659, end_position_on_the_genomic_accession=25430193, orientation='minus', exon_count=14, OMIM=[111700], no_hdr0=''),
    6007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6007, CurrentID=0, Status='live', Symbol='RHD', Aliases=['CD240D', 'DIIIc', 'RH', 'RH30', 'RHCEDVA(TT)', 'RHDel', 'RHPII', 'RHXIII', 'Rh4', 'RhDCw', 'RhII', 'RhK562-II', 'RhPI', 'RHD'], description='Rh blood group D antigen', other_designations='blood group Rh(D) polypeptide|D antigen (DCS)|RH polypeptide 2|Rh blood group C antigen|Rh blood group CcEe antigen|Rh blood group D antigen weak D type 160|Rh blood group antigen Evans|Rh blood group, D anitgen|RhD antigen|RhD blood group antigen|RhD polypeptide|Rhesus D blood group protein|Rhesus blood group D antigen allele DIII type 7|Rhesus blood group antigen D|Rhesus system D polypeptide|blood group antigen D|blood group protein RHD|rhesus D antigen|truncated Rh blood group D antigen|truncated RhD antigen|truncated rhesus D|truncated rhesus blood group D antigen', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25272393, end_position_on_the_genomic_accession=25330445, orientation='plus', exon_count=11, OMIM=[111680], no_hdr0=''),
    6009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6009, CurrentID=0, Status='live', Symbol='RHEB', Aliases=['RHEB2'], description='Ras homolog, mTORC1 binding', other_designations='GTP-binding protein Rheb|Ras homolog enriched in brain 2', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151466012, end_position_on_the_genomic_accession=151519895, orientation='minus', exon_count=10, OMIM=[601293], no_hdr0=''),
    6010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6010, CurrentID=0, Status='live', Symbol='RHO', Aliases=['CSNBAD1', 'OPN2', 'RP4'], description='rhodopsin', other_designations='rhodopsin|opsin 2, rod pigment|opsin-2', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129528639, end_position_on_the_genomic_accession=129535344, orientation='plus', exon_count=5, OMIM=[180380], no_hdr0=''),
    6011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6011, CurrentID=0, Status='live', Symbol='GRK1', Aliases=['GPRK1', 'RHOK', 'RK'], description='G protein-coupled receptor kinase 1', other_designations='rhodopsin kinase GRK1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113645771, end_position_on_the_genomic_accession=113737736, orientation='plus', exon_count=8, OMIM=[180381], no_hdr0=''),
    6013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6013, CurrentID=0, Status='live', Symbol='RLN1', Aliases=['H1', 'H1RLX', 'RLXH1', 'bA12D24.3.1', 'bA12D24.3.2'], description='relaxin 1', other_designations='prorelaxin H1|preprorelaxin H1', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5334930, end_position_on_the_genomic_accession=5339876, orientation='minus', exon_count=2, OMIM=[179730], no_hdr0=''),
    6014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6014, CurrentID=0, Status='live', Symbol='RIT2', Aliases=['RIBA', 'RIN', 'ROC2'], description='Ras like without CAAX 2', other_designations='GTP-binding protein Rit2|GTP-binding protein Roc2|Ric-like, expressed in neurons|ras-like protein expressed in neurons|ras-like without CAAX protein 2', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=42743227, end_position_on_the_genomic_accession=43115685, orientation='minus', exon_count=6, OMIM=[609592], no_hdr0=''),
    6015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6015, CurrentID=0, Status='live', Symbol='RING1', Aliases=['RING1A', 'RNF1'], description='ring finger protein 1', other_designations='E3 ubiquitin-protein ligase RING1|RING-type E3 ubiquitin transferase RING1|polycomb complex protein RING1|really interesting new gene 1 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33208500, end_position_on_the_genomic_accession=33212716, orientation='plus', exon_count=7, OMIM=[602045], no_hdr0=''),
    6016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6016, CurrentID=0, Status='live', Symbol='RIT1', Aliases=['NS8', 'RIBB', 'RIT', 'ROC1'], description='Ras like without CAAX 1', other_designations='GTP-binding protein Rit1|GTP-binding protein Roc1|Ric-like, expressed in many tissues|ras-like protein expressed in many tissues|ras-like without CAAX protein 1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155897808, end_position_on_the_genomic_accession=155911349, orientation='minus', exon_count=7, OMIM=[609591], no_hdr0=''),
    6017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6017, CurrentID=0, Status='live', Symbol='RLBP1', Aliases=['CRALBP'], description='retinaldehyde binding protein 1', other_designations='retinaldehyde-binding protein 1|cellular retinaldehyde-binding protein|cellular retinaldehyde-binding protein-1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89209869, end_position_on_the_genomic_accession=89223179, orientation='minus', exon_count=9, OMIM=[180090], no_hdr0=''),
    6018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6018, CurrentID=0, Status='live', Symbol='RLF', Aliases=['ZN-15L', 'ZNF292L'], description='RLF zinc finger', other_designations='zinc finger protein Rlf|Zn-15 related|rearranged L-myc fusion gene protein|rearranged L-myc fusion sequence|zn-15-related protein', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40161387, end_position_on_the_genomic_accession=40240921, orientation='plus', exon_count=10, OMIM=[180610], no_hdr0=''),
    6019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6019, CurrentID=0, Status='live', Symbol='RLN2', Aliases=['H2', 'H2-RLX', 'RLXH2', 'bA12D24.1.1', 'bA12D24.1.2'], description='relaxin 2', other_designations='prorelaxin H2|H2-preprorelaxin|relaxin H2|relaxin, ovarian, of pregnancy', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5299864, end_position_on_the_genomic_accession=5339438, orientation='minus', exon_count=9, OMIM=[179740], no_hdr0=''),
    6035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6035, CurrentID=0, Status='live', Symbol='RNASE1', Aliases=['RAC1', 'RIB1', 'RNS1'], description='ribonuclease A family member 1, pancreatic', other_designations='ribonuclease pancreatic|HP-RNase|RIB-1|RNase 1|RNase A|RNase upI-1|ribonuclease 1|ribonuclease A C1|ribonuclease, RNase A family, 1 (pancreatic)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20801228, end_position_on_the_genomic_accession=20802844, orientation='minus', exon_count=3, OMIM=[180440], no_hdr0=''),
    6036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6036, CurrentID=0, Status='live', Symbol='RNASE2', Aliases=['EDN', 'RAF3', 'RNS2'], description='ribonuclease A family member 2', other_designations='non-secretory ribonuclease|RNase 2|RNase UpI-2|eosinophil-derived neurotoxin|ribonuclease 2|ribonuclease A F3|ribonuclease US|ribonuclease, RNase A family, 2 (liver, eosinophil-derived neurotoxin)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20955487, end_position_on_the_genomic_accession=20956436, orientation='plus', exon_count=2, OMIM=[131410], no_hdr0=''),
    6037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6037, CurrentID=0, Status='live', Symbol='RNASE3', Aliases=['ECP', 'RAF1', 'RNS3'], description='ribonuclease A family member 3', other_designations='eosinophil cationic protein|RNase 3|cytotoxic ribonuclease|ribonuclease 3|ribonuclease, RNase A family, 3', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20891385, end_position_on_the_genomic_accession=20892348, orientation='plus', exon_count=2, OMIM=[131398], no_hdr0=''),
    6038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6038, CurrentID=0, Status='live', Symbol='RNASE4', Aliases=['RAB1', 'RNS4'], description='ribonuclease A family member 4', other_designations='ribonuclease 4|RNase 4|epididymis secretory sperm binding protein|ribonuclease A B1|ribonuclease, RNase A family, 4', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20684560, end_position_on_the_genomic_accession=20701216, orientation='plus', exon_count=4, OMIM=[601030], no_hdr0=''),
    6039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6039, CurrentID=0, Status='live', Symbol='RNASE6', Aliases=['RAD1', 'RNS6', 'RNasek6'], description='ribonuclease A family member k6', other_designations='ribonuclease K6|ribonuclease A D1|ribonuclease, RNase A family, k6|testicular tissue protein Li 166', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20780956, end_position_on_the_genomic_accession=20782467, orientation='plus', exon_count=4, OMIM=[601981], no_hdr0=''),
    6041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6041, CurrentID=0, Status='live', Symbol='RNASEL', Aliases=['PRCA1', 'RNS4'], description='ribonuclease L', other_designations="2-5A-dependent ribonuclease|2',5'-oligoisoadenylate synthetase-dependent|2-5A-dependent RNase|RNase L|interferon-induced 2-5A-dependent RNase|ribonuclease 4", map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182573634, end_position_on_the_genomic_accession=182589285, orientation='minus', exon_count=8, OMIM=[180435], no_hdr0=''),
    6045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6045, CurrentID=0, Status='live', Symbol='RNF2', Aliases=['BAP-1', 'BAP1', 'DING', 'HIPI3', 'RING1B', 'RING2'], description='ring finger protein 2', other_designations='E3 ubiquitin-protein ligase RING2|HIP2-interacting protein 3|RING finger protein 1B|RING finger protein BAP-1|RING-type E3 ubiquitin transferase RING2|huntingtin-interacting protein 2-interacting protein 3|protein DinG', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=185045430, end_position_on_the_genomic_accession=185102603, orientation='plus', exon_count=9, OMIM=[608985], no_hdr0=''),
    6046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6046, CurrentID=0, Status='live', Symbol='BRD2', Aliases=['BRD2-IT1', 'D6S113E', 'FSH', 'FSRG1', 'NAT', 'O27.1.1', 'RING3', 'RNF3'], description='bromodomain containing 2', other_designations='bromodomain-containing protein 2|BRD2 intronic transcript 1|female sterile homeotic-related gene 1|really interesting new gene 3 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32968594, end_position_on_the_genomic_accession=32981505, orientation='plus', exon_count=17, OMIM=[601540], no_hdr0=''),
    6047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6047, CurrentID=0, Status='live', Symbol='RNF4', Aliases=['RES4-26', 'SLX5', 'SNURF'], description='ring finger protein 4', other_designations='E3 ubiquitin-protein ligase RNF4|E3 ubiquitin ligase RNF4|RING-type E3 ubiquitin transferase RNF4|small nuclear RING finger protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2469106, end_position_on_the_genomic_accession=2515857, orientation='plus', exon_count=10, OMIM=[602850], no_hdr0=''),
    6048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6048, CurrentID=0, Status='live', Symbol='RNF5', Aliases=['RING5', 'RMA1'], description='ring finger protein 5', other_designations='E3 ubiquitin-protein ligase RNF5|RING-type E3 ubiquitin transferase RNF5|protein G16|ram1 homolog|ring finger protein 5, E3 ubiquitin protein ligase', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32178405, end_position_on_the_genomic_accession=32180793, orientation='plus', exon_count=6, OMIM=[602677], no_hdr0=''),
    6049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6049, CurrentID=0, Status='live', Symbol='RNF6', Aliases=[], description='ring finger protein 6', other_designations='E3 ubiquitin-protein ligase RNF6|RING-H2 protein RNF-6|RING-type E3 ubiquitin transferase RNF6|ring finger protein (C3H2C3 type) 6', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=26132115, end_position_on_the_genomic_accession=26223085, orientation='minus', exon_count=9, OMIM=[604242], no_hdr0=''),
    6050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6050, CurrentID=0, Status='live', Symbol='RNH1', Aliases=['RAI', 'RNH'], description='ribonuclease/angiogenin inhibitor 1', other_designations='ribonuclease inhibitor|placental RNase inhibitor|placental ribonuclease inhibitor|testicular tissue protein Li 164', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=494512, end_position_on_the_genomic_accession=507255, orientation='minus', exon_count=14, OMIM=[173320], no_hdr0=''),
    6051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6051, CurrentID=0, Status='live', Symbol='RNPEP', Aliases=['AP-B', 'APB'], description='arginyl aminopeptidase', other_designations='aminopeptidase B|arginine aminopeptidase', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201982648, end_position_on_the_genomic_accession=202006143, orientation='plus', exon_count=12, OMIM=[602675], no_hdr0=''),
    6059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6059, CurrentID=0, Status='live', Symbol='ABCE1', Aliases=['ABC38', 'OABP', 'RLI', 'RLI1', 'RNASEL1', 'RNASELI', 'RNS4I'], description='ATP binding cassette subfamily E member 1', other_designations="ATP-binding cassette sub-family E member 1|2'-5'-oligoadenylate-binding protein|ATP-binding cassette, sub-family E (OABP), member 1|RNase L inhibitor 1|huHP68|ribonuclease 4 inhibitor|ribonuclease L (2',5'-oligoisoadenylate synthetase-dependent) inhibitor", map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145098311, end_position_on_the_genomic_accession=145129524, orientation='plus', exon_count=18, OMIM=[601213], no_hdr0=''),
    6091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6091, CurrentID=0, Status='live', Symbol='ROBO1', Aliases=['DUTT1', 'SAX3'], description='roundabout guidance receptor 1', other_designations='roundabout homolog 1|deleted in U twenty twenty|roundabout, axon guidance receptor, homolog 1', map_location='3p12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=78597239, end_position_on_the_genomic_accession=79767998, orientation='minus', exon_count=35, OMIM=[602430], no_hdr0=''),
    6092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6092, CurrentID=0, Status='live', Symbol='ROBO2', Aliases=['SAX3'], description='roundabout guidance receptor 2', other_designations='roundabout homolog 2|roundabout, axon guidance receptor, homolog 2', map_location='3p12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=75906675, end_position_on_the_genomic_accession=77649964, orientation='plus', exon_count=34, OMIM=[602431], no_hdr0=''),
    6093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6093, CurrentID=0, Status='live', Symbol='ROCK1', Aliases=['P160ROCK', 'ROCK-I'], description='Rho associated coiled-coil containing protein kinase 1', other_designations='rho-associated protein kinase 1|p160 ROCK-1|renal carcinoma antigen NY-REN-35', map_location='18q11.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=20946906, end_position_on_the_genomic_accession=21111813, orientation='minus', exon_count=33, OMIM=[601702], no_hdr0=''),
    6094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6094, CurrentID=0, Status='live', Symbol='ROM1', Aliases=['ROM', 'ROSP1', 'RP7', 'TSPAN23'], description='retinal outer segment membrane protein 1', other_designations='rod outer segment membrane protein 1|tetraspanin-23', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62613257, end_position_on_the_genomic_accession=62615116, orientation='plus', exon_count=3, OMIM=[180721], no_hdr0=''),
    6095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6095, CurrentID=0, Status='live', Symbol='RORA', Aliases=['IDDECA', 'NR1F1', 'ROR1', 'ROR2', 'ROR3', 'RZR-ALPHA', 'RZRA'], description='RAR related orphan receptor A', other_designations='nuclear receptor ROR-alpha|ROR-alpha|nuclear receptor RZR-alpha|nuclear receptor subfamily 1 group F member 1|retinoic acid receptor-related orphan receptor alpha|retinoid-related orphan receptor alpha|thyroid hormone nuclear receptor alpha variant 4|transcription factor RZR-alpha', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=60488284, end_position_on_the_genomic_accession=61229302, orientation='minus', exon_count=21, OMIM=[600825], no_hdr0=''),
    6096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6096, CurrentID=0, Status='live', Symbol='RORB', Aliases=['EIG15', 'NR1F2', 'ROR-BETA', 'RZR-BETA', 'RZRB', 'bA133M9.1'], description='RAR related orphan receptor B', other_designations='nuclear receptor ROR-beta|RAR-related orphan receptor beta|nuclear receptor RZR-beta|nuclear receptor subfamily 1 group F member 2|retinoic acid-binding receptor beta|retinoid-related orphan receptor beta', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=74497335, end_position_on_the_genomic_accession=74693177, orientation='plus', exon_count=11, OMIM=[601972], no_hdr0=''),
    6097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6097, CurrentID=0, Status='live', Symbol='RORC', Aliases=['IMD42', 'NR1F3', 'RORG', 'RZR-GAMMA', 'RZRG', 'TOR'], description='RAR related orphan receptor C', other_designations='nuclear receptor ROR-gamma|RAR-related orphan nuclear receptor variant 2|nuclear receptor RZR-gamma|nuclear receptor subfamily 1 group F member 3|retinoic acid-binding receptor gamma|retinoid-related orphan receptor gamma', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151806071, end_position_on_the_genomic_accession=151832451, orientation='minus', exon_count=13, OMIM=[602943], no_hdr0=''),
    6098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6098, CurrentID=0, Status='live', Symbol='ROS1', Aliases=['MCF3', 'ROS', 'c-ros-1'], description='ROS proto-oncogene 1, receptor tyrosine kinase', other_designations='proto-oncogene tyrosine-protein kinase ROS|ROS proto-oncogene 1 , receptor tyrosine kinase|c-ros oncogene 1 , receptor tyrosine kinase|proto-oncogene c-Ros-1|transmembrane tyrosine-specific protein kinase|v-ros avian UR2 sarcoma virus oncogene homolog 1', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117287353, end_position_on_the_genomic_accession=117426065, orientation='minus', exon_count=46, OMIM=[165020], no_hdr0=''),
    6100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6100, CurrentID=0, Status='live', Symbol='RP9', Aliases=['PAP-1', 'PAP1'], description='RP9 pre-mRNA splicing factor', other_designations='retinitis pigmentosa 9 protein|Pim-1 kinase associated protein|pim-1-associated protein|retinitis pigmentosa 9 (autosomal dominant)', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=33094797, end_position_on_the_genomic_accession=33109404, orientation='minus', exon_count=7, OMIM=[607331], no_hdr0=''),
    6101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6101, CurrentID=0, Status='live', Symbol='RP1', Aliases=['DCDC4A', 'ORP1'], description='RP1 axonemal microtubule associated', other_designations='oxygen-regulated protein 1|doublecortin domain containing 4A|retinitis pigmentosa 1 (autosomal dominant)|retinitis pigmentosa 1 protein|retinitis pigmentosa RP1 protein', map_location='8q11.23-q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=54509448, end_position_on_the_genomic_accession=54871720, orientation='plus', exon_count=38, OMIM=[603937], no_hdr0=''),
    6102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6102, CurrentID=0, Status='live', Symbol='RP2', Aliases=['DELXp11.3', 'NM23-H10', 'NME10', 'TBCCD2', 'XRP2'], description='RP2 activator of ARL3 GTPase', other_designations='protein XRP2|RP2, ARL3 GTPase activating protein|retinitis pigmentosa 2 (X-linked recessive)', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46837043, end_position_on_the_genomic_accession=46882358, orientation='plus', exon_count=5, OMIM=[300757], no_hdr0=''),
    6103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6103, CurrentID=0, Status='live', Symbol='RPGR', Aliases=['COD1', 'CORDX1', 'CRD', 'PCDX', 'RP15', 'RP3', 'XLRP3', 'orf15'], description='retinitis pigmentosa GTPase regulator', other_designations='X-linked retinitis pigmentosa GTPase regulator|retinitis pigmentosa 15|retinitis pigmentosa 3 GTPase regulator', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=38269163, end_position_on_the_genomic_accession=38327509, orientation='minus', exon_count=25, OMIM=[312610], no_hdr0=''),
    6117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6117, CurrentID=0, Status='live', Symbol='RPA1', Aliases=['HSSB', 'MST075', 'REPA1', 'RF-A', 'RP-A', 'RPA70'], description='replication protein A1', other_designations='replication protein A 70 kDa DNA-binding subunit|MSTP075|RF-A protein 1|RP-A p70|replication factor A protein 1|replication protein A1, 70kDa|single-stranded DNA-binding protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1830005, end_position_on_the_genomic_accession=1900082, orientation='plus', exon_count=17, OMIM=[179835], no_hdr0=''),
    6118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6118, CurrentID=0, Status='live', Symbol='RPA2', Aliases=['REPA2', 'RP-A p32', 'RP-A p34', 'RPA32'], description='replication protein A2', other_designations='replication protein A 32 kDa subunit|RF-A protein 2|replication factor A protein 2|replication protein A 34 kDa subunit', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27891524, end_position_on_the_genomic_accession=27914797, orientation='minus', exon_count=9, OMIM=[179836], no_hdr0=''),
    6119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6119, CurrentID=0, Status='live', Symbol='RPA3', Aliases=['REPA3', 'RP-A p14'], description='replication protein A3', other_designations='replication protein A 14 kDa subunit|RF-A protein 3|replication factor A protein 3|replication protein A3, 14kDa', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7636518, end_position_on_the_genomic_accession=7718607, orientation='minus', exon_count=8, OMIM=[179837], no_hdr0=''),
    6120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6120, CurrentID=0, Status='live', Symbol='RPE', Aliases=['RPE2-1'], description='ribulose-5-phosphate-3-epimerase', other_designations='ribulose-phosphate 3-epimerase', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210002628, end_position_on_the_genomic_accession=210023363, orientation='plus', exon_count=10, OMIM=[180480], no_hdr0=''),
    6121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6121, CurrentID=0, Status='live', Symbol='RPE65', Aliases=['BCO3', 'LCA2', 'RP20', 'mRPE65', 'p63', 'rd12', 'sRPE65'], description='retinoid isomerohydrolase RPE65', other_designations='retinoid isomerohydrolase|BCO family, member 3|RBP-binding membrane protein|RPE65, retinoid isomerohydrolase|all-trans-retinyl-palmitate hydrolase|lutein isomerase|meso-zeaxanthin isomerase|retinal pigment epithelium specific protein 65|retinal pigment epithelium-specific 65 kDa protein|retinal pigment epithelium-specific protein 65kDa|retinitis pigmentosa 20 (autosomal recessive)|retinol isomerase', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=68428822, end_position_on_the_genomic_accession=68450322, orientation='minus', exon_count=14, OMIM=[180069], no_hdr0=''),
    6122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6122, CurrentID=0, Status='live', Symbol='RPL3', Aliases=['ASC-1', 'L3', 'TARBP-B'], description='ribosomal protein L3', other_designations='60S ribosomal protein L3|HIV-1 TAR RNA-binding protein B|large ribosomal subunit protein uL3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39312882, end_position_on_the_genomic_accession=39319623, orientation='minus', exon_count=10, OMIM=[604163], no_hdr0=''),
    6123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6123, CurrentID=0, Status='live', Symbol='RPL3L', Aliases=['CMD2D'], description='ribosomal protein L3 like', other_designations='60S ribosomal protein L3-like|large ribosomal subunit protein uL3-like', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1943974, end_position_on_the_genomic_accession=1955123, orientation='minus', exon_count=10, OMIM=[617416], no_hdr0=''),
    6124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6124, CurrentID=0, Status='live', Symbol='RPL4', Aliases=['L4'], description='ribosomal protein L4', other_designations='60S ribosomal protein L4|60S ribosomal protein L1|large ribosomal subunit protein uL4', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66498015, end_position_on_the_genomic_accession=66504855, orientation='minus', exon_count=10, OMIM=[180479], no_hdr0=''),
    6125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6125, CurrentID=0, Status='live', Symbol='RPL5', Aliases=['L5', 'MSTP030', 'PPP1R135', 'uL18'], description='ribosomal protein L5', other_designations='60S ribosomal protein L5|large ribosomal subunit protein uL18|protein phosphatase 1, regulatory subunit 135', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92831986, end_position_on_the_genomic_accession=92841924, orientation='plus', exon_count=8, OMIM=[603634], no_hdr0=''),
    6128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6128, CurrentID=0, Status='live', Symbol='RPL6', Aliases=['L6', 'SHUJUN-2', 'TAXREB107', 'TXREB1'], description='ribosomal protein L6', other_designations='60S ribosomal protein L6|DNA-binding protein TAXREB107|large ribosomal subunit protein eL6|neoplasm-related protein C140|tax-responsive enhancer element-binding protein 107', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112405181, end_position_on_the_genomic_accession=112418850, orientation='minus', exon_count=12, OMIM=[603703], no_hdr0=''),
    6129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6129, CurrentID=0, Status='live', Symbol='RPL7', Aliases=['L7', 'humL7-1'], description='ribosomal protein L7', other_designations='60S ribosomal protein L7|large ribosomal subunit protein uL30', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73290242, end_position_on_the_genomic_accession=73294466, orientation='minus', exon_count=8, OMIM=[604166], no_hdr0=''),
    6130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6130, CurrentID=0, Status='live', Symbol='RPL7A', Aliases=['L7A', 'SURF3', 'TRUP'], description='ribosomal protein L7a', other_designations='60S ribosomal protein L7a|PLA-X polypeptide|large ribosomal subunit protein eL8|surfeit 3|surfeit locus protein 3|thyroid hormone receptor uncoupling protein', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133348218, end_position_on_the_genomic_accession=133351426, orientation='plus', exon_count=8, OMIM=[185640], no_hdr0=''),
    6132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6132, CurrentID=0, Status='live', Symbol='RPL8', Aliases=['L8'], description='ribosomal protein L8', other_designations='60S ribosomal protein L8|large ribosomal subunit protein uL2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144789769, end_position_on_the_genomic_accession=144792390, orientation='minus', exon_count=6, OMIM=[604177], no_hdr0=''),
    6133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6133, CurrentID=0, Status='live', Symbol='RPL9', Aliases=['L9', 'NPC-A-16'], description='ribosomal protein L9', other_designations='60S ribosomal protein L9|large ribosomal subunit protein uL6', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39454124, end_position_on_the_genomic_accession=39458922, orientation='minus', exon_count=8, OMIM=[603686], no_hdr0=''),
    6134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6134, CurrentID=0, Status='live', Symbol='RPL10', Aliases=['AUTSX5', 'DXS648', 'DXS648E', 'L10', 'MRXS35', 'NOV', 'QM'], description='ribosomal protein L10', other_designations='60S ribosomal protein L10|Wilms tumor-related protein|laminin receptor homolog|large ribosomal subunit protein uL16|tumor suppressor QM', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154398065, end_position_on_the_genomic_accession=154402339, orientation='plus', exon_count=7, OMIM=[312173], no_hdr0=''),
    6135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6135, CurrentID=0, Status='live', Symbol='RPL11', Aliases=['DBA7', 'GIG34', 'L11', 'uL5'], description='ribosomal protein L11', other_designations='60S ribosomal protein L11|CLL-associated antigen KW-12|cell growth-inhibiting protein 34|large ribosomal subunit protein uL5', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23691779, end_position_on_the_genomic_accession=23696835, orientation='plus', exon_count=6, OMIM=[604175], no_hdr0=''),
    6136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6136, CurrentID=0, Status='live', Symbol='RPL12', Aliases=['L12'], description='ribosomal protein L12', other_designations='60S ribosomal protein L12|large ribosomal subunit protein uL11', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127447674, end_position_on_the_genomic_accession=127451406, orientation='minus', exon_count=7, OMIM=[180475], no_hdr0=''),
    6137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6137, CurrentID=0, Status='live', Symbol='RPL13', Aliases=['BBC1', 'D16S444E', 'D16S44E', 'L13', 'SEMDIST'], description='ribosomal protein L13', other_designations='60S ribosomal protein L13|breast basic conserved 1|breast basic conserved protein 1|large ribosomal subunit protein eL13', map_location='17p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89560657, end_position_on_the_genomic_accession=89566829, orientation='plus', exon_count=7, OMIM=[113703], no_hdr0=''),
    6138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6138, CurrentID=0, Status='live', Symbol='RPL15', Aliases=['DBA12', 'EC45', 'L15', 'RPL10', 'RPLY10', 'RPYL10'], description='ribosomal protein L15', other_designations='60S ribosomal protein L15|large ribosomal subunit protein eL15', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=23916545, end_position_on_the_genomic_accession=23924631, orientation='plus', exon_count=5, OMIM=[604174], no_hdr0=''),
    6139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6139, CurrentID=0, Status='live', Symbol='RPL17', Aliases=['L17', 'PD-1', 'RPL23'], description='ribosomal protein L17', other_designations='60S ribosomal protein L17|60S ribosomal protein L23|gene encoding putative NFkB activating protein|large ribosomal subunit protein uL22', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49488481, end_position_on_the_genomic_accession=49492465, orientation='minus', exon_count=8, OMIM=[603661], no_hdr0=''),
    6141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6141, CurrentID=0, Status='live', Symbol='RPL18', Aliases=['DBA18', 'L18'], description='ribosomal protein L18', other_designations='60S ribosomal protein L18|large ribosomal subunit protein eL18', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48615331, end_position_on_the_genomic_accession=48619178, orientation='minus', exon_count=7, OMIM=[604179], no_hdr0=''),
    6142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6142, CurrentID=0, Status='live', Symbol='RPL18A', Aliases=['L18A'], description='ribosomal protein L18a', other_designations='60S ribosomal protein L18a|large ribosomal subunit protein eL20|ribosomal protein L18a-like protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17859910, end_position_on_the_genomic_accession=17863319, orientation='plus', exon_count=5, OMIM=[604178], no_hdr0=''),
    6143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6143, CurrentID=0, Status='live', Symbol='RPL19', Aliases=['L19'], description='ribosomal protein L19', other_designations='60S ribosomal protein L19|large ribosomal subunit protein eL19', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39200283, end_position_on_the_genomic_accession=39204732, orientation='plus', exon_count=6, OMIM=[180466], no_hdr0=''),
    6144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6144, CurrentID=0, Status='live', Symbol='RPL21', Aliases=['HYPT12', 'L21'], description='ribosomal protein L21', other_designations='60S ribosomal protein L21|large ribosomal subunit protein eL21', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27251558, end_position_on_the_genomic_accession=27256568, orientation='plus', exon_count=6, OMIM=[603636], no_hdr0=''),
    6146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6146, CurrentID=0, Status='live', Symbol='RPL22', Aliases=['EAP', 'HBP15', 'HBP15/L22', 'L22'], description='ribosomal protein L22', other_designations='60S ribosomal protein L22|EBER-associated protein|Epstein-Barr virus small RNA-associated protein|Epstein-Barr-encoded RNA-associated protein|heparin-binding protein 15|heparin-binding protein HBp15|large ribosomal subunit protein eL22', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6185020, end_position_on_the_genomic_accession=6199595, orientation='minus', exon_count=4, OMIM=[180474], no_hdr0=''),
    6147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6147, CurrentID=0, Status='live', Symbol='RPL23A', Aliases=['L23A', 'MDA20'], description='ribosomal protein L23a', other_designations='60S ribosomal protein L23a|large ribosomal subunit protein uL23|melanoma differentiation-associated gene 20', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28719985, end_position_on_the_genomic_accession=28724359, orientation='plus', exon_count=5, OMIM=[602326], no_hdr0=''),
    6150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6150, CurrentID=0, Status='live', Symbol='MRPL23', Aliases=['L23MRP', 'RPL23', 'RPL23L'], description='mitochondrial ribosomal protein L23', other_designations='39S ribosomal protein L23, mitochondrial|L23 mitochondrial-related protein|L23mt|MRP-L23|mitochondrial large ribosomal subunit protein uL23m|ribosomal protein related to L23 (mitochondrial)', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1947272, end_position_on_the_genomic_accession=2013176, orientation='plus', exon_count=11, OMIM=[600789], no_hdr0=''),
    6152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6152, CurrentID=0, Status='live', Symbol='RPL24', Aliases=['HEL-S-310', 'L24'], description='ribosomal protein L24', other_designations='60S ribosomal protein L24|60S ribosomal protein L30|epididymis secretory protein Li 310|large ribosomal subunit protein eL24|ribosomal protein L30', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101681091, end_position_on_the_genomic_accession=101686718, orientation='minus', exon_count=6, OMIM=[604180], no_hdr0=''),
    6154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6154, CurrentID=0, Status='live', Symbol='RPL26', Aliases=['DBA11', 'L26'], description='ribosomal protein L26', other_designations='60S ribosomal protein L26|large ribosomal subunit protein uL24', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8377516, end_position_on_the_genomic_accession=8383193, orientation='minus', exon_count=4, OMIM=[603704], no_hdr0=''),
    6155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6155, CurrentID=0, Status='live', Symbol='RPL27', Aliases=['DBA16', 'L27'], description='ribosomal protein L27', other_designations='60S ribosomal protein L27|large ribosomal subunit protein eL27', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42998273, end_position_on_the_genomic_accession=43002959, orientation='plus', exon_count=6, OMIM=[607526], no_hdr0=''),
    6156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6156, CurrentID=0, Status='live', Symbol='RPL30', Aliases=['L30'], description='ribosomal protein L30', other_designations='60S ribosomal protein L30|large ribosomal subunit protein eL30', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98041721, end_position_on_the_genomic_accession=98045545, orientation='minus', exon_count=5, OMIM=[180467], no_hdr0=''),
    6157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6157, CurrentID=0, Status='live', Symbol='RPL27A', Aliases=['L27A'], description='ribosomal protein L27a', other_designations='60S ribosomal protein L27a|large ribosomal subunit protein uL15', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8682792, end_position_on_the_genomic_accession=8689872, orientation='plus', exon_count=5, OMIM=[603637], no_hdr0=''),
    6158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6158, CurrentID=0, Status='live', Symbol='RPL28', Aliases=['L28'], description='ribosomal protein L28', other_designations='60S ribosomal protein L28|large ribosomal subunit protein eL28', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55385932, end_position_on_the_genomic_accession=55403342, orientation='plus', exon_count=6, OMIM=[603638], no_hdr0=''),
    6159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6159, CurrentID=0, Status='live', Symbol='RPL29', Aliases=['HIP', 'HUMRPL29', 'L29P10', 'RPL29_3_370', 'RPL29'], description='ribosomal protein L29', other_designations='60S ribosomal protein L29|HP/HS-interacting protein|cell surface heparin-binding protein HIP|heparin/heparan sulfate-binding protein|heparin/heparan sulfate-interacting protein|large ribosomal subunit protein eL29|ribosomal protein YL43 homologue', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51993522, end_position_on_the_genomic_accession=51995895, orientation='minus', exon_count=4, OMIM=[601832], no_hdr0=''),
    6160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6160, CurrentID=0, Status='live', Symbol='RPL31', Aliases=['L31'], description='ribosomal protein L31', other_designations='60S ribosomal protein L31|large ribosomal subunit protein eL31', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101002289, end_position_on_the_genomic_accession=101019724, orientation='plus', exon_count=6, OMIM=[617415], no_hdr0=''),
    6161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6161, CurrentID=0, Status='live', Symbol='RPL32', Aliases=['L32', 'PP9932'], description='ribosomal protein L32', other_designations='60S ribosomal protein L32|large ribosomal subunit protein eL32', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12834485, end_position_on_the_genomic_accession=12841582, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    6164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6164, CurrentID=0, Status='live', Symbol='RPL34', Aliases=['L34'], description='ribosomal protein L34', other_designations='60S ribosomal protein L34|large ribosomal subunit protein eL34|leukemia-associated protein', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=108620576, end_position_on_the_genomic_accession=108630484, orientation='plus', exon_count=8, OMIM=[616862], no_hdr0=''),
    6165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6165, CurrentID=0, Status='live', Symbol='RPL35A', Aliases=['DBA5', 'L35A', 'eL33'], description='ribosomal protein L35a', other_designations='60S ribosomal protein L35a|cell growth-inhibiting gene 33 protein|large ribosomal subunit protein eL33', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197950190, end_position_on_the_genomic_accession=197956610, orientation='plus', exon_count=5, OMIM=[180468], no_hdr0=''),
    6166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6166, CurrentID=0, Status='live', Symbol='RPL36AL', Aliases=['RPL36A'], description='ribosomal protein L36a like', other_designations='60S ribosomal protein L36a-like|large ribosomal subunit protein eL42-like|ribosomal protein HL44', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49618530, end_position_on_the_genomic_accession=49620626, orientation='minus', exon_count=2, OMIM=[180469], no_hdr0=''),
    6167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6167, CurrentID=0, Status='live', Symbol='RPL37', Aliases=['L37'], description='ribosomal protein L37', other_designations='60S ribosomal protein L37|60S ribosomal protein L37a|G1.16|large ribosomal subunit protein eL37', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40825262, end_position_on_the_genomic_accession=40835222, orientation='minus', exon_count=4, OMIM=[604181], no_hdr0=''),
    6168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6168, CurrentID=0, Status='live', Symbol='RPL37A', Aliases=['L37A'], description='ribosomal protein L37a', other_designations='60S ribosomal protein L37a|large ribosomal subunit protein eL43', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216498844, end_position_on_the_genomic_accession=216504086, orientation='plus', exon_count=4, OMIM=[613314], no_hdr0=''),
    6169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6169, CurrentID=0, Status='live', Symbol='RPL38', Aliases=['L38'], description='ribosomal protein L38', other_designations='60S ribosomal protein L38|large ribosomal subunit protein eL38', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74203678, end_position_on_the_genomic_accession=74210655, orientation='plus', exon_count=5, OMIM=[604182], no_hdr0=''),
    6170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6170, CurrentID=0, Status='live', Symbol='RPL39', Aliases=['L39P42', 'RPL39_23_1806', 'RPL39'], description='ribosomal protein L39', other_designations='60S ribosomal protein L39|large ribosomal subunit protein eL39', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119786504, end_position_on_the_genomic_accession=119791630, orientation='minus', exon_count=3, OMIM=[300899], no_hdr0=''),
    6171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6171, CurrentID=0, Status='live', Symbol='RPL41', Aliases=['L41'], description='ribosomal protein L41', other_designations='60S ribosomal protein L41|HG12 protein|homologue of yeast ribosomal protein YL41|large ribosomal subunit protein eL41', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56116633, end_position_on_the_genomic_accession=56117967, orientation='plus', exon_count=4, OMIM=[613315], no_hdr0=''),
    6173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6173, CurrentID=0, Status='live', Symbol='RPL36A', Aliases=['L36A', 'L44L', 'MIG6', 'RPL44'], description='ribosomal protein L36a', other_designations='60S ribosomal protein L36a|60S ribosomal protein L44|L44-like ribosomal protein|cell growth-inhibiting gene 15 protein|cell migration-inducing gene 6 protein|dJ164F3.3 (ribosomal protein L44)|large ribosomal subunit protein eL42', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101391011, end_position_on_the_genomic_accession=101396155, orientation='plus', exon_count=5, OMIM=[300902], no_hdr0=''),
    6175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6175, CurrentID=0, Status='live', Symbol='RPLP0', Aliases=['L10E', 'LP0', 'P0', 'PRLP0', 'RPP0'], description='ribosomal protein lateral stalk subunit P0', other_designations='60S acidic ribosomal protein P0|60S ribosomal protein L10E|acidic ribosomal phosphoprotein P0|large ribosomal subunit protein uL10|neutral ribosomal phosphoprotein P0|ribosomal protein, large, P0', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120196699, end_position_on_the_genomic_accession=120201111, orientation='minus', exon_count=8, OMIM=[180510], no_hdr0=''),
    6176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6176, CurrentID=0, Status='live', Symbol='RPLP1', Aliases=['LP1', 'P1', 'RPP1'], description='ribosomal protein lateral stalk subunit P1', other_designations='60S acidic ribosomal protein P1|acidic ribosomal phosphoprotein P1|large ribosomal subunit protein P1|ribosomal protein, large, P1', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=69452818, end_position_on_the_genomic_accession=69456205, orientation='plus', exon_count=4, OMIM=[180520], no_hdr0=''),
    6181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6181, CurrentID=0, Status='live', Symbol='RPLP2', Aliases=['D11S2243E', 'LP2', 'P2', 'RPP2'], description='ribosomal protein lateral stalk subunit P2', other_designations='60S acidic ribosomal protein P2|acidic ribosomal phosphoprotein P2|large ribosomal subunit protein P2|renal carcinoma antigen NY-REN-44|ribosomal protein, large, P2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=809967, end_position_on_the_genomic_accession=812876, orientation='plus', exon_count=5, OMIM=[180530], no_hdr0=''),
    6182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6182, CurrentID=0, Status='live', Symbol='MRPL12', Aliases=['5c5-2', 'L12mt', 'MRP-L31/34', 'MRPL7', 'MRPL7/L12', 'RPML12'], description='mitochondrial ribosomal protein L12', other_designations='39S ribosomal protein L12, mitochondrial|MRP-L12|mitochondrial large ribosomal subunit protein bL12m', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81703367, end_position_on_the_genomic_accession=81707517, orientation='plus', exon_count=5, OMIM=[602375], no_hdr0=''),
    6183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6183, CurrentID=0, Status='live', Symbol='MRPS12', Aliases=['MPR-S12', 'MT-RPS12', 'RPMS12', 'RPS12', 'RPSM12'], description='mitochondrial ribosomal protein S12', other_designations='28S ribosomal protein S12, mitochondrial|MRP-S12|S12mt|mitochondrial small ribosomal subunit protein uS12m', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38930944, end_position_on_the_genomic_accession=38933168, orientation='plus', exon_count=3, OMIM=[603021], no_hdr0=''),
    6184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6184, CurrentID=0, Status='live', Symbol='RPN1', Aliases=['OST1', 'RBPH1'], description='ribophorin I', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit 1|RPN-I|dolichyl-diphosphooligosaccharide-protein glycosyltransferase 67 kDa subunit|oligosaccharyltransferase 1 homolog|oligosaccharyltransferase complex subunit (non-catalytic)|ribophorin-1', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128619969, end_position_on_the_genomic_accession=128650818, orientation='minus', exon_count=10, OMIM=[180470], no_hdr0=''),
    6185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6185, CurrentID=0, Status='live', Symbol='RPN2', Aliases=['RIBIIR', 'RPN-II', 'RPNII', 'SWP1'], description='ribophorin II', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit 2|dolichyl-diphosphooligosaccharide--protein glycosyltransferase 63 kDa subunit|oligosaccharyltransferase complex subunit (non-catalytic)|ribophorin-2', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37179161, end_position_on_the_genomic_accession=37241623, orientation='plus', exon_count=19, OMIM=[180490], no_hdr0=''),
    6187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6187, CurrentID=0, Status='live', Symbol='RPS2', Aliases=['LLREP3', 'S2'], description='ribosomal protein S2', other_designations='40S ribosomal protein S2|40S ribosomal protein S4|OK/KNS-cl.6|protein LLRep3|small ribosomal subunit protein uS5', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1962058, end_position_on_the_genomic_accession=1964826, orientation='minus', exon_count=7, OMIM=[603624], no_hdr0=''),
    6188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6188, CurrentID=0, Status='live', Symbol='RPS3', Aliases=['S3'], description='ribosomal protein S3', other_designations='40S ribosomal protein S3|IMR-90 ribosomal protein S3|small ribosomal subunit protein uS3', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75399518, end_position_on_the_genomic_accession=75422302, orientation='plus', exon_count=8, OMIM=[600454], no_hdr0=''),
    6189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6189, CurrentID=0, Status='live', Symbol='RPS3A', Aliases=['FTE1', 'MFTL', 'S3A'], description='ribosomal protein S3A', other_designations='40S ribosomal protein S3a|fte-1|small ribosomal subunit protein eS1|v-fos transformation effector protein 1', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=151099628, end_position_on_the_genomic_accession=151104642, orientation='plus', exon_count=5, OMIM=[180478], no_hdr0=''),
    6191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6191, CurrentID=0, Status='live', Symbol='RPS4X', Aliases=['CCG2', 'DXS306', 'RPS4', 'S4', 'SCAR', 'SCR10'], description='ribosomal protein S4 X-linked', other_designations='40S ribosomal protein S4, X isoform|cell cycle gene 2|single copy abundant mRNA protein|single-copy abundant mRNA|small ribosomal subunit protein eS4', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72272042, end_position_on_the_genomic_accession=72277248, orientation='minus', exon_count=7, OMIM=[312760], no_hdr0=''),
    6192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6192, CurrentID=0, Status='live', Symbol='RPS4Y1', Aliases=['RPS4Y', 'S4'], description='ribosomal protein S4 Y-linked 1', other_designations='40S ribosomal protein S4, Y isoform 1|40S ribosomal protein S4, Y|ribosomal protein S4, Y-linked|ribosomal protein S4Y|small ribosomal subunit protein eS4', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=2841602, end_position_on_the_genomic_accession=2867268, orientation='plus', exon_count=7, OMIM=[470000], no_hdr0=''),
    6193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6193, CurrentID=0, Status='live', Symbol='RPS5', Aliases=['S5'], description='ribosomal protein S5', other_designations='40S ribosomal protein S5|small ribosomal subunit protein uS7', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58387269, end_position_on_the_genomic_accession=58394804, orientation='plus', exon_count=6, OMIM=[603630], no_hdr0=''),
    6194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6194, CurrentID=0, Status='live', Symbol='RPS6', Aliases=['S6'], description='ribosomal protein S6', other_designations='40S ribosomal protein S6|phosphoprotein NP33|small ribosomal subunit protein eS6', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19375715, end_position_on_the_genomic_accession=19380236, orientation='minus', exon_count=6, OMIM=[180460], no_hdr0=''),
    6195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6195, CurrentID=0, Status='live', Symbol='RPS6KA1', Aliases=['HU-1', 'MAPKAPK1', 'MAPKAPK1A', 'RSK', 'RSK1', 'p90Rsk'], description='ribosomal protein S6 kinase A1', other_designations='ribosomal protein S6 kinase alpha-1|90 kDa ribosomal protein S6 kinase 1|MAP kinase-activated protein kinase 1a|MAPK-activated protein kinase 1a|MAPKAP kinase 1a|MAPKAPK-1a|RSK-1|S6K-alpha 1|dJ590P13.1 (ribosomal protein S6 kinase, 90kD, polypeptide 1)|p90-RSK 1|p90RSK1|p90S6K|ribosomal S6 kinase 1|ribosomal protein S6 kinase, 90kDa, polypeptide 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26529761, end_position_on_the_genomic_accession=26575028, orientation='plus', exon_count=25, OMIM=[601684], no_hdr0=''),
    6196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6196, CurrentID=0, Status='live', Symbol='RPS6KA2', Aliases=['HU-2', 'MAPKAPK1C', 'RSK', 'RSK3', 'S6K-alpha', 'S6K-alpha2', 'p90-RSK3', 'p90RSK2', 'pp90RSK3'], description='ribosomal protein S6 kinase A2', other_designations='ribosomal protein S6 kinase alpha-2|MAP kinase-activated protein kinase 1c|MAPK-activated protein kinase 1c|mitogen-activated protein kinase-activated protein kinase 1C|ribosomal S6 kinase 3|ribosomal protein S6 kinase, 90kDa, polypeptide 2', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166409364, end_position_on_the_genomic_accession=166862525, orientation='minus', exon_count=26, OMIM=[601685], no_hdr0=''),
    6197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6197, CurrentID=0, Status='live', Symbol='RPS6KA3', Aliases=['CLS', 'HU-3', 'ISPK-1', 'MAPKAPK1B', 'MRX19', 'RSK', 'RSK2', 'S6K-alpha3', 'p90-RSK2', 'pp90RSK2'], description='ribosomal protein S6 kinase A3', other_designations='ribosomal protein S6 kinase alpha-3|MAP kinase-activated protein kinase 1b|MAPK-activated protein kinase 1b|MAPKAP kinase 1b|MAPKAPK-1b|RSK-2|S6K-alpha-3|epididymis secretory sperm binding protein|insulin-stimulated protein kinase 1|p90-RSK 3|ribosomal S6 kinase 2|ribosomal protein S6 kinase, 90kDa, polypeptide 3', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=20149911, end_position_on_the_genomic_accession=20267514, orientation='minus', exon_count=27, OMIM=[300075], no_hdr0=''),
    6198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6198, CurrentID=0, Status='live', Symbol='RPS6KB1', Aliases=['PS6K', 'S6K', 'S6K-beta-1', 'S6K1', 'STK14A', 'p70 S6KA', 'p70(S6K)-alpha', 'p70-S6K', 'p70-alpha'], description='ribosomal protein S6 kinase B1', other_designations='ribosomal protein S6 kinase beta-1|ribosomal protein S6 kinase I|ribosomal protein S6 kinase, 70kDa, polypeptide 1|serine/threonine kinase 14 alpha|serine/threonine-protein kinase 14A', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59893121, end_position_on_the_genomic_accession=59950574, orientation='plus', exon_count=19, OMIM=[608938], no_hdr0=''),
    6199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6199, CurrentID=0, Status='live', Symbol='RPS6KB2', Aliases=['KLS', 'P70-beta', 'P70-beta-1', 'P70-beta-2', 'S6K-beta2', 'S6K2', 'S6KB', 'S6KI(2)', 'S6Kbeta', 'SRK', 'STK14B', 'p70(S6K)-beta', 'p70S6Kb'], description='ribosomal protein S6 kinase B2', other_designations='ribosomal protein S6 kinase beta-2|70 kDa ribosomal protein S6 kinase 2|P70S6K2|S6 kinase-related kinase|S6K-beta|S6K-beta-2|p70 S6 kinase beta|p70 S6K-beta|p70 S6KB|p70 ribosomal S6 kinase beta|p70-S6K 2|ribosomal protein S6 kinase, 70kDa, polypeptide 2|serine/threonine-protein kinase 14 beta|serine/threonine-protein kinase 14B', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67428475, end_position_on_the_genomic_accession=67435408, orientation='plus', exon_count=16, OMIM=[608939], no_hdr0=''),
    6201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6201, CurrentID=0, Status='live', Symbol='RPS7', Aliases=['DBA8', 'S7', 'eS7'], description='ribosomal protein S7', other_designations='40S ribosomal protein S7|small ribosomal subunit protein eS7', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3575260, end_position_on_the_genomic_accession=3580920, orientation='plus', exon_count=7, OMIM=[603658], no_hdr0=''),
    6202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6202, CurrentID=0, Status='live', Symbol='RPS8', Aliases=['S8'], description='ribosomal protein S8', other_designations='40S ribosomal protein S8|OK/SW-cl.83|small ribosomal subunit protein eS8', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44775540, end_position_on_the_genomic_accession=44778779, orientation='plus', exon_count=6, OMIM=[600357], no_hdr0=''),
    6203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6203, CurrentID=0, Status='live', Symbol='RPS9', Aliases=['S9'], description='ribosomal protein S9', other_designations='40S ribosomal protein S9|small ribosomal subunit protein uS4', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54200557, end_position_on_the_genomic_accession=54207647, orientation='plus', exon_count=7, OMIM=[603631], no_hdr0=''),
    6204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6204, CurrentID=0, Status='live', Symbol='RPS10', Aliases=['DBA9', 'S10'], description='ribosomal protein S10', other_designations='40S ribosomal protein S10|small ribosomal subunit protein eS10', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34417454, end_position_on_the_genomic_accession=34426069, orientation='minus', exon_count=6, OMIM=[603632], no_hdr0=''),
    6205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6205, CurrentID=0, Status='live', Symbol='RPS11', Aliases=['S11'], description='ribosomal protein S11', other_designations='40S ribosomal protein S11|small ribosomal subunit protein uS17', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49496434, end_position_on_the_genomic_accession=49499708, orientation='plus', exon_count=5, OMIM=[180471], no_hdr0=''),
    6206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6206, CurrentID=0, Status='live', Symbol='RPS12', Aliases=['S12'], description='ribosomal protein S12', other_designations='40S ribosomal protein S12|small ribosomal subunit protein eS12', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132814569, end_position_on_the_genomic_accession=132817564, orientation='plus', exon_count=6, OMIM=[603660], no_hdr0=''),
    6207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6207, CurrentID=0, Status='live', Symbol='RPS13', Aliases=['S13'], description='ribosomal protein S13', other_designations='40S ribosomal protein S13|small ribosomal subunit protein uS15', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17074388, end_position_on_the_genomic_accession=17077667, orientation='minus', exon_count=6, OMIM=[180476], no_hdr0=''),
    6208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6208, CurrentID=0, Status='live', Symbol='RPS14', Aliases=['EMTB', 'S14'], description='ribosomal protein S14', other_designations='40S ribosomal protein S14|emetine resistance|small ribosomal subunit protein uS11', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150442635, end_position_on_the_genomic_accession=150449739, orientation='minus', exon_count=5, OMIM=[130620], no_hdr0=''),
    6209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6209, CurrentID=0, Status='live', Symbol='RPS15', Aliases=['RIG', 'S15'], description='ribosomal protein S15', other_designations='40S ribosomal protein S15|homolog of rat insulinoma|insulinoma protein|small ribosomal subunit protein uS19', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1438396, end_position_on_the_genomic_accession=1440495, orientation='plus', exon_count=4, OMIM=[180535], no_hdr0=''),
    6210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6210, CurrentID=0, Status='live', Symbol='RPS15A', Aliases=['DBA20', 'S15a'], description='ribosomal protein S15a', other_designations='40S ribosomal protein S15a|small ribosomal subunit protein uS8|up-regulated by HBV X protein', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18781295, end_position_on_the_genomic_accession=18790334, orientation='minus', exon_count=5, OMIM=[603674], no_hdr0=''),
    6217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6217, CurrentID=0, Status='live', Symbol='RPS16', Aliases=['S16'], description='ribosomal protein S16', other_designations='40S ribosomal protein S16|small ribosomal subunit protein uS9', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39433137, end_position_on_the_genomic_accession=39435949, orientation='minus', exon_count=5, OMIM=[603675], no_hdr0=''),
    6218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6218, CurrentID=0, Status='live', Symbol='RPS17', Aliases=['DBA4L', 'RPS17L1', 'RPS17L2', 'S17', 'RPS17'], description='ribosomal protein S17', other_designations='40S ribosomal protein S17|small ribosomal subunit protein eS17', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82536750, end_position_on_the_genomic_accession=82540457, orientation='minus', exon_count=6, OMIM=[180472], no_hdr0=''),
    6222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6222, CurrentID=0, Status='live', Symbol='RPS18', Aliases=['D6S218E', 'HKE3', 'KE-3', 'KE3', 'S18'], description='ribosomal protein S18', other_designations='40S ribosomal protein S18|rhabdomyosarcoma antigen MU-RMS-40.21|small ribosomal subunit protein uS13', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33272075, end_position_on_the_genomic_accession=33276511, orientation='plus', exon_count=6, OMIM=[180473], no_hdr0=''),
    6223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6223, CurrentID=0, Status='live', Symbol='RPS19', Aliases=['DBA', 'DBA1', 'LOH19CR1', 'S19', 'eS19'], description='ribosomal protein S19', other_designations='40S ribosomal protein S19|loss of heterozygosity on chromosome 19, region 1|loss of heterozygosity, 19, chromosomal region 1|small ribosomal subunit protein eS19', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41860255, end_position_on_the_genomic_accession=41872925, orientation='plus', exon_count=6, OMIM=[603474], no_hdr0=''),
    6224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6224, CurrentID=0, Status='live', Symbol='RPS20', Aliases=['S20', 'uS10'], description='ribosomal protein S20', other_designations='40S ribosomal protein S20|small ribosomal subunit protein uS10', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56067254, end_position_on_the_genomic_accession=56074506, orientation='minus', exon_count=6, OMIM=[603682], no_hdr0=''),
    6227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6227, CurrentID=0, Status='live', Symbol='RPS21', Aliases=['HLDF', 'S21'], description='ribosomal protein S21', other_designations='40S ribosomal protein S21|8.2 kDa differentiation factor|human leukemia differentiation factor|small ribosomal subunit protein eS21', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62386275, end_position_on_the_genomic_accession=62388520, orientation='plus', exon_count=4, OMIM=[180477], no_hdr0=''),
    6228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6228, CurrentID=0, Status='live', Symbol='RPS23', Aliases=['BTDD', 'MABAS', 'MCINS', 'PAMAS', 'S23', 'uS12'], description='ribosomal protein S23', other_designations='40S ribosomal protein S23|homolog of yeast ribosomal protein S28|small ribosomal subunit protein uS12', map_location='5q14.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=82273320, end_position_on_the_genomic_accession=82278354, orientation='minus', exon_count=4, OMIM=[603683], no_hdr0=''),
    6229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6229, CurrentID=0, Status='live', Symbol='RPS24', Aliases=['DBA3', 'S24', 'eS24'], description='ribosomal protein S24', other_designations='40S ribosomal protein S24|small ribosomal subunit protein eS24', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=78033863, end_position_on_the_genomic_accession=78056806, orientation='plus', exon_count=9, OMIM=[602412], no_hdr0=''),
    6230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6230, CurrentID=0, Status='live', Symbol='RPS25', Aliases=['S25'], description='ribosomal protein S25', other_designations='40S ribosomal protein S25|small ribosomal subunit protein eS25', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119015717, end_position_on_the_genomic_accession=119018343, orientation='minus', exon_count=5, OMIM=[180465], no_hdr0=''),
    6231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6231, CurrentID=0, Status='live', Symbol='RPS26', Aliases=['DBA10', 'S26', 'eS26'], description='ribosomal protein S26', other_designations='40S ribosomal protein S26|small ribosomal subunit protein eS26', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56041918, end_position_on_the_genomic_accession=56044697, orientation='plus', exon_count=4, OMIM=[603701], no_hdr0=''),
    6232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6232, CurrentID=0, Status='live', Symbol='RPS27', Aliases=['DBA17', 'MPS-1', 'MPS1', 'S27'], description='ribosomal protein S27', other_designations='40S ribosomal protein S27|metallopan-stimulin 1|metallopanstimulin 1|small ribosomal subunit protein eS27', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153990762, end_position_on_the_genomic_accession=153992155, orientation='plus', exon_count=4, OMIM=[603702], no_hdr0=''),
    6233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6233, CurrentID=0, Status='live', Symbol='RPS27A', Aliases=['CEP80', 'HEL112', 'S27A', 'UBA80', 'UBC', 'UBCEP1', 'UBCEP80'], description='ribosomal protein S27a', other_designations='ubiquitin-40S ribosomal protein S27a|40S ribosomal protein S27a|epididymis luminal protein 112|ubiquitin C|ubiquitin and ribosomal protein S27a|ubiquitin carboxyl extension protein 80|ubiquitin-CEP80', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55231903, end_position_on_the_genomic_accession=55235853, orientation='plus', exon_count=7, OMIM=[191343], no_hdr0=''),
    6234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6234, CurrentID=0, Status='live', Symbol='RPS28', Aliases=['DBA15', 'S28', 'eS28'], description='ribosomal protein S28', other_designations='40S ribosomal protein S28|small ribosomal subunit protein eS28', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8321496, end_position_on_the_genomic_accession=8323340, orientation='plus', exon_count=4, OMIM=[603685], no_hdr0=''),
    6235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6235, CurrentID=0, Status='live', Symbol='RPS29', Aliases=['DBA13', 'S29', 'uS14'], description='ribosomal protein S29', other_designations='40S ribosomal protein S29|small ribosomal subunit protein uS14', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49570988, end_position_on_the_genomic_accession=49598710, orientation='minus', exon_count=5, OMIM=[603633], no_hdr0=''),
    6236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6236, CurrentID=0, Status='live', Symbol='RRAD', Aliases=['RAD', 'RAD1', 'REM3'], description='RRAD, Ras related glycolysis inhibitor and calcium channel regulator', other_designations='GTP-binding protein RAD|RAS (RAD and GEM) like GTP binding 3|RRAD, Ras related glycolysis inihibitor and calcium channel regulator|Ras-related associated with diabetes|ras associated with diabetes', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66921685, end_position_on_the_genomic_accession=66925535, orientation='minus', exon_count=5, OMIM=[179503], no_hdr0=''),
    6237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6237, CurrentID=0, Status='live', Symbol='RRAS', Aliases=['R-Ras'], description='RAS related', other_designations='ras-related protein R-Ras|oncogene RRAS|p23|ras family small GTP binding protein R-Ras|related RAS viral (r-ras) oncogene homolog', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49635292, end_position_on_the_genomic_accession=49640143, orientation='minus', exon_count=6, OMIM=[165090], no_hdr0=''),
    6238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6238, CurrentID=0, Status='live', Symbol='RRBP1', Aliases=['ES/130', 'ES130', 'RRp', 'hES', 'p180'], description='ribosome binding protein 1', other_designations='ribosome-binding protein 1|180 kDa ribosome receptor homolog|ES/130-related protein|endoplasmic reticulum ribosome-binding protein 1|ribosomal receptor-binding protein 1|ribosome binding protein 1 homolog 180kDa (dog)|ribosome receptor protein', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17613679, end_position_on_the_genomic_accession=17682242, orientation='minus', exon_count=26, OMIM=[601418], no_hdr0=''),
    6239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6239, CurrentID=0, Status='live', Symbol='RREB1', Aliases=['FINB', 'HNT', 'LZ321', 'RREB-1', 'Zep-1'], description='ras responsive element binding protein 1', other_designations='ras-responsive element-binding protein 1|DNA-binding protein|finger protein in nuclear bodies|hindsight homolog|raf-responsive zinc finger protein LZ321|zinc finger motif enhancer-binding protein 1', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7107743, end_position_on_the_genomic_accession=7251980, orientation='plus', exon_count=14, OMIM=[602209], no_hdr0=''),
    6240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6240, CurrentID=0, Status='live', Symbol='RRM1', Aliases=['R1', 'RIR1', 'RR1'], description='ribonucleotide reductase catalytic subunit M1', other_designations='ribonucleoside-diphosphate reductase large subunit|ribonucleoside-diphosphate reductase subunit M1|ribonucleotide reductase M1 polypeptide|ribonucleotide reductase, R1 subunit', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4094685, end_position_on_the_genomic_accession=4138932, orientation='plus', exon_count=20, OMIM=[180410], no_hdr0=''),
    6241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6241, CurrentID=0, Status='live', Symbol='RRM2', Aliases=['C2orf48', 'R2', 'RR2', 'RR2M'], description='ribonucleotide reductase regulatory subunit M2', other_designations='ribonucleoside-diphosphate reductase subunit M2|ribonucleotide reductase M2 polypeptide|ribonucleotide reductase small chain|ribonucleotide reductase small subunit|uncharacterized protein C2orf48', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10122568, end_position_on_the_genomic_accession=10211010, orientation='plus', exon_count=14, OMIM=[180390], no_hdr0=''),
    6242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6242, CurrentID=0, Status='live', Symbol='RTKN', Aliases=[], description='rhotekin', other_designations='rhotekin', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74425835, end_position_on_the_genomic_accession=74441937, orientation='minus', exon_count=16, OMIM=[602288], no_hdr0=''),
    6247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6247, CurrentID=0, Status='live', Symbol='RS1', Aliases=['RS', 'XLRS1'], description='retinoschisin 1', other_designations='retinoschisin|X-linked juvenile retinoschisis protein', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18639688, end_position_on_the_genomic_accession=18672108, orientation='minus', exon_count=6, OMIM=[300839], no_hdr0=''),
    6248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6248, CurrentID=0, Status='live', Symbol='RSC1A1', Aliases=['RS1'], description='regulator of solute carriers 1', other_designations='regulatory solute carrier protein family 1 member 1|regulatory solute carrier protein, family 1, member 1|transporter regulator RS1', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15659713, end_position_on_the_genomic_accession=15662033, orientation='plus', exon_count=1, OMIM=[601966], no_hdr0=''),
    6249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6249, CurrentID=0, Status='live', Symbol='CLIP1', Aliases=['CLIP', 'CLIP-17070', 'CYLN1', 'RSN', 'CLIP1'], description='CAP-Gly domain containing linker protein 1', other_designations='CAP-Gly domain-containing linker protein 1|cytoplasmic linker protein 1|cytoplasmic linker protein 170 alpha-2|cytoplasmic linker protein CLIP-170|restin (Reed-Steinberg cell-expressed intermediate filament-associated protein)', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122271432, end_position_on_the_genomic_accession=122422956, orientation='minus', exon_count=31, OMIM=[179838], no_hdr0=''),
    6251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6251, CurrentID=0, Status='live', Symbol='RSU1', Aliases=['RSP-1'], description='Ras suppressor protein 1', other_designations='ras suppressor protein 1|ras suppressor protein 1 variant 1|ras suppressor protein 1 variant 2|ras suppressor protein 1 variant 3|ras suppressor protein 1 variant 5|rsu-1', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=16590611, end_position_on_the_genomic_accession=16817451, orientation='minus', exon_count=9, OMIM=[179555], no_hdr0=''),
    6252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6252, CurrentID=0, Status='live', Symbol='RTN1', Aliases=['NSP'], description='reticulon 1', other_designations='reticulon-1|neuroendocrine-specific protein', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59595976, end_position_on_the_genomic_accession=59871288, orientation='minus', exon_count=12, OMIM=[600865], no_hdr0=''),
    6253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6253, CurrentID=0, Status='live', Symbol='RTN2', Aliases=['NSP2', 'NSPL1', 'NSPLI', 'SPG12'], description='reticulon 2', other_designations='reticulon-2|NSP-like protein 1|NSP-like protein I|neuroendocrine-specific protein-like I', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45485294, end_position_on_the_genomic_accession=45497047, orientation='minus', exon_count=11, OMIM=[603183], no_hdr0=''),
    6256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6256, CurrentID=0, Status='live', Symbol='RXRA', Aliases=['NR2B1'], description='retinoid X receptor alpha', other_designations='retinoic acid receptor RXR-alpha|nuclear receptor subfamily 2 group B member 1|retinoid X nuclear receptor alpha', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134326455, end_position_on_the_genomic_accession=134440585, orientation='plus', exon_count=12, OMIM=[180245], no_hdr0=''),
    6257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6257, CurrentID=0, Status='live', Symbol='RXRB', Aliases=['DAUDI6', 'H-2RIIBP', 'NR2B2', 'RCoR-1'], description='retinoid X receptor beta', other_designations='retinoic acid receptor RXR-beta|MHC class I promoter binding protein|nuclear receptor subfamily 2 group B member 2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33193588, end_position_on_the_genomic_accession=33200991, orientation='minus', exon_count=10, OMIM=[180246], no_hdr0=''),
    6258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6258, CurrentID=0, Status='live', Symbol='RXRG', Aliases=['NR2B3', 'RXRC'], description='retinoid X receptor gamma', other_designations='retinoic acid receptor RXR-gamma|nuclear receptor subfamily 2 group B member 3', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165400922, end_position_on_the_genomic_accession=165445126, orientation='minus', exon_count=12, OMIM=[180247], no_hdr0=''),
    6259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6259, CurrentID=0, Status='live', Symbol='RYK', Aliases=['D3S3195', 'JTK5', 'JTK5A1', 'RYK'], description='receptor like tyrosine kinase', other_designations='tyrosine-protein kinase RYK|JTK5A protein tyrosine kinase|hydroxyaryl-protein kinase', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134157133, end_position_on_the_genomic_accession=134250859, orientation='minus', exon_count=15, OMIM=[600524], no_hdr0=''),
    6261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6261, CurrentID=0, Status='live', Symbol='RYR1', Aliases=['CCO', 'MHS', 'MHS1', 'PPP1R137', 'RYDR', 'RYR', 'RYR-1', 'SKRR'], description='ryanodine receptor 1', other_designations='ryanodine receptor 1|central core disease of muscle|protein phosphatase 1, regulatory subunit 137|ryanodine receptor 1 (skeletal)|sarcoplasmic reticulum calcium release channel|skeletal muscle calcium release channel|skeletal muscle ryanodine receptor|type 1-like ryanodine receptor', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38433691, end_position_on_the_genomic_accession=38587564, orientation='plus', exon_count=106, OMIM=[180901], no_hdr0=''),
    6262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6262, CurrentID=0, Status='live', Symbol='RYR2', Aliases=['ARVC2', 'ARVD2', 'RYR-2', 'RyR', 'VACRDS', 'VTSIP'], description='ryanodine receptor 2', other_designations='ryanodine receptor 2|cardiac muscle ryanodine receptor-calcium release channel|cardiac-type ryanodine receptor|islet-type ryanodine receptor|kidney-type ryanodine receptor|ryanodine receptor 2 (cardiac)|type 2 ryanodine receptor', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=237042184, end_position_on_the_genomic_accession=237833988, orientation='plus', exon_count=107, OMIM=[180902], no_hdr0=''),
    6263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6263, CurrentID=0, Status='live', Symbol='RYR3', Aliases=['RYR-3'], description='ryanodine receptor 3', other_designations='ryanodine receptor 3|brain ryanodine receptor-calcium release channel|brain-type ryanodine receptor|type 3 ryanodine receptor', map_location='15q13.3-q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=33310773, end_position_on_the_genomic_accession=33866103, orientation='plus', exon_count=107, OMIM=[180903], no_hdr0=''),
    6271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6271, CurrentID=0, Status='live', Symbol='S100A1', Aliases=['S100', 'S100-alpha', 'S100A'], description='S100 calcium binding protein A1', other_designations='protein S100-A1|S-100 protein alpha chain|S-100 protein subunit alpha|S100 alpha|S100 protein, alpha polypeptide', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153628434, end_position_on_the_genomic_accession=153632039, orientation='plus', exon_count=3, OMIM=[176940], no_hdr0=''),
    6272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6272, CurrentID=0, Status='live', Symbol='SORT1', Aliases=['Gp95', 'LDLCQ6', 'NT3', 'NTR3'], description='sortilin 1', other_designations='sortilin|100 kDa NT receptor|glycoprotein 95|neurotensin receptor 3', map_location='1p21.3-p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109309575, end_position_on_the_genomic_accession=109397940, orientation='minus', exon_count=23, OMIM=[602458], no_hdr0=''),
    6273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6273, CurrentID=0, Status='live', Symbol='S100A2', Aliases=['CAN19', 'S100L'], description='S100 calcium binding protein A2', other_designations='protein S100-A2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153561108, end_position_on_the_genomic_accession=153565844, orientation='minus', exon_count=4, OMIM=[176993], no_hdr0=''),
    6274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6274, CurrentID=0, Status='live', Symbol='S100A3', Aliases=['S100E'], description='S100 calcium binding protein A3', other_designations='protein S100-A3', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153547329, end_position_on_the_genomic_accession=153549258, orientation='minus', exon_count=3, OMIM=[176992], no_hdr0=''),
    6275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6275, CurrentID=0, Status='live', Symbol='S100A4', Aliases=['18A2', '42A', 'CAPL', 'FSP1', 'MTS1', 'P9KA', 'PEL98'], description='S100 calcium binding protein A4', other_designations='protein S100-A4|S100 calcium-binding protein A4 (calcium protein, calvasculin, metastasin, murine placental homolog)|calcium placental protein|fibroblast-specific protein-1|leukemia multidrug resistance associated protein|malignant transformation suppression 1|metastasin 1|murine placental homolog|placental calcium-binding protein|protein Mts1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153543621, end_position_on_the_genomic_accession=153545806, orientation='minus', exon_count=4, OMIM=[114210], no_hdr0=''),
    6276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6276, CurrentID=0, Status='live', Symbol='S100A5', Aliases=['S100D'], description='S100 calcium binding protein A5', other_designations='protein S100-A5', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153537114, end_position_on_the_genomic_accession=153543514, orientation='minus', exon_count=6, OMIM=[176991], no_hdr0=''),
    6277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6277, CurrentID=0, Status='live', Symbol='S100A6', Aliases=['2A9', '5B10', 'CABP', 'CACY', 'PRA', 'S10A6'], description='S100 calcium binding protein A6', other_designations='protein S100-A6|MLN 4|calcyclin|growth factor-inducible protein 2A9|prolactin receptor-associated protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153534599, end_position_on_the_genomic_accession=153536049, orientation='minus', exon_count=3, OMIM=[114110], no_hdr0=''),
    6278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6278, CurrentID=0, Status='live', Symbol='S100A7', Aliases=['PSOR1c', 'S100A7'], description='S100 calcium binding protein A7', other_designations='protein S100-A7|psoriasin 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153457744, end_position_on_the_genomic_accession=153460651, orientation='minus', exon_count=3, OMIM=[600353], no_hdr0=''),
    6279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6279, CurrentID=0, Status='live', Symbol='S100A8', Aliases=['60B8AG', 'CAGA', 'CFAG', 'CGLA', 'CP-10', 'L1Ag', 'MA387', 'MIF', 'MRP8', 'NIF', 'P8'], description='S100 calcium binding protein A8', other_designations='protein S100-A8|calgranulin A|calprotectin L1L subunit|cystic fibrosis antigen|leukocyte L1 complex light chain|migration inhibitory factor-related protein 8|urinary stone protein band A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153390032, end_position_on_the_genomic_accession=153422583, orientation='minus', exon_count=5, OMIM=[123885], no_hdr0=''),
    6280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6280, CurrentID=0, Status='live', Symbol='S100A9', Aliases=['60B8AG', 'CAGB', 'CFAG', 'CGLB', 'L1AG', 'LIAG', 'MAC387', 'MIF', 'MRP14', 'NIF', 'P14'], description='S100 calcium binding protein A9', other_designations='protein S100-A9|MRP-14|calgranulin B|calprotectin L1H subunit|leukocyte L1 complex heavy chain|migration inhibitory factor-related protein 14', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153357854, end_position_on_the_genomic_accession=153361023, orientation='plus', exon_count=3, OMIM=[123886], no_hdr0=''),
    6281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6281, CurrentID=0, Status='live', Symbol='S100A10', Aliases=['42C', 'ANX2L', 'ANX2LG', 'CAL1L', 'CLP11', 'Ca[1]', 'GP11', 'P11', 'p10'], description='S100 calcium binding protein A10', other_designations='protein S100-A10|S100 calcium binding protein A10 (annexin II ligand, calpactin I, light polypeptide (p11))|annexin II ligand, calpactin I, light polypeptide|annexin II tetramer (AIIt) p11 subunit|calpactin I light chain|calpactin-1 light chain|cellular ligand of annexin II', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151982915, end_position_on_the_genomic_accession=151993859, orientation='minus', exon_count=3, OMIM=[114085], no_hdr0=''),
    6282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6282, CurrentID=0, Status='live', Symbol='S100A11', Aliases=['HEL-S-43', 'MLN70', 'S100C'], description='S100 calcium binding protein A11', other_designations='protein S100-A11|MLN 70|calgizzarin|epididymis secretory protein Li 43|metastatic lymph node gene 70 protein|protein S100-C', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152032506, end_position_on_the_genomic_accession=152037004, orientation='minus', exon_count=3, OMIM=[603114], no_hdr0=''),
    6283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6283, CurrentID=0, Status='live', Symbol='S100A12', Aliases=['CAAF1', 'CAGC', 'CGRP', 'ENRAGE', 'MRP-6', 'MRP6', 'p6'], description='S100 calcium binding protein A12', other_designations='protein S100-A12|EN-RAGE|calcitermin|calcium-binding protein in amniotic fluid 1|calgranulin C|extracellular newly identified RAGE-binding protein|migration inhibitory factor-related protein 6|neutrophil S100 protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153373711, end_position_on_the_genomic_accession=153375621, orientation='minus', exon_count=3, OMIM=[603112], no_hdr0=''),
    6284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6284, CurrentID=0, Status='live', Symbol='S100A13', Aliases=[], description='S100 calcium binding protein A13', other_designations='protein S100-A13', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153618799, end_position_on_the_genomic_accession=153634361, orientation='minus', exon_count=10, OMIM=[601989], no_hdr0=''),
    6285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6285, CurrentID=0, Status='live', Symbol='S100B', Aliases=['NEF', 'S100', 'S100-B', 'S100beta'], description='S100 calcium binding protein B', other_designations='protein S100-B|S-100 calcium-binding protein, beta chain|S-100 protein subunit beta|S100 calcium-binding protein, beta (neural)', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46598604, end_position_on_the_genomic_accession=46605243, orientation='minus', exon_count=3, OMIM=[176990], no_hdr0=''),
    6286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6286, CurrentID=0, Status='live', Symbol='S100P', Aliases=['MIG9'], description='S100 calcium binding protein P', other_designations='protein S100-P|migration-inducing gene 9 protein|protein S100-E', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6693878, end_position_on_the_genomic_accession=6697170, orientation='plus', exon_count=2, OMIM=[600614], no_hdr0=''),
    6288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6288, CurrentID=0, Status='live', Symbol='SAA1', Aliases=['PIG4', 'SAA', 'SAA2', 'TP53I4'], description='serum amyloid A1', other_designations='serum amyloid A-1 protein|serum amyloid A protein|tumor protein p53 inducible protein 4', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18266264, end_position_on_the_genomic_accession=18269967, orientation='plus', exon_count=4, OMIM=[104750], no_hdr0=''),
    6289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6289, CurrentID=0, Status='live', Symbol='SAA2', Aliases=['SAA', 'SAA1'], description='serum amyloid A2', other_designations='serum amyloid A-2 protein|Serum amyloid A-1 protein', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18238236, end_position_on_the_genomic_accession=18248668, orientation='minus', exon_count=7, OMIM=[104751], no_hdr0=''),
    6291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6291, CurrentID=0, Status='live', Symbol='SAA4', Aliases=['C-SAA', 'CSAA'], description='serum amyloid A4, constitutive', other_designations='serum amyloid A-4 protein|constitutively expressed serum amyloid A protein', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18231355, end_position_on_the_genomic_accession=18236802, orientation='minus', exon_count=4, OMIM=[104752], no_hdr0=''),
    6293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6293, CurrentID=0, Status='live', Symbol='VPS52', Aliases=['ARE1', 'SAC2', 'SACM2L', 'dJ1033B10.5'], description='VPS52 subunit of GARP complex', other_designations='vacuolar protein sorting-associated protein 52 homolog|SAC2 suppressor of actin mutations 2-like protein|VPS52, GARP complex subunit|vacuolar protein sorting 52 homolog', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33250272, end_position_on_the_genomic_accession=33271965, orientation='minus', exon_count=23, OMIM=[603443], no_hdr0=''),
    6294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6294, CurrentID=0, Status='live', Symbol='SAFB', Aliases=['HAP', 'HET', 'SAB-B1', 'SAF-B', 'SAF-B11', 'SAFB'], description='scaffold attachment factor B', other_designations='scaffold attachment factor B1|HSP27 ERE-TATA-binding protein|HSP27 estrogen response element-TATA box-binding protein|Hsp27 ERE-TATA binding protein|glutathione S-transferase fusion protein|heat-shock protein (HSP27) estrogen response element and TATA box-binding protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5623081, end_position_on_the_genomic_accession=5668478, orientation='plus', exon_count=21, OMIM=[602895], no_hdr0=''),
    6295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6295, CurrentID=0, Status='live', Symbol='SAG', Aliases=['RP47', 'S-AG'], description='S-antigen visual arrestin', other_designations='S-arrestin|48 kDa protein|S-antigen; retina and pineal gland (arrestin)|arrestin 1|retinal S-antigen (48 KDa protein)|rod arrestin|rod photoreceptor arrestin', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233307816, end_position_on_the_genomic_accession=233347066, orientation='plus', exon_count=21, OMIM=[181031], no_hdr0=''),
    6296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6296, CurrentID=0, Status='live', Symbol='ACSM3', Aliases=['SA', 'SAH'], description='acyl-CoA synthetase medium chain family member 3', other_designations='acyl-coenzyme A synthetase ACSM3, mitochondrial|SA (rat hypertension-associated) homolog|SA hypertension-associated homolog|butyrate--CoA ligase 3|butyryl-coenzyme A synthetase 3|middle-chain acyl-CoA synthetase 3|propionate--CoA ligase|protein SA homolog', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20742440, end_position_on_the_genomic_accession=20797811, orientation='plus', exon_count=19, OMIM=[145505], no_hdr0=''),
    6297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6297, CurrentID=0, Status='live', Symbol='SALL2', Aliases=['COLB', 'HSAL2', 'Sal-2', 'ZNF795', 'p150(Sal2)'], description='spalt like transcription factor 2', other_designations='sal-like protein 2|zinc finger protein 795|zinc finger protein SALL2|zinc finger protein Spalt-2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21521080, end_position_on_the_genomic_accession=21537142, orientation='minus', exon_count=5, OMIM=[602219], no_hdr0=''),
    6299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6299, CurrentID=0, Status='live', Symbol='SALL1', Aliases=['HEL-S-89', 'HSAL1', 'Sal-1', 'TBS', 'ZNF794'], description='spalt like transcription factor 1', other_designations='sal-like protein 1|epididymis secretory protein Li 89|zinc finger protein 794|zinc finger protein SALL1|zinc finger protein Spalt-1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=51135982, end_position_on_the_genomic_accession=51151270, orientation='minus', exon_count=4, OMIM=[602218], no_hdr0=''),
    6300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6300, CurrentID=0, Status='live', Symbol='MAPK12', Aliases=['ERK-6', 'ERK3', 'ERK6', 'MAPK 12', 'P38GAMMA', 'PRKM12', 'SAPK-3', 'SAPK3'], description='mitogen-activated protein kinase 12', other_designations='mitogen-activated protein kinase 12|MAP kinase 12|MAP kinase p38 gamma|extracellular signal-regulated kinase 6|mitogen-activated protein kinase 3|mitogen-activated protein kinase p38 gamma|stress-activated protein kinase 3', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50252901, end_position_on_the_genomic_accession=50261683, orientation='minus', exon_count=12, OMIM=[602399], no_hdr0=''),
    6301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6301, CurrentID=0, Status='live', Symbol='SARS1', Aliases=['NEDMAS', 'SARS', 'SERRS', 'SERS'], description='seryl-tRNA synthetase 1', other_designations='serine--tRNA ligase, cytoplasmic|serine tRNA ligase 1, cytoplasmic|seryl-tRNA synthetase, cytoplasmic|seryl-tRNA(Ser/Sec) synthetase', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109213893, end_position_on_the_genomic_accession=109238182, orientation='plus', exon_count=13, OMIM=[607529], no_hdr0=''),
    6302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6302, CurrentID=0, Status='live', Symbol='TSPAN31', Aliases=['SAS'], description='tetraspanin 31', other_designations='tetraspanin-31|sarcoma-amplified sequence|transmembrane 4 protein|tspan-31', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57745039, end_position_on_the_genomic_accession=57750219, orientation='plus', exon_count=7, OMIM=[181035], no_hdr0=''),
    6303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6303, CurrentID=0, Status='live', Symbol='SAT1', Aliases=['DC21', 'KFSD', 'KFSDX', 'SAT', 'SSAT', 'SSAT-1'], description='spermidine/spermine N1-acetyltransferase 1', other_designations='diamine acetyltransferase 1|diamine N-acetyltransferase 1|epididymis secretory sperm binding protein|polyamine N-acetyltransferase 1|putrescine acetyltransferase|spermidine/spermine N1-acetyltransferase alpha', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23783173, end_position_on_the_genomic_accession=23786210, orientation='plus', exon_count=7, OMIM=[313020], no_hdr0=''),
    6304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6304, CurrentID=0, Status='live', Symbol='SATB1', Aliases=['DEFDA', 'KTZSL'], description='SATB homeobox 1', other_designations='DNA-binding protein SATB1|special AT-rich sequence binding protein 1 (binds to nuclear matrix/scaffold-associating DNA)', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=18345377, end_position_on_the_genomic_accession=18445592, orientation='minus', exon_count=17, OMIM=[602075], no_hdr0=''),
    6305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6305, CurrentID=0, Status='live', Symbol='SBF1', Aliases=['CMT4B3', 'DENND7A', 'MTMR5'], description='SET binding factor 1', other_designations='myotubularin-related protein 5|DENN/MADD domain containing 7A|inactive phosphatidylinositol 3-phosphatase 5', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50445000, end_position_on_the_genomic_accession=50475035, orientation='minus', exon_count=42, OMIM=[603560], no_hdr0=''),
    6307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6307, CurrentID=0, Status='live', Symbol='MSMO1', Aliases=['DESP4', 'ERG25', 'MCCPD', 'SC4MOL'], description='methylsterol monooxygenase 1', other_designations='methylsterol monooxygenase 1|C-4 methylsterol oxidase|sterol-C4-methyl oxidase', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165327669, end_position_on_the_genomic_accession=165343164, orientation='plus', exon_count=6, OMIM=[607545], no_hdr0=''),
    6309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6309, CurrentID=0, Status='live', Symbol='SC5D', Aliases=['ERG3', 'S5DESL', 'SC5D'], description='sterol-C5-desaturase', other_designations='lathosterol oxidase|3beta-hydroxysteroid-delta5-desaturase|C-5 sterol desaturase|delta(7)-sterol 5(6)-desaturase|delta(7)-sterol 5-desaturase|delta(7)-sterol C5(6)-desaturase|fungal ERG3, delta-5-desaturase-like|lathosterol 5-desaturase|lathosterol dehydrogenase|sterol-C5-desaturase (ERG3 delta-5-desaturase homolog, S. cerevisiae)-like', map_location='11q23.3-q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=121292771, end_position_on_the_genomic_accession=121313410, orientation='plus', exon_count=6, OMIM=[602286], no_hdr0=''),
    6310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6310, CurrentID=0, Status='live', Symbol='ATXN1', Aliases=['ATX1', 'D6S504E', 'SCA1'], description='ataxin 1', other_designations='ataxin-1|alternative ataxin1|spinocerebellar ataxia type 1 protein', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=16299112, end_position_on_the_genomic_accession=16761490, orientation='minus', exon_count=11, OMIM=[601556], no_hdr0=''),
    6311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6311, CurrentID=0, Status='live', Symbol='ATXN2', Aliases=['ATX2', 'SCA2', 'TNRC13'], description='ataxin 2', other_designations='ataxin-2|spinocerebellar ataxia type 2 protein|trinucleotide repeat-containing gene 13 protein', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111452214, end_position_on_the_genomic_accession=111599673, orientation='minus', exon_count=27, OMIM=[601517], no_hdr0=''),
    6314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6314, CurrentID=0, Status='live', Symbol='ATXN7', Aliases=['ADCAII', 'OPCA3', 'SCA7', 'SGF73'], description='ataxin 7', other_designations='ataxin-7|spinocerebellar ataxia type 7 protein', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=63863144, end_position_on_the_genomic_accession=64003462, orientation='plus', exon_count=22, OMIM=[607640], no_hdr0=''),
    6317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6317, CurrentID=0, Status='live', Symbol='SERPINB3', Aliases=['HsT1196', 'SCC', 'SCCA-1', 'SCCA-PD', 'SCCA1', 'SSCA1', 'T4-A'], description='serpin family B member 3', other_designations='serpin B3|protein T4-A|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 3|serpin peptidase inhibitor, clade B (ovalbumin), member 3|squamous cell carcinoma antigen 1', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63655197, end_position_on_the_genomic_accession=63661893, orientation='minus', exon_count=8, OMIM=[600517], no_hdr0=''),
    6318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6318, CurrentID=0, Status='live', Symbol='SERPINB4', Aliases=['LEUPIN', 'PI11', 'SCCA-2', 'SCCA1', 'SCCA2'], description='serpin family B member 4', other_designations='serpin B4|SCCA2/SCCA1 fusion protein|peptidase inhibitor 11|protease inhibitor (leucine-serpin)|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 4|serpin peptidase inhibitor, clade B (ovalbumin), member 4|squamous cell carcinoma antigen 1|squamous cell carcinoma antigen 2', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63637259, end_position_on_the_genomic_accession=63644310, orientation='minus', exon_count=8, OMIM=[600518], no_hdr0=''),
    6319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6319, CurrentID=0, Status='live', Symbol='SCD', Aliases=['FADS5', 'MSTP0081', 'SCDOS', 'hSCD1', 'SCD'], description='stearoyl-CoA desaturase', other_designations='stearoyl-CoA desaturase|acyl-CoA desaturase|delta(9)-desaturase|fatty acid desaturase|predicted protein of HQ0998|stearoyl-CoA desaturase (delta-9-desaturase)|stearoyl-CoA desaturase opposite strand', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100347233, end_position_on_the_genomic_accession=100364826, orientation='plus', exon_count=6, OMIM=[604031], no_hdr0=''),
    6320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6320, CurrentID=0, Status='live', Symbol='CLEC11A', Aliases=['CLECSF3', 'LSLCL', 'P47', 'SCGF'], description='C-type lectin domain containing 11A', other_designations='C-type lectin domain family 11 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 3|C-type lectin superfamily member 3|lymphocyte secreted C-type lectin|lymphocyte secreted long form of C-type lectin|osteolectin|stem cell growth factor|stem cell growth factor; lymphocyte secreted C-type lectin', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50723364, end_position_on_the_genomic_accession=50725708, orientation='plus', exon_count=4, OMIM=[604713], no_hdr0=''),
    6322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6322, CurrentID=0, Status='live', Symbol='SCML1', Aliases=[], description='Scm polycomb group protein like 1', other_designations='sex comb on midleg-like protein 1|sex comb on midleg like 1', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=17737457, end_position_on_the_genomic_accession=17754985, orientation='plus', exon_count=8, OMIM=[300227], no_hdr0=''),
    6323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6323, CurrentID=0, Status='live', Symbol='SCN1A', Aliases=['DEE6', 'DEE6A', 'DEE6B', 'DRVT', 'EIEE6', 'FEB3', 'FEB3A', 'FHM3', 'GEFSP2', 'HBSCI', 'NAC1', 'Nav1.1', 'SCN1', 'SMEI'], description='sodium voltage-gated channel alpha subunit 1', other_designations='sodium channel protein type 1 subunit alpha|sodium channel protein type I subunit alpha|sodium channel protein, brain I alpha subunit|sodium channel voltage gated type 1 alpha subunit|sodium channel, voltage-gated, type I, alpha polypeptide|sodium channel, voltage-gated, type I, alpha subunit|voltage-gated sodium channel subunit alpha Nav1.1', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165984641, end_position_on_the_genomic_accession=166149161, orientation='minus', exon_count=31, OMIM=[182389], no_hdr0=''),
    6324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6324, CurrentID=0, Status='live', Symbol='SCN1B', Aliases=['ATFB13', 'BRGDA5', 'DEE52', 'EIEE52', 'GEFSP1'], description='sodium voltage-gated channel beta subunit 1', other_designations='sodium channel subunit beta-1|sodium channel, voltage gated, type I beta subunit|sodium channel, voltage-gated, type I, beta', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35030470, end_position_on_the_genomic_accession=35040449, orientation='plus', exon_count=7, OMIM=[600235], no_hdr0=''),
    6326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6326, CurrentID=0, Status='live', Symbol='SCN2A', Aliases=['BFIC3', 'BFIS3', 'BFNIS', 'DEE11', 'EA9', 'EIEE11', 'HBA', 'HBSCI', 'HBSCII', 'NAC2', 'Na(v)1.2', 'Nav1.21', 'SCN2A2', 'SCN2A'], description='sodium voltage-gated channel alpha subunit 2', other_designations='sodium channel protein type 2 subunit alpha|sodium channel protein brain II subunit alpha|sodium channel protein type II subunit alpha|sodium channel protein, brain type 2 alpha subunit|sodium channel, voltage-gated, type II, alpha 1 polypeptide|sodium channel, voltage-gated, type II, alpha 2 polypeptide|sodium channel, voltage-gated, type II, alpha subunit|voltage-gated sodium channel subtype II|voltage-gated sodium channel subunit alpha Nav1.2|voltage-gated sodium channel type II alpha subunit', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165239414, end_position_on_the_genomic_accession=165392304, orientation='plus', exon_count=31, OMIM=[182390], no_hdr0=''),
    6327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6327, CurrentID=0, Status='live', Symbol='SCN2B', Aliases=['ATFB14'], description='sodium voltage-gated channel beta subunit 2', other_designations='sodium channel subunit beta-2|neuronal voltage-gated sodium channel beta 2 subunit|sodium channel, voltage gated, type II beta subunit|sodium channel, voltage-gated, type II, beta polypeptide', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118162806, end_position_on_the_genomic_accession=118176639, orientation='minus', exon_count=4, OMIM=[601327], no_hdr0=''),
    6328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6328, CurrentID=0, Status='live', Symbol='SCN3A', Aliases=['DEE62', 'EIEE62', 'FFEVF4', 'NAC3', 'Nav1.3'], description='sodium voltage-gated channel alpha subunit 3', other_designations='sodium channel protein type 3 subunit alpha|brain III voltage-gated sodium channel|sodium channel protein brain III subunit alpha|sodium channel protein type III subunit alpha|sodium channel, voltage gated, type III alpha subunit|sodium channel, voltage-gated, type III, alpha polypeptide|voltage-gated sodium channel subtype III|voltage-gated sodium channel subunit alpha Nav1.3', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165087526, end_position_on_the_genomic_accession=165204295, orientation='minus', exon_count=31, OMIM=[182391], no_hdr0=''),
    6329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6329, CurrentID=0, Status='live', Symbol='SCN4A', Aliases=['CMS16', 'HOKPP2', 'HYKPP', 'HYPP', 'NAC1A', 'Na(V)1.4', 'Nav1.4', 'SkM1'], description='sodium voltage-gated channel alpha subunit 4', other_designations='sodium channel protein type 4 subunit alpha|CTC-264K15.6|skeletal muscle sodium channel alpha subunit|skeletal muscle voltage-dependent sodium channel type IV alpha subunit|sodium channel protein skeletal muscle subunit alpha|sodium channel protein type IV subunit alpha|sodium channel, voltage-gated, type IV, alpha subunit|voltage-gated sodium channel subunit alpha Nav1.4', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63938554, end_position_on_the_genomic_accession=63972918, orientation='minus', exon_count=24, OMIM=[603967], no_hdr0=''),
    6330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6330, CurrentID=0, Status='live', Symbol='SCN4B', Aliases=['ATFB17', 'LQT10', 'Navbeta4'], description='sodium voltage-gated channel beta subunit 4', other_designations='sodium channel subunit beta-4|sodium channel, voltage-gated, type IV, beta subunit', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118133377, end_position_on_the_genomic_accession=118152823, orientation='minus', exon_count=5, OMIM=[608256], no_hdr0=''),
    6331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6331, CurrentID=0, Status='live', Symbol='SCN5A', Aliases=['CDCD2', 'CMD1E', 'CMPD2', 'HB1', 'HB2', 'HBBD', 'HH1', 'ICCD', 'IVF', 'LQT3', 'Nav1.5', 'PFHB1', 'SSS1', 'VF1'], description='sodium voltage-gated channel alpha subunit 5', other_designations='sodium channel protein type 5 subunit alpha|cardiac tetrodotoxin-insensitive voltage-dependent sodium channel alpha subunit|sodium channel protein cardiac muscle subunit alpha|sodium channel, voltage-gated, type V, alpha subunit|voltage-gated sodium channel subunit alpha Nav1.5', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38548061, end_position_on_the_genomic_accession=38649687, orientation='minus', exon_count=29, OMIM=[600163], no_hdr0=''),
    6332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6332, CurrentID=0, Status='live', Symbol='SCN7A', Aliases=['NaG', 'Nav2.1', 'Nav2.2', 'SCN6A'], description='sodium voltage-gated channel alpha subunit 7', other_designations='sodium channel protein type 7 subunit alpha|putative voltage-gated sodium channel subunit alpha Nax|sodium channel protein cardiac and skeletal muscle subunit alpha|sodium channel protein type VII subunit alpha|sodium channel, voltage-gated, type VI, alpha polypeptide|sodium channel, voltage-gated, type VII, alpha subunit|voltage-dependent sodium channel alpha subunit', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=166403573, end_position_on_the_genomic_accession=166494264, orientation='minus', exon_count=29, OMIM=[182392], no_hdr0=''),
    6334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6334, CurrentID=0, Status='live', Symbol='SCN8A', Aliases=['BFIS5', 'CERIII', 'CIAT', 'DEE13', 'EIEE13', 'MED', 'MYOCL2', 'NaCh6', 'Nav1.6', 'PN4'], description='sodium voltage-gated channel alpha subunit 8', other_designations='sodium channel protein type 8 subunit alpha|hNa6/Scn8a voltage-gated sodium channel|sodium channel, voltage gated, type VIII, alpha subunit|voltage-gated sodium channel subunit alpha Nav1.6|voltage-gated sodium channel type VIII alpha protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51591233, end_position_on_the_genomic_accession=51812864, orientation='plus', exon_count=28, OMIM=[600702], no_hdr0=''),
    6335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6335, CurrentID=0, Status='live', Symbol='SCN9A', Aliases=['ETHA', 'FEB3B', 'GEFSP7', 'HSAN2D', 'NE-NA', 'NENA', 'Nav1.7', 'PN1', 'SFNP'], description='sodium voltage-gated channel alpha subunit 9', other_designations='sodium channel protein type 9 subunit alpha|hNE-Na|neuroendocrine sodium channel|peripheral sodium channel 1|sodium channel protein type IX subunit alpha|sodium channel, voltage-gated, type IX, alpha polypeptide|sodium channel, voltage-gated, type IX, alpha subunit|voltage-gated sodium channel alpha subunit Nav1.7|voltage-gated sodium channel subunit alpha Nav1.7', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=166195185, end_position_on_the_genomic_accession=166375987, orientation='minus', exon_count=30, OMIM=[603415], no_hdr0=''),
    6336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6336, CurrentID=0, Status='live', Symbol='SCN10A', Aliases=['FEPS2', 'Nav1.8', 'PN3', 'SNS'], description='sodium voltage-gated channel alpha subunit 10', other_designations='sodium channel protein type 10 subunit alpha|peripheral nerve sodium channel 3|sensory neuron sodium channel|sodium channel protein type X subunit alpha|sodium channel, voltage-gated, type X, alpha polypeptide|sodium channel, voltage-gated, type X, alpha subunit|voltage-gated sodium channel subunit alpha Nav1.8', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38696807, end_position_on_the_genomic_accession=38816217, orientation='minus', exon_count=28, OMIM=[604427], no_hdr0=''),
    6337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6337, CurrentID=0, Status='live', Symbol='SCNN1A', Aliases=['BESC2', 'ENaCa', 'ENaCalpha', 'LIDLS3', 'SCNEA', 'SCNN1'], description='sodium channel epithelial 1 subunit alpha', other_designations='amiloride-sensitive sodium channel subunit alpha|alpha ENaC-2|alpha-ENaC|alpha-NaCH|amiloride-sensitive epithelial sodium channel alpha subunit|amiloride-sensitive sodium channel subunit alpha 2|epithelial Na(+) channel subunit alpha|nasal epithelial sodium channel alpha subunit|nonvoltage-gated sodium channel 1 subunit alpha|sodium channel epithelial 1 alpha subunit|sodium channel, non voltage gated 1 alpha subunit|sodium channel, non-voltage-gated 1 alpha|sodium channel, nonvoltage-gated 1 alpha', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6346847, end_position_on_the_genomic_accession=6377359, orientation='minus', exon_count=14, OMIM=[600228], no_hdr0=''),
    6338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6338, CurrentID=0, Status='live', Symbol='SCNN1B', Aliases=['BESC1', 'ENaCb', 'ENaCbeta', 'LIDLS1', 'SCNEB'], description='sodium channel epithelial 1 subunit beta', other_designations='amiloride-sensitive sodium channel subunit beta|amiloride-sensitive sodium channel subunit beta 1|beta-ENaC|beta-NaCH|epithelial Na(+) channel subunit beta|epithelial sodium channel beta-2 subunit|epithelial sodium channel beta-3 subunit|mutant sodium channel epithelial 1 beta subunit|nasal epithelial sodium channel beta subunit|nonvoltage-gated sodium channel 1 subunit beta|sodium channel epithelial 1 beta subunit|sodium channel, non-voltage-gated 1, beta subunit', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23278231, end_position_on_the_genomic_accession=23381295, orientation='plus', exon_count=17, OMIM=[600760], no_hdr0=''),
    6339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6339, CurrentID=0, Status='live', Symbol='SCNN1D', Aliases=['ENaCd', 'ENaCdelta', 'SCNED', 'dNaCh'], description='sodium channel epithelial 1 subunit delta', other_designations='amiloride-sensitive sodium channel subunit delta|delta-ENaC|delta-NaCH|epithelial Na(+) channel subunit delta|nonvoltage-gated sodium channel 1 subunit delta|sodium channel epithelial 1 delta subunit|sodium channel, non-voltage-gated 1, delta subunit|sodium channel, nonvoltage-gated 1, delta|sodium channel, voltage-gated, type I, delta polypeptide', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1280436, end_position_on_the_genomic_accession=1292025, orientation='plus', exon_count=18, OMIM=[601328], no_hdr0=''),
    6340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6340, CurrentID=0, Status='live', Symbol='SCNN1G', Aliases=['BESC3', 'ENaCg', 'ENaCgamma', 'LDLS2', 'PHA1', 'SCNEG'], description='sodium channel epithelial 1 subunit gamma', other_designations='amiloride-sensitive sodium channel subunit gamma|ENaC gamma subunit|amiloride-sensitive epithelial sodium channel gamma subunit|amiloride-sensitive sodium channel gamma-subunit|epithelial Na(+) channel subunit gamma|gamma-ENaC|gamma-NaCH|nonvoltage-gated sodium channel 1 subunit gamma|sodium channe epithelial 1 gamma subunit|sodium channel epithelial 1 gamma subunit|sodium channel, non-voltage-gated 1, gamma subunit|sodium channel, nonvoltage-gated 1, gamma', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23182745, end_position_on_the_genomic_accession=23216883, orientation='plus', exon_count=13, OMIM=[600761], no_hdr0=''),
    6341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6341, CurrentID=0, Status='live', Symbol='SCO1', Aliases=['MC4DN4', 'SCOD1'], description='synthesis of cytochrome C oxidase 1', other_designations='protein SCO1 homolog, mitochondrial|SCO cytochrome c oxidase assembly protein 1|SCO cytochrome oxidase deficient homolog 1|SCO1, cytochrome c oxidase assembly protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10672474, end_position_on_the_genomic_accession=10697533, orientation='minus', exon_count=6, OMIM=[603644], no_hdr0=''),
    6342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6342, CurrentID=0, Status='live', Symbol='SCP2', Aliases=['NLTP', 'NSL-TP', 'SCOX', 'SCP-2', 'SCP-CHI', 'SCP-X', 'SCPX'], description='sterol carrier protein 2', other_designations='sterol carrier protein 2|SCP-2/3-oxoacyl-CoA thiolase|SCP-2/thiolase|acetyl-CoA C-myristoyltransferase|epididymis secretory sperm binding protein|non-specific lipid-transfer protein|propanoyl-CoA C-acyltransferase|sterol carrier protein X|straight-chain acyl-CoA oxidase', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52927276, end_position_on_the_genomic_accession=53051698, orientation='plus', exon_count=18, OMIM=[184755], no_hdr0=''),
    6343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6343, CurrentID=0, Status='live', Symbol='SCT', Aliases=[], description='secretin', other_designations='secretin|prepro-secretin', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=626095, end_position_on_the_genomic_accession=627692, orientation='minus', exon_count=5, OMIM=[182099], no_hdr0=''),
    6344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6344, CurrentID=0, Status='live', Symbol='SCTR', Aliases=['SR'], description='secretin receptor', other_designations='secretin receptor|pancreatic secretin receptor', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119439843, end_position_on_the_genomic_accession=119524483, orientation='minus', exon_count=16, OMIM=[182098], no_hdr0=''),
    6345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6345, CurrentID=0, Status='live', Symbol='SRL', Aliases=['SAR'], description='sarcalumenin', other_designations='sarcalumenin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4189374, end_position_on_the_genomic_accession=4242253, orientation='minus', exon_count=10, OMIM=[604992], no_hdr0=''),
    6346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6346, CurrentID=0, Status='live', Symbol='CCL1', Aliases=['I-309', 'P500', 'SCYA1', 'SISe', 'TCA3'], description='C-C motif chemokine ligand 1', other_designations='C-C motif chemokine 1|T lymphocyte-secreted protein I-309|chemokine (C-C motif) ligand 1|inflammatory cytokine I-309|small inducible cytokine A1 (I-309, homologous to mouse Tca-3)', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34360328, end_position_on_the_genomic_accession=34363233, orientation='minus', exon_count=3, OMIM=[182281], no_hdr0=''),
    6347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6347, CurrentID=0, Status='live', Symbol='CCL2', Aliases=['GDCF-2', 'HC11', 'HSMCR30', 'MCAF', 'MCP-1', 'MCP1', 'SCYA2', 'SMC-CF'], description='C-C motif chemokine ligand 2', other_designations='C-C motif chemokine 2|chemokine (C-C motif) ligand 2|monocyte chemoattractant protein-1|monocyte chemotactic and activating factor|monocyte chemotactic protein 1|monocyte secretory protein JE|small inducible cytokine A2 (monocyte chemotactic protein 1, homologous to mouse Sig-je)|small inducible cytokine subfamily A (Cys-Cys), member 2|small-inducible cytokine A2', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34255285, end_position_on_the_genomic_accession=34257203, orientation='plus', exon_count=3, OMIM=[158105], no_hdr0=''),
    6348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6348, CurrentID=0, Status='live', Symbol='CCL3', Aliases=['G0S19-1', 'LD78ALPHA', 'MIP-1-alpha', 'MIP1A', 'SCYA3'], description='C-C motif chemokine ligand 3', other_designations='C-C motif chemokine 3|G0/G1 switch regulatory protein 19-1|PAT 464.1|SIS-beta|macrophage inflammatory protein 1-alpha|small inducible cytokine A3 (homologous to mouse Mip-1a)|tonsillar lymphocyte LD78 alpha protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36088256, end_position_on_the_genomic_accession=36090143, orientation='minus', exon_count=2, OMIM=[182283], no_hdr0=''),
    6349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6349, CurrentID=0, Status='live', Symbol='CCL3L1', Aliases=['464.2', 'D17S1718', 'G0S19-2', 'LD78', 'LD78-beta(1-70)', 'LD78BETA', 'MIP1AP', 'SCYA3L', 'SCYA3L1'], description='C-C motif chemokine ligand 3 like 1', other_designations='C-C motif chemokine 3-like 1|G0/G1 switch regulatory protein 19-2|chemokine (C-C motif) ligand 3-like 1|small inducible cytokine A3-like 1|tonsillar lymphocyte LD78 beta protein', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[601395], no_hdr0=''),
    6351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6351, CurrentID=0, Status='live', Symbol='CCL4', Aliases=['ACT2', 'AT744.1', 'G-26', 'HC21', 'LAG-1', 'LAG1', 'MIP-1-beta', 'MIP1B', 'MIP1B1', 'SCYA2', 'SCYA4'], description='C-C motif chemokine ligand 4', other_designations='C-C motif chemokine 4|G-26 T-lymphocyte-secreted protein|MIP-1-beta(1-69)|PAT 744|SIS-gamma|T-cell activation protein 2|chemokine (C-C motif) ligand 4|lymphocyte activation gene 1 protein|macrophage inflammatory protein 1-beta|secreted protein G-26|small inducible cytokine A4 (homologous to mouse Mip-1b)', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36103827, end_position_on_the_genomic_accession=36105614, orientation='plus', exon_count=3, OMIM=[182284], no_hdr0=''),
    6352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6352, CurrentID=0, Status='live', Symbol='CCL5', Aliases=['D17S136E', 'RANTES', 'SCYA5', 'SIS-delta', 'SISd', 'TCP228', 'eoCP'], description='C-C motif chemokine ligand 5', other_designations='C-C motif chemokine 5|T-cell specific protein p288|beta-chemokine RANTES|chemokine (C-C motif) ligand 5|eosinophil chemotactic cytokine|regulated upon activation, normally T-expressed, and presumably secreted|small inducible cytokine subfamily A (Cys-Cys), member 5', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35871491, end_position_on_the_genomic_accession=35880360, orientation='minus', exon_count=4, OMIM=[187011], no_hdr0=''),
    6354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6354, CurrentID=0, Status='live', Symbol='CCL7', Aliases=['FIC', 'MARC', 'MCP-3', 'MCP3', 'NC28', 'SCYA6', 'SCYA7'], description='C-C motif chemokine ligand 7', other_designations='C-C motif chemokine 7|chemokine (C-C motif) ligand 7|monocyte chemoattractant protein 3|monocyte chemotactic protein 3|small inducible cytokine A7 (monocyte chemotactic protein 3)|small-inducible cytokine A7', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34270221, end_position_on_the_genomic_accession=34272242, orientation='plus', exon_count=3, OMIM=[158106], no_hdr0=''),
    6355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6355, CurrentID=0, Status='live', Symbol='CCL8', Aliases=['HC14', 'MCP-2', 'MCP2', 'SCYA10', 'SCYA8'], description='C-C motif chemokine ligand 8', other_designations='C-C motif chemokine 8|chemokine (C-C motif) ligand 8|monocyte chemoattractant protein 2|monocyte chemotactic protein 2|small inducible cytokine subfamily A (Cys-Cys), member 8 (monocyte chemotactic protein 2)|small-inducible cytokine A8', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34319435, end_position_on_the_genomic_accession=34321402, orientation='plus', exon_count=3, OMIM=[602283], no_hdr0=''),
    6356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6356, CurrentID=0, Status='live', Symbol='CCL11', Aliases=['SCYA11'], description='C-C motif chemokine ligand 11', other_designations='eotaxin|chemokine (C-C motif) ligand 11|eosinophil chemotactic protein|eotaxin-1|small inducible cytokine subfamily A (Cys-Cys), member 11 (eotaxin)', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34285742, end_position_on_the_genomic_accession=34288334, orientation='plus', exon_count=3, OMIM=[601156], no_hdr0=''),
    6357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6357, CurrentID=0, Status='live', Symbol='CCL13', Aliases=['CKb10', 'MCP-4', 'NCC-1', 'NCC1', 'SCYA13', 'SCYL1'], description='C-C motif chemokine ligand 13', other_designations='C-C motif chemokine 13|CK-beta-10|chemokine (C-C motif) ligand 13|monocyte chemoattractant protein 4|monocyte chemotactic protein 4|new CC chemokine 1|small inducible cytokine subfamily A (Cys-Cys), member 13|small-inducible cytokine A13', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34356480, end_position_on_the_genomic_accession=34358610, orientation='plus', exon_count=3, OMIM=[601391], no_hdr0=''),
    6358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6358, CurrentID=0, Status='live', Symbol='CCL14', Aliases=['CC-1', 'CC-3', 'CKB1', 'HCC-1', 'HCC-1(1-74)', 'HCC-1/HCC-3', 'HCC-3', 'MCIF', 'NCC-2', 'NCC2', 'SCYA14', 'SCYL2', 'SY14'], description='C-C motif chemokine ligand 14', other_designations='C-C motif chemokine 14|chemokine (C-C motif) ligand 14|chemokine CC-1/CC-3|chemokine CC-3|hemofiltrate CC chemokine 1|new CC chemokine 2|small inducible cytokine subfamily A (Cys-Cys), member 14|small-inducible cytokine A14', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35983288, end_position_on_the_genomic_accession=35986729, orientation='minus', exon_count=4, OMIM=[601392], no_hdr0=''),
    6359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6359, CurrentID=0, Status='live', Symbol='CCL15', Aliases=['HCC-2', 'HMRP-2B', 'LKN-1', 'LKN1', 'MIP-1 delta', 'MIP-1D', 'MIP-5', 'MRP-2B', 'NCC-3', 'NCC3', 'SCYA15', 'SCYL3', 'SY15'], description='C-C motif chemokine ligand 15', other_designations='C-C motif chemokine 15|chemokine (C-C motif) ligand 15|chemokine CC-2|leukotactin 1|macrophage inflammatory protein 5|new CC chemokine 3|small inducible cytokine subfamily A (Cys-Cys), member 15|small-inducible cytokine A15', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35997582, end_position_on_the_genomic_accession=36001553, orientation='minus', exon_count=4, OMIM=[601393], no_hdr0=''),
    6360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6360, CurrentID=0, Status='live', Symbol='CCL16', Aliases=['CKb12', 'HCC-4', 'ILINCK', 'LCC-1', 'LEC', 'LMC', 'Mtn-1', 'NCC-4', 'NCC4', 'SCYA16', 'SCYL4'], description='C-C motif chemokine ligand 16', other_designations='C-C motif chemokine 16|IL-10-inducible chemokine|chemokine (C-C motif) ligand 16|chemokine LEC|liver CC chemokine-1|liver-expressed chemokine|lymphocyte and monocyte chemoattractant|monotactin-1|new CC chemokine 4|small inducible cytokine subfamily A (Cys-Cys), member 16|small-inducible cytokine A16', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35976493, end_position_on_the_genomic_accession=35983620, orientation='minus', exon_count=5, OMIM=[601394], no_hdr0=''),
    6361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6361, CurrentID=0, Status='live', Symbol='CCL17', Aliases=['A-152E5.3', 'ABCD-2', 'SCYA17', 'TARC'], description='C-C motif chemokine ligand 17', other_designations='C-C motif chemokine 17|CC chemokine TARC|T cell-directed CC chemokine|chemokine (C-C motif) ligand 17|small inducible cytokine subfamily A (Cys-Cys), member 17|small-inducible cytokine A17|thymus and activation-regulated chemokine', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57396076, end_position_on_the_genomic_accession=57416063, orientation='plus', exon_count=6, OMIM=[601520], no_hdr0=''),
    6362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6362, CurrentID=0, Status='live', Symbol='CCL18', Aliases=['AMAC-1', 'AMAC1', 'CKb7', 'DC-CK1', 'DCCK1', 'MIP-4', 'PARC', 'SCYA18'], description='C-C motif chemokine ligand 18', other_designations='C-C motif chemokine 18|CC chemokine PARC|CC chemokine ligand 18|alternative macrophage activation-associated CC chemokine 1|chemokine (C-C motif) ligand 18 (pulmonary and activation-regulated)|chemokine (C-C), dendritic|dendritic cell chemokine 1|macrophage inflammatory protein 4|pulmonary and activation-regulated chemokine|small inducible cytokine A18|small inducible cytokine subfamily A (Cys-Cys), member 18, pulmonary and activation-regulated', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36064272, end_position_on_the_genomic_accession=36072032, orientation='plus', exon_count=3, OMIM=[603757], no_hdr0=''),
    6363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6363, CurrentID=0, Status='live', Symbol='CCL19', Aliases=['CKb11', 'ELC', 'MIP-3b', 'MIP3B', 'SCYA19'], description='C-C motif chemokine ligand 19', other_designations='C-C motif chemokine 19|CC chemokine ligand 19|CK beta-11|EBI1-ligand chemokine|MIP-3-beta|beta chemokine exodus-3|chemokine (C-C motif) ligand 19|epstein-Barr virus-induced molecule 1 ligand chemokine|exodus-3|macrophage inflammatory protein 3-beta|small inducible cytokine subfamily A (Cys-Cys), member 19|small-inducible cytokine A19', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34689570, end_position_on_the_genomic_accession=34691276, orientation='minus', exon_count=4, OMIM=[602227], no_hdr0=''),
    6364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6364, CurrentID=0, Status='live', Symbol='CCL20', Aliases=['CKb4', 'Exodus', 'LARC', 'MIP-3-alpha', 'MIP-3a', 'MIP3A', 'SCYA20', 'ST38'], description='C-C motif chemokine ligand 20', other_designations='C-C motif chemokine 20|CC chemokine LARC|beta chemokine exodus-1|chemokine (C-C motif) ligand 20|liver and activation-regulated chemokine|macrophage inflammatory protein 3 alpha|small inducible cytokine subfamily A (Cys-Cys), member 20|small-inducible cytokine A20', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227813842, end_position_on_the_genomic_accession=227817556, orientation='plus', exon_count=4, OMIM=[601960], no_hdr0=''),
    6366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6366, CurrentID=0, Status='live', Symbol='CCL21', Aliases=['6Ckine', 'CKb9', 'ECL', 'SCYA21', 'SLC', 'TCA4'], description='C-C motif chemokine ligand 21', other_designations='C-C motif chemokine 21|Efficient Chemoattractant for Lymphocytes|beta chemokine exodus-2|chemokine (C-C motif) ligand 21|secondary lymphoid tissue chemokine|small inducible cytokine subfamily A (Cys-Cys), member 21', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34709005, end_position_on_the_genomic_accession=34710136, orientation='minus', exon_count=4, OMIM=[602737], no_hdr0=''),
    6367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6367, CurrentID=0, Status='live', Symbol='CCL22', Aliases=['A-152E5.1', 'ABCD-1', 'DC/B-CK', 'MDC', 'SCYA22', 'STCP-1'], description='C-C motif chemokine ligand 22', other_designations='C-C motif chemokine 22|CC chemokine STCP-1|MDC(1-69)|chemokine (C-C motif) ligand 22|macrophage-derived chemokine|small inducible cytokine A22|small inducible cytokine subfamily A (Cys-Cys), member 22|stimulated T cell chemotactic protein 1', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57358783, end_position_on_the_genomic_accession=57366189, orientation='plus', exon_count=3, OMIM=[602957], no_hdr0=''),
    6368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6368, CurrentID=0, Status='live', Symbol='CCL23', Aliases=['CK-BETA-8', 'CKb8', 'Ckb-8', 'Ckb-8-1', 'MIP-3', 'MIP3', 'MPIF-1', 'SCYA23', 'hmrp-2a'], description='C-C motif chemokine ligand 23', other_designations='C-C motif chemokine 23|C6 beta-chemokine|chemokine (C-C motif) ligand 23|macrophage inflammatory protein 3|myeloid progenitor inhibitory factor 1|small inducible cytokine subfamily A (Cys-Cys), member 23', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36013056, end_position_on_the_genomic_accession=36018179, orientation='minus', exon_count=4, OMIM=[602494], no_hdr0=''),
    6369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6369, CurrentID=0, Status='live', Symbol='CCL24', Aliases=['Ckb-6', 'MPIF-2', 'MPIF2', 'SCYA24'], description='C-C motif chemokine ligand 24', other_designations='C-C motif chemokine 24|CK-beta-6|chemokine (C-C motif) ligand 24|eosinophil chemotactic protein 2|eotaxin-2|myeloid progenitor inhibitory factor 2|small inducible cytokine subfamily A (Cys-Cys), member 24|small-inducible cytokine A24', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75810825, end_position_on_the_genomic_accession=75823372, orientation='minus', exon_count=6, OMIM=[602495], no_hdr0=''),
    6370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6370, CurrentID=0, Status='live', Symbol='CCL25', Aliases=['Ck beta-15', 'Ckb15', 'SCYA25', 'TECK'], description='C-C motif chemokine ligand 25', other_designations='C-C motif chemokine 25|TECKvar|chemokine (C-C motif) ligand 25|chemokine TECK|small inducible cytokine subfamily A (Cys-Cys), member 25|small-inducible cytokine A25|thymus expressed chemokine', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8052341, end_position_on_the_genomic_accession=8062650, orientation='plus', exon_count=7, OMIM=[602565], no_hdr0=''),
    6372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6372, CurrentID=0, Status='live', Symbol='CXCL6', Aliases=['CKA-3', 'GCP-2', 'GCP2', 'SCYB6'], description='C-X-C motif chemokine ligand 6', other_designations='C-X-C motif chemokine 6|chemokine (C-X-C motif) ligand 6 (granulocyte chemotactic protein 2)|chemokine alpha 3|granulocyte chemotactic protein 2|small inducible cytokine subfamily B (Cys-X-Cys), member 6 (granulocyte chemotactic protein 2)|small inducible cytokine subfamily B (Cys-X-Cys), member b|small-inducible cytokine B6', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73836678, end_position_on_the_genomic_accession=73838760, orientation='plus', exon_count=4, OMIM=[138965], no_hdr0=''),
    6373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6373, CurrentID=0, Status='live', Symbol='CXCL11', Aliases=['H174', 'I-TAC', 'IP-9', 'IP9', 'SCYB11', 'SCYB9B', 'b-R1'], description='C-X-C motif chemokine ligand 11', other_designations='C-X-C motif chemokine 11|beta-R1|chemokine (C-X-C motif) ligand 11|interferon gamma-inducible protein 9|interferon-inducible T-cell alpha chemoattractant|small inducible cytokine B11|small inducible cytokine subfamily B (Cys-X-Cys), member 11|small inducible cytokine subfamily B (Cys-X-Cys), member 9B', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76033682, end_position_on_the_genomic_accession=76036070, orientation='minus', exon_count=4, OMIM=[604852], no_hdr0=''),
    6374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6374, CurrentID=0, Status='live', Symbol='CXCL5', Aliases=['ENA-78', 'SCYB5'], description='C-X-C motif chemokine ligand 5', other_designations='C-X-C motif chemokine 5|chemokine (C-X-C motif) ligand 5|epithelial-derived neutrophil-activating protein 78|neutrophil-activating peptide ENA-78|neutrophil-activating protein 78|small inducible cytokine subfamily B (Cys-X-Cys), member 5 (epithelial-derived neutrophil-activating peptide 78)', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73995642, end_position_on_the_genomic_accession=73998677, orientation='minus', exon_count=4, OMIM=[600324], no_hdr0=''),
    6375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6375, CurrentID=0, Status='live', Symbol='XCL1', Aliases=['ATAC', 'LPTN', 'LTN', 'SCM-1', 'SCM-1a', 'SCM1', 'SCM1A', 'SCYC1'], description='X-C motif chemokine ligand 1', other_designations='lymphotactin|SCM-1-alpha|XC chemokine ligand 1|c motif chemokine 1|chemokine (C motif) ligand 1|cytokine SCM-1|lymphotaxin|single cysteine motif 1a|small inducible cytokine subfamily C, member 1 (lymphotactin)|small-inducible cytokine C1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168574128, end_position_on_the_genomic_accession=168582069, orientation='plus', exon_count=4, OMIM=[600250], no_hdr0=''),
    6376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6376, CurrentID=0, Status='live', Symbol='CX3CL1', Aliases=['ABCD-3', 'C3Xkine', 'CXC3', 'CXC3C', 'NTN', 'NTT', 'SCYD1', 'fractalkine', 'neurotactin'], description='C-X3-C motif chemokine ligand 1', other_designations='fractalkine|C-X3-C motif chemokine 1|CX3C membrane-anchored chemokine|chemokine (C-X3-C motif) ligand 1|small inducible cytokine subfamily D (Cys-X3-Cys), member 1 (fractalkine, neurotactin)|small inducible cytokine subfamily D (Cys-X3-Cys), member-1|small-inducible cytokine D1', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57372490, end_position_on_the_genomic_accession=57385044, orientation='plus', exon_count=3, OMIM=[601880], no_hdr0=''),
    6382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6382, CurrentID=0, Status='live', Symbol='SDC1', Aliases=['CD138', 'SDC', 'SYND1', 'syndecan'], description='syndecan 1', other_designations='syndecan-1|CD138 antigen|heparan sulfate proteoglycan fibroblast growth factor receptor|syndecan proteoglycan 1', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20200797, end_position_on_the_genomic_accession=20225475, orientation='minus', exon_count=9, OMIM=[186355], no_hdr0=''),
    6383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6383, CurrentID=0, Status='live', Symbol='SDC2', Aliases=['CD362', 'HSPG', 'HSPG1', 'SYND2'], description='syndecan 2', other_designations='syndecan-2|cell surface-associated heparan sulfate proteoglycan 1|fibroglycan|heparan sulfate proteoglycan 1, cell surface-associated|heparan sulfate proteoglycan core protein|syndecan proteoglycan 2', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96493601, end_position_on_the_genomic_accession=96611790, orientation='plus', exon_count=9, OMIM=[142460], no_hdr0=''),
    6385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6385, CurrentID=0, Status='live', Symbol='SDC4', Aliases=['SYND4'], description='syndecan 4', other_designations='syndecan-4|amphiglycan|ryudocan amphiglycan|ryudocan core protein|syndecan 4 (amphiglycan, ryudocan)|syndecan proteoglycan 4', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45325288, end_position_on_the_genomic_accession=45348424, orientation='minus', exon_count=5, OMIM=[600017], no_hdr0=''),
    6386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6386, CurrentID=0, Status='live', Symbol='SDCBP', Aliases=['MDA-9', 'MDA9', 'ST1', 'SYCL', 'TACIP18'], description='syndecan binding protein', other_designations='syntenin-1|melanoma differentiation associated protein-9|pro-TGF-alpha cytoplasmic domain-interacting protein 18|scaffold protein Pbp1|syndecan binding protein (syntenin)|syndecan-binding protein 1', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=58553261, end_position_on_the_genomic_accession=58582860, orientation='plus', exon_count=10, OMIM=[602217], no_hdr0=''),
    6387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6387, CurrentID=0, Status='live', Symbol='CXCL12', Aliases=['IRH', 'PBSF', 'SCYB12', 'SDF1', 'TLSF', 'TPAR1'], description='C-X-C motif chemokine ligand 12', other_designations='stromal cell-derived factor 1|chemokine (C-X-C motif) ligand 12|intercrine reduced in hepatomas|pre-B cell growth-stimulating factor', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=44292088, end_position_on_the_genomic_accession=44385097, orientation='minus', exon_count=9, OMIM=[600835], no_hdr0=''),
    6388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6388, CurrentID=0, Status='live', Symbol='SDF2', Aliases=[], description='stromal cell derived factor 2', other_designations='stromal cell-derived factor 2|SDF-2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28648346, end_position_on_the_genomic_accession=28662194, orientation='minus', exon_count=5, OMIM=[602934], no_hdr0=''),
    6389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6389, CurrentID=0, Status='live', Symbol='SDHA', Aliases=['CMD1GG', 'FP', 'MC2DN1', 'NDAXOA', 'PGL5', 'SDH1', 'SDH2', 'SDHF'], description='succinate dehydrogenase complex flavoprotein subunit A', other_designations='succinate dehydrogenase [ubiquinone] flavoprotein subunit, mitochondrial|flavoprotein subunit of complex II|succinate dehydrogenase complex, subunit A, flavoprotein (Fp)', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=218309, end_position_on_the_genomic_accession=264816, orientation='plus', exon_count=15, OMIM=[600857], no_hdr0=''),
    6390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6390, CurrentID=0, Status='live', Symbol='SDHB', Aliases=['CWS2', 'IP', 'MC2DN4', 'PGL4', 'SDH', 'SDH1', 'SDH2', 'SDHIP'], description='succinate dehydrogenase complex iron sulfur subunit B', other_designations='succinate dehydrogenase [ubiquinone] iron-sulfur subunit, mitochondrial|iron-sulfur subunit of complex II|succinate dehydrogenase complex, subunit B, iron sulfur (Ip)', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17018722, end_position_on_the_genomic_accession=17054032, orientation='minus', exon_count=8, OMIM=[185470], no_hdr0=''),
    6391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6391, CurrentID=0, Status='live', Symbol='SDHC', Aliases=['CYB560', 'CYBL', 'PGL3', 'QPS1', 'SDH3'], description='succinate dehydrogenase complex subunit C', other_designations='succinate dehydrogenase cytochrome b560 subunit, mitochondrial|cytochrome B large subunit of complex II|integral membrane protein CII-3b|large subunit of cytochrome b|succinate dehydrgenase cytochrome b|succinate dehydrogenase 3, integral membrane subunit|succinate dehydrogenase complex subunit C integral membrane protein 15kDa|succinate dehydrogenase complex, subunit C, integral membrane protein, 15kD|succinate-ubiquinone oxidoreductase cytochrome B large subunit', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161314381, end_position_on_the_genomic_accession=161375340, orientation='plus', exon_count=7, OMIM=[602413], no_hdr0=''),
    6392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6392, CurrentID=0, Status='live', Symbol='SDHD', Aliases=['CBT1', 'CII-4', 'CWS3', 'MC2DN3', 'PGL', 'PGL1', 'QPs3', 'SDH4', 'cybS'], description='succinate dehydrogenase complex subunit D', other_designations='succinate dehydrogenase [ubiquinone] cytochrome b small subunit, mitochondrial|succinate dehydrogenase complex subunit D integral membrane protein|succinate-ubiquinone oxidoreductase cytochrome b small subunit|succinate-ubiquinone reductase membrane anchor subunit', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112086873, end_position_on_the_genomic_accession=112095794, orientation='plus', exon_count=6, OMIM=[602690], no_hdr0=''),
    6395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6395, CurrentID=0, Status='live', Symbol='SEA', Aliases=[], description='S13 erythroblastosis (avian) oncogene homolog', other_designations='S13 erythroblastosis (avian) oncogene homolog|Oncogene SEA (S13 avian erythroblastosis)|S13 avian erythroblastosis oncogene homolog|S13 erythroblastosis oncogene homolog', map_location='11q13', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[165110], no_hdr0=''),
    6396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6396, CurrentID=0, Status='live', Symbol='SEC13', Aliases=['D3S1231EL1', 'SEC13R', 'npp-20', 'SEC13'], description='SEC13 homolog, nuclear pore and COPII coat complex component', other_designations='protein SEC13 homolog|GATOR complex protein SEC13|SEC13 homolog, nuclear pore and COPII coating complex component|SEC13-like protein 1|SEC13-related protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10300931, end_position_on_the_genomic_accession=10321112, orientation='minus', exon_count=12, OMIM=[600152], no_hdr0=''),
    6397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6397, CurrentID=0, Status='live', Symbol='SEC14L1', Aliases=['PRELID4A', 'SEC14L'], description='SEC14 like lipid binding 1', other_designations='SEC14-like protein 1', map_location='17q25.2-q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=77088685, end_position_on_the_genomic_accession=77217101, orientation='plus', exon_count=21, OMIM=[601504], no_hdr0=''),
    6398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6398, CurrentID=0, Status='live', Symbol='SECTM1', Aliases=['K12', 'SECTM'], description='secreted and transmembrane 1', other_designations='secreted and transmembrane protein 1|type 1a transmembrane protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82321024, end_position_on_the_genomic_accession=82333951, orientation='minus', exon_count=7, OMIM=[602602], no_hdr0=''),
    6399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6399, CurrentID=0, Status='live', Symbol='TRAPPC2', Aliases=['MIP2A', 'SEDL', 'SEDTP1', 'TRS20', 'ZNF547L', 'hYP38334', 'TRAPPC2'], description='trafficking protein particle complex subunit 2', other_designations='trafficking protein particle complex subunit 2|sedlin|trafficking protein particle complex 2', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13712243, end_position_on_the_genomic_accession=13734633, orientation='minus', exon_count=7, OMIM=[300202], no_hdr0=''),
    6400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6400, CurrentID=0, Status='live', Symbol='SEL1L', Aliases=['Hrd3', 'PRO1063', 'SEL1-LIKE1', 'SEL1L'], description='SEL1L adaptor subunit of ERAD E3 ubiquitin ligase', other_designations='protein sel-1 homolog 1|SEL1L, ERAD E3 ligase adaptor subunit|Suppressor of lin 12 (sel-1), C. elegans, homolog of|sel-1 suppressor of lin-12-like 1|suppressor of lin-12-like protein 1', map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=81471547, end_position_on_the_genomic_accession=81533853, orientation='minus', exon_count=21, OMIM=[602329], no_hdr0=''),
    6401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6401, CurrentID=0, Status='live', Symbol='SELE', Aliases=['CD62E', 'ELAM', 'ELAM1', 'ESEL', 'LECAM2'], description='selectin E', other_designations='E-selectin|CD62 antigen-like family member E|ELAM-1|endothelial adhesion molecule 1|endothelial leukocyte adhesion molecule 1|leukocyte endothelial cell adhesion molecule 2', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169722640, end_position_on_the_genomic_accession=169734079, orientation='minus', exon_count=14, OMIM=[131210], no_hdr0=''),
    6402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6402, CurrentID=0, Status='live', Symbol='SELL', Aliases=['CD62L', 'LAM1', 'LECAM1', 'LEU8', 'LNHR', 'LSEL', 'LYAM1', 'PLNHR', 'TQ1'], description='selectin L', other_designations='L-selectin|CD62 antigen-like family member L|gp90-MEL|leukocyte surface antigen Leu-8|leukocyte-endothelial cell adhesion molecule 1|lymph node homing receptor|lymphocyte adhesion molecule 1|pln homing receptor', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169690667, end_position_on_the_genomic_accession=169711620, orientation='minus', exon_count=9, OMIM=[153240], no_hdr0=''),
    6403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6403, CurrentID=0, Status='live', Symbol='SELP', Aliases=['CD62', 'CD62P', 'GMP140', 'GRMP', 'LECAM3', 'PADGEM', 'PSEL'], description='selectin P', other_designations='P-selectin|CD62 antigen-like family member P|GMP-140|granule membrane protein 140|granule membrane protein 140kDa|granulocyte membrane protein|leukocyte-endothelial cell adhesion molecule 3|platelet activation dependent granule-external membrane protein|platelet alpha-granule membrane protein|selectin P (granule membrane protein 140kDa, antigen CD62)', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169588849, end_position_on_the_genomic_accession=169630125, orientation='minus', exon_count=18, OMIM=[173610], no_hdr0=''),
    6404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6404, CurrentID=0, Status='live', Symbol='SELPLG', Aliases=['CD162', 'CLA', 'PSGL-1', 'PSGL1'], description='selectin P ligand', other_designations='P-selectin glycoprotein ligand 1|cutaneous lymphocyte-associated associated antigen', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108621895, end_position_on_the_genomic_accession=108633894, orientation='minus', exon_count=3, OMIM=[600738], no_hdr0=''),
    6405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6405, CurrentID=0, Status='live', Symbol='SEMA3F', Aliases=['SEMA-IV', 'SEMA4', 'SEMAK'], description='semaphorin 3F', other_designations='semaphorin-3F|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3F|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, 3F|semaphorin III/F|semaphorin IV', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50155058, end_position_on_the_genomic_accession=50189075, orientation='plus', exon_count=23, OMIM=[601124], no_hdr0=''),
    6406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6406, CurrentID=0, Status='live', Symbol='SEMG1', Aliases=['CT103', 'SEMG', 'SGI', 'dJ172H20.2'], description='semenogelin 1', other_designations='semenogelin-1|SgI-29|cancer/testis antigen 103|semen coagulating protein|semenogelin I', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45207033, end_position_on_the_genomic_accession=45209768, orientation='plus', exon_count=3, OMIM=[182140], no_hdr0=''),
    6407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6407, CurrentID=0, Status='live', Symbol='SEMG2', Aliases=['SGII'], description='semenogelin 2', other_designations='semenogelin-2|semenogelin II', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45221373, end_position_on_the_genomic_accession=45224458, orientation='plus', exon_count=3, OMIM=[182141], no_hdr0=''),
    6414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6414, CurrentID=0, Status='live', Symbol='SELENOP', Aliases=['SELP', 'SEPP', 'SEPP1', 'SeP'], description='selenoprotein P', other_designations='selenoprotein P|selenoprotein P, plasma, 1', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=42799880, end_position_on_the_genomic_accession=42811892, orientation='minus', exon_count=7, OMIM=[601484], no_hdr0=''),
    6415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6415, CurrentID=0, Status='live', Symbol='SELENOW', Aliases=['SEPW1', 'selW'], description='selenoprotein W', other_designations='selenoprotein W|selenoprotein W, 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47778703, end_position_on_the_genomic_accession=47784682, orientation='plus', exon_count=6, OMIM=[603235], no_hdr0=''),
    6416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6416, CurrentID=0, Status='live', Symbol='MAP2K4', Aliases=['JNKK', 'JNKK1', 'MAPKK4', 'MEK4', 'MKK4', 'PRKMK4', 'SAPKK-1', 'SAPKK1', 'SEK1', 'SERK1', 'SKK1'], description='mitogen-activated protein kinase kinase 4', other_designations='dual specificity mitogen-activated protein kinase kinase 4|JNK-activated kinase 1|JNK-activating kinase 1|MAP kinase kinase 4|MAPK/ERK kinase 4|MAPKK 4|MEK 4|SAPK/ERK kinase 1|c-Jun N-terminal kinase kinase 1|stress-activated protein kinase kinase 1', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=12020822, end_position_on_the_genomic_accession=12143828, orientation='plus', exon_count=15, OMIM=[601335], no_hdr0=''),
    6418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6418, CurrentID=0, Status='live', Symbol='SET', Aliases=['2PP2A', 'I2PP2A', 'IGAAD', 'IPP2A2', 'MRD58', 'PHAPII', 'TAF-I', 'TAF-IBETA'], description='SET nuclear proto-oncogene', other_designations='protein SET|HLA-DR-associated protein II|SET nuclear oncogene|SET translocation (myeloid leukemia-associated)|Template-Activating Factor-I, chromatin remodelling factor|chromatin remodelling factor|inhibitor of granzyme A-activated DNase|inhibitor-2 of protein phosphatase-2A|phosphatase 2A inhibitor I2PP2A|protein phosphatase type 2A inhibitor', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128683424, end_position_on_the_genomic_accession=128696396, orientation='plus', exon_count=13, OMIM=[600960], no_hdr0=''),
    6419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6419, CurrentID=0, Status='live', Symbol='SETMAR', Aliases=['METNASE', 'Mar1'], description='SET domain and mariner transposase fusion gene', other_designations='histone-lysine N-methyltransferase SETMAR|SET domain and mariner transposase fusion gene-containing protein|SET domain and mariner transposase fusion protein', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=4303369, end_position_on_the_genomic_accession=4320649, orientation='plus', exon_count=4, OMIM=[609834], no_hdr0=''),
    6421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6421, CurrentID=0, Status='live', Symbol='SFPQ', Aliases=['POMP100', 'PPP1R140', 'PSF'], description='splicing factor proline and glutamine rich', other_designations='splicing factor, proline- and glutamine-rich|100 kDa DNA-pairing protein|DNA-binding p52/p100 complex, 100 kDa subunit|PTB-associated splicing factor|epididymis secretory sperm binding protein|polypyrimidine tract binding protein associated|polypyrimidine tract-binding protein-associated splicing factor|protein phosphatase 1, regulatory subunit 140|splicing factor proline/glutamine rich (polypyrimidine tract binding protein associated)|splicing factor proline/glutamine-rich', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35176380, end_position_on_the_genomic_accession=35193174, orientation='minus', exon_count=13, OMIM=[605199], no_hdr0=''),
    6422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6422, CurrentID=0, Status='live', Symbol='SFRP1', Aliases=['FRP', 'FRP-1', 'FRP1', 'FrzA', 'SARP2'], description='secreted frizzled related protein 1', other_designations='secreted frizzled-related protein 1|SARP-2|frizzled-related protein|sFRP-1|secreted apoptosis-related protein 2', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41261962, end_position_on_the_genomic_accession=41309473, orientation='minus', exon_count=3, OMIM=[604156], no_hdr0=''),
    6423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6423, CurrentID=0, Status='live', Symbol='SFRP2', Aliases=['FRP-2', 'SARP1', 'SDF-5'], description='secreted frizzled related protein 2', other_designations='secreted frizzled-related protein 2|SARP-1|sFRP-2|secreted apoptosis related protein 1|testicular tissue protein Li 170', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153780591, end_position_on_the_genomic_accession=153789083, orientation='minus', exon_count=3, OMIM=[604157], no_hdr0=''),
    6424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6424, CurrentID=0, Status='live', Symbol='SFRP4', Aliases=['FRP-4', 'FRPHE', 'FRZB-2', 'PYL', 'sFRP-4'], description='secreted frizzled related protein 4', other_designations='secreted frizzled-related protein 4|frizzled protein, human endometrium|secreted frizzled-related protein 4; secreted frizzled-related protein 4', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=37905932, end_position_on_the_genomic_accession=37916817, orientation='minus', exon_count=6, OMIM=[606570], no_hdr0=''),
    6425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6425, CurrentID=0, Status='live', Symbol='SFRP5', Aliases=['SARP3'], description='secreted frizzled related protein 5', other_designations='secreted frizzled-related protein 5|FRP-1b|SARP-3|frizzled-related protein 1b|sFRP-5|secreted apoptosis related protein 3', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97766751, end_position_on_the_genomic_accession=97771999, orientation='minus', exon_count=3, OMIM=[604158], no_hdr0=''),
    6426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6426, CurrentID=0, Status='live', Symbol='SRSF1', Aliases=['ASF', 'SF2', 'SF2p33', 'SFRS1', 'SRp30a'], description='serine and arginine rich splicing factor 1', other_designations='serine/arginine-rich splicing factor 1|SR splicing factor 1|alternative-splicing factor 1|pre-mRNA-splicing factor SF2, P33 subunit|splicing factor 2|splicing factor, arginine/serine-rich, 30-KD, A', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58000919, end_position_on_the_genomic_accession=58007273, orientation='minus', exon_count=4, OMIM=[600812], no_hdr0=''),
    6427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6427, CurrentID=0, Status='live', Symbol='SRSF2', Aliases=['PR264', 'SC-35', 'SC35', 'SFRS2', 'SFRS2A', 'SRp30b'], description='serine and arginine rich splicing factor 2', other_designations='serine/arginine-rich splicing factor 2|SR splicing factor 2|splicing component, 35 kDa|splicing factor SC35|splicing factor, arginine/serine-rich 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76734115, end_position_on_the_genomic_accession=76737411, orientation='minus', exon_count=5, OMIM=[600813], no_hdr0=''),
    6428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6428, CurrentID=0, Status='live', Symbol='SRSF3', Aliases=['SFRS3', 'SRp20'], description='serine and arginine rich splicing factor 3', other_designations='serine/arginine-rich splicing factor 3|epididymis secretory sperm binding protein|pre-mRNA splicing factor SRp20|pre-mRNA-splicing factor SRP20|splicing factor, arginine/serine-rich 3|splicing factor, arginine/serine-rich, 20-kD', map_location='6p21.31-p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36594362, end_position_on_the_genomic_accession=36605600, orientation='plus', exon_count=7, OMIM=[603364], no_hdr0=''),
    6429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6429, CurrentID=0, Status='live', Symbol='SRSF4', Aliases=['SFRS4', 'SRP75'], description='serine and arginine rich splicing factor 4', other_designations='serine/arginine-rich splicing factor 4|SR splicing factor 4|SRP001LB|pre-mRNA-splicing factor SRP75|splicing factor, arginine/serine-rich 4', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=29147743, end_position_on_the_genomic_accession=29181900, orientation='minus', exon_count=6, OMIM=[601940], no_hdr0=''),
    6430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6430, CurrentID=0, Status='live', Symbol='SRSF5', Aliases=['HRS', 'SFRS5', 'SRP40'], description='serine and arginine rich splicing factor 5', other_designations='serine/arginine-rich splicing factor 5|SR splicing factor 5|delayed-early protein HRS|pre-mRNA-splicing factor SRP40|splicing factor, arginine/serine-rich 5', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69767112, end_position_on_the_genomic_accession=69772005, orientation='plus', exon_count=9, OMIM=[600914], no_hdr0=''),
    6431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6431, CurrentID=0, Status='live', Symbol='SRSF6', Aliases=['B52', 'HEL-S-91', 'SFRS6', 'SRP55'], description='serine and arginine rich splicing factor 6', other_designations='serine/arginine-rich splicing factor 6|SR splicing factor 6|epididymis secretory protein Li 91|pre-mRNA-splicing factor SRP55|splicing factor, arginine/serine-rich, 55 kDa', map_location='20q13.11', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43457893, end_position_on_the_genomic_accession=43464243, orientation='plus', exon_count=6, OMIM=[601944], no_hdr0=''),
    6432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6432, CurrentID=0, Status='live', Symbol='SRSF7', Aliases=['9G8', 'AAG3', 'SFRS7'], description='serine and arginine rich splicing factor 7', other_designations='serine/arginine-rich splicing factor 7|SR splicing factor 7|aging-associated protein 3|splicing factor 9G8|splicing factor, arginine/serine-rich 7, 35kDa', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38743599, end_position_on_the_genomic_accession=38751494, orientation='minus', exon_count=9, OMIM=[600572], no_hdr0=''),
    6433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6433, CurrentID=0, Status='live', Symbol='SFSWAP', Aliases=['SFRS8', 'SWAP'], description='splicing factor SWAP', other_designations='splicing factor, suppressor of white-apricot homolog|splicing factor SWAP homolog|splicing factor, arginine/serine-rich 8 (suppressor-of-white-apricot homolog, Drosophila)|splicing factor, arginine/serine-rich 8 (suppressor-of-white-apricot, Drosophila homolog)|splicing factor, suppressor of white-apricot family|suppressor of white apricot protein homolog', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131711088, end_position_on_the_genomic_accession=131799738, orientation='plus', exon_count=20, OMIM=[601945], no_hdr0=''),
    6434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6434, CurrentID=0, Status='live', Symbol='TRA2B', Aliases=['Htra2-beta', 'PPP1R156', 'SFRS10', 'SRFS10', 'TRA2-BETA', 'TRAN2B'], description='transformer 2 beta homolog', other_designations='transformer-2 protein homolog beta|TRA-2 beta|protein phosphatase 1, regulatory subunit 156|splicing factor, arginine/serine-rich 10 (transformer 2 homolog, Drosophila)|transformer-2 protein homolog B', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185914558, end_position_on_the_genomic_accession=185938027, orientation='minus', exon_count=10, OMIM=[602719], no_hdr0=''),
    6439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6439, CurrentID=0, Status='live', Symbol='SFTPB', Aliases=['PSP-B', 'SFTB3', 'SFTP3', 'SMDP1', 'SP-B'], description='surfactant protein B', other_designations='pulmonary surfactant-associated protein B|18 kDa pulmonary-surfactant protein|6 kDa protein|pulmonary surfactant-associated proteolipid SPL(Phe)', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85657307, end_position_on_the_genomic_accession=85668741, orientation='minus', exon_count=14, OMIM=[178640], no_hdr0=''),
    6440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6440, CurrentID=0, Status='live', Symbol='SFTPC', Aliases=['BRICD6', 'PSP-C', 'SFTP2', 'SMDP2', 'SP-C', 'SP5'], description='surfactant protein C', other_designations='pulmonary surfactant-associated protein C|BRICHOS domain containing 6|pulmonary surfactant apoprotein-2 SP-C|pulmonary surfactant-associated proteolipid SPL(Val)', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22157383, end_position_on_the_genomic_accession=22164479, orientation='plus', exon_count=9, OMIM=[178620], no_hdr0=''),
    6441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6441, CurrentID=0, Status='live', Symbol='SFTPD', Aliases=['COLEC7', 'PSP-D', 'SFTP4', 'SP-D'], description='surfactant protein D', other_designations='pulmonary surfactant-associated protein D|collectin-7|lung surfactant protein D|pulmonary surfactant apoprotein|surfactant-associated protein, pulmonary 4', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79937740, end_position_on_the_genomic_accession=79982236, orientation='minus', exon_count=9, OMIM=[178635], no_hdr0=''),
    6442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6442, CurrentID=0, Status='live', Symbol='SGCA', Aliases=['50DAG', 'ADL', 'DAG2', 'DMDA2', 'LGMD2D', 'LGMDR3', 'SCARMD1', 'adhalin'], description='sarcoglycan alpha', other_designations='alpha-sarcoglycan|50 kDa dystrophin-associated glycoprotein|50kD DAG|alpha-SG|dystroglycan-2|limb girdle muscular dystrophy 2D|sarcoglycan, alpha (50kDa dystrophin-associated glycoprotein)', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50165517, end_position_on_the_genomic_accession=50175928, orientation='plus', exon_count=10, OMIM=[600119], no_hdr0=''),
    6443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6443, CurrentID=0, Status='live', Symbol='SGCB', Aliases=['A3b', 'LGMD2E', 'LGMDR4', 'SGC'], description='sarcoglycan beta', other_designations='beta-sarcoglycan|43 kDa dystrophin-associated glycoprotein|43DAG|beta-SG|beta-sarcoglycan(43kD dystrophin-associated glycoprotein)|limb girdle muscular dystrophy 2E (non-linked families)|sarcoglycan, beta (43kDa dystrophin-associated glycoprotein)', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52020706, end_position_on_the_genomic_accession=52038299, orientation='minus', exon_count=6, OMIM=[600900], no_hdr0=''),
    6444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6444, CurrentID=0, Status='live', Symbol='SGCD', Aliases=['35DAG', 'CMD1L', 'DAGD', 'LGMDR6', 'SG-deltaP', 'SGD', 'SGCD'], description='sarcoglycan delta', other_designations='delta-sarcoglycan|35 kDa dystrophin-associated glycoprotein|delta-SG|dystrophin associated glycoprotein, delta sarcoglycan|placental delta sarcoglycan|sarcoglycan, delta (35kDa dystrophin-associated glycoprotein)', map_location='5q33.2-q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=155728636, end_position_on_the_genomic_accession=156767788, orientation='plus', exon_count=14, OMIM=[601411], no_hdr0=''),
    6445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6445, CurrentID=0, Status='live', Symbol='SGCG', Aliases=['35DAG', 'A4', 'DAGA4', 'DMDA', 'DMDA1', 'LGMD2C', 'LGMDR5', 'MAM', 'SCARMD2', 'SCG3', 'gamma-SG'], description='sarcoglycan gamma', other_designations='gamma-sarcoglycan|35 kDa dystrophin-associated glycoprotein|35kD dystrophin-associated glycoprotein|sarcoglycan, gamma (35kDa dystrophin-associated glycoprotein)', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23160508, end_position_on_the_genomic_accession=23325162, orientation='plus', exon_count=10, OMIM=[608896], no_hdr0=''),
    6446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6446, CurrentID=0, Status='live', Symbol='SGK1', Aliases=['SGK'], description='serum/glucocorticoid regulated kinase 1', other_designations='serine/threonine-protein kinase Sgk1|Sgk1 variant i3|serine/threonine protein kinase SGK', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=134169248, end_position_on_the_genomic_accession=134318112, orientation='minus', exon_count=17, OMIM=[602958], no_hdr0=''),
    6447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6447, CurrentID=0, Status='live', Symbol='SCG5', Aliases=['7B2', 'P7B2', 'SGNE1', 'SgV'], description='secretogranin V', other_designations='neuroendocrine protein 7B2|pituitary polypeptide|prohormone convertase chaperone|secretogranin-5|secretory granule endocrine protein I|secretory granule, neuroendocrine protein 1 (7B2 protein)', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32641710, end_position_on_the_genomic_accession=32697092, orientation='plus', exon_count=6, OMIM=[173120], no_hdr0=''),
    6448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6448, CurrentID=0, Status='live', Symbol='SGSH', Aliases=['HSS', 'MPS3A', 'SFMD'], description='N-sulfoglucosamine sulfohydrolase', other_designations='N-sulphoglucosamine sulphohydrolase|heparan sulfate sulfatase|mucopolysaccharidosis type IIIA|sulfoglucosamine sulfamidase|sulphamidase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80200668, end_position_on_the_genomic_accession=80220333, orientation='minus', exon_count=16, OMIM=[605270], no_hdr0=''),
    6449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6449, CurrentID=0, Status='live', Symbol='SGTA', Aliases=['SGT', 'alphaSGT', 'hSGT'], description='small glutamine rich tetratricopeptide repeat co-chaperone alpha', other_designations='small glutamine-rich tetratricopeptide repeat-containing protein alpha|UBP|alpha-SGT|protein containing three tetratricopeptide repeats|small glutamine rich tetratricopeptide repeat containing alpha|small glutamine-rich tetratricopeptide repeat (TPR)-containing, alpha|vpu-binding protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2754714, end_position_on_the_genomic_accession=2783317, orientation='minus', exon_count=13, OMIM=[603419], no_hdr0=''),
    6450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6450, CurrentID=0, Status='live', Symbol='SH3BGR', Aliases=['21-GARP'], description='SH3 domain binding glutamate rich protein', other_designations='SH3 domain-binding glutamic acid-rich protein|SH3-binding domain and glutamic acid-rich protein', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39445865, end_position_on_the_genomic_accession=39515506, orientation='plus', exon_count=8, OMIM=[602230], no_hdr0=''),
    6451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6451, CurrentID=0, Status='live', Symbol='SH3BGRL', Aliases=['HEL-S-115', 'SH3BGR'], description='SH3 domain binding glutamate rich protein like', other_designations='SH3 domain-binding glutamic acid-rich-like protein|SH3 domain binding glutamic acid-rich protein like|SH3-binding domain glutamic acid-rich protein like|epididymis secretory protein Li 115', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=81201984, end_position_on_the_genomic_accession=81298547, orientation='plus', exon_count=7, OMIM=[300190], no_hdr0=''),
    6452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6452, CurrentID=0, Status='live', Symbol='SH3BP2', Aliases=['3BP-2', '3BP2', 'CRBM', 'CRPM', 'RES4-23'], description='SH3 domain binding protein 2', other_designations='SH3 domain-binding protein 2|Abl-SH3 binding protein 2|TNFAIP3 interacting protein 2|epididymis secretory sperm binding protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2793085, end_position_on_the_genomic_accession=2841096, orientation='plus', exon_count=16, OMIM=[602104], no_hdr0=''),
    6453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6453, CurrentID=0, Status='live', Symbol='ITSN1', Aliases=['ITSN', 'SH3D1A', 'SH3P17'], description='intersectin 1', other_designations='intersectin-1|SH3 domain-containing protein 1A|Src homology 3 domain-containing protein|human intersectin-SH3 domain-containing protein SH3P17|intersectin 1 (SH3 domain protein)|intersectin 1 short form variant 3|intersectin 1 short form variant, 11|intersectin short variant 12', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33642452, end_position_on_the_genomic_accession=33899861, orientation='plus', exon_count=43, OMIM=[602442], no_hdr0=''),
    6455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6455, CurrentID=0, Status='live', Symbol='SH3GL1', Aliases=['CNSA1', 'EEN', 'SH3D2B', 'SH3P8'], description='SH3 domain containing GRB2 like 1, endophilin A2', other_designations='endophilin-A2|EEN fusion partner of MLL|SH3 domain protein 2B|SH3 domain-containing GRB2-like protein 1|SH3-containing Grb-2-like 1 protein|SH3-domain GRB2-like 1|endophilin-2|extra 11-19 leukemia fusion|extra eleven-nineteen leukemia fusion gene protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4360369, end_position_on_the_genomic_accession=4400547, orientation='minus', exon_count=12, OMIM=[601768], no_hdr0=''),
    6456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6456, CurrentID=0, Status='live', Symbol='SH3GL2', Aliases=['CNSA2', 'EEN-B1', 'SH3D2A', 'SH3P4'], description='SH3 domain containing GRB2 like 2, endophilin A1', other_designations='endophilin-A1|Endophilin A1 BAR domain|SH3 domain protein 2A|SH3 domain-containing GRB2-like protein 2|SH3-domain GRB2-like 2|bA335L15.1 (SH3-domain GRB2-like 2)|endophilin-1', map_location='9p22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=17579066, end_position_on_the_genomic_accession=17797124, orientation='plus', exon_count=10, OMIM=[604465], no_hdr0=''),
    6457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6457, CurrentID=0, Status='live', Symbol='SH3GL3', Aliases=['CNSA3', 'EEN-B2', 'HsT19371', 'SH3D2C', 'SH3P13'], description='SH3 domain containing GRB2 like 3, endophilin A3', other_designations='endophilin-A3|SH3 domain containing GRB2 like endophilin A3|SH3 domain protein 2C|SH3 domain-containing GRB2-like protein 3|SH3-domain GRB2-like 3|endophilin-3', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83447123, end_position_on_the_genomic_accession=83618743, orientation='plus', exon_count=17, OMIM=[603362], no_hdr0=''),
    6461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6461, CurrentID=0, Status='live', Symbol='SHB', Aliases=['bA3J10.2'], description='SH2 domain containing adaptor protein B', other_designations='SH2 domain-containing adapter protein B|SHB (Src homology 2 domain containing) adaptor protein B|SHB adaptor protein (a Src homology 2 protein)|Src homology 2 domain containing adaptor protein B', map_location='9p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37915898, end_position_on_the_genomic_accession=38069227, orientation='minus', exon_count=6, OMIM=[600314], no_hdr0=''),
    6462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6462, CurrentID=0, Status='live', Symbol='SHBG', Aliases=['ABP', 'SBP', 'TEBG'], description='sex hormone binding globulin', other_designations='sex hormone-binding globulin|sex steroid-binding protein|testis-specific androgen-binding protein|testosterone-binding beta-globulin|testosterone-estradiol-binding globulin|testosterone-estrogen-binding globulin', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7614064, end_position_on_the_genomic_accession=7633372, orientation='plus', exon_count=10, OMIM=[182205], no_hdr0=''),
    6464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6464, CurrentID=0, Status='live', Symbol='SHC1', Aliases=['SHC', 'SHCA'], description='SHC adaptor protein 1', other_designations='SHC-transforming protein 1|SH2 domain protein C1|SHC (Src homology 2 domain containing) transforming protein 1|SHC-transforming protein 3|SHC-transforming protein A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154962298, end_position_on_the_genomic_accession=154974492, orientation='minus', exon_count=14, OMIM=[600560], no_hdr0=''),
    6468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6468, CurrentID=0, Status='live', Symbol='FBXW4', Aliases=['DAC', 'FBW4', 'FBWD4', 'SHFM3', 'SHSF3'], description='F-box and WD repeat domain containing 4', other_designations='F-box/WD repeat-containing protein 4|F-box and WD-40 domain protein 4|F-box and WD-40 domain-containing protein 4|F-box/WD repeat protein 4|dactylin|epididymis secretory sperm binding protein', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101610664, end_position_on_the_genomic_accession=101695295, orientation='minus', exon_count=12, OMIM=[608071], no_hdr0=''),
    6469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6469, CurrentID=0, Status='live', Symbol='SHH', Aliases=['HHG1', 'HLP3', 'HPE3', 'MCOPCB5', 'SMMCI', 'ShhNC', 'TPT', 'TPTPS'], description='sonic hedgehog signaling molecule', other_designations='sonic hedgehog protein|shh unprocessed N-terminal signaling and C-terminal autoprocessing domains|sonic hedgehog homolog', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155799980, end_position_on_the_genomic_accession=155812463, orientation='minus', exon_count=8, OMIM=[600725], no_hdr0=''),
    6470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6470, CurrentID=0, Status='live', Symbol='SHMT1', Aliases=['CSHMT', 'SHMT'], description='serine hydroxymethyltransferase 1', other_designations='serine hydroxymethyltransferase, cytosolic|cytoplasmic serine hydroxymethyltransferase|glycine hydroxymethyltransferase|serine hydroxymethyltransferase 1 (soluble)|serine methylase', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18327873, end_position_on_the_genomic_accession=18363560, orientation='minus', exon_count=14, OMIM=[182144], no_hdr0=''),
    6472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6472, CurrentID=0, Status='live', Symbol='SHMT2', Aliases=['GLYA', 'HEL-S-51e', 'NEDCASB', 'SHMT'], description='serine hydroxymethyltransferase 2', other_designations='serine hydroxymethyltransferase, mitochondrial|GLY A+|epididymis secretory sperm binding protein Li 51e|glycine auxotroph A, human complement for hamster|glycine hydroxymethyltransferase|serine aldolase|serine hydroxymethylase|serine hydroxymethyltransferase 2 (mitochondrial)|serine methylase|threonine aldolase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57229685, end_position_on_the_genomic_accession=57234935, orientation='plus', exon_count=14, OMIM=[138450], no_hdr0=''),
    6473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6473, CurrentID=0, Status='live', Symbol='SHOX', Aliases=['GCFX', 'PHOGY', 'SS', 'SHOX'], description='short stature homeobox', other_designations='short stature homeobox protein|growth control factor, X-linked|pseudoautosomal homeobox-containing osteogenic protein', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=624344, end_position_on_the_genomic_accession=659411, orientation='plus', exon_count=7, OMIM=[312865, 400020], no_hdr0=''),
    6474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6474, CurrentID=0, Status='live', Symbol='SHOX2', Aliases=['OG12', 'OG12X', 'SHOT'], description='short stature homeobox 2', other_designations='short stature homeobox protein 2|SHOX homologous gene on chromosome 3|homeobox protein Og12X|paired-related homeobox protein SHOT', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158095905, end_position_on_the_genomic_accession=158106420, orientation='minus', exon_count=7, OMIM=[602504], no_hdr0=''),
    6476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6476, CurrentID=0, Status='live', Symbol='SI', Aliases=[], description='sucrase-isomaltase', other_designations='sucrase-isomaltase, intestinal|Alpha-methylglucosidase|Oligo-1,6-glucosidase|alpha-glucosidase|oligosaccharide alpha-1,6-glucosidase', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=164978898, end_position_on_the_genomic_accession=165078496, orientation='minus', exon_count=48, OMIM=[609845], no_hdr0=''),
    6477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6477, CurrentID=0, Status='live', Symbol='SIAH1', Aliases=['BURHASA', 'SIAH1'], description='siah E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase SIAH1|RING-type E3 ubiquitin transferase SIAH1|seven in absentia homolog 1|siah-1a', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=48354581, end_position_on_the_genomic_accession=48448435, orientation='minus', exon_count=9, OMIM=[602212], no_hdr0=''),
    6478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6478, CurrentID=0, Status='live', Symbol='SIAH2', Aliases=['hSiah2'], description='siah E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase SIAH2|RING-type E3 ubiquitin transferase SIAH2|seven in absentia homolog 2|siah-2', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150741125, end_position_on_the_genomic_accession=150763169, orientation='minus', exon_count=2, OMIM=[602213], no_hdr0=''),
    6480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6480, CurrentID=0, Status='live', Symbol='ST6GAL1', Aliases=['SIAT1', 'ST6GalI', 'ST6N'], description='ST6 beta-galactoside alpha-2,6-sialyltransferase 1', other_designations='beta-galactoside alpha-2,6-sialyltransferase 1|B-cell antigen CD75|CMP-N-acetylneuraminate beta-galactosamide alpha-2,6-sialyltransferase|CMP-N-acetylneuraminate-beta-galactosamide-alpha-2,6-sialyltransferase 1|ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 1|ST6 beta-galactosamide alpha-2,6-sialyltranferase 1|alpha 2,6-ST 1|sialyltransferase 1 (beta-galactoside alpha-2,6-sialyltransferase)', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186930526, end_position_on_the_genomic_accession=187078553, orientation='plus', exon_count=9, OMIM=[109675], no_hdr0=''),
    6482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6482, CurrentID=0, Status='live', Symbol='ST3GAL1', Aliases=['Gal-NAc6S', 'SIAT4A', 'SIATFL', 'ST3GalA', 'ST3GalA.1', 'ST3GalIA', 'ST3GalIA', '1', 'ST3O'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 1', other_designations='CMP-N-acetylneuraminate-beta-galactosamide-alpha-2,3-sialyltransferase 1|Gal-beta-1,3-GalNAc-alpha-2,3-sialyltransferase|SIAT4-A|ST3GalI|alpha 2,3-ST 1|beta-galactoside alpha-2,3-sialyltransferase 1|monosialoganglioside sialyltransferase|sialyltransferase 4A (beta-galactosidase alpha-2,3-sialytransferase)|sialyltransferase 4A (beta-galactoside alpha-2,3-sialyltransferase)|sialyltransferase 4A (beta-galactoside alpha-2,3-sialytransferase)', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=133454848, end_position_on_the_genomic_accession=133572534, orientation='minus', exon_count=11, OMIM=[607187], no_hdr0=''),
    6483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6483, CurrentID=0, Status='live', Symbol='ST3GAL2', Aliases=['Gal-NAc6S', 'SIAT4B', 'ST3GALII', 'ST3GalA.2'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 2', other_designations='CMP-N-acetylneuraminate-beta-galactosamide-alpha-2,3-sialyltransferase 2|Gal-beta-1,3-GalNAc-alpha-2,3-sialyltransferase|SIAT4-B|ST3Gal II|alpha 2,3-ST 2|beta-galactoside alpha-2,3-sialyltransferase 2|monosialoganglioside sialyltransferase|sialyltransferase 4B (beta-galactosidase alpha-2,3-sialytransferase)', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70375977, end_position_on_the_genomic_accession=70439100, orientation='minus', exon_count=7, OMIM=[607188], no_hdr0=''),
    6484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6484, CurrentID=0, Status='live', Symbol='ST3GAL4', Aliases=['CGS23', 'NANTA3', 'SAT3', 'SIAT4', 'SIAT4C', 'ST-4', 'ST3GalA.2', 'ST3GalIV', 'STZ', 'gal-NAc6S'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 4', other_designations='CMP-N-acetylneuraminate-beta-galactosamide-alpha-2,3-sialyltransferase 4|N-acetyllactosaminide alpha-2,3-sialyltransferase|alpha 2,3-ST 4|alpha 2,3-sialyltransferase IV|alpha-3-N-acetylneuraminyltransferase|beta-galactoside alpha-2,3-sialyltransferase 4|gal-beta-1,3-GalNAc-alpha-2,3-sialyltransferase|gal-beta-1,4-GalNAc-alpha-2,3-sialyltransferase|gal-beta-1,4-GlcNAc-alpha-2,3-sialyltransferase|sialyltransferase 4C (beta-galactosidase alpha-2,3-sialytransferase)|sialyltransferase 4C (beta-galactoside alpha-2,3-sialytransferase)', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126355686, end_position_on_the_genomic_accession=126414638, orientation='plus', exon_count=17, OMIM=[104240], no_hdr0=''),
    6487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6487, CurrentID=0, Status='live', Symbol='ST3GAL3', Aliases=['DEE15', 'EIEE15', 'MRT12', 'SIAT6', 'ST3GALII', 'ST3Gal III', 'ST3GalIII', 'ST3N'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 3', other_designations='CMP-N-acetylneuraminate-beta-1,4-galactoside alpha-2,3-sialyltransferase|Gal beta-1,3(4)GlcNAc alpha-2,3 sialyltransferase|alpha 2,3-ST 3|alpha 2,3-sialyltransferase III|alpha-2,3-sialyltransferase II|sialyltransferase 6 (N-acetyllacosaminide alpha 2,3-sialyltransferase)|sialyltransferase 6 (N-acetyllactosaminide alpha 2,3-sialyltransferase)', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43707465, end_position_on_the_genomic_accession=43931164, orientation='plus', exon_count=25, OMIM=[606494], no_hdr0=''),
    6489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6489, CurrentID=0, Status='live', Symbol='ST8SIA1', Aliases=['GD3S', 'SIAT8', 'SIAT8-A', 'SIAT8A', 'ST8SiaI'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 1', other_designations='alpha-N-acetylneuraminide alpha-2,8-sialyltransferase|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 1|alpha-2,8-sialyltransferase 8A|disialoganglioside (GD3) synthase|ganglioside GD3 synthase|ganglioside GT3 synthase|ganglioside-specific alpha-2,8-polysialyltransferase|sialyltransferase 8 (alpha-N-acetylneuraminate: alpha-2,8-sialytransferase, GD3 synthase) A|sialyltransferase 8A (alpha-N-acetylneuraminate: alpha-2,8-sialyltransferase, GD3 synthase)|sialyltransferase St8Sia I|sialytransferase St8Sia I', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=22193391, end_position_on_the_genomic_accession=22334707, orientation='minus', exon_count=5, OMIM=[601123], no_hdr0=''),
    6490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6490, CurrentID=0, Status='live', Symbol='PMEL', Aliases=['D12S53E', 'ME20', 'ME20-M', 'ME20M', 'P1', 'P10017', 'SI', 'SIL', 'SILV', 'gp100', 'PMEL'], description='premelanosome protein', other_designations='melanocyte protein PMEL|melanocyte protein Pmel 17|melanocyte protein mel 17|melanocytes lineage-specific antigen GP100|melanoma-associated ME20 antigen|melanosomal matrix protein17|silver locus protein homolog|silver, mouse, homolog of', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55954105, end_position_on_the_genomic_accession=55966709, orientation='minus', exon_count=12, OMIM=[155550], no_hdr0=''),
    6491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6491, CurrentID=0, Status='live', Symbol='STIL', Aliases=['MCPH7', 'SIL'], description='STIL centriolar assembly protein', other_designations='SCL-interrupting locus protein|SCL/TAL1 interrupting locus|TAL-1-interrupting locus protein', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47250139, end_position_on_the_genomic_accession=47314896, orientation='minus', exon_count=22, OMIM=[181590], no_hdr0=''),
    6492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6492, CurrentID=0, Status='live', Symbol='SIM1', Aliases=['bHLHe14'], description='SIM bHLH transcription factor 1', other_designations='single-minded homolog 1|class E basic helix-loop-helix protein 14|single-minded family bHLH transcription factor 1', map_location='6q16.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=100385009, end_position_on_the_genomic_accession=100464929, orientation='minus', exon_count=13, OMIM=[603128], no_hdr0=''),
    6493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6493, CurrentID=0, Status='live', Symbol='SIM2', Aliases=['HMC13F06', 'HMC29C01', 'SIM', 'bHLHe15'], description='SIM bHLH transcription factor 2', other_designations='single-minded homolog 2|class E basic helix-loop-helix protein 15|single-minded family bHLH transcription factor 2|transcription factor SIM2', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36699115, end_position_on_the_genomic_accession=36750219, orientation='plus', exon_count=12, OMIM=[600892], no_hdr0=''),
    6494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6494, CurrentID=0, Status='live', Symbol='SIPA1', Aliases=['SPA1'], description='signal-induced proliferation-associated 1', other_designations='signal-induced proliferation-associated protein 1|GTPase-activating protein Spa-1|p130 SPA-1|signal-induced proliferation-associated gene 1|sipa-1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65638101, end_position_on_the_genomic_accession=65650930, orientation='plus', exon_count=18, OMIM=[602180], no_hdr0=''),
    6495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6495, CurrentID=0, Status='live', Symbol='SIX1', Aliases=['BOS3', 'DFNA23', 'TIP39'], description='SIX homeobox 1', other_designations='homeobox protein SIX1|sine oculis homeobox homolog 1', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60643421, end_position_on_the_genomic_accession=60649489, orientation='minus', exon_count=2, OMIM=[601205], no_hdr0=''),
    6496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6496, CurrentID=0, Status='live', Symbol='SIX3', Aliases=['HPE2'], description='SIX homeobox 3', other_designations='homeobox protein SIX3|sine oculis homeobox homolog 3|sine oculis homeobox-like protein 3|truncated SIX3', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=44941702, end_position_on_the_genomic_accession=44946071, orientation='plus', exon_count=2, OMIM=[603714], no_hdr0=''),
    6497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6497, CurrentID=0, Status='live', Symbol='SKI', Aliases=['SGS', 'SKV'], description='SKI proto-oncogene', other_designations='ski oncogene|proto-oncogene c-Ski|ski oncoprotein|v-ski avian sarcoma viral oncogene homolog', map_location='1p36.33-p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2228319, end_position_on_the_genomic_accession=2310213, orientation='plus', exon_count=9, OMIM=[164780], no_hdr0=''),
    6498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6498, CurrentID=0, Status='live', Symbol='SKIL', Aliases=['SNO', 'SnoA', 'SnoI', 'SnoN'], description='SKI like proto-oncogene', other_designations='ski-like protein|SKI-like oncogene|ski-related oncogene snoN', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170357678, end_position_on_the_genomic_accession=170396849, orientation='plus', exon_count=9, OMIM=[165340], no_hdr0=''),
    6499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6499, CurrentID=0, Status='live', Symbol='SKIV2L', Aliases=['170A', 'DDX13', 'HLP', 'SKI2', 'SKI2W', 'SKIV21', 'THES2', 'SKIV2L'], description='Ski2 like RNA helicase', other_designations='helicase SKI2W|SKI2 homolog, superkiller viralicidic activity 2-like|helicase-like protein|superkiller viralicidic activity 2-like', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31959157, end_position_on_the_genomic_accession=31969852, orientation='plus', exon_count=28, OMIM=[600478], no_hdr0=''),
    6500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6500, CurrentID=0, Status='live', Symbol='SKP1', Aliases=['EMC19', 'OCP-II', 'OCP2A', 'TCEB1L', 'p19A', 'SKP1'], description='S-phase kinase associated protein 1', other_designations='S-phase kinase-associated protein 1|OCP-2|RNA polymerase II elongation factor-like protein OCP2|SIII|cyclin A/CDK2-associated p19|cyclin-A/CDK2-associated protein p19|organ of Corti protein 2|organ of Corti protein II|p19skp1|transcription elongation factor B polypeptide 1-like', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134148935, end_position_on_the_genomic_accession=134176950, orientation='minus', exon_count=5, OMIM=[601434], no_hdr0=''),
    6502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6502, CurrentID=0, Status='live', Symbol='SKP2', Aliases=['FBL1', 'FBXL1', 'FLB1', 'p45'], description='S-phase kinase associated protein 2', other_designations='S-phase kinase-associated protein 2|CDK2/cyclin A-associated protein p45|F-box/LRR-repeat protein 1|S-phase kinase-associated protein 2, E3 ubiquitin protein ligase|p45skp2', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36152067, end_position_on_the_genomic_accession=36184319, orientation='plus', exon_count=11, OMIM=[601436], no_hdr0=''),
    6503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6503, CurrentID=0, Status='live', Symbol='SLA', Aliases=['SLA1P', 'SLA'], description='Src like adaptor', other_designations='src-like-adapter|SLAP-1|hSLAP|src-like-adapter protein 1', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=133036728, end_position_on_the_genomic_accession=133103053, orientation='minus', exon_count=9, OMIM=[601099], no_hdr0=''),
    6504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6504, CurrentID=0, Status='live', Symbol='SLAMF1', Aliases=['CD150', 'CDw150', 'SLAM'], description='signaling lymphocytic activation molecule family member 1', other_designations='signaling lymphocytic activation molecule|IPO-3|SLAM family member 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160608106, end_position_on_the_genomic_accession=160647281, orientation='minus', exon_count=8, OMIM=[603492], no_hdr0=''),
    6505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6505, CurrentID=0, Status='live', Symbol='SLC1A1', Aliases=['DCBXA', 'EAAC1', 'EAAT3', 'SCZD18'], description='solute carrier family 1 member 1', other_designations='excitatory amino acid transporter 3|excitatory amino acid carrier 1|neuronal and epithelial glutamate transporter|sodium-dependent glutamate/aspartate transporter 3|solute carrier family 1 (neuronal/epithelial high affinity glutamate transporter, system Xag), member 1', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4490466, end_position_on_the_genomic_accession=4587469, orientation='plus', exon_count=14, OMIM=[133550], no_hdr0=''),
    6506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6506, CurrentID=0, Status='live', Symbol='SLC1A2', Aliases=['DEE41', 'EAAT2', 'EIEE41', 'GLT-1', 'HBGT'], description='solute carrier family 1 member 2', other_designations='excitatory amino acid transporter 2|excitotoxic amino acid transporter 2|glutamate/aspartate transporter II|sodium-dependent glutamate/aspartate transporter 2|solute carrier family 1 (glial high affinity glutamate transporter), member 2', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35251205, end_position_on_the_genomic_accession=35420058, orientation='minus', exon_count=16, OMIM=[600300], no_hdr0=''),
    6507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6507, CurrentID=0, Status='live', Symbol='SLC1A3', Aliases=['EA6', 'EAAT1', 'GLAST', 'GLAST1'], description='solute carrier family 1 member 3', other_designations='excitatory amino acid transporter 1|GLAST-1|sodium-dependent glutamate/aspartate transporter 1|solute carrier family 1 (glial high affinity glutamate transporter), member 3', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36606606, end_position_on_the_genomic_accession=36688334, orientation='plus', exon_count=12, OMIM=[600111], no_hdr0=''),
    6508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6508, CurrentID=0, Status='live', Symbol='SLC4A3', Aliases=['AE3', 'CAE3/BAE3', 'SLC2C'], description='solute carrier family 4 member 3', other_designations='anion exchange protein 3|Anion exchanger 3, neuronal|cardiac/brain band 3-like protein|neuronal band 3-like protein|solute carrier family 4 (anion exchanger), member 3', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219627630, end_position_on_the_genomic_accession=219641980, orientation='plus', exon_count=24, OMIM=[106195], no_hdr0=''),
    6509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6509, CurrentID=0, Status='live', Symbol='SLC1A4', Aliases=['ASCT1', 'SATT', 'SPATCCM'], description='solute carrier family 1 member 4', other_designations='neutral amino acid transporter A|alanine/serine/cysteine/threonine transporter 1|glutamate/neutral amino acid transporter|solute carrier family 1 (glutamate/neutral amino acid transporter), member 4', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=64988479, end_position_on_the_genomic_accession=65023865, orientation='plus', exon_count=9, OMIM=[600229], no_hdr0=''),
    6510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6510, CurrentID=0, Status='live', Symbol='SLC1A5', Aliases=['AAAT', 'ASCT2', 'ATBO', 'M7V1', 'M7VS1', 'R16', 'RDRC'], description='solute carrier family 1 member 5', other_designations='neutral amino acid transporter B(0)|ATB(0)|RD114 virus receptor|RD114/simian type D retrovirus receptor|baboon M7 virus receptor|neutral amino acid transporter B|sodium-dependent neutral amino acid transporter type 2|solute carrier family 1 (neutral amino acid transporter), member 5', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46774883, end_position_on_the_genomic_accession=46788594, orientation='minus', exon_count=10, OMIM=[109190], no_hdr0=''),
    6511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6511, CurrentID=0, Status='live', Symbol='SLC1A6', Aliases=['EAAT4'], description='solute carrier family 1 member 6', other_designations='excitatory amino acid transporter 4|sodium-dependent glutamate/aspartate transporter|solute carrier family 1 (high affinity aspartate/glutamate transporter), member 6', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14950033, end_position_on_the_genomic_accession=15010643, orientation='minus', exon_count=13, OMIM=[600637], no_hdr0=''),
    6512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6512, CurrentID=0, Status='live', Symbol='SLC1A7', Aliases=['AAAT', 'EAAT5'], description='solute carrier family 1 member 7', other_designations='excitatory amino acid transporter 5|excitatory amino acid transporter 5 (retinal glutamate transporter)|retinal glutamate transporter|solute carrier family 1 (glutamate transporter), member 7', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53087183, end_position_on_the_genomic_accession=53142638, orientation='minus', exon_count=13, OMIM=[604471], no_hdr0=''),
    6513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6513, CurrentID=0, Status='live', Symbol='SLC2A1', Aliases=['CSE', 'DYT17', 'DYT18', 'DYT9', 'EIG12', 'GLUT', 'GLUT-1', 'GLUT1', 'GLUT1DS', 'HTLVR', 'PED', 'SDCHCN'], description='solute carrier family 2 member 1', other_designations='solute carrier family 2, facilitated glucose transporter member 1|choreoathetosis/spasticity, episodic (paroxysmal choreoathetosis/spasticity)|glucose transporter type 1, erythrocyte/brain|hepG2 glucose transporter|human T-cell leukemia virus (I and II) receptor|receptor for HTLV-1 and HTLV-2|solute carrier family 2 (facilitated glucose transporter), member 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42925353, end_position_on_the_genomic_accession=42958868, orientation='minus', exon_count=10, OMIM=[138140], no_hdr0=''),
    6514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6514, CurrentID=0, Status='live', Symbol='SLC2A2', Aliases=['GLUT2'], description='solute carrier family 2 member 2', other_designations='solute carrier family 2, facilitated glucose transporter member 2|glucose transporter type 2, liver|solute carrier family 2 (facilitated glucose transporter), member 2', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170996341, end_position_on_the_genomic_accession=171026721, orientation='minus', exon_count=12, OMIM=[138160], no_hdr0=''),
    6515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6515, CurrentID=0, Status='live', Symbol='SLC2A3', Aliases=['GLUT3'], description='solute carrier family 2 member 3', other_designations='solute carrier family 2, facilitated glucose transporter member 3|GLUT-3|glucose transporter type 3, brain|solute carrier family 2 (facilitated glucose transporter), member 3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7919230, end_position_on_the_genomic_accession=7936187, orientation='minus', exon_count=10, OMIM=[138170], no_hdr0=''),
    6517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6517, CurrentID=0, Status='live', Symbol='SLC2A4', Aliases=['GLUT4'], description='solute carrier family 2 member 4', other_designations='solute carrier family 2, facilitated glucose transporter member 4|GLUT-4|glucose transporter type 4, insulin-responsive|insulin-responsive glucose transporter type 4|solute carrier family 2 (facilitated glucose transporter), member 4', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7281718, end_position_on_the_genomic_accession=7288257, orientation='plus', exon_count=11, OMIM=[138190], no_hdr0=''),
    6518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6518, CurrentID=0, Status='live', Symbol='SLC2A5', Aliases=['GLUT-5', 'GLUT5'], description='solute carrier family 2 member 5', other_designations='solute carrier family 2, facilitated glucose transporter member 5|glucose transporter type 5, small intestine|glucose transporter-like protein 5|solute carrier family 2 (facilitated glucose/fructose transporter), member 5|testicular tissue protein Li 81', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9035106, end_position_on_the_genomic_accession=9072259, orientation='minus', exon_count=13, OMIM=[138230], no_hdr0=''),
    6519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6519, CurrentID=0, Status='live', Symbol='SLC3A1', Aliases=['ATR1', 'CSNU1', 'D2H', 'NBAT', 'RBAT'], description='solute carrier family 3 member 1', other_designations='neutral and basic amino acid transport protein rBAT|B(0,+)-type amino acid transport protein|SLC3A1 variant B|SLC3A1 variant C|SLC3A1 variant D|SLC3A1 variant E|SLC3A1 variant F|SLC3A1 variant G|amino acid transporter 1|solute carrier family 3 (amino acid transporter heavy chain), member 1|solute carrier family 3 (cystine, dibasic and neutral amino acid transporters), member 1|solute carrier family 3 (cystine, dibasic and neutral amino acid transporters, activator of cystine, dibasic and neutral amino acid transport), member 1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=44275464, end_position_on_the_genomic_accession=44321494, orientation='plus', exon_count=10, OMIM=[104614], no_hdr0=''),
    6520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6520, CurrentID=0, Status='live', Symbol='SLC3A2', Aliases=['4F2', '4F2HC', '4T2HC', 'CD98', 'CD98HC', 'MDU1', 'NACAE'], description='solute carrier family 3 member 2', other_designations='4F2 cell-surface antigen heavy chain|CD98 heavy chain|antigen defined by monoclonal antibody 4F2, heavy chain|antigen identified by monoclonal antibodies 4F2, TRA1.10, TROP4, and T43|lymphocyte activation antigen 4F2 large subunit|monoclonal antibody 44D7|solute carrier family 3 (activators of dibasic and neutral amino acid transport), member 2|solute carrier family 3 (amino acid transporter heavy chain), member 2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62856109, end_position_on_the_genomic_accession=62888860, orientation='plus', exon_count=14, OMIM=[158070], no_hdr0=''),
    6521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6521, CurrentID=0, Status='live', Symbol='SLC4A1', Aliases=['AE1', 'BND3', 'CD233', 'CHC', 'DI', 'EMPB3', 'EPB3', 'FR', 'RTA1A', 'SAO', 'SPH4', 'SW', 'WD', 'WD1', 'WR'], description='solute carrier family 4 member 1 (Diego blood group)', other_designations='band 3 anion transport protein|Diego blood group|Froese blood group|Swann blood group|Waldner blood group|Wright blood group|anion exchange protein 1|anion exchanger-1|band 3 anion exchanger|erythrocyte membrane protein band 3|erythroid anion exchange protein|solute carrier family 4 (anion exchanger), member 1 (Diego blood group)|solute carrier family 4, anion exchanger, member 1 (erythrocyte membrane protein band 3, Diego blood group)|solute carrier family 4, anion exchanger, number 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44248390, end_position_on_the_genomic_accession=44268161, orientation='minus', exon_count=21, OMIM=[109270], no_hdr0=''),
    6522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6522, CurrentID=0, Status='live', Symbol='SLC4A2', Aliases=['AE2', 'BND3L', 'EPB3L1', 'HKB3', 'NBND3'], description='solute carrier family 4 member 2', other_designations='anion exchange protein 2|anion exchanger 2 type a|anion exchanger 2 type b1|anion exchanger 2 type b2|erythrocyte membrane protein band 3-like 1|non-erythroid band 3-like protein|solute carrier family 4 (anion exchanger), member 2', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151058200, end_position_on_the_genomic_accession=151076527, orientation='plus', exon_count=25, OMIM=[109280], no_hdr0=''),
    6523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6523, CurrentID=0, Status='live', Symbol='SLC5A1', Aliases=['D22S675', 'NAGT', 'SGLT1'], description='solute carrier family 5 member 1', other_designations='sodium/glucose cotransporter 1|Na+/glucose cotransporter 1|high affinity sodium-glucose cotransporter|solute carrier family 5 (sodium/glucose cotransporter), member 1', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32043050, end_position_on_the_genomic_accession=32113029, orientation='plus', exon_count=16, OMIM=[182380], no_hdr0=''),
    6524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6524, CurrentID=0, Status='live', Symbol='SLC5A2', Aliases=['SGLT2'], description='solute carrier family 5 member 2', other_designations='sodium/glucose cotransporter 2|Na(+)/glucose cotransporter 2|low affinity sodium-glucose cotransporter|solute carrier family 5 (sodium/glucose cotransporter), member 2|solute carrier family 5 (sodium/glucose transporter), member 2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31482535, end_position_on_the_genomic_accession=31490769, orientation='plus', exon_count=14, OMIM=[182381], no_hdr0=''),
    6525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6525, CurrentID=0, Status='live', Symbol='SMTN', Aliases=[], description='smoothelin', other_designations='smoothelin', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31064118, end_position_on_the_genomic_accession=31104624, orientation='plus', exon_count=29, OMIM=[602127], no_hdr0=''),
    6526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6526, CurrentID=0, Status='live', Symbol='SLC5A3', Aliases=['BCW2', 'SMIT', 'SMIT1', 'SMIT2'], description='solute carrier family 5 member 3', other_designations='sodium/myo-inositol cotransporter|Na(+)/myo-inositol cotransporter|sodium/myo-inositol cotransporter 1|sodium/myo-inositol transporter 1|solute carrier family 5 (inositol transporters), member 3|solute carrier family 5 (sodium/myo-inositol cotransporter), member 3', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34073578, end_position_on_the_genomic_accession=34106260, orientation='plus', exon_count=2, OMIM=[600444], no_hdr0=''),
    6527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6527, CurrentID=0, Status='live', Symbol='SLC5A4', Aliases=['DJ90G24.4', 'SAAT1', 'SGLT3'], description='solute carrier family 5 member 4', other_designations='solute carrier family 5 member 4|Na(+)/glucose cotransporter 3|low affinity sodium-glucose cotransporter|sodium transporter|sodium/glucose cotransporter 3|solute carrier family 5 (glucose activated ion channel), member 4|solute carrier family 5 (low affinity glucose cotransporter), member 4|solute carrier family 5 (neutral amino acid transporters, system A), member 4', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32218423, end_position_on_the_genomic_accession=32355057, orientation='minus', exon_count=18, OMIM=[618633], no_hdr0=''),
    6528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6528, CurrentID=0, Status='live', Symbol='SLC5A5', Aliases=['NIS', 'TDH1'], description='solute carrier family 5 member 5', other_designations='sodium/iodide cotransporter|Na(+)/I(-) cotransporter|Na(+)/I(-) symporter|solute carrier family 5 (sodium iodide symporter), member 5|solute carrier family 5 (sodium/iodide cotransporter), member 5', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17871394, end_position_on_the_genomic_accession=17895175, orientation='plus', exon_count=16, OMIM=[601843], no_hdr0=''),
    6529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6529, CurrentID=0, Status='live', Symbol='SLC6A1', Aliases=['GABATHG', 'GABATR', 'GAT1', 'MAE'], description='solute carrier family 6 member 1', other_designations='sodium- and chloride-dependent GABA transporter 1|GABA transporter 1|solute carrier family 6 (neurotransmitter transporter), member 1|solute carrier family 6 (neurotransmitter transporter, GABA), member 1', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10992748, end_position_on_the_genomic_accession=11039247, orientation='plus', exon_count=18, OMIM=[137165], no_hdr0=''),
    6530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6530, CurrentID=0, Status='live', Symbol='SLC6A2', Aliases=['NAT1', 'NET', 'NET1', 'SLC6A5'], description='solute carrier family 6 member 2', other_designations='sodium-dependent noradrenaline transporter|neurotransmitter transporter|norepinephrine transporter|solute carrier family 6 (neurotransmitter transporter), member 2|solute carrier family 6 (neurotransmitter transporter, noradrenalin), member 2|solute carrier family 6 member 5', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55655928, end_position_on_the_genomic_accession=55706192, orientation='plus', exon_count=18, OMIM=[163970], no_hdr0=''),
    6531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6531, CurrentID=0, Status='live', Symbol='SLC6A3', Aliases=['DAT', 'DAT1', 'PKDYS', 'PKDYS1'], description='solute carrier family 6 member 3', other_designations='sodium-dependent dopamine transporter|DA transporter|dopamine transporter 1|solute carrier family 6 (neurotransmitter transporter), member 3|solute carrier family 6 (neurotransmitter transporter, dopamine), member 3', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1392794, end_position_on_the_genomic_accession=1445440, orientation='minus', exon_count=15, OMIM=[126455], no_hdr0=''),
    6532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6532, CurrentID=0, Status='live', Symbol='SLC6A4', Aliases=['5-HTT', '5-HTTLPR', '5HTT', 'HTT', 'OCD1', 'SERT', 'SERT1', 'hSERT'], description='solute carrier family 6 member 4', other_designations='sodium-dependent serotonin transporter|5-hydroxytryptamine (serotonin) transporter|5HT transporter|Na+/Cl- dependent serotonin transporter|serotonin transporter 1|solute carrier family 6 (neurotransmitter transporter), member 4|solute carrier family 6 (neurotransmitter transporter, serotonin), member 4', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30194319, end_position_on_the_genomic_accession=30235697, orientation='minus', exon_count=15, OMIM=[182138], no_hdr0=''),
    6533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6533, CurrentID=0, Status='live', Symbol='SLC6A6', Aliases=['HTRDC', 'TAUT'], description='solute carrier family 6 member 6', other_designations='sodium- and chloride-dependent taurine transporter|solute carrier family 6 (neurotransmitter transporter, taurine), member 6', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14402576, end_position_on_the_genomic_accession=14489349, orientation='plus', exon_count=19, OMIM=[186854], no_hdr0=''),
    6534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6534, CurrentID=0, Status='live', Symbol='SLC6A7', Aliases=['PROT'], description='solute carrier family 6 member 7', other_designations='sodium-dependent proline transporter|brain-specific L-proline transporter|solute carrier family 6 (neurotransmitter transporter, L-proline), member 7', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150190062, end_position_on_the_genomic_accession=150211072, orientation='plus', exon_count=16, OMIM=[606205], no_hdr0=''),
    6535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6535, CurrentID=0, Status='live', Symbol='SLC6A8', Aliases=['CCDS1', 'CRT', 'CRTR', 'CT1', 'CTR5'], description='solute carrier family 6 member 8', other_designations='sodium- and chloride-dependent creatine transporter 1|creatine transporter 1|creatine transporter SLC6A8 variant D|solute carrier family 6 (neurotransmitter transporter), member 8|solute carrier family 6 (neurotransmitter transporter, creatine), member 8', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153687926, end_position_on_the_genomic_accession=153696593, orientation='plus', exon_count=14, OMIM=[300036], no_hdr0=''),
    6536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6536, CurrentID=0, Status='live', Symbol='SLC6A9', Aliases=['GCENSG', 'GLYT1'], description='solute carrier family 6 member 9', other_designations='sodium- and chloride-dependent glycine transporter 1|glyT-1|solute carrier family 6 (neurotransmitter transporter, glycine), member 9', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43996483, end_position_on_the_genomic_accession=44031462, orientation='minus', exon_count=18, OMIM=[601019], no_hdr0=''),
    6538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6538, CurrentID=0, Status='live', Symbol='SLC6A11', Aliases=['GAT-3', 'GAT3', 'GAT4'], description='solute carrier family 6 member 11', other_designations='sodium- and chloride-dependent GABA transporter 3|GABA transporter 3|solute carrier family 6 (neurotransmitter transporter), member 11|solute carrier family 6 (neurotransmitter transporter, GABA), member 11', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10816200, end_position_on_the_genomic_accession=10940714, orientation='plus', exon_count=16, OMIM=[607952], no_hdr0=''),
    6539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6539, CurrentID=0, Status='live', Symbol='SLC6A12', Aliases=['BGT-1', 'BGT1', 'GAT2'], description='solute carrier family 6 member 12', other_designations='sodium- and chloride-dependent betaine transporter|Na(+)/Cl(-) betaine/GABA transporter|betaine/GABA transporter-1|gamma-aminobutyric acid transporter|solute carrier family 6 (neurotransmitter transporter), member 12|solute carrier family 6 (neurotransmitter transporter, betaine/GABA), member 12', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=190081, end_position_on_the_genomic_accession=214157, orientation='minus', exon_count=19, OMIM=[603080], no_hdr0=''),
    6540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6540, CurrentID=0, Status='live', Symbol='SLC6A13', Aliases=['GAT-2', 'GAT2', 'GAT3'], description='solute carrier family 6 member 13', other_designations='sodium- and chloride-dependent GABA transporter 2|GABA transport protein|GABA transporter 2|solute carrier family 6 (neurotransmitter transporter), member 13|solute carrier family 6 (neurotransmitter transporter, GABA), member 13', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=220622, end_position_on_the_genomic_accession=262930, orientation='minus', exon_count=20, OMIM=[615097], no_hdr0=''),
    6541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6541, CurrentID=0, Status='live', Symbol='SLC7A1', Aliases=['ATRC1', 'CAT-1', 'ERR', 'HCAT1', 'REC1L'], description='solute carrier family 7 member 1', other_designations='high affinity cationic amino acid transporter 1|CAT1|amino acid transporter, cationic 1|ecotropic retroviral leukemia receptor homolog|ecotropic retroviral receptor|ecotropic retrovirus receptor homolog|solute carrier family 7 (cationic amino acid transporter, y+ system), member 1|system Y+ basic amino acid transporter', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=29509410, end_position_on_the_genomic_accession=29595688, orientation='minus', exon_count=14, OMIM=[104615], no_hdr0=''),
    6542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6542, CurrentID=0, Status='live', Symbol='SLC7A2', Aliases=['ATRC2', 'CAT2', 'HCAT2'], description='solute carrier family 7 member 2', other_designations='cationic amino acid transporter 2|low affinity cationic amino acid transporter 2|solute carrier family 7 (cationic amino acid transporter, y+ system), member 2', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17494349, end_position_on_the_genomic_accession=17570566, orientation='plus', exon_count=17, OMIM=[601872], no_hdr0=''),
    6543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6543, CurrentID=0, Status='live', Symbol='SLC8A2', Aliases=['NCX2'], description='solute carrier family 8 member A2', other_designations='sodium/calcium exchanger 2|Na(+)/Ca(2+)-exchange protein 2|Na+/Ca2+-exchanging protein Nac2|solute carrier family 8 (sodium/calcium exchanger), member 2|solute carrier family 8 member 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47428017, end_position_on_the_genomic_accession=47471893, orientation='minus', exon_count=11, OMIM=[601901], no_hdr0=''),
    6545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6545, CurrentID=0, Status='live', Symbol='SLC7A4', Aliases=['CAT-4', 'CAT4', 'HCAT3', 'VH'], description='solute carrier family 7 member 4', other_designations='cationic amino acid transporter 4|Ig heavy chain variable region|VH 3 family|solute carrier family 7 (cationic amino acid transporter, y+ system), member 4|solute carrier family 7 (orphan transporter), member 4', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21028718, end_position_on_the_genomic_accession=21032561, orientation='minus', exon_count=5, OMIM=[603752], no_hdr0=''),
    6546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6546, CurrentID=0, Status='live', Symbol='SLC8A1', Aliases=['NCX1'], description='solute carrier family 8 member A1', other_designations='sodium/calcium exchanger 1|Na(+)/Ca(2+)-exchange protein 1|Na+/Ca++ exchanger|Na+/Ca2+ exchanger|solute carrier family 8 (sodium/calcium exchanger), member 1|solute carrier family 8 member 1', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=40097270, end_position_on_the_genomic_accession=40512435, orientation='minus', exon_count=16, OMIM=[182305], no_hdr0=''),
    6547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6547, CurrentID=0, Status='live', Symbol='SLC8A3', Aliases=['NCX3'], description='solute carrier family 8 member A3', other_designations='sodium/calcium exchanger 3|Na(+)/Ca(2+)-exchange protein 3|sodium/calcium exchanger SLC8A3|solute carrier family 8 (sodium/calcium exchanger), member 3', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70044215, end_position_on_the_genomic_accession=70189626, orientation='minus', exon_count=12, OMIM=[607991], no_hdr0=''),
    6548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6548, CurrentID=0, Status='live', Symbol='SLC9A1', Aliases=['APNH', 'LIKNS', 'NHE-1', 'NHE1', 'PPP1R143'], description='solute carrier family 9 member A1', other_designations='sodium/hydrogen exchanger 1|Na(+)/H(+) exchanger 1|Na-Li countertransporter|protein phosphatase 1, regulatory subunit 143|solute carrier family 9 (sodium/hydrogen exchanger), member 1 (antiporter, Na+/H+, amiloride sensitive)|solute carrier family 9, subfamily A (NHE1, cation proton antiporter 1), member 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27098809, end_position_on_the_genomic_accession=27155125, orientation='minus', exon_count=13, OMIM=[107310], no_hdr0=''),
    6549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6549, CurrentID=0, Status='live', Symbol='SLC9A2', Aliases=['NHE2'], description='solute carrier family 9 member A2', other_designations='sodium/hydrogen exchanger 2|Na(+)/H(+) exchanger 2|solute carrier family 9 (sodium/hydrogen exchanger), member 2|solute carrier family 9, subfamily A (NHE2, cation proton antiporter 2), member 2', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102619553, end_position_on_the_genomic_accession=102711355, orientation='plus', exon_count=12, OMIM=[600530], no_hdr0=''),
    6550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6550, CurrentID=0, Status='live', Symbol='SLC9A3', Aliases=['DIAR8', 'NHE-3', 'NHE3'], description='solute carrier family 9 member A3', other_designations='sodium/hydrogen exchanger 3|Na(+)/H(+) exchanger 3|solute carrier family 9 (sodium/hydrogen exchanger), member 3|solute carrier family 9, subfamily A (NHE3, cation proton antiporter 3), member 3', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=470456, end_position_on_the_genomic_accession=524449, orientation='minus', exon_count=17, OMIM=[182307], no_hdr0=''),
    6553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6553, CurrentID=0, Status='live', Symbol='SLC9A5', Aliases=['NHE5'], description='solute carrier family 9 member A5', other_designations='sodium/hydrogen exchanger 5|NHE-5|Na(+)/H(+) exchanger 5|solute carrier family 9 (sodium/hydrogen exchanger), member 5|solute carrier family 9 member 5|solute carrier family 9, subfamily A (NHE5, cation proton antiporter 5), member 5', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67247549, end_position_on_the_genomic_accession=67272191, orientation='plus', exon_count=17, OMIM=[600477], no_hdr0=''),
    6554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6554, CurrentID=0, Status='live', Symbol='SLC10A1', Aliases=['FHCA2', 'NTCP'], description='solute carrier family 10 member 1', other_designations='sodium/bile acid cotransporter|Na(+)/bile acid cotransporter|Na(+)/taurocholate transport protein|Na/taurocholate cotransporting polypeptide|cell growth-inhibiting gene 29 protein|growth-inhibiting protein 29|sodium/taurocholate cotransporter|sodium/taurocholate cotransporting polypeptide|solute carrier family 10 (sodium/bile acid cotransporter family), member 1|solute carrier family 10 (sodium/bile acid cotransporter), member 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69775416, end_position_on_the_genomic_accession=69797241, orientation='minus', exon_count=5, OMIM=[182396], no_hdr0=''),
    6555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6555, CurrentID=0, Status='live', Symbol='SLC10A2', Aliases=['ASBT', 'IBAT', 'ISBT', 'NTCP2', 'PBAM'], description='solute carrier family 10 member 2', other_designations='ileal sodium/bile acid cotransporter|Na(+)-dependent ileal bile acid transporter|ileal apical sodium-dependent bile acid transporter|ileal sodium-dependent bile acid transporter|sodium/taurocholate cotransporting polypeptide, ileal|solute carrier family 10 (sodium/bile acid cotransporter family), member 2|solute carrier family 10 (sodium/bile acid cotransporter), member 2', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=103043998, end_position_on_the_genomic_accession=103066417, orientation='minus', exon_count=6, OMIM=[601295], no_hdr0=''),
    6556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6556, CurrentID=0, Status='live', Symbol='SLC11A1', Aliases=['LSH', 'NRAMP', 'NRAMP1'], description='solute carrier family 11 member 1', other_designations='natural resistance-associated macrophage protein 1|NRAMP 1|solute carrier family 11 (proton-coupled divalent metal ion transporter), member 1|solute carrier family 11 (proton-coupled divalent metal ion transporters), member 1|solute carrier family 11 (sodium/phosphate symporters), member 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218381766, end_position_on_the_genomic_accession=218396894, orientation='plus', exon_count=16, OMIM=[600266], no_hdr0=''),
    6557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6557, CurrentID=0, Status='live', Symbol='SLC12A1', Aliases=['BSC1', 'NKCC2'], description='solute carrier family 12 member 1', other_designations='solute carrier family 12 member 1|NKCC2A variant A|Na-K-2Cl cotransporter|bumetanide-sensitive sodium-(potassium)-chloride cotransporter 2|kidney-specific Na-K-Cl symporter|solute carrier family 12 (sodium/potassium/chloride transporter), member 1|solute carrier family 12 (sodium/potassium/chloride transporters), member 1', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48206302, end_position_on_the_genomic_accession=48304078, orientation='plus', exon_count=29, OMIM=[600839], no_hdr0=''),
    6558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6558, CurrentID=0, Status='live', Symbol='SLC12A2', Aliases=['BSC', 'BSC2', 'KILQS', 'NKCC1', 'PPP1R141'], description='solute carrier family 12 member 2', other_designations='solute carrier family 12 member 2|basolateral Na-K-Cl symporter|bumetanide-sensitive sodium-(potassium)-chloride cotransporter 1|bumetanide-sensitive sodium-(potassium)-chloride cotransporter 2|protein phosphatase 1, regulatory subunit 141|solute carrier family 12 (sodium/potassium/chloride transporter), member 2|solute carrier family 12 (sodium/potassium/chloride transporters), member 2', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=128083766, end_position_on_the_genomic_accession=128189677, orientation='plus', exon_count=29, OMIM=[600840], no_hdr0=''),
    6559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6559, CurrentID=0, Status='live', Symbol='SLC12A3', Aliases=['NCC', 'NCCT', 'TSC'], description='solute carrier family 12 member 3', other_designations='solute carrier family 12 member 3|Na-Cl cotransporter|Na-Cl symporter|NaCl electroneutral thiazide-sensitive cotransporter|solute carrier family 12 (sodium/chloride transporter), member 3|thiazide-sensitive Na-Cl cotransporter|thiazide-sensitive sodium-chloride cotransporter', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56865207, end_position_on_the_genomic_accession=56915850, orientation='plus', exon_count=26, OMIM=[600968], no_hdr0=''),
    6560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6560, CurrentID=0, Status='live', Symbol='SLC12A4', Aliases=['CTC-479C5.17', 'KCC1', 'hKCC1'], description='solute carrier family 12 member 4', other_designations='solute carrier family 12 member 4|electroneutral potassium-chloride cotransporter 1|erythroid K-Cl cotransporter 1|potassium/chloride cotransporter 1|solute carrier family 12 (potassium/chloride transporter), member 4|solute carrier family 12 (potassium/chloride transporters), member 4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67943474, end_position_on_the_genomic_accession=67968694, orientation='minus', exon_count=26, OMIM=[604119], no_hdr0=''),
    6561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6561, CurrentID=0, Status='live', Symbol='SLC13A1', Aliases=['NAS1', 'NaSi-1'], description='solute carrier family 13 member 1', other_designations='solute carrier family 13 member 1|Na(+)/sulfate cotransporter|renal sodium/sulfate cotransporter|solute carrier family 13 (sodium/sulfate symporters), member 1|solute carrier family 13 (sodium/sulphate symporters), member 1', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123113490, end_position_on_the_genomic_accession=123201836, orientation='minus', exon_count=22, OMIM=[606193], no_hdr0=''),
    6563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6563, CurrentID=0, Status='live', Symbol='SLC14A1', Aliases=['HUT11', 'HsT1341', 'JK', 'Jk(b)', 'RACH1', 'RACH2', 'UT-B1', 'UT1', 'UTE'], description='solute carrier family 14 member 1 (Kidd blood group)', other_designations='urea transporter 1|Kidd blood group antigen|SLC14A1 JK|solute carrier family 14 (urea transporter), member 1 (Kidd blood group)|urea transporter JK glycoprotein|urea transporter, erythrocyte|urea transporter-B1', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=45724127, end_position_on_the_genomic_accession=45752520, orientation='plus', exon_count=13, OMIM=[613868], no_hdr0=''),
    6564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6564, CurrentID=0, Status='live', Symbol='SLC15A1', Aliases=['HPECT1', 'HPEPT1', 'PEPT1'], description='solute carrier family 15 member 1', other_designations='solute carrier family 15 member 1|Caco-2 oligopeptide transporter|intestinal H+/peptide cotransporter|macrophage oligopeptide transporter PEPT1|peptide transporter 1|solute carrier family 15 (oligopeptide transporter), member 1', map_location='13q32.2-q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=98683801, end_position_on_the_genomic_accession=98752672, orientation='minus', exon_count=23, OMIM=[600544], no_hdr0=''),
    6565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6565, CurrentID=0, Status='live', Symbol='SLC15A2', Aliases=['PEPT2'], description='solute carrier family 15 member 2', other_designations='solute carrier family 15 member 2|kidney H(+)/peptide cotransporter|peptide transporter 2|solute carrier family 15 (H+/peptide transporter), member 2|solute carrier family 15 (oligopeptide transporter), member 2', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121894401, end_position_on_the_genomic_accession=121944188, orientation='plus', exon_count=23, OMIM=[602339], no_hdr0=''),
    6566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6566, CurrentID=0, Status='live', Symbol='SLC16A1', Aliases=['HHF7', 'MCT', 'MCT1', 'MCT1D'], description='solute carrier family 16 member 1', other_designations='monocarboxylate transporter 1|MCT 1|solute carrier family 16 (monocarboxylate transporter), member 1|solute carrier family 16 (monocarboxylic acid transporters), member 1|solute carrier family 16, member 1 (monocarboxylic acid transporter 1)', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112911847, end_position_on_the_genomic_accession=112956196, orientation='minus', exon_count=5, OMIM=[600682], no_hdr0=''),
    6567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6567, CurrentID=0, Status='live', Symbol='SLC16A2', Aliases=['AHDS', 'DXS128', 'DXS128E', 'MCT 7', 'MCT 8', 'MCT7', 'MCT8', 'MRX22', 'XPCT'], description='solute carrier family 16 member 2', other_designations='monocarboxylate transporter 8|X-linked PEST-containing transporter|monocarboxylate transporter 7|solute carrier family 16, member 2 (thyroid hormone transporter)', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=74421493, end_position_on_the_genomic_accession=74533916, orientation='plus', exon_count=6, OMIM=[300095], no_hdr0=''),
    6568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6568, CurrentID=0, Status='live', Symbol='SLC17A1', Aliases=['NAPI-1', 'NPT-1', 'NPT1'], description='solute carrier family 17 member 1', other_designations='sodium-dependent phosphate transport protein 1|Na(+)/PI cotransporter 1|na/Pi-4|renal Na(+)-dependent phosphate cotransporter 1|renal sodium-dependent phosphate transport protein 1|renal sodium-phosphate transport protein 1|sodium phosphate transporter|sodium/phosphate cotransporter 1|sodium/phosphate type I cotransporter|solute carrier family 17 (organic anion transporter), member 1|solute carrier family 17 (sodium phosphate), member 1|solute carrier family 17 (vesicular glutamate transporter), member 1', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25723743, end_position_on_the_genomic_accession=25832108, orientation='minus', exon_count=14, OMIM=[182308], no_hdr0=''),
    6569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6569, CurrentID=0, Status='live', Symbol='SLC34A1', Aliases=['FRTS2', 'HCINF2', 'NAPI-3', 'NPHLOP1', 'NPT2', 'NPTIIa', 'SLC11', 'SLC17A2'], description='solute carrier family 34 member 1', other_designations='sodium-dependent phosphate transport protein 2A|Na(+)-dependent phosphate cotransporter 2A|Na(+)/Pi cotransporter 2A|Na+-phosphate cotransporter type II|naPi-2a|renal sodium-dependent phosphate transporter|sodium-phosphate transport protein 2A|sodium/phosphate co-transporter|sodium/phosphate cotransporter 2A|solute carrier family 17 (sodium phosphate), member 2|solute carrier family 34 (sodium phosphate), member 1|solute carrier family 34 (type II sodium/phosphate cotransporter), member 1', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177384434, end_position_on_the_genomic_accession=177412021, orientation='plus', exon_count=16, OMIM=[182309], no_hdr0=''),
    6570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6570, CurrentID=0, Status='live', Symbol='SLC18A1', Aliases=['CGAT', 'VAT1', 'VMAT1'], description='solute carrier family 18 member A1', other_designations='chromaffin granule amine transporter|solute carrier family 18 (vesicular monoamine transporter), member 1|solute carrier family 18 (vesicular monoamine), member 1|solute carrier family 18 member 1|vesicular amine transporter 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=20144855, end_position_on_the_genomic_accession=20183139, orientation='minus', exon_count=17, OMIM=[193002], no_hdr0=''),
    6571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6571, CurrentID=0, Status='live', Symbol='SLC18A2', Aliases=['PKDYS2', 'SVAT', 'SVMT', 'VAT2', 'VMAT2'], description='solute carrier family 18 member A2', other_designations='synaptic vesicular amine transporter|monoamine neurotransmitter transporter|solute carrier family 18 (vesicular monoamine transporter), member 2|synaptic vesicle amine transporter, brain|synaptic vesicle monoamine transporter, brain|vesicle monoamine transporter type 2|vesicle monoamine/H+ antiporter|vesicular amine transporter 2', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=117241114, end_position_on_the_genomic_accession=117279430, orientation='plus', exon_count=16, OMIM=[193001], no_hdr0=''),
    6572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6572, CurrentID=0, Status='live', Symbol='SLC18A3', Aliases=['CMS21', 'VACHT'], description='solute carrier family 18 member A3', other_designations='vesicular acetylcholine transporter|solute carrier family 18 (vesicular acetylcholine transporter), member 3|solute carrier family 18 (vesicular acetylcholine), member 3|solute carrier family 18, member 3', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49610310, end_position_on_the_genomic_accession=49612720, orientation='plus', exon_count=1, OMIM=[600336], no_hdr0=''),
    6573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6573, CurrentID=0, Status='live', Symbol='SLC19A1', Aliases=['CHMD', 'FOLT', 'IFC-1', 'IFC1', 'MEGAF', 'REFC', 'RFC', 'RFC1', 'RFT-1', 'hRFC', 'hSLC19A1'], description='solute carrier family 19 member 1', other_designations='reduced folate transporter|folate transporter 1|intestinal folate carrier 1|placental folate transporter|reduced folate carrier 1|reduced folate carrier protein|reduced folate transporter 1|solute carrier family 19 (folate transporter), member 1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45502517, end_position_on_the_genomic_accession=45563140, orientation='minus', exon_count=17, OMIM=[600424], no_hdr0=''),
    6574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6574, CurrentID=0, Status='live', Symbol='SLC20A1', Aliases=['GLVR1', 'Glvr-1', 'PIT1', 'PiT-1'], description='solute carrier family 20 member 1', other_designations='sodium-dependent phosphate transporter 1|gibbon ape leukemia virus receptor 1|leukemia virus receptor 1 homolog|solute carrier family 20 (phosphate transporter), member 1', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112645938, end_position_on_the_genomic_accession=112663825, orientation='plus', exon_count=13, OMIM=[137570], no_hdr0=''),
    6575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6575, CurrentID=0, Status='live', Symbol='SLC20A2', Aliases=['GLVR-2', 'GLVR2', 'IBGC1', 'IBGC2', 'IBGC3', 'MLVAR', 'PIT-2', 'PIT2', 'RAM1', 'Ram-1'], description='solute carrier family 20 member 2', other_designations='sodium-dependent phosphate transporter 2|epididymis secretory sperm binding protein|gibbon ape leukemia virus receptor 2|murine leukemia virus, amphotropic, receptor for|murine leukemia virus, amphotropic; receptor|solute carrier family 20 (phosphate transporter), member 2', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42416475, end_position_on_the_genomic_accession=42542143, orientation='minus', exon_count=18, OMIM=[158378], no_hdr0=''),
    6576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6576, CurrentID=0, Status='live', Symbol='SLC25A1', Aliases=['CMS23', 'CTP', 'D2L2AD', 'SEA', 'SLC20A3'], description='solute carrier family 25 member 1', other_designations='tricarboxylate transport protein, mitochondrial|citrate transport protein|solute carrier family 20 (mitochondrial citrate transporter), member 3|solute carrier family 25 (mitochondrial carrier; citrate transporter), member 1|tricarboxylate carrier protein', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19175581, end_position_on_the_genomic_accession=19178736, orientation='minus', exon_count=10, OMIM=[190315], no_hdr0=''),
    6578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6578, CurrentID=0, Status='live', Symbol='SLCO2A1', Aliases=['MATR1', 'OATP2A1', 'PGT', 'PHOAD', 'PHOAR2', 'SLC21A2'], description='solute carrier organic anion transporter family member 2A1', other_designations='solute carrier organic anion transporter family member 2A1|matrin F/G 1|solute carrier family 21 (prostaglandin transporter), member 2', map_location='3q22.1-q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133932701, end_position_on_the_genomic_accession=134029955, orientation='minus', exon_count=16, OMIM=[601460], no_hdr0=''),
    6579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6579, CurrentID=0, Status='live', Symbol='SLCO1A2', Aliases=['OATP', 'OATP-A', 'OATP1A2', 'SLC21A3'], description='solute carrier organic anion transporter family member 1A2', other_designations='solute carrier organic anion transporter family member 1A2|OATP-1|organic anion transporting polypeptide A|organic anion-transporting polypeptide 1|sodium-independent organic anion transporter|solute carrier family 21 (organic anion transporter), member 3|solute carrier family 21 member 3', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21264600, end_position_on_the_genomic_accession=21419634, orientation='minus', exon_count=31, OMIM=[602883], no_hdr0=''),
    6580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6580, CurrentID=0, Status='live', Symbol='SLC22A1', Aliases=['HOCT1', 'OCT1', 'oct1_cds'], description='solute carrier family 22 member 1', other_designations='solute carrier family 22 member 1|organic cation transporter 1|solute carrier family 22 (organic cation transporter), member 1', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160121808, end_position_on_the_genomic_accession=160160590, orientation='plus', exon_count=13, OMIM=[602607], no_hdr0=''),
    6581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6581, CurrentID=0, Status='live', Symbol='SLC22A3', Aliases=['EMT', 'EMTH', 'OCT3'], description='solute carrier family 22 member 3', other_designations='solute carrier family 22 member 3|EMT organic cation transporter 3|extraneuronal monoamine transporter|organic cation transporter 3|solute carrier family 22 (extraneuronal monoamine transporter), member 3|solute carrier family 22 (organic cation transporter), member 3', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160348378, end_position_on_the_genomic_accession=160454982, orientation='plus', exon_count=15, OMIM=[604842], no_hdr0=''),
    6582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6582, CurrentID=0, Status='live', Symbol='SLC22A2', Aliases=['OCT2'], description='solute carrier family 22 member 2', other_designations='solute carrier family 22 member 2|organic cation transporter 2|solute carrier family 22 (organic cation transporter), member 2', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=160216755, end_position_on_the_genomic_accession=160258821, orientation='minus', exon_count=11, OMIM=[602608], no_hdr0=''),
    6583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6583, CurrentID=0, Status='live', Symbol='SLC22A4', Aliases=['DFNB60', 'OCTN1'], description='solute carrier family 22 member 4', other_designations='solute carrier family 22 member 4|ET transporter|deafness, autosomal recessive 60|ergothioneine transporter|integral membrane transport protein|organic cation/carnitine transporter 1|solute carrier family 22 (organic cation/ergothioneine transporter), member 4|solute carrier family 22 (organic cation/zwitterion transporter), member 4', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132294384, end_position_on_the_genomic_accession=132344199, orientation='plus', exon_count=11, OMIM=[604190], no_hdr0=''),
    6584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6584, CurrentID=0, Status='live', Symbol='SLC22A5', Aliases=['CDSP', 'OCTN2'], description='solute carrier family 22 member 5', other_designations='solute carrier family 22 member 5|high-affinity sodium dependent carnitine cotransporter|organic cation/carnitine transporter 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132369704, end_position_on_the_genomic_accession=132395614, orientation='plus', exon_count=11, OMIM=[603377], no_hdr0=''),
    6585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6585, CurrentID=0, Status='live', Symbol='SLIT1', Aliases=['MEGF4', 'SLIL1', 'SLIT-1', 'SLIT3'], description='slit guidance ligand 1', other_designations='slit homolog 1 protein|multiple EGF-like domains protein 4|multiple epidermal growth factor-like domains protein 4|slit homolog 1', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96998038, end_position_on_the_genomic_accession=97185959, orientation='minus', exon_count=37, OMIM=[603742], no_hdr0=''),
    6586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6586, CurrentID=0, Status='live', Symbol='SLIT3', Aliases=['MEGF5', 'SLIL2', 'SLIT1', 'Slit-3', 'slit2'], description='slit guidance ligand 3', other_designations='slit homolog 3 protein|multiple EGF-like domains protein 5|multiple epidermal growth factor-like domains protein 5|slit homolog 3', map_location='5q34-q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=168661740, end_position_on_the_genomic_accession=169301139, orientation='minus', exon_count=37, OMIM=[603745], no_hdr0=''),
    6588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6588, CurrentID=0, Status='live', Symbol='SLN', Aliases=[], description='sarcolipin', other_designations='sarcolipin', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107707378, end_position_on_the_genomic_accession=107712056, orientation='minus', exon_count=2, OMIM=[602203], no_hdr0=''),
    6590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6590, CurrentID=0, Status='live', Symbol='SLPI', Aliases=['ALK1', 'ALP', 'BLPI', 'HUSI', 'HUSI-I', 'MPI', 'WAP4', 'WFDC4'], description='secretory leukocyte peptidase inhibitor', other_designations='antileukoproteinase|HUSI-1|WAP four-disulfide core domain protein 4|mucus proteinase inhibitor|protease inhibitor WAP4|secretory leukocyte protease inhibitor (antileukoproteinase)|seminal proteinase inhibitor', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45252239, end_position_on_the_genomic_accession=45254564, orientation='minus', exon_count=4, OMIM=[107285], no_hdr0=''),
    6591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6591, CurrentID=0, Status='live', Symbol='SNAI2', Aliases=['SLUG', 'SLUGH', 'SLUGH1', 'SNAIL2', 'WS2D'], description='snail family transcriptional repressor 2', other_designations='zinc finger protein SNAI2|neural crest transcription factor SLUG|protein snail homolog 2|slug (chicken homolog), zinc finger protein|snail family zinc finger 2|snail homolog 2', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=48917598, end_position_on_the_genomic_accession=48921429, orientation='minus', exon_count=3, OMIM=[602150], no_hdr0=''),
    6594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6594, CurrentID=0, Status='live', Symbol='SMARCA1', Aliases=['ISWI', 'NURF140', 'SNF2L', 'SNF2L1', 'SNF2LB', 'SNF2LT', 'SWI', 'SWI2', 'hSNF2L'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a, member 1', other_designations='probable global transcription activator SNF2L1|ATP-dependent helicase SMARCA1|SNF2-like 1|global transcription activator homologous sequence|nucleosome-remodeling factor subunit SNF2L|sucrose nonfermenting 2-like protein 1', map_location='Xq25-q26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129446501, end_position_on_the_genomic_accession=129523520, orientation='minus', exon_count=25, OMIM=[300012], no_hdr0=''),
    6595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6595, CurrentID=0, Status='live', Symbol='SMARCA2', Aliases=['BAF190', 'BIS', 'BRM', 'NCBRS', 'SNF2', 'SNF2L2', 'SNF2LA', 'SWI2', 'Sth1p', 'hBRM', 'hSNF2a'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a, member 2', other_designations='probable global transcription activator SNF2L2|ATP-dependent helicase SMARCA2|BAF190B|BRG1-associated factor 190B|SNF2-alpha|SNF2/SWI2-like protein 2|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin a2|brahma homolog|global transcription activator homologous sequence|protein brahma homolog|sucrose nonfermenting 2-like protein 2', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=2015347, end_position_on_the_genomic_accession=2193624, orientation='plus', exon_count=38, OMIM=[600014], no_hdr0=''),
    6596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6596, CurrentID=0, Status='live', Symbol='HLTF', Aliases=['HIP116', 'HIP116A1', 'RNF80', 'SMARCA3', 'SNF2L3', 'ZBU1', 'HLTF'], description='helicase like transcription factor', other_designations='helicase-like transcription factor|DNA-binding protein/plasminogen activator inhibitor-1 regulator|RING finger protein 80|RING-type E3 ubiquitin transferase HLTF|SNF2-like 3|SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a, member 3|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily A member 3|sucrose nonfermenting protein 2-like 3|sucrose nonfermenting-like 3', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149030063, end_position_on_the_genomic_accession=149086534, orientation='minus', exon_count=25, OMIM=[603257], no_hdr0=''),
    6597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6597, CurrentID=0, Status='live', Symbol='SMARCA4', Aliases=['BAF190', 'BAF190A', 'BRG1', 'CSS4', 'MRD16', 'RTPS2', 'SNF2', 'SNF2-beta', 'SNF2L4', 'SNF2LB', 'SWI2', 'hSNF2b'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a, member 4', other_designations='transcription activator BRG1|ATP-dependent helicase SMARCA4|BRG1-associated factor 190A|BRM/SWI2-related gene 1|SNF2-like 4|brahma protein-like 1|global transcription activator homologous sequence|homeotic gene regulator|mitotic growth and transcription activator|nuclear protein GRB1|protein BRG-1|protein brahma homolog 1|sucrose nonfermenting-like 4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10960999, end_position_on_the_genomic_accession=11062277, orientation='plus', exon_count=40, OMIM=[603254], no_hdr0=''),
    6598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6598, CurrentID=0, Status='live', Symbol='SMARCB1', Aliases=['BAF47', 'CSS3', 'INI1', 'MRD15', 'PPP1R144', 'RDT', 'RTPS1', 'SNF5', 'SNF5L1', 'SWNTS1', 'Sfh1p', 'Snr1', 'hSNFS'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily b, member 1', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily B member 1|BRG1-associated factor 47|SNF5 homolog|SWI/SNF-related matrix-associated protein|hSNF5|integrase interactor 1 protein|malignant rhabdoid tumor suppressor|protein phosphatase 1, regulatory subunit 144|sucrose nonfermenting, yeast, homolog-like 1', map_location='22q11', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23786966, end_position_on_the_genomic_accession=23838009, orientation='plus', exon_count=9, OMIM=[601607], no_hdr0=''),
    6599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6599, CurrentID=0, Status='live', Symbol='SMARCC1', Aliases=['BAF155', 'CRACC1', 'Rsc8', 'SRG3', 'SWI3'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin subfamily c member 1', other_designations='SWI/SNF complex subunit SMARCC1|BRG1-associated factor 155|SWI/SNF complex 155 kDa subunit|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily C member 1|chromatin remodeling complex BAF155 subunit|mammalian chromatin remodeling complex BRG1-associated factor 155', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47585269, end_position_on_the_genomic_accession=47781893, orientation='minus', exon_count=28, OMIM=[601732], no_hdr0=''),
    6601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6601, CurrentID=0, Status='live', Symbol='SMARCC2', Aliases=['BAF170', 'CRACC2', 'CSS8', 'Rsc8'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin subfamily c member 2', other_designations='SWI/SNF complex subunit SMARCC2|SWI/SNF complex 170 kDa subunit|SWI3-like protein|chromatin remodeling complex BAF170 subunit|mammalian chromatin remodeling complex BRG1-associated factor 170', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56162359, end_position_on_the_genomic_accession=56189504, orientation='minus', exon_count=30, OMIM=[601734], no_hdr0=''),
    6602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6602, CurrentID=0, Status='live', Symbol='SMARCD1', Aliases=['BAF60A', 'CRACD1', 'CSS11', 'Rsc6p'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily d, member 1', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily D member 1|60 kDa BRG-1/Brm-associated factor subunit A|BRG1-associated factor 60A|SWI/SNF complex 60 kDa subunit A|Swp73-like protein|chromatin remodeling complex BAF60A subunit|mammalian chromatin remodeling complex BRG1-associated factor 60A', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50085236, end_position_on_the_genomic_accession=50100707, orientation='plus', exon_count=14, OMIM=[601735], no_hdr0=''),
    6603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6603, CurrentID=0, Status='live', Symbol='SMARCD2', Aliases=['BAF60B', 'CRACD2', 'PRO2451', 'Rsc6p', 'SGD2'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily d, member 2', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily D member 2|60 kDa BRG-1/Brm-associated factor subunit B|BRG1-associated factor 60B|SWI/SNF complex 60 kDa subunit B|Swp73-like protein|chromatin remodeling complex BAF60B subunit|mammalian chromatin remodeling complex BRG1-associated factor 60B', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63832081, end_position_on_the_genomic_accession=63842685, orientation='minus', exon_count=14, OMIM=[601736], no_hdr0=''),
    6604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6604, CurrentID=0, Status='live', Symbol='SMARCD3', Aliases=['BAF60C', 'CRACD3', 'Rsc6p'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily d, member 3', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily D member 3|60 kDa BRG-1/Brm-associated factor subunit C|BRG1-associated factor 60C|SWI/SNF complex 60 kDa subunit C|Swp73-like protein|chromatin remodeling complex BAF60C subunit|mammalian chromatin remodeling complex BRG1-associated factor 60C', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151238780, end_position_on_the_genomic_accession=151277452, orientation='minus', exon_count=17, OMIM=[601737], no_hdr0=''),
    6605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6605, CurrentID=0, Status='live', Symbol='SMARCE1', Aliases=['BAF57', 'CSS5'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily e, member 1', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily E member 1|BRG1-associated factor 57|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin e1|chromatin remodeling complex BRG1-associated factor 57', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40624962, end_position_on_the_genomic_accession=40647818, orientation='minus', exon_count=11, OMIM=[603111], no_hdr0=''),
    6606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6606, CurrentID=0, Status='live', Symbol='SMN1', Aliases=['BCD541', 'GEMIN1', 'SMA', 'SMA1', 'SMA2', 'SMA3', 'SMA4', 'SMA@', 'SMN', 'SMNT', 'T-BCD541', 'TDRD16A'], description='survival of motor neuron 1, telomeric', other_designations='survival motor neuron protein|component of gems 1|gemin-1|survival motor neuron 1 protein|tudor domain containing 16A', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=70924941, end_position_on_the_genomic_accession=70953015, orientation='plus', exon_count=10, OMIM=[600354], no_hdr0=''),
    6607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6607, CurrentID=0, Status='live', Symbol='SMN2', Aliases=['BCD541', 'C-BCD541', 'GEMIN1', 'SMNC', 'TDRD16B'], description='survival of motor neuron 2, centromeric', other_designations='survival motor neuron protein|component of gems 1|gemin-1|tudor domain containing 16B', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=70049523, end_position_on_the_genomic_accession=70077595, orientation='plus', exon_count=10, OMIM=[601627], no_hdr0=''),
    6608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6608, CurrentID=0, Status='live', Symbol='SMO', Aliases=['CRJS', 'FZD11', 'Gx', 'PHLSH', 'SMO'], description='smoothened, frizzled class receptor', other_designations='smoothened homolog|frizzled family member 11|protein Gx|seven transmembrane helix receptor|smoothened, frizzled family receptor|smoothened, seven transmembrane spanning receptor', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129188633, end_position_on_the_genomic_accession=129213548, orientation='plus', exon_count=13, OMIM=[601500], no_hdr0=''),
    6609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6609, CurrentID=0, Status='live', Symbol='SMPD1', Aliases=['ASM', 'ASMASE', 'NPD'], description='sphingomyelin phosphodiesterase 1', other_designations='sphingomyelin phosphodiesterase|Niemann-Pick type A/B|acid sphingomyelinase|sphingomyelin phosphodiesterase 1, acid lysosomal', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6390474, end_position_on_the_genomic_accession=6394998, orientation='plus', exon_count=5, OMIM=[607608], no_hdr0=''),
    6610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6610, CurrentID=0, Status='live', Symbol='SMPD2', Aliases=['ISC1', 'NSMASE', 'NSMASE1'], description='sphingomyelin phosphodiesterase 2', other_designations='sphingomyelin phosphodiesterase 2|N-SMase|lyso-PAF-PLC|lyso-platelet-activating factor-phospholipase C|neutral sphingomyelinase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109440721, end_position_on_the_genomic_accession=109443922, orientation='plus', exon_count=10, OMIM=[603498], no_hdr0=''),
    6611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6611, CurrentID=0, Status='live', Symbol='SMS', Aliases=['MRSR', 'SPMSY', 'SRS', 'SpS'], description='spermine synthase', other_designations='spermine synthase|spermidine aminopropyltransferase', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21940709, end_position_on_the_genomic_accession=21994837, orientation='plus', exon_count=14, OMIM=[300105], no_hdr0=''),
    6612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6612, CurrentID=0, Status='live', Symbol='SUMO3', Aliases=['SMT3A', 'SMT3H1', 'SUMO-3', 'Smt3B'], description='small ubiquitin like modifier 3', other_designations='small ubiquitin-related modifier 3|SMT3 suppressor of mif two 3 homolog 1|SMT3 suppressor of mif two 3 homolog 3|ubiquitin-like protein SMT3B', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44805617, end_position_on_the_genomic_accession=44818062, orientation='minus', exon_count=4, OMIM=[602231], no_hdr0=''),
    6613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6613, CurrentID=0, Status='live', Symbol='SUMO2', Aliases=['HSMT3', 'SMT3B', 'SMT3H2', 'SUMO3', 'Smt3A'], description='small ubiquitin like modifier 2', other_designations='small ubiquitin-related modifier 2|SMT3 homolog 2|SMT3 suppressor of mif two 3 homolog 2|sentrin 2|ubiquitin-like protein SMT3A|ubiquitin-like protein SMT3B', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75165586, end_position_on_the_genomic_accession=75182959, orientation='minus', exon_count=4, OMIM=[603042], no_hdr0=''),
    6614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6614, CurrentID=0, Status='live', Symbol='SIGLEC1', Aliases=['CD169', 'SIGLEC-1', 'SN'], description='sialic acid binding Ig like lectin 1', other_designations='sialoadhesin|sialic acid binding Ig-like lectin 1, sialoadhesin|sialic acid-binding immunoglobulin-like lectin 1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3686970, end_position_on_the_genomic_accession=3712600, orientation='minus', exon_count=22, OMIM=[600751], no_hdr0=''),
    6615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6615, CurrentID=0, Status='live', Symbol='SNAI1', Aliases=['SLUGH2', 'SNA', 'SNAH', 'SNAIL', 'SNAIL1', 'dJ710H13.1'], description='snail family transcriptional repressor 1', other_designations='zinc finger protein SNAI1|protein sna|protein snail homolog 1|snail 1 homolog|snail 1 zinc finger protein|snail family zinc finger 1|snail homolog 1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49982980, end_position_on_the_genomic_accession=49988886, orientation='plus', exon_count=3, OMIM=[604238], no_hdr0=''),
    6616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6616, CurrentID=0, Status='live', Symbol='SNAP25', Aliases=['CMS18', 'RIC-4', 'RIC4', 'SEC9', 'SNAP', 'SNAP-25', 'SUP', 'bA416N4.2', 'dJ1068F16.2'], description='synaptosome associated protein 25', other_designations='synaptosomal-associated protein 25|resistance to inhibitors of cholinesterase 4 homolog|synaptosomal-associated protein, 25kDa|synaptosome associated protein 25kDa', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=10218830, end_position_on_the_genomic_accession=10307420, orientation='plus', exon_count=17, OMIM=[600322], no_hdr0=''),
    6617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6617, CurrentID=0, Status='live', Symbol='SNAPC1', Aliases=['PTFgamma', 'SNAP43'], description='small nuclear RNA activating complex polypeptide 1', other_designations='snRNA-activating protein complex subunit 1|PSE-binding factor subunit gamma|PTF subunit gamma|SNAPc 43 kDa subunit|SNAPc subunit 1|proximal sequence element-binding transcription factor subunit gamma|small nuclear RNA activating complex, polypeptide 1, 43kD|small nuclear RNA activating complex, polypeptide 1, 43kDa|snRNA-activating protein complex 43 kDa subunit', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=61762420, end_position_on_the_genomic_accession=61796428, orientation='plus', exon_count=10, OMIM=[600591], no_hdr0=''),
    6618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6618, CurrentID=0, Status='live', Symbol='SNAPC2', Aliases=['PTFDELTA', 'SNAP45'], description='small nuclear RNA activating complex polypeptide 2', other_designations='snRNA-activating protein complex subunit 2|PSE-binding factor subunit delta|PTF subunit delta|SNAPC 45 kDa subunit|SNAPc subunit 2|proximal sequence element-binding transcription factor subunit delta|small nuclear RNA activating complex, polypeptide 2, 45kD|small nuclear RNA activating complex, polypeptide 2, 45kDa|snRNA-activating protein complex 45 kDa subunit', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7920338, end_position_on_the_genomic_accession=7923250, orientation='plus', exon_count=6, OMIM=[605076], no_hdr0=''),
    6619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6619, CurrentID=0, Status='live', Symbol='SNAPC3', Aliases=['PTFbeta', 'SNAP50'], description='small nuclear RNA activating complex polypeptide 3', other_designations='snRNA-activating protein complex subunit 3|PSE-binding factor subunit beta|PTF subunit beta|SNAPc 50 kDa subunit|SNAPc subunit 3|proximal sequence element-binding transcription factor subunit beta|small nuclear RNA activating complex, polypeptide 3, 50kD|small nuclear RNA activating complex, polypeptide 3, 50kDa|snRNA-activating protein complex 50 kDa subunit', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=15422809, end_position_on_the_genomic_accession=15466749, orientation='plus', exon_count=11, OMIM=[602348], no_hdr0=''),
    6620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6620, CurrentID=0, Status='live', Symbol='SNCB', Aliases=[], description='synuclein beta', other_designations='beta-synuclein|I(2)-synuclein', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176620082, end_position_on_the_genomic_accession=176630556, orientation='minus', exon_count=7, OMIM=[602569], no_hdr0=''),
    6621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6621, CurrentID=0, Status='live', Symbol='SNAPC4', Aliases=['PTFalpha', 'SNAP190'], description='small nuclear RNA activating complex polypeptide 4', other_designations='snRNA-activating protein complex subunit 4|PSE-binding factor subunit alpha|PTF subunit alpha|SNAPc 190 kDa subunit|SNAPc subunit 4|proximal sequence element-binding transcription factor subunit alpha|snRNA-activating protein complex 190 kDa subunit', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136375571, end_position_on_the_genomic_accession=136400170, orientation='minus', exon_count=24, OMIM=[602777], no_hdr0=''),
    6622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6622, CurrentID=0, Status='live', Symbol='SNCA', Aliases=['NACP', 'PARK1', 'PARK4', 'PD1'], description='synuclein alpha', other_designations='alpha-synuclein|I+/--synuclein|non A-beta component of AD amyloid|synuclein alpha-140|synuclein, alpha (non A4 component of amyloid precursor)|truncated alpha synuclein', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=89724099, end_position_on_the_genomic_accession=89838324, orientation='minus', exon_count=13, OMIM=[163890], no_hdr0=''),
    6623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6623, CurrentID=0, Status='live', Symbol='SNCG', Aliases=['BCSG1', 'SR'], description='synuclein gamma', other_designations='gamma-synuclein|-synuclein|E pound-synuclein|breast cancer-specific gene 1 protein|persyn|synoretin|synuclein, gamma (breast cancer-specific protein 1)', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86955759, end_position_on_the_genomic_accession=86963260, orientation='plus', exon_count=7, OMIM=[602998], no_hdr0=''),
    6624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6624, CurrentID=0, Status='live', Symbol='FSCN1', Aliases=['FAN1', 'HSN', 'SNL', 'p55'], description='fascin actin-bundling protein 1', other_designations='fascin|55 kDa actin-bundling protein|epididymis secretory sperm binding protein|fascin homolog 1, actin-bundling protein|singed-like (fascin homolog, sea urchin)', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5592816, end_position_on_the_genomic_accession=5606655, orientation='plus', exon_count=5, OMIM=[602689], no_hdr0=''),
    6625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6625, CurrentID=0, Status='live', Symbol='SNRNP70', Aliases=['RNPU1Z', 'RPU1', 'SNRP70', 'Snp1', 'U1-70K', 'U170K', 'U1AP', 'U1RNP'], description='small nuclear ribonucleoprotein U1 subunit 70', other_designations='U1 small nuclear ribonucleoprotein 70 kDa|U1 snRNP 70 kDa|small nuclear ribonucleoprotein 70kDa (U1)|small nuclear ribonucleoprotein, U1 70kDa subunit', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49085451, end_position_on_the_genomic_accession=49108606, orientation='plus', exon_count=12, OMIM=[180740], no_hdr0=''),
    6626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6626, CurrentID=0, Status='live', Symbol='SNRPA', Aliases=['Mud1', 'U1-A', 'U1A'], description='small nuclear ribonucleoprotein polypeptide A', other_designations='U1 small nuclear ribonucleoprotein A|U1 small nuclear RNP-specific A|U1 snRNP A|U1 snRNP-specific protein A', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40751203, end_position_on_the_genomic_accession=40765389, orientation='plus', exon_count=6, OMIM=[182285], no_hdr0=''),
    6627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6627, CurrentID=0, Status='live', Symbol='SNRPA1', Aliases=['Lea1', "U2A'"], description="small nuclear ribonucleoprotein polypeptide A'", other_designations="U2 small nuclear ribonucleoprotein A'|U2 small nuclear ribonucleoprotein polypeptide A'|U2 snRNP A'", map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101281510, end_position_on_the_genomic_accession=101295248, orientation='minus', exon_count=9, OMIM=[603521], no_hdr0=''),
    6628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6628, CurrentID=0, Status='live', Symbol='SNRPB', Aliases=['CCMS', 'COD1', "Sm-B/B'", "SmB/B'", "SmB/SmB'", 'snRNP-B', 'SNRPB'], description='small nuclear ribonucleoprotein polypeptides B and B1', other_designations="small nuclear ribonucleoprotein-associated proteins B and B'|B polypeptide of Sm protein|Sm protein B/B'|sm-B/Sm-B'|small nuclear ribonucleoprotein polypeptide B|small nuclear ribonucleoprotein polypeptides B and B'", map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2461642, end_position_on_the_genomic_accession=2470789, orientation='minus', exon_count=7, OMIM=[182282], no_hdr0=''),
    6629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6629, CurrentID=0, Status='live', Symbol='SNRPB2', Aliases=['Msl1', "U2B''"], description='small nuclear ribonucleoprotein polypeptide B2', other_designations="U2 small nuclear ribonucleoprotein B''|U2 snRNP B''|small nuclear ribonucleoprotein polypeptide B", map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=16730026, end_position_on_the_genomic_accession=16742564, orientation='plus', exon_count=7, OMIM=[603520], no_hdr0=''),
    6631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6631, CurrentID=0, Status='live', Symbol='SNRPC', Aliases=['U1C', 'Yhc1'], description='small nuclear ribonucleoprotein polypeptide C', other_designations='U1 small nuclear ribonucleoprotein C|U1 small nuclear RNP specific C|U1 snRNP C|U1 snRNP protein C', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34757505, end_position_on_the_genomic_accession=34773857, orientation='plus', exon_count=6, OMIM=[603522], no_hdr0=''),
    6632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6632, CurrentID=0, Status='live', Symbol='SNRPD1', Aliases=['HsT2456', 'SMD1', 'SNRPD', 'Sm-D1'], description='small nuclear ribonucleoprotein D1 polypeptide', other_designations='small nuclear ribonucleoprotein Sm D1|Sm-D autoantigen|small nuclear ribonucleoprotein D1 polypeptide 16kDa pseudogene|snRNP core protein D1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=21612314, end_position_on_the_genomic_accession=21633520, orientation='plus', exon_count=4, OMIM=[601063], no_hdr0=''),
    6633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6633, CurrentID=0, Status='live', Symbol='SNRPD2', Aliases=['SMD2', 'SNRPD1', 'Sm-D2'], description='small nuclear ribonucleoprotein D2 polypeptide', other_designations='small nuclear ribonucleoprotein Sm D2|small nuclear ribonucleoprotein D2 polypeptide 16.5kDa|snRNP core protein D2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45687454, end_position_on_the_genomic_accession=45692316, orientation='minus', exon_count=6, OMIM=[601061], no_hdr0=''),
    6634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6634, CurrentID=0, Status='live', Symbol='SNRPD3', Aliases=['SMD3', 'Sm-D3'], description='small nuclear ribonucleoprotein D3 polypeptide', other_designations='small nuclear ribonucleoprotein Sm D3|small nuclear ribonucleoprotein D3 polypeptide 18kDa|snRNP core protein D3', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24555650, end_position_on_the_genomic_accession=24574971, orientation='plus', exon_count=4, OMIM=[601062], no_hdr0=''),
    6635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6635, CurrentID=0, Status='live', Symbol='SNRPE', Aliases=['HYPT11', 'SME', 'Sm-E', 'snRNP-E'], description='small nuclear ribonucleoprotein polypeptide E', other_designations='small nuclear ribonucleoprotein E|sm protein E', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203861599, end_position_on_the_genomic_accession=203871152, orientation='plus', exon_count=6, OMIM=[128260], no_hdr0=''),
    6636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6636, CurrentID=0, Status='live', Symbol='SNRPF', Aliases=['SMF', 'Sm-F', 'snRNP-F'], description='small nuclear ribonucleoprotein polypeptide F', other_designations='small nuclear ribonucleoprotein F|sm protein F', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95858952, end_position_on_the_genomic_accession=95866140, orientation='plus', exon_count=4, OMIM=[603541], no_hdr0=''),
    6637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6637, CurrentID=0, Status='live', Symbol='SNRPG', Aliases=['SMG', 'Sm-G'], description='small nuclear ribonucleoprotein polypeptide G', other_designations='small nuclear ribonucleoprotein G|sm protein G|snRNP-G', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70281362, end_position_on_the_genomic_accession=70293740, orientation='minus', exon_count=7, OMIM=[603542], no_hdr0=''),
    6638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6638, CurrentID=0, Status='live', Symbol='SNRPN', Aliases=['HCERN3', 'PWCR', 'RT-LI', 'SM-D', 'SMN', 'SNRNP-N', 'SNURF-SNRPN', 'sm-N'], description='small nuclear ribonucleoprotein polypeptide N', other_designations='small nuclear ribonucleoprotein-associated protein N|SM protein N|sm protein D|tissue-specific splicing protein', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=24823637, end_position_on_the_genomic_accession=24978723, orientation='plus', exon_count=23, OMIM=[182279], no_hdr0=''),
    6640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6640, CurrentID=0, Status='live', Symbol='SNTA1', Aliases=['LQT12', 'SNT1', 'TACIP1', 'dJ1187J4.5'], description='syntrophin alpha 1', other_designations='alpha-1-syntrophin|59 kDa dystrophin-associated protein A1 acidic component 1|acidic alpha 1 syntrophin|dystrophin-associated protein A1, 59kDa, acidic component|pro-TGF-alpha cytoplasmic domain-interacting protein 1|syntrophin-1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33407957, end_position_on_the_genomic_accession=33443853, orientation='minus', exon_count=9, OMIM=[601017], no_hdr0=''),
    6641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6641, CurrentID=0, Status='live', Symbol='SNTB1', Aliases=['59-DAP', 'A1B', 'BSYN2', 'DAPA1B', 'SNT2', 'SNT2B1', 'TIP-43'], description='syntrophin beta 1', other_designations='beta-1-syntrophin|59 kDa dystrophin-associated protein A1 basic component 1|dystrophin-associated protein A1, 59kD, basic component 1|syntrophin, beta 1 (dystrophin-associated protein A1, 59kDa, basic component 1)|syntrophin-2|tax interaction protein 43', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=120535756, end_position_on_the_genomic_accession=120812046, orientation='minus', exon_count=8, OMIM=[600026], no_hdr0=''),
    6642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6642, CurrentID=0, Status='live', Symbol='SNX1', Aliases=['HsT17379', 'VPS5'], description='sorting nexin 1', other_designations='sorting nexin-1|sorting nexin 1A', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64094066, end_position_on_the_genomic_accession=64144231, orientation='plus', exon_count=17, OMIM=[601272], no_hdr0=''),
    6643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6643, CurrentID=0, Status='live', Symbol='SNX2', Aliases=['TRG-9'], description='sorting nexin 2', other_designations='sorting nexin-2|CTB-36H16.2|transformation-related gene 9 protein', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122774996, end_position_on_the_genomic_accession=122834543, orientation='plus', exon_count=15, OMIM=[605929], no_hdr0=''),
    6645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6645, CurrentID=0, Status='live', Symbol='SNTB2', Aliases=['D16S2531E', 'EST25263', 'SNT2B2', 'SNT3', 'SNTL'], description='syntrophin beta 2', other_designations='beta-2-syntrophin|59 kDa dystrophin-associated protein A1 basic component 2|dystrophin-associated protein A1, 59kD, basic component 2|syntrophin, beta 2 (dystrophin-associated protein A1, 59kDa, basic component 2)|syntrophin-3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69187164, end_position_on_the_genomic_accession=69309052, orientation='plus', exon_count=8, OMIM=[600027], no_hdr0=''),
    6646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6646, CurrentID=0, Status='live', Symbol='SOAT1', Aliases=['ACACT', 'ACAT', 'ACAT-1', 'ACAT1', 'SOAT', 'STAT'], description='sterol O-acyltransferase 1', other_designations='sterol O-acyltransferase 1|acyl-coenzyme A:cholesterol acyltransferase 1|sterol O-acyltransferase (acyl-Coenzyme A: cholesterol acyltransferase) 1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179293719, end_position_on_the_genomic_accession=179358680, orientation='plus', exon_count=17, OMIM=[102642], no_hdr0=''),
    6647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6647, CurrentID=0, Status='live', Symbol='SOD1', Aliases=['ALS', 'ALS1', 'HEL-S-44', 'IPOA', 'SOD', 'STAHP', 'hSod1', 'homodimer'], description='superoxide dismutase 1', other_designations='superoxide dismutase [Cu-Zn]|Cu/Zn superoxide dismutase|SOD, soluble|epididymis secretory protein Li 44|indophenoloxidase A|superoxide dismutase 1, soluble|superoxide dismutase, cystolic', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=31659693, end_position_on_the_genomic_accession=31668931, orientation='plus', exon_count=5, OMIM=[147450], no_hdr0=''),
    6648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6648, CurrentID=0, Status='live', Symbol='SOD2', Aliases=['GClnc1', 'IPO-B', 'IPOB', 'MNSOD', 'MVCD6', 'Mn-SOD'], description='superoxide dismutase 2', other_designations='superoxide dismutase [Mn], mitochondrial|Mn superoxide dismutase|epididymis secretory sperm binding protein|gastric cancer-associated lncRNA 1|indophenoloxidase B|manganese-containing superoxide dismutase|mangano-superoxide dismutase|superoxide dismutase 2, mitochondrial', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159669069, end_position_on_the_genomic_accession=159762281, orientation='minus', exon_count=10, OMIM=[147460], no_hdr0=''),
    6649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6649, CurrentID=0, Status='live', Symbol='SOD3', Aliases=['EC-SOD'], description='superoxide dismutase 3', other_designations='extracellular superoxide dismutase [Cu-Zn]|superoxide dismutase 3, extracellular|testicular tissue protein Li 175', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=24795478, end_position_on_the_genomic_accession=24800845, orientation='plus', exon_count=3, OMIM=[185490], no_hdr0=''),
    6650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6650, CurrentID=0, Status='live', Symbol='CAPN15', Aliases=['OGIN', 'SOLH'], description='calpain 15', other_designations='calpain-15|small optic lobes homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=527712, end_position_on_the_genomic_accession=554636, orientation='plus', exon_count=17, OMIM=[603267], no_hdr0=''),
    6651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6651, CurrentID=0, Status='live', Symbol='SON', Aliases=['BASS1', 'C21orf50', 'DBP-5', 'NREBP3', 'TOKIMS', 'SON'], description='SON DNA and RNA binding protein', other_designations='protein SON|Bax antagonist selected in Saccharomyces 1|NRE-binding protein|SON DNA binding protein|negative regulatory element-binding protein', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33543038, end_position_on_the_genomic_accession=33577481, orientation='plus', exon_count=15, OMIM=[182465], no_hdr0=''),
    6652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6652, CurrentID=0, Status='live', Symbol='SORD', Aliases=['HEL-S-95n', 'RDH', 'SDH1', 'SORDD', 'XDH', 'SORD'], description='sorbitol dehydrogenase', other_designations='sorbitol dehydrogenase|(R,R)-butanediol dehydrogenase|L-iditol 2-dehydrogenase|epididymis secretory sperm binding protein Li 95n|polyol dehydrogenase|ribitol dehydrogenase|xylitol dehydrogenase', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45023195, end_position_on_the_genomic_accession=45077185, orientation='plus', exon_count=9, OMIM=[182500], no_hdr0=''),
    6653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6653, CurrentID=0, Status='live', Symbol='SORL1', Aliases=['C11orf32', 'LR11', 'LRP9', 'SORLA', 'SorLA-1', 'gp250'], description='sortilin related receptor 1', other_designations='sortilin-related receptor|LDLR relative with 11 ligand-binding repeats|low-density lipoprotein receptor relative with 11 ligand-binding repeats|mosaic protein LR11|sortilin-related receptor, L(DLR class) A repeats containing|sorting protein-related receptor containing LDLR class A repeats', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=121452314, end_position_on_the_genomic_accession=121633763, orientation='plus', exon_count=48, OMIM=[602005], no_hdr0=''),
    6654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6654, CurrentID=0, Status='live', Symbol='SOS1', Aliases=['GF1', 'GGF1', 'GINGF', 'HGF', 'NS4', 'SOS-1'], description='SOS Ras/Rac guanine nucleotide exchange factor 1', other_designations='son of sevenless homolog 1|gingival fibromatosis, hereditary, 1|guanine nucleotide exchange factor', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38981549, end_position_on_the_genomic_accession=39124868, orientation='minus', exon_count=25, OMIM=[182530], no_hdr0=''),
    6655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6655, CurrentID=0, Status='live', Symbol='SOS2', Aliases=['NS9', 'SOS-2'], description='SOS Ras/Rho guanine nucleotide exchange factor 2', other_designations='son of sevenless homolog 2|guanine nucleotide releasing factor', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50117130, end_position_on_the_genomic_accession=50231578, orientation='minus', exon_count=23, OMIM=[601247], no_hdr0=''),
    6656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6656, CurrentID=0, Status='live', Symbol='SOX1', Aliases=[], description='SRY-box transcription factor 1', other_designations='transcription factor SOX-1|SRY (sex determining region Y)-box 1|SRY-box 1|SRY-related HMG-box gene 1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112067149, end_position_on_the_genomic_accession=112071706, orientation='plus', exon_count=1, OMIM=[602148], no_hdr0=''),
    6657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6657, CurrentID=0, Status='live', Symbol='SOX2', Aliases=['ANOP3', 'MCOPS3'], description='SRY-box transcription factor 2', other_designations='transcription factor SOX-2|SRY (sex determining region Y)-box 2|SRY-box 2|SRY-related HMG-box gene 2|sex determining region Y-box 2|transcription factor SOX2', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=181711925, end_position_on_the_genomic_accession=181714436, orientation='plus', exon_count=1, OMIM=[184429], no_hdr0=''),
    6658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6658, CurrentID=0, Status='live', Symbol='SOX3', Aliases=['GHDX', 'MRGH', 'PHP', 'PHPX', 'SOXB'], description='SRY-box transcription factor 3', other_designations='transcription factor SOX-3|SRY (sex determining region Y)-box 3|SRY-box 3', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=140502985, end_position_on_the_genomic_accession=140505069, orientation='minus', exon_count=1, OMIM=[313430], no_hdr0=''),
    6659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6659, CurrentID=0, Status='live', Symbol='SOX4', Aliases=['CSS10', 'EVI16'], description='SRY-box transcription factor 4', other_designations='transcription factor SOX-4|SRY (sex determining region Y)-box 4|SRY-box 4|SRY-related HMG-box gene 4|ecotropic viral integration site 16', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=21593751, end_position_on_the_genomic_accession=21598619, orientation='plus', exon_count=1, OMIM=[184430], no_hdr0=''),
    6660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6660, CurrentID=0, Status='live', Symbol='SOX5', Aliases=['L-SOX5', 'L-SOX5B', 'L-SOX5F', 'LAMSHF'], description='SRY-box transcription factor 5', other_designations='transcription factor SOX-5|SRY (sex determining region Y)-box 5|SRY-box 5', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=23529499, end_position_on_the_genomic_accession=24562701, orientation='minus', exon_count=29, OMIM=[604975], no_hdr0=''),
    6662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6662, CurrentID=0, Status='live', Symbol='SOX9', Aliases=['CMD1', 'CMPD1', 'SRA1', 'SRXX2', 'SRXY10'], description='SRY-box transcription factor 9', other_designations='transcription factor SOX-9|SRY (sex determining region Y)-box9|SRY (sex-determining region Y)-box 9 protein|SRY-box 9|SRY-related HMG-box, gene 9', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=72121020, end_position_on_the_genomic_accession=72126416, orientation='plus', exon_count=3, OMIM=[608160], no_hdr0=''),
    6663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6663, CurrentID=0, Status='live', Symbol='SOX10', Aliases=['DOM', 'PCWH', 'WS2E', 'WS4', 'WS4C'], description='SRY-box transcription factor 10', other_designations='transcription factor SOX-10|SRY (sex determining region Y)-box 10|SRY-box 10|SRY-related HMG-box gene 10|dominant megacolon, mouse, human homolog of', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37972312, end_position_on_the_genomic_accession=37984555, orientation='minus', exon_count=4, OMIM=[602229], no_hdr0=''),
    6664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6664, CurrentID=0, Status='live', Symbol='SOX11', Aliases=['CSS9', 'MRD27'], description='SRY-box transcription factor 11', other_designations='transcription factor SOX-11|SRY (sex-determining region Y)-box 11|SRY-box 11|SRY-related HMG-box gene 11', map_location='2p25.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=5692384, end_position_on_the_genomic_accession=5701385, orientation='plus', exon_count=1, OMIM=[600898], no_hdr0=''),
    6665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6665, CurrentID=0, Status='live', Symbol='SOX15', Aliases=['SOX20', 'SOX26', 'SOX27'], description='SRY-box transcription factor 15', other_designations='protein SOX-15|SRY (sex determining region Y)-box 15|SRY (sex determining region Y)-box 20|SRY-box 15', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7588178, end_position_on_the_genomic_accession=7590094, orientation='minus', exon_count=2, OMIM=[601297], no_hdr0=''),
    6666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6666, CurrentID=0, Status='live', Symbol='SOX12', Aliases=['SOX22'], description='SRY-box transcription factor 12', other_designations='transcription factor SOX-12|SOX-22 protein|SRY (sex determining region Y)-box 12|SRY-box 12|SRY-related HMG-box gene 22', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=325552, end_position_on_the_genomic_accession=330224, orientation='plus', exon_count=1, OMIM=[601947], no_hdr0=''),
    6667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6667, CurrentID=0, Status='live', Symbol='SP1', Aliases=[], description='Sp1 transcription factor', other_designations='transcription factor Sp1|specificity protein 1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53380176, end_position_on_the_genomic_accession=53416446, orientation='plus', exon_count=7, OMIM=[189906], no_hdr0=''),
    6668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6668, CurrentID=0, Status='live', Symbol='SP2', Aliases=[], description='Sp2 transcription factor', other_designations='transcription factor Sp2', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47896032, end_position_on_the_genomic_accession=47932271, orientation='plus', exon_count=14, OMIM=[601801], no_hdr0=''),
    6670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6670, CurrentID=0, Status='live', Symbol='SP3', Aliases=['SPR2'], description='Sp3 transcription factor', other_designations='transcription factor Sp3|GC-binding transcription factor Sp3|specificity protein 3', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=173900775, end_position_on_the_genomic_accession=173965702, orientation='minus', exon_count=7, OMIM=[601804], no_hdr0=''),
    6671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6671, CurrentID=0, Status='live', Symbol='SP4', Aliases=['HF1B', 'SPR-1'], description='Sp4 transcription factor', other_designations='transcription factor Sp4', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=21428083, end_position_on_the_genomic_accession=21514822, orientation='plus', exon_count=10, OMIM=[600540], no_hdr0=''),
    6672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6672, CurrentID=0, Status='live', Symbol='SP100', Aliases=['lysp100b'], description='SP100 nuclear antigen', other_designations='nuclear autoantigen Sp-100|SP100-HMG nuclear autoantigen|nuclear dot-associated Sp100 protein|speckled 100 kDa', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230416201, end_position_on_the_genomic_accession=230545606, orientation='plus', exon_count=32, OMIM=[604585], no_hdr0=''),
    6674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6674, CurrentID=0, Status='live', Symbol='SPAG1', Aliases=['CILD28', 'CT140', 'DNAAF13', 'HEL-S-268', 'HSD-3.8', 'SP75', 'TPIS'], description='sperm associated antigen 1', other_designations='sperm-associated antigen 1|TPR-containing protein involved in spermatogenesis|epididymis secretory protein Li 268|infertility-related sperm protein Spag-1|tetratricopeptide repeat-containing protein', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100157869, end_position_on_the_genomic_accession=100241904, orientation='plus', exon_count=21, OMIM=[603395], no_hdr0=''),
    6675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6675, CurrentID=0, Status='live', Symbol='UAP1', Aliases=['AGX', 'AGX1', 'AGX2', 'SPAG2'], description='UDP-N-acetylglucosamine pyrophosphorylase 1', other_designations='UDP-N-acetylhexosamine pyrophosphorylase|UDP-N-acetylglucosamine diphosphorylase 1|UDP-N-acetylhexosamine pyrophosphorylase 1|antigen X|sperm associated antigen 2|testis tissue sperm-binding protein Li 37a', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162561531, end_position_on_the_genomic_accession=162599837, orientation='plus', exon_count=13, OMIM=[602862], no_hdr0=''),
    6676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6676, CurrentID=0, Status='live', Symbol='SPAG4', Aliases=['CT127', 'SUN4'], description='sperm associated antigen 4', other_designations='sperm-associated antigen 4 protein|SUN domain-containing protein 4|Sad1 and UNC84 domain containing 4|acrosomal protein ACR55|cancer/testis antigen 127|outer dense fiber-associated protein SPAG4|sperm tail protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35615829, end_position_on_the_genomic_accession=35621094, orientation='plus', exon_count=13, OMIM=[603038], no_hdr0=''),
    6677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6677, CurrentID=0, Status='live', Symbol='SPAM1', Aliases=['HEL-S-96n', 'HYA1', 'HYAL1', 'HYAL3', 'HYAL5', 'PH-20', 'PH20', 'SPAG15'], description='sperm adhesion molecule 1', other_designations='hyaluronidase PH-20|PH-20 hyaluronidase|epididymis secretory sperm binding protein Li 96n|hyal-PH20|hyaluronoglucosaminidase PH-20|sperm adhesion molecule 1 (PH-20 hyaluronidase, zona pellucida binding)|sperm surface protein PH-20', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123925241, end_position_on_the_genomic_accession=123971414, orientation='plus', exon_count=9, OMIM=[600930], no_hdr0=''),
    6678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6678, CurrentID=0, Status='live', Symbol='SPARC', Aliases=['BM-40', 'OI17', 'ON', 'ONT'], description='secreted protein acidic and cysteine rich', other_designations='SPARC|basement-membrane protein 40|secreted protein, acidic, cysteine-rich (osteonectin)', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151661096, end_position_on_the_genomic_accession=151686915, orientation='minus', exon_count=10, OMIM=[182120], no_hdr0=''),
    6683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6683, CurrentID=0, Status='live', Symbol='SPAST', Aliases=['ADPSP', 'FSP2', 'SPG4'], description='spastin', other_designations='spastin|spastic paraplegia 4 (autosomal dominant; spastin)|spastic paraplegia 4 protein', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32063551, end_position_on_the_genomic_accession=32157637, orientation='plus', exon_count=17, OMIM=[604277], no_hdr0=''),
    6687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6687, CurrentID=0, Status='live', Symbol='SPG7', Aliases=['CAR', 'CMAR', 'PGN', 'SPG5C'], description='SPG7 matrix AAA peptidase subunit, paraplegin', other_designations='paraplegin|SPG7, paraplegin matrix AAA peptidase subunit|cell matrix adhesion regulator|spastic paraplegia 7 (pure and complicated autosomal recessive)|spastic paraplegia 7 protein', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89508379, end_position_on_the_genomic_accession=89557768, orientation='plus', exon_count=22, OMIM=[602783], no_hdr0=''),
    6688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6688, CurrentID=0, Status='live', Symbol='SPI1', Aliases=['OF', 'PU.1', 'SFPI1', 'SPI-1', 'SPI-A'], description='Spi-1 proto-oncogene', other_designations='transcription factor PU.1|31 kDa transforming protein|hematopoietic transcription factor PU.1|spleen focus forming virus (SFFV) proviral integration oncogene spi1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47354859, end_position_on_the_genomic_accession=47395640, orientation='minus', exon_count=8, OMIM=[165170], no_hdr0=''),
    6689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6689, CurrentID=0, Status='live', Symbol='SPIB', Aliases=['SPI-B'], description='Spi-B transcription factor', other_designations='transcription factor Spi-B|Spi-B transcription factor (Spi-1/PU.1 related)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50418938, end_position_on_the_genomic_accession=50431314, orientation='plus', exon_count=6, OMIM=[606802], no_hdr0=''),
    6690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6690, CurrentID=0, Status='live', Symbol='SPINK1', Aliases=['PCTT', 'PSTI', 'Spink3', 'TATI', 'TCP'], description='serine peptidase inhibitor Kazal type 1', other_designations='serine protease inhibitor Kazal-type 1|pancreatic secretory trypsin inhibitor|serine protease inhibitor, Kazal type 1|tumor-associated trypsin inhibitor', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147824582, end_position_on_the_genomic_accession=147839196, orientation='minus', exon_count=5, OMIM=[167790], no_hdr0=''),
    6691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6691, CurrentID=0, Status='live', Symbol='SPINK2', Aliases=['HUSI-II', 'SPGF29'], description='serine peptidase inhibitor Kazal type 2', other_designations='serine protease inhibitor Kazal-type 2|epididymis tissue protein Li 172|serine peptidase inhibitor, Kazal type 2 (acrosin-trypsin inhibitor)', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56809860, end_position_on_the_genomic_accession=56822210, orientation='minus', exon_count=4, OMIM=[605753], no_hdr0=''),
    6692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6692, CurrentID=0, Status='live', Symbol='SPINT1', Aliases=['HAI', 'HAI1', 'MANSC2'], description='serine peptidase inhibitor, Kunitz type 1', other_designations='kunitz-type protease inhibitor 1|HAI-1|hepatocyte growth factor activator inhibitor type 1|serine protease inhibitor, Kunitz type 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40844048, end_position_on_the_genomic_accession=40858207, orientation='plus', exon_count=11, OMIM=[605123], no_hdr0=''),
    6693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6693, CurrentID=0, Status='live', Symbol='SPN', Aliases=['CD43', 'GALGP', 'GPL115', 'LSN'], description='sialophorin', other_designations='leukosialin|galactoglycoprotein|leukocyte sialoglycoprotein|sialophorin (gpL115, leukosialin, CD43)', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29662963, end_position_on_the_genomic_accession=29670876, orientation='plus', exon_count=3, OMIM=[182160], no_hdr0=''),
    6694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6694, CurrentID=0, Status='live', Symbol='SPP2', Aliases=['SPP-244', 'SPP2'], description='secreted phosphoprotein 2', other_designations='secreted phosphoprotein 24|secreted phosphoprotein 2, 24kD|secreted phosphoprotein 2, 24kDa', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=234050667, end_position_on_the_genomic_accession=234077134, orientation='plus', exon_count=10, OMIM=[602637], no_hdr0=''),
    6695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6695, CurrentID=0, Status='live', Symbol='SPOCK1', Aliases=['SPOCK', 'TESTICAN', 'TIC1'], description='SPARC (osteonectin), cwcv and kazal like domains proteoglycan 1', other_designations='testican-1|SPARC/osteonectin, cwcv and kazal like domains proteoglycan 1|sparc/osteonectin, cwcv and kazal-like domains proteoglycan (testican) 1', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=136975298, end_position_on_the_genomic_accession=137499326, orientation='minus', exon_count=11, OMIM=[602264], no_hdr0=''),
    6696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6696, CurrentID=0, Status='live', Symbol='SPP1', Aliases=['BNSP', 'BSPI', 'ETA-1', 'OPN'], description='secreted phosphoprotein 1', other_designations='osteopontin|SPP1/CALPHA1 fusion|early T-lymphocyte activation 1|nephropontin|osteopontin/immunoglobulin alpha 1 heavy chain constant region fusion protein|secreted phosphoprotein 1 (osteopontin, bone sialoprotein I, early T-lymphocyte activation 1)|secreted phosphoprotein 1 variant 6|urinary stone protein|uropontin', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87975714, end_position_on_the_genomic_accession=87983411, orientation='plus', exon_count=8, OMIM=[166490], no_hdr0=''),
    6697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6697, CurrentID=0, Status='live', Symbol='SPR', Aliases=['SDR38C1'], description='sepiapterin reductase', other_designations='sepiapterin reductase|Sepiapterin reductase (L-erythro-7,8-dihydrobiopterin forming)|sepiapterin reductase (7,8-dihydrobiopterin:NADP+ oxidoreductase)|short chain dehydrogenase/reductase family 38C, member 1', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=72887408, end_position_on_the_genomic_accession=72892158, orientation='plus', exon_count=3, OMIM=[182125], no_hdr0=''),
    6698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6698, CurrentID=0, Status='live', Symbol='SPRR1A', Aliases=['SPRK'], description='small proline rich protein 1A', other_designations='cornifin-A|19 kDa pancornulin|SPR-IA|small proline-rich protein IA', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152984081, end_position_on_the_genomic_accession=152985814, orientation='plus', exon_count=2, OMIM=[182265], no_hdr0=''),
    6699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6699, CurrentID=0, Status='live', Symbol='SPRR1B', Aliases=['CORNIFIN', 'GADD33', 'SPR-IB', 'SPRR1'], description='small proline rich protein 1B', other_designations='cornifin-B|14.9 kDa pancornulin|small proline-rich protein IB', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153031203, end_position_on_the_genomic_accession=153032900, orientation='plus', exon_count=2, OMIM=[182266], no_hdr0=''),
    6700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6700, CurrentID=0, Status='live', Symbol='SPRR2A', Aliases=[], description='small proline rich protein 2A', other_designations='small proline-rich protein 2A|2-1|SPR-2A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153056120, end_position_on_the_genomic_accession=153057512, orientation='minus', exon_count=2, OMIM=[182267], no_hdr0=''),
    6701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6701, CurrentID=0, Status='live', Symbol='SPRR2B', Aliases=[], description='small proline rich protein 2B', other_designations='small proline-rich protein 2B|SPR-2B', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153070226, end_position_on_the_genomic_accession=153071611, orientation='minus', exon_count=2, OMIM=[182268], no_hdr0=''),
    6703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6703, CurrentID=0, Status='live', Symbol='SPRR2D', Aliases=[], description='small proline rich protein 2D', other_designations='small proline-rich protein 2D|SPR-2D|SPR-II|small proline-rich protein II', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153039732, end_position_on_the_genomic_accession=153041120, orientation='minus', exon_count=2, OMIM=[617587], no_hdr0=''),
    6704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6704, CurrentID=0, Status='live', Symbol='SPRR2E', Aliases=[], description='small proline rich protein 2E', other_designations='small proline-rich protein 2E|SPR-2E|SPR-II|small proline-rich protein II', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153093135, end_position_on_the_genomic_accession=153094526, orientation='minus', exon_count=2, OMIM=[617588], no_hdr0=''),
    6705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6705, CurrentID=0, Status='live', Symbol='SPRR2F', Aliases=[], description='small proline rich protein 2F', other_designations='small proline-rich protein 2F|SPR-2F', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153112121, end_position_on_the_genomic_accession=153119468, orientation='minus', exon_count=3, OMIM=[617589], no_hdr0=''),
    6706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6706, CurrentID=0, Status='live', Symbol='SPRR2G', Aliases=[], description='small proline rich protein 2G', other_designations='small proline-rich protein 2G|SPR-2G', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153149582, end_position_on_the_genomic_accession=153195377, orientation='minus', exon_count=6, OMIM=[617590], no_hdr0=''),
    6707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6707, CurrentID=0, Status='live', Symbol='SPRR3', Aliases=[], description='small proline rich protein 3', other_designations='small proline-rich protein 3|22 kDa pancornulin|cornifin beta|esophagin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153001749, end_position_on_the_genomic_accession=153003856, orientation='plus', exon_count=3, OMIM=[182271], no_hdr0=''),
    6708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6708, CurrentID=0, Status='live', Symbol='SPTA1', Aliases=['EL2', 'HPP', 'HS3', 'SPH3', 'SPTA'], description='spectrin alpha, erythrocytic 1', other_designations='spectrin alpha chain, erythrocytic 1|alpha-I spectrin|elliptocytosis 2|erythroid alpha-spectrin|spectrin alpha chain, erythrocyte', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158610498, end_position_on_the_genomic_accession=158686715, orientation='minus', exon_count=53, OMIM=[182860], no_hdr0=''),
    6709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6709, CurrentID=0, Status='live', Symbol='SPTAN1', Aliases=['DEE5', 'EIEE5', 'NEAS', 'SPTA2'], description='spectrin alpha, non-erythrocytic 1', other_designations='spectrin alpha chain, non-erythrocytic 1|alpha-II spectrin|alpha-fodrin|epididymis secretory sperm binding protein|fodrin alpha chain|spectrin, non-erythroid alpha chain|spectrin, non-erythroid alpha subunit', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128552564, end_position_on_the_genomic_accession=128633662, orientation='plus', exon_count=60, OMIM=[182810], no_hdr0=''),
    6710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6710, CurrentID=0, Status='live', Symbol='SPTB', Aliases=['EL3', 'HS2', 'HSPTB1', 'SPH2'], description='spectrin beta, erythrocytic', other_designations='spectrin beta chain, erythrocytic|Sp beta|beta-I spectrin|membrane cytoskeletal protein|spectrin beta Tandil|spectrin beta chain, erythrocyte', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64744106, end_position_on_the_genomic_accession=64879907, orientation='minus', exon_count=38, OMIM=[182870], no_hdr0=''),
    6711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6711, CurrentID=0, Status='live', Symbol='SPTBN1', Aliases=['ELF', 'HEL102', 'SPTB2', 'betaSpII'], description='spectrin beta, non-erythrocytic 1', other_designations='spectrin beta chain, non-erythrocytic 1|beta-G spectrin|beta-II spectrin|beta-fodrin|beta-spectrin 2|beta-spectrin II|beta-spectrin non-erythrocytic 1|embryonic liver beta-fodrin|epididymis luminal protein 102|fodrin beta chain|spectrin beta chain, brain 1|spectrin, non-erythroid beta chain 1', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=54456327, end_position_on_the_genomic_accession=54671446, orientation='plus', exon_count=39, OMIM=[182790], no_hdr0=''),
    6712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6712, CurrentID=0, Status='live', Symbol='SPTBN2', Aliases=['GTRAP41', 'SCA5', 'SCAR14'], description='spectrin beta, non-erythrocytic 2', other_designations='spectrin beta chain, non-erythrocytic 2|beta-III spectrin|glutamate transporter EAAT4-associated protein 41|spectrin beta III sigma 2|spectrin beta chain, brain 2|spectrin, non-erythroid beta chain 2|spinocerebellar ataxia 5 protein', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66682496, end_position_on_the_genomic_accession=66729361, orientation='minus', exon_count=44, OMIM=[604985], no_hdr0=''),
    6713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6713, CurrentID=0, Status='live', Symbol='SQLE', Aliases=[], description='squalene epoxidase', other_designations='squalene monooxygenase|SE', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124998505, end_position_on_the_genomic_accession=125022283, orientation='plus', exon_count=12, OMIM=[602019], no_hdr0=''),
    6714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6714, CurrentID=0, Status='live', Symbol='SRC', Aliases=['ASV1', 'THC6', 'c-SRC', 'p60-Src', 'SRC'], description='SRC proto-oncogene, non-receptor tyrosine kinase', other_designations='proto-oncogene tyrosine-protein kinase Src|proto-oncogene c-Src|protooncogene SRC, Rous sarcoma|tyrosine kinase pp60c-src|tyrosine-protein kinase SRC-1|v-src avian sarcoma (Schmidt-Ruppin A-2) viral oncogene homolog', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37344690, end_position_on_the_genomic_accession=37406050, orientation='plus', exon_count=17, OMIM=[190090], no_hdr0=''),
    6715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6715, CurrentID=0, Status='live', Symbol='SRD5A1', Aliases=['S5AR 1'], description='steroid 5 alpha-reductase 1', other_designations='3-oxo-5-alpha-steroid 4-dehydrogenase 1|SR type 1|steroid 5-alpha-reductase type I|steroid-5-alpha-reductase, alpha polypeptide 1 (3-oxo-5 alpha-steroid delta 4-dehydrogenase alpha 1)', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=6633440, end_position_on_the_genomic_accession=6674386, orientation='plus', exon_count=7, OMIM=[184753], no_hdr0=''),
    6716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6716, CurrentID=0, Status='live', Symbol='SRD5A2', Aliases=[], description='steroid 5 alpha-reductase 2', other_designations='3-oxo-5-alpha-steroid 4-dehydrogenase 2|5 alpha-SR2|S5AR 2|SR type 2|steroid-5-alpha-reductase, alpha polypeptide 2 (3-oxo-5 alpha-steroid delta 4-dehydrogenase alpha 2)|type II 5-alpha reductase', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=31522480, end_position_on_the_genomic_accession=31665651, orientation='minus', exon_count=10, OMIM=[607306], no_hdr0=''),
    6717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6717, CurrentID=0, Status='live', Symbol='SRI', Aliases=['CP-22', 'CP22', 'SCN', 'V19'], description='sorcin', other_designations='sorcin|22 kDa protein|H_RG167B05.1|calcium binding protein amplified in mutlidrug-resistant cells', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=88205115, end_position_on_the_genomic_accession=88226976, orientation='minus', exon_count=9, OMIM=[182520], no_hdr0=''),
    6718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6718, CurrentID=0, Status='live', Symbol='AKR1D1', Aliases=['3o5bred', 'CBAS2', 'SRD5B1'], description='aldo-keto reductase family 1 member D1', other_designations='aldo-keto reductase family 1 member D1|delta(4)-3-ketosteroid 5-beta-reductase|delta(4)-3-oxosteroid 5-beta-reductase|steroid-5-beta-reductase, beta polypeptide 1 (3-oxo-5 beta-steroid delta 4-dehydrogenase beta 1)', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138076459, end_position_on_the_genomic_accession=138118305, orientation='plus', exon_count=9, OMIM=[604741], no_hdr0=''),
    6720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6720, CurrentID=0, Status='live', Symbol='SREBF1', Aliases=['HMD', 'IFAP2', 'SREBP1', 'bHLHd1'], description='sterol regulatory element binding transcription factor 1', other_designations='sterol regulatory element-binding protein 1|class D basic helix-loop-helix protein 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17811334, end_position_on_the_genomic_accession=17837017, orientation='minus', exon_count=23, OMIM=[184756], no_hdr0=''),
    6721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6721, CurrentID=0, Status='live', Symbol='SREBF2', Aliases=['SREBP-2', 'SREBP2', 'bHLHd2'], description='sterol regulatory element binding transcription factor 2', other_designations='sterol regulatory element-binding protein 2|class D basic helix-loop-helix protein 2', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41833105, end_position_on_the_genomic_accession=41907308, orientation='plus', exon_count=24, OMIM=[600481], no_hdr0=''),
    6722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6722, CurrentID=0, Status='live', Symbol='SRF', Aliases=['MCM1'], description='serum response factor', other_designations='serum response factor|c-fos serum response element-binding transcription factor|minichromosome maintenance 1 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43171269, end_position_on_the_genomic_accession=43181506, orientation='plus', exon_count=8, OMIM=[600589], no_hdr0=''),
    6723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6723, CurrentID=0, Status='live', Symbol='SRM', Aliases=['PAPT', 'SPDSY', 'SPS1L1', 'SRM'], description='spermidine synthase', other_designations='spermidine synthase|putrescine aminopropyltransferase|spermidine synthase-1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11054589, end_position_on_the_genomic_accession=11060053, orientation='minus', exon_count=8, OMIM=[182891], no_hdr0=''),
    6725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6725, CurrentID=0, Status='live', Symbol='SRMS', Aliases=['C20orf148', 'PTK70', 'SRM', 'dJ697K14.1'], description='src-related kinase lacking C-terminal regulatory tyrosine and N-terminal myristylation sites', other_designations='tyrosine-protein kinase Srms', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63538489, end_position_on_the_genomic_accession=63547749, orientation='minus', exon_count=8, OMIM=[617797], no_hdr0=''),
    6726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6726, CurrentID=0, Status='live', Symbol='SRP9', Aliases=['ALURBP'], description='signal recognition particle 9', other_designations='signal recognition particle 9 kDa protein|signal recognition particle 9kD|signal recognition particle 9kDa', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225777826, end_position_on_the_genomic_accession=225790464, orientation='plus', exon_count=4, OMIM=[600707], no_hdr0=''),
    6727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6727, CurrentID=0, Status='live', Symbol='SRP14', Aliases=['ALURBP'], description='signal recognition particle 14', other_designations='signal recognition particle 14 kDa protein|18 kDa Alu RNA-binding protein|homologous Alu RNA binding protein', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40035690, end_position_on_the_genomic_accession=40039202, orientation='minus', exon_count=6, OMIM=[600708], no_hdr0=''),
    6728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6728, CurrentID=0, Status='live', Symbol='SRP19', Aliases=[], description='signal recognition particle 19', other_designations='signal recognition particle 19 kDa protein|signal recognition particle 19kD|signal recognition particle 19kDa', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=112861287, end_position_on_the_genomic_accession=112898371, orientation='plus', exon_count=6, OMIM=[182175], no_hdr0=''),
    6729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6729, CurrentID=0, Status='live', Symbol='SRP54', Aliases=['SCN8'], description='signal recognition particle 54', other_designations='signal recognition particle 54 kDa protein|signal recognition particle 54kD|signal recognition particle 54kDa', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34982981, end_position_on_the_genomic_accession=35029567, orientation='plus', exon_count=17, OMIM=[604857], no_hdr0=''),
    6730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6730, CurrentID=0, Status='live', Symbol='SRP68', Aliases=[], description='signal recognition particle 68', other_designations='signal recognition particle subunit SRP68|signal recognition particle 68 kDa protein|signal recognition particle 68kD|signal recognition particle 68kDa', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76038785, end_position_on_the_genomic_accession=76072517, orientation='minus', exon_count=17, OMIM=[604858], no_hdr0=''),
    6731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6731, CurrentID=0, Status='live', Symbol='SRP72', Aliases=['BMFF', 'BMFS1', 'HEL103'], description='signal recognition particle 72', other_designations='signal recognition particle subunit SRP72|epididymis luminal protein 103|signal recognition particle 72 kDa protein|signal recognition particle 72kD|signal recognition particle 72kDa', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56467617, end_position_on_the_genomic_accession=56503681, orientation='plus', exon_count=20, OMIM=[602122], no_hdr0=''),
    6732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6732, CurrentID=0, Status='live', Symbol='SRPK1', Aliases=['SFRSK1'], description='SRSF protein kinase 1', other_designations='SRSF protein kinase 1|SFRS protein kinase 1|SR-protein-specific kinase 1|serine/arginine-rich splicing factor kinase 1|serine/threonine-protein kinase SRPK1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35832966, end_position_on_the_genomic_accession=35921098, orientation='minus', exon_count=16, OMIM=[601939], no_hdr0=''),
    6733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6733, CurrentID=0, Status='live', Symbol='SRPK2', Aliases=['SFRSK2'], description='SRSF protein kinase 2', other_designations='SRSF protein kinase 2|SFRS protein kinase 2|SR protein kinase 2|SR-protein-specific kinase 2|serine kinase SRPK2|serine/arginine-rich protein-specific kinase 2|serine/arginine-rich splicing factor kinase 2|serine/threonine-protein kinase SRPK2', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105110708, end_position_on_the_genomic_accession=105399363, orientation='minus', exon_count=25, OMIM=[602980], no_hdr0=''),
    6734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6734, CurrentID=0, Status='live', Symbol='SRPRA', Aliases=['DP', 'SRPR', 'Sralpha'], description='SRP receptor subunit alpha', other_designations='signal recognition particle receptor subunit alpha|DP-alpha|SR-alpha|SRP receptor alpha subunit|SRP-alpha|docking protein alpha|signal recognition particle receptor (docking protein)', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126255151, end_position_on_the_genomic_accession=126268925, orientation='minus', exon_count=15, OMIM=[182180], no_hdr0=''),
    6736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6736, CurrentID=0, Status='live', Symbol='SRY', Aliases=['SRXX1', 'SRXY1', 'TDF', 'TDY'], description='sex determining region Y', other_designations='sex-determining region Y protein|essential protein for sex determination in human males|sex-determining region on Y|testis-determining factor on Y|truncated sex-determining region Y protein', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=2786855, end_position_on_the_genomic_accession=2787682, orientation='minus', exon_count=1, OMIM=[480000], no_hdr0=''),
    6737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6737, CurrentID=0, Status='live', Symbol='TRIM21', Aliases=['RNF81', 'RO52', 'Ro/SSA', 'SSA', 'SSA1'], description='tripartite motif containing 21', other_designations='E3 ubiquitin-protein ligase TRIM21|52 kDa Ro protein|52 kDa ribonucleoprotein autoantigen Ro/SS-A|RING finger protein 81|RING-type E3 ubiquitin transferase TRIM21|Ro/SSA 52kDa|SS-A|Sicca syndrome antigen A|Sjogren syndrome antigen A1 (52kDa, ribonucleoprotein autoantigen SS-A/Ro)|ro(SS-A)|sjoegren syndrome type A antigen|tripartite motif-containing protein 21', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4384897, end_position_on_the_genomic_accession=4393702, orientation='minus', exon_count=7, OMIM=[109092], no_hdr0=''),
    6738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6738, CurrentID=0, Status='live', Symbol='RO60', Aliases=['RORNP', 'SSA2', 'TROVE2'], description='Ro60, Y RNA binding protein', other_designations='60 kDa SS-A/Ro ribonucleoprotein|60 kDa ribonucleoprotein Ro|Ro/SSA 60kDa|Sjogren syndrome antigen A2 (60kD, ribonucleoprotein autoantigen SS-A/Ro)|TROVE domain family member 2|gastric cancer multi-drug resistance protein|ro60 autoantigen|sjoegren syndrome type A antigen', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=193059454, end_position_on_the_genomic_accession=193091777, orientation='plus', exon_count=12, OMIM=[600063], no_hdr0=''),
    6741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6741, CurrentID=0, Status='live', Symbol='SSB', Aliases=['LARP3', 'La', 'La/SSB'], description='small RNA binding exonuclease protection factor La', other_designations='lupus La protein|La ribonucleoprotein domain family, member 3|SS-B|SS-B/La protein|Sjogren syndrome antigen B|autoantigen La|la autoantigen|lupus La antigen|sjoegren syndrome type B antigen', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169798871, end_position_on_the_genomic_accession=169812064, orientation='plus', exon_count=13, OMIM=[109090], no_hdr0=''),
    6742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6742, CurrentID=0, Status='live', Symbol='SSBP1', Aliases=['Mt-SSB', 'OPA13', 'SOSS-B1', 'SSBP', 'mtSSB'], description='single stranded DNA binding protein 1', other_designations='single-stranded DNA-binding protein, mitochondrial|PWP1-interacting protein 17|single-stranded DNA binding protein 1, mitochondrial', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141738321, end_position_on_the_genomic_accession=141750488, orientation='plus', exon_count=9, OMIM=[600439], no_hdr0=''),
    6744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6744, CurrentID=0, Status='live', Symbol='ITPRID2', Aliases=['CS-1', 'CS1', 'KRAP', 'SPAG13', 'SSFA2'], description='ITPR interacting domain containing 2', other_designations='protein ITPRID2|ITPR-interacting domain-containing protein 2|KRAS-induced actin-interacting protein|cleavage signal-1 protein|ki-ras-induced actin-interacting protein|sperm associated antigen 13|sperm specific antigen 2', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=181891730, end_position_on_the_genomic_accession=181930738, orientation='plus', exon_count=21, OMIM=[118990], no_hdr0=''),
    6745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6745, CurrentID=0, Status='live', Symbol='SSR1', Aliases=['TRAPA'], description='signal sequence receptor subunit 1', other_designations='translocon-associated protein subunit alpha|SSR alpha subunit|SSR-alpha|TRAP alpha|signal sequence receptor subunit alpha|signal sequence receptor, alpha|translocon-associated protein alpha subunit', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7281143, end_position_on_the_genomic_accession=7313199, orientation='minus', exon_count=8, OMIM=[600868], no_hdr0=''),
    6746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6746, CurrentID=0, Status='live', Symbol='SSR2', Aliases=['HSD25', 'TLAP', 'TRAP-BETA', 'TRAPB'], description='signal sequence receptor subunit 2', other_designations='translocon-associated protein subunit beta|SSR-beta|signal sequence receptor subunit beta|signal sequence receptor, beta (translocon-associated protein beta)|translocon-associated protein beta', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156009048, end_position_on_the_genomic_accession=156020951, orientation='minus', exon_count=6, OMIM=[600867], no_hdr0=''),
    6747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6747, CurrentID=0, Status='live', Symbol='SSR3', Aliases=['TRAPG'], description='signal sequence receptor subunit 3', other_designations='translocon-associated protein subunit gamma|SSR gamma|TRAP-complex gamma subunit|TRAP-gamma|signal sequence receptor subunit gamma|signal sequence receptor, gamma (translocon-associated protein gamma)|translocon-associated protein gamma subunit', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=156539553, end_position_on_the_genomic_accession=156555117, orientation='minus', exon_count=7, OMIM=[606213], no_hdr0=''),
    6748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6748, CurrentID=0, Status='live', Symbol='SSR4', Aliases=['CDG1Y', 'TRAPD'], description='signal sequence receptor subunit 4', other_designations='translocon-associated protein subunit delta|SSR-delta|TRAP-delta|signal sequence receptor, delta', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153794159, end_position_on_the_genomic_accession=153798512, orientation='plus', exon_count=9, OMIM=[300090], no_hdr0=''),
    6749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6749, CurrentID=0, Status='live', Symbol='SSRP1', Aliases=['FACT', 'FACT80', 'T160'], description='structure specific recognition protein 1', other_designations='FACT complex subunit SSRP1|FACT 80 kDa subunit|FACTp80|chromatin-specific transcription elongation factor 80 kDa subunit|cisplatin-DNA SSRP|facilitates chromatin remodeling 80 kDa subunit|facilitates chromatin transcription complex 80 kDa subunit|facilitates chromatin transcription complex subunit SSRP1|hSSRP1|high mobility group box|recombination signal sequence recognition protein 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57325986, end_position_on_the_genomic_accession=57335892, orientation='minus', exon_count=17, OMIM=[604328], no_hdr0=''),
    6750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6750, CurrentID=0, Status='live', Symbol='SST', Aliases=['SMST1', 'SST'], description='somatostatin', other_designations='somatostatin|growth hormone release-inhibiting factor|prepro-somatostatin|somatostatin-14|somatostatin-28', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187668912, end_position_on_the_genomic_accession=187670394, orientation='minus', exon_count=2, OMIM=[182450], no_hdr0=''),
    6751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6751, CurrentID=0, Status='live', Symbol='SSTR1', Aliases=['SRIF-2', 'SS-1-R', 'SS1-R', 'SS1R'], description='somatostatin receptor 1', other_designations='somatostatin receptor type 1', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=38207904, end_position_on_the_genomic_accession=38213067, orientation='plus', exon_count=3, OMIM=[182451], no_hdr0=''),
    6752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6752, CurrentID=0, Status='live', Symbol='SSTR2', Aliases=[], description='somatostatin receptor 2', other_designations='somatostatin receptor type 2|SRIF-1|SS2R', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73165010, end_position_on_the_genomic_accession=73176633, orientation='plus', exon_count=2, OMIM=[182452], no_hdr0=''),
    6753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6753, CurrentID=0, Status='live', Symbol='SSTR3', Aliases=['SS-3-R', 'SS3-R', 'SS3R', 'SSR-28'], description='somatostatin receptor 3', other_designations='somatostatin receptor type 3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37204237, end_position_on_the_genomic_accession=37220451, orientation='minus', exon_count=8, OMIM=[182453], no_hdr0=''),
    6754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6754, CurrentID=0, Status='live', Symbol='SSTR4', Aliases=['SS-4-R', 'SS4-R', 'SS4R'], description='somatostatin receptor 4', other_designations='somatostatin receptor type 4|G-protein coupled receptor', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23035312, end_position_on_the_genomic_accession=23039237, orientation='plus', exon_count=1, OMIM=[182454], no_hdr0=''),
    6755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6755, CurrentID=0, Status='live', Symbol='SSTR5', Aliases=['SS-5-R'], description='somatostatin receptor 5', other_designations='somatostatin receptor type 5|somatostatin receptor subtype 5', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1072747, end_position_on_the_genomic_accession=1081454, orientation='plus', exon_count=2, OMIM=[182455], no_hdr0=''),
    6756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6756, CurrentID=0, Status='live', Symbol='SSX1', Aliases=['CT5.1', 'SSRC'], description='SSX family member 1', other_designations='protein SSX1|cancer/testis antigen 5.1|cancer/testis antigen family 5, member 1|sarcoma, synovial, X-chromosome-related 1|synovial sarcoma, X breakpoint 1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48255392, end_position_on_the_genomic_accession=48267444, orientation='plus', exon_count=9, OMIM=[312820], no_hdr0=''),
    6757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6757, CurrentID=0, Status='live', Symbol='SSX2', Aliases=['CT5.2', 'CT5.2A', 'HD21', 'HOM-MEL-40', 'SSX'], description='SSX family member 2', other_designations='protein SSX2|cancer/testis antigen 5.2|cancer/testis antigen family 5, member 2a|sarcoma, synovial, X-chromosome-related 2|synovial sarcoma, X breakpoint 2|synovial sarcoma, X breakpoint 2B|tumor antigen HOM-MEL-40', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52696896, end_position_on_the_genomic_accession=52707227, orientation='minus', exon_count=9, OMIM=[300192], no_hdr0=''),
    6758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6758, CurrentID=0, Status='live', Symbol='SSX5', Aliases=[], description='SSX family member 5', other_designations='protein SSX5|synovial sarcoma, X breakpoint 5', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48177982, end_position_on_the_genomic_accession=48196798, orientation='minus', exon_count=11, OMIM=[300327], no_hdr0=''),
    6759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6759, CurrentID=0, Status='live', Symbol='SSX4', Aliases=['CT5.4'], description='SSX family member 4', other_designations='protein SSX4|cancer/testis antigen 5.4|synovial sarcoma, X breakpoint 4', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48383539, end_position_on_the_genomic_accession=48393347, orientation='plus', exon_count=9, OMIM=[300326], no_hdr0=''),
    6760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6760, CurrentID=0, Status='live', Symbol='SS18', Aliases=['SSXT', 'SYT'], description='SS18 subunit of BAF chromatin remodeling complex', other_designations='protein SSXT|SS18, nBAF chromatin remodeling complex subunit|synovial sarcoma translocated to X chromosome protein|synovial sarcoma translocation, chromosome 18|synovial sarcoma, translocated to X chromosome', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26016253, end_position_on_the_genomic_accession=26091219, orientation='minus', exon_count=17, OMIM=[600192], no_hdr0=''),
    6764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6764, CurrentID=0, Status='live', Symbol='DENND2B', Aliases=['HTS1', 'ST5', 'p126'], description='DENN domain containing 2B', other_designations='DENN domain-containing protein 2B|DENN/MADD domain containing 2B|heLa tumor suppression 1|suppression of tumorigenicity 5 protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8693352, end_position_on_the_genomic_accession=8910951, orientation='minus', exon_count=40, OMIM=[140750], no_hdr0=''),
    6767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6767, CurrentID=0, Status='live', Symbol='ST13', Aliases=['AAG2', 'FAM10A1', 'FAM10A4', 'HIP', 'HOP', 'HSPABP', 'HSPABP1', 'P48', 'PRO0786', 'SNC6'], description='ST13 Hsp70 interacting protein', other_designations='hsc70-interacting protein|Hsp70-interacting protein|aging-associated protein 2|heat shock 70kD protein binding protein|progesterone receptor-associated p48 protein|putative tumor suppressor ST13|renal carcinoma antigen NY-REN-33|suppression of tumorigenicity 13 (colon carcinoma) (Hsp70 interacting protein)|suppression of tumorigenicity 13 protein|testis secretory sperm-binding protein Li 233m', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40824535, end_position_on_the_genomic_accession=40856639, orientation='minus', exon_count=12, OMIM=[606796], no_hdr0=''),
    6768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6768, CurrentID=0, Status='live', Symbol='ST14', Aliases=['ARCI11', 'CAP3', 'HAI', 'MT-SP1', 'MTSP1', 'PRSS14', 'SNC19', 'TADG15', 'TMPRSS14'], description='ST14 transmembrane serine protease matriptase', other_designations='suppressor of tumorigenicity 14 protein|channel-activating protein 3|membrane-type serine protease 1|prostamin|serine protease 14|serine protease TADG-15|suppression of tumorigenicity 14 (colon carcinoma)|suppression of tumorigenicity 14 (colon carcinoma, matriptase, epithin)|tumor associated differentially expressed gene 15 protein', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130159782, end_position_on_the_genomic_accession=130210362, orientation='plus', exon_count=19, OMIM=[606797], no_hdr0=''),
    6769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6769, CurrentID=0, Status='live', Symbol='STAC', Aliases=['STAC1'], description='SH3 and cysteine rich domain', other_designations='SH3 and cysteine-rich domain-containing protein|SRC homology 3 and cysteine-rich domain-containing protein', map_location='3p22.3-p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=36380343, end_position_on_the_genomic_accession=36548007, orientation='plus', exon_count=14, OMIM=[602317], no_hdr0=''),
    6770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6770, CurrentID=0, Status='live', Symbol='STAR', Aliases=['STARD1'], description='steroidogenic acute regulatory protein', other_designations='steroidogenic acute regulatory protein, mitochondrial|START domain containing 1|START domain-containing protein 1|StAR related lipid transfer (START) domain containing 1|cholesterol trafficker|mitochondrial steroid acute regulatory protein|steroid acute regulatory protein|steroidogenic acute regulator|testis secretory sperm-binding protein Li 241mP', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38142700, end_position_on_the_genomic_accession=38150952, orientation='minus', exon_count=7, OMIM=[600617], no_hdr0=''),
    6772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6772, CurrentID=0, Status='live', Symbol='STAT1', Aliases=['CANDF7', 'IMD31A', 'IMD31B', 'IMD31C', 'ISGF-3', 'STAT91'], description='signal transducer and activator of transcription 1', other_designations='signal transducer and activator of transcription 1-alpha/beta|signal transducer and activator of transcription 1, 91kD|signal transducer and activator of transcription 1, 91kDa|transcription factor ISGF-3 components p91/p84', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190968989, end_position_on_the_genomic_accession=191014197, orientation='minus', exon_count=26, OMIM=[600555], no_hdr0=''),
    6773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6773, CurrentID=0, Status='live', Symbol='STAT2', Aliases=['IMD44', 'ISGF-3', 'P113', 'PTORCH3', 'STAT113'], description='signal transducer and activator of transcription 2', other_designations='signal transducer and activator of transcription 2|interferon alpha induced transcriptional activator|signal transducer and activator of transcription 2, 113kDa', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56341597, end_position_on_the_genomic_accession=56360161, orientation='minus', exon_count=25, OMIM=[600556], no_hdr0=''),
    6774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6774, CurrentID=0, Status='live', Symbol='STAT3', Aliases=['ADMIO', 'ADMIO1', 'APRF', 'HIES'], description='signal transducer and activator of transcription 3', other_designations='signal transducer and activator of transcription 3|DNA-binding protein APRF|acute-phase response factor', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42313324, end_position_on_the_genomic_accession=42388502, orientation='minus', exon_count=24, OMIM=[102582], no_hdr0=''),
    6775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6775, CurrentID=0, Status='live', Symbol='STAT4', Aliases=['SLEB11'], description='signal transducer and activator of transcription 4', other_designations='signal transducer and activator of transcription 4|signal transducer and activator of transcription 4 variant 3', map_location='2q32.2-q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=191029576, end_position_on_the_genomic_accession=191172684, orientation='minus', exon_count=30, OMIM=[600558], no_hdr0=''),
    6776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6776, CurrentID=0, Status='live', Symbol='STAT5A', Aliases=['MGF', 'STAT5'], description='signal transducer and activator of transcription 5A', other_designations='signal transducer and activator of transcription 5A|epididymis secretory sperm binding protein', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42287547, end_position_on_the_genomic_accession=42311943, orientation='plus', exon_count=20, OMIM=[601511], no_hdr0=''),
    6777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6777, CurrentID=0, Status='live', Symbol='STAT5B', Aliases=['GHISID2', 'STAT5'], description='signal transducer and activator of transcription 5B', other_designations='signal transducer and activator of transcription 5B|transcription factor STAT5B', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42199177, end_position_on_the_genomic_accession=42288437, orientation='minus', exon_count=22, OMIM=[604260], no_hdr0=''),
    6778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6778, CurrentID=0, Status='live', Symbol='STAT6', Aliases=['D12S1644', 'IL-4-STATB', 'STAT6C', 'STAT6'], description='signal transducer and activator of transcription 6', other_designations='signal transducer and activator of transcription 6|STAT, interleukin4-induced|signal transducer and activator of transcription 6, interleukin-4 induced|transcription factor IL-4 STAT', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57095408, end_position_on_the_genomic_accession=57111413, orientation='minus', exon_count=24, OMIM=[601512], no_hdr0=''),
    6779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6779, CurrentID=0, Status='live', Symbol='STATH', Aliases=['STR'], description='statherin', other_designations='statherin', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69995966, end_position_on_the_genomic_accession=70002570, orientation='plus', exon_count=6, OMIM=[184470], no_hdr0=''),
    6780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6780, CurrentID=0, Status='live', Symbol='STAU1', Aliases=['PPP1R150', 'STAU'], description='staufen double-stranded RNA binding protein 1', other_designations='double-stranded RNA-binding protein Staufen homolog 1|protein phosphatase 1, regulatory subunit 150|staufen, RNA binding protein, homolog 1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49113339, end_position_on_the_genomic_accession=49219295, orientation='minus', exon_count=19, OMIM=[601716], no_hdr0=''),
    6781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6781, CurrentID=0, Status='live', Symbol='STC1', Aliases=['STC'], description='stanniocalcin 1', other_designations='stanniocalcin-1', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23841929, end_position_on_the_genomic_accession=23854806, orientation='minus', exon_count=4, OMIM=[601185], no_hdr0=''),
    6782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6782, CurrentID=0, Status='live', Symbol='HSPA13', Aliases=['STCH'], description='heat shock protein family A (Hsp70) member 13', other_designations='heat shock 70 kDa protein 13|heat shock protein 70kDa family, member 13|microsomal stress 70 protein ATPase core|stress 70 protein chaperone, microsome-associated, 60kD|stress 70 protein chaperone, microsome-associated, 60kDa|stress-70 protein chaperone microsome-associated 60 kDa protein|testis secretory sperm-binding protein Li 199a', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14371115, end_position_on_the_genomic_accession=14383146, orientation='minus', exon_count=5, OMIM=[601100], no_hdr0=''),
    6783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6783, CurrentID=0, Status='live', Symbol='SULT1E1', Aliases=['EST', 'EST-1', 'ST1E1', 'STE'], description='sulfotransferase family 1E member 1', other_designations='sulfotransferase 1E1|estrogen sulfotransferase|estrone sulfotransferase|sulfotransferase family 1E, estrogen-preferring, member 1|sulfotransferase, estrogen-preferring', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69841212, end_position_on_the_genomic_accession=69860151, orientation='minus', exon_count=9, OMIM=[600043], no_hdr0=''),
    6785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6785, CurrentID=0, Status='live', Symbol='ELOVL4', Aliases=['ADMD', 'CT118', 'ISQMR', 'SCA34', 'STGD2', 'STGD3'], description='ELOVL fatty acid elongase 4', other_designations='elongation of very long chain fatty acids protein 4|3-keto acyl-CoA synthase ELOVL4|ELOVL FA elongase 4|cancer/testis antigen 118|elongation of very long chain fatty acids (FEN1/Elo2, SUR4/Elo3, yeast)-like 4|very long chain 3-ketoacyl-CoA synthase 4|very long chain 3-oxoacyl-CoA synthase 4', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=79914814, end_position_on_the_genomic_accession=79947553, orientation='minus', exon_count=6, OMIM=[605512], no_hdr0=''),
    6786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6786, CurrentID=0, Status='live', Symbol='STIM1', Aliases=['D11S4896E', 'GOK', 'IMD10', 'STRMK', 'TAM', 'TAM1'], description='stromal interaction molecule 1', other_designations='stromal interaction molecule 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3854604, end_position_on_the_genomic_accession=4093210, orientation='plus', exon_count=17, OMIM=[605921], no_hdr0=''),
    6787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6787, CurrentID=0, Status='live', Symbol='NEK4', Aliases=['NRK2', 'STK2', 'pp12301'], description='NIMA related kinase 4', other_designations='serine/threonine-protein kinase Nek4|NIMA (never in mitosis gene a)-related kinase 4|never in mitosis A-related kinase 4|nimA-related protein kinase 4|serine/threonine kinase 2|serine/threonine protein kinase-2|serine/threonine-protein kinase NRK2|serine/threonine-protein kinase Nek4 variant 2', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52708444, end_position_on_the_genomic_accession=52770946, orientation='minus', exon_count=19, OMIM=[601959], no_hdr0=''),
    6788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6788, CurrentID=0, Status='live', Symbol='STK3', Aliases=['KRS1', 'MST2'], description='serine/threonine kinase 3', other_designations='serine/threonine-protein kinase 3|KB-1458E12.1|MST-2|STE20-like kinase MST2|epididymis secretory sperm binding protein|hippo homolog|mammalian STE20-like protein kinase 2|serine/threonine kinase 3 (STE20 homolog, yeast)|serine/threonine kinase 3 (Ste20, yeast homolog)|serine/threonine-protein kinase Krs-1', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98433048, end_position_on_the_genomic_accession=98944329, orientation='minus', exon_count=27, OMIM=[605030], no_hdr0=''),
    6789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6789, CurrentID=0, Status='live', Symbol='STK4', Aliases=['KRS2', 'MST1', 'YSK3'], description='serine/threonine kinase 4', other_designations='serine/threonine-protein kinase 4|STE20-like kinase MST1|hippo homolog|kinase responsive to stress 2|mammalian STE20-like protein kinase 1|mammalian sterile 20-like 1|serine/threonine-protein kinase Krs-2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44966470, end_position_on_the_genomic_accession=45080021, orientation='plus', exon_count=17, OMIM=[604965], no_hdr0=''),
    6790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6790, CurrentID=0, Status='live', Symbol='AURKA', Aliases=['AIK', 'ARK1', 'AURA', 'BTAK', 'PPP1R47', 'STK15', 'STK6', 'STK7'], description='aurora kinase A', other_designations='aurora kinase A|aurora 2|aurora/IPL1-like kinase|aurora/IPL1-related kinase 1|breast tumor-amplified kinase|protein phosphatase 1, regulatory subunit 47|serine/threonine protein kinase 15|serine/threonine-protein kinase 6|serine/threonine-protein kinase aurora-A', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56369390, end_position_on_the_genomic_accession=56392308, orientation='minus', exon_count=12, OMIM=[603072], no_hdr0=''),
    6792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6792, CurrentID=0, Status='live', Symbol='CDKL5', Aliases=['CFAP247', 'DEE2', 'EIEE2', 'ISSX', 'STK9'], description='cyclin dependent kinase like 5', other_designations='cyclin-dependent kinase-like 5|cyclin dependent kinase 5 transcript|serine/threonine kinase 9|serine/threonine-protein kinase 9', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18425608, end_position_on_the_genomic_accession=18653629, orientation='plus', exon_count=23, OMIM=[300203], no_hdr0=''),
    6793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6793, CurrentID=0, Status='live', Symbol='STK10', Aliases=['LOK', 'PRO2729'], description='serine/threonine kinase 10', other_designations='serine/threonine-protein kinase 10|lymphocyte-oriented kinase', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172042074, end_position_on_the_genomic_accession=172188224, orientation='minus', exon_count=21, OMIM=[603919], no_hdr0=''),
    6794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6794, CurrentID=0, Status='live', Symbol='STK11', Aliases=['LKB1', 'PJS', 'hLKB1'], description='serine/threonine kinase 11', other_designations='serine/threonine-protein kinase STK11|liver kinase B1|polarization-related protein LKB1|renal carcinoma antigen NY-REN-19|serine/threonine-protein kinase 11|serine/threonine-protein kinase LKB1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1205778, end_position_on_the_genomic_accession=1228431, orientation='plus', exon_count=10, OMIM=[602216], no_hdr0=''),
    6795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6795, CurrentID=0, Status='live', Symbol='AURKC', Aliases=['AIE2', 'AIK3', 'ARK3', 'AurC', 'HEL-S-90', 'SPGF5', 'STK13', 'aurora-C'], description='aurora kinase C', other_designations='aurora kinase C|ARK-3|aurora 3|aurora-related kinase 3|aurora/IPL1-related kinase 3|aurora/IPL1/EG2 protein 2|epididymis secretory protein Li 90|serine/threonine kinase 13 (aurora/IPL1-like)|serine/threonine-protein kinase 13|serine/threonine-protein kinase aurora-C', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57230317, end_position_on_the_genomic_accession=57235550, orientation='plus', exon_count=7, OMIM=[603495], no_hdr0=''),
    6799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6799, CurrentID=0, Status='live', Symbol='SULT1A2', Aliases=['HAST4', 'P-PST', 'P-PST 2', 'ST1A2', 'STP2', 'TSPST2'], description='sulfotransferase family 1A member 2', other_designations='sulfotransferase 1A2|aryl sulfotransferase 2|arylamine sulfotransferase|phenol sulfotransferase 2|phenol-preferring phenol sulfotransferase2|phenol-sulfating phenol sulfotransferase 2|phenolic-metabolizing (P) form of PST|sulfotransferase family, cytosolic, 1A, phenol-preferring, member 2|thermostable phenol sulfotransferase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28591943, end_position_on_the_genomic_accession=28597070, orientation='minus', exon_count=8, OMIM=[601292], no_hdr0=''),
    6801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6801, CurrentID=0, Status='live', Symbol='STRN', Aliases=['PPP2R6A', 'SG2NA1', 'STRN'], description='striatin', other_designations="striatin|protein phosphatase 2 regulatory subunit B'''alpha|striatin, calmodulin binding protein", map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=36837698, end_position_on_the_genomic_accession=36966607, orientation='minus', exon_count=19, OMIM=[614765], no_hdr0=''),
    6804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6804, CurrentID=0, Status='live', Symbol='STX1A', Aliases=['HPC-1', 'P35-1', 'STX1', 'SYN1A'], description='syntaxin 1A', other_designations='syntaxin-1A|neuron-specific antigen HPC-1|syntaxin 1A (brain)', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73699210, end_position_on_the_genomic_accession=73719673, orientation='minus', exon_count=10, OMIM=[186590], no_hdr0=''),
    6809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6809, CurrentID=0, Status='live', Symbol='STX3', Aliases=['STX3A'], description='syntaxin 3', other_designations='syntaxin-3|syntaxin 3A', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59755374, end_position_on_the_genomic_accession=59805879, orientation='plus', exon_count=14, OMIM=[600876], no_hdr0=''),
    6810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6810, CurrentID=0, Status='live', Symbol='STX4', Aliases=['STX4A', 'p35-2'], description='syntaxin 4', other_designations='syntaxin-4|renal carcinoma antigen NY-REN-31|syntaxin 4A (placental)', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31033095, end_position_on_the_genomic_accession=31040168, orientation='plus', exon_count=13, OMIM=[186591], no_hdr0=''),
    6811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6811, CurrentID=0, Status='live', Symbol='STX5', Aliases=['SED5A', 'STX5'], description='syntaxin 5', other_designations='syntaxin-5|syntaxin 5A', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62806860, end_position_on_the_genomic_accession=62832053, orientation='minus', exon_count=11, OMIM=[603189], no_hdr0=''),
    6812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6812, CurrentID=0, Status='live', Symbol='STXBP1', Aliases=['DEE4', 'MUNC18-1', 'N-Sec1', 'NSEC1', 'P67', 'RBSEC1', 'UNC18', 'unc-18A', 'unc18-1'], description='syntaxin binding protein 1', other_designations='syntaxin-binding protein 1|neuronal SEC1|protein unc-18 homolog 1|protein unc-18 homolog A', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127611912, end_position_on_the_genomic_accession=127696029, orientation='plus', exon_count=25, OMIM=[602926], no_hdr0=''),
    6813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6813, CurrentID=0, Status='live', Symbol='STXBP2', Aliases=['FHL5', 'Hunc18b', 'MUNC18-2', 'UNC18-2', 'UNC18B', 'pp10122'], description='syntaxin binding protein 2', other_designations='syntaxin-binding protein 2|protein unc-18 homolog B|unc-18B', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7637110, end_position_on_the_genomic_accession=7647873, orientation='plus', exon_count=21, OMIM=[601717], no_hdr0=''),
    6814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6814, CurrentID=0, Status='live', Symbol='STXBP3', Aliases=['MUNC18-3', 'MUNC18C', 'PSP', 'UNC-18C'], description='syntaxin binding protein 3', other_designations='syntaxin-binding protein 3|platelet Sec1 protein|protein unc-18 homolog 3|protein unc-18 homolog C|syntaxin 4 binding protein|unc18-3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108746674, end_position_on_the_genomic_accession=108809523, orientation='plus', exon_count=19, OMIM=[608339], no_hdr0=''),
    6815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6815, CurrentID=0, Status='live', Symbol='STYX', Aliases=[], description='serine/threonine/tyrosine interacting protein', other_designations='serine/threonine/tyrosine-interacting protein|inactive tyrosine-protein phosphatase STYX|phosphoserine/threonine/tyrosine interaction protein|protein tyrosine phosphatase-like protein', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52730159, end_position_on_the_genomic_accession=52774989, orientation='plus', exon_count=12, OMIM=[615814], no_hdr0=''),
    6817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6817, CurrentID=0, Status='live', Symbol='SULT1A1', Aliases=['HAST1/HAST2', 'P-PST', 'P-PST 1', 'PST', 'ST1A1', 'ST1A3', 'STP', 'STP1', 'TSPST1', 'ts-PST'], description='sulfotransferase family 1A member 1', other_designations='sulfotransferase 1A1|aryl sulfotransferase 1|phenol-sulfating phenol sulfotransferase 1|sulfotransferase family, cytosolic, 1A, phenol-preferring, member 1|thermostable phenol sulfotransferase1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28605258, end_position_on_the_genomic_accession=28623395, orientation='minus', exon_count=14, OMIM=[171150], no_hdr0=''),
    6818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6818, CurrentID=0, Status='live', Symbol='SULT1A3', Aliases=['HAST', 'HAST3', 'M-PST', 'ST1A3', 'ST1A3/ST1A4', 'ST1A4', 'ST1A5', 'STM', 'TL-PST'], description='sulfotransferase family 1A member 3', other_designations='sulfotransferase 1A3|Sulfotransferase 1A4|aryl sulfotransferase 1A3/1A4|catecholamine-sulfating phenol sulfotransferase|dopamine-specific sulfotransferase|monoamine-sulfating phenosulfotransferase|phenol sulfotransferase 1A5|placental estrogen sulfotransferase|sulfokinase|sulfotransferase family, cytosolic, 1A, phenol-preferring, member 3|thermolabile (monoamine, M form) phenol sulfotransferase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30199255, end_position_on_the_genomic_accession=30204310, orientation='plus', exon_count=8, OMIM=[600641], no_hdr0=''),
    6819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6819, CurrentID=0, Status='live', Symbol='SULT1C2', Aliases=['ST1C1', 'ST1C2', 'SULT1C1', 'humSULTC2'], description='sulfotransferase family 1C member 2', other_designations='sulfotransferase 1C2|SULT1C#1|sulfotransferase 1C1|sulfotransferase family, cytosolic, 1C, member 1|sulfotransferase family, cytosolic, 1C, member 2', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108288895, end_position_on_the_genomic_accession=108309915, orientation='plus', exon_count=9, OMIM=[602385], no_hdr0=''),
    6820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6820, CurrentID=0, Status='live', Symbol='SULT2B1', Aliases=['ARCI14', 'HSST2'], description='sulfotransferase family 2B member 1', other_designations='sulfotransferase 2B1|ST2B1|alcohol sulfotransferase|hydroxysteroid sulfotransferase 2|hydroxysteroid sulfotransferase SULT2B1a|sulfotransferase family, cytosolic, 2B, member 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48552172, end_position_on_the_genomic_accession=48599427, orientation='plus', exon_count=7, OMIM=[604125], no_hdr0=''),
    6821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6821, CurrentID=0, Status='live', Symbol='SUOX', Aliases=[], description='sulfite oxidase', other_designations='sulfite oxidase, mitochondrial', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55992547, end_position_on_the_genomic_accession=56005525, orientation='plus', exon_count=8, OMIM=[606887], no_hdr0=''),
    6822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6822, CurrentID=0, Status='live', Symbol='SULT2A1', Aliases=['DHEA-ST', 'DHEA-ST8', 'DHEAS', 'HST', 'ST2', 'ST2A1', 'ST2A3', 'STD', 'SULT2A3', 'hSTa'], description='sulfotransferase family 2A member 1', other_designations='sulfotransferase 2A1|alcohol/hydroxysteroid sulfotransferase|bile-salt sulfotranasferase 2A1|sulfotransferase family, cytosolic, 2A, dehydroepiandrosterone (DHEA)-preferring, member 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47870467, end_position_on_the_genomic_accession=47886315, orientation='minus', exon_count=6, OMIM=[125263], no_hdr0=''),
    6827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6827, CurrentID=0, Status='live', Symbol='SUPT4H1', Aliases=['SPT4', 'SPT4H', 'SUPT4H', 'Supt4a'], description='SPT4 homolog, DSIF elongation factor subunit', other_designations='transcription elongation factor SPT4|DRB sensitivity-inducing factor 14 kDa subunit|DSIF p14|small hSpt4 subunit|suppressor of Ty 4 homolog 1', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58345178, end_position_on_the_genomic_accession=58352201, orientation='minus', exon_count=5, OMIM=[603555], no_hdr0=''),
    6829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6829, CurrentID=0, Status='live', Symbol='SUPT5H', Aliases=['SPT5', 'SPT5H', 'Tat-CT1'], description='SPT5 homolog, DSIF elongation factor subunit', other_designations='transcription elongation factor SPT5|DRB sensitivity-inducing factor 160 kDa subunit|DRB sensitivity-inducing factor large subunit|DSIF large subunit|DSIF p160|Tat-cotransactivator 1 protein|hSPT5|suppressor of Ty 5 homolog', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39445582, end_position_on_the_genomic_accession=39476670, orientation='plus', exon_count=30, OMIM=[602102], no_hdr0=''),
    6830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6830, CurrentID=0, Status='live', Symbol='SUPT6H', Aliases=['SPT6', 'SPT6H', 'emb-5'], description='SPT6 homolog, histone chaperone and transcription elongation factor', other_designations='transcription elongation factor SPT6|histone chaperone suppressor of Ty6|suppressor of Ty 6 homolog|tat-CT2 protein|tat-cotransactivator 2 protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28662183, end_position_on_the_genomic_accession=28702679, orientation='plus', exon_count=41, OMIM=[601333], no_hdr0=''),
    6832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6832, CurrentID=0, Status='live', Symbol='SUPV3L1', Aliases=['SUV3'], description='Suv3 like RNA helicase', other_designations='ATP-dependent RNA helicase SUPV3L1, mitochondrial|SUV3-like helicase|SUV3-like protein 1|suppressor of var1, 3-like 1|suppressor of var1, 3-like 1(SUV3)', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69180234, end_position_on_the_genomic_accession=69209093, orientation='plus', exon_count=17, OMIM=[605122], no_hdr0=''),
    6833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6833, CurrentID=0, Status='live', Symbol='ABCC8', Aliases=['ABC36', 'HHF1', 'HI', 'HRINS', 'MRP8', 'PHHI', 'PNDM3', 'SUR', 'SUR1', 'SUR1delta2', 'TNDM2'], description='ATP binding cassette subfamily C member 8', other_designations='ATP-binding cassette sub-family C member 8|ATP-binding cassette transporter sub-family C member 8|ATP-binding cassette, sub-family C (CFTR/MRP), member 8|sulfonylurea receptor (hyperinsulinemia)|sulfonylurea receptor 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17392498, end_position_on_the_genomic_accession=17476849, orientation='minus', exon_count=38, OMIM=[600509], no_hdr0=''),
    6834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6834, CurrentID=0, Status='live', Symbol='SURF1', Aliases=['CMT4K', 'MC4DN1', 'SHY1'], description='SURF1 cytochrome c oxidase assembly factor', other_designations='surfeit locus protein 1|surfeit 1', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133351758, end_position_on_the_genomic_accession=133356487, orientation='minus', exon_count=9, OMIM=[185620], no_hdr0=''),
    6835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6835, CurrentID=0, Status='live', Symbol='SURF2', Aliases=['SURF-2'], description='surfeit 2', other_designations='surfeit locus protein 2', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133356550, end_position_on_the_genomic_accession=133361158, orientation='plus', exon_count=6, OMIM=[185630], no_hdr0=''),
    6836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6836, CurrentID=0, Status='live', Symbol='SURF4', Aliases=['ERV29'], description='surfeit 4', other_designations='surfeit locus protein 4|surface 4 integral membrane protein', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133361464, end_position_on_the_genomic_accession=133377949, orientation='minus', exon_count=11, OMIM=[185660], no_hdr0=''),
    6837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6837, CurrentID=0, Status='live', Symbol='MED22', Aliases=['MED24', 'SRB6', 'SURF5', 'surf-5'], description='mediator complex subunit 22', other_designations='mediator of RNA polymerase II transcription subunit 22|surfeit locus protein 5', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133338312, end_position_on_the_genomic_accession=133348131, orientation='minus', exon_count=5, OMIM=[185641], no_hdr0=''),
    6838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6838, CurrentID=0, Status='live', Symbol='SURF6', Aliases=['RRP14'], description='surfeit 6', other_designations='surfeit locus protein 6', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133328776, end_position_on_the_genomic_accession=133336188, orientation='minus', exon_count=5, OMIM=[185642], no_hdr0=''),
    6839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6839, CurrentID=0, Status='live', Symbol='SUV39H1', Aliases=['H3-K9-HMTase 1', 'KMT1A', 'MG44', 'SUV39H'], description='suppressor of variegation 3-9 homolog 1', other_designations='histone-lysine N-methyltransferase SUV39H1|Su(var)3-9 homolog 1|histone H3-K9 methyltransferase 1|histone-lysine N-methyltransferase, H3 lysine-9 specific 1|lysine N-methyltransferase 1A|position-effect variegation 3-9 homolog', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48695554, end_position_on_the_genomic_accession=48709016, orientation='plus', exon_count=7, OMIM=[300254], no_hdr0=''),
    6840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6840, CurrentID=0, Status='live', Symbol='SVIL', Aliases=['MFM10'], description='supervillin', other_designations='supervillin|archvillin|membrane-associated F-actin binding protein p205|p205/p250', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=29457338, end_position_on_the_genomic_accession=29736936, orientation='minus', exon_count=47, OMIM=[604126], no_hdr0=''),
    6843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6843, CurrentID=0, Status='live', Symbol='VAMP1', Aliases=['CMS25', 'SPAX1', 'SYB1', 'VAMP-1'], description='vesicle associated membrane protein 1', other_designations='vesicle-associated membrane protein 1|vesicle-associated membrane protein 1 (synaptobrevin 1)', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6462237, end_position_on_the_genomic_accession=6470677, orientation='minus', exon_count=5, OMIM=[185880], no_hdr0=''),
    6844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6844, CurrentID=0, Status='live', Symbol='VAMP2', Aliases=['NEDHAHM', 'SYB2', 'VAMP-2'], description='vesicle associated membrane protein 2', other_designations='vesicle-associated membrane protein 2|synaptobrevin 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8159147, end_position_on_the_genomic_accession=8162948, orientation='minus', exon_count=6, OMIM=[185881], no_hdr0=''),
    6845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6845, CurrentID=0, Status='live', Symbol='VAMP7', Aliases=['SYBL1', 'TI-VAMP', 'TIVAMP', 'VAMP-7'], description='vesicle associated membrane protein 7', other_designations='vesicle-associated membrane protein 7|synaptobrevin-like 1|synaptobrevin-like protein 1|tetanus neurotoxin-insensitive VAMP|tetanus-insensitive VAMP', map_location='Xq28 and Yq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155881318, end_position_on_the_genomic_accession=155943769, orientation='plus', exon_count=8, OMIM=[300053], no_hdr0=''),
    6846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6846, CurrentID=0, Status='live', Symbol='XCL2', Aliases=['SCM-1b', 'SCM1B', 'SCYC2'], description='X-C motif chemokine ligand 2', other_designations='cytokine SCM-1 beta|XC chemokine ligand 2|c motif chemokine 2|chemokine (C motif) ligand 2|small inducible cytokine subfamily C, member 2', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168540768, end_position_on_the_genomic_accession=168543997, orientation='minus', exon_count=3, OMIM=[604828], no_hdr0=''),
    6847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6847, CurrentID=0, Status='live', Symbol='SYCP1', Aliases=['CT8', 'HOM-TES-14', 'SCP-1', 'SCP1'], description='synaptonemal complex protein 1', other_designations='synaptonemal complex protein 1|cancer/testis antigen 8|testicular tissue protein Li 191', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114854268, end_position_on_the_genomic_accession=114995370, orientation='plus', exon_count=38, OMIM=[602162], no_hdr0=''),
    6850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6850, CurrentID=0, Status='live', Symbol='SYK', Aliases=['IMD82', 'p72-Syk'], description='spleen associated tyrosine kinase', other_designations='tyrosine-protein kinase SYK|spleen tyrosine kinase', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=90801600, end_position_on_the_genomic_accession=90898549, orientation='plus', exon_count=16, OMIM=[600085], no_hdr0=''),
    6853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6853, CurrentID=0, Status='live', Symbol='SYN1', Aliases=['EPILX', 'MRX50a', 'SYN1b', 'SYNI', 'SYN1'], description='synapsin I', other_designations='synapsin-1|brain protein 4.1|synapsin Ib', map_location='Xp11.3-p11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47571901, end_position_on_the_genomic_accession=47619857, orientation='minus', exon_count=13, OMIM=[313440], no_hdr0=''),
    6854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6854, CurrentID=0, Status='live', Symbol='SYN2', Aliases=['SYNII'], description='synapsin II', other_designations='synapsin-2', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12004366, end_position_on_the_genomic_accession=12192032, orientation='plus', exon_count=17, OMIM=[600755], no_hdr0=''),
    6855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6855, CurrentID=0, Status='live', Symbol='SYP', Aliases=['MRX96', 'MRXSYP'], description='synaptophysin', other_designations='synaptophysin|major synaptic vesicle protein P38', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49187815, end_position_on_the_genomic_accession=49200193, orientation='minus', exon_count=7, OMIM=[313475], no_hdr0=''),
    6856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6856, CurrentID=0, Status='live', Symbol='SYPL1', Aliases=['H-SP1', 'SYPL'], description='synaptophysin like 1', other_designations='synaptophysin-like protein 1|pantophysin', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=106090505, end_position_on_the_genomic_accession=106112576, orientation='minus', exon_count=9, OMIM=[616665], no_hdr0=''),
    6857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6857, CurrentID=0, Status='live', Symbol='SYT1', Aliases=['BAGOS', 'P65', 'SVP65', 'SYT'], description='synaptotagmin 1', other_designations='synaptotagmin-1|synaptotagmin I|sytI', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=78863982, end_position_on_the_genomic_accession=79452008, orientation='plus', exon_count=13, OMIM=[185605], no_hdr0=''),
    6860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6860, CurrentID=0, Status='live', Symbol='SYT4', Aliases=['HsT1192'], description='synaptotagmin 4', other_designations='synaptotagmin-4|synaptotagmin IV|sytIV', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=43267892, end_position_on_the_genomic_accession=43277490, orientation='minus', exon_count=4, OMIM=[600103], no_hdr0=''),
    6861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6861, CurrentID=0, Status='live', Symbol='SYT5', Aliases=[], description='synaptotagmin 5', other_designations='synaptotagmin-5|synaptotagmin V|sytV', map_location='11p', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55171196, end_position_on_the_genomic_accession=55180441, orientation='minus', exon_count=10, OMIM=[600782], no_hdr0=''),
    6862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6862, CurrentID=0, Status='live', Symbol='TBXT', Aliases=['SAVA', 'T', 'TFT'], description='T-box transcription factor T', other_designations='T-box transcription factor T|T brachyury transcription factor|T, brachyury homolog|brachyury protein|protein T', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166157656, end_position_on_the_genomic_accession=166168655, orientation='minus', exon_count=9, OMIM=[601397], no_hdr0=''),
    6863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6863, CurrentID=0, Status='live', Symbol='TAC1', Aliases=['Hs.2563', 'NK2', 'NKNA', 'NPK', 'TAC2'], description='tachykinin precursor 1', other_designations='protachykinin-1|PPT|neurokinin 1|neurokinin 2|neurokinin A|neurokinin alpha|neuromedin L|neuropeptide K|neuropeptide gamma|preprotachykinin|protachykinin|substance K|substance P|tachykinin 2|tachykinin, precursor 1 (substance K, substance P, neurokinin 1, neurokinin 2, neuromedin L, neurokinin alpha, neuropeptide K, neuropeptide gamma)', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97732086, end_position_on_the_genomic_accession=97740472, orientation='plus', exon_count=7, OMIM=[162320], no_hdr0=''),
    6865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6865, CurrentID=0, Status='live', Symbol='TACR2', Aliases=['NK2R', 'NKNAR', 'SKR', 'TAC2R'], description='tachykinin receptor 2', other_designations='substance-K receptor|NK-2 receptor|NK-2R|neurokinin 2 receptor|neurokinin A receptor|neurokinin B receptor|seven transmembrane helix receptor', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69403903, end_position_on_the_genomic_accession=69416918, orientation='minus', exon_count=5, OMIM=[162321], no_hdr0=''),
    6866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6866, CurrentID=0, Status='live', Symbol='TAC3', Aliases=['HH10', 'LncZBTB39', 'NK3', 'NKB', 'NKNB', 'PRO1155', 'ZNEUROK1'], description='tachykinin precursor 3', other_designations='tachykinin-3|LncZBTB39-1:2|gamma tachykinin 3|neurokinin b|neuromedin K|preprotachykinin B|tachykinin 3', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57010000, end_position_on_the_genomic_accession=57016529, orientation='minus', exon_count=9, OMIM=[162330], no_hdr0=''),
    6867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6867, CurrentID=0, Status='live', Symbol='TACC1', Aliases=['Ga55'], description='transforming acidic coiled-coil containing protein 1', other_designations='transforming acidic coiled-coil-containing protein 1|gastric cancer antigen Ga55|taxin-1', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38728205, end_position_on_the_genomic_accession=38853028, orientation='plus', exon_count=23, OMIM=[605301], no_hdr0=''),
    6868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6868, CurrentID=0, Status='live', Symbol='ADAM17', Aliases=['ADAM18', 'CD156B', 'CSVP', 'NISBD', 'NISBD1', 'TACE'], description='ADAM metallopeptidase domain 17', other_designations='disintegrin and metalloproteinase domain-containing protein 17|ADAM metallopeptidase domain 18|TNF-alpha convertase|TNF-alpha convertase enzyme|TNF-alpha converting enzyme|a disintegrin and metalloproteinase 17|cartilage snake venom-like protease|snake venom-like protease|tumor necrosis factor, alpha, converting enzyme', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9488486, end_position_on_the_genomic_accession=9555830, orientation='minus', exon_count=20, OMIM=[603639], no_hdr0=''),
    6869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6869, CurrentID=0, Status='live', Symbol='TACR1', Aliases=['NK1R', 'NKIR', 'SPR', 'TAC1R'], description='tachykinin receptor 1', other_designations='substance-P receptor|NK-1 receptor|NK-1R|neurokinin receptor 1|tachykinin receptor 1 (substance P receptor; neurokinin-1 receptor)', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=75046463, end_position_on_the_genomic_accession=75199520, orientation='minus', exon_count=5, OMIM=[162323], no_hdr0=''),
    6870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6870, CurrentID=0, Status='live', Symbol='TACR3', Aliases=['HH11', 'NK-3R', 'NK3', 'NK3R', 'NKR', 'TAC3R', 'TAC3RL'], description='tachykinin receptor 3', other_designations='neuromedin-K receptor|NK-3 receptor|NK3 receptor|neurokinin B receptor|neurokinin beta receptor', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=103586031, end_position_on_the_genomic_accession=103719985, orientation='minus', exon_count=5, OMIM=[162332], no_hdr0=''),
    6871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6871, CurrentID=0, Status='live', Symbol='TADA2A', Aliases=['ADA2', 'ADA2A', 'KL04P', 'TADA2L', 'hADA2'], description='transcriptional adaptor 2A', other_designations='transcriptional adapter 2-alpha|ADA2-like protein|transcriptional adaptor 2 alpha', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37406877, end_position_on_the_genomic_accession=37479725, orientation='plus', exon_count=17, OMIM=[602276], no_hdr0=''),
    6872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6872, CurrentID=0, Status='live', Symbol='TAF1', Aliases=['BA2R', 'CCG1', 'CCGS', 'DYT3', 'DYT3/TAF1', 'KAT4', 'MRXS33', 'N-TAF1', 'NSCL2', 'OF', 'P250', 'TAF(II)250', 'TAF2A', 'TAFII-250', 'TAFII250', 'XDP'], description='TATA-box binding protein associated factor 1', other_designations='transcription initiation factor TFIID subunit 1|TAF1 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 250kDa|TBP-associated factor 250 kDa|cell cycle gene 1 protein|cell cycle, G1 phase defect|complementation of cell cycle block, G1-to-S|transcription factor TFIID p250 polypeptide', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71366220, end_position_on_the_genomic_accession=71530525, orientation='plus', exon_count=45, OMIM=[313650], no_hdr0=''),
    6873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6873, CurrentID=0, Status='live', Symbol='TAF2', Aliases=['CIF150', 'MRT40B', 'TAFII150', 'TAF2'], description='TATA-box binding protein associated factor 2', other_designations='transcription initiation factor TFIID subunit 2|150 kDa cofactor of initiator function|RNA polymerase II TBP-associated factor subunit B|TAF(II)150|TAF2 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 150kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase II, B, 150kD|TBP-associated factor 150 kDa|cofactor of initiator function, 150kD subunit|transcription initiation factor TFIID 150 kDa subunit', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119730773, end_position_on_the_genomic_accession=119832858, orientation='minus', exon_count=30, OMIM=[604912], no_hdr0=''),
    6874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6874, CurrentID=0, Status='live', Symbol='TAF4', Aliases=['TAF(II)130', 'TAF(II)135', 'TAF2C', 'TAF2C1A', 'TAFII-130', 'TAFII-135', 'TAFII130', 'TAFII135', 'TAF4'], description='TATA-box binding protein associated factor 4', other_designations='transcription initiation factor TFIID subunit 4|RNA polymerase II TBP-associated factor subunit C|TAF4 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 135kDa|TAF4A RNA polymerase II, TATA box binding protein (TBP)-associated factor, 135 kD|TATA box binding protein (TBP)-associated factor, RNA polymerase II, C1, 130kD|TBP-associated factor 4|transcription initiation factor TFIID 130 kDa subunit|transcription initiation factor TFIID 135 kD subunit|transcription initiation factor TFIID 135 kDa subunit', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=61974798, end_position_on_the_genomic_accession=62065881, orientation='minus', exon_count=15, OMIM=[601796], no_hdr0=''),
    6875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6875, CurrentID=0, Status='live', Symbol='TAF4B', Aliases=['SPGF13', 'TAF2C2', 'TAFII105'], description='TATA-box binding protein associated factor 4b', other_designations='transcription initiation factor TFIID subunit 4B|TAF(II)105|TAF4b RNA polymerase II, TATA box binding protein (TBP)-associated factor, 105kDa|TATA box binding protein (TBP)-associated factor 4B|TATA box binding protein (TBP)-associated factor, RNA polymerase II, C2, 105kD|transcription initiation factor TFIID 105 kDa subunit', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26226445, end_position_on_the_genomic_accession=26391685, orientation='plus', exon_count=18, OMIM=[601689], no_hdr0=''),
    6876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6876, CurrentID=0, Status='live', Symbol='TAGLN', Aliases=['SM22', 'SM22-alpha', 'SMCC1', 'WS3-10', 'TAGLN'], description='transgelin', other_designations='transgelin|22 kDa actin-binding protein|epididymis secretory sperm binding protein|smooth muscle protein 22-alpha|transgelin variant 2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117199294, end_position_on_the_genomic_accession=117207465, orientation='plus', exon_count=5, OMIM=[600818], no_hdr0=''),
    6877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6877, CurrentID=0, Status='live', Symbol='TAF5', Aliases=['TAF(II)100', 'TAF2D', 'TAFII-100', 'TAFII100'], description='TATA-box binding protein associated factor 5', other_designations='transcription initiation factor TFIID subunit 5|TAF5 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 100kDa|TATA box binding protein (TBP)-associated factor 2D|TATA box binding protein (TBP)-associated factor, RNA polymerase II, D, 100kD|transcription initiation factor TFIID 100 kD subunit|transcription initiation factor TFIID 100 kDa subunit', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103367976, end_position_on_the_genomic_accession=103389065, orientation='plus', exon_count=11, OMIM=[601787], no_hdr0=''),
    6878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6878, CurrentID=0, Status='live', Symbol='TAF6', Aliases=['ALYUS', 'MGC:8964', 'TAF(II)70', 'TAF(II)80', 'TAF2E', 'TAFII-70', 'TAFII-80', 'TAFII70', 'TAFII80', 'TAFII85'], description='TATA-box binding protein associated factor 6', other_designations='transcription initiation factor TFIID subunit 6|RNA polymerase II TBP-associated factor subunit E|TAF6 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 80kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase II, E, 70/85kD|transcription initiation factor TFIID 70 kDa subunit', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100107070, end_position_on_the_genomic_accession=100127208, orientation='minus', exon_count=20, OMIM=[602955], no_hdr0=''),
    6879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6879, CurrentID=0, Status='live', Symbol='TAF7', Aliases=['TAF2F', 'TAFII55'], description='TATA-box binding protein associated factor 7', other_designations='transcription initiation factor TFIID subunit 7|RNA polymerase II TBP-associated factor subunit F|TAF(II)55|TAF7 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 55kDa|TAFII-55|TATA box binding protein (TBP)-associated factor, RNA polymerase II, F, 55kD|TBP-associated factor F|transcription factor IID subunit TAFII55|transcription initiation factor TFIID, 55 kDa subunit', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141318490, end_position_on_the_genomic_accession=141320784, orientation='minus', exon_count=1, OMIM=[600573], no_hdr0=''),
    6880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6880, CurrentID=0, Status='live', Symbol='TAF9', Aliases=['MGC:5067', 'STAF31/32', 'TAF2G', 'TAFII-31', 'TAFII-32', 'TAFII31', 'TAFII32', 'TAFIID32'], description='TATA-box binding protein associated factor 9', other_designations='transcription initiation factor TFIID subunit 9|RNA polymerase II TBP-associated factor subunit G|TAF9 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 32kDa|transcription initiation factor TFIID 31 kD subunit|transcription initiation factor TFIID 31 kDa subunit|transcription initiation factor TFIID 32 kDa subunit', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69364743, end_position_on_the_genomic_accession=69369824, orientation='minus', exon_count=4, OMIM=[600822], no_hdr0=''),
    6881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6881, CurrentID=0, Status='live', Symbol='TAF10', Aliases=['TAF2A', 'TAF2H', 'TAFII30'], description='TATA-box binding protein associated factor 10', other_designations='transcription initiation factor TFIID subunit 10|STAF28|TAF(II)30|TAF10 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 30kDa|TAFII-30|TATA box binding protein (TBP)-associated factor, RNA polymerase II, H, 30kD|transcription initiation factor TFIID 30 kD subunit|transcription initiation factor TFIID 30 kDa subunit', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6606294, end_position_on_the_genomic_accession=6612216, orientation='minus', exon_count=5, OMIM=[600475], no_hdr0=''),
    6882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6882, CurrentID=0, Status='live', Symbol='TAF11', Aliases=['MGC:15243', 'PRO2134', 'TAF2I', 'TAFII28'], description='TATA-box binding protein associated factor 11', other_designations='transcription initiation factor TFIID subunit 11|TAF(II)28|TAF11 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 28kDa|TAFII-28|TATA box binding protein (TBP)-associated factor, RNA polymerase II, I, 28kD|TFIID subunit p30-beta|transcription initiation factor TFIID 28 kD subunit|transcription initiation factor TFIID 28 kDa subunit', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34877462, end_position_on_the_genomic_accession=34888071, orientation='minus', exon_count=6, OMIM=[600772], no_hdr0=''),
    6883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6883, CurrentID=0, Status='live', Symbol='TAF12', Aliases=['TAF2J', 'TAFII20'], description='TATA-box binding protein associated factor 12', other_designations='transcription initiation factor TFIID subunit 12|TAF12 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 20kDa|TAFII-20/TAFII-15|TAFII20/TAFII15|TATA box binding protein (TBP)-associated factor, RNA polymerase II, J, 20kD|transcription initiation factor TFIID 20/15 kDa subunits', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28602850, end_position_on_the_genomic_accession=28648707, orientation='minus', exon_count=8, OMIM=[600773], no_hdr0=''),
    6884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6884, CurrentID=0, Status='live', Symbol='TAF13', Aliases=['MRT60', 'TAF(II)18', 'TAF2K', 'TAFII-18', 'TAFII18'], description='TATA-box binding protein associated factor 13', other_designations='transcription initiation factor TFIID subunit 13|TAF13 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 18kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase II, K, 18kD|transcription initiation factor TFIID 18 kD subunit|transcription initiation factor TFIID 18 kDa subunit', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109064140, end_position_on_the_genomic_accession=109076003, orientation='minus', exon_count=4, OMIM=[600774], no_hdr0=''),
    6885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6885, CurrentID=0, Status='live', Symbol='MAP3K7', Aliases=['CSCF', 'FMD2', 'MEKK7', 'TAK1', 'TGF1a'], description='mitogen-activated protein kinase kinase kinase 7', other_designations='mitogen-activated protein kinase kinase kinase 7|TGF-beta activated kinase 1|transforming growth factor-beta-activated kinase 1', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=90513579, end_position_on_the_genomic_accession=90587072, orientation='minus', exon_count=17, OMIM=[602614], no_hdr0=''),
    6886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6886, CurrentID=0, Status='live', Symbol='TAL1', Aliases=['SCL', 'TCL5', 'bHLHa17', 'tal-1'], description='TAL bHLH transcription factor 1, erythroid differentiation factor', other_designations='T-cell acute lymphocytic leukemia protein 1|T-cell acute lymphocytic leukemia 1|T-cell leukemia/lymphoma protein 5|class A basic helix-loop-helix protein 17|stem cell protein|tal-1 product', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47216290, end_position_on_the_genomic_accession=47232389, orientation='minus', exon_count=9, OMIM=[187040], no_hdr0=''),
    6887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6887, CurrentID=0, Status='live', Symbol='TAL2', Aliases=[], description='TAL bHLH transcription factor 2', other_designations='T-cell acute lymphocytic leukemia protein 2|T-cell acute lymphocytic leukemia 2|TAL-2|class A basic helix-loop-helix protein 19', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=105662457, end_position_on_the_genomic_accession=105663124, orientation='plus', exon_count=1, OMIM=[186855], no_hdr0=''),
    6888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6888, CurrentID=0, Status='live', Symbol='TALDO1', Aliases=['TAL', 'TAL-H', 'TALDOR', 'TALH'], description='transaldolase 1', other_designations='transaldolase|dihydroxyacetone transferase|glycerone transferase|testicular secretory protein Li 56', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=747464, end_position_on_the_genomic_accession=765012, orientation='plus', exon_count=8, OMIM=[602063], no_hdr0=''),
    6890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6890, CurrentID=0, Status='live', Symbol='TAP1', Aliases=['ABC17', 'ABCB2', 'APT1', 'D6S114E', 'PSF-1', 'PSF1', 'RING4*0102N', 'TAP1N', 'TAP1'], description='transporter 1, ATP binding cassette subfamily B member', other_designations='antigen peptide transporter 1|ABC transporter, MHC 1|ATP-binding cassette sub-family B member 2|ATP-binding cassette, sub-family B (MDR/TAP), member 2|peptide supply factor 1|peptide transporter PSF1|peptide transporter TAP1|peptide transporter involved in antigen processing 1|really interesting new gene 4 protein|transporter 1 ATP-binding cassette sub-family B|transporter 1, ATP-binding cassette, sub-family B (MDR/TAP)|transporter associated with antigen processing|transporter, ATP-binding cassette, major histocompatibility complex, 1', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32845209, end_position_on_the_genomic_accession=32853704, orientation='minus', exon_count=12, OMIM=[170260], no_hdr0=''),
    6891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6891, CurrentID=0, Status='live', Symbol='TAP2', Aliases=['ABC18', 'ABCB3', 'APT2', 'D6S217E', 'PSF-2', 'PSF2', 'RING11'], description='transporter 2, ATP binding cassette subfamily B member', other_designations='antigen peptide transporter 2|ABC transporter, MHC 2|ATP-binding cassette, sub-family B (MDR/TAP), member 3|peptide supply factor 2|peptide transporter PSF2|peptide transporter involved in antigen processing 2|really interesting new gene 11 protein|transporter 2, ABC (ATP binding cassette)|transporter 2, ATP-binding cassette, sub-family B (MDR/TAP)', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32821831, end_position_on_the_genomic_accession=32838739, orientation='minus', exon_count=13, OMIM=[170261], no_hdr0=''),
    6892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6892, CurrentID=0, Status='live', Symbol='TAPBP', Aliases=['NGS17', 'TAPA', 'TPN', 'TPSN'], description='TAP binding protein', other_designations='tapasin|NGS-17|TAP binding protein (tapasin)|TAP-associated protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33299694, end_position_on_the_genomic_accession=33314254, orientation='minus', exon_count=8, OMIM=[601962], no_hdr0=''),
    6894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6894, CurrentID=0, Status='live', Symbol='TARBP1', Aliases=['TRM3', 'TRMT3', 'TRP-185', 'TRP185'], description='TAR (HIV-1) RNA binding protein 1', other_designations='probable methyltransferase TARBP1|TAR (HIV) RNA-binding protein 1|TAR RNA loop binding protein|TAR RNA-binding protein 1|TAR RNA-binding protein of 185 kDa|tRNA methyltransferase 3 homolog', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=234391313, end_position_on_the_genomic_accession=234479179, orientation='minus', exon_count=34, OMIM=[605052], no_hdr0=''),
    6895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6895, CurrentID=0, Status='live', Symbol='TARBP2', Aliases=['LOQS', 'TRBP', 'TRBP1', 'TRBP2'], description='TARBP2 subunit of RISC loading complex', other_designations='RISC-loading complex subunit TARBP2|TAR (HIV) RNA-binding protein 2|TAR (HIV) RNA-binding protein TRBP1|TAR (HIV-1) RNA binding protein 2|TAR RNA binding protein 2|TARBP2, RISC loading complex RNA binding subunit|trans-activation responsive RNA-binding protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53500923, end_position_on_the_genomic_accession=53506431, orientation='plus', exon_count=11, OMIM=[605053], no_hdr0=''),
    6897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6897, CurrentID=0, Status='live', Symbol='TARS1', Aliases=['TARS', 'TTD7', 'ThrRS'], description='threonyl-tRNA synthetase 1', other_designations='threonine--tRNA ligase 1, cytoplasmic|threonine tRNA ligase 1, cytoplasmic|threonine--tRNA ligase, cytoplasmic|threonyl-tRNA synthetase, cytoplasmic', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=33440696, end_position_on_the_genomic_accession=33468091, orientation='plus', exon_count=22, OMIM=[187790], no_hdr0=''),
    6898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6898, CurrentID=0, Status='live', Symbol='TAT', Aliases=[], description='tyrosine aminotransferase', other_designations='tyrosine aminotransferase|L-tyrosine:2-oxoglutarate aminotransferase|testis tissue sperm-binding protein Li 34a|tyrosine aminotransferase, cytosolic', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71565660, end_position_on_the_genomic_accession=71577092, orientation='minus', exon_count=12, OMIM=[613018], no_hdr0=''),
    6899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6899, CurrentID=0, Status='live', Symbol='TBX1', Aliases=['CAFS', 'CATCH22', 'CTHM', 'DGCR', 'DGS', 'DORVC', 'TGA', 'VCF', 'VCFS', 'TBX1'], description='T-box transcription factor 1', other_designations='T-box transcription factor TBX1|T-box 1 transcription factor C|Testis-specific T-box protein|brachyury', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19756703, end_position_on_the_genomic_accession=19783593, orientation='plus', exon_count=13, OMIM=[602054], no_hdr0=''),
    6900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6900, CurrentID=0, Status='live', Symbol='CNTN2', Aliases=['AXT', 'FAME5', 'TAG-1', 'TAX', 'TAX1'], description='contactin 2', other_designations='contactin-2|axonal glycoprotein TAG-1|axonin-1 cell adhesion molecule|contactin 2 (axonal)|contactin 2 (transiently expressed)|transient axonal glycoprotein 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205042937, end_position_on_the_genomic_accession=205078289, orientation='plus', exon_count=25, OMIM=[190197], no_hdr0=''),
    6901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6901, CurrentID=0, Status='live', Symbol='TAFAZZIN', Aliases=['BTHS', 'CMD3A', 'EFE', 'EFE2', 'G4.5', 'LVNCX', 'TAZ', 'Taz1'], description='tafazzin, phospholipid-lysophospholipid transacylase', other_designations='tafazzin|protein G4.5', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154411539, end_position_on_the_genomic_accession=154421726, orientation='plus', exon_count=11, OMIM=[300394], no_hdr0=''),
    6902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6902, CurrentID=0, Status='live', Symbol='TBCA', Aliases=[], description='tubulin folding cofactor A', other_designations='tubulin-specific chaperone A|CFA|TCP1-chaperonin cofactor A|chaperonin cofactor A|epididymis secretory sperm binding protein', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77691166, end_position_on_the_genomic_accession=77776339, orientation='minus', exon_count=4, OMIM=[610058], no_hdr0=''),
    6903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6903, CurrentID=0, Status='live', Symbol='TBCC', Aliases=['CFC'], description='tubulin folding cofactor C', other_designations='tubulin-specific chaperone C', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42744498, end_position_on_the_genomic_accession=42746103, orientation='minus', exon_count=1, OMIM=[602971], no_hdr0=''),
    6904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6904, CurrentID=0, Status='live', Symbol='TBCD', Aliases=['PEBAT', 'SSD-1', 'tfcD'], description='tubulin folding cofactor D', other_designations='tubulin-specific chaperone D|beta-tubulin cofactor D', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82752048, end_position_on_the_genomic_accession=82945914, orientation='plus', exon_count=61, OMIM=[604649], no_hdr0=''),
    6905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6905, CurrentID=0, Status='live', Symbol='TBCE', Aliases=['HRD', 'KCS', 'KCS1', 'PEAMO', 'pac2'], description='tubulin folding cofactor E', other_designations='tubulin-specific chaperone E|hypoparathyroidism, growth and mental retardation, and dysmorphism', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235367427, end_position_on_the_genomic_accession=235452443, orientation='plus', exon_count=18, OMIM=[604934], no_hdr0=''),
    6906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6906, CurrentID=0, Status='live', Symbol='SERPINA7', Aliases=['TBG', 'TBGQTL'], description='serpin family A member 7', other_designations='thyroxine-binding globulin|T4-binding globulin|mutant serpin family A member 7|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 7|serpin A7|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 7|thyroxin-binding globulin', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106032435, end_position_on_the_genomic_accession=106038727, orientation='minus', exon_count=5, OMIM=[314200], no_hdr0=''),
    6907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6907, CurrentID=0, Status='live', Symbol='TBL1X', Aliases=['CHNG8', 'EBI', 'SMAP55', 'TBL1'], description='transducin beta like 1 X-linked', other_designations='F-box-like/WD repeat-containing protein TBL1X|transducin beta like 1X-linked|transducin beta-like protein 1X|transducin-beta-like protein 1, X-linked', map_location='Xp22.31-p22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=9463295, end_position_on_the_genomic_accession=9719740, orientation='plus', exon_count=20, OMIM=[300196], no_hdr0=''),
    6908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6908, CurrentID=0, Status='live', Symbol='TBP', Aliases=['GTF2D', 'GTF2D1', 'HDL4', 'SCA17', 'TFIID'], description='TATA-box binding protein', other_designations='TATA-box-binding protein|TATA sequence-binding protein|TATA-box binding protein N-terminal domain|TATA-box factor|transcription initiation factor TFIID TBP subunit', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=170554369, end_position_on_the_genomic_accession=170572859, orientation='plus', exon_count=8, OMIM=[600075], no_hdr0=''),
    6909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6909, CurrentID=0, Status='live', Symbol='TBX2', Aliases=['VETD'], description='T-box transcription factor 2', other_designations='T-box transcription factor TBX2|T-box 2|T-box protein 2', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61399843, end_position_on_the_genomic_accession=61409466, orientation='plus', exon_count=7, OMIM=[600747], no_hdr0=''),
    6910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6910, CurrentID=0, Status='live', Symbol='TBX5', Aliases=['HOS'], description='T-box transcription factor 5', other_designations='T-box transcription factor TBX5|T-box 5|T-box protein 5', map_location='12q24.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=114353911, end_position_on_the_genomic_accession=114408708, orientation='minus', exon_count=10, OMIM=[601620], no_hdr0=''),
    6911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6911, CurrentID=0, Status='live', Symbol='TBX6', Aliases=['SCDO5'], description='T-box transcription factor 6', other_designations='T-box transcription factor TBX6|T-box 6|T-box protein 6', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30085793, end_position_on_the_genomic_accession=30091927, orientation='minus', exon_count=8, OMIM=[602427], no_hdr0=''),
    6913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6913, CurrentID=0, Status='live', Symbol='TBX15', Aliases=['TBX14'], description='T-box transcription factor 15', other_designations='T-box transcription factor TBX15|T-box 14|T-box 15|T-box protein 14|T-box protein 15|T-box transcription factor TBX14', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=118883046, end_position_on_the_genomic_accession=118989510, orientation='minus', exon_count=11, OMIM=[604127], no_hdr0=''),
    6914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6914, CurrentID=0, Status='live', Symbol='TBXA1R', Aliases=[], description='thromboxane A1 receptor', other_designations='thromboxane A1 receptor', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    6915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6915, CurrentID=0, Status='live', Symbol='TBXA2R', Aliases=['BDPLT13', 'TXA2-R'], description='thromboxane A2 receptor', other_designations='thromboxane A2 receptor|prostanoid TP receptor', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3594507, end_position_on_the_genomic_accession=3608749, orientation='minus', exon_count=5, OMIM=[188070], no_hdr0=''),
    6916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6916, CurrentID=0, Status='live', Symbol='TBXAS1', Aliases=['BDPLT14', 'CYP5', 'CYP5A1', 'GHOSAL', 'THAS', 'TS', 'TXAS', 'TXS'], description='thromboxane A synthase 1', other_designations='thromboxane-A synthase|TXA synthase|cytochrome P450 5A1|cytochrome P450, family 5, subfamily A, polypeptide 1|hydroperoxy icosatetraenoate dehydratase|platelet, cytochrome P450, subfamily V|thromboxane A synthase 1 (platelet)', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139778242, end_position_on_the_genomic_accession=140020293, orientation='plus', exon_count=25, OMIM=[274180], no_hdr0=''),
    6917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6917, CurrentID=0, Status='live', Symbol='TCEA1', Aliases=['GTF2S', 'SII', 'TCEA', 'TF2S', 'TFIIS'], description='transcription elongation factor A1', other_designations='transcription elongation factor A protein 1|epididymis secretory sperm binding protein|transcription elongation factor A (SII), 1|transcription elongation factor S-II protein 1|transcription elongation factor TFIIS.o|transcription factor IIS', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=53966556, end_position_on_the_genomic_accession=54022448, orientation='minus', exon_count=13, OMIM=[601425], no_hdr0=''),
    6919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6919, CurrentID=0, Status='live', Symbol='TCEA2', Aliases=['TFIIS'], description='transcription elongation factor A2', other_designations='transcription elongation factor A protein 2|testis-specific S-II|transcription elongation factor A (SII), 2|transcription elongation factor S-II protein 2|transcription elongation factor TFIIS.1|transcription elongation factor TFIIS.l', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64042350, end_position_on_the_genomic_accession=64072347, orientation='plus', exon_count=17, OMIM=[604784], no_hdr0=''),
    6920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6920, CurrentID=0, Status='live', Symbol='TCEA3', Aliases=['TFIIS', 'TFIIS.H'], description='transcription elongation factor A3', other_designations='transcription elongation factor A protein 3|rhabdomyosarcoma antigen MU-RMS-40.22|transcription elongation factor A (SII), 3|transcription elongation factor S-II protein 3|transcription elongation factor TFIIS.h', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23380909, end_position_on_the_genomic_accession=23424776, orientation='minus', exon_count=12, OMIM=[604128], no_hdr0=''),
    6921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6921, CurrentID=0, Status='live', Symbol='ELOC', Aliases=['SIII', 'TCEB1'], description='elongin C', other_designations='elongin-C|RNA polymerase II transcription factor SIII subunit C|SIII p15|elongin 15 kDa subunit|transcription elongation factor B (SIII), polypeptide 1 (15kDa, elongin C)|transcription elongation factor B polypeptide 1|transcription elongation factor B subunit 1', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73945119, end_position_on_the_genomic_accession=73972287, orientation='minus', exon_count=9, OMIM=[600788], no_hdr0=''),
    6923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6923, CurrentID=0, Status='live', Symbol='ELOB', Aliases=['SIII', 'TCEB2'], description='elongin B', other_designations='elongin-B|RNA polymerase II transcription factor SIII p18 subunit|RNA polymerase II transcription factor SIII subunit B|SIII p18|elongin 18 kDa subunit|elongin, 18-kD subunit|epididymis secretory sperm binding protein|transcription elongation factor B (SIII), polypeptide 2 (18kDa, elongin B)|transcription elongation factor B polypeptide 2|transcription elongation factor B subunit 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2771414, end_position_on_the_genomic_accession=2777280, orientation='minus', exon_count=5, OMIM=[600787], no_hdr0=''),
    6924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6924, CurrentID=0, Status='live', Symbol='ELOA', Aliases=['SIII', 'SIII p110', 'TCEB3', 'TCEB3A'], description='elongin A', other_designations='elongin-A|RNA polymerase II transcription factor SIII subunit A1|elongin 110 kDa subunit|transcription elongation factor B (SIII), polypeptide 3 (110kDa, elongin A)|transcription elongation factor B alpha subunit|transcription elongation factor B polypeptide 3|transcription elongation factor B subunit 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23743471, end_position_on_the_genomic_accession=23762059, orientation='plus', exon_count=11, OMIM=[600786], no_hdr0=''),
    6925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6925, CurrentID=0, Status='live', Symbol='TCF4', Aliases=['CDG2T', 'E2-2', 'FECD3', 'ITF-2', 'ITF2', 'PTHS', 'SEF-2', 'SEF2', 'SEF2-1', 'SEF2-1A', 'SEF2-1B', 'SEF2-1D', 'TCF-4', 'bHLHb19'], description='transcription factor 4', other_designations='transcription factor 4|SL3-3 enhancer factor 2|class B basic helix-loop-helix protein 19|immunoglobulin transcription factor 2', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=55222185, end_position_on_the_genomic_accession=55635957, orientation='minus', exon_count=34, OMIM=[602272], no_hdr0=''),
    6926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6926, CurrentID=0, Status='live', Symbol='TBX3', Aliases=['TBX3-ISO', 'UMS', 'XHL'], description='T-box transcription factor 3', other_designations='T-box transcription factor TBX3|T-box 3|T-box protein 3|bladder cancer related protein XHL', map_location='12q24.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=114670255, end_position_on_the_genomic_accession=114684175, orientation='minus', exon_count=8, OMIM=[601621], no_hdr0=''),
    6927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6927, CurrentID=0, Status='live', Symbol='HNF1A', Aliases=['HNF-1A', 'HNF1', 'HNF1alpha', 'HNF4A', 'IDDM20', 'LFB1', 'MODY3', 'TCF-1', 'TCF1'], description='HNF1 homeobox A', other_designations='hepatocyte nuclear factor 1-alpha|HNF-1-alpha|albumin proximal factor|hepatic nuclear factor 1|interferon production regulator factor|liver-specific transcription factor LF-B1|transcription factor 1, hepatic|truncated hepatocyte nuclear factor 1 alpha', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120977683, end_position_on_the_genomic_accession=121002512, orientation='plus', exon_count=9, OMIM=[142410], no_hdr0=''),
    6928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6928, CurrentID=0, Status='live', Symbol='HNF1B', Aliases=['ADTKD3', 'FJHN', 'HNF-1-beta', 'HNF-1B', 'HNF1beta', 'HNF2', 'HPC11', 'LF-B3', 'LFB3', 'MODY5', 'RCAD', 'T2D', 'TCF-2', 'TCF2', 'VHNF1'], description='HNF1 homeobox B', other_designations='hepatocyte nuclear factor 1-beta|HNF1 beta A|homeoprotein LFB3|transcription factor 2, hepatic', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37686431, end_position_on_the_genomic_accession=37745059, orientation='minus', exon_count=11, OMIM=[189907], no_hdr0=''),
    6929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6929, CurrentID=0, Status='live', Symbol='TCF3', Aliases=['AGM8', 'E2A', 'E47', 'ITF1', 'TCF-3', 'VDIR', 'bHLHb21', 'p75'], description='transcription factor 3', other_designations='transcription factor E2-alpha|E2A-HLF fusion transcript protein|NOL1-TCF3 fusion|VDR interacting repressor|class B basic helix-loop-helix protein 21|helix-loop-helix protein HE47|immunoglobulin transcription factor 1|kappa-E2-binding factor|negative vitamin D response element-binding protein|transcription factor 3 (E2A immunoglobulin enhancer binding factors E12/E47)|transcription factor 3 variant 3|transcription factor ITF-1|vitamin D receptor-interacting repressor', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1609292, end_position_on_the_genomic_accession=1652615, orientation='minus', exon_count=21, OMIM=[147141], no_hdr0=''),
    6932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6932, CurrentID=0, Status='live', Symbol='TCF7', Aliases=['TCF-1'], description='transcription factor 7', other_designations='transcription factor 7|T-cell-factor-7|T-cell-specific transcription factor 1|transcription factor 7 (T-cell specific, HMG-box)', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134114681, end_position_on_the_genomic_accession=134148229, orientation='plus', exon_count=18, OMIM=[189908], no_hdr0=''),
    6934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6934, CurrentID=0, Status='live', Symbol='TCF7L2', Aliases=['TCF-4', 'TCF4'], description='transcription factor 7 like 2', other_designations='transcription factor 7-like 2|HMG box transcription factor 4|T-cell factor 4|T-cell-specific transcription factor 4|hTCF-4|transcription factor 7-like 2 (T-cell specific, HMG-box)', map_location='10q25.2-q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112950247, end_position_on_the_genomic_accession=113167678, orientation='plus', exon_count=20, OMIM=[602228], no_hdr0=''),
    6935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6935, CurrentID=0, Status='live', Symbol='ZEB1', Aliases=['AREB6', 'BZP', 'DELTAEF1', 'FECD6', 'NIL2A', 'PPCD3', 'TCF8', 'ZFHEP', 'ZFHX1A'], description='zinc finger E-box binding homeobox 1', other_designations='zinc finger E-box-binding homeobox 1|delta-crystallin enhancer binding factor 1|negative regulator of IL2|posterior polymorphous corneal dystrophy 3|transcription factor 8 (represses interleukin 2 expression)|zinc finger homeodomain enhancer-binding protein', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=31318417, end_position_on_the_genomic_accession=31529804, orientation='plus', exon_count=20, OMIM=[189909], no_hdr0=''),
    6936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6936, CurrentID=0, Status='live', Symbol='GCFC2', Aliases=['C2orf3', 'DNABF', 'GCF', 'TCF9'], description='GC-rich sequence DNA-binding factor 2', other_designations='intron Large complex component GCFC2|GC binding factor|GC bindng factor|TCF-9|transcription factor 9 (binds GC-rich sequences)', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=75655606, end_position_on_the_genomic_accession=75711642, orientation='minus', exon_count=17, OMIM=[189901], no_hdr0=''),
    6938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6938, CurrentID=0, Status='live', Symbol='TCF12', Aliases=['CRS3', 'HEB', 'HTF4', 'HsT17266', 'TCF-12', 'bHLHb20', 'p64'], description='transcription factor 12', other_designations='transcription factor 12|DNA-binding protein HTF4|E-box-binding protein|class B basic helix-loop-helix protein 20|helix-loop-helix transcription factor 4|transcription factor HTF-4', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=56918090, end_position_on_the_genomic_accession=57292595, orientation='plus', exon_count=27, OMIM=[600480], no_hdr0=''),
    6939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6939, CurrentID=0, Status='live', Symbol='TCF15', Aliases=['EC2', 'PARAXIS', 'bHLHa40'], description='transcription factor 15', other_designations='transcription factor 15|TCF-15|basic helix-loop-helix transcription factor 15|class A basic helix-loop-helix protein 40|protein bHLH-EC2|transcription factor 15 (basic helix-loop-helix)', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=604257, end_position_on_the_genomic_accession=610309, orientation='minus', exon_count=2, OMIM=[601010], no_hdr0=''),
    6940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6940, CurrentID=0, Status='live', Symbol='ZNF354A', Aliases=['EZNF', 'HEL104', 'HKL1', 'KID-1', 'KID1', 'TCF17'], description='zinc finger protein 354A', other_designations='zinc finger protein 354A|epididymis luminal protein 104|transcription factor 17|zinc finger protein eZNF', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178711512, end_position_on_the_genomic_accession=178730659, orientation='minus', exon_count=6, OMIM=[602444], no_hdr0=''),
    6941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6941, CurrentID=0, Status='live', Symbol='TCF19', Aliases=['SC1', 'TCF-19'], description='transcription factor 19', other_designations='transcription factor 19|transcription factor SC1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31158589, end_position_on_the_genomic_accession=31164215, orientation='plus', exon_count=5, OMIM=[600912], no_hdr0=''),
    6942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6942, CurrentID=0, Status='live', Symbol='TCF20', Aliases=['AR1', 'DDVIBA', 'SPBP', 'TCF-20'], description='transcription factor 20', other_designations='transcription factor 20|SPRE-binding protein|nuclear factor SPBP|stromelysin-1 PDGF-responsive element-binding protein|stromelysin-1 platelet-derived growth factor-responsive element binding protein', map_location='22q13.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42160013, end_position_on_the_genomic_accession=42283927, orientation='minus', exon_count=8, OMIM=[603107], no_hdr0=''),
    6943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6943, CurrentID=0, Status='live', Symbol='TCF21', Aliases=['POD1', 'bHLHa23'], description='transcription factor 21', other_designations='transcription factor 21|capsulin|class A basic helix-loop-helix protein 23|epicardin|pod-1|podocyte-expressed 1', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=133889113, end_position_on_the_genomic_accession=133895537, orientation='plus', exon_count=3, OMIM=[603306], no_hdr0=''),
    6944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6944, CurrentID=0, Status='live', Symbol='VPS72', Aliases=['CFL1', 'Swc2', 'TCFL1', 'YL-1', 'YL1'], description='vacuolar protein sorting 72 homolog', other_designations='vacuolar protein sorting-associated protein 72 homolog|transcription factor-like 1|transformation suppressor gene YL-1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151176304, end_position_on_the_genomic_accession=151190210, orientation='minus', exon_count=6, OMIM=[600607], no_hdr0=''),
    6945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6945, CurrentID=0, Status='live', Symbol='MLX', Aliases=['MAD7', 'MXD7', 'TCFL4', 'TF4', 'bHLHd13'], description='MAX dimerization protein MLX', other_designations='max-like protein X|BigMax protein|MAX-like bHLHZIP protein|MLX, MAX dimerization protein|class D basic helix-loop-helix protein 13|transcription factor-like protein 4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42567100, end_position_on_the_genomic_accession=42573203, orientation='plus', exon_count=8, OMIM=[602976], no_hdr0=''),
    6947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6947, CurrentID=0, Status='live', Symbol='TCN1', Aliases=['HC', 'TC-1', 'TC1', 'TCI'], description='transcobalamin 1', other_designations='transcobalamin-1|haptocorin|haptocorrin|protein R|transcobalamin I (vitamin B12 binding protein, R binder family)', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59852808, end_position_on_the_genomic_accession=59866487, orientation='minus', exon_count=9, OMIM=[189905], no_hdr0=''),
    6948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6948, CurrentID=0, Status='live', Symbol='TCN2', Aliases=['D22S676', 'D22S750', 'II', 'TC', 'TC II', 'TC-2', 'TC2', 'TCII'], description='transcobalamin 2', other_designations='transcobalamin-2|macrocytic anemia|transcobalamin II|transcobalamin II; macrocytic anemia|vitamin B12-binding protein 2', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30607174, end_position_on_the_genomic_accession=30627271, orientation='plus', exon_count=9, OMIM=[613441], no_hdr0=''),
    6949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6949, CurrentID=0, Status='live', Symbol='TCOF1', Aliases=['MFD1', 'TCS', 'TCS1', 'treacle'], description='treacle ribosome biogenesis factor 1', other_designations='treacle protein|Treacher Collins syndrome protein|Treacher Collins-Franceschetti syndrome 1|nucleolar trafficking phosphoprotein', map_location='5q32-q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150357697, end_position_on_the_genomic_accession=150400306, orientation='plus', exon_count=29, OMIM=[606847], no_hdr0=''),
    6950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6950, CurrentID=0, Status='live', Symbol='TCP1', Aliases=['CCT-alpha', 'CCT1', 'CCTa', 'D6S230E', 'TCP-1-alpha'], description='t-complex 1', other_designations='T-complex protein 1 subunit alpha|T-complex protein 1, alpha subunit|t-complex 1 protein|tailless complex polypeptide 1', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159778498, end_position_on_the_genomic_accession=159789602, orientation='minus', exon_count=12, OMIM=[186980], no_hdr0=''),
    6954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6954, CurrentID=0, Status='live', Symbol='TCP11', Aliases=['D6S230E', 'FPPR'], description='t-complex 11', other_designations='T-complex protein 11 homolog|fertilization-promoting peptide receptor|t-complex 11 (a murine tcp homolog)|t-complex 11 homolog|t-complex 11, testis-specific|testis secretory sperm-binding protein Li 222n', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35118071, end_position_on_the_genomic_accession=35141339, orientation='minus', exon_count=14, OMIM=[186982], no_hdr0=''),
    6955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6955, CurrentID=0, Status='live', Symbol='TRA', Aliases=['IMD7', 'TCRA@', 'TRA'], description='T cell receptor alpha locus', other_designations='T-cell antigen receptor, alpha polypeptide|T-cell receptor, alpha (V,D,J,C)|TCRA, TRA@', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21621904, end_position_on_the_genomic_accession=22552132, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    6957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6957, CurrentID=0, Status='live', Symbol='TRB', Aliases=['TCRB@', 'TRB'], description='T cell receptor beta locus', other_designations='T-cell antigen receptor, beta polypeptide, T-cell receptor, beta cluster|T-cell receptor, beta cluster|TCRB, TRB@', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142299011, end_position_on_the_genomic_accession=142813287, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    6964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6964, CurrentID=0, Status='live', Symbol='TRD', Aliases=['TCRD', 'TCRDV1@', 'TRD'], description='T cell receptor delta locus', other_designations='T-cell antigen receptor, delta polypeptide|T-cell receptor, delta (V,D,J,C)|TCRD, TRD@', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22422546, end_position_on_the_genomic_accession=22466577, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    6965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6965, CurrentID=0, Status='live', Symbol='TRG', Aliases=['TCRG@', 'TRG'], description='T cell receptor gamma locus', other_designations='T-cell antigen receptor, gamma polypeptide|T-cell rearranging gene, gamma|T-cell receptor, gamma cluster|TCRG, TRG@', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38240024, end_position_on_the_genomic_accession=38368055, orientation='minus', exon_count=0, OMIM=[], no_hdr0=''),
    6975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6975, CurrentID=0, Status='live', Symbol='TECTB', Aliases=[], description='tectorin beta', other_designations='beta-tectorin', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112283400, end_position_on_the_genomic_accession=112305038, orientation='plus', exon_count=11, OMIM=[602653], no_hdr0=''),
    6988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6988, CurrentID=0, Status='live', Symbol='TCTA', Aliases=[], description='T cell leukemia translocation altered', other_designations='T-cell leukemia translocation-altered gene protein|T-cell leukemia translocation-associated gene protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49412423, end_position_on_the_genomic_accession=49416476, orientation='plus', exon_count=3, OMIM=[600690], no_hdr0=''),
    6990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6990, CurrentID=0, Status='live', Symbol='DYNLT3', Aliases=['RP3', 'TCTE1L', 'TCTEX1L'], description='dynein light chain Tctex-type 3', other_designations='dynein light chain Tctex-type 3|protein 91/23', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37838836, end_position_on_the_genomic_accession=37847571, orientation='minus', exon_count=5, OMIM=[300302], no_hdr0=''),
    6991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6991, CurrentID=0, Status='live', Symbol='DYNLT2', Aliases=['TCTE3', 'TCTEX1D3', 'TCTEX2', 'Tctex4'], description='dynein light chain Tctex-type 2', other_designations='dynein light chain Tctex-type protein 2|T-complex testis-specific protein 3|T-complex-associated testis-expressed protein 3|Tctex1 domain containing 3|t-complex-associated-testis-expressed 3|tctex1 domain-containing protein 3', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169725488, end_position_on_the_genomic_accession=169751581, orientation='minus', exon_count=5, OMIM=[186977], no_hdr0=''),
    6992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6992, CurrentID=0, Status='live', Symbol='PPP1R11', Aliases=['CFAP255', 'HCG-V', 'HCGV', 'IPP3', 'TCTE5', 'TCTEX5'], description='protein phosphatase 1 regulatory inhibitor subunit 11', other_designations='E3 ubiquitin-protein ligase PPP1R11|HCG V|hemochromatosis candidate gene V protein|inhibitor-3|protein phosphatase 1 regulatory subunit 11|protein phosphatase inhibitor 3|t-complex-associated-testis-expressed 5', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30066864, end_position_on_the_genomic_accession=30070333, orientation='plus', exon_count=4, OMIM=[606670], no_hdr0=''),
    6993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6993, CurrentID=0, Status='live', Symbol='DYNLT1', Aliases=['CW-1', 'TCTEL1', 'TCTEX1', 'tctex-1'], description='dynein light chain Tctex-type 1', other_designations='dynein light chain Tctex-type 1|T-complex testis-specific protein 1 homolog|t-complex-associated-testis-expressed 1-like 1', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158636474, end_position_on_the_genomic_accession=158644743, orientation='minus', exon_count=5, OMIM=[601554], no_hdr0=''),
    6996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6996, CurrentID=0, Status='live', Symbol='TDG', Aliases=['hTDG'], description='thymine DNA glycosylase', other_designations='G/T mismatch-specific thymine DNA glycosylase', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103965842, end_position_on_the_genomic_accession=103988874, orientation='plus', exon_count=10, OMIM=[601423], no_hdr0=''),
    6997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6997, CurrentID=0, Status='live', Symbol='TDGF1', Aliases=['CR', 'CR-1', 'CRGF', 'CRIPTO'], description='teratocarcinoma-derived growth factor 1', other_designations='teratocarcinoma-derived growth factor 1|cripto-1 growth factor|epidermal growth factor-like cripto protein CR1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46574535, end_position_on_the_genomic_accession=46582457, orientation='plus', exon_count=7, OMIM=[187395], no_hdr0=''),
    6999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=6999, CurrentID=0, Status='live', Symbol='TDO2', Aliases=['HYPTRP', 'TDO', 'TO', 'TPH2', 'TRPO'], description='tryptophan 2,3-dioxygenase', other_designations='tryptophan 2,3-dioxygenase|tryptamin 2,3-dioxygenase|tryptophan oxygenase|tryptophan pyrrolase|tryptophanase', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155903696, end_position_on_the_genomic_accession=155920406, orientation='plus', exon_count=12, OMIM=[191070], no_hdr0=''),
    7001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7001, CurrentID=0, Status='live', Symbol='PRDX2', Aliases=['HEL-S-2a', 'NKEF-B', 'NKEFB', 'PRP', 'PRX2', 'PRXII', 'PTX1', 'TDPX1', 'TPX1', 'TSA'], description='peroxiredoxin 2', other_designations='peroxiredoxin-2|epididymis secretory sperm binding protein Li 2a|natural killer cell-enhancing factor B|thiol-specific antioxidant 1|thioredoxin peroxidase 1|thioredoxin-dependent peroxide reductase 1|thioredoxin-dependent peroxiredoxin 2|torin', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12796823, end_position_on_the_genomic_accession=12801800, orientation='minus', exon_count=6, OMIM=[600538], no_hdr0=''),
    7003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7003, CurrentID=0, Status='live', Symbol='TEAD1', Aliases=['AA', 'NTEF-1', 'REF1', 'TCF-13', 'TCF13', 'TEAD-1', 'TEF-1'], description='TEA domain transcription factor 1', other_designations='transcriptional enhancer factor TEF-1|TEA domain family member 1 (SV40 transcriptional enhancer factor)|protein GT-IIC|transcription factor 13|transcriptional enhancer factor 1', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=12674421, end_position_on_the_genomic_accession=12944737, orientation='plus', exon_count=13, OMIM=[189967], no_hdr0=''),
    7004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7004, CurrentID=0, Status='live', Symbol='TEAD4', Aliases=['EFTR-2', 'RTEF1', 'TCF13L1', 'TEF-3', 'TEF3', 'TEFR-1', 'hRTEF-1B'], description='TEA domain transcription factor 4', other_designations='transcriptional enhancer factor TEF-3|TEA domain family member 4|related transcription enhancer factor 1B|transcription factor 13-like 1|transcription factor RTEF-1|transcriptional enhancer factor 1-related|transcriptional enhancer factor 3', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2959397, end_position_on_the_genomic_accession=3040676, orientation='plus', exon_count=13, OMIM=[601714], no_hdr0=''),
    7005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7005, CurrentID=0, Status='live', Symbol='TEAD3', Aliases=['DTEF-1', 'ETFR-1', 'TEAD-3', 'TEAD5', 'TEF-5', 'TEF5'], description='TEA domain transcription factor 3', other_designations='transcriptional enhancer factor TEF-5|TEA domain family member 3|TEA domain family member 5|transcriptional enhancer factor 5|transcriptional enhancer factor TEF-5 (DTEF-1)', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35473597, end_position_on_the_genomic_accession=35497079, orientation='minus', exon_count=13, OMIM=[603170], no_hdr0=''),
    7006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7006, CurrentID=0, Status='live', Symbol='TEC', Aliases=['PSCTK4'], description='tec protein tyrosine kinase', other_designations='tyrosine-protein kinase Tec', map_location='4p12-p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48135783, end_position_on_the_genomic_accession=48269864, orientation='minus', exon_count=21, OMIM=[600583], no_hdr0=''),
    7007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7007, CurrentID=0, Status='live', Symbol='TECTA', Aliases=['DFNA12', 'DFNA8', 'DFNB21'], description='tectorin alpha', other_designations='alpha-tectorin', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=121101243, end_position_on_the_genomic_accession=121191490, orientation='plus', exon_count=24, OMIM=[602574], no_hdr0=''),
    7008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7008, CurrentID=0, Status='live', Symbol='TEF', Aliases=[], description='TEF transcription factor, PAR bZIP family member', other_designations='thyrotroph embryonic factor|TEF, PAR bZIP transcription factor|thyrotrophic embryonic factor', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41367455, end_position_on_the_genomic_accession=41399326, orientation='plus', exon_count=5, OMIM=[188595], no_hdr0=''),
    7009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7009, CurrentID=0, Status='live', Symbol='TMBIM6', Aliases=['BAXI1', 'BI-1', 'TEGT'], description='transmembrane BAX inhibitor motif containing 6', other_designations='bax inhibitor 1|testis enhanced gene transcript|testis-enhanced gene transcript protein|transmembrane BAX inhibitor motif-containing protein 6', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49741557, end_position_on_the_genomic_accession=49764934, orientation='plus', exon_count=16, OMIM=[600748], no_hdr0=''),
    7010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7010, CurrentID=0, Status='live', Symbol='TEK', Aliases=['CD202B', 'GLC3E', 'TIE-2', 'TIE2', 'VMCM', 'VMCM1'], description='TEK receptor tyrosine kinase', other_designations='angiopoietin-1 receptor|TEK tyrosine kinase, endothelial|endothelial tyrosine kinase|tunica interna endothelial cell kinase|tyrosine kinase with Ig and EGF homology domains-2|tyrosine-protein kinase receptor TEK|tyrosine-protein kinase receptor TIE-2', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27109141, end_position_on_the_genomic_accession=27230178, orientation='plus', exon_count=23, OMIM=[600221], no_hdr0=''),
    7011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7011, CurrentID=0, Status='live', Symbol='TEP1', Aliases=['TLP1', 'TP1', 'TROVE1', 'VAULT2', 'p240'], description='telomerase associated protein 1', other_designations='telomerase protein component 1|TROVE domain family, member 1|p80 telomerase homolog|telomerase protein 1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20365667, end_position_on_the_genomic_accession=20413540, orientation='minus', exon_count=55, OMIM=[601686], no_hdr0=''),
    7013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7013, CurrentID=0, Status='live', Symbol='TERF1', Aliases=['PIN2', 'TRBF1', 'TRF', 'TRF1', 'hTRF1-AS', 't-TRF1'], description='telomeric repeat binding factor 1', other_designations='telomeric repeat-binding factor 1|NIMA-interacting protein 2|TTAGGG repeat-binding factor 1|telomeric protein Pin2/TRF1|telomeric repeat binding factor (NIMA-interacting) 1', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73008856, end_position_on_the_genomic_accession=73048123, orientation='plus', exon_count=12, OMIM=[600951], no_hdr0=''),
    7014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7014, CurrentID=0, Status='live', Symbol='TERF2', Aliases=['TRBF2', 'TRF2'], description='telomeric repeat binding factor 2', other_designations='telomeric repeat-binding factor 2|TTAGGG repeat-binding factor 2|telomeric DNA-binding protein|telomeric repeat binding protein 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69355567, end_position_on_the_genomic_accession=69386007, orientation='minus', exon_count=11, OMIM=[602027], no_hdr0=''),
    7015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7015, CurrentID=0, Status='live', Symbol='TERT', Aliases=['CMM9', 'DKCA2', 'DKCB4', 'EST2', 'PFBMFT1', 'TCS1', 'TP2', 'TRT', 'hEST2', 'hTRT'], description='telomerase reverse transcriptase', other_designations='telomerase reverse transcriptase|telomerase catalytic subunit|telomerase-associated protein 2', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1253167, end_position_on_the_genomic_accession=1295068, orientation='minus', exon_count=16, OMIM=[187270], no_hdr0=''),
    7016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7016, CurrentID=0, Status='live', Symbol='TESK1', Aliases=[], description='testis associated actin remodelling kinase 1', other_designations='dual specificity testis-specific protein kinase 1|testicular protein kinase 1|testis-specific kinase 1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35605262, end_position_on_the_genomic_accession=35610033, orientation='plus', exon_count=10, OMIM=[601782], no_hdr0=''),
    7018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7018, CurrentID=0, Status='live', Symbol='TF', Aliases=['HEL-S-71p', 'PRO1557', 'PRO2086QTL1', 'TF'], description='transferrin', other_designations='serotransferrin|beta-1 metal-binding globulin|epididymis secretory sperm binding protein Li 71p|siderophilin', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133661998, end_position_on_the_genomic_accession=133796641, orientation='plus', exon_count=24, OMIM=[190000], no_hdr0=''),
    7019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7019, CurrentID=0, Status='live', Symbol='TFAM', Aliases=['MTDPS15', 'MTTF1', 'MTTFA', 'TCF6', 'TCF6L1', 'TCF6L2', 'TCF6L3'], description='transcription factor A, mitochondrial', other_designations='transcription factor A, mitochondrial|mitochondrial transcription factor 1|mitochondrial transcription factor A|transcription factor 6|transcription factor 6-like 1|transcription factor 6-like 2 (mitochondrial transcription factor)|transcription factor 6-like 3', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=58385409, end_position_on_the_genomic_accession=58399220, orientation='plus', exon_count=8, OMIM=[600438], no_hdr0=''),
    7020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7020, CurrentID=0, Status='live', Symbol='TFAP2A', Aliases=['AP-2', 'AP-2alpha', 'AP2TF', 'BOFS', 'TFAP2'], description='transcription factor AP-2 alpha', other_designations='transcription factor AP-2-alpha|AP-2 transcription factor|activating enhancer-binding protein 2-alpha|activator protein 2|transcription factor AP-2 alpha (activating enhancer binding protein 2 alpha)', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10396677, end_position_on_the_genomic_accession=10419897, orientation='minus', exon_count=10, OMIM=[107580], no_hdr0=''),
    7021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7021, CurrentID=0, Status='live', Symbol='TFAP2B', Aliases=['AP-2B', 'AP-2beta', 'AP2-B', 'PDA2'], description='transcription factor AP-2 beta', other_designations='transcription factor AP-2-beta|AP2-beta|activating enhancer binding protein 2 beta', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=50817692, end_position_on_the_genomic_accession=50847619, orientation='plus', exon_count=11, OMIM=[601601], no_hdr0=''),
    7022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7022, CurrentID=0, Status='live', Symbol='TFAP2C', Aliases=['AP2-GAMMA', 'ERF1', 'TFAP2G', 'hAP-2g'], description='transcription factor AP-2 gamma', other_designations='transcription factor AP-2 gamma|activating enhancer-binding protein 2 gamma|estrogen receptor factor 1|transcription factor ERF-1', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56629306, end_position_on_the_genomic_accession=56639283, orientation='plus', exon_count=7, OMIM=[601602], no_hdr0=''),
    7023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7023, CurrentID=0, Status='live', Symbol='TFAP4', Aliases=['AP-4', 'bHLHc41'], description='transcription factor AP-4', other_designations='transcription factor AP-4|activating enhancer-binding protein 4|class C basic helix-loop-helix protein 41|transcription factor AP-4 (activating enhancer binding protein 4)', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4257186, end_position_on_the_genomic_accession=4273023, orientation='minus', exon_count=9, OMIM=[600743], no_hdr0=''),
    7024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7024, CurrentID=0, Status='live', Symbol='TFCP2', Aliases=['LBP1C', 'LSF', 'LSF1D', 'SEFC', 'TFCP2'], description='transcription factor CP2', other_designations='alpha-globin transcription factor CP2|SAA3 enhancer factor', map_location='12q13.12-q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51093656, end_position_on_the_genomic_accession=51173135, orientation='minus', exon_count=15, OMIM=[189889], no_hdr0=''),
    7025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7025, CurrentID=0, Status='live', Symbol='NR2F1', Aliases=['BBOAS', 'BBSOAS', 'COUP-TFI', 'COUPTF1', 'EAR-3', 'EAR3', 'ERBAL3', 'SVP44', 'TCFCOUP1', 'TFCOUP1'], description='nuclear receptor subfamily 2 group F member 1', other_designations='COUP transcription factor 1|COUP transcription factor I|COUP-TF I|COUP-TF1|V-erbA-related protein 3|chicken ovalbumin upstream promoter-transcription factor I|transcription factor COUP 1 (chicken ovalbumin upstream promoter 1, v-erb-a homolog-like 3)', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=93583222, end_position_on_the_genomic_accession=93594613, orientation='plus', exon_count=4, OMIM=[132890], no_hdr0=''),
    7026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7026, CurrentID=0, Status='live', Symbol='NR2F2', Aliases=['ARP-1', 'ARP1', 'CHTD4', 'COUPTF2', 'COUPTFB', 'COUPTFII', 'NF-E3', 'SRXX5', 'SVP40', 'TFCOUP2'], description='nuclear receptor subfamily 2 group F member 2', other_designations='COUP transcription factor 2|ADP-ribosylation factor related protein 1|COUP transcription factor II|apolipoprotein A-I regulatory protein 1|apolipoprotein AI regulatory protein 1|chicken ovalbumin upstream promoter transcription factor 2|chicken ovalbumin upstream promoter-transcription factor I', map_location='15q26.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=96326046, end_position_on_the_genomic_accession=96340263, orientation='plus', exon_count=6, OMIM=[107773], no_hdr0=''),
    7027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7027, CurrentID=0, Status='live', Symbol='TFDP1', Aliases=['DILC', 'DP1', 'DRTF1', 'Dp-1'], description='transcription factor Dp-1', other_designations='transcription factor Dp-1|DRTF1-polypeptide 1|E2F dimerization partner 1|E2F-related transcription factor|down-regulated in liver cancer stem cells', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113584688, end_position_on_the_genomic_accession=113641473, orientation='plus', exon_count=14, OMIM=[189902], no_hdr0=''),
    7029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7029, CurrentID=0, Status='live', Symbol='TFDP2', Aliases=['DP2'], description='transcription factor Dp-2', other_designations='transcription factor Dp-2|transcription factor Dp-2 (E2F dimerization partner 2)', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141944428, end_position_on_the_genomic_accession=142149544, orientation='minus', exon_count=18, OMIM=[602160], no_hdr0=''),
    7030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7030, CurrentID=0, Status='live', Symbol='TFE3', Aliases=['RCCP2', 'RCCX1', 'TFEA', 'bHLHe33'], description='transcription factor binding to IGHM enhancer 3', other_designations='transcription factor E3|class E basic helix-loop-helix protein 33|transcription factor E family, member A|transcription factor for IgH enhancer|transcription factor for immunoglobulin heavy-chain enhancer 3', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49028726, end_position_on_the_genomic_accession=49043357, orientation='minus', exon_count=11, OMIM=[314310], no_hdr0=''),
    7031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7031, CurrentID=0, Status='live', Symbol='TFF1', Aliases=['BCEI', 'D21S21', 'HP1.A', 'HPS2', 'pNR-2', 'pS2'], description='trefoil factor 1', other_designations='trefoil factor 1|breast cancer estrogen-inducible protein|breast cancer estrogen-inducible sequence|gastrointestinal trefoil protein pS2|polypeptide P1.A|protein pS2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42362282, end_position_on_the_genomic_accession=42366535, orientation='minus', exon_count=3, OMIM=[113710], no_hdr0=''),
    7032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7032, CurrentID=0, Status='live', Symbol='TFF2', Aliases=['SML1', 'SP'], description='trefoil factor 2', other_designations='trefoil factor 2|spasmolysin|spasmolytic polypeptide|spasmolytic protein 1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42346357, end_position_on_the_genomic_accession=42350994, orientation='minus', exon_count=4, OMIM=[182590], no_hdr0=''),
    7033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7033, CurrentID=0, Status='live', Symbol='TFF3', Aliases=['ITF', 'P1B', 'TFI'], description='trefoil factor 3', other_designations='trefoil factor 3|polypeptide P1.B|trefoil factor 3 (intestinal)', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42311667, end_position_on_the_genomic_accession=42315409, orientation='minus', exon_count=3, OMIM=[600633], no_hdr0=''),
    7035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7035, CurrentID=0, Status='live', Symbol='TFPI', Aliases=['EPI', 'LACI', 'TFI1', 'TFPI'], description='tissue factor pathway inhibitor', other_designations='tissue factor pathway inhibitor|anti-convertin|extrinsic pathway inhibitor|tissue factor pathway inhibitor (lipoprotein-associated coagulation inhibitor)', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=187464230, end_position_on_the_genomic_accession=187554501, orientation='minus', exon_count=13, OMIM=[152310], no_hdr0=''),
    7036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7036, CurrentID=0, Status='live', Symbol='TFR2', Aliases=['HFE3', 'TFRC2'], description='transferrin receptor 2', other_designations='transferrin receptor protein 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100620420, end_position_on_the_genomic_accession=100641552, orientation='minus', exon_count=18, OMIM=[604720], no_hdr0=''),
    7037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7037, CurrentID=0, Status='live', Symbol='TFRC', Aliases=['CD71', 'IMD46', 'T9', 'TFR', 'TFR1', 'TR', 'TRFR', 'p90'], description='transferrin receptor', other_designations='transferrin receptor protein 1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196018694, end_position_on_the_genomic_accession=196082123, orientation='minus', exon_count=24, OMIM=[190010], no_hdr0=''),
    7038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7038, CurrentID=0, Status='live', Symbol='TG', Aliases=['AITD3N', 'TG'], description='thyroglobulin', other_designations='thyroglobulin', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132866943, end_position_on_the_genomic_accession=133134902, orientation='plus', exon_count=52, OMIM=[188450], no_hdr0=''),
    7039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7039, CurrentID=0, Status='live', Symbol='TGFA', Aliases=['TFGA'], description='transforming growth factor alpha', other_designations='protransforming growth factor alpha|TGF-alpha', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70447284, end_position_on_the_genomic_accession=70553826, orientation='minus', exon_count=7, OMIM=[190170], no_hdr0=''),
    7040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7040, CurrentID=0, Status='live', Symbol='TGFB1', Aliases=['CED', 'DPD1', 'IBDIMDE', 'LAP', 'TGF-beta1', 'TGFB', 'TGFbeta'], description='transforming growth factor beta 1', other_designations='transforming growth factor beta-1 proprotein|TGF-beta-1|latency-associated peptide|prepro-transforming growth factor beta-1|transforming growth factor beta1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41330323, end_position_on_the_genomic_accession=41353922, orientation='minus', exon_count=7, OMIM=[190180], no_hdr0=''),
    7041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7041, CurrentID=0, Status='live', Symbol='TGFB1I1', Aliases=['ARA55', 'HIC-5', 'HIC5', 'TSC-5'], description='transforming growth factor beta 1 induced transcript 1', other_designations='transforming growth factor beta-1-induced transcript 1 protein|androgen receptor coactivator 55 kDa protein|androgen receptor coactivator ARA55|androgen receptor-associated protein of 55 kDa|hydrogen peroxide-inducible clone 5 protein|hydrogen peroxide-inducible clone-5', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31472152, end_position_on_the_genomic_accession=31477960, orientation='plus', exon_count=14, OMIM=[602353], no_hdr0=''),
    7042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7042, CurrentID=0, Status='live', Symbol='TGFB2', Aliases=['G-TSF', 'LDS4', 'TGF-beta2'], description='transforming growth factor beta 2', other_designations='transforming growth factor beta-2 proprotein|BSC-1 cell growth inhibitor|cetermin|glioblastoma-derived T-cell suppressor factor|polyergin|prepro-transforming growth factor beta-2', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=218345336, end_position_on_the_genomic_accession=218444619, orientation='plus', exon_count=8, OMIM=[190220], no_hdr0=''),
    7043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7043, CurrentID=0, Status='live', Symbol='TGFB3', Aliases=['ARVD', 'ARVD1', 'LDS5', 'RNHF', 'TGF-beta3'], description='transforming growth factor beta 3', other_designations='transforming growth factor beta-3 proprotein|prepro-transforming growth factor beta-3', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75958097, end_position_on_the_genomic_accession=75983011, orientation='minus', exon_count=8, OMIM=[190230], no_hdr0=''),
    7044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7044, CurrentID=0, Status='live', Symbol='LEFTY2', Aliases=['EBAF', 'LEFTA', 'LEFTYA', 'TGFB4'], description='left-right determination factor 2', other_designations='left-right determination factor 2|TGF-beta-4|endometrial bleeding-associated factor|left-right determination factor A|protein lefty-2|protein lefty-A|transforming growth factor beta-4', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225936603, end_position_on_the_genomic_accession=225941367, orientation='minus', exon_count=6, OMIM=[601877], no_hdr0=''),
    7045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7045, CurrentID=0, Status='live', Symbol='TGFBI', Aliases=['BIGH3', 'CDB1', 'CDG2', 'CDGG1', 'CSD', 'CSD1', 'CSD2', 'CSD3', 'EBMD', 'LCD1'], description='transforming growth factor beta induced', other_designations='transforming growth factor-beta-induced protein ig-h3|RGD-CAP|RGD-containing collagen-associated protein|beta ig-h3|betaig-h3|kerato-epithelin|transforming growth factor beta-induced 68kDa|transforming growth factor, beta-induced, 68kD', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=136028988, end_position_on_the_genomic_accession=136063818, orientation='plus', exon_count=17, OMIM=[601692], no_hdr0=''),
    7046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7046, CurrentID=0, Status='live', Symbol='TGFBR1', Aliases=['AAT5', 'ACVRLK4', 'ALK-5', 'ALK5', 'ESS1', 'LDS1', 'LDS1A', 'LDS2A', 'MSSE', 'SKR4', 'TBR-i', 'TBRI', 'TGFR-1', 'tbetaR-I'], description='transforming growth factor beta receptor 1', other_designations='TGF-beta receptor type-1|activin A receptor type II-like kinase, 53kDa|activin A receptor type II-like protein kinase of 53kD|activin receptor-like kinase 5|mutant transforming growth factor beta receptor I|serine/threonine-protein kinase receptor R4|transforming growth factor beta receptor I|transforming growth factor-beta receptor type I', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99104038, end_position_on_the_genomic_accession=99154192, orientation='plus', exon_count=11, OMIM=[190181], no_hdr0=''),
    7047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7047, CurrentID=0, Status='live', Symbol='TGM4', Aliases=['TGP', 'hTGP'], description='transglutaminase 4', other_designations='protein-glutamine gamma-glutamyltransferase 4|TG(P)|TGase P|TGase-4|fibrinoligase|prostate transglutaminase|prostate-specific transglutaminase|transglutaminase 4 (prostate)|transglutaminase P', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44874608, end_position_on_the_genomic_accession=44914990, orientation='plus', exon_count=15, OMIM=[600585], no_hdr0=''),
    7048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7048, CurrentID=0, Status='live', Symbol='TGFBR2', Aliases=['AAT3', 'FAA3', 'LDS1B', 'LDS2', 'LDS2B', 'MFS2', 'RIIC', 'TAAD2', 'TBR-ii', 'TBRII', 'TGFR-2', 'TGFbeta-RII'], description='transforming growth factor beta receptor 2', other_designations='TGF-beta receptor type-2|TGF-beta receptor type IIB|TGF-beta type II receptor|tbetaR-II|transforming growth factor beta receptor II|transforming growth factor beta receptor type IIC|transforming growth factor, beta receptor II (70/80kDa)|transforming growth factor, beta receptor II alpha|transforming growth factor, beta receptor II beta|transforming growth factor, beta receptor II delta|transforming growth factor, beta receptor II epsilon|transforming growth factor, beta receptor II gamma', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=30606472, end_position_on_the_genomic_accession=30694142, orientation='plus', exon_count=11, OMIM=[190182], no_hdr0=''),
    7049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7049, CurrentID=0, Status='live', Symbol='TGFBR3', Aliases=['BGCAN', 'betaglycan'], description='transforming growth factor beta receptor 3', other_designations='transforming growth factor beta receptor type 3|TGF-beta receptor type 3|TGF-beta receptor type III|TGFR-3|betaglycan proteoglycan|transforming growth factor beta receptor III', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=91680343, end_position_on_the_genomic_accession=91906002, orientation='minus', exon_count=20, OMIM=[600742], no_hdr0=''),
    7050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7050, CurrentID=0, Status='live', Symbol='TGIF1', Aliases=['HPE4', 'TGIF'], description='TGFB induced factor homeobox 1', other_designations="homeobox protein TGIF1|5'-TG-3'-interacting factor 1|TALE homeobox TG-interacting factor|transforming growth factor-beta-induced factor", map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=3412009, end_position_on_the_genomic_accession=3459978, orientation='plus', exon_count=12, OMIM=[602630], no_hdr0=''),
    7051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7051, CurrentID=0, Status='live', Symbol='TGM1', Aliases=['ARCI1', 'ICR2', 'KTG', 'LI', 'LI1', 'TGASE', 'TGK'], description='transglutaminase 1', other_designations='protein-glutamine gamma-glutamyltransferase K|K polypeptide epidermal type I, protein-glutamine-gamma-glutamyltransferase|TG(K)|TGase K|TGase-1|epidermal TGase|transglutaminase K|transglutaminase, keratinocyte', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24249114, end_position_on_the_genomic_accession=24263177, orientation='minus', exon_count=15, OMIM=[190195], no_hdr0=''),
    7052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7052, CurrentID=0, Status='live', Symbol='TGM2', Aliases=['G(h)', 'TG(C)', 'TGC', 'hTG2', 'tTG'], description='transglutaminase 2', other_designations='protein-glutamine gamma-glutamyltransferase 2|C polypeptide, protein-glutamine-gamma-glutamyltransferase|TGase C|TGase H|TGase II|TGase-2|erythrocyte transglutaminase|heart G alpha(h)|hhG alpha(h)|isopeptidase TGM2|protein G alpha(h)|protein-glutamine deamidase TGM2|protein-glutamine dopaminyltransferase TGM2|protein-glutamine histaminyltransferase TGM2|protein-glutamine noradrenalinyltransferase TGM2|protein-glutamine serotonyltransferase TGM2|tTgase|tissue transglutaminase|transglutaminase C|transglutaminase H|transglutaminase II', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38127385, end_position_on_the_genomic_accession=38166508, orientation='minus', exon_count=14, OMIM=[190196], no_hdr0=''),
    7053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7053, CurrentID=0, Status='live', Symbol='TGM3', Aliases=['TGE', 'UHS2'], description='transglutaminase 3', other_designations='protein-glutamine gamma-glutamyltransferase E|E polypeptide, protein-glutamine-gamma-glutamyltransferase|TG(E)|TGase E|TGase-3|transglutaminase E', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2296001, end_position_on_the_genomic_accession=2341079, orientation='plus', exon_count=13, OMIM=[600238], no_hdr0=''),
    7054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7054, CurrentID=0, Status='live', Symbol='TH', Aliases=['DYT14', 'DYT5b', 'TYH'], description='tyrosine hydroxylase', other_designations='tyrosine 3-monooxygenase|dystonia 14|tyrosine 3-hydroxylase', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2163929, end_position_on_the_genomic_accession=2174081, orientation='minus', exon_count=14, OMIM=[191290], no_hdr0=''),
    7056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7056, CurrentID=0, Status='live', Symbol='THBD', Aliases=['AHUS6', 'BDCA-3', 'BDCA3', 'CD141', 'THPH12', 'THRM', 'TM'], description='thrombomodulin', other_designations='thrombomodulin|CD141 antigen|fetomodulin', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23045633, end_position_on_the_genomic_accession=23049672, orientation='minus', exon_count=1, OMIM=[188040], no_hdr0=''),
    7057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7057, CurrentID=0, Status='live', Symbol='THBS1', Aliases=['THBS', 'THBS-1', 'TSP', 'TSP-1', 'TSP1'], description='thrombospondin 1', other_designations='thrombospondin-1|glycoprotein G|thrombospondin-1p180|thrombospondin-p50', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=39581079, end_position_on_the_genomic_accession=39599466, orientation='plus', exon_count=22, OMIM=[188060], no_hdr0=''),
    7058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7058, CurrentID=0, Status='live', Symbol='THBS2', Aliases=['TSP2'], description='thrombospondin 2', other_designations='thrombospondin-2', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169215785, end_position_on_the_genomic_accession=169253846, orientation='minus', exon_count=23, OMIM=[188061], no_hdr0=''),
    7059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7059, CurrentID=0, Status='live', Symbol='THBS3', Aliases=['TSP3'], description='thrombospondin 3', other_designations='thrombospondin-3', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155195588, end_position_on_the_genomic_accession=155209180, orientation='minus', exon_count=25, OMIM=[188062], no_hdr0=''),
    7060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7060, CurrentID=0, Status='live', Symbol='THBS4', Aliases=['TSP-4', 'TSP4'], description='thrombospondin 4', other_designations='thrombospondin-4', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79991332, end_position_on_the_genomic_accession=80083753, orientation='plus', exon_count=27, OMIM=[600715], no_hdr0=''),
    7062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7062, CurrentID=0, Status='live', Symbol='TCHH', Aliases=['THH', 'THL', 'TRHY', 'UHS3'], description='trichohyalin', other_designations='trichohyalin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152106317, end_position_on_the_genomic_accession=152115444, orientation='minus', exon_count=3, OMIM=[190370], no_hdr0=''),
    7064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7064, CurrentID=0, Status='live', Symbol='THOP1', Aliases=['EP24.15', 'MEPD_HUMAN', 'MP78', 'TOP'], description='thimet oligopeptidase 1', other_designations='thimet oligopeptidase|endopeptidase 24.15', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2785466, end_position_on_the_genomic_accession=2815807, orientation='plus', exon_count=15, OMIM=[601117], no_hdr0=''),
    7066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7066, CurrentID=0, Status='live', Symbol='THPO', Aliases=['MGDF', 'MKCSF', 'ML', 'MPLLG', 'THCYT1', 'TPO'], description='thrombopoietin', other_designations='thrombopoietin|MPL ligand|c-mpl ligand|megakaryocyte colony-stimulating factor|megakaryocyte growth and development factor|megakaryocyte stimulating factor|myeloproliferative leukemia virus oncogene ligand|prepro-thrombopoietin', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184371935, end_position_on_the_genomic_accession=184379688, orientation='minus', exon_count=7, OMIM=[600044], no_hdr0=''),
    7067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7067, CurrentID=0, Status='live', Symbol='THRA', Aliases=['AR7', 'CHNG6', 'EAR7', 'ERB-T-1', 'ERBA', 'ERBA1', 'NR1A11', 'THRA2', 'TRalpha', 'c-ERBA-1', 'THRA'], description='thyroid hormone receptor alpha', other_designations='thyroid hormone receptor alpha|EAR-7|ERBA-related 7|V-erbA-related protein 7|c-erbA-alpha|nuclear receptor subfamily 1 group A member 1|thyroid hormone receptor alpha 1|thyroid hormone receptor, alpha (erythroblastic leukemia viral (v-erb-a) oncogene homolog, avian)|thyroid normone nuclear receptor alpha variant 1|triiodothyronine receptor', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40062193, end_position_on_the_genomic_accession=40093867, orientation='plus', exon_count=11, OMIM=[190120], no_hdr0=''),
    7068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7068, CurrentID=0, Status='live', Symbol='THRB', Aliases=['C-ERBA-2', 'C-ERBA-BETA', 'ERBA2', 'GRTH', 'NR1A2', 'PRTH', 'THR11', 'THRB2', 'TRbeta', 'THRB'], description='thyroid hormone receptor beta', other_designations='thyroid hormone receptor beta|nuclear receptor subfamily 1 group A member 2|oncogene ERBA2|thyroid hormone nuclear receptor beta variant 1|thyroid hormone receptor, beta (erythroblastic leukemia viral (v-erb-a) oncogene homolog 2, avian)', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=24117153, end_position_on_the_genomic_accession=24495708, orientation='minus', exon_count=18, OMIM=[190160], no_hdr0=''),
    7069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7069, CurrentID=0, Status='live', Symbol='THRSP', Aliases=['LPGP1', 'Lpgp', 'S14', 'SPOT14', 'THRP'], description='thyroid hormone responsive', other_designations='thyroid hormone-inducible hepatic protein|SPOT14 homolog|lipogenic protein 1|spot 14 protein|thyroid hormone responsive (SPOT14 homolog, rat)', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78063861, end_position_on_the_genomic_accession=78068351, orientation='plus', exon_count=2, OMIM=[601926], no_hdr0=''),
    7070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7070, CurrentID=0, Status='live', Symbol='THY1', Aliases=['CD90', 'CDw90'], description='Thy-1 cell surface antigen', other_designations='thy-1 membrane glycoprotein|Thy-1 T-cell antigen|thy-1 antigen', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119415476, end_position_on_the_genomic_accession=119424985, orientation='minus', exon_count=7, OMIM=[188230], no_hdr0=''),
    7071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7071, CurrentID=0, Status='live', Symbol='KLF10', Aliases=['EGR-alpha', 'EGRA', 'TIEG', 'TIEG1'], description='Kruppel like factor 10', other_designations='Krueppel-like factor 10|TGFB-inducible early growth response protein 1|early growth response-alpha|transforming growth factor-beta-inducible early growth response protein 1|zinc finger transcription factor TIEG', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=102648784, end_position_on_the_genomic_accession=102655725, orientation='minus', exon_count=5, OMIM=[601878], no_hdr0=''),
    7072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7072, CurrentID=0, Status='live', Symbol='TIA1', Aliases=['ALS26', 'TIA-1', 'WDM'], description='TIA1 cytotoxic granule associated RNA binding protein', other_designations='nucleolysin TIA-1 isoform p40|nucleolysin TIA-1|T-cell-restricted intracellular antigen-1|p40-TIA-1 (containing p15-TIA-1)', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70209444, end_position_on_the_genomic_accession=70248793, orientation='minus', exon_count=18, OMIM=[603518], no_hdr0=''),
    7073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7073, CurrentID=0, Status='live', Symbol='TIAL1', Aliases=['TCBP', 'TIAR'], description='TIA1 cytotoxic granule associated RNA binding protein like 1', other_designations='nucleolysin TIAR|T-cluster binding protein|TIA-1-related nucleolysin|TIA1 related|aging-associated gene 7 protein', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119573465, end_position_on_the_genomic_accession=119598841, orientation='minus', exon_count=16, OMIM=[603413], no_hdr0=''),
    7074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7074, CurrentID=0, Status='live', Symbol='TIAM1', Aliases=['TIAM-1'], description='TIAM Rac1 associated GEF 1', other_designations='rho guanine nucleotide exchange factor TIAM1|T-lymphoma invasion and metastasis-inducing protein 1|T cell lymphoma invasion and metastasis 1|human T-lymphoma invasion and metastasis inducing TIAM1 protein', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=31118418, end_position_on_the_genomic_accession=31559977, orientation='minus', exon_count=37, OMIM=[600687], no_hdr0=''),
    7075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7075, CurrentID=0, Status='live', Symbol='TIE1', Aliases=['JTK14', 'LMPHM11', 'TIE'], description='tyrosine kinase with immunoglobulin like and EGF like domains 1', other_designations='tyrosine-protein kinase receptor Tie-1|tyrosine kinase with immunoglobulin and epidermal growth factor homology domains 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43300954, end_position_on_the_genomic_accession=43323108, orientation='plus', exon_count=24, OMIM=[600222], no_hdr0=''),
    7076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7076, CurrentID=0, Status='live', Symbol='TIMP1', Aliases=['CLGI', 'EPA', 'EPO', 'HCI', 'TIMP', 'TIMP-1'], description='TIMP metallopeptidase inhibitor 1', other_designations='metalloproteinase inhibitor 1|collagenase inhibitor|epididymis secretory sperm binding protein|erythroid potentiating activity|fibroblast collagenase inhibitor|tissue inhibitor of metalloproteinases 1', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47582408, end_position_on_the_genomic_accession=47586789, orientation='plus', exon_count=5, OMIM=[305370], no_hdr0=''),
    7077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7077, CurrentID=0, Status='live', Symbol='TIMP2', Aliases=['CSC-21K', 'DDC8'], description='TIMP metallopeptidase inhibitor 2', other_designations='metalloproteinase inhibitor 2|testicular secretory protein Li 57|tissue inhibitor of metalloproteinases 2', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78852977, end_position_on_the_genomic_accession=78925387, orientation='minus', exon_count=5, OMIM=[188825], no_hdr0=''),
    7078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7078, CurrentID=0, Status='live', Symbol='TIMP3', Aliases=['HSMRK222', 'K222', 'K222TA2', 'SFD'], description='TIMP metallopeptidase inhibitor 3', other_designations='metalloproteinase inhibitor 3|MIG-5 protein|TIMP-3|protein MIG-5|tissue inhibitor of metalloproteinases 3', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32801705, end_position_on_the_genomic_accession=32863041, orientation='plus', exon_count=5, OMIM=[188826], no_hdr0=''),
    7079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7079, CurrentID=0, Status='live', Symbol='TIMP4', Aliases=['TIMP-4'], description='TIMP metallopeptidase inhibitor 4', other_designations='metalloproteinase inhibitor 4|tissue inhibitor of metalloproteinase 4|tissue inhibitor of metalloproteinases 4', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12153068, end_position_on_the_genomic_accession=12158912, orientation='minus', exon_count=5, OMIM=[601915], no_hdr0=''),
    7080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7080, CurrentID=0, Status='live', Symbol='NKX2-1', Aliases=['BCH', 'BHC', 'NK-2', 'NKX2.1', 'NKX2A', 'NMTC1', 'T/EBP', 'TEBP', 'TITF1', 'TTF-1', 'TTF1'], description='NK2 homeobox 1', other_designations='homeobox protein Nkx-2.1|NK-2 homolog A|homeobox protein NK-2 homolog A|thyroid nuclear factor 1|thyroid transcription factor 1|thyroid-specific enhancer-binding protein', map_location='14q13.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=36516397, end_position_on_the_genomic_accession=36520232, orientation='minus', exon_count=3, OMIM=[600635], no_hdr0=''),
    7082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7082, CurrentID=0, Status='live', Symbol='TJP1', Aliases=['ZO-1'], description='tight junction protein 1', other_designations='tight junction protein ZO-1|zona occludens 1|zonula occludens 1 protein', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=29699367, end_position_on_the_genomic_accession=29969049, orientation='minus', exon_count=33, OMIM=[601009], no_hdr0=''),
    7083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7083, CurrentID=0, Status='live', Symbol='TK1', Aliases=['TK2'], description='thymidine kinase 1', other_designations='thymidine kinase, cytosolic|cytosolic thymidine kinase|epididymis secretory sperm binding protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78174079, end_position_on_the_genomic_accession=78187204, orientation='minus', exon_count=6, OMIM=[188300], no_hdr0=''),
    7084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7084, CurrentID=0, Status='live', Symbol='TK2', Aliases=['MTDPS2', 'MTTK', 'PEOB3', 'SCA31'], description='thymidine kinase 2', other_designations='thymidine kinase 2, mitochondrial|thymidine kinase 2|mitochondrial thymidine kinase|mt-TK', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66508003, end_position_on_the_genomic_accession=66550291, orientation='minus', exon_count=11, OMIM=[188250], no_hdr0=''),
    7086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7086, CurrentID=0, Status='live', Symbol='TKT', Aliases=['HEL-S-48', 'HEL107', 'SDDHD', 'TK1', 'TKT'], description='transketolase', other_designations='transketolase|epididymis luminal protein 107|epididymis secretory protein Li 48', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53224712, end_position_on_the_genomic_accession=53256052, orientation='minus', exon_count=15, OMIM=[606781], no_hdr0=''),
    7087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7087, CurrentID=0, Status='live', Symbol='ICAM5', Aliases=['TLCN', 'TLN'], description='intercellular adhesion molecule 5', other_designations='intercellular adhesion molecule 5|ICAM-5|intercellular adhesion molecule 5, telencephalin|telencephalin', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10289351, end_position_on_the_genomic_accession=10296778, orientation='plus', exon_count=11, OMIM=[601852], no_hdr0=''),
    7088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7088, CurrentID=0, Status='live', Symbol='TLE1', Aliases=['ESG', 'ESG1', 'GRG1'], description='TLE family member 1, transcriptional corepressor', other_designations='transducin-like enhancer protein 1|enhancer of split groucho-like protein 1|transducin like enhancer of split 1|transducin-like enhancer of split 1 (E(sp1) homolog, Drosophila)', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=81583683, end_position_on_the_genomic_accession=81689547, orientation='minus', exon_count=22, OMIM=[600189], no_hdr0=''),
    7089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7089, CurrentID=0, Status='live', Symbol='TLE2', Aliases=['ESG', 'ESG2', 'GRG2'], description='TLE family member 2, transcriptional corepressor', other_designations='transducin-like enhancer protein 2|enhancer of split groucho-like protein 2|transducin like enhancer of split 2|transducin-like enhancer of split 2 (E(sp1) homolog, Drosophila)|transducin-like enhancer of split 2, homolog of Drosophila E(sp1)', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2997638, end_position_on_the_genomic_accession=3047635, orientation='minus', exon_count=23, OMIM=[601041], no_hdr0=''),
    7090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7090, CurrentID=0, Status='live', Symbol='TLE3', Aliases=['ESG', 'ESG3', 'GRG3', 'HsT18976'], description='TLE family member 3, transcriptional corepressor', other_designations='transducin-like enhancer protein 3|enhancer of split groucho 3|enhancer of split groucho-like protein 3|transducin like enhancer of split 3|transducin-like enhancer of split 3 (E(sp1) homolog, Drosophila)|transducin-like enhancer of split 3, homolog of Drosophila E(sp1)', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=70047790, end_position_on_the_genomic_accession=70098171, orientation='minus', exon_count=23, OMIM=[600190], no_hdr0=''),
    7091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7091, CurrentID=0, Status='live', Symbol='TLE4', Aliases=['BCE-1', 'BCE1', 'E(spI)', 'E(spl)', 'ESG', 'ESG4', 'GRG4', 'Grg-4'], description='TLE family member 4, transcriptional corepressor', other_designations='transducin-like enhancer protein 4|B lymphocyte gene 1|enhancer of split groucho 4|groucho-related protein 4|transducin like enhancer of split 4|transducin-like enhancer of split 4 (E(sp1) homolog, Drosophila)|transducin-like enhancer of split 4, homolog of Drosophila E(sp1)', map_location='9q21.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=79571965, end_position_on_the_genomic_accession=79726882, orientation='plus', exon_count=28, OMIM=[605132], no_hdr0=''),
    7092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7092, CurrentID=0, Status='live', Symbol='TLL1', Aliases=['ASD6', 'TLL'], description='tolloid like 1', other_designations='tolloid-like protein 1', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165873124, end_position_on_the_genomic_accession=166105178, orientation='plus', exon_count=25, OMIM=[606742], no_hdr0=''),
    7093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7093, CurrentID=0, Status='live', Symbol='TLL2', Aliases=[], description='tolloid like 2', other_designations='tolloid-like protein 2', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96364608, end_position_on_the_genomic_accession=96513926, orientation='minus', exon_count=21, OMIM=[606743], no_hdr0=''),
    7094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7094, CurrentID=0, Status='live', Symbol='TLN1', Aliases=['ILWEQ', 'TLN', 'talin-1'], description='talin 1', other_designations='talin-1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35696948, end_position_on_the_genomic_accession=35732195, orientation='minus', exon_count=57, OMIM=[186745], no_hdr0=''),
    7095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7095, CurrentID=0, Status='live', Symbol='SEC62', Aliases=['Dtrp1', 'HTP1', 'TLOC1', 'TP-1'], description='SEC62 homolog, preprotein translocation factor', other_designations='translocation protein SEC62|SEC62 preprotein translocation factor|hTP-1|membrane protein SEC62, S.cerevisiae, homolog of|translocation protein 1', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169966136, end_position_on_the_genomic_accession=169998373, orientation='plus', exon_count=9, OMIM=[602173], no_hdr0=''),
    7096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7096, CurrentID=0, Status='live', Symbol='TLR1', Aliases=['CD281', 'TIL', 'TIL. LPRS5', 'rsc786'], description='toll like receptor 1', other_designations='toll-like receptor 1|toll/interleukin-1 receptor-like protein', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38791055, end_position_on_the_genomic_accession=38806262, orientation='minus', exon_count=7, OMIM=[601194], no_hdr0=''),
    7097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7097, CurrentID=0, Status='live', Symbol='TLR2', Aliases=['CD282', 'TIL4'], description='toll like receptor 2', other_designations='toll-like receptor 2|toll/interleukin-1 receptor-like protein 4', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153684080, end_position_on_the_genomic_accession=153710643, orientation='plus', exon_count=5, OMIM=[603028], no_hdr0=''),
    7098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7098, CurrentID=0, Status='live', Symbol='TLR3', Aliases=['CD283', 'IIAE2', 'IMD83'], description='toll like receptor 3', other_designations='toll-like receptor 3', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186069156, end_position_on_the_genomic_accession=186088073, orientation='plus', exon_count=5, OMIM=[603029], no_hdr0=''),
    7099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7099, CurrentID=0, Status='live', Symbol='TLR4', Aliases=['ARMD10', 'CD284', 'TLR-4', 'TOLL'], description='toll like receptor 4', other_designations='toll-like receptor 4|hToll|homolog of Drosophila toll|toll like receptor 4 protein', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=117704403, end_position_on_the_genomic_accession=117724735, orientation='plus', exon_count=4, OMIM=[603030], no_hdr0=''),
    7100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7100, CurrentID=0, Status='live', Symbol='TLR5', Aliases=['MELIOS', 'SLE1', 'SLEB1', 'TIL3'], description='toll like receptor 5', other_designations='toll-like receptor 5|systemic lupus erythematosus susceptibility 1|toll/interleukin-1 receptor-like protein 3', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223108401, end_position_on_the_genomic_accession=223143281, orientation='minus', exon_count=7, OMIM=[603031], no_hdr0=''),
    7101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7101, CurrentID=0, Status='live', Symbol='NR2E1', Aliases=['TLL', 'TLX', 'XTLL'], description='nuclear receptor subfamily 2 group E member 1', other_designations='nuclear receptor subfamily 2 group E member 1|nuclear receptor TLX|protein tailless homolog|tailes-related receptor|tailless', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108166022, end_position_on_the_genomic_accession=108188809, orientation='plus', exon_count=10, OMIM=[603849], no_hdr0=''),
    7102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7102, CurrentID=0, Status='live', Symbol='TSPAN7', Aliases=['A15', 'CCG-B7', 'CD231', 'DXS1692E', 'MRX58', 'MXS1', 'TALLA-1', 'TM4SF2', 'TM4SF2b'], description='tetraspanin 7', other_designations='tetraspanin-7|CD231 antigen|T-cell acute lymphoblastic leukemia associated antigen 1|cell surface glycoprotein A15|membrane component chromosome X surface marker 1|membrane component, X chromosome, surface marker 1|tetraspanin protein|transmembrane 4 superfamily 2b|transmembrane 4 superfamily member 2|transmembrane protein A15|tspan-7', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=38561542, end_position_on_the_genomic_accession=38688918, orientation='plus', exon_count=8, OMIM=[300096], no_hdr0=''),
    7103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7103, CurrentID=0, Status='live', Symbol='TSPAN8', Aliases=['CO-029', 'TM4SF3'], description='tetraspanin 8', other_designations='tetraspanin-8|transmembrane 4 superfamily member 3|tspan-8|tumor-associated antigen CO-029', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71125093, end_position_on_the_genomic_accession=71157999, orientation='minus', exon_count=10, OMIM=[600769], no_hdr0=''),
    7104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7104, CurrentID=0, Status='live', Symbol='TM4SF4', Aliases=['ILTMP', 'il-TMP'], description='transmembrane 4 L six family member 4', other_designations='transmembrane 4 L6 family member 4|intestinal and liver (il) tetraspan membrane protein|intestine and liver tetraspan membrane protein|transmembrane 4 superfamily member 4', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149474697, end_position_on_the_genomic_accession=149503394, orientation='plus', exon_count=5, OMIM=[606567], no_hdr0=''),
    7105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7105, CurrentID=0, Status='live', Symbol='TSPAN6', Aliases=['T245', 'TM4SF6', 'TSPAN-6'], description='tetraspanin 6', other_designations='tetraspanin-6|A15 homolog|putative NF-kappa-B-activating protein 321|tetraspan TM4SF|tetraspanin TM4-D|transmembrane 4 superfamily member 6', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100627108, end_position_on_the_genomic_accession=100637104, orientation='minus', exon_count=9, OMIM=[300191], no_hdr0=''),
    7106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7106, CurrentID=0, Status='live', Symbol='TSPAN4', Aliases=['NAG-2', 'NAG2', 'TETRASPAN', 'TM4SF7', 'TSPAN-4'], description='tetraspanin 4', other_designations='tetraspanin-4|novel antigen 2|tetraspan TM4SF|transmembrane 4 superfamily member 7', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=842852, end_position_on_the_genomic_accession=867116, orientation='plus', exon_count=13, OMIM=[602644], no_hdr0=''),
    7107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7107, CurrentID=0, Status='live', Symbol='GPR137B', Aliases=['TM7SF1'], description='G protein-coupled receptor 137B', other_designations='integral membrane protein GPR137B|transmembrane 7 superfamily member 1 (upregulated in kidney)|transmembrane 7 superfamily member 1 protein', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236142529, end_position_on_the_genomic_accession=236213535, orientation='plus', exon_count=7, OMIM=[604658], no_hdr0=''),
    7108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7108, CurrentID=0, Status='live', Symbol='TM7SF2', Aliases=['ANG1', 'C14SR', 'DHCR14A', 'NET47'], description='transmembrane 7 superfamily member 2', other_designations='delta(14)-sterol reductase TM7SF2|3-beta-hydroxysterol Delta (14)-reductase|C-14 sterol reductase|another new gene 1 protein|delta-14-SR|putative sterol reductase SR-1|sterol C14-reductase', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65111872, end_position_on_the_genomic_accession=65116230, orientation='plus', exon_count=10, OMIM=[603414], no_hdr0=''),
    7109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7109, CurrentID=0, Status='live', Symbol='TRAPPC10', Aliases=['EHOC-1', 'EHOC1', 'GT334', 'TMEM1', 'TRS130', 'TRS30'], description='trafficking protein particle complex subunit 10', other_designations='trafficking protein particle complex subunit 10|TRAPP 130 kDa subunit|TRAPP subunit TMEM1|epilepsy holoprosencephaly candidate-1 protein|trafficking protein particle complex 10|trafficking protein particle complex subunit 130|trafficking protein particle complex subunit TMEM1|transmembrane protein 1|transport protein particle subunit TMEM1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44012309, end_position_on_the_genomic_accession=44106552, orientation='plus', exon_count=28, OMIM=[602103], no_hdr0=''),
    7110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7110, CurrentID=0, Status='live', Symbol='TMF1', Aliases=['ARA160', 'TMF'], description='TATA element modulatory factor 1', other_designations='TATA element modulatory factor|androgen receptor coactivator 160 kDa protein|androgen receptor-associated protein of 160 kDa', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69019827, end_position_on_the_genomic_accession=69052333, orientation='minus', exon_count=17, OMIM=[601126], no_hdr0=''),
    7111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7111, CurrentID=0, Status='live', Symbol='TMOD1', Aliases=['D9S57E', 'ETMOD', 'TMOD'], description='tropomodulin 1', other_designations='tropomodulin-1|E-Tmod|e-tropomodulin|erythrocyte tropomodulin', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97501180, end_position_on_the_genomic_accession=97601743, orientation='plus', exon_count=11, OMIM=[190930], no_hdr0=''),
    7112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7112, CurrentID=0, Status='live', Symbol='TMPO', Aliases=['CMD1T', 'LAP2', 'LEMD4', 'PRO0868', 'TP'], description='thymopoietin', other_designations='thymopoietin|LEM domain containing 4|lamina-associated polypeptide 2', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=98515573, end_position_on_the_genomic_accession=98550351, orientation='plus', exon_count=11, OMIM=[188380], no_hdr0=''),
    7113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7113, CurrentID=0, Status='live', Symbol='TMPRSS2', Aliases=['PRSS10'], description='transmembrane serine protease 2', other_designations='transmembrane protease serine 2|epitheliasin|serine protease 10|transmembrane protease, serine 2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41464305, end_position_on_the_genomic_accession=41508158, orientation='minus', exon_count=15, OMIM=[602060], no_hdr0=''),
    7114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7114, CurrentID=0, Status='live', Symbol='TMSB4X', Aliases=['FX', 'PTMB4', 'TB4X', 'TMSB4'], description='thymosin beta 4 X-linked', other_designations='thymosin beta-4|prothymosin beta-4|t beta-4|thymosin, beta 4, X chromosome', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=12975110, end_position_on_the_genomic_accession=12977223, orientation='plus', exon_count=3, OMIM=[300159], no_hdr0=''),
    7122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7122, CurrentID=0, Status='live', Symbol='CLDN5', Aliases=['AWAL', 'BEC1', 'CPETRL1', 'TMDVCF', 'TMVCF'], description='claudin 5', other_designations='claudin-5|transmembrane protein deleted in VCFS|transmembrane protein deleted in velocardiofacial syndrome', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19523024, end_position_on_the_genomic_accession=19525337, orientation='minus', exon_count=2, OMIM=[602101], no_hdr0=''),
    7123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7123, CurrentID=0, Status='live', Symbol='CLEC3B', Aliases=['TN', 'TNA'], description='C-type lectin domain family 3 member B', other_designations='tetranectin|plasminogen kringle 4-binding protein|tetranectin (plasminogen-binding protein)', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45026207, end_position_on_the_genomic_accession=45036071, orientation='plus', exon_count=5, OMIM=[187520], no_hdr0=''),
    7124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7124, CurrentID=0, Status='live', Symbol='TNF', Aliases=['DIF-alpha', 'TNFA', 'TNFSF2', 'TNLG1F', 'TNF'], description='tumor necrosis factor', other_designations='tumor necrosis factor|APC1 protein|TNF, macrophage-derived|TNF, monocyte-derived|TNF-a|tumor necrosis factor ligand 1F|tumor necrosis factor ligand superfamily member 2|tumor necrosis factor-alpha', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31575565, end_position_on_the_genomic_accession=31578336, orientation='plus', exon_count=4, OMIM=[191160], no_hdr0=''),
    7125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7125, CurrentID=0, Status='live', Symbol='TNNC2', Aliases=['CFAP85', 'FAP85'], description='troponin C2, fast skeletal type', other_designations='troponin C, skeletal muscle|troponin C type 2 (fast)', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45823214, end_position_on_the_genomic_accession=45833329, orientation='minus', exon_count=7, OMIM=[191039], no_hdr0=''),
    7126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7126, CurrentID=0, Status='live', Symbol='TNFAIP1', Aliases=['B12', 'B61', 'BTBD34', 'EDP1', 'hBACURD2'], description='TNF alpha induced protein 1', other_designations='BTB/POZ domain-containing adapter for CUL3-mediated RhoA degradation protein 2|BTB/POZ domain-containing protein TNFAIP1|tumor necrosis factor, alpha induced protein 1|tumor necrosis factor, alpha-induced protein 1 (endothelial)', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28335671, end_position_on_the_genomic_accession=28347009, orientation='plus', exon_count=7, OMIM=[191161], no_hdr0=''),
    7127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7127, CurrentID=0, Status='live', Symbol='TNFAIP2', Aliases=['B94', 'EXOC3L3'], description='TNF alpha induced protein 2', other_designations='tumor necrosis factor alpha-induced protein 2|exocyst complex component 3-like 3|primary response gene B94 protein|tumor necrosis factor, alpha induced protein 2', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103121175, end_position_on_the_genomic_accession=103137439, orientation='plus', exon_count=14, OMIM=[603300], no_hdr0=''),
    7128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7128, CurrentID=0, Status='live', Symbol='TNFAIP3', Aliases=['A20', 'AISBL', 'OTUD7C', 'TNFA1P2'], description='TNF alpha induced protein 3', other_designations='tumor necrosis factor alpha-induced protein 3|OTU domain-containing protein 7C|putative DNA-binding protein A20|tumor necrosis factor inducible protein A20|tumor necrosis factor, alpha induced protein 3|zinc finger protein A20', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=137866317, end_position_on_the_genomic_accession=137883312, orientation='plus', exon_count=13, OMIM=[191163], no_hdr0=''),
    7130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7130, CurrentID=0, Status='live', Symbol='TNFAIP6', Aliases=['TSG-6', 'TSG6'], description='TNF alpha induced protein 6', other_designations='tumor necrosis factor-inducible gene 6 protein|TNF-stimulated gene 6 protein|hyaluronate-binding protein|tumor necrosis factor alpha-inducible protein 6|tumor necrosis factor, alpha induced protein 6|tumor necrosis factor-stimulated gene-6 protein', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151357592, end_position_on_the_genomic_accession=151380046, orientation='plus', exon_count=6, OMIM=[600410], no_hdr0=''),
    7132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7132, CurrentID=0, Status='live', Symbol='TNFRSF1A', Aliases=['CD120a', 'FPF', 'TBP1', 'TNF-R', 'TNF-R-I', 'TNF-R55', 'TNFAR', 'TNFR1', 'TNFR55', 'TNFR60', 'p55', 'p55-R', 'p60'], description='TNF receptor superfamily member 1A', other_designations='tumor necrosis factor receptor superfamily member 1A|TNF-R1|TNF-RI|TNFR-I|tumor necrosis factor binding protein 1|tumor necrosis factor receptor type 1|tumor necrosis factor-alpha receptor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6328771, end_position_on_the_genomic_accession=6342076, orientation='minus', exon_count=11, OMIM=[191190], no_hdr0=''),
    7133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7133, CurrentID=0, Status='live', Symbol='TNFRSF1B', Aliases=['CD120b', 'TBPII', 'TNF-R-II', 'TNF-R75', 'TNFBR', 'TNFR1B', 'TNFR2', 'TNFR80', 'p75', 'p75TNFR'], description='TNF receptor superfamily member 1B', other_designations='tumor necrosis factor receptor superfamily member 1B|TNF-R2|TNF-RII|p75 TNF receptor|p80 TNF-alpha receptor|soluble TNFR1B variant 1|tumor necrosis factor beta receptor|tumor necrosis factor binding protein 2|tumor necrosis factor receptor 2|tumor necrosis factor receptor type II', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12166948, end_position_on_the_genomic_accession=12209222, orientation='plus', exon_count=11, OMIM=[191191], no_hdr0=''),
    7134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7134, CurrentID=0, Status='live', Symbol='TNNC1', Aliases=['CMD1Z', 'CMH13', 'TN-C', 'TNC', 'TNNC'], description='troponin C1, slow skeletal and cardiac type', other_designations='troponin C, slow skeletal and cardiac muscles|cardiac troponin C|slow twitch skeletal/cardiac muscle troponin C|troponin C type 1 (slow)', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52451100, end_position_on_the_genomic_accession=52454041, orientation='minus', exon_count=6, OMIM=[191040], no_hdr0=''),
    7135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7135, CurrentID=0, Status='live', Symbol='TNNI1', Aliases=['SSTNI', 'TNN1'], description='troponin I1, slow skeletal type', other_designations='troponin I, slow skeletal muscle|troponin I type 1 (skeletal, slow)', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201403784, end_position_on_the_genomic_accession=201421730, orientation='minus', exon_count=9, OMIM=[191042], no_hdr0=''),
    7136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7136, CurrentID=0, Status='live', Symbol='TNNI2', Aliases=['AMCD2B', 'DA2B', 'DA2B1', 'FSSV', 'fsTnI'], description='troponin I2, fast skeletal type', other_designations='troponin I, fast skeletal muscle|troponin I fast twitch 2|troponin I type 2 (skeletal, fast)|troponin I, skeletal, fast', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1838981, end_position_on_the_genomic_accession=1841678, orientation='plus', exon_count=10, OMIM=[191043], no_hdr0=''),
    7137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7137, CurrentID=0, Status='live', Symbol='TNNI3', Aliases=['CMD1FF', 'CMD2A', 'CMH7', 'RCM1', 'TNNC1', 'cTnI'], description='troponin I3, cardiac type', other_designations='troponin I, cardiac muscle|cardiomyopathy, dilated 2A (autosomal recessive)|troponin I type 3 (cardiac)', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55151767, end_position_on_the_genomic_accession=55157732, orientation='minus', exon_count=8, OMIM=[191044], no_hdr0=''),
    7138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7138, CurrentID=0, Status='live', Symbol='TNNT1', Aliases=['ANM', 'NEM5', 'STNT', 'TNT', 'TNTS'], description='troponin T1, slow skeletal type', other_designations='troponin T, slow skeletal muscle|slow skeletal muscle troponin T|troponin T type 1 (skeletal, slow)|troponin-T1, skeletal, slow', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55132698, end_position_on_the_genomic_accession=55149332, orientation='minus', exon_count=15, OMIM=[191041], no_hdr0=''),
    7139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7139, CurrentID=0, Status='live', Symbol='TNNT2', Aliases=['CMD1D', 'CMH2', 'CMPD2', 'LVNC6', 'RCM3', 'TnTC', 'cTnT'], description='troponin T2, cardiac type', other_designations='troponin T, cardiac muscle|cardiomyopathy, dilated 1D (autosomal dominant)|cardiomyopathy, hypertrophic 2|troponin T type 2 (cardiac)|truncated cardiac troponin T', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201359014, end_position_on_the_genomic_accession=201377828, orientation='minus', exon_count=17, OMIM=[191045], no_hdr0=''),
    7140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7140, CurrentID=0, Status='live', Symbol='TNNT3', Aliases=['DA2B2', 'TNTF', 'beta-TnTF'], description='troponin T3, fast skeletal type', other_designations='troponin T, fast skeletal muscle|troponin T type 3 (skeletal, fast)', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1919551, end_position_on_the_genomic_accession=1938704, orientation='plus', exon_count=22, OMIM=[600692], no_hdr0=''),
    7141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7141, CurrentID=0, Status='live', Symbol='TNP1', Aliases=['TP1'], description='transition protein 1', other_designations='spermatid nuclear transition protein 1|STP-1|TP-1|transition protein 1 (during histone to protamine replacement)', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216859458, end_position_on_the_genomic_accession=216860064, orientation='minus', exon_count=2, OMIM=[190231], no_hdr0=''),
    7142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7142, CurrentID=0, Status='live', Symbol='TNP2', Aliases=['TP2'], description='transition protein 2', other_designations='nuclear transition protein 2|TP-2|transition protein 2 (during histone to protamine replacement)', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11267857, end_position_on_the_genomic_accession=11269325, orientation='minus', exon_count=2, OMIM=[190232], no_hdr0=''),
    7143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7143, CurrentID=0, Status='live', Symbol='TNR', Aliases=['TN-R'], description='tenascin R', other_designations='tenascin-R|janusin|restrictin', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=175315194, end_position_on_the_genomic_accession=175743702, orientation='minus', exon_count=25, OMIM=[601995], no_hdr0=''),
    7145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7145, CurrentID=0, Status='live', Symbol='TNS1', Aliases=['MST091', 'MST122', 'MST127', 'MSTP091', 'MSTP122', 'MSTP127', 'MXRA6', 'PPP1R155', 'TNS'], description='tensin 1', other_designations='tensin-1|Matrix-remodelling-associated protein 6|matrix-remodelling associated 6|protein phosphatase 1, regulatory subunit 155', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=217799789, end_position_on_the_genomic_accession=218002995, orientation='minus', exon_count=45, OMIM=[600076], no_hdr0=''),
    7148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7148, CurrentID=0, Status='live', Symbol='TNXB', Aliases=['EDS3', 'EDSCLL', 'EDSCLL1', 'HXBL', 'TENX', 'TN-X', 'TNX1', 'TNXB2', 'TNXBS', 'VUR8', 'XB', 'XBS', 'TNXB'], description='tenascin XB', other_designations='tenascin-X|growth-inhibiting protein 45|hexabrachion-like protein|tenascin XB1|tenascin XB2', map_location='6p21.33-p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32041153, end_position_on_the_genomic_accession=32109338, orientation='minus', exon_count=44, OMIM=[600985], no_hdr0=''),
    7150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7150, CurrentID=0, Status='live', Symbol='TOP1', Aliases=['TOPI'], description='DNA topoisomerase I', other_designations='DNA topoisomerase 1|Scl-70 antigen|topoisomerase (DNA) I|type I DNA topoisomerase', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41028822, end_position_on_the_genomic_accession=41124487, orientation='plus', exon_count=21, OMIM=[126420], no_hdr0=''),
    7153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7153, CurrentID=0, Status='live', Symbol='TOP2A', Aliases=['TOP2', 'TOP2alpha', 'TOPIIA', 'TP2A'], description='DNA topoisomerase II alpha', other_designations='DNA topoisomerase 2-alpha|DNA gyrase|DNA topoisomerase (ATP-hydrolyzing)|DNA topoisomerase II, 170 kD|DNA topoisomerase II, alpha isozyme|topoisomerase (DNA) II alpha 170kDa', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40388525, end_position_on_the_genomic_accession=40417902, orientation='minus', exon_count=36, OMIM=[126430], no_hdr0=''),
    7155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7155, CurrentID=0, Status='live', Symbol='TOP2B', Aliases=['TOPIIB', 'top2beta'], description='DNA topoisomerase II beta', other_designations='DNA topoisomerase 2-beta|DNA topoisomerase II, 180 kD|DNA topoisomerase II, beta isozyme|U937 associated antigen|antigen MLAA-44|topo II beta|topoisomerase (DNA) II beta 180kDa|topoisomerase II beta|topoisomerase IIb', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=25597905, end_position_on_the_genomic_accession=25664907, orientation='minus', exon_count=36, OMIM=[126431], no_hdr0=''),
    7156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7156, CurrentID=0, Status='live', Symbol='TOP3A', Aliases=['MGRISCE2', 'PEOB5', 'TOP3', 'ZGRF7'], description='DNA topoisomerase III alpha', other_designations='DNA topoisomerase 3-alpha|topo III-alpha|topoisomerase (DNA) III alpha|zinc finger, GRF-type containing 7', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18269958, end_position_on_the_genomic_accession=18314996, orientation='minus', exon_count=19, OMIM=[601243], no_hdr0=''),
    7157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7157, CurrentID=0, Status='live', Symbol='TP53', Aliases=['BCC7', 'BMFS5', 'LFS1', 'P53', 'TRP53'], description='tumor protein p53', other_designations='cellular tumor antigen p53|antigen NY-CO-13|mutant tumor protein 53|p53 tumor suppressor|phosphoprotein p53|transformation-related protein 53|tumor protein 53|tumor supressor p53', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7668421, end_position_on_the_genomic_accession=7687490, orientation='minus', exon_count=12, OMIM=[191170], no_hdr0=''),
    7158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7158, CurrentID=0, Status='live', Symbol='TP53BP1', Aliases=['53BP1', 'TDRD30', 'p202', 'p53BP1'], description='tumor protein p53 binding protein 1', other_designations='TP53-binding protein 1|p53-binding protein 1|tumor protein 53-binding protein, 1|tumor suppressor p53-binding protein 1', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43403061, end_position_on_the_genomic_accession=43510640, orientation='minus', exon_count=32, OMIM=[605230], no_hdr0=''),
    7159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7159, CurrentID=0, Status='live', Symbol='TP53BP2', Aliases=['53BP2', 'ASPP2', 'BBP', 'P53BP2', 'PPP1R13A'], description='tumor protein p53 binding protein 2', other_designations='apoptosis-stimulating of p53 protein 2|BCL2-binding protein|apoptosis-stimulating protein of p53, 2|renal carcinoma antigen NY-REN-51|tumor suppressor p53-binding protein 2', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223779893, end_position_on_the_genomic_accession=223845954, orientation='minus', exon_count=20, OMIM=[602143], no_hdr0=''),
    7161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7161, CurrentID=0, Status='live', Symbol='TP73', Aliases=['P73'], description='tumor protein p73', other_designations='tumor protein p73|p53-like transcription factor|p53-related protein', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3652516, end_position_on_the_genomic_accession=3736201, orientation='plus', exon_count=16, OMIM=[601990], no_hdr0=''),
    7162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7162, CurrentID=0, Status='live', Symbol='TPBG', Aliases=['5T4', '5T4AG', 'M6P1', 'WAIF1'], description='trophoblast glycoprotein', other_designations='trophoblast glycoprotein|5T4 oncofetal antigen|5T4 oncofetal trophoblast glycoprotein|5T4 oncotrophoblast glycoprotein|wnt-activated inhibitory factor 1', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=82362983, end_position_on_the_genomic_accession=82367420, orientation='plus', exon_count=4, OMIM=[190920], no_hdr0=''),
    7163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7163, CurrentID=0, Status='live', Symbol='TPD52', Aliases=['D52', 'N8L', 'PC-1', 'PrLZ', 'hD52'], description='tumor protein D52', other_designations='tumor protein D52|prostate and colon associated protein|prostate leucine zipper|protein N8', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=79918717, end_position_on_the_genomic_accession=80171564, orientation='minus', exon_count=17, OMIM=[604068], no_hdr0=''),
    7164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7164, CurrentID=0, Status='live', Symbol='TPD52L1', Aliases=['D53', 'TPD53'], description='TPD52 like 1', other_designations='tumor protein D53|tumor protein D52 like 1', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125153730, end_position_on_the_genomic_accession=125264407, orientation='plus', exon_count=12, OMIM=[604069], no_hdr0=''),
    7165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7165, CurrentID=0, Status='live', Symbol='TPD52L2', Aliases=['D54', 'TPD54'], description='TPD52 like 2', other_designations='tumor protein D54|HCCR-binding protein 2|tumor protein D52 like 2', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63865247, end_position_on_the_genomic_accession=63891538, orientation='plus', exon_count=10, OMIM=[603747], no_hdr0=''),
    7166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7166, CurrentID=0, Status='live', Symbol='TPH1', Aliases=['TPRH', 'TRPH'], description='tryptophan hydroxylase 1', other_designations='tryptophan 5-hydroxylase 1|L-tryptophan hydroxylase|indoleacetic acid-5-hydroxylase|tryptophan 5-monooxygenase 1|tryptophan hydroxylase (tryptophan 5-monooxygenase)', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18017555, end_position_on_the_genomic_accession=18046269, orientation='minus', exon_count=11, OMIM=[191060], no_hdr0=''),
    7167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7167, CurrentID=0, Status='live', Symbol='TPI1', Aliases=['HEL-S-49', 'TIM', 'TPI', 'TPID'], description='triosephosphate isomerase 1', other_designations='triosephosphate isomerase|epididymis secretory protein Li 49|methylglyoxal synthase|triose-phosphate isomerase', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6866834, end_position_on_the_genomic_accession=6870948, orientation='plus', exon_count=7, OMIM=[190450], no_hdr0=''),
    7168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7168, CurrentID=0, Status='live', Symbol='TPM1', Aliases=['C15orf13', 'CMD1Y', 'CMH3', 'HEL-S-265', 'HTM-alpha', 'LVNC9', 'TMSA'], description='tropomyosin 1', other_designations='tropomyosin alpha-1 chain|cardiomyopathy, hypertrophic 3|epididymis secretory protein Li 265|sarcomeric tropomyosin kappa', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63042698, end_position_on_the_genomic_accession=63071915, orientation='plus', exon_count=14, OMIM=[191010], no_hdr0=''),
    7169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7169, CurrentID=0, Status='live', Symbol='TPM2', Aliases=['AMCD1', 'DA1', 'DA2B', 'DA2B4', 'HEL-S-273', 'NEM4', 'TMSB'], description='tropomyosin 2', other_designations='tropomyosin beta chain|epididymis secretory protein Li 273|nemaline myopathy type 4|tropomyosin 2 (beta)', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35681993, end_position_on_the_genomic_accession=35690056, orientation='minus', exon_count=11, OMIM=[190990], no_hdr0=''),
    7170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7170, CurrentID=0, Status='live', Symbol='TPM3', Aliases=['CAPM1', 'CFTD', 'HEL-189', 'HEL-S-82p', 'NEM1', 'OK/SW-cl.5', 'TM-5', 'TM3', 'TM30', 'TM30nm', 'TM5nu', 'TPMsk3', 'TRK', 'hscp30', 'TPM3'], description='tropomyosin 3', other_designations='tropomyosin alpha-3 chain|alpha-tropomyosin, slow skeletal|cytoskeletal tropomyosin TM30|epididymis luminal protein 189|epididymis secretory sperm binding protein Li 82p|heat-stable cytoskeletal protein 30 kDa|tropomyosin 3 nu|tropomyosin gamma|tropomyosin-5', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154155308, end_position_on_the_genomic_accession=154192100, orientation='minus', exon_count=16, OMIM=[191030], no_hdr0=''),
    7171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7171, CurrentID=0, Status='live', Symbol='TPM4', Aliases=['HEL-S-108'], description='tropomyosin 4', other_designations='tropomyosin alpha-4 chain|TM30p1|epididymis secretory protein Li 108', map_location='19p13.12-p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16067507, end_position_on_the_genomic_accession=16103005, orientation='plus', exon_count=15, OMIM=[600317], no_hdr0=''),
    7172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7172, CurrentID=0, Status='live', Symbol='TPMT', Aliases=['TPMTD'], description='thiopurine S-methyltransferase', other_designations='thiopurine S-methyltransferase|S-adenosyl-L-methionine:thiopurine S-methyltransferase', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=18128311, end_position_on_the_genomic_accession=18155169, orientation='minus', exon_count=10, OMIM=[187680], no_hdr0=''),
    7173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7173, CurrentID=0, Status='live', Symbol='TPO', Aliases=['MSA', 'TDH2A', 'TPX'], description='thyroid peroxidase', other_designations='thyroid peroxidase|thyroid microsomal antigen|thyroperoxidase', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=1413288, end_position_on_the_genomic_accession=1543673, orientation='plus', exon_count=19, OMIM=[606765], no_hdr0=''),
    7174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7174, CurrentID=0, Status='live', Symbol='TPP2', Aliases=['IMD78', 'TPP-2', 'TPP-II', 'TPPII'], description='tripeptidyl peptidase 2', other_designations='tripeptidyl-peptidase 2|tripeptidyl aminopeptidase|tripeptidyl-peptidase II', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102596985, end_position_on_the_genomic_accession=102679958, orientation='plus', exon_count=31, OMIM=[190470], no_hdr0=''),
    7175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7175, CurrentID=0, Status='live', Symbol='TPR', Aliases=[], description='translocated promoter region, nuclear basket protein', other_designations='nucleoprotein TPR|NPC-associated intranuclear protein|megator|nuclear pore complex-associated protein TPR|translocated promoter region (to activated MET oncogene)|translocated promoter region protein|tumor potentiating region', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186311652, end_position_on_the_genomic_accession=186375253, orientation='minus', exon_count=51, OMIM=[189940], no_hdr0=''),
    7177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7177, CurrentID=0, Status='live', Symbol='TPSAB1', Aliases=['TPS1', 'TPS2', 'TPSB1', 'TPSB2', 'Tryptase-2'], description='tryptase alpha/beta 1', other_designations='tryptase alpha/beta-1|Tryptase II|Tryptase beta-2|epididymis secretory sperm binding protein|mast cell alpha II tryptase|mast cell beta I tryptase|tryptase alpha II|tryptase alpha-1|tryptase beta I|tryptase beta-1|tryptase-1|tryptase-I|tryptase-III', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1240705, end_position_on_the_genomic_accession=1242554, orientation='plus', exon_count=6, OMIM=[191080], no_hdr0=''),
    7178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7178, CurrentID=0, Status='live', Symbol='TPT1', Aliases=['HRF', 'TCTP', 'p02', 'p23'], description='tumor protein, translationally-controlled 1', other_designations='translationally-controlled tumor protein|fortilin|histamine-releasing factor', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45333471, end_position_on_the_genomic_accession=45341183, orientation='minus', exon_count=6, OMIM=[600763], no_hdr0=''),
    7179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7179, CurrentID=0, Status='live', Symbol='TPTE', Aliases=['CT44', 'PTEN2'], description='transmembrane phosphatase with tensin homology', other_designations='putative tyrosine-protein phosphatase TPTE|PTEN-related tyrosine phosphatase|cancer/testis antigen 44|tensin, putative protein-tyrosine phosphatase|tumor antigen BJ-HCC-5', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=10521583, end_position_on_the_genomic_accession=10605716, orientation='plus', exon_count=24, OMIM=[604336], no_hdr0=''),
    7180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7180, CurrentID=0, Status='live', Symbol='CRISP2', Aliases=['CRISP-2', 'CT36', 'GAPDL5', 'TPX1', 'TSP1'], description='cysteine rich secretory protein 2', other_designations='cysteine-rich secretory protein 2|cancer/testis antigen 36|glyceraldehyde-3-phosphate dehydrogenase-like 5|testicular tissue protein Li 43|testis specific protein 1 (probe H4-1 p3-1)|testis-specific protein TPX-1', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49676665, end_position_on_the_genomic_accession=49714198, orientation='minus', exon_count=14, OMIM=[187430], no_hdr0=''),
    7181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7181, CurrentID=0, Status='live', Symbol='NR2C1', Aliases=['TR2'], description='nuclear receptor subfamily 2 group C member 1', other_designations='nuclear receptor subfamily 2 group C member 1|TR2 nuclear hormone receptor|orphan nuclear receptor TR2', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95020229, end_position_on_the_genomic_accession=95073618, orientation='minus', exon_count=16, OMIM=[601529], no_hdr0=''),
    7182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7182, CurrentID=0, Status='live', Symbol='NR2C2', Aliases=['TAK1', 'TR4'], description='nuclear receptor subfamily 2 group C member 2', other_designations='nuclear receptor subfamily 2 group C member 2|Nuclear hormone receptor TR4|orphan nuclear receptor TAK1|orphan nuclear receptor TR4|orphan receptor TR4|testicular nuclear receptor 4', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14947583, end_position_on_the_genomic_accession=15049273, orientation='plus', exon_count=22, OMIM=[601426], no_hdr0=''),
    7184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7184, CurrentID=0, Status='live', Symbol='HSP90B1', Aliases=['ECGP', 'GP96', 'GRP94', 'HEL-S-125m', 'HEL35', 'TRA1'], description='heat shock protein 90 beta family member 1', other_designations='endoplasmin|94 kDa glucose-regulated protein|endothelial cell (HBMEC) glycoprotein|epididymis luminal protein 35|epididymis secretory sperm binding protein Li 125m|heat shock protein 90 kDa beta member 1|heat shock protein 90kDa beta (Grp94), member 1|heat shock protein 90kDa beta family member 1|stress-inducible tumor rejection antigen gp96|tumor rejection antigen (gp96) 1|tumor rejection antigen 1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103930410, end_position_on_the_genomic_accession=103947926, orientation='plus', exon_count=18, OMIM=[191175], no_hdr0=''),
    7185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7185, CurrentID=0, Status='live', Symbol='TRAF1', Aliases=['EBI6', 'MGC:10353'], description='TNF receptor associated factor 1', other_designations='TNF receptor-associated factor 1|Epstein-Bar virus-induced protein 6', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120902393, end_position_on_the_genomic_accession=120929171, orientation='minus', exon_count=10, OMIM=[601711], no_hdr0=''),
    7186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7186, CurrentID=0, Status='live', Symbol='TRAF2', Aliases=['MGC:45012', 'RNF117', 'TRAP', 'TRAP3'], description='TNF receptor associated factor 2', other_designations='TNF receptor-associated factor 2|E3 ubiquitin-protein ligase TRAF2|RING-type E3 ubiquitin transferase TRAF2|tumor necrosis factor type 2 receptor associated protein 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136881933, end_position_on_the_genomic_accession=136926615, orientation='plus', exon_count=15, OMIM=[601895], no_hdr0=''),
    7187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7187, CurrentID=0, Status='live', Symbol='TRAF3', Aliases=['CAP-1', 'CAP1', 'CD40bp', 'CRAF1', 'IIAE5', 'LAP1', 'RNF118'], description='TNF receptor associated factor 3', other_designations='TNF receptor-associated factor 3|CD40 associated protein 1|CD40 binding protein|CD40 receptor associated factor 1|LMP1-associated protein 1|RING-type E3 ubiquitin transferase TRAF3', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102777449, end_position_on_the_genomic_accession=102911500, orientation='plus', exon_count=15, OMIM=[601896], no_hdr0=''),
    7188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7188, CurrentID=0, Status='live', Symbol='TRAF5', Aliases=['MGC:39780', 'RNF84'], description='TNF receptor associated factor 5', other_designations='TNF receptor-associated factor 5|RING finger protein 84', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211326594, end_position_on_the_genomic_accession=211374946, orientation='plus', exon_count=14, OMIM=[602356], no_hdr0=''),
    7189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7189, CurrentID=0, Status='live', Symbol='TRAF6', Aliases=['MGC:3310', 'RNF85'], description='TNF receptor associated factor 6', other_designations='TNF receptor-associated factor 6|E3 ubiquitin-protein ligase TRAF6|RING finger protein 85|RING-type E3 ubiquitin transferase TRAF6|TNF receptor-associated factor 6, E3 ubiquitin protein ligase|interleukin-1 signal transducer', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36483769, end_position_on_the_genomic_accession=36510313, orientation='minus', exon_count=9, OMIM=[602355], no_hdr0=''),
    7200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7200, CurrentID=0, Status='live', Symbol='TRH', Aliases=['Pro-TRH', 'TRF'], description='thyrotropin releasing hormone', other_designations='thyrotropin releasing hormone|TSH-releasing factor|pro-thyrotropin-releasing hormone|prothyroliberin|protirelin|thyrotropin-releasing factor', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129974720, end_position_on_the_genomic_accession=129977935, orientation='plus', exon_count=3, OMIM=[613879], no_hdr0=''),
    7201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7201, CurrentID=0, Status='live', Symbol='TRHR', Aliases=['CHNG7', 'TRH-R'], description='thyrotropin releasing hormone receptor', other_designations='thyrotropin-releasing hormone receptor|thyroliberin receptor', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109086585, end_position_on_the_genomic_accession=109121565, orientation='plus', exon_count=3, OMIM=[188545], no_hdr0=''),
    7203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7203, CurrentID=0, Status='live', Symbol='CCT3', Aliases=['CCT-gamma', 'CCTG', 'PIG48', 'TCP-1-gamma', 'TRIC5'], description='chaperonin containing TCP1 subunit 3', other_designations='T-complex protein 1 subunit gamma|T-complex protein 1, gamma subunit|TCP1 (t-complex-1) ring complex, polypeptide 5|chaperonin containing TCP1, subunit 3 (gamma)|hTRiC5', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156308968, end_position_on_the_genomic_accession=156338292, orientation='minus', exon_count=16, OMIM=[600114], no_hdr0=''),
    7204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7204, CurrentID=0, Status='live', Symbol='TRIO', Aliases=['ARHGEF23', 'MEBAS', 'MRD44', 'MRD63', 'tgat'], description='trio Rho guanine nucleotide exchange factor', other_designations='triple functional domain protein|PTPRF-interacting protein|triple functional domain (PTPRF interacting)', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=14143342, end_position_on_the_genomic_accession=14510204, orientation='plus', exon_count=63, OMIM=[601893], no_hdr0=''),
    7205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7205, CurrentID=0, Status='live', Symbol='TRIP6', Aliases=['OIP-1', 'OIP1', 'TRIP-6i2', 'ZRP-1', 'TRIP6'], description='thyroid hormone receptor interactor 6', other_designations='thyroid receptor-interacting protein 6|OPA-interacting protein 1|TR-interacting protein 6|thyroid hormone receptor interacting protein 6|zyxin related protein 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100867387, end_position_on_the_genomic_accession=100873454, orientation='plus', exon_count=9, OMIM=[602933], no_hdr0=''),
    7216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7216, CurrentID=0, Status='live', Symbol='TRO', Aliases=['MAGE-d3', 'MAGED3'], description='trophinin', other_designations='trophinin|MAGE superfamily protein|MAGE-D3 antigen|magphinin|melanoma antigen, family D, 3', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54920796, end_position_on_the_genomic_accession=54931436, orientation='plus', exon_count=15, OMIM=[300132], no_hdr0=''),
    7220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7220, CurrentID=0, Status='live', Symbol='TRPC1', Aliases=['HTRP-1', 'TRP1'], description='transient receptor potential cation channel subfamily C member 1', other_designations='short transient receptor potential channel 1|TRP-1|capacitative calcium channel protein Trp1|transient receptor potential canonical 1|transient receptor protein 1', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142724034, end_position_on_the_genomic_accession=142807888, orientation='plus', exon_count=16, OMIM=[602343], no_hdr0=''),
    7222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7222, CurrentID=0, Status='live', Symbol='TRPC3', Aliases=['SCA41', 'TRP3'], description='transient receptor potential cation channel subfamily C member 3', other_designations='short transient receptor potential channel 3|hTrp-3|transient receptor potential cation channel subfamily C member 3 variant c|transient receptor protein 3', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121874481, end_position_on_the_genomic_accession=121952060, orientation='minus', exon_count=13, OMIM=[602345], no_hdr0=''),
    7223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7223, CurrentID=0, Status='live', Symbol='TRPC4', Aliases=['HTRP-4', 'HTRP4', 'TRP4'], description='transient receptor potential cation channel subfamily C member 4', other_designations='short transient receptor potential channel 4|trp-related protein 4', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=37632063, end_position_on_the_genomic_accession=37869772, orientation='minus', exon_count=11, OMIM=[603651], no_hdr0=''),
    7224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7224, CurrentID=0, Status='live', Symbol='TRPC5', Aliases=['PPP1R159', 'TRP5'], description='transient receptor potential cation channel subfamily C member 5', other_designations='short transient receptor potential channel 5|TRP-5|hTRP5|protein phosphatase 1, regulatory subunit 159|transient receptor potential channel 5|transient receptor protein 5', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111768011, end_position_on_the_genomic_accession=112082943, orientation='minus', exon_count=12, OMIM=[300334], no_hdr0=''),
    7225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7225, CurrentID=0, Status='live', Symbol='TRPC6', Aliases=['FSGS2', 'TRP6'], description='transient receptor potential cation channel subfamily C member 6', other_designations='short transient receptor potential channel 6|TRP-6|focal segmental glomerulosclerosis 2|transient receptor protein 6', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=101451470, end_position_on_the_genomic_accession=101584007, orientation='minus', exon_count=14, OMIM=[603652], no_hdr0=''),
    7226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7226, CurrentID=0, Status='live', Symbol='TRPM2', Aliases=['EREG1', 'KNP3', 'LTRPC2', 'LTrpC-2', 'NUDT9H', 'NUDT9L1', 'TRPC7'], description='transient receptor potential cation channel subfamily M member 2', other_designations='transient receptor potential cation channel subfamily M member 2|estrogen-responsive element-associated gene 1 protein|long transient receptor potential channel 2|transient receptor potential channel 7|transient receptor potential melastatin 2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44350112, end_position_on_the_genomic_accession=44442807, orientation='plus', exon_count=35, OMIM=[603749], no_hdr0=''),
    7227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7227, CurrentID=0, Status='live', Symbol='TRPS1', Aliases=['GC79', 'LGCR'], description='transcriptional repressor GATA binding 1', other_designations='zinc finger transcription factor Trps1|tricho-rhino-phalangeal syndrome type I protein|trichorhinophalangeal syndrome I|zinc finger protein GC79', map_location='8q23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=115408496, end_position_on_the_genomic_accession=115668975, orientation='minus', exon_count=8, OMIM=[604386], no_hdr0=''),
    7247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7247, CurrentID=0, Status='live', Symbol='TSN', Aliases=['BCLF-1', 'C3PO', 'RCHF1', 'REHF-1', 'TBRBP', 'TRSLN'], description='translin', other_designations='translin|component 3 of promoter of RISC|recombination hotspot associated factor|recombination hotspot-binding protein|testis brain-RNA binding protein', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=121755651, end_position_on_the_genomic_accession=121767853, orientation='plus', exon_count=6, OMIM=[600575], no_hdr0=''),
    7248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7248, CurrentID=0, Status='live', Symbol='TSC1', Aliases=['LAM', 'TSC'], description='TSC complex subunit 1', other_designations='hamartin|truncated hemartin|tuberous sclerosis 1 protein', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132891349, end_position_on_the_genomic_accession=132945269, orientation='minus', exon_count=25, OMIM=[605284], no_hdr0=''),
    7249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7249, CurrentID=0, Status='live', Symbol='TSC2', Aliases=['LAM', 'PPP1R160', 'TSC4'], description='TSC complex subunit 2', other_designations='tuberin|protein phosphatase 1, regulatory subunit 160|tuberous sclerosis 2 protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2047804, end_position_on_the_genomic_accession=2089491, orientation='plus', exon_count=44, OMIM=[191092], no_hdr0=''),
    7251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7251, CurrentID=0, Status='live', Symbol='TSG101', Aliases=['TSG10', 'VPS23'], description='tumor susceptibility 101', other_designations='tumor susceptibility gene 101 protein|ESCRT-I complex subunit TSG101|tumor susceptibility gene 10|tumor susceptibility gene 101|tumor susceptibility protein', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18480311, end_position_on_the_genomic_accession=18526942, orientation='minus', exon_count=11, OMIM=[601387], no_hdr0=''),
    7252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7252, CurrentID=0, Status='live', Symbol='TSHB', Aliases=['TSH-B', 'TSH-BETA'], description='thyroid stimulating hormone subunit beta', other_designations='thyrotropin subunit beta|thyroid stimulating hormone beta|thyrotropin beta chain', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115029826, end_position_on_the_genomic_accession=115035935, orientation='plus', exon_count=3, OMIM=[188540], no_hdr0=''),
    7253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7253, CurrentID=0, Status='live', Symbol='TSHR', Aliases=['CHNG1', 'LGR3', 'hTSHR-I'], description='thyroid stimulating hormone receptor', other_designations='thyrotropin receptor|TSH receptor|seven transmembrane helix receptor|thyrotropin receptor-I, hTSHR-I', map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=80954989, end_position_on_the_genomic_accession=81146306, orientation='plus', exon_count=12, OMIM=[603372], no_hdr0=''),
    7257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7257, CurrentID=0, Status='live', Symbol='TSNAX', Aliases=['C3PO', 'TRAX'], description='translin associated factor X', other_designations='translin-associated protein X|translin-like protein', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231528669, end_position_on_the_genomic_accession=231566524, orientation='plus', exon_count=6, OMIM=[602964], no_hdr0=''),
    7258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7258, CurrentID=0, Status='live', Symbol='TSPY1', Aliases=['CT78', 'DYS14', 'TSPY', 'pJA923'], description='testis specific protein Y-linked 1', other_designations='testis-specific Y-encoded protein 1|cancer/testis antigen 78|testis specific protein, Y-linked', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=9466955, end_position_on_the_genomic_accession=9469756, orientation='plus', exon_count=6, OMIM=[480100], no_hdr0=''),
    7259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7259, CurrentID=0, Status='live', Symbol='TSPYL1', Aliases=['TSPYL'], description='TSPY like 1', other_designations='testis-specific Y-encoded-like protein 1|TSPY-like protein 1', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116274858, end_position_on_the_genomic_accession=116279930, orientation='minus', exon_count=1, OMIM=[604714], no_hdr0=''),
    7260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7260, CurrentID=0, Status='live', Symbol='EIPR1', Aliases=['EIPR-1', 'TSSC1'], description='EARP complex and GARP complex interacting protein 1', other_designations='EARP and GARP complex-interacting protein 1|EARP-interacting protein|Golgi-associated retrograde protein-interacting protein|endosome-associated recycling protein-interacting protein|protein TSSC1|tumor suppressing subtransferable candidate 1|tumor-suppressing STF cDNA 1 protein|tumor-suppressing subchromosomal transferable fragment candidate gene 1 protein|tumor-suppressing subtransferable fragment candidate gene 1', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3188968, end_position_on_the_genomic_accession=3377818, orientation='minus', exon_count=13, OMIM=[608998], no_hdr0=''),
    7262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7262, CurrentID=0, Status='live', Symbol='PHLDA2', Aliases=['BRW1C', 'BWR1C', 'HLDA2', 'IPL', 'TSSC3'], description='pleckstrin homology like domain family A member 2', other_designations='pleckstrin homology-like domain family A member 2|beckwith-Wiedemann syndrome chromosomal region 1 candidate gene C protein|imprinted in placenta and liver protein|p17-BWR1C|p17-Beckwith-Wiedemann region 1 C|p17-Beckwith-Wiedemann region 1C|tumor suppressing subchromosomal transferable fragment cDNA 3|tumor suppressing subtransferable candidate 3|tumor-suppressing subchromosomal transferable fragment candidate gene 3 protein|tumor-supressing STF cDNA 3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2928273, end_position_on_the_genomic_accession=2929420, orientation='minus', exon_count=2, OMIM=[602131], no_hdr0=''),
    7263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7263, CurrentID=0, Status='live', Symbol='TST', Aliases=['RDS'], description='thiosulfate sulfurtransferase', other_designations='thiosulfate sulfurtransferase|epididymis secretory sperm binding protein|thiosulfate sulfurtransferase (rhodanese)', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37010859, end_position_on_the_genomic_accession=37020183, orientation='minus', exon_count=4, OMIM=[180370], no_hdr0=''),
    7264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7264, CurrentID=0, Status='live', Symbol='GFUS', Aliases=['FX', 'P35B', 'SDR4E1', 'TSTA3'], description='GDP-L-fucose synthase', other_designations='GDP-L-fucose synthase|3-5 epimerase/4-reductase|GDP-4-keto-6-deoxy-D-mannose epimerase-reductase|GDP-4-keto-6-deoxy-D-mannose-3,5-epimerase-4-reductase|red cell NADP(H)-binding protein|short chain dehydrogenase/reductase family 4E, member 1|testis tissue sperm-binding protein Li 45a|tissue specific transplantation antigen 3|tissue specific transplantation antigen P35B', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143612618, end_position_on_the_genomic_accession=143618043, orientation='minus', exon_count=13, OMIM=[137020], no_hdr0=''),
    7265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7265, CurrentID=0, Status='live', Symbol='TTC1', Aliases=['TPR1'], description='tetratricopeptide repeat domain 1', other_designations='tetratricopeptide repeat protein 1|TPR repeat protein 1', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160009139, end_position_on_the_genomic_accession=160065543, orientation='plus', exon_count=8, OMIM=[601963], no_hdr0=''),
    7266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7266, CurrentID=0, Status='live', Symbol='DNAJC7', Aliases=['DJ11', 'DJC7', 'TPR2', 'TTC2'], description='DnaJ heat shock protein family (Hsp40) member C7', other_designations='dnaJ homolog subfamily C member 7|DnaJ (Hsp40) homolog, subfamily C, member 7|TPR repeat protein 2|tetratricopeptide repeat domain 2|tetratricopeptide repeat protein 2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41976427, end_position_on_the_genomic_accession=42021371, orientation='minus', exon_count=19, OMIM=[601964], no_hdr0=''),
    7267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7267, CurrentID=0, Status='live', Symbol='TTC3', Aliases=['DCRR1', 'RNF105', 'TPRDIII'], description='tetratricopeptide repeat domain 3', other_designations='E3 ubiquitin-protein ligase TTC3|RING finger protein 105|RING-type E3 ubiquitin transferase TTC3|TPR repeat protein 3|TPR repeat protein D|tetratricopeptide repeat protein 3', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37073235, end_position_on_the_genomic_accession=37203118, orientation='plus', exon_count=52, OMIM=[602259], no_hdr0=''),
    7268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7268, CurrentID=0, Status='live', Symbol='TTC4', Aliases=['CNS1'], description='tetratricopeptide repeat domain 4', other_designations='tetratricopeptide repeat protein 4|TPR repeat protein 4', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54715861, end_position_on_the_genomic_accession=54742657, orientation='plus', exon_count=10, OMIM=[606753], no_hdr0=''),
    7270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7270, CurrentID=0, Status='live', Symbol='TTF1', Aliases=['TTF-1', 'TTF-I'], description='transcription termination factor 1', other_designations='transcription termination factor 1|transcription termination factor, RNA polymerase I', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132375548, end_position_on_the_genomic_accession=132406840, orientation='minus', exon_count=12, OMIM=[600777], no_hdr0=''),
    7272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7272, CurrentID=0, Status='live', Symbol='TTK', Aliases=['CT96', 'ESK', 'MPH1', 'MPS1', 'MPS1L1', 'PYT'], description='TTK protein kinase', other_designations='dual specificity protein kinase TTK|cancer/testis antigen 96|monopolar spindle 1 kinase|monopolar spindle 1-like 1|phosphotyrosine picked threonine kinase|phosphotyrosine picked threonine-protein kinase', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=80004147, end_position_on_the_genomic_accession=80042651, orientation='plus', exon_count=23, OMIM=[604092], no_hdr0=''),
    7273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7273, CurrentID=0, Status='live', Symbol='TTN', Aliases=['CMD1G', 'CMH9', 'CMPD4', 'EOMFC', 'HMERF', 'LGMD2J', 'LGMDR10', 'MYLK5', 'SALMY', 'TMD'], description='titin', other_designations='titin|connectin|rhabdomyosarcoma antigen MU-RMS-40.14', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178525989, end_position_on_the_genomic_accession=178807423, orientation='minus', exon_count=365, OMIM=[188840], no_hdr0=''),
    7274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7274, CurrentID=0, Status='live', Symbol='TTPA', Aliases=['ATTP', 'AVED', 'TTP1', 'alphaTTP'], description='alpha tocopherol transfer protein', other_designations='alpha-tocopherol transfer protein|alpha-TTP|tocopherol (alpha) transfer protein (ataxia (Friedreich-like) with vitamin E deficiency)', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=63059488, end_position_on_the_genomic_accession=63086523, orientation='minus', exon_count=5, OMIM=[600415], no_hdr0=''),
    7275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7275, CurrentID=0, Status='live', Symbol='TUB', Aliases=['RDOB', 'rd5'], description='TUB bipartite transcription factor', other_designations='tubby protein homolog|tubby bipartite transcription factor|tubby homolog|tubby homologue', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8019180, end_position_on_the_genomic_accession=8106243, orientation='plus', exon_count=16, OMIM=[601197], no_hdr0=''),
    7276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7276, CurrentID=0, Status='live', Symbol='TTR', Aliases=['ATTR', 'CTS', 'CTS1', 'HEL111', 'HsT2651', 'PALB', 'TBPA', 'TTN'], description='transthyretin', other_designations='transthyretin|epididymis luminal protein 111|prealbumin, amyloidosis type I|thyroxine-binding prealbumin', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31591877, end_position_on_the_genomic_accession=31598821, orientation='plus', exon_count=4, OMIM=[176300], no_hdr0=''),
    7277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7277, CurrentID=0, Status='live', Symbol='TUBA4A', Aliases=['ALS22', 'H2-ALPHA', 'TUBA1'], description='tubulin alpha 4a', other_designations='tubulin alpha-4A chain|tubulin H2-alpha|tubulin alpha-1 chain|tubulin, alpha 1 (testis specific)', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219249710, end_position_on_the_genomic_accession=219254740, orientation='minus', exon_count=5, OMIM=[191110], no_hdr0=''),
    7278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7278, CurrentID=0, Status='live', Symbol='TUBA3C', Aliases=['TUBA2', 'bA408E5.3'], description='tubulin alpha 3c', other_designations='tubulin alpha-3C chain|Alpha-tubulin 3D|Tubulin alpha-3D chain|alpha-tubulin 2|alpha-tubulin 3C|alpha-tubulin 3C/D|tubulin alpha-2 chain|tubulin alpha-3C/D chain|tubulin, alpha 2', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19173772, end_position_on_the_genomic_accession=19181824, orientation='minus', exon_count=5, OMIM=[602528], no_hdr0=''),
    7280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7280, CurrentID=0, Status='live', Symbol='TUBB2A', Aliases=['CDCBM5', 'TUBB', 'TUBB2'], description='tubulin beta 2A class IIa', other_designations='tubulin beta-2A chain|class IIa beta-tubulin|tubulin, beta 2A|tubulin, beta polypeptide 2', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3153666, end_position_on_the_genomic_accession=3157544, orientation='minus', exon_count=4, OMIM=[615101], no_hdr0=''),
    7283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7283, CurrentID=0, Status='live', Symbol='TUBG1', Aliases=['CDCBM4', 'GCP-1', 'TUBG', 'TUBGCP1'], description='tubulin gamma 1', other_designations='tubulin gamma-1 chain|gamma-tubulin complex component 1|tubulin, gamma polypeptide', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42609390, end_position_on_the_genomic_accession=42615238, orientation='plus', exon_count=10, OMIM=[191135], no_hdr0=''),
    7284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7284, CurrentID=0, Status='live', Symbol='TUFM', Aliases=['COXPD4', 'EF-TuMT', 'EFTU', 'P43'], description='Tu translation elongation factor, mitochondrial', other_designations='elongation factor Tu, mitochondrial|EF-Tu|epididymis secretory sperm binding protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28842411, end_position_on_the_genomic_accession=28846348, orientation='minus', exon_count=10, OMIM=[602389], no_hdr0=''),
    7286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7286, CurrentID=0, Status='live', Symbol='TUFT1', Aliases=[], description='tuftelin 1', other_designations='tuftelin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151540294, end_position_on_the_genomic_accession=151583583, orientation='plus', exon_count=15, OMIM=[600087], no_hdr0=''),
    7287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7287, CurrentID=0, Status='live', Symbol='TULP1', Aliases=['LCA15', 'RP14', 'TUBL1'], description='TUB like protein 1', other_designations='tubby-related protein 1|tubby like protein 1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35497874, end_position_on_the_genomic_accession=35512896, orientation='minus', exon_count=15, OMIM=[602280], no_hdr0=''),
    7288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7288, CurrentID=0, Status='live', Symbol='TULP2', Aliases=['CT65', 'TUBL2'], description='TUB like protein 2', other_designations='tubby-related protein 2|cancer testis antigen 65|tubby like protein 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48880967, end_position_on_the_genomic_accession=48898744, orientation='minus', exon_count=13, OMIM=[602309], no_hdr0=''),
    7289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7289, CurrentID=0, Status='live', Symbol='TULP3', Aliases=['TUBL3'], description='TUB like protein 3', other_designations='tubby-related protein 3|tubby like protein 3', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2890891, end_position_on_the_genomic_accession=2941138, orientation='plus', exon_count=11, OMIM=[604730], no_hdr0=''),
    7290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7290, CurrentID=0, Status='live', Symbol='HIRA', Aliases=['DGCR1', 'TUP1', 'TUPLE1'], description='histone cell cycle regulator', other_designations='protein HIRA|DiGeorge critical region gene 1|HIR histone cell cycle regulation defective homolog A|TUP1-like enhancer of split protein 1|histone regulator A', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19330698, end_position_on_the_genomic_accession=19431733, orientation='minus', exon_count=25, OMIM=[600237], no_hdr0=''),
    7291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7291, CurrentID=0, Status='live', Symbol='TWIST1', Aliases=['ACS3', 'BPES2', 'BPES3', 'CRS', 'CRS1', 'CSO', 'SCS', 'SWCOS', 'TWIST', 'bHLHa38'], description='twist family bHLH transcription factor 1', other_designations='twist-related protein 1|B-HLH DNA binding protein|H-twist|TWIST homolog of drosophila|class A basic helix-loop-helix protein 38|twist basic helix-loop-helix transcription factor 1|twist homolog 1', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=19113047, end_position_on_the_genomic_accession=19117636, orientation='minus', exon_count=4, OMIM=[601622], no_hdr0=''),
    7292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7292, CurrentID=0, Status='live', Symbol='TNFSF4', Aliases=['CD134L', 'CD252', 'GP34', 'OX-40L', 'OX4OL', 'TNLG2B', 'TXGP1'], description='TNF superfamily member 4', other_designations='tumor necrosis factor ligand superfamily member 4|CD134 ligand|OX40 antigen ligand|glycoprotein Gp34|tax-transcriptionally activated glycoprotein 1 (34kD)|tumor necrosis factor (ligand) superfamily member 4|tumor necrosis factor ligand 2B|tumor necrosis factor superfamily member 4', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173183729, end_position_on_the_genomic_accession=173462208, orientation='minus', exon_count=13, OMIM=[603594], no_hdr0=''),
    7293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7293, CurrentID=0, Status='live', Symbol='TNFRSF4', Aliases=['ACT35', 'CD134', 'IMD16', 'OX40', 'TXGP1L'], description='TNF receptor superfamily member 4', other_designations='tumor necrosis factor receptor superfamily member 4|ACT35 antigen|ATC35 antigen|CD134 antigen|OX40 antigen|OX40 cell surface antigen|OX40 homologue|OX40L receptor|TAX transcriptionally-activated glycoprotein 1 receptor|lymphoid activation antigene ACT35|tax-transcriptionally activated glycoprotein 1 receptor', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1211326, end_position_on_the_genomic_accession=1216812, orientation='minus', exon_count=9, OMIM=[600315], no_hdr0=''),
    7294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7294, CurrentID=0, Status='live', Symbol='TXK', Aliases=['BTKL', 'PSCTK5', 'PTK4', 'RLK', 'TKL'], description='TXK tyrosine kinase', other_designations='tyrosine-protein kinase TXK|PTK4 protein tyrosine kinase 4|protein-tyrosine kinase 4|resting lymphocyte kinase', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48063504, end_position_on_the_genomic_accession=48135322, orientation='minus', exon_count=17, OMIM=[600058], no_hdr0=''),
    7295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7295, CurrentID=0, Status='live', Symbol='TXN', Aliases=['TRDX', 'TRX', 'TRX1', 'Trx80'], description='thioredoxin', other_designations='thioredoxin|ADF|ATL-derived factor|SASP|TXN delta 3|surface-associated sulphydryl protein|testicular tissue protein Li 199|thioredoxin delta 3', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110243810, end_position_on_the_genomic_accession=110256507, orientation='minus', exon_count=5, OMIM=[187700], no_hdr0=''),
    7296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7296, CurrentID=0, Status='live', Symbol='TXNRD1', Aliases=['GRIM-12', 'TR', 'TR1', 'TRXR1', 'TXNR'], description='thioredoxin reductase 1', other_designations='thioredoxin reductase 1, cytoplasmic|KM-102-derived reductase-like factor|gene associated with retinoic and IFN-induced mortality 12 protein|gene associated with retinoic and interferon-induced mortality 12 protein|oxidoreductase|selenoprotein TXNRD1|testis tissue sperm-binding protein Li 46a|thioredoxin reductase GRIM-12|thioredoxin reductase TR1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104215779, end_position_on_the_genomic_accession=104350307, orientation='plus', exon_count=18, OMIM=[601112], no_hdr0=''),
    7297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7297, CurrentID=0, Status='live', Symbol='TYK2', Aliases=['IMD35', 'JTK1'], description='tyrosine kinase 2', other_designations='non-receptor tyrosine-protein kinase TYK2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10350528, end_position_on_the_genomic_accession=10380572, orientation='minus', exon_count=29, OMIM=[176941], no_hdr0=''),
    7298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7298, CurrentID=0, Status='live', Symbol='TYMS', Aliases=['HST422', 'TMS', 'TS'], description='thymidylate synthetase', other_designations='thymidylate synthase|TSase', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=657653, end_position_on_the_genomic_accession=673578, orientation='plus', exon_count=8, OMIM=[188350], no_hdr0=''),
    7299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7299, CurrentID=0, Status='live', Symbol='TYR', Aliases=['ATN', 'CMM8', 'OCA1', 'OCA1A', 'OCAIA', 'SHEP3'], description='tyrosinase', other_designations='tyrosinase|LB24-AB|SK29-AB|monophenol monooxygenase|oculocutaneous albinism IA|tumor rejection antigen AB', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89177565, end_position_on_the_genomic_accession=89295759, orientation='plus', exon_count=6, OMIM=[606933], no_hdr0=''),
    7301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7301, CurrentID=0, Status='live', Symbol='TYRO3', Aliases=['BYK', 'Dtk', 'Etk-2', 'RSE', 'Rek', 'Sky', 'Tif'], description='TYRO3 protein tyrosine kinase', other_designations='tyrosine-protein kinase receptor TYRO3|tyrosine-protein kinase DTK|tyrosine-protein kinase RSE|tyrosine-protein kinase SKY|tyrosine-protein kinase TIF|tyrosine-protein kinase byk', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41559212, end_position_on_the_genomic_accession=41583589, orientation='plus', exon_count=21, OMIM=[600341], no_hdr0=''),
    7305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7305, CurrentID=0, Status='live', Symbol='TYROBP', Aliases=['DAP12', 'KARAP', 'PLOSL', 'PLOSL1'], description='transmembrane immune signaling adaptor TYROBP', other_designations='TYRO protein tyrosine kinase-binding protein|DNAX adaptor protein 12|DNAX-activation protein 12|KAR-associated protein|TYRO protein tyrosine kinase binding protein|killer-activating receptor-associated protein|polycystic lipomembranous osteodysplasia with sclerosing leukoencephalopathy', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35904403, end_position_on_the_genomic_accession=35908295, orientation='minus', exon_count=5, OMIM=[604142], no_hdr0=''),
    7306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7306, CurrentID=0, Status='live', Symbol='TYRP1', Aliases=['CAS2', 'CATB', 'GP75', 'OCA3', 'TRP', 'TRP1', 'TYRP', 'b-PROTEIN'], description='tyrosinase related protein 1', other_designations='5,6-dihydroxyindole-2-carboxylic acid oxidase|DHICA oxidase|catalase B|glycoprotein 75|melanoma antigen gp75', map_location='9p23', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=12693375, end_position_on_the_genomic_accession=12710285, orientation='plus', exon_count=8, OMIM=[115501], no_hdr0=''),
    7307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7307, CurrentID=0, Status='live', Symbol='U2AF1', Aliases=['FP793', 'RN', 'RNU2AF1', 'U2AF35', 'U2AFBP'], description='U2 small nuclear RNA auxiliary factor 1', other_designations='splicing factor U2AF 35 kDa subunit|U2 small nuclear RNA auxillary factor 1|U2 small nuclear ribonucleoprotein auxillary factor, 35-KD subunit|U2 snRNP auxiliary factor small subunit|U2(RNU2) small nuclear RNA auxiliary factor binding protein|splicing factor U2AF 35kDa subunit', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43092956, end_position_on_the_genomic_accession=43108291, orientation='minus', exon_count=11, OMIM=[191317], no_hdr0=''),
    7311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7311, CurrentID=0, Status='live', Symbol='UBA52', Aliases=['CEP52', 'HUBCEP52', 'L40', 'RPL40'], description='ubiquitin A-52 residue ribosomal protein fusion product 1', other_designations='ubiquitin-60S ribosomal protein L40|ubiquitin carboxyl extension protein 52|ubiquitin-52 amino acid fusion protein|ubiquitin-CEP52', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18563766, end_position_on_the_genomic_accession=18577550, orientation='plus', exon_count=7, OMIM=[191321], no_hdr0=''),
    7314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7314, CurrentID=0, Status='live', Symbol='UBB', Aliases=['HEL-S-50'], description='ubiquitin B', other_designations='polyubiquitin-B|epididymis secretory protein Li 50|polyubiquitin B', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16380779, end_position_on_the_genomic_accession=16382745, orientation='plus', exon_count=5, OMIM=[191339], no_hdr0=''),
    7316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7316, CurrentID=0, Status='live', Symbol='UBC', Aliases=['HMG20'], description='ubiquitin C', other_designations='polyubiquitin-C', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124911646, end_position_on_the_genomic_accession=124914650, orientation='minus', exon_count=2, OMIM=[191340], no_hdr0=''),
    7317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7317, CurrentID=0, Status='live', Symbol='UBA1', Aliases=['A1S9', 'A1S9T', 'A1ST', 'AMCX1', 'CFAP124', 'GXP1', 'POC20', 'SMAX2A', 'UBE1', 'UBE1X', 'VEXAS', 'UBA1'], description='ubiquitin like modifier activating enzyme 1', other_designations='ubiquitin-like modifier-activating enzyme 1|A1S9T and BN75 temperature sensitivity complementing|POC20 centriolar protein homolog|UBA1, ubiquitin-activating enzyme E1 homolog A|testicular secretory protein Li 63', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47190847, end_position_on_the_genomic_accession=47215128, orientation='plus', exon_count=31, OMIM=[314370], no_hdr0=''),
    7318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7318, CurrentID=0, Status='live', Symbol='UBA7', Aliases=['D8', 'UBA1B', 'UBE1L', 'UBE2'], description='ubiquitin like modifier activating enzyme 7', other_designations='ubiquitin-like modifier-activating enzyme 7|UBA1, ubiquitin-activating enzyme E1 homolog B|UBA7, ubiquitin-activating enzyme E1|ubiquitin-activating enzyme 7|ubiquitin-activating enzyme E1 homolog|ubiquitin-activating enzyme E1-related protein|ubiquitin-activating enzyme-2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49805209, end_position_on_the_genomic_accession=49813953, orientation='minus', exon_count=24, OMIM=[191325], no_hdr0=''),
    7319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7319, CurrentID=0, Status='live', Symbol='UBE2A', Aliases=['HHR6A', 'MRXS30', 'MRXSN', 'RAD6A', 'UBC2'], description='ubiquitin conjugating enzyme E2 A', other_designations='ubiquitin-conjugating enzyme E2 A|E2 ubiquitin-conjugating enzyme A|RAD6 homolog A|ubiquitin carrier protein A|ubiquitin-conjugating enzyme E2A|ubiquitin-protein ligase A', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119574563, end_position_on_the_genomic_accession=119584423, orientation='plus', exon_count=6, OMIM=[312180], no_hdr0=''),
    7320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7320, CurrentID=0, Status='live', Symbol='UBE2B', Aliases=['E2-17kDa', 'HHR6B', 'HR6B', 'RAD6B', 'UBC2'], description='ubiquitin conjugating enzyme E2 B', other_designations='ubiquitin-conjugating enzyme E2 B|E2 protein|E2 ubiquitin-conjugating enzyme B|RAD6 homolog B|ubiquitin carrier protein B|ubiquitin conjugating enzyme E2B|ubiquitin-conjugating enzyme E2-17 kDa|ubiquitin-conjugating enzyme E2B (RAD6 homolog)|ubiquitin-protein ligase B', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134371569, end_position_on_the_genomic_accession=134392108, orientation='plus', exon_count=6, OMIM=[179095], no_hdr0=''),
    7321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7321, CurrentID=0, Status='live', Symbol='UBE2D1', Aliases=['E2(17)KB1', 'SFT', 'UBC4/5', 'UBCH5', 'UBCH5A'], description='ubiquitin conjugating enzyme E2 D1', other_designations='ubiquitin-conjugating enzyme E2 D1|(E3-independent) E2 ubiquitin-conjugating enzyme D1|E2 ubiquitin-conjugating enzyme D1|UBC4/5 homolog|stimulator of Fe transport|ubiquitin carrier protein D1|ubiquitin conjugating enzyme E2D 1|ubiquitin-conjugating enzyme E2(17)KB 1|ubiquitin-conjugating enzyme E2-17 kDa 1|ubiquitin-conjugating enzyme E2D 1 (UBC4/5 homolog, yeast)|ubiquitin-protein ligase D1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=58335006, end_position_on_the_genomic_accession=58370748, orientation='plus', exon_count=7, OMIM=[602961], no_hdr0=''),
    7322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7322, CurrentID=0, Status='live', Symbol='UBE2D2', Aliases=['E2(17)KB2', 'PUBC1', 'UBC4', 'UBC4/5', 'UBCH4', 'UBCH5B'], description='ubiquitin conjugating enzyme E2 D2', other_designations='ubiquitin-conjugating enzyme E2 D2|(E3-independent) E2 ubiquitin-conjugating enzyme D2|E2 ubiquitin-conjugating enzyme D2|p53-regulated ubiquitin-conjugating enzyme 1|ubiquitin carrier protein D2|ubiquitin conjugating enzyme E2D 2|ubiquitin-conjugating enzyme E2-17 kDa 2|ubiquitin-conjugating enzyme E2D 2 (homologous to yeast UBC4/5)|ubiquitin-protein ligase D2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139561286, end_position_on_the_genomic_accession=139628434, orientation='plus', exon_count=10, OMIM=[602962], no_hdr0=''),
    7323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7323, CurrentID=0, Status='live', Symbol='UBE2D3', Aliases=['E2(17)KB3', 'UBC4/5', 'UBCH5C'], description='ubiquitin conjugating enzyme E2 D3', other_designations='ubiquitin-conjugating enzyme E2 D3|(E3-independent) E2 ubiquitin-conjugating enzyme D3|E2 ubiquitin-conjugating enzyme D3|ubiquitin carrier protein D3|ubiquitin conjugating enzyme E2D 3|ubiquitin-conjugating enzyme E2(17)KB 3|ubiquitin-conjugating enzyme E2-17 kDa 3|ubiquitin-conjugating enzyme E2D 3 (UBC4/5 homolog, yeast)|ubiquitin-conjugating enzyme E2D 3 (homologous to yeast UBC4/5)|ubiquitin-protein ligase D3', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102794383, end_position_on_the_genomic_accession=102868895, orientation='minus', exon_count=13, OMIM=[602963], no_hdr0=''),
    7324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7324, CurrentID=0, Status='live', Symbol='UBE2E1', Aliases=['UBCH6'], description='ubiquitin conjugating enzyme E2 E1', other_designations='ubiquitin-conjugating enzyme E2 E1|(E3-independent) E2 ubiquitin-conjugating enzyme E1|E2 ubiquitin-conjugating enzyme E1|ubiquitin carrier protein E1|ubiquitin conjugating enzyme E2E 1|ubiquitin-conjugating enzyme E2E 1 (UBC4/5 homolog, yeast)|ubiquitin-conjugating enzyme E2E 1 (homologous to yeast UBC4/5)|ubiquitin-protein ligase E1', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=23805955, end_position_on_the_genomic_accession=23891640, orientation='plus', exon_count=7, OMIM=[602916], no_hdr0=''),
    7325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7325, CurrentID=0, Status='live', Symbol='UBE2E2', Aliases=['UBCH8'], description='ubiquitin conjugating enzyme E2 E2', other_designations='ubiquitin-conjugating enzyme E2 E2|E2 ubiquitin-conjugating enzyme E2|ubiquitin carrier protein E2|ubiquitin conjugating enzyme E2E 2|ubiquitin-conjugating enzyme E2E 2 (UBC4/5 homolog, yeast)|ubiquitin-conjugating enzyme E2E 2 (homologous to yeast UBC4/5)|ubiquitin-protein ligase E2', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=23203007, end_position_on_the_genomic_accession=23591925, orientation='plus', exon_count=13, OMIM=[602163], no_hdr0=''),
    7326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7326, CurrentID=0, Status='live', Symbol='UBE2G1', Aliases=['E217K', 'UBC7', 'UBE2G'], description='ubiquitin conjugating enzyme E2 G1', other_designations='ubiquitin-conjugating enzyme E2 G1|E2 ubiquitin-conjugating enzyme G1|ubiquitin carrier protein G1|ubiquitin conjugating enzyme E2G 1|ubiquitin-conjugating enzyme E2G 1 (UBC7 homolog, C. elegans)|ubiquitin-conjugating enzyme E2G 1 (UBC7 homolog, yeast)|ubiquitin-conjugating enzyme E2G 1 (homologous to C. elegans UBC7)|ubiquitin-protein ligase G1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4269259, end_position_on_the_genomic_accession=4366675, orientation='minus', exon_count=6, OMIM=[601569], no_hdr0=''),
    7327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7327, CurrentID=0, Status='live', Symbol='UBE2G2', Aliases=['UBC7'], description='ubiquitin conjugating enzyme E2 G2', other_designations='ubiquitin-conjugating enzyme E2 G2|E2 ubiquitin-conjugating enzyme G2|ubiquitin carrier protein G2|ubiquitin conjugating enzyme 7|ubiquitin conjugating enzyme G2|ubiquitin-conjugating enzyme E2G 2 (UBC7 homolog, yeast)|ubiquitin-conjugating enzyme E2G 2 (homologous to yeast UBC7)|ubiquitin-protein ligase G2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44768580, end_position_on_the_genomic_accession=44801820, orientation='minus', exon_count=8, OMIM=[603124], no_hdr0=''),
    7328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7328, CurrentID=0, Status='live', Symbol='UBE2H', Aliases=['E2-20K', 'GID3', 'UBC8', 'UBCH', 'UBCH2'], description='ubiquitin conjugating enzyme E2 H', other_designations='ubiquitin-conjugating enzyme E2 H|(E3-independent) E2 ubiquitin-conjugating enzyme H|E2 ubiquitin-conjugating enzyme H|GID complex subunit 3, UBC8 homolog|ubiquitin carrier protein H|ubiquitin conjugating enzyme E2H|ubiquitin-conjugating enzyme E2-20K|ubiquitin-conjugating enzyme E2H (UBC8 homolog, yeast)|ubiquitin-conjugating enzyme E2H (homologous to yeast UBC8)|ubiquitin-protein ligase H', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129830732, end_position_on_the_genomic_accession=129952960, orientation='minus', exon_count=7, OMIM=[601082], no_hdr0=''),
    7329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7329, CurrentID=0, Status='live', Symbol='UBE2I', Aliases=['C358B7.1', 'P18', 'UBC9'], description='ubiquitin conjugating enzyme E2 I', other_designations='SUMO-conjugating enzyme UBC9|RING-type E3 SUMO transferase UBC9|SUMO-1-protein ligase|SUMO-protein ligase|ubiquitin carrier protein 9|ubiquitin carrier protein I|ubiquitin conjugating enzyme 9|ubiquitin conjugating enzyme E2I|ubiquitin-conjugating enzyme E2I (UBC9 homolog, yeast)|ubiquitin-conjugating enzyme E2I (homologous to yeast UBC9)|ubiquitin-conjugating enzyme UbcE2A|ubiquitin-like protein SUMO-1 conjugating enzyme|ubiquitin-protein ligase E2I|ubiquitin-protein ligase I', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1309152, end_position_on_the_genomic_accession=1327017, orientation='plus', exon_count=10, OMIM=[601661], no_hdr0=''),
    7332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7332, CurrentID=0, Status='live', Symbol='UBE2L3', Aliases=['E2-F1', 'L-UBC', 'UBCH7', 'UbcM4'], description='ubiquitin conjugating enzyme E2 L3', other_designations='ubiquitin-conjugating enzyme E2 L3|E2 ubiquitin-conjugating enzyme L3|ubiquitin carrier protein L3|ubiquitin conjugating enzyme E2L 3|ubiquitin-conjugating enzyme E2-F1|ubiquitin-conjugating enzyme UBCH7|ubiquitin-protein ligase L3', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21549447, end_position_on_the_genomic_accession=21624034, orientation='plus', exon_count=6, OMIM=[603721], no_hdr0=''),
    7334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7334, CurrentID=0, Status='live', Symbol='UBE2N', Aliases=['HEL-S-71', 'UBC13', 'UBCHBEN; UBC13', 'UbcH-ben', 'UbcH13'], description='ubiquitin conjugating enzyme E2 N', other_designations='ubiquitin-conjugating enzyme E2 N|E2 ubiquitin-conjugating enzyme N|bendless-like ubiquitin conjugating enzyme|epididymis secretory protein Li 71|ubiquitin carrier protein N|ubiquitin conjugating enzyme E2N|ubiquitin-conjugating enzyme E2N (UBC13 homolog, yeast)|ubiquitin-conjugating enzyme E2N (homologous to yeast UBC13)|ubiquitin-protein ligase N|yeast UBC13 homolog', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=93405684, end_position_on_the_genomic_accession=93442336, orientation='minus', exon_count=4, OMIM=[603679], no_hdr0=''),
    7335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7335, CurrentID=0, Status='live', Symbol='UBE2V1', Aliases=['CIR1', 'CROC-1', 'CROC1', 'UBE2V', 'UEV-1', 'UEV1', 'UEV1A'], description='ubiquitin conjugating enzyme E2 V1', other_designations='ubiquitin-conjugating enzyme E2 variant 1|DNA-binding protein|TRAF6-regulated IKK activator 1 beta Uev1A', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50081124, end_position_on_the_genomic_accession=50115957, orientation='minus', exon_count=11, OMIM=[602995], no_hdr0=''),
    7336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7336, CurrentID=0, Status='live', Symbol='UBE2V2', Aliases=['DDVIT1', 'DDVit-1', 'EDAF-1', 'EDPF-1', 'EDPF1', 'MMS2', 'UEV-2', 'UEV2'], description='ubiquitin conjugating enzyme E2 V2', other_designations='ubiquitin-conjugating enzyme E2 variant 2|1 alpha,25-dihydroxyvitamin D3-inducible|DDVit 1|MMS2 homolog|enterocyte differentiation promoting factor|enterocyte differentiation-associated factor 1|enterocyte differentiation-associated factor EDAF-1|enterocyte differentiation-promoting factor 1|methyl methanesulfonate sensitive 2, S. cerevisiae, homolog of|vitamin D3-inducible protein', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47997527, end_position_on_the_genomic_accession=48064708, orientation='plus', exon_count=6, OMIM=[603001], no_hdr0=''),
    7337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7337, CurrentID=0, Status='live', Symbol='UBE3A', Aliases=['ANCR', 'AS', 'E6-AP', 'EPVE6AP', 'HPVE6A'], description='ubiquitin protein ligase E3A', other_designations='ubiquitin-protein ligase E3A|CTCL tumor antigen se37-2|E6AP ubiquitin-protein ligase|HECT-type ubiquitin transferase E3A|human papilloma virus E6-associated protein|human papillomavirus E6-associated protein|oncogenic protein-associated protein E6-AP|renal carcinoma antigen NY-REN-54', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=25333728, end_position_on_the_genomic_accession=25439381, orientation='minus', exon_count=21, OMIM=[601623], no_hdr0=''),
    7341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7341, CurrentID=0, Status='live', Symbol='SUMO1', Aliases=['DAP1', 'GMP1', 'OFC10', 'PIC1', 'SENP2', 'SMT3', 'SMT3C', 'SMT3H3', 'UBL1'], description='small ubiquitin like modifier 1', other_designations='small ubiquitin-related modifier 1|GAP modifying protein 1|SMT3 homolog 3|SMT3 suppressor of mif two 3 homolog 1|sentrin|ubiquitin-homology domain protein PIC1|ubiquitin-like protein SMT3C|ubiquitin-like protein UBL1', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202206171, end_position_on_the_genomic_accession=202238597, orientation='minus', exon_count=7, OMIM=[601912], no_hdr0=''),
    7342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7342, CurrentID=0, Status='live', Symbol='UBP1', Aliases=['LBP-1B', 'LBP-1a', 'LBP1A', 'LBP1B'], description='upstream binding protein 1', other_designations='upstream-binding protein 1|transcription factor LBP-1', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33388336, end_position_on_the_genomic_accession=33440405, orientation='minus', exon_count=19, OMIM=[609784], no_hdr0=''),
    7343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7343, CurrentID=0, Status='live', Symbol='UBTF', Aliases=['CONDBA', 'NOR-90', 'UBF', 'UBF-1', 'UBF1', 'UBF2'], description='upstream binding transcription factor', other_designations='nucleolar transcription factor 1|90-kDa nucleolus organizer region autoantigen|autoantigen NOR-90|upstream binding transcription factor, RNA polymerase I', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44205036, end_position_on_the_genomic_accession=44221304, orientation='minus', exon_count=26, OMIM=[600673], no_hdr0=''),
    7345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7345, CurrentID=0, Status='live', Symbol='UCHL1', Aliases=['HEL-117', 'HEL-S-53', 'NDGOA', 'PARK5', 'PGP 9.5', 'PGP9.5', 'PGP95', 'SPG79', 'Uch-L1'], description='ubiquitin C-terminal hydrolase L1', other_designations='ubiquitin carboxyl-terminal hydrolase isozyme L1|epididymis luminal protein 117|epididymis secretory protein Li 53|neuron cytoplasmic protein 9.5|ubiquitin carboxyl-terminal esterase L1 (ubiquitin thiolesterase)|ubiquitin thioesterase L1|ubiquitin thiolesterase', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41256928, end_position_on_the_genomic_accession=41268455, orientation='plus', exon_count=9, OMIM=[191342], no_hdr0=''),
    7347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7347, CurrentID=0, Status='live', Symbol='UCHL3', Aliases=['UCH-L3'], description='ubiquitin C-terminal hydrolase L3', other_designations='ubiquitin carboxyl-terminal hydrolase isozyme L3|testicular tissue protein Li 221|ubiquitin carboxyl-terminal esterase L3 (ubiquitin thiolesterase)|ubiquitin thioesterase L3|ubiquitin thiolesterase', map_location='13q22.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=75549490, end_position_on_the_genomic_accession=75606020, orientation='plus', exon_count=13, OMIM=[603090], no_hdr0=''),
    7348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7348, CurrentID=0, Status='live', Symbol='UPK1B', Aliases=['TSPAN20', 'UPIB', 'UPK1'], description='uroplakin 1B', other_designations='uroplakin-1b|UP1b|tetraspan|tetraspanin-20|tspan-20|uroplakin Ib', map_location='3q13.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119173598, end_position_on_the_genomic_accession=119205143, orientation='plus', exon_count=8, OMIM=[602380], no_hdr0=''),
    7349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7349, CurrentID=0, Status='live', Symbol='UCN', Aliases=['UI', 'UROC'], description='urocortin', other_designations='urocortin|prepro-urocortin|urocortin, preproprotein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27307400, end_position_on_the_genomic_accession=27308445, orientation='minus', exon_count=2, OMIM=[600945], no_hdr0=''),
    7350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7350, CurrentID=0, Status='live', Symbol='UCP1', Aliases=['SLC25A7', 'UCP'], description='uncoupling protein 1', other_designations='mitochondrial brown fat uncoupling protein 1|solute carrier family 25 member 7|thermogenin|uncoupling protein 1 (mitochondrial, proton carrier)', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140555770, end_position_on_the_genomic_accession=140568961, orientation='minus', exon_count=7, OMIM=[113730], no_hdr0=''),
    7351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7351, CurrentID=0, Status='live', Symbol='UCP2', Aliases=['BMIQ4', 'SLC25A8', 'UCPH'], description='uncoupling protein 2', other_designations='mitochondrial uncoupling protein 2|solute carrier family 25 member 8|uncoupling protein 2 (mitochondrial, proton carrier)', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73974671, end_position_on_the_genomic_accession=73983202, orientation='minus', exon_count=10, OMIM=[601693], no_hdr0=''),
    7352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7352, CurrentID=0, Status='live', Symbol='UCP3', Aliases=['SLC25A9'], description='uncoupling protein 3', other_designations='mitochondrial uncoupling protein 3|solute carrier family 25 member 9|uncoupling protein 3 (mitochondrial, proton carrier)', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74000277, end_position_on_the_genomic_accession=74009085, orientation='minus', exon_count=7, OMIM=[602044], no_hdr0=''),
    7353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7353, CurrentID=0, Status='live', Symbol='UFD1', Aliases=['UFD1L'], description='ubiquitin recognition factor in ER associated degradation 1', other_designations='ubiquitin recognition factor in ER-associated degradation protein 1|UB fusion protein 1|ubiquitin fusion degradation 1 like|ubiquitin fusion degradation protein 1 homolog', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19449911, end_position_on_the_genomic_accession=19479193, orientation='minus', exon_count=12, OMIM=[601754], no_hdr0=''),
    7355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7355, CurrentID=0, Status='live', Symbol='SLC35A2', Aliases=['CDG2M', 'CDGX', 'UDP-Gal-Tr', 'UGALT', 'UGAT', 'UGT', 'UGT1', 'UGT2', 'UGTL'], description='solute carrier family 35 member A2', other_designations='UDP-galactose translocator|solute carrier family 35 (UDP-galactose transporter), member 2|solute carrier family 35 (UDP-galactose transporter), member A2', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48903183, end_position_on_the_genomic_accession=48911958, orientation='minus', exon_count=6, OMIM=[314375], no_hdr0=''),
    7356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7356, CurrentID=0, Status='live', Symbol='SCGB1A1', Aliases=['CC10', 'CC16', 'CCPBP', 'CCSP', 'UGB', 'UP-1', 'UP1'], description='secretoglobin family 1A member 1', other_designations='uteroglobin|blastokinin|clara cell phospholipid-binding protein|clara cells 10 kDa secretory protein|secretoglobin, family 1A, member 1 (uteroglobin)|urinary protein 1|urine protein 1', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62419033, end_position_on_the_genomic_accession=62423195, orientation='plus', exon_count=3, OMIM=[192020], no_hdr0=''),
    7357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7357, CurrentID=0, Status='live', Symbol='UGCG', Aliases=['GCS', 'GLCT1'], description='UDP-glucose ceramide glucosyltransferase', other_designations='ceramide glucosyltransferase|UDP-glucose:N-acylsphingosine D-glucosyltransferase|glucosylceramide synthase', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111896766, end_position_on_the_genomic_accession=111935369, orientation='plus', exon_count=11, OMIM=[602874], no_hdr0=''),
    7358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7358, CurrentID=0, Status='live', Symbol='UGDH', Aliases=['DEE84', 'EIEE84', 'GDH', 'UDP-GlcDH', 'UDPGDH', 'UGD'], description='UDP-glucose 6-dehydrogenase', other_designations='UDP-glucose 6-dehydrogenase|UDP-Glc dehydrogenase|UDP-glucose dehydrogenase|uridine diphospho-glucose dehydrogenase', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39498755, end_position_on_the_genomic_accession=39527439, orientation='minus', exon_count=13, OMIM=[603370], no_hdr0=''),
    7360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7360, CurrentID=0, Status='live', Symbol='UGP2', Aliases=['DEE83', 'EIEE83', 'SVUGP2', 'UDPG', 'UDPGP', 'UDPGP2', 'UGP1', 'UGPP1', 'UGPP2', 'pHC379'], description='UDP-glucose pyrophosphorylase 2', other_designations='UTP--glucose-1-phosphate uridylyltransferase|UDP-glucose diphosphorylase|UDP-glucose pyrophosphorylase 1|UGPase 2|UTP--glucose-1-phosphate uridylyltransferase 2|UTP-glucose-1-phosphate uridyltransferase|Uridyl diphosphate glucose pyrophosphorylase-1|testis tissue sperm-binding protein Li 58p|uridyl diphosphate glucose pyrophosphorylase 2', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=63840969, end_position_on_the_genomic_accession=63891562, orientation='plus', exon_count=16, OMIM=[191760], no_hdr0=''),
    7363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7363, CurrentID=0, Status='live', Symbol='UGT2B4', Aliases=['HLUG25', 'UDPGT2B4', 'UDPGTH1', 'UDPGTh-1', 'UGT2B11'], description='UDP glucuronosyltransferase family 2 member B4', other_designations='UDP-glucuronosyltransferase 2B4|UDP glucuronosyltransferase 2 family, polypeptide B4|UDP-glucuronyltransferase, family 2, beta-4|UDPGT 2B4|hyodeoxycholic acid|hyodeoxycholic acid-specific UDPGT', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69480165, end_position_on_the_genomic_accession=69526014, orientation='minus', exon_count=7, OMIM=[600067], no_hdr0=''),
    7364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7364, CurrentID=0, Status='live', Symbol='UGT2B7', Aliases=['UDPGT 2B7', 'UDPGT 2B9', 'UDPGT2B7', 'UDPGTH2', 'UDPGTh-2', 'UGT2B9'], description='UDP glucuronosyltransferase family 2 member B7', other_designations='UDP-glucuronosyltransferase 2B7|3,4-catechol estrogen specific|3,4-catechol estrogen-specific UDPGT|UDP glucuronosyltransferase 2 family, polypeptide B7|UDP-glucuronosyltransferase 2B9|UDP-glucuronyltransferase, family 2, beta-7', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69051375, end_position_on_the_genomic_accession=69112987, orientation='plus', exon_count=8, OMIM=[600068], no_hdr0=''),
    7365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7365, CurrentID=0, Status='live', Symbol='UGT2B10', Aliases=['UDPGT2B10'], description='UDP glucuronosyltransferase family 2 member B10', other_designations='UDP-glucuronosyltransferase 2B10|UDP glucuronosyltransferase 2 family, polypeptide B10|UDPGT 2B10', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68815994, end_position_on_the_genomic_accession=68832038, orientation='plus', exon_count=6, OMIM=[600070], no_hdr0=''),
    7366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7366, CurrentID=0, Status='live', Symbol='UGT2B15', Aliases=['HLUG4', 'UDPGT 2B8', 'UDPGT2B15', 'UDPGTH3', 'UGT2B8'], description='UDP glucuronosyltransferase family 2 member B15', other_designations='UDP-glucuronosyltransferase 2B15|UDP glucuronosyltransferase 2 family, member 15|UDP glucuronosyltransferase 2 family, member B8|UDP glucuronosyltransferase 2 family, polypeptide B15|UDP glycosyltransferase 2B15|UDP gycosyltransferase 2 family, member B15|UDP-glucuronosyltransferase 2B8|UDP-glucuronosyltransferase UGT2B15|UDP-glucuronyltransferase, family 2, beta-15|uridine diphosphate glucuronosyltransferase 2 family, member B8|uridine diphosphate glycosyltransferase 2 family, member B15', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68646597, end_position_on_the_genomic_accession=68670652, orientation='minus', exon_count=6, OMIM=[600069], no_hdr0=''),
    7367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7367, CurrentID=0, Status='live', Symbol='UGT2B17', Aliases=['BMND12', 'UDPGT2B17'], description='UDP glucuronosyltransferase family 2 member B17', other_designations='UDP-glucuronosyltransferase 2B17|C19-steroid-specific UDP-glucuronosyltransferase|C19-steroid-specific UDPGT|UDP glucuronosyltransferase 2 family, polypeptide B17|UDP glycosyltransferase 2 family, member B17|UDP-glucuronyltransferase, family 2, beta-17', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68537173, end_position_on_the_genomic_accession=68576322, orientation='minus', exon_count=7, OMIM=[601903], no_hdr0=''),
    7368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7368, CurrentID=0, Status='live', Symbol='UGT8', Aliases=['CGT', 'UGT4'], description='UDP glycosyltransferase 8', other_designations='2-hydroxyacylsphingosine 1-beta-galactosyltransferase|UDP-galactose-ceramide galactosyltransferase|ceramide UDP-galactosyltransferase|cerebroside synthase|uridine diphosphate glycosyltransferase 8', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=114598402, end_position_on_the_genomic_accession=114687914, orientation='plus', exon_count=10, OMIM=[601291], no_hdr0=''),
    7369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7369, CurrentID=0, Status='live', Symbol='UMOD', Aliases=['ADMCKD2', 'ADTKD1', 'FJHN', 'HNFJ', 'HNFJ1', 'MCKD2', 'THGP', 'THP'], description='uromodulin', other_designations='uromodulin|Tamm-Horsfall urinary glycoprotein|uromucoid', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20333051, end_position_on_the_genomic_accession=20356301, orientation='minus', exon_count=15, OMIM=[191845], no_hdr0=''),
    7371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7371, CurrentID=0, Status='live', Symbol='UCK2', Aliases=['TSA903', 'UK', 'UMPK'], description='uridine-cytidine kinase 2', other_designations='uridine-cytidine kinase 2|cytidine monophosphokinase 2|testis-specific protein TSA903|uridine kinase|uridine monophosphate kinase|uridine monophosphokinase 2', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165827614, end_position_on_the_genomic_accession=165911618, orientation='plus', exon_count=8, OMIM=[609329], no_hdr0=''),
    7372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7372, CurrentID=0, Status='live', Symbol='UMPS', Aliases=['OPRT'], description='uridine monophosphate synthetase', other_designations="uridine 5'-monophosphate synthase|OMPdecase|OPRTase|UMP synthase|orotate phosphoribosyltransferase|orotidine 5'-phosphate decarboxylase", map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=124730442, end_position_on_the_genomic_accession=124749273, orientation='plus', exon_count=7, OMIM=[613891], no_hdr0=''),
    7373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7373, CurrentID=0, Status='live', Symbol='COL14A1', Aliases=['UND'], description='collagen type XIV alpha 1 chain', other_designations='collagen alpha-1(XIV) chain|collagen, type XIV, alpha 1|undulin (fibronectin-tenascin-related)', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=120124467, end_position_on_the_genomic_accession=120373573, orientation='plus', exon_count=50, OMIM=[120324], no_hdr0=''),
    7374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7374, CurrentID=0, Status='live', Symbol='UNG', Aliases=['DGU', 'HIGM4', 'HIGM5', 'UDG1', 'UNG15', 'UNG2', 'UNG'], description='uracil DNA glycosylase', other_designations='uracil-DNA glycosylase|uracil-DNA glycosylase 1, uracil-DNA glycosylase 2', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109097597, end_position_on_the_genomic_accession=109110992, orientation='plus', exon_count=7, OMIM=[191525], no_hdr0=''),
    7375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7375, CurrentID=0, Status='live', Symbol='USP4', Aliases=['UNP', 'Unph'], description='ubiquitin specific peptidase 4', other_designations='ubiquitin carboxyl-terminal hydrolase 4|deubiquitinating enzyme 4|ubiquitin carboxyl-terminal esterase 4|ubiquitin specific peptidase 4 (proto-oncogene)|ubiquitin specific protease 4 (proto-oncogene)|ubiquitin thioesterase 4|ubiquitin thiolesterase 4|ubiquitin-specific processing protease 4|ubiquitous nuclear protein homolog', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49277144, end_position_on_the_genomic_accession=49340053, orientation='minus', exon_count=23, OMIM=[603486], no_hdr0=''),
    7376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7376, CurrentID=0, Status='live', Symbol='NR1H2', Aliases=['LXR-b', 'LXRB', 'NER', 'NER-I', 'RIP15', 'UNR'], description='nuclear receptor subfamily 1 group H member 2', other_designations='oxysterols receptor LXR-beta|LX receptor beta|liver X nuclear receptor beta|nuclear orphan receptor LXR-beta|nuclear receptor NER|steroid hormone-nuclear receptor NER|ubiquitously-expressed nuclear receptor', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50376457, end_position_on_the_genomic_accession=50383388, orientation='plus', exon_count=10, OMIM=[600380], no_hdr0=''),
    7378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7378, CurrentID=0, Status='live', Symbol='UPP1', Aliases=['UDRPASE', 'UP', 'UPASE', 'UPP'], description='uridine phosphorylase 1', other_designations='uridine phosphorylase 1|UPase 1|urdPase 1', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=48088308, end_position_on_the_genomic_accession=48108736, orientation='plus', exon_count=10, OMIM=[191730], no_hdr0=''),
    7379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7379, CurrentID=0, Status='live', Symbol='UPK2', Aliases=['UP2', 'UPII'], description='uroplakin 2', other_designations='uroplakin-2|uroplakin II', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118956298, end_position_on_the_genomic_accession=118958559, orientation='plus', exon_count=5, OMIM=[611558], no_hdr0=''),
    7380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7380, CurrentID=0, Status='live', Symbol='UPK3A', Aliases=['UP3A', 'UPIII', 'UPIIIA', 'UPK3'], description='uroplakin 3A', other_designations='uroplakin-3a|uroplakin 3|uroplakin III', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45284949, end_position_on_the_genomic_accession=45295874, orientation='plus', exon_count=6, OMIM=[611559], no_hdr0=''),
    7381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7381, CurrentID=0, Status='live', Symbol='UQCRB', Aliases=['MC3DN3', 'QCR7', 'QP-C', 'QPC', 'UQBC', 'UQBP', 'UQCR6', 'UQPC'], description='ubiquinol-cytochrome c reductase binding protein', other_designations='cytochrome b-c1 complex subunit 7|complex III subunit 7|complex III subunit VII|mitochondrial ubiquinone-binding protein|ubiquinol-cytochrome c reductase complex 14 kDa protein|ubiquinol-cytochrome c reductase, complex III subunit VI', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96222947, end_position_on_the_genomic_accession=96235545, orientation='minus', exon_count=6, OMIM=[191330], no_hdr0=''),
    7384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7384, CurrentID=0, Status='live', Symbol='UQCRC1', Aliases=['D3S3191', 'PKNPY', 'QCR1', 'UQCR1'], description='ubiquinol-cytochrome c reductase core protein 1', other_designations='cytochrome b-c1 complex subunit 1, mitochondrial|complex III subunit 1|core protein I|ubiquinol-cytochrome c reductase core protein I|ubiquinol-cytochrome-c reductase complex core protein 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48599002, end_position_on_the_genomic_accession=48609664, orientation='minus', exon_count=12, OMIM=[191328], no_hdr0=''),
    7385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7385, CurrentID=0, Status='live', Symbol='UQCRC2', Aliases=['MC3DN5', 'QCR2', 'UQCR2'], description='ubiquinol-cytochrome c reductase core protein 2', other_designations='cytochrome b-c1 complex subunit 2, mitochondrial|complex III subunit 2|cytochrome bc-1 complex core protein II|ubiquinol-cytochrome c reductase core protein II|ubiquinol-cytochrome-c reductase complex core protein 2', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21953361, end_position_on_the_genomic_accession=21983660, orientation='plus', exon_count=14, OMIM=[191329], no_hdr0=''),
    7386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7386, CurrentID=0, Status='live', Symbol='UQCRFS1', Aliases=['MC3DN10', 'RIP1', 'RIS1', 'RISP', 'UQCR5'], description='ubiquinol-cytochrome c reductase, Rieske iron-sulfur polypeptide 1', other_designations='cytochrome b-c1 complex subunit Rieske, mitochondrial|Rieske iron-sulfur protein|Rieske protein UQCRFS1|complex III subunit 5|cytochrome b-c1 complex subunit 5|epididymis secretory sperm binding protein|ubiquinol-cytochrome c reductase iron-sulfur subunit', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29205320, end_position_on_the_genomic_accession=29213151, orientation='minus', exon_count=2, OMIM=[191327], no_hdr0=''),
    7388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7388, CurrentID=0, Status='live', Symbol='UQCRH', Aliases=['QCR6', 'UQCR8'], description='ubiquinol-cytochrome c reductase hinge protein', other_designations='cytochrome b-c1 complex subunit 6, mitochondrial|complex III subunit 6|cytochrome c1 non-heme 11 kDa protein|mitochondrial hinge protein|ubiquinol-cytochrome c reductase complex 11 kDa protein|ubiquinol-cytochrome c reductase, complex III subunit VIII', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46303698, end_position_on_the_genomic_accession=46316776, orientation='plus', exon_count=5, OMIM=[613844], no_hdr0=''),
    7389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7389, CurrentID=0, Status='live', Symbol='UROD', Aliases=['PCT', 'UPD'], description='uroporphyrinogen decarboxylase', other_designations='uroporphyrinogen decarboxylase|uroporphyrinogen III decarboxylase', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45012254, end_position_on_the_genomic_accession=45015575, orientation='plus', exon_count=10, OMIM=[613521], no_hdr0=''),
    7390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7390, CurrentID=0, Status='live', Symbol='UROS', Aliases=['UROIIIS'], description='uroporphyrinogen III synthase', other_designations='uroporphyrinogen-III synthase|hydroxymethylbilane hydrolyase|uroporphyrinogen-III cosynthase', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125784980, end_position_on_the_genomic_accession=125823280, orientation='minus', exon_count=17, OMIM=[606938], no_hdr0=''),
    7391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7391, CurrentID=0, Status='live', Symbol='USF1', Aliases=['FCHL', 'FCHL1', 'HYPLIP1', 'MLTF', 'MLTFI', 'UEF', 'bHLHb11'], description='upstream transcription factor 1', other_designations='upstream stimulatory factor 1|class B basic helix-loop-helix protein 11|major late transcription factor 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161039251, end_position_on_the_genomic_accession=161045977, orientation='minus', exon_count=12, OMIM=[191523], no_hdr0=''),
    7392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7392, CurrentID=0, Status='live', Symbol='USF2', Aliases=['FIP', 'bHLHb12'], description='upstream transcription factor 2, c-fos interacting', other_designations='upstream stimulatory factor 2|c-fos interacting protein|class B basic helix-loop-helix protein 12|major late transcription factor 2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35268962, end_position_on_the_genomic_accession=35279821, orientation='plus', exon_count=12, OMIM=[600390], no_hdr0=''),
    7398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7398, CurrentID=0, Status='live', Symbol='USP1', Aliases=['UBP'], description='ubiquitin specific peptidase 1', other_designations='ubiquitin carboxyl-terminal hydrolase 1|Ubiquitinyl hydrolase 1, Ubiquitin carboxyl-terminal hydrolase 1, ubiquitin thiolesterase 1|deubiquitinating enzyme 1|hUBP|ubiquitin specific processing protease 1|ubiquitin specific protease 1|ubiquitin thioesterase 1|ubiquitin thiolesterase 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62436395, end_position_on_the_genomic_accession=62451804, orientation='plus', exon_count=10, OMIM=[603478], no_hdr0=''),
    7399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7399, CurrentID=0, Status='live', Symbol='USH2A', Aliases=['RP39', 'US2', 'USH2', 'dJ1111A8.1'], description='usherin', other_designations='usherin|Usher syndrome 2A (autosomal recessive, mild)|usher syndrome type IIa protein|usher syndrome type-2A protein', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=215622891, end_position_on_the_genomic_accession=216423448, orientation='minus', exon_count=72, OMIM=[608400], no_hdr0=''),
    7401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7401, CurrentID=0, Status='live', Symbol='CLRN1', Aliases=['RP61', 'USH3', 'USH3A'], description='clarin 1', other_designations='clarin-1|Usher syndrome type-3 protein', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150926163, end_position_on_the_genomic_accession=150972999, orientation='minus', exon_count=6, OMIM=[606397], no_hdr0=''),
    7402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7402, CurrentID=0, Status='live', Symbol='UTRN', Aliases=['DMDL', 'DRP', 'DRP1'], description='utrophin', other_designations='utrophin|dystrophin-related protein 1', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=144285261, end_position_on_the_genomic_accession=144853034, orientation='plus', exon_count=85, OMIM=[128240], no_hdr0=''),
    7403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7403, CurrentID=0, Status='live', Symbol='KDM6A', Aliases=['KABUK2', 'UTX', 'bA386N14.2'], description='lysine demethylase 6A', other_designations='lysine-specific demethylase 6A|[histone H3]-trimethyl-L-lysine(27) demethylase 6A|bA386N14.2 (ubiquitously transcribed X chromosome tetratricopeptide repeat protein (UTX))|histone demethylase UTX|lysine (K)-specific demethylase 6A|ubiquitously transcribed tetratricopeptide repeat protein X-linked|ubiquitously-transcribed TPR gene on the X chromosome', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=44873182, end_position_on_the_genomic_accession=45112779, orientation='plus', exon_count=32, OMIM=[300128], no_hdr0=''),
    7404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7404, CurrentID=0, Status='live', Symbol='UTY', Aliases=['KDM6AL', 'KDM6C1', 'UTY'], description='ubiquitously transcribed tetratricopeptide repeat containing, Y-linked', other_designations='histone demethylase UTY|[histone H3]-trimethyl-L-lysine(27) demethylase UTY|ubiquitous TPR motif protein UTY|ubiquitously transcribed TPR gene on Y chromosome|ubiquitously transcribed tetratricopeptide repeat gene, Y chromosome|ubiquitously transcribed tetratricopeptide repeat gene, Y-linked|ubiquitously-transcribed TPR protein on the Y chromosome|ubiquitously-transcribed Y chromosome tetratricopeptide repeat protein', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=13231827, end_position_on_the_genomic_accession=13480670, orientation='minus', exon_count=45, OMIM=[400009], no_hdr0=''),
    7405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7405, CurrentID=0, Status='live', Symbol='UVRAG', Aliases=['DHTX', 'VPS38', 'p63'], description='UV radiation resistance associated', other_designations='UV radiation resistance-associated gene protein|beclin 1 binding protein|disrupted in heterotaxy', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75815189, end_position_on_the_genomic_accession=76144232, orientation='plus', exon_count=23, OMIM=[602493], no_hdr0=''),
    7407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7407, CurrentID=0, Status='live', Symbol='VARS1', Aliases=['G7A', 'NDMSCA', 'VARS', 'VARS2'], description='valyl-tRNA synthetase 1', other_designations='valine--tRNA ligase|protein G7a|valRS|valine tRNA ligase 1, cytoplasmic|valyl-tRNA synthetase 2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31777518, end_position_on_the_genomic_accession=31795928, orientation='minus', exon_count=30, OMIM=[192150], no_hdr0=''),
    7408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7408, CurrentID=0, Status='live', Symbol='VASP', Aliases=[], description='vasodilator stimulated phosphoprotein', other_designations='vasodilator-stimulated phosphoprotein', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45507459, end_position_on_the_genomic_accession=45526989, orientation='plus', exon_count=13, OMIM=[601703], no_hdr0=''),
    7409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7409, CurrentID=0, Status='live', Symbol='VAV1', Aliases=['VAV'], description='vav guanine nucleotide exchange factor 1', other_designations='proto-oncogene vav|vav 1 guanine nucleotide exchange factor|vav 1 oncogene', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6772708, end_position_on_the_genomic_accession=6857366, orientation='plus', exon_count=27, OMIM=[164875], no_hdr0=''),
    7410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7410, CurrentID=0, Status='live', Symbol='VAV2', Aliases=['VAV-2'], description='vav guanine nucleotide exchange factor 2', other_designations='guanine nucleotide exchange factor VAV2|vav 2 oncogene', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133761894, end_position_on_the_genomic_accession=133992374, orientation='minus', exon_count=32, OMIM=[600428], no_hdr0=''),
    7411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7411, CurrentID=0, Status='live', Symbol='VBP1', Aliases=['HIBBJ46', 'PFD3', 'PFDN3', 'VBP-1'], description='VHL binding protein 1', other_designations='prefoldin subunit 3|von Hippel-Lindau binding protein 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155197007, end_position_on_the_genomic_accession=155239841, orientation='plus', exon_count=8, OMIM=[300133], no_hdr0=''),
    7412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7412, CurrentID=0, Status='live', Symbol='VCAM1', Aliases=['CD106', 'INCAM-100'], description='vascular cell adhesion molecule 1', other_designations='vascular cell adhesion protein 1|CD106 antigen', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100719742, end_position_on_the_genomic_accession=100739045, orientation='plus', exon_count=9, OMIM=[192225], no_hdr0=''),
    7414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7414, CurrentID=0, Status='live', Symbol='VCL', Aliases=['CMD1W', 'CMH15', 'HEL114', 'MV', 'MVCL'], description='vinculin', other_designations='vinculin|epididymis luminal protein 114|epididymis secretory sperm binding protein|meta-vinculin|metavinculin|vinculin isoform meta-VCL', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73998116, end_position_on_the_genomic_accession=74121363, orientation='plus', exon_count=22, OMIM=[193065], no_hdr0=''),
    7415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7415, CurrentID=0, Status='live', Symbol='VCP', Aliases=['CDC48', 'FTDALS6', 'TERA', 'p97'], description='valosin containing protein', other_designations='transitional endoplasmic reticulum ATPase|15S Mg(2+)-ATPase p97 subunit|TER ATPase', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35056064, end_position_on_the_genomic_accession=35072625, orientation='minus', exon_count=17, OMIM=[601023], no_hdr0=''),
    7416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7416, CurrentID=0, Status='live', Symbol='VDAC1', Aliases=['PORIN', 'VDAC-1'], description='voltage dependent anion channel 1', other_designations='voltage-dependent anion-selective channel protein 1|outer mitochondrial membrane protein porin 1|plasmalemmal porin|porin 31HL|porin 31HM|sperm binding protein 1a', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=133971871, end_position_on_the_genomic_accession=134070987, orientation='minus', exon_count=11, OMIM=[604492], no_hdr0=''),
    7417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7417, CurrentID=0, Status='live', Symbol='VDAC2', Aliases=['POR'], description='voltage dependent anion channel 2', other_designations='voltage-dependent anion-selective channel protein 2|epididymis secretory sperm binding protein|outer mitochondrial membrane protein porin 2', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75210170, end_position_on_the_genomic_accession=75231448, orientation='plus', exon_count=13, OMIM=[193245], no_hdr0=''),
    7419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7419, CurrentID=0, Status='live', Symbol='VDAC3', Aliases=['HD-VDAC3', 'VDAC-3'], description='voltage dependent anion channel 3', other_designations='voltage-dependent anion-selective channel protein 3|outer mitochondrial membrane protein porin 3', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42391624, end_position_on_the_genomic_accession=42405937, orientation='plus', exon_count=11, OMIM=[610029], no_hdr0=''),
    7421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7421, CurrentID=0, Status='live', Symbol='VDR', Aliases=['NR1I1', 'PPP1R163'], description='vitamin D receptor', other_designations='vitamin D3 receptor|1,25-dihydroxyvitamin D3 receptor|nuclear receptor subfamily 1 group I member 1|protein phosphatase 1, regulatory subunit 163|vitamin D (1,25- dihydroxyvitamin D3) receptor|vitamin D nuclear receptor variant 1|vitamin D3 receptor isoform VDRA', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47841537, end_position_on_the_genomic_accession=47905022, orientation='minus', exon_count=12, OMIM=[601769], no_hdr0=''),
    7422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7422, CurrentID=0, Status='live', Symbol='VEGFA', Aliases=['MVCD1', 'VEGF', 'VPF'], description='vascular endothelial growth factor A', other_designations='vascular endothelial growth factor A|vascular endothelial growth factor A121|vascular endothelial growth factor A165|vascular permeability factor', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43770209, end_position_on_the_genomic_accession=43786487, orientation='plus', exon_count=9, OMIM=[192240], no_hdr0=''),
    7423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7423, CurrentID=0, Status='live', Symbol='VEGFB', Aliases=['VEGFL', 'VRF'], description='vascular endothelial growth factor B', other_designations='vascular endothelial growth factor B|VEGF-related factor', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64234584, end_position_on_the_genomic_accession=64239264, orientation='plus', exon_count=7, OMIM=[601398], no_hdr0=''),
    7424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7424, CurrentID=0, Status='live', Symbol='VEGFC', Aliases=['Flt4-L', 'LMPH1D', 'LMPHM4', 'VRP'], description='vascular endothelial growth factor C', other_designations='vascular endothelial growth factor C|FLT4 ligand DHM|vascular endothelial growth factor-related protein', map_location='4q34.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=176683538, end_position_on_the_genomic_accession=176792922, orientation='minus', exon_count=7, OMIM=[601528], no_hdr0=''),
    7425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7425, CurrentID=0, Status='live', Symbol='VGF', Aliases=['SCG7', 'SgVII'], description='VGF nerve growth factor inducible', other_designations='neurosecretory protein VGF|neuro-endocrine specific protein VGF', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101162509, end_position_on_the_genomic_accession=101169956, orientation='minus', exon_count=5, OMIM=[602186], no_hdr0=''),
    7428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7428, CurrentID=0, Status='live', Symbol='VHL', Aliases=['HRCA1', 'RCA11', 'pVHL', 'VHL'], description='von Hippel-Lindau tumor suppressor', other_designations='von Hippel-Lindau disease tumor suppressor|elongin binding protein|protein G7|von Hippel-Lindau tumor suppressor, E3 ubiquitin protein ligase', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10141778, end_position_on_the_genomic_accession=10153667, orientation='plus', exon_count=4, OMIM=[608537], no_hdr0=''),
    7429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7429, CurrentID=0, Status='live', Symbol='VIL1', Aliases=['D2S1471', 'VIL'], description='villin 1', other_designations='villin-1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218419123, end_position_on_the_genomic_accession=218453295, orientation='plus', exon_count=20, OMIM=[193040], no_hdr0=''),
    7430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7430, CurrentID=0, Status='live', Symbol='EZR', Aliases=['CVIL', 'CVL', 'HEL-S-105', 'VIL2'], description='ezrin', other_designations='ezrin|cytovillin 2|epididymis secretory protein Li 105|p81|villin 2 (ezrin)', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158765744, end_position_on_the_genomic_accession=158819368, orientation='minus', exon_count=14, OMIM=[123900], no_hdr0=''),
    7431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7431, CurrentID=0, Status='live', Symbol='VIM', Aliases=[], description='vimentin', other_designations='vimentin|epididymis secretory sperm binding protein', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17228241, end_position_on_the_genomic_accession=17237593, orientation='plus', exon_count=10, OMIM=[193060], no_hdr0=''),
    7432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7432, CurrentID=0, Status='live', Symbol='VIP', Aliases=['PHM27'], description='vasoactive intestinal peptide', other_designations='VIP peptides|prepro-VIP', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=152750797, end_position_on_the_genomic_accession=152759765, orientation='plus', exon_count=7, OMIM=[192320], no_hdr0=''),
    7433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7433, CurrentID=0, Status='live', Symbol='VIPR1', Aliases=['HVR1', 'II', 'PACAP-R-2', 'PACAP-R2', 'RDC1', 'V1RG', 'VAPC1', 'VIP-R-1', 'VIPR', 'VIRG', 'VPAC1', 'VPAC1R', 'VPCAP1R'], description='vasoactive intestinal peptide receptor 1', other_designations='vasoactive intestinal polypeptide receptor 1|PACAP type II receptor|VIP and PACAP receptor 1|VIP receptor, type I|VPAC1 receptor|pituitary adenylate cyclase activating polypeptide receptor, type II|type 1 vasoactive intestinal peptide receptor', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42489299, end_position_on_the_genomic_accession=42537573, orientation='plus', exon_count=16, OMIM=[192321], no_hdr0=''),
    7434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7434, CurrentID=0, Status='live', Symbol='VIPR2', Aliases=['C16DUPq36.3', 'DUP7q36.3', 'PACAP-R-3', 'PACAP-R3', 'VIP-R-2', 'VPAC2', 'VPAC2R', 'VPCAP2R'], description='vasoactive intestinal peptide receptor 2', other_designations='vasoactive intestinal polypeptide receptor 2|PACAP type III receptor|VIP and PACAP receptor 2|helodermin-preferring VIP receptor|pituitary adenylate cyclase-activating polypeptide type III receptor', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=159028175, end_position_on_the_genomic_accession=159144957, orientation='minus', exon_count=18, OMIM=[601970], no_hdr0=''),
    7436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7436, CurrentID=0, Status='live', Symbol='VLDLR', Aliases=['CAMRQ1', 'CARMQ1', 'CHRMQ1', 'VLDL-RCH', 'VLDLR'], description='very low density lipoprotein receptor', other_designations='very low-density lipoprotein receptor|VLDL receptor', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=2621786, end_position_on_the_genomic_accession=2660056, orientation='plus', exon_count=19, OMIM=[192977], no_hdr0=''),
    7439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7439, CurrentID=0, Status='live', Symbol='BEST1', Aliases=['ARB', 'BEST', 'BMD', 'Best1V1Delta2', 'RP50', 'TU15B', 'VMD2'], description='bestrophin 1', other_designations='bestrophin-1|Best disease|vitelliform macular dystrophy protein 2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61946722, end_position_on_the_genomic_accession=61965515, orientation='plus', exon_count=14, OMIM=[607854], no_hdr0=''),
    7441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7441, CurrentID=0, Status='live', Symbol='VPREB1', Aliases=['CD179a', 'IGI', 'IGVPB', 'VPREB'], description='V-set pre-B cell surrogate light chain 1', other_designations='immunoglobulin iota chain|CD179 antigen-like family member A|pre-B lymphocyte 1|v(pre)B protein', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22244786, end_position_on_the_genomic_accession=22245515, orientation='plus', exon_count=2, OMIM=[605141], no_hdr0=''),
    7442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7442, CurrentID=0, Status='live', Symbol='TRPV1', Aliases=['VR1'], description='transient receptor potential cation channel subfamily V member 1', other_designations='transient receptor potential cation channel subfamily V member 1|OTRPC1|capsaicin receptor|osm-9-like TRP channel 1|transient receptor potential vanilloid 1a|transient receptor potential vanilloid 1b|vanilloid receptor subtype 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3565446, end_position_on_the_genomic_accession=3609411, orientation='minus', exon_count=19, OMIM=[602076], no_hdr0=''),
    7443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7443, CurrentID=0, Status='live', Symbol='VRK1', Aliases=['PCH1', 'PCH1A'], description='VRK serine/threonine kinase 1', other_designations='serine/threonine-protein kinase VRK1|vaccinia related kinase 1|vaccinia virus B1R-related kinase 1', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96797382, end_position_on_the_genomic_accession=96881614, orientation='plus', exon_count=15, OMIM=[602168], no_hdr0=''),
    7444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7444, CurrentID=0, Status='live', Symbol='VRK2', Aliases=[], description='VRK serine/threonine kinase 2', other_designations='serine/threonine-protein kinase VRK2|vaccinia related kinase 2|vaccinia virus B1R-related kinase 2', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=57907592, end_position_on_the_genomic_accession=58163993, orientation='plus', exon_count=22, OMIM=[602169], no_hdr0=''),
    7447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7447, CurrentID=0, Status='live', Symbol='VSNL1', Aliases=['HLP3', 'HPCAL3', 'HUVISL1', 'VILIP', 'VILIP-1'], description='visinin like 1', other_designations='visinin-like protein 1|VLP-1|hippocalcin-like protein 3', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17539972, end_position_on_the_genomic_accession=17657018, orientation='plus', exon_count=6, OMIM=[600817], no_hdr0=''),
    7448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7448, CurrentID=0, Status='live', Symbol='VTN', Aliases=['V75', 'VN', 'VNT'], description='vitronectin', other_designations='vitronectin|complement S-protein|epibolin|serum spreading factor|somatomedin B', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28367284, end_position_on_the_genomic_accession=28370307, orientation='minus', exon_count=8, OMIM=[193190], no_hdr0=''),
    7450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7450, CurrentID=0, Status='live', Symbol='VWF', Aliases=['F8VWF', 'VWD'], description='von Willebrand factor', other_designations='von Willebrand factor|coagulation factor VIII VWF', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=5948877, end_position_on_the_genomic_accession=6124670, orientation='minus', exon_count=52, OMIM=[613160], no_hdr0=''),
    7453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7453, CurrentID=0, Status='live', Symbol='WARS1', Aliases=['GAMMA-2', 'HMN9', 'IFI53', 'IFP53', 'WARS'], description='tryptophanyl-tRNA synthetase 1', other_designations='tryptophan--tRNA ligase, cytoplasmic|epididymis secretory sperm binding protein|hWRS|interferon-induced protein 53|trpRS|tryptophan tRNA ligase 1, cytoplasmic', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100333789, end_position_on_the_genomic_accession=100376327, orientation='minus', exon_count=15, OMIM=[191050], no_hdr0=''),
    7454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7454, CurrentID=0, Status='live', Symbol='WAS', Aliases=['IMD2', 'SCNX', 'THC', 'THC1P', 'WASPA', 'WAS'], description='WASP actin nucleation promoting factor', other_designations='wiskott-Aldrich syndrome protein|eczema-thrombocytopenia|thrombocytopenia 1 (X-linked)', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48683753, end_position_on_the_genomic_accession=48691427, orientation='plus', exon_count=13, OMIM=[300392], no_hdr0=''),
    7455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7455, CurrentID=0, Status='live', Symbol='ZAN', Aliases=[], description='zonadhesin', other_designations='zonadhesin', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100733595, end_position_on_the_genomic_accession=100797797, orientation='plus', exon_count=48, OMIM=[602372], no_hdr0=''),
    7456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7456, CurrentID=0, Status='live', Symbol='WIPF1', Aliases=['PRPL-2', 'WAS2', 'WASPIP', 'WIP'], description='WAS/WASL interacting protein family member 1', other_designations='WAS/WASL-interacting protein family member 1|WASP-interacting protein|Wiskott-Aldrich syndrome protein interacting protein|protein PRPL-2|testicular tissue protein Li 226', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174559574, end_position_on_the_genomic_accession=174682913, orientation='minus', exon_count=14, OMIM=[602357], no_hdr0=''),
    7458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7458, CurrentID=0, Status='live', Symbol='EIF4H', Aliases=['WBSCR1', 'WSCR1', 'eIF-4H'], description='eukaryotic translation initiation factor 4H', other_designations='eukaryotic translation initiation factor 4H|Williams-Beuren syndrome chromosome region 1', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74174356, end_position_on_the_genomic_accession=74197096, orientation='plus', exon_count=7, OMIM=[603431], no_hdr0=''),
    7461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7461, CurrentID=0, Status='live', Symbol='CLIP2', Aliases=['CLIP', 'CLIP-115', 'CYLN2', 'WBSCR3', 'WBSCR4', 'WSCR3', 'WSCR4'], description='CAP-Gly domain containing linker protein 2', other_designations='CAP-Gly domain-containing linker protein 2|Williams-Beuren syndrome chromosome region 3|Williams-Beuren syndrome chromosome region 4|cytoplasmic linker 2|cytoplasmic linker protein 115|cytoplasmic linker protein 2|testicular tissue protein Li 40|williams-Beuren syndrome chromosomal region 3 protein|williams-Beuren syndrome chromosomal region 4 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74289407, end_position_on_the_genomic_accession=74405943, orientation='plus', exon_count=17, OMIM=[603432], no_hdr0=''),
    7462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7462, CurrentID=0, Status='live', Symbol='LAT2', Aliases=['HSPC046', 'LAB', 'NTAL', 'WBSCR15', 'WBSCR5', 'WSCR5'], description='linker for activation of T cells family member 2', other_designations='linker for activation of T-cells family member 2|Williams-Beuren syndrome chromosomal region 15 protein|Williams-Beuren syndrome chromosomal region 5 protein|linker for activation of B-cells|linker for activation of T cells, transmembrane adaptor 2|membrane-associated adapter molecule|non-T-cell activation linker', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74210006, end_position_on_the_genomic_accession=74229834, orientation='plus', exon_count=14, OMIM=[605719], no_hdr0=''),
    7464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7464, CurrentID=0, Status='live', Symbol='CORO2A', Aliases=['CLIPINB', 'IR10', 'WDR2'], description='coronin 2A', other_designations='coronin-2A|WD protein IR10|WD repeat-containing protein 2|WD-repeat protein 2|coronin, actin binding protein, 2A|coronin-like protein B', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98120975, end_position_on_the_genomic_accession=98192637, orientation='minus', exon_count=14, OMIM=[602159], no_hdr0=''),
    7465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7465, CurrentID=0, Status='live', Symbol='WEE1', Aliases=['WEE1Ahu', 'WEE1'], description='WEE1 G2 checkpoint kinase', other_designations='wee1-like protein kinase|WEE1 homolog|WEE1+ homolog|wee1A kinase', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9573670, end_position_on_the_genomic_accession=9589985, orientation='plus', exon_count=12, OMIM=[193525], no_hdr0=''),
    7466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7466, CurrentID=0, Status='live', Symbol='WFS1', Aliases=['CTRCT41', 'WFRS', 'WFS', 'WFSL'], description='wolframin ER transmembrane glycoprotein', other_designations='wolframin|Wolfram syndrome 1 (wolframin)', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6260368, end_position_on_the_genomic_accession=6303265, orientation='plus', exon_count=10, OMIM=[606201], no_hdr0=''),
    7468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7468, CurrentID=0, Status='live', Symbol='NSD2', Aliases=['KMT3F', 'KMT3G', 'MMSET', 'REIIBP', 'TRX5', 'WHS', 'WHSC1'], description='nuclear receptor binding SET domain protein 2', other_designations='histone-lysine N-methyltransferase NSD2|IL5 promoter REII region-binding protein|Wolf-Hirschhorn syndrome candidate 1|multiple myeloma SET domain containing protein type III|nuclear SET domain-containing protein 2|probable histone-lysine N-methyltransferase NSD2|trithorax/ash1-related protein 5', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1871393, end_position_on_the_genomic_accession=1982207, orientation='plus', exon_count=29, OMIM=[602952], no_hdr0=''),
    7469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7469, CurrentID=0, Status='live', Symbol='NELFA', Aliases=['NELF-A', 'P/OKcl.15', 'WHSC2'], description='negative elongation factor complex member A', other_designations='negative elongation factor A|wolf-Hirschhorn syndrome candidate 2 protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1982717, end_position_on_the_genomic_accession=2041914, orientation='minus', exon_count=15, OMIM=[606026], no_hdr0=''),
    7471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7471, CurrentID=0, Status='live', Symbol='WNT1', Aliases=['BMND16', 'INT1', 'OI15'], description='Wnt family member 1', other_designations='proto-oncogene Wnt-1|proto-oncogene Int-1 homolog|wingless-type MMTV integration site family member 1|wingless-type MMTV integration site family, member 1 (oncogene INT1)', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48978322, end_position_on_the_genomic_accession=48982620, orientation='plus', exon_count=4, OMIM=[164820], no_hdr0=''),
    7472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7472, CurrentID=0, Status='live', Symbol='WNT2', Aliases=['INT1L1', 'IRP'], description='Wnt family member 2', other_designations='protein Wnt-2|Int-1-related protein|epididymis secretory sperm binding protein|int-1-like protein 1|secreted growth factor|wingless-type MMTV integration site family member 2', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=117275451, end_position_on_the_genomic_accession=117323058, orientation='minus', exon_count=5, OMIM=[147870], no_hdr0=''),
    7473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7473, CurrentID=0, Status='live', Symbol='WNT3', Aliases=['INT4', 'TETAMS'], description='Wnt family member 3', other_designations='proto-oncogene Wnt-3|WNT-3 proto-oncogene protein|proto-oncogene Int-4 homolog|wingless-type MMTV integration site family, member 3', map_location='17q21.31-q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46762506, end_position_on_the_genomic_accession=46818692, orientation='minus', exon_count=5, OMIM=[165330], no_hdr0=''),
    7474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7474, CurrentID=0, Status='live', Symbol='WNT5A', Aliases=['hWNT5A'], description='Wnt family member 5A', other_designations='protein Wnt-5a|WNT-5A protein|epididymis secretory sperm binding protein|wingless-type MMTV integration site family, member 5A', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=55465715, end_position_on_the_genomic_accession=55505261, orientation='minus', exon_count=15, OMIM=[164975], no_hdr0=''),
    7475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7475, CurrentID=0, Status='live', Symbol='WNT6', Aliases=[], description='Wnt family member 6', other_designations='protein Wnt-6|wingless-type MMTV integration site family, member 6', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218859805, end_position_on_the_genomic_accession=218874233, orientation='plus', exon_count=4, OMIM=[604663], no_hdr0=''),
    7476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7476, CurrentID=0, Status='live', Symbol='WNT7A', Aliases=['Wnt-7a'], description='Wnt family member 7A', other_designations='protein Wnt-7a|proto-oncogene Wnt7a protein|wingless-type MMTV integration site family, member 7A', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=13816258, end_position_on_the_genomic_accession=13880071, orientation='minus', exon_count=6, OMIM=[601570], no_hdr0=''),
    7477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7477, CurrentID=0, Status='live', Symbol='WNT7B', Aliases=[], description='Wnt family member 7B', other_designations='protein Wnt-7b|wingless-type MMTV integration site family, member 7B', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45920362, end_position_on_the_genomic_accession=45977162, orientation='minus', exon_count=5, OMIM=[601967], no_hdr0=''),
    7478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7478, CurrentID=0, Status='live', Symbol='WNT8A', Aliases=['WNT8D'], description='Wnt family member 8A', other_designations='protein Wnt-8a|WNT8d|protein Wnt-8d|wingless-type MMTV integration site family, member 8A', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138077367, end_position_on_the_genomic_accession=138092900, orientation='plus', exon_count=10, OMIM=[606360], no_hdr0=''),
    7479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7479, CurrentID=0, Status='live', Symbol='WNT8B', Aliases=[], description='Wnt family member 8B', other_designations='protein Wnt-8b|epididymis secretory sperm binding protein|wingless-type MMTV integration site family, member 8B', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100463009, end_position_on_the_genomic_accession=100483744, orientation='plus', exon_count=6, OMIM=[601396], no_hdr0=''),
    7480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7480, CurrentID=0, Status='live', Symbol='WNT10B', Aliases=['SHFM6', 'STHAG8', 'WNT-12'], description='Wnt family member 10B', other_designations='protein Wnt-10b|WNT-10B protein|wingless-type MMTV integration site family, member 10B', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48965340, end_position_on_the_genomic_accession=48979587, orientation='minus', exon_count=8, OMIM=[601906], no_hdr0=''),
    7481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7481, CurrentID=0, Status='live', Symbol='WNT11', Aliases=['HWNT11'], description='Wnt family member 11', other_designations='protein Wnt-11|wingless-type MMTV integration site family, member 11', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76186325, end_position_on_the_genomic_accession=76210842, orientation='minus', exon_count=8, OMIM=[603699], no_hdr0=''),
    7482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7482, CurrentID=0, Status='live', Symbol='WNT2B', Aliases=['WNT13'], description='Wnt family member 2B', other_designations='protein Wnt-2b|XWNT2, Xenopus, homolog of|wingless-type MMTV integration site family, member 13|wingless-type MMTV integration site family, member 2B', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112466541, end_position_on_the_genomic_accession=112530165, orientation='plus', exon_count=7, OMIM=[601968], no_hdr0=''),
    7483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7483, CurrentID=0, Status='live', Symbol='WNT9A', Aliases=['WNT14'], description='Wnt family member 9A', other_designations='protein Wnt-9a|wingless-type MMTV integration site family, member 14|wingless-type MMTV integration site family, member 9A', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=227918656, end_position_on_the_genomic_accession=227947932, orientation='minus', exon_count=5, OMIM=[602863], no_hdr0=''),
    7484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7484, CurrentID=0, Status='live', Symbol='WNT9B', Aliases=['WNT14B', 'WNT15'], description='Wnt family member 9B', other_designations='protein Wnt-9b|protein Wnt-14b|wingless-type MMTV integration site family member 9B|wingless-type MMTV integration site family, member 15', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46833201, end_position_on_the_genomic_accession=46886738, orientation='plus', exon_count=6, OMIM=[602864], no_hdr0=''),
    7485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7485, CurrentID=0, Status='live', Symbol='GET1', Aliases=['CHD5', 'WRB'], description='guided entry of tail-anchored proteins factor 1', other_designations='guided entry of tail-anchored proteins factor 1|congenital heart disease 5 protein|tail-anchored protein insertion receptor WRB|tryptophan rich basic protein', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39380326, end_position_on_the_genomic_accession=39428528, orientation='plus', exon_count=14, OMIM=[602915], no_hdr0=''),
    7486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7486, CurrentID=0, Status='live', Symbol='WRN', Aliases=['RECQ3', 'RECQL2', 'RECQL3'], description='WRN RecQ like helicase', other_designations='Werner syndrome ATP-dependent helicase|DNA helicase, RecQ-like type 3|Werner syndrome RecQ like helicase|Werner syndrome, RecQ helicase-like|exonuclease WRN|recQ protein-like 2', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=31033749, end_position_on_the_genomic_accession=31176138, orientation='plus', exon_count=38, OMIM=[604611], no_hdr0=''),
    7490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7490, CurrentID=0, Status='live', Symbol='WT1', Aliases=['AWT1', 'GUD', 'NPHS4', 'WAGR', 'WIT-2', 'WT33'], description='WT1 transcription factor', other_designations='Wilms tumor protein|Wilms tumor 1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32387775, end_position_on_the_genomic_accession=32435539, orientation='minus', exon_count=12, OMIM=[607102], no_hdr0=''),
    7494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7494, CurrentID=0, Status='live', Symbol='XBP1', Aliases=['TREB-5', 'TREB5', 'XBP-1', 'XBP2'], description='X-box binding protein 1', other_designations='X-box-binding protein 1|tax-responsive element-binding protein 5', map_location='22q12', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=28794560, end_position_on_the_genomic_accession=28800569, orientation='minus', exon_count=7, OMIM=[194355], no_hdr0=''),
    7498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7498, CurrentID=0, Status='live', Symbol='XDH', Aliases=['XAN1', 'XO', 'XOR'], description='xanthine dehydrogenase', other_designations='xanthine dehydrogenase/oxidase|xanthine oxidoreductase', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=31334320, end_position_on_the_genomic_accession=31414777, orientation='minus', exon_count=37, OMIM=[607633], no_hdr0=''),
    7499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7499, CurrentID=0, Status='live', Symbol='XG', Aliases=['PBDX'], description='Xg glycoprotein (Xg blood group)', other_designations='glycoprotein Xg|Xg blood group (pseudoautosomal boundary-divided on the X chromosome)', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2751104, end_position_on_the_genomic_accession=2816500, orientation='plus', exon_count=11, OMIM=[300879], no_hdr0=''),
    7504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7504, CurrentID=0, Status='live', Symbol='XK', Aliases=['KX', 'NA', 'NAC', 'X1kR1', 'XK'], description='X-linked Kx blood group', other_designations='membrane transport protein XK|Kell blood group precursor (McLeod phenotype)|Kx antigen|Kx blood group antigen|XK, Kell blood group complex subunit (McLeod syndrome)|XK-related protein 1|kell complex 37 kDa component|truncated X-linked Kx blood group', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37685686, end_position_on_the_genomic_accession=37732130, orientation='plus', exon_count=4, OMIM=[314850], no_hdr0=''),
    7507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7507, CurrentID=0, Status='live', Symbol='XPA', Aliases=['XP1C', 'XPA'], description='XPA, DNA damage recognition and repair factor', other_designations='DNA repair protein complementing XP-A cells|xeroderma pigmentosum group A-complementing protein|xeroderma pigmentosum, complementation group A', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97654398, end_position_on_the_genomic_accession=97697403, orientation='minus', exon_count=9, OMIM=[611153], no_hdr0=''),
    7508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7508, CurrentID=0, Status='live', Symbol='XPC', Aliases=['RAD4', 'XP3C', 'p125', 'XPC'], description='XPC complex subunit, DNA damage recognition and repair factor', other_designations='DNA repair protein complementing XP-C cells|mutant xeroderma pigmentosum group C|xeroderma pigmentosum, complementation group C', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14145145, end_position_on_the_genomic_accession=14178601, orientation='minus', exon_count=18, OMIM=[613208], no_hdr0=''),
    7511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7511, CurrentID=0, Status='live', Symbol='XPNPEP1', Aliases=['APP1', 'SAMP', 'XPNPEP', 'XPNPEPL', 'XPNPEPL1'], description='X-prolyl aminopeptidase 1', other_designations='xaa-Pro aminopeptidase 1|X-Pro aminopeptidase 1|X-prolyl aminopeptidase (aminopeptidase P) 1, soluble|X-prolyl aminopeptidase 1, soluble|aminoacylproline aminopeptidase|aminopeptidase P, cytosolic|cytosolic aminopeptidase P|soluble aminopeptidase P', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=109864766, end_position_on_the_genomic_accession=109923511, orientation='minus', exon_count=24, OMIM=[602443], no_hdr0=''),
    7512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7512, CurrentID=0, Status='live', Symbol='XPNPEP2', Aliases=['AEACEI', 'APP2'], description='X-prolyl aminopeptidase 2', other_designations='xaa-Pro aminopeptidase 2|X-Pro aminopeptidase 2|X-prolyl aminopeptidase (aminopeptidase P) 2, membrane-bound|aminoacylproline aminopeptidase|mAmP|membrane-bound APP|membrane-bound AmP|membrane-bound aminopeptidase P', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129738979, end_position_on_the_genomic_accession=129769536, orientation='plus', exon_count=21, OMIM=[300145], no_hdr0=''),
    7514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7514, CurrentID=0, Status='live', Symbol='XPO1', Aliases=['CRM-1', 'CRM1', 'emb', 'exp1'], description='exportin 1', other_designations='exportin-1|chromosome region maintenance 1 homolog|chromosome region maintenance 1 protein homolog|exportin 1 (CRM1 homolog, yeast)|exportin-1 (required for chromosome region maintenance)', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61477849, end_position_on_the_genomic_accession=61538522, orientation='minus', exon_count=31, OMIM=[602559], no_hdr0=''),
    7515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7515, CurrentID=0, Status='live', Symbol='XRCC1', Aliases=['RCC', 'SCAR26'], description='X-ray repair cross complementing 1', other_designations='DNA repair protein XRCC1|X-ray repair complementing defective repair in Chinese hamster cells 1|X-ray repair cross-complementing protein 1', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43543311, end_position_on_the_genomic_accession=43575527, orientation='minus', exon_count=17, OMIM=[194360], no_hdr0=''),
    7516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7516, CurrentID=0, Status='live', Symbol='XRCC2', Aliases=['FANCU', 'POF17', 'SPGF50'], description='X-ray repair cross complementing 2', other_designations='DNA repair protein XRCC2|X-ray repair complementing defective repair in Chinese hamster cells 2|X-ray repair cross-complementing protein 2|epididymis secretory sperm binding protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=152644776, end_position_on_the_genomic_accession=152676141, orientation='minus', exon_count=3, OMIM=[600375], no_hdr0=''),
    7517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7517, CurrentID=0, Status='live', Symbol='XRCC3', Aliases=['CMM6'], description='X-ray repair cross complementing 3', other_designations='DNA repair protein XRCC3|X-ray repair complementing defective repair in Chinese hamster cells 3|X-ray repair cross-complementing protein 3', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103697611, end_position_on_the_genomic_accession=103715486, orientation='minus', exon_count=10, OMIM=[600675], no_hdr0=''),
    7518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7518, CurrentID=0, Status='live', Symbol='XRCC4', Aliases=['SSMED'], description='X-ray repair cross complementing 4', other_designations='DNA repair protein XRCC4|X-ray repair complementing defective repair in Chinese hamster cells 4', map_location='5q14.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=83077534, end_position_on_the_genomic_accession=83370333, orientation='plus', exon_count=13, OMIM=[194363], no_hdr0=''),
    7520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7520, CurrentID=0, Status='live', Symbol='XRCC5', Aliases=['KARP-1', 'KARP1', 'KU80', 'KUB2', 'Ku86', 'NFIV'], description='X-ray repair cross complementing 5', other_designations='X-ray repair cross-complementing protein 5|86 kDa subunit of Ku antigen|ATP-dependent DNA helicase 2 subunit 2|ATP-dependent DNA helicase II 80 kDa subunit|CTC box-binding factor 85 kDa subunit|CTC85|CTCBF|DNA repair protein XRCC5|Ku autoantigen, 80kDa|Ku86 autoantigen related protein 1|TLAA|X-ray repair complementing defective repair in Chinese hamster cells 5 (double-strand-break rejoining)|lupus Ku autoantigen protein p86|nuclear factor IV|thyroid-lupus autoantigen', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216109348, end_position_on_the_genomic_accession=216206293, orientation='plus', exon_count=21, OMIM=[194364], no_hdr0=''),
    7525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7525, CurrentID=0, Status='live', Symbol='YES1', Aliases=['HsT441', 'P61-YES', 'Yes', 'c-yes'], description='YES proto-oncogene 1, Src family tyrosine kinase', other_designations='tyrosine-protein kinase Yes|YES1 proto-oncogene, Src family tyrosine kinase|Yamaguchi sarcoma oncogene|cellular yes-1 protein|proto-oncogene c-Yes|proto-oncogene tyrosine-protein kinase YES|v-yes-1 Yamaguchi sarcoma viral oncogene homolog 1', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=721588, end_position_on_the_genomic_accession=812846, orientation='minus', exon_count=16, OMIM=[164880], no_hdr0=''),
    7528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7528, CurrentID=0, Status='live', Symbol='YY1', Aliases=['DELTA', 'GADEVS', 'INO80S', 'NF-E1', 'UCRBP', 'YIN-YANG-1'], description='YY1 transcription factor', other_designations='transcriptional repressor protein YY1|INO80 complex subunit S|YY-1|Yin and Yang 1 protein|delta transcription factor', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100239144, end_position_on_the_genomic_accession=100282788, orientation='plus', exon_count=5, OMIM=[600013], no_hdr0=''),
    7529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7529, CurrentID=0, Status='live', Symbol='YWHAB', Aliases=['GW128', 'HEL-S-1', 'HS1', 'KCIP-1', 'YWHAA'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein beta', other_designations='14-3-3 protein beta/alpha|14-3-3 alpha|epididymis secretory protein Li 1|protein 1054|protein kinase C inhibitor protein-1|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, alpha polypeptide|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, beta polypeptide', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44885705, end_position_on_the_genomic_accession=44908532, orientation='plus', exon_count=8, OMIM=[601289], no_hdr0=''),
    7531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7531, CurrentID=0, Status='live', Symbol='YWHAE', Aliases=['14-3-3E', 'HEL2', 'KCIP-1', 'MDCR', 'MDS'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein epsilon', other_designations='14-3-3 protein epsilon|14-3-3 epsilon|epididymis luminal protein 2|mitochondrial import stimulation factor L subunit|protein kinase C inhibitor protein-1|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, epsilon polypeptide|tyrosine 3/tryptophan 5 -monooxygenase activation protein, epsilon polypeptide', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1344275, end_position_on_the_genomic_accession=1400229, orientation='minus', exon_count=8, OMIM=[605066], no_hdr0=''),
    7532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7532, CurrentID=0, Status='live', Symbol='YWHAG', Aliases=['14-3-3GAMMA', 'DEE56', 'EIEE56', 'PPP1R170'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein gamma', other_designations='14-3-3 protein gamma|KCIP-1|protein kinase C inhibitor protein 1|protein phosphatase 1, regulatory subunit 170|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, gamma polypeptide', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76326799, end_position_on_the_genomic_accession=76358991, orientation='minus', exon_count=2, OMIM=[605356], no_hdr0=''),
    7533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7533, CurrentID=0, Status='live', Symbol='YWHAH', Aliases=['YWHA1'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein eta', other_designations='14-3-3 protein eta|14-3-3 eta|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, eta polypeptide', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31944535, end_position_on_the_genomic_accession=31957603, orientation='plus', exon_count=2, OMIM=[113508], no_hdr0=''),
    7534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7534, CurrentID=0, Status='live', Symbol='YWHAZ', Aliases=['14-3-3-zeta', 'HEL-S-3', 'HEL-S-93', 'HEL4', 'KCIP-1', 'POPCHAS', 'YWHAD'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein zeta', other_designations='14-3-3 protein zeta/delta|14-3-3 delta|14-3-3 protein/cytosolic phospholipase A2|14-3-3 zeta|epididymis luminal protein 4|epididymis secretory protein Li 3|epididymis secretory protein Li 93|phospholipase A2|protein kinase C inhibitor protein-1|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, delta polypeptide|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, zeta polypeptide|tyrosine 3/tryptophan 5 -monooxygenase activation protein, zeta polypeptide', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100916523, end_position_on_the_genomic_accession=100954068, orientation='minus', exon_count=12, OMIM=[601288], no_hdr0=''),
    7535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7535, CurrentID=0, Status='live', Symbol='ZAP70', Aliases=['ADMIO2', 'IMD48', 'SRK', 'STCD', 'STD', 'TZK', 'ZAP-70'], description='zeta chain of T cell receptor associated protein kinase 70', other_designations='tyrosine-protein kinase ZAP-70|70 kDa zeta-associated protein|70 kDa zeta-chain associated protein|syk-related tyrosine kinase|zeta chain of T cell receptor associated protein kinase 70kDa|zeta-chain (TCR) associated protein kinase 70kDa|zeta-chain associated protein kinase, 70kD', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97712030, end_position_on_the_genomic_accession=97744327, orientation='plus', exon_count=20, OMIM=[176947], no_hdr0=''),
    7536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7536, CurrentID=0, Status='live', Symbol='SF1', Aliases=['BBP', 'D11S636', 'MBBP', 'ZCCHC25', 'ZFM1', 'ZNF162'], description='splicing factor 1', other_designations='splicing factor 1|mammalian branch point-binding protein|transcription factor ZFM1|zinc finger gene in MEN1 locus|zinc finger protein 162', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64764606, end_position_on_the_genomic_accession=64778769, orientation='minus', exon_count=15, OMIM=[601516], no_hdr0=''),
    7538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7538, CurrentID=0, Status='live', Symbol='ZFP36', Aliases=['G0S24', 'GOS24', 'NUP475', 'RNF162A', 'TIS11', 'TTP', 'zfp-36'], description='ZFP36 ring finger protein', other_designations='mRNA decay activator protein ZFP36|G0/G1 switch regulatory protein 24|growth factor-inducible nuclear protein NUP475|tristetraprolin|tristetraproline|zinc finger protein 36 homolog|zinc finger protein 36, C3H type, homolog', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39406847, end_position_on_the_genomic_accession=39409407, orientation='plus', exon_count=2, OMIM=[190700], no_hdr0=''),
    7539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7539, CurrentID=0, Status='live', Symbol='ZFP37', Aliases=['ZNF906', 'zfp-37'], description='ZFP37 zinc finger protein', other_designations='zinc finger protein 37 homolog|zinc finger protein homologous to Zfp37 in mouse', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113038377, end_position_on_the_genomic_accession=113056724, orientation='minus', exon_count=4, OMIM=[602951], no_hdr0=''),
    7541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7541, CurrentID=0, Status='live', Symbol='ZBTB14', Aliases=['ZF5', 'ZFP-161', 'ZFP-5', 'ZFP161', 'ZNF478'], description='zinc finger and BTB domain containing 14', other_designations='zinc finger and BTB domain-containing protein 14|ZFP161 zinc finger protein|zinc finger protein 161 homolog|zinc finger protein 478|zinc finger protein 5 homolog|zinc finger protein homologous to Zfp161 in mouse', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5289019, end_position_on_the_genomic_accession=5297053, orientation='minus', exon_count=9, OMIM=[602126], no_hdr0=''),
    7542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7542, CurrentID=0, Status='live', Symbol='ZFPL1', Aliases=['D11S750', 'MCG4'], description='zinc finger protein like 1', other_designations='zinc finger protein-like 1|zinc finger protein MCG4|zinc-finger protein in MEN1 region', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65084222, end_position_on_the_genomic_accession=65088398, orientation='plus', exon_count=8, OMIM=[619397], no_hdr0=''),
    7543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7543, CurrentID=0, Status='live', Symbol='ZFX', Aliases=['ZNF926'], description='zinc finger protein X-linked', other_designations='zinc finger X-chromosomal protein|X-linked zinc finger protein', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24148982, end_position_on_the_genomic_accession=24216255, orientation='plus', exon_count=20, OMIM=[314980], no_hdr0=''),
    7544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7544, CurrentID=0, Status='live', Symbol='ZFY', Aliases=['ZNF911'], description='zinc finger protein Y-linked', other_designations='zinc finger Y-chromosomal protein', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=2935381, end_position_on_the_genomic_accession=2982508, orientation='plus', exon_count=8, OMIM=[490000], no_hdr0=''),
    7545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7545, CurrentID=0, Status='live', Symbol='ZIC1', Aliases=['BAIDCS', 'CRS6', 'ZIC', 'ZNF201'], description='Zic family member 1', other_designations='zinc finger protein ZIC 1|Zic family member 1 (odd-paired homolog, Drosophila)|Zinc finger protein of the cerebellum 1|zinc finger protein 201', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=147409365, end_position_on_the_genomic_accession=147416719, orientation='plus', exon_count=3, OMIM=[600470], no_hdr0=''),
    7546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7546, CurrentID=0, Status='live', Symbol='ZIC2', Aliases=['HPE5'], description='Zic family member 2', other_designations='zinc finger protein ZIC 2|Zic family member 2 (odd-paired homolog, Drosophila)|Zinc finger protein of the cerebellum 2', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99981784, end_position_on_the_genomic_accession=99986765, orientation='plus', exon_count=3, OMIM=[603073], no_hdr0=''),
    7547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7547, CurrentID=0, Status='live', Symbol='ZIC3', Aliases=['HTX', 'HTX1', 'VACTERLX', 'ZNF203'], description='Zic family member 3', other_designations='zinc finger protein ZIC 3|Zic family member 3 (odd-paired homolog, Drosophila)|heterotaxy 1|zinc finger protein 203|zinc finger protein of the cerebellum 3', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=137566127, end_position_on_the_genomic_accession=137577691, orientation='plus', exon_count=4, OMIM=[300265], no_hdr0=''),
    7549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7549, CurrentID=0, Status='live', Symbol='ZNF2', Aliases=['A1-5', 'ZNF661', 'Zfp661'], description='zinc finger protein 2', other_designations='zinc finger protein 2|zinc finger protein 2.2|zinc finger protein 661', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95165809, end_position_on_the_genomic_accession=95184317, orientation='plus', exon_count=5, OMIM=[194500], no_hdr0=''),
    7551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7551, CurrentID=0, Status='live', Symbol='ZNF3', Aliases=['A8-51', 'HF.12', 'KOX25', 'PP838', 'Zfp113'], description='zinc finger protein 3', other_designations='zinc finger protein 3|C2-H2 type zinc finger protein|zinc finger protein HF.12|zinc finger protein HZF3.1|zinc finger protein KOX25', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100063837, end_position_on_the_genomic_accession=100082577, orientation='minus', exon_count=10, OMIM=[194510], no_hdr0=''),
    7552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7552, CurrentID=0, Status='live', Symbol='ZNF711', Aliases=['CMPX1', 'MRX65', 'MRX97', 'ZNF4', 'ZNF5', 'ZNF6', 'Zfp711', 'dJ75N13.1'], description='zinc finger protein 711', other_designations='zinc finger protein 711|dJ75N13.1 (znf6-like)|mental retardation, X-linked 65|zinc finger protein 6 (CMPX1)', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=85243820, end_position_on_the_genomic_accession=85273362, orientation='plus', exon_count=10, OMIM=[314990], no_hdr0=''),
    7553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7553, CurrentID=0, Status='live', Symbol='ZNF7', Aliases=['HF.16', 'KOX4', 'zf30'], description='zinc finger protein 7', other_designations='zinc finger protein 7|C2-H2 type zinc finger protein|Zinc finger protein-7 (KOX4)|zinc finger protein 7 (KOX 4, clone HF.16)|zinc finger protein HF.16|zinc finger protein KOX4|zinc finger protein zfp30', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144827509, end_position_on_the_genomic_accession=144848070, orientation='plus', exon_count=9, OMIM=[194531], no_hdr0=''),
    7554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7554, CurrentID=0, Status='live', Symbol='ZNF8', Aliases=['HF.18', 'Zfp128'], description='zinc finger protein 8', other_designations='zinc finger protein 8|zinc finger protein 272|zinc finger protein 8 (clone HF.18)|zinc finger protein HF.18', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58278955, end_position_on_the_genomic_accession=58302791, orientation='plus', exon_count=4, OMIM=[194532], no_hdr0=''),
    7555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7555, CurrentID=0, Status='live', Symbol='CNBP', Aliases=['CNBP1', 'DM2', 'PROMM', 'RNF163', 'ZCCHC22', 'ZNF9'], description='CCHC-type zinc finger nucleic acid binding protein', other_designations='cellular nucleic acid-binding protein|erythroid differentiation-related|sterol regulatory element-binding protein|zinc finger protein 273|zinc finger protein 9 (a cellular retroviral nucleic acid binding protein)', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129167827, end_position_on_the_genomic_accession=129183896, orientation='minus', exon_count=5, OMIM=[116955], no_hdr0=''),
    7556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7556, CurrentID=0, Status='live', Symbol='ZNF10', Aliases=['KOX1'], description='zinc finger protein 10', other_designations='zinc finger protein 10|zinc finger protein 10 (KOX 1)|zinc finger protein KOX1', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133130627, end_position_on_the_genomic_accession=133159465, orientation='plus', exon_count=5, OMIM=[194538], no_hdr0=''),
    7559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7559, CurrentID=0, Status='live', Symbol='ZNF12', Aliases=['GIOT-3', 'HZF11', 'KOX3', 'ZNF325'], description='zinc finger protein 12', other_designations='zinc finger protein 12|gonadotropin inducible transcription repressor 3|gonadotropin-inducible ovary transcription repressor 3|zinc finger protein 11|zinc finger protein 325|zinc finger protein KOX3', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6688433, end_position_on_the_genomic_accession=6706947, orientation='minus', exon_count=5, OMIM=[194536], no_hdr0=''),
    7561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7561, CurrentID=0, Status='live', Symbol='ZNF14', Aliases=['GIOT-4', 'KOX6'], description='zinc finger protein 14', other_designations='zinc finger protein 14|gonadotropin inducible transcription repressor-4|gonadotropin-inducible ovary transcription repressor 4|zinc finger protein 14 (KOX 6)|zinc finger protein KOX6', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19710472, end_position_on_the_genomic_accession=19733112, orientation='minus', exon_count=4, OMIM=[194556], no_hdr0=''),
    7562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7562, CurrentID=0, Status='live', Symbol='ZNF708', Aliases=['KOX8', 'ZNF15', 'ZNF15L1'], description='zinc finger protein 708', other_designations='zinc finger protein 708|ZNF15, ZNF15L1|zinc finger protein 15-like 1 (KOX 8)', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21290385, end_position_on_the_genomic_accession=21329437, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    7564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7564, CurrentID=0, Status='live', Symbol='ZNF16', Aliases=['HZF1', 'KOX9'], description='zinc finger protein 16', other_designations='zinc finger protein 16|zinc finger protein KOX9|zinc finger protein Kruppel type 9', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144930358, end_position_on_the_genomic_accession=144950880, orientation='minus', exon_count=5, OMIM=[601262], no_hdr0=''),
    7565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7565, CurrentID=0, Status='live', Symbol='ZNF17', Aliases=['HPF3', 'KOX10'], description='zinc finger protein 17', other_designations='zinc finger protein 17|zinc finger protein 17 (HPF3, KOX 10)|zinc finger protein HPF3|zinc finger protein KOX10', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57411161, end_position_on_the_genomic_accession=57421934, orientation='plus', exon_count=4, OMIM=[619254], no_hdr0=''),
    7566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7566, CurrentID=0, Status='live', Symbol='ZNF18', Aliases=['HDSG1', 'KOX11', 'ZKSCAN6', 'ZNF535', 'ZSCAN38', 'Zfp535'], description='zinc finger protein 18', other_designations='zinc finger protein 18|heart development-specific gene 1 protein|zinc finger protein 18 (KOX 11)|zinc finger protein 535|zinc finger protein with KRAB and SCAN domains 6', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=11957433, end_position_on_the_genomic_accession=12021522, orientation='minus', exon_count=19, OMIM=[194524], no_hdr0=''),
    7567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7567, CurrentID=0, Status='live', Symbol='ZNF19', Aliases=['KOX12'], description='zinc finger protein 19', other_designations='zinc finger protein 19|zinc finger protein 19 (KOX 12)|zinc finger protein KOX12', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71473583, end_position_on_the_genomic_accession=71489324, orientation='minus', exon_count=6, OMIM=[194525], no_hdr0=''),
    7568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7568, CurrentID=0, Status='live', Symbol='ZNF20', Aliases=['KOX13'], description='zinc finger protein 20', other_designations='zinc finger protein 20|zinc finger protein KOX13', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12131350, end_position_on_the_genomic_accession=12140350, orientation='minus', exon_count=4, OMIM=[194557], no_hdr0=''),
    7569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7569, CurrentID=0, Status='live', Symbol='ZNF182', Aliases=['HHZ150', 'KOX14', 'ZNF21', 'Zfp182'], description='zinc finger protein 182', other_designations='zinc finger protein 182|zinc finger protein 21 (KOX 14)|zinc finger protein KOX14', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47974851, end_position_on_the_genomic_accession=48003989, orientation='minus', exon_count=7, OMIM=[314993], no_hdr0=''),
    7570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7570, CurrentID=0, Status='live', Symbol='ZNF22', Aliases=['HKR-T1', 'KOX15', 'ZNF422', 'Zfp422'], description='zinc finger protein 22', other_designations='zinc finger protein 22|krox-26 protein|zinc finger protein 22 (KOX 15)|zinc finger protein KOX15|zinc finger protein Krox-26', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45000923, end_position_on_the_genomic_accession=45005326, orientation='plus', exon_count=2, OMIM=[194529], no_hdr0=''),
    7571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7571, CurrentID=0, Status='live', Symbol='ZNF23', Aliases=['KOX16', 'ZNF359', 'ZNF612', 'Zfp612'], description='zinc finger protein 23', other_designations='zinc finger protein 23|kruppel-like zinc finger factor X31|zinc finger protein 23 (KOX 16)|zinc finger protein 32|zinc finger protein 359|zinc finger protein 612', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71447597, end_position_on_the_genomic_accession=71462247, orientation='minus', exon_count=8, OMIM=[194527], no_hdr0=''),
    7572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7572, CurrentID=0, Status='live', Symbol='ZNF24', Aliases=['KOX17', 'RSG-A', 'ZNF191', 'ZSCAN3', 'Zfp191'], description='zinc finger protein 24', other_designations='zinc finger protein 24|retinoic acid suppression protein A|zinc finger and SCAN domain-containing protein 3|zinc finger protein 191|zinc finger protein 24 (KOX 17)|zinc finger protein KOX17', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35332227, end_position_on_the_genomic_accession=35344420, orientation='minus', exon_count=4, OMIM=[194534], no_hdr0=''),
    7574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7574, CurrentID=0, Status='live', Symbol='ZNF26', Aliases=['HEL-179', 'KOX20'], description='zinc finger protein 26', other_designations='zinc finger protein 26|epididymis luminal protein 179|zinc finger protein KOX20', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132986365, end_position_on_the_genomic_accession=133027102, orientation='plus', exon_count=9, OMIM=[194537], no_hdr0=''),
    7576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7576, CurrentID=0, Status='live', Symbol='ZNF28', Aliases=['KOX24'], description='zinc finger protein 28', other_designations='zinc finger protein 28|zinc finger protein KOX24', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52797408, end_position_on_the_genomic_accession=52821637, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    7579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7579, CurrentID=0, Status='live', Symbol='ZSCAN20', Aliases=['KOX29', 'ZFP-31', 'ZNF31', 'ZNF360'], description='zinc finger and SCAN domain containing 20', other_designations='zinc finger and SCAN domain-containing protein 20|zinc finger protein 31|zinc finger protein 360|zinc finger protein KOX29', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33472591, end_position_on_the_genomic_accession=33504253, orientation='plus', exon_count=9, OMIM=[611315], no_hdr0=''),
    7580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7580, CurrentID=0, Status='live', Symbol='ZNF32', Aliases=['KOX30', 'ZNF637', 'Zfp637'], description='zinc finger protein 32', other_designations='zinc finger protein 32|C2H2-546|zinc finger protein 32 (KOX 30)|zinc finger protein KOX30', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43643862, end_position_on_the_genomic_accession=43648881, orientation='minus', exon_count=4, OMIM=[194539], no_hdr0=''),
    7581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7581, CurrentID=0, Status='live', Symbol='ZNF33A', Aliases=['KOX2', 'KOX31', 'KOX5', 'NF11A', 'ZNF11', 'ZNF11A', 'ZNF33', 'ZZAPK'], description='zinc finger protein 33A', other_designations='zinc finger protein 33A|brain my041 protein|zinc finger and ZAK-associated protein with KRAB domain|zinc finger protein 11A|zinc finger protein 33a (KOX 31)|zinc finger protein KOX31', map_location='10p11.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=38010483, end_position_on_the_genomic_accession=38067834, orientation='plus', exon_count=11, OMIM=[194521], no_hdr0=''),
    7582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7582, CurrentID=0, Status='live', Symbol='ZNF33B', Aliases=['KOX2', 'KOX31', 'ZNF11B'], description='zinc finger protein 33B', other_designations='zinc finger protein 33B|zinc finger protein 11b (KOX 2)|zinc finger protein 33b (KOX 31)', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=42574169, end_position_on_the_genomic_accession=42638570, orientation='minus', exon_count=9, OMIM=[194522], no_hdr0=''),
    7584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7584, CurrentID=0, Status='live', Symbol='ZNF35', Aliases=['HF.10', 'HF10', 'Zfp105'], description='zinc finger protein 35', other_designations='zinc finger protein 35|zinc finger protein 35 (clone HF.10)|zinc finger protein HF.10', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44648732, end_position_on_the_genomic_accession=44660791, orientation='plus', exon_count=4, OMIM=[194533], no_hdr0=''),
    7586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7586, CurrentID=0, Status='live', Symbol='ZKSCAN1', Aliases=['KOX18', 'PHZ-37', 'ZNF139', 'ZNF36', 'ZSCAN33'], description='zinc finger with KRAB and SCAN domains 1', other_designations='zinc finger protein with KRAB and SCAN domains 1|zinc finger protein 139|zinc finger protein 36 (KOX 18)', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100015581, end_position_on_the_genomic_accession=100045374, orientation='plus', exon_count=7, OMIM=[601260], no_hdr0=''),
    7587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7587, CurrentID=0, Status='live', Symbol='ZNF37A', Aliases=['KOX21', 'ZNF37'], description='zinc finger protein 37A', other_designations='zinc finger protein 37A|zinc finger protein 37a (KOX 21)|zinc finger protein KOX21', map_location='10p11.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=38094327, end_position_on_the_genomic_accession=38150293, orientation='plus', exon_count=12, OMIM=[616085], no_hdr0=''),
    7589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7589, CurrentID=0, Status='live', Symbol='ZSCAN21', Aliases=['NY-REN-21', 'ZNF38', 'Zipro1'], description='zinc finger and SCAN domain containing 21', other_designations='zinc finger and SCAN domain-containing protein 21|renal carcinoma antigen NY-REN-21|zfp-38|zinc finger protein 38 (KOX 25)|zinc finger protein 38 homolog|zinc finger protein NY-REN-21 antigen', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100049774, end_position_on_the_genomic_accession=100065041, orientation='plus', exon_count=5, OMIM=[601261], no_hdr0=''),
    7592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7592, CurrentID=0, Status='live', Symbol='ZNF41', Aliases=['MRX89'], description='zinc finger protein 41', other_designations='zinc finger protein 41', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47444691, end_position_on_the_genomic_accession=47485934, orientation='minus', exon_count=7, OMIM=[314995], no_hdr0=''),
    7593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7593, CurrentID=0, Status='live', Symbol='MZF1', Aliases=['MZF-1B', 'ZFP98', 'ZNF42', 'ZSCAN6', 'MZF1'], description='myeloid zinc finger 1', other_designations='myeloid zinc finger 1|zinc finger and SCAN domain-containing protein 6|zinc finger protein 42 (myeloid-specific retinoic acid-responsive)', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58561921, end_position_on_the_genomic_accession=58574478, orientation='minus', exon_count=7, OMIM=[194550], no_hdr0=''),
    7594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7594, CurrentID=0, Status='live', Symbol='ZNF43', Aliases=['HTF6', 'KOX27', 'ZNF39L1'], description='zinc finger protein 43', other_designations='zinc finger protein 43|zinc finger protein 39-like 1 (KOX 27)|zinc finger protein HTF6|zinc finger protein KOX27', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21804946, end_position_on_the_genomic_accession=21852095, orientation='minus', exon_count=10, OMIM=[603972], no_hdr0=''),
    7596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7596, CurrentID=0, Status='live', Symbol='ZNF45', Aliases=['KOX5', 'ZNF13'], description='zinc finger protein 45', other_designations='zinc finger protein 45|BRC1744|zinc finger protein 13|zinc finger protein 45 (a Kruppel-associated box (KRAB) domain polypeptide)|zinc finger protein KOX5', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43912624, end_position_on_the_genomic_accession=43935315, orientation='minus', exon_count=12, OMIM=[194554], no_hdr0=''),
    7597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7597, CurrentID=0, Status='live', Symbol='ZBTB25', Aliases=['C14orf51', 'KUP', 'ZNF46'], description='zinc finger and BTB domain containing 25', other_designations='zinc finger and BTB domain-containing protein 25|zinc finger protein 46|zinc finger protein KUP', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64449106, end_position_on_the_genomic_accession=64505213, orientation='minus', exon_count=12, OMIM=[194541], no_hdr0=''),
    7617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7617, CurrentID=0, Status='live', Symbol='ZNF66', Aliases=['ZNF66P'], description='zinc finger protein 66', other_designations='putative zinc finger protein 66', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20776304, end_position_on_the_genomic_accession=20809995, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    7620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7620, CurrentID=0, Status='live', Symbol='ZNF69', Aliases=['Cos5', 'hZNF3'], description='zinc finger protein 69', other_designations='zinc finger protein 69|ZNF3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11887773, end_position_on_the_genomic_accession=11980222, orientation='plus', exon_count=6, OMIM=[194543], no_hdr0=''),
    7621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7621, CurrentID=0, Status='live', Symbol='ZNF70', Aliases=['Cos17'], description='zinc finger protein 70', other_designations='zinc finger protein 70|zinc finger protein N27C7-1', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23738682, end_position_on_the_genomic_accession=23751112, orientation='minus', exon_count=3, OMIM=[194544], no_hdr0=''),
    7625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7625, CurrentID=0, Status='live', Symbol='ZNF74', Aliases=['COS52', 'ZFP520', 'ZNF520', 'hZNF7'], description='zinc finger protein 74', other_designations='zinc finger protein 74|zinc finger protein 520', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20394151, end_position_on_the_genomic_accession=20408455, orientation='plus', exon_count=6, OMIM=[194548], no_hdr0=''),
    7626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7626, CurrentID=0, Status='live', Symbol='ZNF75D', Aliases=['D8C6', 'ZKSCAN24', 'ZNF75', 'ZNF82', 'ZSCAN28'], description='zinc finger protein 75D', other_designations='zinc finger protein 75D|zinc finger protein 75|zinc finger protein 82', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135248589, end_position_on_the_genomic_accession=135344629, orientation='minus', exon_count=10, OMIM=[314997], no_hdr0=''),
    7627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7627, CurrentID=0, Status='live', Symbol='ZNF75A', Aliases=[], description='zinc finger protein 75a', other_designations='zinc finger protein 75A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3305478, end_position_on_the_genomic_accession=3322999, orientation='plus', exon_count=10, OMIM=[601473], no_hdr0=''),
    7629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7629, CurrentID=0, Status='live', Symbol='ZNF76', Aliases=['D6S229E', 'ZNF523', 'Zfp523'], description='zinc finger protein 76', other_designations='zinc finger protein 76|zinc finger protein 523|zinc finger protein 76 (expressed in testis)', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35259473, end_position_on_the_genomic_accession=35295985, orientation='plus', exon_count=17, OMIM=[194549], no_hdr0=''),
    7633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7633, CurrentID=0, Status='live', Symbol='ZNF79', Aliases=['pT7'], description='zinc finger protein 79', other_designations='zinc finger protein 79|ZNFpT7', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127424382, end_position_on_the_genomic_accession=127446289, orientation='plus', exon_count=6, OMIM=[194552], no_hdr0=''),
    7634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7634, CurrentID=0, Status='live', Symbol='ZNF80', Aliases=['pT17'], description='zinc finger protein 80', other_designations='zinc finger protein 80|ZNFPT17', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=114234631, end_position_on_the_genomic_accession=114237578, orientation='minus', exon_count=1, OMIM=[194553], no_hdr0=''),
    7637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7637, CurrentID=0, Status='live', Symbol='ZNF84', Aliases=['HPF2'], description='zinc finger protein 84', other_designations='zinc finger protein 84|zinc finger protein HPF2', map_location='map from Rosati ref via FISH [AFS]', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133037301, end_position_on_the_genomic_accession=133063299, orientation='plus', exon_count=7, OMIM=[618554], no_hdr0=''),
    7638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7638, CurrentID=0, Status='live', Symbol='ZNF221', Aliases=[], description='zinc finger protein 221', other_designations='zinc finger protein 221', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43951196, end_position_on_the_genomic_accession=43970207, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    7639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7639, CurrentID=0, Status='live', Symbol='ZNF85', Aliases=['HPF4', 'HTF1'], description='zinc finger protein 85', other_designations='zinc finger protein 85|zinc finger protein 85 (HPF4, HTF1)', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20923227, end_position_on_the_genomic_accession=20950697, orientation='plus', exon_count=8, OMIM=[603899], no_hdr0=''),
    7643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7643, CurrentID=0, Status='live', Symbol='ZNF90', Aliases=['HTF9'], description='zinc finger protein 90', other_designations='zinc finger protein 90|zinc finger protein HTF9', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20078000, end_position_on_the_genomic_accession=20127090, orientation='plus', exon_count=7, OMIM=[603973], no_hdr0=''),
    7644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7644, CurrentID=0, Status='live', Symbol='ZNF91', Aliases=['HPF7', 'HTF10'], description='zinc finger protein 91', other_designations='zinc finger protein 91|zinc finger protein 91 (HPF7, HTF10)|zinc finger protein HPF7|zinc finger protein HTF10', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23305004, end_position_on_the_genomic_accession=23395527, orientation='minus', exon_count=9, OMIM=[603971], no_hdr0=''),
    7652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7652, CurrentID=0, Status='live', Symbol='ZNF99', Aliases=['C19orf9', 'F8281'], description='zinc finger protein 99', other_designations='zinc finger protein 99|zinc finger protein ENSP00000375192', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22752183, end_position_on_the_genomic_accession=22784151, orientation='minus', exon_count=4, OMIM=[603981], no_hdr0=''),
    7673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7673, CurrentID=0, Status='live', Symbol='ZNF222', Aliases=[], description='zinc finger protein 222', other_designations='zinc finger protein 222', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44025324, end_position_on_the_genomic_accession=44033110, orientation='plus', exon_count=6, OMIM=[617357], no_hdr0=''),
    7675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7675, CurrentID=0, Status='live', Symbol='ZNF121', Aliases=['D19S204', 'ZHC32', 'ZNF20'], description='zinc finger protein 121', other_designations='zinc finger protein 121|zinc finger protein 121 (clone ZHC32)|zinc finger protein 20', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9560329, end_position_on_the_genomic_accession=9584544, orientation='minus', exon_count=6, OMIM=[194628], no_hdr0=''),
    7678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7678, CurrentID=0, Status='live', Symbol='ZNF124', Aliases=['HZF-16', 'HZF16', 'ZK7'], description='zinc finger protein 124', other_designations='zinc finger protein 124|zinc finger protein HZF-16', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247121975, end_position_on_the_genomic_accession=247172379, orientation='minus', exon_count=8, OMIM=[194631], no_hdr0=''),
    7681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7681, CurrentID=0, Status='live', Symbol='MKRN3', Aliases=['CPPB2', 'D15S9', 'RNF63', 'ZFP127', 'ZNF127'], description='makorin ring finger protein 3', other_designations='probable E3 ubiquitin-protein ligase makorin-3|RING finger protein 63|RING-type E3 ubiquitin transferase makorin-3|zinc finger protein 127', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23565674, end_position_on_the_genomic_accession=23568044, orientation='plus', exon_count=1, OMIM=[603856], no_hdr0=''),
    7690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7690, CurrentID=0, Status='live', Symbol='ZNF131', Aliases=['ZBTB35', 'pHZ-10'], description='zinc finger protein 131', other_designations='zinc finger protein 131|zinc finger and BTB domain containing 35|zinc finger protein 131 (clone pHZ-10)', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43120914, end_position_on_the_genomic_accession=43176324, orientation='plus', exon_count=9, OMIM=[604073], no_hdr0=''),
    7691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7691, CurrentID=0, Status='live', Symbol='ZNF132', Aliases=['pHZ-12'], description='zinc finger protein 132', other_designations='zinc finger protein 132', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58432814, end_position_on_the_genomic_accession=58440153, orientation='minus', exon_count=3, OMIM=[604074], no_hdr0=''),
    7692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7692, CurrentID=0, Status='live', Symbol='ZNF133', Aliases=['ZNF150', 'pHZ-13', 'pHZ-66'], description='zinc finger protein 133', other_designations='zinc finger protein 133|zinc finger protein 133 (clone pHZ-13)|zinc finger protein 150 (pHZ-66)', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18288520, end_position_on_the_genomic_accession=18316996, orientation='plus', exon_count=10, OMIM=[604075], no_hdr0=''),
    7693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7693, CurrentID=0, Status='live', Symbol='ZNF134', Aliases=['pHZ-15'], description='zinc finger protein 134', other_designations='zinc finger protein 134|zinc finger protein 134 (clone pHZ-15)', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57614242, end_position_on_the_genomic_accession=57624724, orientation='plus', exon_count=3, OMIM=[604076], no_hdr0=''),
    7694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7694, CurrentID=0, Status='live', Symbol='ZNF135', Aliases=['ZNF61', 'ZNF78L1', 'pHZ-17', 'pT3'], description='zinc finger protein 135', other_designations='zinc finger protein 135|zinc finger protein 135 (clone pHZ-17)|zinc finger protein 61|zinc finger protein 78-like 1 (pT3)', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58059227, end_position_on_the_genomic_accession=58069755, orientation='plus', exon_count=6, OMIM=[604077], no_hdr0=''),
    7695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7695, CurrentID=0, Status='live', Symbol='ZNF136', Aliases=['pHZ-20'], description='zinc finger protein 136', other_designations='zinc finger protein 136', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12163096, end_position_on_the_genomic_accession=12189871, orientation='plus', exon_count=5, OMIM=[604078], no_hdr0=''),
    7697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7697, CurrentID=0, Status='live', Symbol='ZNF138', Aliases=['pHZ-32'], description='zinc finger protein 138', other_designations='zinc finger protein 138|zinc finger protein 138 (clone pHZ-32)', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64794428, end_position_on_the_genomic_accession=64860823, orientation='plus', exon_count=12, OMIM=[604080], no_hdr0=''),
    7699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7699, CurrentID=0, Status='live', Symbol='ZNF140', Aliases=['pHZ-39'], description='zinc finger protein 140', other_designations='zinc finger protein 140', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133079470, end_position_on_the_genomic_accession=133107526, orientation='plus', exon_count=9, OMIM=[604082], no_hdr0=''),
    7700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7700, CurrentID=0, Status='live', Symbol='ZNF141', Aliases=['D4S90', 'pHZ-44'], description='zinc finger protein 141', other_designations='zinc finger protein 141|zinc finger protein 141 (clone pHZ-44)', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=337814, end_position_on_the_genomic_accession=384868, orientation='plus', exon_count=6, OMIM=[194648], no_hdr0=''),
    7701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7701, CurrentID=0, Status='live', Symbol='ZNF142', Aliases=['HA4654', 'NEDISHM', 'pHZ-49'], description='zinc finger protein 142', other_designations='zinc finger protein 142|zinc finger protein 142 (clone pHZ-49)', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218633329, end_position_on_the_genomic_accession=218659623, orientation='minus', exon_count=11, OMIM=[604083], no_hdr0=''),
    7702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7702, CurrentID=0, Status='live', Symbol='ZNF143', Aliases=['SBF', 'STAF', 'pHZ-1'], description='zinc finger protein 143', other_designations='zinc finger protein 143|SPH-binding factor|hStaf|selenocysteine tRNA gene transcription-activating factor|transcriptional activator Staf', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9460982, end_position_on_the_genomic_accession=9528524, orientation='plus', exon_count=20, OMIM=[603433], no_hdr0=''),
    7703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7703, CurrentID=0, Status='live', Symbol='PCGF2', Aliases=['MEL-18', 'RNF110', 'TPFS', 'ZNF144'], description='polycomb group ring finger 2', other_designations='polycomb group RING finger protein 2|DNA-binding protein Mel-18|ring finger protein 110|zinc finger protein 144', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38733898, end_position_on_the_genomic_accession=38749817, orientation='minus', exon_count=13, OMIM=[600346], no_hdr0=''),
    7704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7704, CurrentID=0, Status='live', Symbol='ZBTB16', Aliases=['PLZF', 'ZNF145'], description='zinc finger and BTB domain containing 16', other_designations='zinc finger and BTB domain-containing protein 16|promyelocytic leukaemia zinc finger|zinc finger protein 145 (Kruppel-like, expressed in promyelocytic leukemia)|zinc finger protein PLZF', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114059576, end_position_on_the_genomic_accession=114256770, orientation='plus', exon_count=13, OMIM=[176797], no_hdr0=''),
    7705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7705, CurrentID=0, Status='live', Symbol='ZNF146', Aliases=['OZF'], description='zinc finger protein 146', other_designations='zinc finger protein OZF|only zinc finger protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36214751, end_position_on_the_genomic_accession=36238768, orientation='plus', exon_count=5, OMIM=[601505], no_hdr0=''),
    7706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7706, CurrentID=0, Status='live', Symbol='TRIM25', Aliases=['EFP', 'RNF147', 'Z147', 'ZNF147'], description='tripartite motif containing 25', other_designations='E3 ubiquitin/ISG15 ligase TRIM25|RING finger protein 147|RING-type E3 ubiquitin transferase TRIM25|estrogen-responsive finger protein|tripartite motif protein TRIM25|tripartite motif-containing protein 25|ubiquitin/ISG15-conjugating enzyme TRIM25|zinc finger protein 147 (estrogen-responsive finger protein)|zinc finger protein-147', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56887909, end_position_on_the_genomic_accession=56914049, orientation='minus', exon_count=9, OMIM=[600453], no_hdr0=''),
    7707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7707, CurrentID=0, Status='live', Symbol='ZNF148', Aliases=['BERF-1', 'BFCOL1', 'GDACCF', 'HT-BETA', 'ZBP-89', 'ZFP148', 'pHZ-52'], description='zinc finger protein 148', other_designations='zinc finger protein 148|CACCC box-binding protein|CLL-associated antigen KW-10|transcription factor ZBP-89|zinc finger DNA-binding protein 89', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=125225669, end_position_on_the_genomic_accession=125375354, orientation='minus', exon_count=14, OMIM=[601897], no_hdr0=''),
    7709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7709, CurrentID=0, Status='live', Symbol='ZBTB17', Aliases=['MIZ-1', 'ZNF151', 'ZNF60', 'pHZ-67'], description='zinc finger and BTB domain containing 17', other_designations='zinc finger and BTB domain-containing protein 17|Myc-interacting Zn finger protein-1|zinc finger protein 151 (pHZ-67)|zinc finger protein 60', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15939933, end_position_on_the_genomic_accession=15976132, orientation='minus', exon_count=16, OMIM=[604084], no_hdr0=''),
    7710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7710, CurrentID=0, Status='live', Symbol='ZNF154', Aliases=['pHZ-92'], description='zinc finger protein 154', other_designations='zinc finger protein 154', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57696275, end_position_on_the_genomic_accession=57709204, orientation='minus', exon_count=5, OMIM=[604085], no_hdr0=''),
    7711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7711, CurrentID=0, Status='live', Symbol='ZNF155', Aliases=['pHZ-96'], description='zinc finger protein 155', other_designations='zinc finger protein 155|KRAB A domain', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43967006, end_position_on_the_genomic_accession=43998326, orientation='plus', exon_count=7, OMIM=[604086], no_hdr0=''),
    7712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7712, CurrentID=0, Status='live', Symbol='ZNF157', Aliases=['HZF22'], description='zinc finger protein 157', other_designations='zinc finger protein 157|zinc finger protein 22|zinc finger protein HZF22', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47370578, end_position_on_the_genomic_accession=47414498, orientation='plus', exon_count=4, OMIM=[300024], no_hdr0=''),
    7716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7716, CurrentID=0, Status='live', Symbol='VEZF1', Aliases=['DB1', 'ZNF161'], description='vascular endothelial zinc finger 1', other_designations='vascular endothelial zinc finger 1|putative transcription factor DB1|zinc finger protein 161', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57971547, end_position_on_the_genomic_accession=57988254, orientation='minus', exon_count=8, OMIM=[606747], no_hdr0=''),
    7718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7718, CurrentID=0, Status='live', Symbol='ZNF165', Aliases=['CT53', 'LD65', 'ZSCAN7'], description='zinc finger protein 165', other_designations='zinc finger protein 165|cancer/testis antigen 53|zinc finger and SCAN domain-containing protein 7', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28080282, end_position_on_the_genomic_accession=28104244, orientation='plus', exon_count=6, OMIM=[600834], no_hdr0=''),
    7726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7726, CurrentID=0, Status='live', Symbol='TRIM26', Aliases=['AFP', 'RNF95', 'ZNF173'], description='tripartite motif containing 26', other_designations='tripartite motif-containing protein 26|RING finger protein 95|acid finger protein|widely expressed acid zinc finger protein|zinc finger protein 173', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30184453, end_position_on_the_genomic_accession=30213435, orientation='minus', exon_count=10, OMIM=[600830], no_hdr0=''),
    7727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7727, CurrentID=0, Status='live', Symbol='ZNF174', Aliases=['ZSCAN8'], description='zinc finger protein 174', other_designations='zinc finger protein 174|AW-1|zinc finger and SCAN domain-containing protein 8', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3401215, end_position_on_the_genomic_accession=3409364, orientation='plus', exon_count=4, OMIM=[603900], no_hdr0=''),
    7728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7728, CurrentID=0, Status='live', Symbol='ZNF175', Aliases=['OTK18'], description='zinc finger protein 175', other_designations='zinc finger protein 175|zinc finger protein OTK18', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51571283, end_position_on_the_genomic_accession=51592510, orientation='plus', exon_count=5, OMIM=[601139], no_hdr0=''),
    7730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7730, CurrentID=0, Status='live', Symbol='ZNF177', Aliases=['PIGX'], description='zinc finger protein 177', other_designations='zinc finger protein 177', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9363013, end_position_on_the_genomic_accession=9382617, orientation='plus', exon_count=9, OMIM=[601276], no_hdr0=''),
    7732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7732, CurrentID=0, Status='live', Symbol='RNF112', Aliases=['BFP', 'ZNF179'], description='ring finger protein 112', other_designations='RING finger protein 112|brain finger protein|neurolastin|zinc finger protein 179', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19406979, end_position_on_the_genomic_accession=19417276, orientation='plus', exon_count=15, OMIM=[601237], no_hdr0=''),
    7733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7733, CurrentID=0, Status='live', Symbol='ZNF180', Aliases=['HHZ168'], description='zinc finger protein 180', other_designations='zinc finger protein 180', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44474431, end_position_on_the_genomic_accession=44500522, orientation='minus', exon_count=7, OMIM=[606740], no_hdr0=''),
    7737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7737, CurrentID=0, Status='live', Symbol='RNF113A', Aliases=['Cwc24', 'RNF113', 'TTD5', 'ZNF183'], description='ring finger protein 113A', other_designations='E3 ubiquitin-protein ligase RNF113A|cwc24 homolog|zinc finger protein 183 (RING finger, C3HC4 type)', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119870475, end_position_on_the_genomic_accession=119871733, orientation='minus', exon_count=1, OMIM=[300951], no_hdr0=''),
    7738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7738, CurrentID=0, Status='live', Symbol='ZNF184', Aliases=['kr-ZNF3'], description='zinc finger protein 184', other_designations='zinc finger protein 184|zinc finger protein 184 (Kruppel-like)', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27404006, end_position_on_the_genomic_accession=27473105, orientation='minus', exon_count=10, OMIM=[602277], no_hdr0=''),
    7739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7739, CurrentID=0, Status='live', Symbol='ZNF185', Aliases=['SCELL'], description='zinc finger protein 185 with LIM domain', other_designations='zinc finger protein 185|P1-A|sciellin like|zinc finger protein 185 (LIM domain)', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152898067, end_position_on_the_genomic_accession=152973481, orientation='plus', exon_count=28, OMIM=[300381], no_hdr0=''),
    7741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7741, CurrentID=0, Status='live', Symbol='ZSCAN26', Aliases=['SRE-ZBP', 'SREZBP', 'ZNF187'], description='zinc finger and SCAN domain containing 26', other_designations='zinc finger and SCAN domain-containing protein 26|zinc finger protein 187', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28267050, end_position_on_the_genomic_accession=28278218, orientation='plus', exon_count=4, OMIM=[616474], no_hdr0=''),
    7743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7743, CurrentID=0, Status='live', Symbol='ZNF189', Aliases=[], description='zinc finger protein 189', other_designations='zinc finger protein 189', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101398830, end_position_on_the_genomic_accession=101410655, orientation='plus', exon_count=7, OMIM=[603132], no_hdr0=''),
    7745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7745, CurrentID=0, Status='live', Symbol='ZKSCAN8', Aliases=['LD5-1', 'ZNF192', 'ZSCAN40'], description='zinc finger with KRAB and SCAN domains 8', other_designations='zinc finger protein with KRAB and SCAN domains 8|zinc finger protein 192', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28141643, end_position_on_the_genomic_accession=28159461, orientation='plus', exon_count=9, OMIM=[602240], no_hdr0=''),
    7746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7746, CurrentID=0, Status='live', Symbol='ZSCAN9', Aliases=['PRD51', 'ZNF193'], description='zinc finger and SCAN domain containing 9', other_designations='zinc finger and SCAN domain-containing protein 9|cell proliferation-inducing gene 12 protein|cell proliferation-inducing protein 12|zinc finger protein 193', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28224702, end_position_on_the_genomic_accession=28233487, orientation='plus', exon_count=7, OMIM=[602246], no_hdr0=''),
    7748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7748, CurrentID=0, Status='live', Symbol='ZNF195', Aliases=['HRF1', 'ZNFP104'], description='zinc finger protein 195', other_designations='zinc finger protein 195|hypoxia-regulated factor-1|krueppel family zinc finger protein (znfp104)', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3357927, end_position_on_the_genomic_accession=3379146, orientation='minus', exon_count=9, OMIM=[602187], no_hdr0=''),
    7750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7750, CurrentID=0, Status='live', Symbol='ZMYM2', Aliases=['FIM', 'MYM', 'RAMP', 'SCLL', 'ZNF198'], description='zinc finger MYM-type containing 2', other_designations='zinc finger MYM-type protein 2|fused in myeloproliferative disorders protein|rearranged in an atypical myeloproliferative disorder|zinc finger protein 198|zinc finger, MYM-type 2', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19957423, end_position_on_the_genomic_accession=20089115, orientation='plus', exon_count=35, OMIM=[602221], no_hdr0=''),
    7752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7752, CurrentID=0, Status='live', Symbol='ZNF200', Aliases=[], description='zinc finger protein 200', other_designations='zinc finger protein 200', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3222325, end_position_on_the_genomic_accession=3236221, orientation='minus', exon_count=7, OMIM=[603231], no_hdr0=''),
    7753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7753, CurrentID=0, Status='live', Symbol='ZNF202', Aliases=['ZKSCAN10', 'ZSCAN42'], description='zinc finger protein 202', other_designations='zinc finger protein 202|zinc finger protein with KRAB and SCAN domains 10', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123723914, end_position_on_the_genomic_accession=123741675, orientation='minus', exon_count=11, OMIM=[603430], no_hdr0=''),
    7755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7755, CurrentID=0, Status='live', Symbol='ZNF205', Aliases=['RhitH', 'ZNF210', 'Zfp13'], description='zinc finger protein 205', other_designations='zinc finger protein 205|transcriptional repressor RhitH|zinc finger protein 210', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3112586, end_position_on_the_genomic_accession=3120517, orientation='plus', exon_count=8, OMIM=[603436], no_hdr0=''),
    7756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7756, CurrentID=0, Status='live', Symbol='ZNF207', Aliases=['BuGZ', 'hBuGZ'], description='zinc finger protein 207', other_designations='BUB3-interacting and GLEBS motif-containing protein ZNF207', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32350157, end_position_on_the_genomic_accession=32381885, orientation='plus', exon_count=12, OMIM=[603428], no_hdr0=''),
    7757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7757, CurrentID=0, Status='live', Symbol='ZNF208', Aliases=['PMIDP', 'ZNF95'], description='zinc finger protein 208', other_designations='zinc finger protein 208|zinc finger protein 95', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21939815, end_position_on_the_genomic_accession=22010943, orientation='minus', exon_count=8, OMIM=[603977], no_hdr0=''),
    7760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7760, CurrentID=0, Status='live', Symbol='ZNF213', Aliases=['CR53', 'ZKSCAN21', 'ZSCAN53'], description='zinc finger protein 213', other_designations='zinc finger protein 213|putative transcription factor CR53|zinc finger protein with KRAB and SCAN domains 21', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3135029, end_position_on_the_genomic_accession=3142804, orientation='plus', exon_count=6, OMIM=[608387], no_hdr0=''),
    7761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7761, CurrentID=0, Status='live', Symbol='ZNF214', Aliases=['BAZ-1', 'BAZ1'], description='zinc finger protein 214', other_designations='zinc finger protein 214|BWSCR2-associated zinc finger protein 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6993482, end_position_on_the_genomic_accession=7020367, orientation='minus', exon_count=5, OMIM=[605015], no_hdr0=''),
    7762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7762, CurrentID=0, Status='live', Symbol='ZNF215', Aliases=['BAZ-2', 'BAZ2', 'ZKSCAN11', 'ZSCAN43'], description='zinc finger protein 215', other_designations='zinc finger protein 215|BWSCR2-associated zinc finger protein 2|zinc finger protein with KRAB and SCAN domains 11', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6926426, end_position_on_the_genomic_accession=6991144, orientation='plus', exon_count=10, OMIM=[605016], no_hdr0=''),
    7763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7763, CurrentID=0, Status='live', Symbol='ZFAND5', Aliases=['ZA20D2A', 'ZNF216', 'ZFAND5'], description='zinc finger AN1-type containing 5', other_designations='AN1-type zinc finger protein 5|zinc finger A20 domain-containing protein 2|zinc finger protein 216|zinc finger, A20 domain containing 2|zinc finger, AN1-type domain 5', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=72351413, end_position_on_the_genomic_accession=72365208, orientation='minus', exon_count=8, OMIM=[604761], no_hdr0=''),
    7764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7764, CurrentID=0, Status='live', Symbol='ZNF217', Aliases=['ZABC1'], description='zinc finger protein 217', other_designations='zinc finger protein 217', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=53567065, end_position_on_the_genomic_accession=53608969, orientation='minus', exon_count=13, OMIM=[602967], no_hdr0=''),
    7766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7766, CurrentID=0, Status='live', Symbol='ZNF223', Aliases=[], description='zinc finger protein 223', other_designations='zinc finger protein 223|Homo sapiens zinc finger protein 223|KRAB A domain', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44051372, end_position_on_the_genomic_accession=44069902, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    7767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7767, CurrentID=0, Status='live', Symbol='ZNF224', Aliases=['BMZF-2', 'BMZF2', 'KOX22', 'ZNF233', 'ZNF255', 'ZNF27'], description='zinc finger protein 224', other_designations='zinc finger protein 224|bone marrow zinc finger 2|zinc finger protein 233|zinc finger protein 255|zinc finger protein 27|zinc finger protein KOX22', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44094350, end_position_on_the_genomic_accession=44109831, orientation='plus', exon_count=5, OMIM=[194555], no_hdr0=''),
    7768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7768, CurrentID=0, Status='live', Symbol='ZNF225', Aliases=[], description='zinc finger protein 225', other_designations='zinc finger protein 225', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44111426, end_position_on_the_genomic_accession=44134822, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    7769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7769, CurrentID=0, Status='live', Symbol='ZNF226', Aliases=[], description='zinc finger protein 226', other_designations='zinc finger protein 226|Kruppel-associated box protein', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44165070, end_position_on_the_genomic_accession=44198261, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    7770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7770, CurrentID=0, Status='live', Symbol='ZNF227', Aliases=[], description='zinc finger protein 227', other_designations='zinc finger protein 227', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44207522, end_position_on_the_genomic_accession=44237268, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    7771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7771, CurrentID=0, Status='live', Symbol='ZNF112', Aliases=['ZFP112', 'ZNF228'], description='zinc finger protein 112', other_designations='zinc finger protein 112|zinc finger protein 112 (Y14)|zinc finger protein 112 homolog|zinc finger protein 228', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44326553, end_position_on_the_genomic_accession=44367217, orientation='minus', exon_count=6, OMIM=[603994], no_hdr0=''),
    7772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7772, CurrentID=0, Status='live', Symbol='ZNF229', Aliases=[], description='zinc finger protein 229', other_designations='zinc finger protein 229', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44426251, end_position_on_the_genomic_accession=44448578, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    7773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7773, CurrentID=0, Status='live', Symbol='ZNF230', Aliases=['FDZF2'], description='zinc finger protein 230', other_designations='zinc finger protein 230|zinc finger protein FDZF2', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44002957, end_position_on_the_genomic_accession=44013924, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    7775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7775, CurrentID=0, Status='live', Symbol='ZNF232', Aliases=['ZSCAN11'], description='zinc finger protein 232', other_designations='zinc finger protein 232|zinc finger and SCAN domain-containing protein 11', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5105734, end_position_on_the_genomic_accession=5123116, orientation='minus', exon_count=7, OMIM=[616463], no_hdr0=''),
    7776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7776, CurrentID=0, Status='live', Symbol='ZNF236', Aliases=['ZNF236AB', 'ZNF236'], description='zinc finger protein 236', other_designations='zinc finger protein 236|regulated by glucose', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=76822550, end_position_on_the_genomic_accession=76972901, orientation='plus', exon_count=36, OMIM=[604760], no_hdr0=''),
    7779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7779, CurrentID=0, Status='live', Symbol='SLC30A1', Aliases=['ZNT1', 'ZRC1'], description='solute carrier family 30 member 1', other_designations='zinc transporter 1|solute carrier family 30 (zinc transporter), member 1|znT-1', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211571568, end_position_on_the_genomic_accession=211579161, orientation='minus', exon_count=2, OMIM=[609521], no_hdr0=''),
    7780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7780, CurrentID=0, Status='live', Symbol='SLC30A2', Aliases=['PP12488', 'TNZD', 'ZNT2', 'ZnT-2'], description='solute carrier family 30 member 2', other_designations='zinc transporter 2|solute carrier family 30 (zinc transporter), member 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26037252, end_position_on_the_genomic_accession=26046118, orientation='minus', exon_count=8, OMIM=[609617], no_hdr0=''),
    7781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7781, CurrentID=0, Status='live', Symbol='SLC30A3', Aliases=['ZNT3'], description='solute carrier family 30 member 3', other_designations='zinc transporter 3|solute carrier family 30 (zinc transporter), member 3|zinc transporter ZnT-3|znT-3', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27253684, end_position_on_the_genomic_accession=27275863, orientation='minus', exon_count=12, OMIM=[602878], no_hdr0=''),
    7782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7782, CurrentID=0, Status='live', Symbol='SLC30A4', Aliases=['ZNT4', 'znT-4'], description='solute carrier family 30 member 4', other_designations='zinc transporter 4|solute carrier family 30 (zinc transporter), member 4', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45479606, end_position_on_the_genomic_accession=45523755, orientation='minus', exon_count=11, OMIM=[602095], no_hdr0=''),
    7783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7783, CurrentID=0, Status='live', Symbol='ZP2', Aliases=['OOMD6', 'ZPA', 'Zp-2'], description='zona pellucida glycoprotein 2', other_designations='zona pellucida sperm-binding protein 2|zona pellucida glycoprotein 2 (sperm receptor)|zona pellucida glycoprotein ZP2|zona pellucida protein A', map_location='16p12.3-p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21197450, end_position_on_the_genomic_accession=21214510, orientation='minus', exon_count=20, OMIM=[182888], no_hdr0=''),
    7784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7784, CurrentID=0, Status='live', Symbol='ZP3', Aliases=['OOMD3A', 'ZP3B', 'ZPC', 'Zp-3', 'ZP3'], description='zona pellucida glycoprotein 3', other_designations='zona pellucida sperm-binding protein 3|ZP3A/ZP3B|sperm receptor|zona pellucida glycoprotein 3B|zona pellucida glycoprotein ZP3|zona pellucida protein C', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76397522, end_position_on_the_genomic_accession=76442069, orientation='plus', exon_count=9, OMIM=[182889], no_hdr0=''),
    7786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7786, CurrentID=0, Status='live', Symbol='MAP3K12', Aliases=['DLK', 'MEKK12', 'MUK', 'ZPK', 'ZPKP1'], description='mitogen-activated protein kinase kinase kinase 12', other_designations='mitogen-activated protein kinase kinase kinase 12|MAPK-upstream kinase|dual leucine zipper bearing kinase|dual leucine zipper kinase DLK|leucine zipper protein kinase|mixed lineage kinase|protein kinase MUK', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53479669, end_position_on_the_genomic_accession=53501205, orientation='minus', exon_count=19, OMIM=[600447], no_hdr0=''),
    7789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7789, CurrentID=0, Status='live', Symbol='ZXDA', Aliases=['ZNF896'], description='zinc finger X-linked duplicated A', other_designations='zinc finger X-linked protein ZXDA|zinc finger protein 896', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57905430, end_position_on_the_genomic_accession=57910458, orientation='minus', exon_count=1, OMIM=[300235], no_hdr0=''),
    7791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7791, CurrentID=0, Status='live', Symbol='ZYX', Aliases=['ESP-2', 'HED-2'], description='zyxin', other_designations='zyxin|zyxin-2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143381345, end_position_on_the_genomic_accession=143391111, orientation='plus', exon_count=10, OMIM=[602002], no_hdr0=''),
    7798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7798, CurrentID=0, Status='live', Symbol='LUZP1', Aliases=['LUZP'], description='leucine zipper protein 1', other_designations='leucine zipper protein 1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23084030, end_position_on_the_genomic_accession=23177808, orientation='minus', exon_count=7, OMIM=[601422], no_hdr0=''),
    7799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7799, CurrentID=0, Status='live', Symbol='PRDM2', Aliases=['HUMHOXY1', 'KMT8', 'KMT8A', 'MTB-ZF', 'RIZ', 'RIZ1', 'RIZ2'], description='PR/SET domain 2', other_designations='PR domain zinc finger protein 2|GATA-3 binding protein G3B|MTE-binding protein|PR domain 2|PR domain containing 2, with ZNF domain|PR domain-containing protein 2|lysine N-methyltransferase 8|retinoblastoma protein-binding zinc finger protein|retinoblastoma protein-interacting zinc finger protein|zinc finger protein RIZ|zinc-finger DNA-binding protein', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13698874, end_position_on_the_genomic_accession=13825079, orientation='plus', exon_count=17, OMIM=[601196], no_hdr0=''),
    7802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7802, CurrentID=0, Status='live', Symbol='DNALI1', Aliases=['P28', 'dJ423B22.5', 'hp28'], description='dynein axonemal light intermediate chain 1', other_designations='axonemal dynein light intermediate polypeptide 1|dJ423B22.5 (axonemal dynein light chain (hp28))|dynein, axonemal, light intermediate polypeptide 1|inner dynein arm light chain, axonemal|inner dynein arm, homolog of chlamydomonas|inner dynein arm, homolog of clamydomonas', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37556940, end_position_on_the_genomic_accession=37566857, orientation='plus', exon_count=6, OMIM=[602135], no_hdr0=''),
    7803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7803, CurrentID=0, Status='live', Symbol='PTP4A1', Aliases=['HH72', 'PRL-1', 'PRL1', 'PTP(CAAX1)', 'PTPCAAX1'], description='protein tyrosine phosphatase 4A1', other_designations='protein tyrosine phosphatase type IVA 1|PVT1/PTP4A1 fusion|phosphatase of regenerating liver 1|protein tyrosine phosphatase type IVA protein 1|protein tyrosine phosphatase type IVA, member 1|protein-tyrosine phosphatase of regenerating liver 1', map_location='6q12', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=63516440, end_position_on_the_genomic_accession=63583588, orientation='plus', exon_count=15, OMIM=[601585], no_hdr0=''),
    7804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7804, CurrentID=0, Status='live', Symbol='LRP8', Aliases=['APOER2', 'HSZ75190', 'LRP-8', 'MCI1'], description='LDL receptor related protein 8', other_designations='low-density lipoprotein receptor-related protein 8|ApoE receptor 2|low density lipoprotein receptor-related protein 8, apolipoprotein e receptor', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53242364, end_position_on_the_genomic_accession=53328070, orientation='minus', exon_count=22, OMIM=[602600], no_hdr0=''),
    7805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7805, CurrentID=0, Status='live', Symbol='LAPTM5', Aliases=['CLAST6'], description='lysosomal protein transmembrane 5', other_designations='lysosomal-associated transmembrane protein 5|CD40-ligand-activated specific transcripts|human retinoic acid-inducible E3 protein|lysosomal associated multispanning membrane protein 5|lysosomal multispanning membrane protein 5|lysosomal-associated multitransmembrane protein 5|retinoic acid-inducible E3 protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=30732469, end_position_on_the_genomic_accession=30757840, orientation='minus', exon_count=8, OMIM=[601476], no_hdr0=''),
    7809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7809, CurrentID=0, Status='live', Symbol='BSND', Aliases=['BART', 'DFNB73'], description='barttin CLCNK type accessory subunit beta', other_designations='barttin|Bartter syndrome, infantile, with sensorineural deafness (Barttin)|barttin CLCNK type accessory beta subunit|barttin CLCNK-type chloride channel accessory beta subunit|deafness, autosomal recessive 73', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54998933, end_position_on_the_genomic_accession=55017172, orientation='plus', exon_count=4, OMIM=[606412], no_hdr0=''),
    7812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7812, CurrentID=0, Status='live', Symbol='CSDE1', Aliases=['D1S155E', 'UNR'], description='cold shock domain containing E1', other_designations='cold shock domain-containing protein E1|N-ras upstream gene protein|NRAS-related|cold shock domain containing E1, RNA binding|upstream of NRAS', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114716916, end_position_on_the_genomic_accession=114757984, orientation='minus', exon_count=21, OMIM=[191510], no_hdr0=''),
    7813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7813, CurrentID=0, Status='live', Symbol='EVI5', Aliases=['EVI-5', 'NB4S'], description='ecotropic viral integration site 5', other_designations='ecotropic viral integration site 5 protein homolog|dJ846D11.1 (ecotropic viral integration site 5)|neuroblastoma stage 4S gene protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92508696, end_position_on_the_genomic_accession=92792413, orientation='minus', exon_count=30, OMIM=[602942], no_hdr0=''),
    7818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7818, CurrentID=0, Status='live', Symbol='DAP3', Aliases=['DAP-3', 'MRP-S29', 'MRPS29', 'S29mt', 'bMRP-10'], description='death associated protein 3', other_designations='28S ribosomal protein S29, mitochondrial|ionizing radiation resistance conferring protein|mitochondrial 28S ribosomal protein S29|mitochondrial small ribosomal subunit protein mS29', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155687902, end_position_on_the_genomic_accession=155739010, orientation='plus', exon_count=15, OMIM=[602074], no_hdr0=''),
    7827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7827, CurrentID=0, Status='live', Symbol='NPHS2', Aliases=['PDCN', 'SRN1'], description='NPHS2 stomatin family member, podocin', other_designations='podocin|NPHS2, podocin|nephrosis 2, idiopathic, steroid-resistant (podocin)', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179550539, end_position_on_the_genomic_accession=179575987, orientation='minus', exon_count=8, OMIM=[604766], no_hdr0=''),
    7832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7832, CurrentID=0, Status='live', Symbol='BTG2', Aliases=['APRO1', 'PC3', 'TIS21'], description='BTG anti-proliferation factor 2', other_designations='protein BTG2|B-cell translocation gene 2|BTG family member 2|NGF-inducible anti-proliferative protein PC3|nerve growth factor-inducible anti-proliferative|pheochromacytoma cell-3', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203305519, end_position_on_the_genomic_accession=203309602, orientation='plus', exon_count=2, OMIM=[601597], no_hdr0=''),
    7837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7837, CurrentID=0, Status='live', Symbol='PXDN', Aliases=['ASGD7', 'COPOA', 'D2S448', 'D2S448E', 'MG50', 'PRG2', 'PXN', 'VPO'], description='peroxidasin', other_designations='peroxidasin homolog|melanoma-associated antigen MG50|p53-responsive gene 2 protein|vascular peroxidase 1', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=1631887, end_position_on_the_genomic_accession=1744852, orientation='minus', exon_count=24, OMIM=[605158], no_hdr0=''),
    7840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7840, CurrentID=0, Status='live', Symbol='ALMS1', Aliases=['ALSS'], description='ALMS1 centrosome and basal body associated protein', other_designations='Alstrom syndrome protein 1|Alstrom syndrome 1', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73385758, end_position_on_the_genomic_accession=73609919, orientation='plus', exon_count=23, OMIM=[606844], no_hdr0=''),
    7841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7841, CurrentID=0, Status='live', Symbol='MOGS', Aliases=['CDG2B', 'CWH41', 'DER7', 'GCS1'], description='mannosyl-oligosaccharide glucosidase', other_designations='mannosyl-oligosaccharide glucosidase|epididymis secretory sperm binding protein|glucosidase I|processing A-glucosidase I', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74461057, end_position_on_the_genomic_accession=74465382, orientation='minus', exon_count=5, OMIM=[601336], no_hdr0=''),
    7844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7844, CurrentID=0, Status='live', Symbol='RNF103', Aliases=['HKF-1', 'KF-1', 'KF1', 'ZFP-103', 'ZFP103'], description='ring finger protein 103', other_designations='E3 ubiquitin-protein ligase RNF103|RING-type E3 ubiquitin transferase RNF103|zinc finger protein 103 homolog|zinc finger protein expressed in cerebellum', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86603393, end_position_on_the_genomic_accession=86623877, orientation='minus', exon_count=5, OMIM=[602507], no_hdr0=''),
    7846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7846, CurrentID=0, Status='live', Symbol='TUBA1A', Aliases=['B-ALPHA-1', 'LIS3', 'TUBA3'], description='tubulin alpha 1a', other_designations='tubulin alpha-1A chain|hum-a-tub1|hum-a-tub2|tubulin B-alpha-1|tubulin alpha-3 chain|tubulin, alpha, brain-specific', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49184795, end_position_on_the_genomic_accession=49189080, orientation='minus', exon_count=4, OMIM=[602529], no_hdr0=''),
    7849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7849, CurrentID=0, Status='live', Symbol='PAX8', Aliases=[], description='paired box 8', other_designations='paired box protein Pax-8|paired domain gene 8', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113215997, end_position_on_the_genomic_accession=113278921, orientation='minus', exon_count=12, OMIM=[167415], no_hdr0=''),
    7850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7850, CurrentID=0, Status='live', Symbol='IL1R2', Aliases=['CD121b', 'CDw121b', 'IL-1R-2', 'IL-1RT-2', 'IL-1RT2c', 'IL1RB', 'IL1R2'], description='interleukin 1 receptor type 2', other_designations='interleukin-1 receptor type 2|CD121 antigen-like family member B|IL-1 type II receptor|IL-1R-beta|antigen CDw121b|interleukin 1 receptor type II variant 3|interleukin-1 receptor beta|interleukin-1 receptor type II|type II interleukin-1 receptor, beta', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101991805, end_position_on_the_genomic_accession=102028544, orientation='plus', exon_count=15, OMIM=[147811], no_hdr0=''),
    7851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7851, CurrentID=0, Status='live', Symbol='MALL', Aliases=['BENE'], description='mal, T cell differentiation protein like', other_designations='MAL-like protein', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110083870, end_position_on_the_genomic_accession=110118139, orientation='minus', exon_count=5, OMIM=[602022], no_hdr0=''),
    7852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7852, CurrentID=0, Status='live', Symbol='CXCR4', Aliases=['CD184', 'D2S201E', 'FB22', 'HM89', 'HSY3RR', 'LAP-3', 'LAP3', 'LCR1', 'LESTR', 'NPY3R', 'NPYR', 'NPYRL', 'NPYY3R', 'WHIM', 'WHIMS', 'WHIMS1'], description='C-X-C motif chemokine receptor 4', other_designations='C-X-C chemokine receptor type 4|CD184 antigen|LPS-associated protein 3|SDF-1 receptor|chemokine (C-X-C motif) receptor 4|fusin|leukocyte-derived seven transmembrane domain receptor|lipopolysaccharide-associated protein 3|neuropeptide Y receptor Y3|neuropeptide Y3 receptor|seven transmembrane helix receptor|seven-transmembrane-segment receptor, spleen|stromal cell-derived factor 1 receptor', map_location='2q22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=136114349, end_position_on_the_genomic_accession=136118149, orientation='minus', exon_count=4, OMIM=[162643], no_hdr0=''),
    7855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7855, CurrentID=0, Status='live', Symbol='FZD5', Aliases=['C2orf31', 'HFZ5'], description='frizzled class receptor 5', other_designations='frizzled-5|Wnt receptor|frizzled 5, seven transmembrane spanning receptor|frizzled family receptor 5|fz-5|fzE5|seven-transmembrane receptor frizzled-5', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207753889, end_position_on_the_genomic_accession=207769906, orientation='minus', exon_count=4, OMIM=[601723], no_hdr0=''),
    7857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7857, CurrentID=0, Status='live', Symbol='SCG2', Aliases=['CHGC', 'EM66', 'SN', 'SgII'], description='secretogranin II', other_designations='secretogranin-2|chromogranin-C|secretoneurin', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223596940, end_position_on_the_genomic_accession=223602361, orientation='minus', exon_count=2, OMIM=[118930], no_hdr0=''),
    7862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7862, CurrentID=0, Status='live', Symbol='BRPF1', Aliases=['BR140', 'IDDDFP'], description='bromodomain and PHD finger containing 1', other_designations='peregrin|bromodomain-containing protein, 140kD', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9731729, end_position_on_the_genomic_accession=9748015, orientation='plus', exon_count=16, OMIM=[602410], no_hdr0=''),
    7866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7866, CurrentID=0, Status='live', Symbol='IFRD2', Aliases=['IFNRP', 'SKMc15', 'SM15'], description='interferon related developmental regulator 2', other_designations='interferon-related developmental regulator 2|interferon-related protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50287732, end_position_on_the_genomic_accession=50292429, orientation='minus', exon_count=12, OMIM=[602725], no_hdr0=''),
    7867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7867, CurrentID=0, Status='live', Symbol='MAPKAPK3', Aliases=['3PK', 'MAPKAP-K3', 'MAPKAP3', 'MAPKAPK-3', 'MDPT3', 'MK-3', 'MK3'], description='MAPK activated protein kinase 3', other_designations='MAP kinase-activated protein kinase 3|MAPKAP kinase 3|chromosome 3p kinase|mitogen-activated protein kinase-activated protein kinase 3', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50611877, end_position_on_the_genomic_accession=50649291, orientation='plus', exon_count=14, OMIM=[602130], no_hdr0=''),
    7869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7869, CurrentID=0, Status='live', Symbol='SEMA3B', Aliases=['LUCA-1', 'SEMA5', 'SEMAA', 'SemA', 'semaV'], description='semaphorin 3B', other_designations='semaphorin-3B|sema A(V)|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3B|semaphorin A|semaphorin-V', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50267652, end_position_on_the_genomic_accession=50277546, orientation='plus', exon_count=18, OMIM=[601281], no_hdr0=''),
    7871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7871, CurrentID=0, Status='live', Symbol='SLMAP', Aliases=['SLAP'], description='sarcolemma associated protein', other_designations='sarcolemmal membrane-associated protein', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57756229, end_position_on_the_genomic_accession=57930013, orientation='plus', exon_count=27, OMIM=[602701], no_hdr0=''),
    7873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7873, CurrentID=0, Status='live', Symbol='MANF', Aliases=['ARMET', 'ARP'], description='mesencephalic astrocyte derived neurotrophic factor', other_designations='mesencephalic astrocyte-derived neurotrophic factor|arginine-rich, mutated in early stage tumors', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51385291, end_position_on_the_genomic_accession=51389397, orientation='plus', exon_count=4, OMIM=[601916], no_hdr0=''),
    7874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7874, CurrentID=0, Status='live', Symbol='USP7', Aliases=['HAFOUS', 'HAUSP', 'TEF1'], description='ubiquitin specific peptidase 7', other_designations='ubiquitin carboxyl-terminal hydrolase 7|Herpes virus-associated ubiquitin-specific protease|deubiquitinating enzyme 7|ubiquitin specific peptidase 7 (herpes virus-associated)|ubiquitin specific protease 7 (herpes virus-associated)|ubiquitin thioesterase 7|ubiquitin-specific-processing protease 7', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8892097, end_position_on_the_genomic_accession=8963912, orientation='minus', exon_count=35, OMIM=[602519], no_hdr0=''),
    7879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7879, CurrentID=0, Status='live', Symbol='RAB7A', Aliases=['CMT2B', 'PRO2706', 'RAB7'], description='RAB7A, member RAS oncogene family', other_designations='ras-related protein Rab-7a|RAB7, member RAS oncogene family|Ras-associated protein RAB7', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128726183, end_position_on_the_genomic_accession=128814798, orientation='plus', exon_count=6, OMIM=[602298], no_hdr0=''),
    7881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7881, CurrentID=0, Status='live', Symbol='KCNAB1', Aliases=['AKR6A3', 'KCNA1B', 'KV-BETA-1', 'Kvb1.3', 'hKvBeta3', 'hKvb3'], description='potassium voltage-gated channel subfamily A regulatory beta subunit 1', other_designations='voltage-gated potassium channel subunit beta-1|K(+) channel subunit beta-1|K+ channel Beta1a chain|potassium channel beta 3 chain|potassium channel beta3 subunit|potassium channel shaker chain beta 1a|potassium channel, voltage gated subfamily A regulatory beta subunit 1|potassium voltage-gated channel subfamily A member regulatory beta subunit 1|potassium voltage-gated channel, shaker-related subfamily, beta member 1', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=156118216, end_position_on_the_genomic_accession=156542648, orientation='plus', exon_count=21, OMIM=[601141], no_hdr0=''),
    7884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7884, CurrentID=0, Status='live', Symbol='SLBP', Aliases=['HBP'], description='stem-loop binding protein', other_designations='histone RNA hairpin-binding protein|hairpin binding protein, histone|histone binding protein|histone stem-loop binding protein|stem-loop (histone) binding protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1692731, end_position_on_the_genomic_accession=1715876, orientation='minus', exon_count=8, OMIM=[602422], no_hdr0=''),
    7903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7903, CurrentID=0, Status='live', Symbol='ST8SIA4', Aliases=['PST', 'PST1', 'SIAT8D', 'ST8SIA-IV'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 4', other_designations='CMP-N-acetylneuraminate-poly-alpha-2,8-sialyltransferase|CMP-N-acetylneuraminate-poly-alpha-2,8-sialyl transferase|SIAT8-D|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 4|ST8SiaIV|alpha-2,8-sialyltransferase 8D|polysialyltransferase-1|sialyltransferase 8 (alpha-2, 8-polysialytransferase) D|sialyltransferase 8D|sialyltransferase St8Sia IV|sialytransferase St8Sia IV', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=100806933, end_position_on_the_genomic_accession=100903282, orientation='minus', exon_count=6, OMIM=[602547], no_hdr0=''),
    7905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7905, CurrentID=0, Status='live', Symbol='REEP5', Aliases=['C5orf18', 'D5S346', 'DP1', 'POB16', 'TB2', 'YOP1', 'Yip2e'], description='receptor accessory protein 5', other_designations='receptor expression-enhancing protein 5|deleted in polyposis 1|polyposis coli region hypothetical protein DP1|polyposis locus protein 1', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=112876385, end_position_on_the_genomic_accession=112922289, orientation='minus', exon_count=5, OMIM=[125265], no_hdr0=''),
    7913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7913, CurrentID=0, Status='live', Symbol='DEK', Aliases=['D6S231E'], description='DEK proto-oncogene', other_designations='protein DEK|DEK oncogene (DNA binding)', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=18223860, end_position_on_the_genomic_accession=18264541, orientation='minus', exon_count=13, OMIM=[125264], no_hdr0=''),
    7915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7915, CurrentID=0, Status='live', Symbol='ALDH5A1', Aliases=['SSADH', 'SSDH'], description='aldehyde dehydrogenase 5 family member A1', other_designations='succinate-semialdehyde dehydrogenase, mitochondrial|NAD(+)-dependent succinic semialdehyde dehydrogenase|mitochondrial succinate semialdehyde dehydrogenase', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24494969, end_position_on_the_genomic_accession=24537207, orientation='plus', exon_count=11, OMIM=[610045], no_hdr0=''),
    7916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7916, CurrentID=0, Status='live', Symbol='PRRC2A', Aliases=['BAT2', 'D6S51', 'D6S51E', 'G2'], description='proline rich coiled-coil 2A', other_designations='protein PRRC2A|HLA-B-associated transcript 2|large proline-rich protein BAT2|proline-rich and coiled-coil-containing protein 2A|protein G2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31620715, end_position_on_the_genomic_accession=31637780, orientation='plus', exon_count=31, OMIM=[142580], no_hdr0=''),
    7917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7917, CurrentID=0, Status='live', Symbol='BAG6', Aliases=['BAG-6', 'BAT3', 'D6S52E', 'G3'], description='BAG cochaperone 6', other_designations='large proline-rich protein BAG6|BAG family molecular chaperone regulator 6|BCL2 associated athanogene 6|HLA-B-associated transcript 3|large proline-rich protein BAT3|protein G3|protein Scythe|scythe', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31639028, end_position_on_the_genomic_accession=31660900, orientation='minus', exon_count=30, OMIM=[142590], no_hdr0=''),
    7918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7918, CurrentID=0, Status='live', Symbol='GPANK1', Aliases=['ANKRD59', 'BAT4', 'D6S54E', 'G5', 'GPATCH10'], description='G-patch domain and ankyrin repeats 1', other_designations='G patch domain and ankyrin repeat-containing protein 1|G patch domain and ankyrin repeats-containing protein 1|G patch domain containing 10|HLA-B-associated transcript 4|ankyrin repeat domain-containing protein 59|g patch domain-containing protein 10|protein BAT4|protein G5', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31661228, end_position_on_the_genomic_accession=31666283, orientation='minus', exon_count=6, OMIM=[142610], no_hdr0=''),
    7919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7919, CurrentID=0, Status='live', Symbol='DDX39B', Aliases=['BAT1', 'D6S81E', 'UAP56'], description='DExD-box helicase 39B', other_designations='spliceosome RNA helicase DDX39B|56 kDa U2AF65-associated protein|ATP-dependent RNA helicase p47|DEAD (Asp-Glu-Ala-Asp) box polypeptide 39B|DEAD-box helicase 39B|HLA-B-associated transcript 1 protein|nuclear RNA helicase (DEAD family)|spliceosome RNA helicase BAT1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31530226, end_position_on_the_genomic_accession=31542003, orientation='minus', exon_count=11, OMIM=[142560], no_hdr0=''),
    7920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7920, CurrentID=0, Status='live', Symbol='ABHD16A', Aliases=['BAT5', 'D6S82E', 'NG26', 'PP199', 'hBAT5'], description='abhydrolase domain containing 16A, phospholipase', other_designations='phosphatidylserine lipase ABHD16A|HLA-B associated transcript 5|abhydrolase domain-containing protein 16A|alpha/beta hydrolase domain-containing protein 16A|monoacylglycerol lipase ABHD16A|protein ABHD16A|protein G5', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31686955, end_position_on_the_genomic_accession=31703324, orientation='minus', exon_count=21, OMIM=[142620], no_hdr0=''),
    7922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7922, CurrentID=0, Status='live', Symbol='SLC39A7', Aliases=['D6S115E', 'D6S2244E', 'H2-KE4', 'HKE4', 'KE4', 'RING5', 'ZIP7'], description='solute carrier family 39 member 7', other_designations='zinc transporter SLC39A7|HLA class II region expressed gene KE4|Ke4 gene, mouse, human homolog of|histidine-rich membrane protein Ke4|really interesting new gene 5 protein|solute carrier family 39 (zinc transporter), member 7|zrt-, Irt-like protein 7', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33200867, end_position_on_the_genomic_accession=33204437, orientation='plus', exon_count=8, OMIM=[601416], no_hdr0=''),
    7923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7923, CurrentID=0, Status='live', Symbol='HSD17B8', Aliases=['D6S2245E', 'FABG', 'FABGL', 'H2-KE6', 'HKE6', 'KE6', 'RING2', 'SDR30C1', 'dJ1033B10.9'], description='hydroxysteroid 17-beta dehydrogenase 8', other_designations='(3R)-3-hydroxyacyl-CoA dehydrogenase|17-beta-HSD 8|17-beta-hydroxysteroid dehydrogenase 8|3-ketoacyl-[acyl-carrier-protein] reductase alpha subunit|3-oxoacyl-[acyl-carrier-protein] reductase|KAR alpha subunit|estradiol 17-beta-dehydrogenase 8|estrogen 17-oxidoreductase|ke-6|protein Ke6|really interesting new gene 2 protein|short chain dehydrogenase/reductase family 30C member 1|testosterone 17-beta-dehydrogenase 8', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33204655, end_position_on_the_genomic_accession=33206831, orientation='plus', exon_count=9, OMIM=[601417], no_hdr0=''),
    7932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7932, CurrentID=0, Status='live', Symbol='OR2H2', Aliases=['FAT11', 'OLFR2', 'OLFR42B', 'OR2H3', 'dJ271M21.2', 'hs6M1-12'], description='olfactory receptor family 2 subfamily H member 2', other_designations='olfactory receptor 2H2|Olfactory receptor 2|olfactory receptor 2H3|olfactory receptor OR6-36|olfactory receptor, family 2, subfamily H, member 3|olfactory receptor-like protein FAT11', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29585121, end_position_on_the_genomic_accession=29592506, orientation='plus', exon_count=3, OMIM=[600578], no_hdr0=''),
    7936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7936, CurrentID=0, Status='live', Symbol='NELFE', Aliases=['D6S45', 'NELF-E', 'RD', 'RDBP', 'RDP'], description='negative elongation factor complex member E', other_designations='negative elongation factor E|RD RNA-binding protein|RNA-binding protein RD|major histocompatibility complex gene RD|negative elongation factor polypeptide E|nuclear protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31952087, end_position_on_the_genomic_accession=31959043, orientation='minus', exon_count=11, OMIM=[154040], no_hdr0=''),
    7938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7938, CurrentID=0, Status='live', Symbol='CP20', Aliases=['LCP20'], description='lymphocyte cytosol polypeptide, 20 kD', other_designations='lymphocyte cytosolic protein, molecular weight 20kD', map_location='6p21.3-p21.2', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[153380], no_hdr0=''),
    7940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7940, CurrentID=0, Status='live', Symbol='LST1', Aliases=['B144', 'D6S49E', 'LST-1'], description='leukocyte specific transcript 1', other_designations='leukocyte-specific transcript 1 protein|lymphocyte antigen 117', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31586185, end_position_on_the_genomic_accession=31588909, orientation='plus', exon_count=6, OMIM=[109170], no_hdr0=''),
    7941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7941, CurrentID=0, Status='live', Symbol='PLA2G7', Aliases=['LDL-PLA2', 'LP-PLA2', 'PAFAD', 'PAFAH'], description='phospholipase A2 group VII', other_designations='platelet-activating factor acetylhydrolase|1-alkyl-2-acetylglycerophosphocholine esterase|2-acetyl-1-alkylglycerophosphocholine esterase|LDL-PLA(2)|LDL-associated phospholipase A2|PAF 2-acylhydrolase|PAF acetylhydrolase|gVIIA-PLA2|group-VIIA phospholipase A2|lipoprotein-associated phospholipase A2|phospholipase A2, group VII (platelet-activating factor acetylhydrolase, plasma)', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46700558, end_position_on_the_genomic_accession=46735836, orientation='minus', exon_count=13, OMIM=[601690], no_hdr0=''),
    7942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7942, CurrentID=0, Status='live', Symbol='TFEB', Aliases=['ALPHATFEB', 'BHLHE35', 'TCFEB'], description='transcription factor EB', other_designations='transcription factor EB|T-cell transcription factor EB|class E basic helix-loop-helix protein 35', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41683978, end_position_on_the_genomic_accession=41736223, orientation='minus', exon_count=17, OMIM=[600744], no_hdr0=''),
    7957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7957, CurrentID=0, Status='live', Symbol='EPM2A', Aliases=['EPM2', 'MELF'], description='EPM2A glucan phosphatase, laforin', other_designations='laforin|EPM2A, laforin glucan phosphatase|LAFPTPase|epilepsy, progressive myoclonus type 2, Lafora disease (laforin)|epilepsy, progressive myoclonus type 2A, Lafora disease (laforin)|glucan phosphatase|glycogen phosphatase|lafora PTPase', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=145382540, end_position_on_the_genomic_accession=145736023, orientation='minus', exon_count=14, OMIM=[607566], no_hdr0=''),
    7965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7965, CurrentID=0, Status='live', Symbol='AIMP2', Aliases=['HLD17', 'JTV-1', 'JTV1', 'P38'], description='aminoacyl tRNA synthetase complex interacting multifunctional protein 2', other_designations='aminoacyl tRNA synthase complex-interacting multifunctional protein 2|ARS-interacting multi-functional protein 2|multisynthase complex auxiliary component p38|multisynthetase complex auxiliary component p38|protein JTV-1', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6009272, end_position_on_the_genomic_accession=6023834, orientation='plus', exon_count=9, OMIM=[600859], no_hdr0=''),
    7975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7975, CurrentID=0, Status='live', Symbol='MAFK', Aliases=['NFE2U', 'P18'], description='MAF bZIP transcription factor K', other_designations='transcription factor MafK|basic-leucine zipper transcription factor MafK|erythroid transcription factor NF-E2 p18 subunit|nuclear factor erythroid-2, ubiquitous (p18)|v-maf avian musculoaponeurotic fibrosarcoma oncogene family, protein K|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog K|v-maf musculoaponeurotic fibrosarcoma oncogene homolog K', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1530702, end_position_on_the_genomic_accession=1543043, orientation='plus', exon_count=5, OMIM=[600197], no_hdr0=''),
    7976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7976, CurrentID=0, Status='live', Symbol='FZD3', Aliases=['Fz-3'], description='frizzled class receptor 3', other_designations='frizzled-3|frizzled 3, seven transmembrane spanning receptor|frizzled family receptor 3|frizzled homolog 3', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28494212, end_position_on_the_genomic_accession=28574268, orientation='plus', exon_count=12, OMIM=[606143], no_hdr0=''),
    7978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7978, CurrentID=0, Status='live', Symbol='MTERF1', Aliases=['MTERF'], description='mitochondrial transcription termination factor 1', other_designations='transcription termination factor 1, mitochondrial|transcription termination factor, mitochondrial', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=91870929, end_position_on_the_genomic_accession=91880733, orientation='minus', exon_count=4, OMIM=[602318], no_hdr0=''),
    7979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7979, CurrentID=0, Status='live', Symbol='SEM1', Aliases=['C7orf76', 'DSS1', 'ECD', 'PSMD15', 'SHFD1', 'SHFM1', 'SHSF1', 'Shfdg1'], description='SEM1 26S proteasome subunit', other_designations='26S proteasome complex subunit SEM1|26S proteasome complex subunit DSS1|SEM1 26S proteasome complex subunit|deleted in split hand/split foot protein 1|deleted in split-hand/split-foot 1|split hand/foot deleted protein 1|split hand/foot malformation (ectrodactyly) type 1|split hand/foot malformation type 1 protein', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=96481626, end_position_on_the_genomic_accession=96709846, orientation='minus', exon_count=18, OMIM=[601285], no_hdr0=''),
    7980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7980, CurrentID=0, Status='live', Symbol='TFPI2', Aliases=['PP5', 'REF1', 'TFPI-2'], description='tissue factor pathway inhibitor 2', other_designations='tissue factor pathway inhibitor 2|placental protein 5|retinal pigment epithelium cell factor 1', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93885396, end_position_on_the_genomic_accession=93890753, orientation='minus', exon_count=5, OMIM=[600033], no_hdr0=''),
    7982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7982, CurrentID=0, Status='live', Symbol='ST7', Aliases=['ETS7q', 'FAM4A', 'FAM4A1', 'HELG', 'RAY1', 'SEN4', 'TSG7'], description='suppression of tumorigenicity 7', other_designations='suppressor of tumorigenicity 7 protein|family with sequence similarity 4, subfamily A, member 1|suppression of tumorigenicity 7 (breast)', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116953501, end_position_on_the_genomic_accession=117230176, orientation='plus', exon_count=21, OMIM=[600833], no_hdr0=''),
    7984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7984, CurrentID=0, Status='live', Symbol='ARHGEF5', Aliases=['GEF5', 'P60', 'TIM', 'TIM1'], description='Rho guanine nucleotide exchange factor 5', other_designations='rho guanine nucleotide exchange factor 5|Rho guanine nucleotide exchange factor (GEF) 5|ephexin-3|ephexin3|guanine nucleotide regulatory protein TIM|oncogene TIM|p60 TIM|transforming immortalized mammary oncogene', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144355396, end_position_on_the_genomic_accession=144380632, orientation='plus', exon_count=15, OMIM=[600888], no_hdr0=''),
    7988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7988, CurrentID=0, Status='live', Symbol='ZNF212', Aliases=['C2H2-150', 'ZNF182', 'ZNFC150'], description='zinc finger protein 212', other_designations='zinc finger protein 212|Zinc finger protein C2H2-150', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149239651, end_position_on_the_genomic_accession=149255606, orientation='plus', exon_count=5, OMIM=[602386], no_hdr0=''),
    7991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7991, CurrentID=0, Status='live', Symbol='TUSC3', Aliases=['D8S1992', 'M33', 'MRT22', 'MRT7', 'MagT2', 'N33', 'OST3A', 'SLC58A2'], description='tumor suppressor candidate 3', other_designations='tumor suppressor candidate 3|dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit TUSC3|magnesium uptake/transporter TUSC3|mental retardation, non-syndromic, autosomal recessive, 22|oligosaccharyl transferase subunit TUSC3|oligosaccharyltransferase 3 homolog A|putative prostate cancer tumor suppressor', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=15540087, end_position_on_the_genomic_accession=15766649, orientation='plus', exon_count=12, OMIM=[601385], no_hdr0=''),
    7993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7993, CurrentID=0, Status='live', Symbol='UBXN8', Aliases=['D8S2298E', 'REP8', 'UBXD6'], description='UBX domain protein 8', other_designations='UBX domain-containing protein 8|Reproduction/chromosome 8|UBX domain-containing protein 6|rep-8 protein|reproduction 8 protein', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30729131, end_position_on_the_genomic_accession=30767006, orientation='plus', exon_count=11, OMIM=[602155], no_hdr0=''),
    7994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=7994, CurrentID=0, Status='live', Symbol='KAT6A', Aliases=['ARTHS', 'MOZ', 'MRD32', 'MYST-3', 'MYST3', 'RUNXBP2', 'ZC2HC6A', 'ZNF220'], description='lysine acetyltransferase 6A', other_designations='histone acetyltransferase KAT6A|K(lysine) acetyltransferase 6A|MOZ, YBF2/SAS3, SAS2 and TIP60 protein 3|MYST histone acetyltransferase (monocytic leukemia) 3|histone acetyltransferase MYST3|monocytic leukemia zinc finger protein|runt-related transcription factor binding protein 2|zinc finger protein 220', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41929479, end_position_on_the_genomic_accession=42051988, orientation='minus', exon_count=19, OMIM=[601408], no_hdr0=''),
    8000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8000, CurrentID=0, Status='live', Symbol='PSCA', Aliases=['PRO232'], description='prostate stem cell antigen', other_designations='prostate stem cell antigen', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142670297, end_position_on_the_genomic_accession=142682725, orientation='plus', exon_count=4, OMIM=[602470], no_hdr0=''),
    8001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8001, CurrentID=0, Status='live', Symbol='GLRA3', Aliases=[], description='glycine receptor alpha 3', other_designations='glycine receptor subunit alpha-3|glycine receptor, alpha-3 polypeptide|ligand gated ion channel', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=174636920, end_position_on_the_genomic_accession=174829568, orientation='minus', exon_count=13, OMIM=[600421], no_hdr0=''),
    8013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8013, CurrentID=0, Status='live', Symbol='NR4A3', Aliases=['CHN', 'CSMF', 'MINOR', 'NOR1'], description='nuclear receptor subfamily 4 group A member 3', other_designations='nuclear receptor subfamily 4 group A member 3|chondrosarcoma, extraskeletal myxoid, fused to EWS|mitogen-induced nuclear orphan receptor|neuron-derived orphan receptor 1|nuclear hormone receptor NOR-1|translocated in extraskeletal chondrosarcoma', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99821885, end_position_on_the_genomic_accession=99866893, orientation='plus', exon_count=10, OMIM=[600542], no_hdr0=''),
    8019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8019, CurrentID=0, Status='live', Symbol='BRD3', Aliases=['ORFX', 'RING3L'], description='bromodomain containing 3', other_designations='bromodomain-containing protein 3|RING3-like protein', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134030305, end_position_on_the_genomic_accession=134068533, orientation='minus', exon_count=15, OMIM=[601541], no_hdr0=''),
    8021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8021, CurrentID=0, Status='live', Symbol='NUP214', Aliases=['CAIN', 'CAN', 'IIAE9'], description='nucleoporin 214', other_designations='nuclear pore complex protein Nup214|CAN protein, putative oncogene|nucleoporin 214kDa', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131125586, end_position_on_the_genomic_accession=131234663, orientation='plus', exon_count=37, OMIM=[114350], no_hdr0=''),
    8022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8022, CurrentID=0, Status='live', Symbol='LHX3', Aliases=['CPHD3', 'LIM3', 'M2-LHX3'], description='LIM homeobox 3', other_designations='LIM/homeobox protein Lhx3|LIM homeobox protein 3|LIM/homeodomain protein LHX3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136196250, end_position_on_the_genomic_accession=136205128, orientation='minus', exon_count=9, OMIM=[600577], no_hdr0=''),
    8027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8027, CurrentID=0, Status='live', Symbol='STAM', Aliases=['STAM-11', 'STAM'], description='signal transducing adaptor molecule', other_designations='signal transducing adapter molecule 1|HSE1 homolog|signal transducing adaptor molecule (SH3 domain and ITAM motif) 1', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17644150, end_position_on_the_genomic_accession=17716824, orientation='plus', exon_count=18, OMIM=[601899], no_hdr0=''),
    8028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8028, CurrentID=0, Status='live', Symbol='MLLT10', Aliases=['AF10'], description='MLLT10 histone lysine methyltransferase DOT1L cofactor', other_designations='protein AF-10|ALL1-fused gene from chromosome 10 protein|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 10|myeloid/lymphoid or mixed-lineage leukemia; translocated to, 10|type I AF10 protein|type III AF10 protein|type IV AF10 protein', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=21524616, end_position_on_the_genomic_accession=21743630, orientation='plus', exon_count=39, OMIM=[602409], no_hdr0=''),
    8029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8029, CurrentID=0, Status='live', Symbol='CUBN', Aliases=['IFCR', 'IGS', 'IGS1', 'MGA1', 'gp280'], description='cubilin', other_designations='cubilin|460 kDa receptor|cubilin (intrinsic factor-cobalamin receptor)|cubilin precursor variant 1|cubilin precursor variant 2|cubilin precursor variant 3|intestinal intrinsic factor receptor|intrinsic factor-vitamin B12 receptor', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=16823966, end_position_on_the_genomic_accession=17130492, orientation='minus', exon_count=71, OMIM=[602997], no_hdr0=''),
    8030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8030, CurrentID=0, Status='live', Symbol='CCDC6', Aliases=['D10S170', 'H4', 'PTC', 'TPC', 'TST1'], description='coiled-coil domain containing 6', other_designations='coiled-coil domain-containing protein 6|papillary thyroid carcinoma-encoded protein', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=59788747, end_position_on_the_genomic_accession=59906556, orientation='minus', exon_count=9, OMIM=[601985], no_hdr0=''),
    8031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8031, CurrentID=0, Status='live', Symbol='NCOA4', Aliases=['ARA70', 'ELE1', 'PTC3', 'RFG'], description='nuclear receptor coactivator 4', other_designations='nuclear receptor coactivator 4|70 kDa AR-activator|70 kDa androgen receptor coactivator|NCoA-4|RET-activating gene ELE1|androgen receptor-associated protein of 70 kDa|ret fused', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46005088, end_position_on_the_genomic_accession=46030623, orientation='minus', exon_count=14, OMIM=[601984], no_hdr0=''),
    8034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8034, CurrentID=0, Status='live', Symbol='SLC25A16', Aliases=['D10S105E', 'GDA', 'GDC', 'HGT.1', 'ML7', 'hML7'], description='solute carrier family 25 member 16', other_designations='graves disease carrier protein|mitochondrial solute carrier protein homolog|solute carrier family 25 (mitochondrial carrier; Graves disease autoantigen), member 16', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68477998, end_position_on_the_genomic_accession=68527523, orientation='minus', exon_count=10, OMIM=[139080], no_hdr0=''),
    8036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8036, CurrentID=0, Status='live', Symbol='SHOC2', Aliases=['NSLH1', 'SIAA0862', 'SOC2', 'SUR8'], description='SHOC2 leucine rich repeat scaffold protein', other_designations='leucine-rich repeat protein SHOC-2|soc-2 suppressor of clear homolog', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110919370, end_position_on_the_genomic_accession=111013665, orientation='plus', exon_count=11, OMIM=[602775], no_hdr0=''),
    8038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8038, CurrentID=0, Status='live', Symbol='ADAM12', Aliases=['ADAM12-OT1', 'CAR10', 'MCMP', 'MCMPMltna', 'MLTN', 'MLTNA'], description='ADAM metallopeptidase domain 12', other_designations='disintegrin and metalloproteinase domain-containing protein 12|meltrin-alpha|metalloprotease-disintegrin 12 transmembrane', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=126012391, end_position_on_the_genomic_accession=126388477, orientation='minus', exon_count=27, OMIM=[602714], no_hdr0=''),
    8045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8045, CurrentID=0, Status='live', Symbol='RASSF7', Aliases=['C11orf13', 'CFAP88', 'FAP88', 'HRAS1', 'HRC1'], description='Ras association domain family member 7', other_designations='ras association domain-containing protein 7|HRAS1-related cluster protein 1|HRAS1-related cluster-1|Ras association (RalGDS/AF-6) domain family (N-terminal) member 7|Ras association (RalGDS/AF-6) domain family 7', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=560970, end_position_on_the_genomic_accession=564025, orientation='plus', exon_count=6, OMIM=[143023], no_hdr0=''),
    8048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8048, CurrentID=0, Status='live', Symbol='CSRP3', Aliases=['CLP', 'CMD1M', 'CMH12', 'CRP3', 'LMO4', 'MLP'], description='cysteine and glycine rich protein 3', other_designations='cysteine and glycine-rich protein 3|LIM domain only 4|cardiac LIM domain protein|cysteine and glycine-rich protein 3 (cardiac LIM protein)', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=19182030, end_position_on_the_genomic_accession=19201983, orientation='minus', exon_count=6, OMIM=[600824], no_hdr0=''),
    8050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8050, CurrentID=0, Status='live', Symbol='PDHX', Aliases=['DLDBP', 'E3BP', 'OPDXD', 'PDX1', 'proX', 'PDHX'], description='pyruvate dehydrogenase complex component X', other_designations='pyruvate dehydrogenase protein X component, mitochondrial|dihydrolipoamide dehydrogenase-binding protein of pyruvate dehydrogenase complex|lipoyl-containing pyruvate dehydrogenase complex component X|pyruvate dehydrogenase complex, E3-binding protein subunit|pyruvate dehydrogenase complex, lipoyl-containing component X', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34915829, end_position_on_the_genomic_accession=34996128, orientation='plus', exon_count=13, OMIM=[608769], no_hdr0=''),
    8061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8061, CurrentID=0, Status='live', Symbol='FOSL1', Aliases=['FRA', 'FRA1', 'fra-1'], description='FOS like 1, AP-1 transcription factor subunit', other_designations='fos-related antigen 1|FOS like 1, AP-1 trancription factor subunit|FOS-like antigen-1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65892049, end_position_on_the_genomic_accession=65900545, orientation='minus', exon_count=5, OMIM=[136515], no_hdr0=''),
    8065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8065, CurrentID=0, Status='live', Symbol='CUL5', Aliases=['CUL-5', 'VACM-1', 'VACM1'], description='cullin 5', other_designations='cullin-5|Cullin-5 (vasopressin-activated calcium-mobilizing receptor-1)|Vasopressin-activated calcium-mobilizing receptor-1|vasopressin-activated calcium-mobilizing receptor 1', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108008733, end_position_on_the_genomic_accession=108107766, orientation='plus', exon_count=22, OMIM=[601741], no_hdr0=''),
    8073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8073, CurrentID=0, Status='live', Symbol='PTP4A2', Aliases=['HH13', 'HH7-2', 'HU-PP-1', 'OV-1', 'PRL-2', 'PRL2', 'PTP4A', 'PTPCAAX2', 'ptp-IV1a', 'ptp-IV1b'], description='protein tyrosine phosphatase 4A2', other_designations='protein tyrosine phosphatase type IVA 2|PTP(CAAXII)|phosphatase of regenerating liver 2|protein tyrosine phosphatase IVA|protein tyrosine phosphatase IVA2|protein tyrosine phosphatase type IVA, member 2|protein-tyrosine phosphatase of regenerating liver 2', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31906421, end_position_on_the_genomic_accession=31938368, orientation='minus', exon_count=9, OMIM=[601584], no_hdr0=''),
    8074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8074, CurrentID=0, Status='live', Symbol='FGF23', Aliases=['ADHR', 'FGFN', 'HFTC2', 'HPDR2', 'HYPF', 'PHPTC'], description='fibroblast growth factor 23', other_designations='fibroblast growth factor 23|phosphatonin|tumor-derived hypophosphatemia inducing factor', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4368227, end_position_on_the_genomic_accession=4379712, orientation='minus', exon_count=3, OMIM=[605380], no_hdr0=''),
    8076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8076, CurrentID=0, Status='live', Symbol='MFAP5', Aliases=['AAT9', 'MAGP-2', 'MAGP2', 'MFAP-5', 'MP25'], description='microfibril associated protein 5', other_designations='microfibrillar-associated protein 5|THE1A-MFAP5|microfibril-associated glycoprotein-2|microfibrillar associated protein 5', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8645943, end_position_on_the_genomic_accession=8662826, orientation='minus', exon_count=11, OMIM=[601103], no_hdr0=''),
    8078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8078, CurrentID=0, Status='live', Symbol='USP5', Aliases=['ISOT'], description='ubiquitin specific peptidase 5', other_designations='ubiquitin carboxyl-terminal hydrolase 5|deubiquitinating enzyme 5|isopeptidase T|testicular tissue protein Li 218|ubiquitin isopeptidase T|ubiquitin specific protease 5 (isopeptidase T)|ubiquitin thioesterase 5|ubiquitin thiolesterase 5|ubiquitin-specific protease-5 (ubiquitin isopeptidase T)|ubiquitin-specific-processing protease 5', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6852150, end_position_on_the_genomic_accession=6866632, orientation='plus', exon_count=20, OMIM=[601447], no_hdr0=''),
    8079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8079, CurrentID=0, Status='live', Symbol='MLF2', Aliases=['NTN4'], description='myeloid leukemia factor 2', other_designations='myeloid leukemia factor 2|myelodysplasia-myeloid leukemia factor 2', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6747996, end_position_on_the_genomic_accession=6753141, orientation='minus', exon_count=9, OMIM=[601401], no_hdr0=''),
    8082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8082, CurrentID=0, Status='live', Symbol='SSPN', Aliases=['DAGA5', 'KRAG', 'NSPN', 'SPN1', 'SPN2'], description='sarcospan', other_designations='sarcospan|K-ras oncogene-associated protein|Kras oncogene-associated|kirsten-ras-associated protein|microspan|nanospan|sarcospan (Kras oncogene-associated gene)', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26121951, end_position_on_the_genomic_accession=26234777, orientation='plus', exon_count=7, OMIM=[601599], no_hdr0=''),
    8085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8085, CurrentID=0, Status='live', Symbol='KMT2D', Aliases=['AAD10', 'ALR', 'CAGL114', 'KABUK1', 'KMS', 'MLL2', 'MLL4', 'TNRC21'], description='lysine methyltransferase 2D', other_designations='histone-lysine N-methyltransferase 2D|ALL1-related protein|Kabuki make-up syndrome|Kabuki mental retardation syndrome|histone-lysine N-methyltransferase MLL2|lysine (K)-specific methyltransferase 2D|lysine N-methyltransferase 2D|myeloid/lymphoid or mixed-lineage leukemia 2|trinucleotide repeat containing 21|truncated lysine methyltransferase 2D', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49018975, end_position_on_the_genomic_accession=49060884, orientation='minus', exon_count=56, OMIM=[602113], no_hdr0=''),
    8086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8086, CurrentID=0, Status='live', Symbol='AAAS', Aliases=['AAAb', 'ADRACALA', 'ADRACALIN', 'ALADIN', 'GL003', 'AAAS'], description='aladin WD repeat nucleoporin', other_designations='aladin|Allgrove, triple-A|achalasia, adrenocortical insufficiency, alacrimia', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53307456, end_position_on_the_genomic_accession=53321610, orientation='minus', exon_count=16, OMIM=[605378], no_hdr0=''),
    8087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8087, CurrentID=0, Status='live', Symbol='FXR1', Aliases=['FXR1P', 'MYOPMIL', 'MYORIBF'], description='FMR1 autosomal homolog 1', other_designations='fragile X mental retardation syndrome-related protein 1|fragile X mental retardation, autosomal homolog 1', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=180912670, end_position_on_the_genomic_accession=180982753, orientation='plus', exon_count=19, OMIM=[600819], no_hdr0=''),
    8089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8089, CurrentID=0, Status='live', Symbol='YEATS4', Aliases=['4930573H17Rik', 'B230215M10Rik', 'GAS41', 'NUBI-1', 'YAF9'], description='YEATS domain containing 4', other_designations='YEATS domain-containing protein 4|NuMA binding protein 1|glioma-amplified sequence 41|nuBI1', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69359705, end_position_on_the_genomic_accession=69427077, orientation='plus', exon_count=11, OMIM=[602116], no_hdr0=''),
    8091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8091, CurrentID=0, Status='live', Symbol='HMGA2', Aliases=['BABL', 'HMGI-C', 'HMGIC', 'LIPO', 'SRS5', 'STQTL9'], description='high mobility group AT-hook 2', other_designations='high mobility group protein HMGI-C|HMGA2/KRT121P fusion', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=65824460, end_position_on_the_genomic_accession=65966291, orientation='plus', exon_count=8, OMIM=[600698], no_hdr0=''),
    8092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8092, CurrentID=0, Status='live', Symbol='ALX1', Aliases=['CART1', 'FND3', 'HEL23'], description='ALX homeobox 1', other_designations='ALX homeobox protein 1|CART-1|cartilage paired-class homeoprotein 1|epididymis luminal protein 23', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85280220, end_position_on_the_genomic_accession=85301784, orientation='plus', exon_count=5, OMIM=[601527], no_hdr0=''),
    8099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8099, CurrentID=0, Status='live', Symbol='CDK2AP1', Aliases=['DOC1', 'DORC1', 'ST19', 'doc-1', 'p12DOC-1'], description='cyclin dependent kinase 2 associated protein 1', other_designations='cyclin-dependent kinase 2-associated protein 1|CDK2-associated protein 1|Deleted in oral cancer-1|deleted in oral cancer 1|putative oral cancer suppressor', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123260976, end_position_on_the_genomic_accession=123272240, orientation='minus', exon_count=8, OMIM=[602198], no_hdr0=''),
    8100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8100, CurrentID=0, Status='live', Symbol='IFT88', Aliases=['D13S1056E', 'DAF19', 'TG737', 'TTC10', 'hTg737'], description='intraflagellar transport 88', other_designations='intraflagellar transport protein 88 homolog|TPR repeat protein 10|intraflagellar transport 88 homolog|polaris homolog|probe hTg737 (polycystic kidney disease, autosomal recessive)|recessive polycystic kidney disease protein Tg737 homolog|testicular tissue protein Li 93|tetratricopeptide repeat domain 10|tetratricopeptide repeat protein 10', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20566446, end_position_on_the_genomic_accession=20691444, orientation='plus', exon_count=34, OMIM=[600595], no_hdr0=''),
    8106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8106, CurrentID=0, Status='live', Symbol='PABPN1', Aliases=['OPMD', 'PAB2', 'PABII', 'PABP-2', 'PABP2'], description='poly(A) binding protein nuclear 1', other_designations='polyadenylate-binding protein 2|poly(A) binding protein 2|poly(A) binding protein II', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23321457, end_position_on_the_genomic_accession=23326163, orientation='plus', exon_count=6, OMIM=[602279], no_hdr0=''),
    8110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8110, CurrentID=0, Status='live', Symbol='DPF3', Aliases=['BAF45C', 'CERD4'], description='double PHD fingers 3', other_designations='zinc finger protein DPF3|BRG1-associated factor 45C|D4, zinc and double PHD fingers, family 3|zinc finger protein cer-d4', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=72609034, end_position_on_the_genomic_accession=72894101, orientation='minus', exon_count=15, OMIM=[601672], no_hdr0=''),
    8111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8111, CurrentID=0, Status='live', Symbol='GPR68', Aliases=['AI2A6', 'GPR12A', 'OGR1'], description='G protein-coupled receptor 68', other_designations='ovarian cancer G-protein coupled receptor 1|ovarian cancer G protein-coupled receptor, 1|sphingosylphosphorylcholine receptor', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91232532, end_position_on_the_genomic_accession=91264581, orientation='minus', exon_count=10, OMIM=[601404], no_hdr0=''),
    8115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8115, CurrentID=0, Status='live', Symbol='TCL1A', Aliases=['TCL1'], description='TCL1 family AKT coactivator A', other_designations='T-cell leukemia/lymphoma protein 1A|T cell leukemia/lymphoma 1A|T-cell lymphoma-1|oncogene TCL-1|oncogene TCL1|protein p14 TCL1', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95694160, end_position_on_the_genomic_accession=95714155, orientation='minus', exon_count=6, OMIM=[186960], no_hdr0=''),
    8120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8120, CurrentID=0, Status='live', Symbol='AP3B2', Aliases=['DEE48', 'EIEE48', 'NAPTB'], description='adaptor related protein complex 3 subunit beta 2', other_designations='AP-3 complex subunit beta-2|Neuronal adaptin-like protein, beta-subunit|adaptor protein complex AP-3 subunit beta-2|adaptor related protein complex 3 beta 2 subunit|beta-3B-adaptin|clathrin assembly protein complex 3 beta-2 large chain|neuron-specific vesicle coat protein beta-NAP', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82659281, end_position_on_the_genomic_accession=82709875, orientation='minus', exon_count=28, OMIM=[602166], no_hdr0=''),
    8125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8125, CurrentID=0, Status='live', Symbol='ANP32A', Aliases=['C15orf1', 'HPPCn', 'I1PP2A', 'LANP', 'MAPM', 'PHAP1', 'PHAPI', 'PP32'], description='acidic nuclear phosphoprotein 32 family member A', other_designations='acidic leucine-rich nuclear phosphoprotein 32 family member A|acidic (leucine-rich) nuclear phosphoprotein 32 family, member A|acidic nuclear phosphoprotein pp32|cerebellar leucine rich acidic nuclear protein|epididymis secretory sperm binding protein|hepatopoietin Cn|inhibitor-1 of protein phosphatase-2A|leucine-rich acidic nuclear protein|mapmodulin|potent heat-stable protein phosphatase 2A inhibitor I1PP2A|putative HLA-DR-associated protein I|putative human HLA class II associated protein I', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68778535, end_position_on_the_genomic_accession=68820895, orientation='minus', exon_count=7, OMIM=[600832], no_hdr0=''),
    8128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8128, CurrentID=0, Status='live', Symbol='ST8SIA2', Aliases=['HsT19690', 'SIAT8-B', 'SIAT8B', 'ST8SIA-II', 'ST8SiaII', 'STX'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 2', other_designations='alpha-2,8-sialyltransferase 8B|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 2|alpha-2,8-sialyltransferase 8B 1|sialyltransferase 8 (alpha-2, 8-sialytransferase) B|sialyltransferase 8B|sialyltransferase St8Sia II|sialyltransferase X', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=92393881, end_position_on_the_genomic_accession=92468728, orientation='plus', exon_count=7, OMIM=[602546], no_hdr0=''),
    8131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8131, CurrentID=0, Status='live', Symbol='NPRL3', Aliases=['C16orf35', 'CGTHBA', 'FFEVF3', 'HS-40', 'MARE', 'NPR3', 'RMD11'], description='NPR3 like, GATOR1 complex subunit', other_designations='GATOR complex protein NPRL3|-14 gene protein|alpha-globin regulatory element-containing gene protein|conserved gene telomeric to alpha globin cluster', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85386, end_position_on_the_genomic_accession=138673, orientation='minus', exon_count=15, OMIM=[600928], no_hdr0=''),
    8139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8139, CurrentID=0, Status='live', Symbol='GAN', Aliases=['GAN1', 'GIG', 'KLHL16'], description='gigaxonin', other_designations='gigaxonin|epididymis secretory sperm binding protein|kelch-like family member 16|kelch-like protein 16', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81314962, end_position_on_the_genomic_accession=81390809, orientation='plus', exon_count=11, OMIM=[605379], no_hdr0=''),
    8140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8140, CurrentID=0, Status='live', Symbol='SLC7A5', Aliases=['4F2LC', 'CD98', 'D16S469E', 'E16', 'LAT1', 'MPE16'], description='solute carrier family 7 member 5', other_designations='large neutral amino acids transporter small subunit 1|4F2 light chain|CD98 light chain|L-type amino acid transporter 1|integral membrane protein E16|sodium-independent neutral amino acid transporter LAT1|solute carrier family 7 (amino acid transporter light chain, L system), member 5|solute carrier family 7 (cationic amino acid transporter, y+ system), member 5', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87830022, end_position_on_the_genomic_accession=87869507, orientation='minus', exon_count=11, OMIM=[600182], no_hdr0=''),
    8148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8148, CurrentID=0, Status='live', Symbol='TAF15', Aliases=['Npl3', 'RBP56', 'TAF2N', 'TAFII68'], description='TATA-box binding protein associated factor 15', other_designations='TATA-binding protein-associated factor 2N|RBP56/CSMF fusion|TAF15 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 68kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase II, N, 68kD (RNA-binding protein 56)|TATA box-binding protein-associated factor 2N (RNA-binding protein 56)|TBP-associated factor 15', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35809484, end_position_on_the_genomic_accession=35847242, orientation='plus', exon_count=16, OMIM=[601574], no_hdr0=''),
    8153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8153, CurrentID=0, Status='live', Symbol='RND2', Aliases=['ARHN', 'RHO7', 'RhoN'], description='Rho family GTPase 2', other_designations='rho-related GTP-binding protein RhoN|CTD-3199J23.4|GTP-binding protein Rho7|ras homolog gene family, member N|rho-related GTP-binding protein Rho7', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43025231, end_position_on_the_genomic_accession=43032041, orientation='plus', exon_count=7, OMIM=[601555], no_hdr0=''),
    8161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8161, CurrentID=0, Status='live', Symbol='COIL', Aliases=['CLN80', 'p80-coilin'], description='coilin', other_designations='coilin|coilin p80|p80', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56938199, end_position_on_the_genomic_accession=56961050, orientation='minus', exon_count=7, OMIM=[600272], no_hdr0=''),
    8165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8165, CurrentID=0, Status='live', Symbol='AKAP1', Aliases=['AKAP21', 'AKAP149', 'AKAP84', 'D-AKAP1', 'PPP1R43', 'PRKA1', 'SAKAP84', 'TDRD17', 'AKAP1'], description='A-kinase anchoring protein 1', other_designations='A-kinase anchor protein 1, mitochondrial|A kinase (PRKA) anchor protein 1|A-kinase anchor protein 149 kDa|AKAP 149|D-AKAP-1|dual-specificity A-kinase anchoring protein 1|protein kinase A anchoring protein 1|protein kinase A1|protein phosphatase 1, regulatory subunit 43|spermatid A-kinase anchor protein 84|testicular secretory protein Li 5|tudor domain containing 17', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57085246, end_position_on_the_genomic_accession=57121344, orientation='plus', exon_count=16, OMIM=[602449], no_hdr0=''),
    8170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8170, CurrentID=0, Status='live', Symbol='SLC14A2', Aliases=['HUT2', 'UT-A2', 'UT2', 'UTA', 'UTR', 'hUT-A6'], description='solute carrier family 14 member 2', other_designations='urea transporter 2|solute carrier family 14 (urea transporter), member 2|urea transporter, kidney', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=45167963, end_position_on_the_genomic_accession=45683688, orientation='plus', exon_count=27, OMIM=[601611], no_hdr0=''),
    8174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8174, CurrentID=0, Status='live', Symbol='MADCAM1', Aliases=['MACAM1'], description='mucosal vascular addressin cell adhesion molecule 1', other_designations='mucosal addressin cell adhesion molecule 1|MAdCAM-1|hMAdCAM-1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=496486, end_position_on_the_genomic_accession=505343, orientation='plus', exon_count=5, OMIM=[102670], no_hdr0=''),
    8175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8175, CurrentID=0, Status='live', Symbol='SF3A2', Aliases=['PRP11', 'PRPF11', 'SAP62', 'SF3a66'], description='splicing factor 3a subunit 2', other_designations='splicing factor 3A subunit 2|SAP 62|pre-mRNA splicing factor SF3A, subunit 2|spliceosome associated protein 62|splicing factor 3a, subunit 2, 66kD|splicing factor 3a, subunit 2, 66kDa', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2236824, end_position_on_the_genomic_accession=2248655, orientation='plus', exon_count=9, OMIM=[600796], no_hdr0=''),
    8178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8178, CurrentID=0, Status='live', Symbol='ELL', Aliases=['C19orf171', 'MEN', 'PPP1R68', 'ELL'], description='elongation factor for RNA polymerase II', other_designations='RNA polymerase II elongation factor ELL|ELL gene (11-19 lysine-rich leukemia gene)|ELL/KMT2A fusion protein|KMT2A/ELL fusion protein|eleven-nineteen lysine-rich leukemia protein|elongation factor RNA polymerase II|protein phosphatase 1, regulatory subunit 68', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18442663, end_position_on_the_genomic_accession=18522070, orientation='minus', exon_count=16, OMIM=[600284], no_hdr0=''),
    8187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8187, CurrentID=0, Status='live', Symbol='ZNF239', Aliases=['HOK-2', 'MOK2'], description='zinc finger protein 239', other_designations='zinc finger protein 239|zinc finger protein (C2H2) homologous to mouse MOK-2|zinc finger protein HOK-2|zinc finger protein MOK-2', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43554516, end_position_on_the_genomic_accession=43574619, orientation='minus', exon_count=9, OMIM=[601069], no_hdr0=''),
    8189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8189, CurrentID=0, Status='live', Symbol='SYMPK', Aliases=['Pta1', 'SPK', 'SYM'], description='symplekin', other_designations='symplekin', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45815410, end_position_on_the_genomic_accession=45863167, orientation='minus', exon_count=28, OMIM=[602388], no_hdr0=''),
    8190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8190, CurrentID=0, Status='live', Symbol='MIA', Aliases=['CD-RAP'], description='MIA SH3 domain containing', other_designations='melanoma-derived growth regulatory protein|melanoma inhibitory activity', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40775160, end_position_on_the_genomic_accession=40777490, orientation='plus', exon_count=5, OMIM=[601340], no_hdr0=''),
    8192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8192, CurrentID=0, Status='live', Symbol='CLPP', Aliases=['DFNB81', 'PRLTS3'], description='caseinolytic mitochondrial matrix peptidase proteolytic subunit', other_designations='ATP-dependent Clp protease proteolytic subunit, mitochondrial|ATP-dependent protease ClpAP, proteolytic subunit, human|ClpP caseinolytic peptidase ATP-dependent, proteolytic subunit|ClpP caseinolytic peptidase, ATP-dependent, proteolytic subunit homolog|ClpP caseinolytic protease, ATP-dependent, proteolytic subunit homolog|endopeptidase Clp|putative ATP-dependent Clp protease proteolytic subunit, mitochondrial', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6361531, end_position_on_the_genomic_accession=6370242, orientation='plus', exon_count=6, OMIM=[601119], no_hdr0=''),
    8193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8193, CurrentID=0, Status='live', Symbol='DPF1', Aliases=['BAF45b', 'NEUD4', 'neuro-d4'], description='double PHD fingers 1', other_designations='zinc finger protein neuro-d4|BRG1-associated factor 45B|D4, zinc and double PHD fingers family 1|neuro-d4 homolog', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38211006, end_position_on_the_genomic_accession=38229695, orientation='minus', exon_count=14, OMIM=[601670], no_hdr0=''),
    8195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8195, CurrentID=0, Status='live', Symbol='MKKS', Aliases=['BBS6', 'HMCS', 'KMS', 'MKS'], description='MKKS centrosomal shuttling protein', other_designations='McKusick-Kaufman/Bardet-Biedl syndromes putative chaperonin|Bardet-Biedl syndrome 6 protein', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=10401009, end_position_on_the_genomic_accession=10434222, orientation='minus', exon_count=7, OMIM=[604896], no_hdr0=''),
    8200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8200, CurrentID=0, Status='live', Symbol='GDF5', Aliases=['BDA1C', 'BMP-14', 'BMP14', 'CDMP1', 'DUPANS', 'LAP-4', 'LAP4', 'OS5', 'SYM1B', 'SYNS2'], description='growth differentiation factor 5', other_designations='growth/differentiation factor 5|LPS-associated protein 4|bone morphogenetic protein 14|cartilage-derived morphogenetic protein-1|lipopolysaccharide-associated protein 4|radotermin', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35433347, end_position_on_the_genomic_accession=35454749, orientation='minus', exon_count=4, OMIM=[601146], no_hdr0=''),
    8202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8202, CurrentID=0, Status='live', Symbol='NCOA3', Aliases=['ACTR', 'AIB-1', 'AIB1', 'CAGH16', 'CTG26', 'KAT13B', 'RAC3', 'SRC-3', 'SRC3', 'TNRC14', 'TNRC16', 'TRAM-1', 'bHLHe42', 'pCIP'], description='nuclear receptor coactivator 3', other_designations='nuclear receptor coactivator 3|CBP-interacting protein|amplified in breast cancer 1 protein|class E basic helix-loop-helix protein 42|receptor-associated coactivator 3|steroid receptor coactivator protein 3|thyroid hormone receptor activator molecule 1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=47501887, end_position_on_the_genomic_accession=47656872, orientation='plus', exon_count=23, OMIM=[601937], no_hdr0=''),
    8204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8204, CurrentID=0, Status='live', Symbol='NRIP1', Aliases=['CAKUT3', 'RIP140'], description='nuclear receptor interacting protein 1', other_designations='nuclear receptor-interacting protein 1|nuclear factor RIP140|receptor-interacting protein 140', map_location='21q11.2-q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14961235, end_position_on_the_genomic_accession=15065903, orientation='minus', exon_count=10, OMIM=[602490], no_hdr0=''),
    8208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8208, CurrentID=0, Status='live', Symbol='CHAF1B', Aliases=['CAF-1', 'CAF-IP60', 'CAF1', 'CAF1A', 'CAF1P60', 'MPHOSPH7', 'MPP7'], description='chromatin assembly factor 1 subunit B', other_designations='chromatin assembly factor 1 subunit B|CAF-1 subunit B|CAF-I 60 kDa subunit|CAF-I p60|M-phase phosphoprotein 7|chromatin assembly factor I p60 subunit|human chromatin assembly factor-I p60 subunit', map_location='21q22.12-q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36380145, end_position_on_the_genomic_accession=36419015, orientation='plus', exon_count=17, OMIM=[601245], no_hdr0=''),
    8209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8209, CurrentID=0, Status='live', Symbol='GATD3', Aliases=['C21orf33', 'ES1A', 'GT335', 'HES1', 'KNPH', 'KNPI', 'GATD3'], description='glutamine amidotransferase class 1 domain containing 3', other_designations='glutamine amidotransferase-like class 1 domain-containing protein 3A, mitochondrial|ES1 protein homolog, mitochondrial|Keio novel protein I|glutamine amidotransferase class 1 domain containing 3A|glutamine amidotransferase like class 1 domain containing 3A|human HES1 protein, homolog to E.coli and zebrafish ES1 protein|testis secretory sperm-binding protein Li 237E', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44133665, end_position_on_the_genomic_accession=44145711, orientation='plus', exon_count=9, OMIM=[601659], no_hdr0=''),
    8214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8214, CurrentID=0, Status='live', Symbol='DGCR6', Aliases=[], description='DiGeorge syndrome critical region gene 6', other_designations='protein DGCR6|DiGeorge syndrome critical region protein 6', map_location='22q11', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18906320, end_position_on_the_genomic_accession=18912088, orientation='plus', exon_count=6, OMIM=[601279], no_hdr0=''),
    8216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8216, CurrentID=0, Status='live', Symbol='LZTR1', Aliases=['BTBD29', 'LZTR-1', 'NS10', 'NS2', 'SWNTS2'], description='leucine zipper like transcription regulator 1', other_designations='leucine-zipper-like transcriptional regulator 1|epididymis secretory sperm binding protein', map_location='22q11.1-q11.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20982297, end_position_on_the_genomic_accession=20999032, orientation='plus', exon_count=21, OMIM=[600574], no_hdr0=''),
    8218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8218, CurrentID=0, Status='live', Symbol='CLTCL1', Aliases=['CHC22', 'CLH22', 'CLTCL', 'CLTD'], description='clathrin heavy chain like 1', other_designations='clathrin heavy chain 2|CLH-22|Clathrin, heavy polypeptide D|clathrin heavy chain on chromosome 22|clathrin, heavy polypeptide-like 1', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19179473, end_position_on_the_genomic_accession=19291719, orientation='minus', exon_count=34, OMIM=[601273], no_hdr0=''),
    8220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8220, CurrentID=0, Status='live', Symbol='ESS2', Aliases=['DGCR13', 'DGCR14', 'DGS-H', 'DGS-I', 'DGSH', 'DGSI', 'ES2', 'ESS-2', 'Es2el', 'bis1'], description='ess-2 splicing factor homolog', other_designations='splicing factor ESS-2 homolog|DiGeorge syndrome critical region gene 13|DiGeorge syndrome critical region gene 14|DiGeorge syndrome critical region gene DGSI|DiGeorge syndrome gene H|DiGeorge syndrome gene I|Protein DGCR13|diGeorge syndrome protein H|protein DGCR14', map_location='22q11.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19130279, end_position_on_the_genomic_accession=19144726, orientation='minus', exon_count=11, OMIM=[601755], no_hdr0=''),
    8224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8224, CurrentID=0, Status='live', Symbol='SYN3', Aliases=[], description='synapsin III', other_designations='synapsin-3|cN28H9.2 (synapsin III)', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32507820, end_position_on_the_genomic_accession=33058381, orientation='minus', exon_count=20, OMIM=[602705], no_hdr0=''),
    8225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8225, CurrentID=0, Status='live', Symbol='GTPBP6', Aliases=['PGPL'], description='GTP binding protein 6 (putative)', other_designations='putative GTP-binding protein 6', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=303352, end_position_on_the_genomic_accession=318819, orientation='minus', exon_count=12, OMIM=[300124], no_hdr0=''),
    8226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8226, CurrentID=0, Status='live', Symbol='PUDP', Aliases=['DXF68S1E', 'FAM16AX', 'GS1', 'HDHD1', 'HDHD1A'], description="pseudouridine 5'-phosphatase", other_designations="pseudouridine-5'-phosphatase|5'-PsiMPase|family with sequence similarity 16, member A, X-linked|haloacid dehalogenase-like hydrolase domain containing 1|haloacid dehalogenase-like hydrolase domain containing 1A|haloacid dehalogenase-like hydrolase domain-containing protein 1|haloacid dehalogenase-like hydrolase domain-containing protein 1A|pseudouridine-5'-monophosphatase", map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=6768840, end_position_on_the_genomic_accession=7148153, orientation='minus', exon_count=9, OMIM=[306480], no_hdr0=''),
    8227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8227, CurrentID=0, Status='live', Symbol='AKAP17A', Aliases=['721P', 'AKAP-17A', 'CCDC133', 'CXYorf3', 'DXYS155E', 'PRKA17A', 'SFRS17A', 'XE7', 'XE7Y'], description='A-kinase anchoring protein 17A', other_designations='A-kinase anchor protein 17A|A kinase (PRKA) anchor protein 17A|B-lymphocyte surface antigen|protein kinase A-anchoring protein 17A|pseudoautosomal gene XE7|splicing factor, arginine/serine-rich 17A', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1591604, end_position_on_the_genomic_accession=1602520, orientation='plus', exon_count=6, OMIM=[312095, 465000], no_hdr0=''),
    8228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8228, CurrentID=0, Status='live', Symbol='PNPLA4', Aliases=['DXS1283E', 'GS2', 'iPLA2eta'], description='patatin like phospholipase domain containing 4', other_designations='patatin-like phospholipase domain-containing protein 4|IPLA2 eta|calcium independent phospholipases A2 eta', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=7898247, end_position_on_the_genomic_accession=7928587, orientation='minus', exon_count=8, OMIM=[300102], no_hdr0=''),
    8233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8233, CurrentID=0, Status='live', Symbol='ZRSR2', Aliases=['U2AF1-RS2', 'U2AF1L2', 'U2AF1RS2', 'URP', 'ZC3H22'], description='zinc finger CCCH-type, RNA binding motif and serine/arginine rich 2', other_designations='U2 small nuclear ribonucleoprotein auxiliary factor 35 kDa subunit-related protein 2|U2 small nuclear ribonucleoprotein auxiliary factor, small subunit 2|U2(RNU2) small nuclear RNA auxiliary factor 1-like 2|U2AF35-related protein|renal carcinoma antigen NY-REN-20|zinc finger (CCCH type), RNA binding motif and serine/arginine rich 2', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15790472, end_position_on_the_genomic_accession=15826807, orientation='plus', exon_count=14, OMIM=[300028], no_hdr0=''),
    8237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8237, CurrentID=0, Status='live', Symbol='USP11', Aliases=['UHX1'], description='ubiquitin specific peptidase 11', other_designations='ubiquitin carboxyl-terminal hydrolase 11|deubiquitinating enzyme 11|ubiquitin carboxyl-terminal hydrolase, X-linked|ubiquitin thioesterase 11|ubiquitin thiolesterase 11|ubiquitin-specific processing protease 11', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47233009, end_position_on_the_genomic_accession=47248328, orientation='plus', exon_count=21, OMIM=[300050], no_hdr0=''),
    8239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8239, CurrentID=0, Status='live', Symbol='USP9X', Aliases=['DFFRX', 'FAF', 'FAM', 'MRX99', 'MRXS99F'], description='ubiquitin specific peptidase 9 X-linked', other_designations='probable ubiquitin carboxyl-terminal hydrolase FAF-X|Drosophila fat facets related, X-linked|deubiquitinating enzyme FAF-X|fat facets in mammals|fat facets protein related, X-linked|hFAM|ubiquitin specific protease 9, X chromosome (fat facets-like Drosophila)|ubiquitin thioesterase FAF-X|ubiquitin thiolesterase FAF-X|ubiquitin-specific processing protease FAF-X|ubiquitin-specific protease 9, X chromosome', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41085420, end_position_on_the_genomic_accession=41236579, orientation='plus', exon_count=45, OMIM=[300072], no_hdr0=''),
    8241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8241, CurrentID=0, Status='live', Symbol='RBM10', Aliases=['DXS8237E', 'GPATC9', 'GPATCH9', 'S1-1', 'TARPS', 'ZRANB5'], description='RNA binding motif protein 10', other_designations='RNA-binding protein 10|RNA-binding protein S1-1|epididymis secretory sperm binding protein|g patch domain-containing protein 9', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47145196, end_position_on_the_genomic_accession=47186813, orientation='plus', exon_count=25, OMIM=[300080], no_hdr0=''),
    8242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8242, CurrentID=0, Status='live', Symbol='KDM5C', Aliases=['DXS1272E', 'JARID1C', 'MRX13', 'MRXJ', 'MRXSCJ', 'MRXSJ', 'SMCX', 'XE169'], description='lysine demethylase 5C', other_designations='lysine-specific demethylase 5C|JmjC domain-containing protein SMCX|Jumonji, AT rich interactive domain 1C (RBP2-like)|Jumonji/ARID domain-containing protein 1C|Smcx homolog, X chromosome|Smcy homolog, X-linked|[histone H3]-trimethyl-L-lysine(4) demethylase 5C|histone demethylase JARID1C|lysine (K)-specific demethylase 5C', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53176277, end_position_on_the_genomic_accession=53225207, orientation='minus', exon_count=29, OMIM=[314690], no_hdr0=''),
    8243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8243, CurrentID=0, Status='live', Symbol='SMC1A', Aliases=['CDLS2', 'DEE85', 'DXS423E', 'EIEE85', 'SB1.8', 'SMC1', 'SMC1L1', 'SMC1alpha', 'SMCB'], description='structural maintenance of chromosomes 1A', other_designations='structural maintenance of chromosomes protein 1A|SMC protein 1A|SMC-1-alpha|SMC1 (structural maintenance of chromosomes 1, yeast)-like 1|epididymis secretory sperm binding protein|segregation of mitotic chromosomes 1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53374149, end_position_on_the_genomic_accession=53422728, orientation='minus', exon_count=26, OMIM=[300040], no_hdr0=''),
    8260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8260, CurrentID=0, Status='live', Symbol='NAA10', Aliases=['ARD1', 'ARD1A', 'ARD1P', 'DXS707', 'MCOPS1', 'NATD', 'OGDNS', 'TE2', 'hARD1'], description='N-alpha-acetyltransferase 10, NatA catalytic subunit', other_designations='N-alpha-acetyltransferase 10|ARD1 homolog A, N-acetyltransferase|N-acetyltransferase ARD1, human homolog of|N-terminal acetyltransferase complex ARD1 subunit homolog A|arrest defective protein 1|natA catalytic subunit Naa10', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153929225, end_position_on_the_genomic_accession=153935037, orientation='minus', exon_count=8, OMIM=[300013], no_hdr0=''),
    8263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8263, CurrentID=0, Status='live', Symbol='F8A1', Aliases=['DXS522E', 'F8A', 'HAP40'], description='coagulation factor VIII associated 1', other_designations='40-kDa huntingtin-associated protein|coagulation factor VIII-associated (intronic transcript) 1|cpG island protein|factor VIII associated protein|factor VIII intron 22 protein|huntingtin-associated protein 40', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154886355, end_position_on_the_genomic_accession=154888061, orientation='plus', exon_count=1, OMIM=[305423], no_hdr0=''),
    8266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8266, CurrentID=0, Status='live', Symbol='UBL4A', Aliases=['DX254E', 'DXS254E', 'G6PD', 'GDX', 'GET5', 'MDY2', 'TMA24', 'UBL4'], description='ubiquitin like 4A', other_designations='ubiquitin-like protein 4A|ubiquitin-like 4|ubiquitin-like protein GDX', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154483717, end_position_on_the_genomic_accession=154486615, orientation='minus', exon_count=4, OMIM=[312070], no_hdr0=''),
    8269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8269, CurrentID=0, Status='live', Symbol='TMEM187', Aliases=['CXorf12', 'DXS9878E', 'ITBA1'], description='transmembrane protein 187', other_designations='transmembrane protein 187', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153972754, end_position_on_the_genomic_accession=153983194, orientation='plus', exon_count=3, OMIM=[300059], no_hdr0=''),
    8270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8270, CurrentID=0, Status='live', Symbol='LAGE3', Aliases=['CVG5', 'DXS9879E', 'DXS9951E', 'ESO3', 'GAMOS2', 'ITBA2', 'Pcc1'], description='L antigen family member 3', other_designations='EKC/KEOPS complex subunit LAGE3|protein ESO-3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154477775, end_position_on_the_genomic_accession=154479281, orientation='minus', exon_count=3, OMIM=[300060], no_hdr0=''),
    8273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8273, CurrentID=0, Status='live', Symbol='SLC10A3', Aliases=['DXS253E', 'P3'], description='solute carrier family 10 member 3', other_designations='P3 protein|Protein P3|solute carrier family 10 (sodium/bile acid cotransporter family), member 3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154487310, end_position_on_the_genomic_accession=154490656, orientation='minus', exon_count=5, OMIM=[312090], no_hdr0=''),
    8277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8277, CurrentID=0, Status='live', Symbol='TKTL1', Aliases=['TKR', 'TKT2'], description='transketolase like 1', other_designations='transketolase-like protein 1|TK 2|transketolase-2|transketolase-related protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154295795, end_position_on_the_genomic_accession=154330350, orientation='plus', exon_count=13, OMIM=[300044], no_hdr0=''),
    8284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8284, CurrentID=0, Status='live', Symbol='KDM5D', Aliases=['HY', 'HYA', 'JARID1D', 'SMCY'], description='lysine demethylase 5D', other_designations='lysine-specific demethylase 5D|H-Y|Jumonji, AT rich interactive domain 1D (RBP2-like)|SMC homolog, Y chromosome|Smcy homolog, Y-linked|[histone H3]-trimethyl-L-lysine(4) demethylase 5D|epididymis secretory sperm binding protein|histocompatibility Y antigen|histone demethylase JARID1D|jumonji/ARID domain-containing protein 1D|lysine (K)-specific demethylase 5D|protein SmcY|selected mouse cDNA on Y, human homolog of', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=19703865, end_position_on_the_genomic_accession=19745341, orientation='minus', exon_count=28, OMIM=[426000], no_hdr0=''),
    8287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8287, CurrentID=0, Status='live', Symbol='USP9Y', Aliases=['DFFRY', 'SPGFY2'], description='ubiquitin specific peptidase 9 Y-linked', other_designations='probable ubiquitin carboxyl-terminal hydrolase FAF-Y|azoospermia factor A|deubiquitinating enzyme FAF-Y|fat facets protein-related, Y-linked|ubiquitin specific peptidase 9, Y-linked (fat facets-like, Drosophila)|ubiquitin thioesterase FAF-Y|ubiquitin thiolesterase FAF-Y|ubiquitin-specific processing protease FAF-Y|ubiquitin-specific protease 9, Y chromosome', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=12701231, end_position_on_the_genomic_accession=12860839, orientation='plus', exon_count=47, OMIM=[400005], no_hdr0=''),
    8288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8288, CurrentID=0, Status='live', Symbol='EPX', Aliases=['EPO', 'EPP-PEN', 'EPXD', 'EPX'], description='eosinophil peroxidase', other_designations='eosinophil peroxidase', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58192726, end_position_on_the_genomic_accession=58205174, orientation='plus', exon_count=13, OMIM=[131399], no_hdr0=''),
    8289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8289, CurrentID=0, Status='live', Symbol='ARID1A', Aliases=['B120', 'BAF250', 'BAF250a', 'BM029', 'C1orf4', 'CSS2', 'ELD', 'MRD14', 'OSA1', 'P270', 'SMARCF1', 'hELD', 'hOSA1'], description='AT-rich interaction domain 1A', other_designations='AT-rich interactive domain-containing protein 1A|ARID domain-containing protein 1A|AT rich interactive domain 1A (SWI-like)|BRG1-associated factor 250a|OSA1 nuclear protein|SWI-like protein|SWI/SNF complex protein p270|SWI/SNF-related, matrix-associated, actin-dependent regulator of chromatin subfamily F member 1|brain protein 120|chromatin remodeling factor p250|osa homolog 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26696015, end_position_on_the_genomic_accession=26782104, orientation='plus', exon_count=20, OMIM=[603024], no_hdr0=''),
    8290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8290, CurrentID=0, Status='live', Symbol='H3-4', Aliases=['H3.4', 'H3/g', 'H3FT', 'H3t', 'HIST3H3'], description='H3.4 histone', other_designations='histone H3.1t|H3 histone family, member T|H3/t|histone 3, H3|histone H3.4|histone cluster 3 H3', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228424845, end_position_on_the_genomic_accession=228425360, orientation='minus', exon_count=1, OMIM=[602820], no_hdr0=''),
    8291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8291, CurrentID=0, Status='live', Symbol='DYSF', Aliases=['FER1L1', 'LGMD2B', 'LGMDR2', 'MMD1'], description='dysferlin', other_designations='dysferlin|dystrophy-associated fer-1-like 1|fer-1-like family member 1|fer-1-like protein 1|limb girdle muscular dystrophy 2B (autosomal recessive)', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71453154, end_position_on_the_genomic_accession=71686763, orientation='plus', exon_count=58, OMIM=[603009], no_hdr0=''),
    8292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8292, CurrentID=0, Status='live', Symbol='COLQ', Aliases=['CMS5', 'EAD'], description='collagen like tail subunit of asymmetric acetylcholinesterase', other_designations='acetylcholinesterase collagenic tail peptide|AChE Q subunit|acetylcholinesterase-associated collagen|collagen-like tail subunit (single strand of homotrimer) of asymmetric acetylcholinesterase|collagenic tail of endplate acetylcholinesterase|single strand of homotrimeric collagen-like tail subunit of asymmetric acetylcholinesterase', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15450133, end_position_on_the_genomic_accession=15521706, orientation='minus', exon_count=18, OMIM=[603033], no_hdr0=''),
    8293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8293, CurrentID=0, Status='live', Symbol='SERF1A', Aliases=['4F5', 'FAM2A', 'H4F5', 'SERF1', 'SMAM1'], description='small EDRK-rich factor 1A', other_designations='small EDRK-rich factor 1|SMA modifier 1|protein 4F5|small EDRK-rich factor 1A (telomeric)|spinal muscular atrophy-related gene H4F5', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=70900669, end_position_on_the_genomic_accession=70918530, orientation='plus', exon_count=4, OMIM=[603011], no_hdr0=''),
    8294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8294, CurrentID=0, Status='live', Symbol='H4C9', Aliases=['H4-16', 'H4/m', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4FM', 'H4M', 'HIST1H4I'], description='H4 clustered histone 9', other_designations='histone H4|H4 histone family, member M|Histone 4 family, member M|histone 1, H4i|histone cluster 1 H4 family member i|histone cluster 1, H4i|histone family member', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27139282, end_position_on_the_genomic_accession=27139678, orientation='plus', exon_count=1, OMIM=[602833], no_hdr0=''),
    8295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8295, CurrentID=0, Status='live', Symbol='TRRAP', Aliases=['DEDDFA', 'DFNA75', 'PAF350/400', 'PAF400', 'STAF40', 'TR-AP', 'Tra1'], description='transformation/transcription domain associated protein', other_designations='transformation/transcription domain-associated protein|350/400 kDa PCAF-associated factor|tra1 homolog', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98878532, end_position_on_the_genomic_accession=99013241, orientation='plus', exon_count=73, OMIM=[603015], no_hdr0=''),
    8301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8301, CurrentID=0, Status='live', Symbol='PICALM', Aliases=['CALM', 'CLTH', 'LAP'], description='phosphatidylinositol binding clathrin assembly protein', other_designations='phosphatidylinositol-binding clathrin assembly protein|clathrin assembly lymphoid myeloid leukemia protein', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85957175, end_position_on_the_genomic_accession=86069860, orientation='minus', exon_count=23, OMIM=[603025], no_hdr0=''),
    8302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8302, CurrentID=0, Status='live', Symbol='KLRC4', Aliases=['NKG2-F', 'NKG2F'], description='killer cell lectin like receptor C4', other_designations='NKG2-F type II integral membrane protein|NK cell receptor F|NKG2-F-activating NK receptor|killer cell lectin-like receptor subfamily C, member 4|natual killer cell group 2-F', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10407384, end_position_on_the_genomic_accession=10409757, orientation='minus', exon_count=4, OMIM=[602893], no_hdr0=''),
    8303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8303, CurrentID=0, Status='live', Symbol='SNN', Aliases=[], description='stannin', other_designations='stannin|AG8_1', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11668455, end_position_on_the_genomic_accession=11679154, orientation='plus', exon_count=4, OMIM=[603032], no_hdr0=''),
    8309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8309, CurrentID=0, Status='live', Symbol='ACOX2', Aliases=['BCOX', 'BRCACOX', 'BRCOX', 'CBAS6', 'THCCox'], description='acyl-CoA oxidase 2', other_designations='peroxisomal acyl-coenzyme A oxidase 2|3-alpha,7-alpha,12-alpha-trihydroxy-5-beta-cholestanoyl-CoA 24-hydroxylase|3-alpha,7-alpha,12-alpha-trihydroxy-5-beta-cholestanoyl-CoA oxidase|THCA-CoA oxidase|acyl-CoA oxidase 2, branched chain|acyl-Coenzyme A oxidase 2, branched chain|branched chain acyl-CoA oxidase|peroxisomal branched chain acyl-CoA oxidase|trihydroxycoprostanoyl-CoA oxidase', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58505136, end_position_on_the_genomic_accession=58537196, orientation='minus', exon_count=15, OMIM=[601641], no_hdr0=''),
    8310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8310, CurrentID=0, Status='live', Symbol='ACOX3', Aliases=[], description='acyl-CoA oxidase 3, pristanoyl', other_designations='peroxisomal acyl-coenzyme A oxidase 3|BRCACox|acyl-Coenzyme A oxidase 3, pristanoyl|branched-chain acyl-CoA oxidase|pristanoyl-CoA oxidase', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8366263, end_position_on_the_genomic_accession=8440723, orientation='minus', exon_count=22, OMIM=[603402], no_hdr0=''),
    8312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8312, CurrentID=0, Status='live', Symbol='AXIN1', Aliases=['AXIN', 'PPP1R49'], description='axin 1', other_designations='axin-1|axis inhibition protein 1|axis inhibitor 1|fused, mouse, homolog of|protein phosphatase 1, regulatory subunit 49', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=287440, end_position_on_the_genomic_accession=355226, orientation='minus', exon_count=18, OMIM=[603816], no_hdr0=''),
    8313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8313, CurrentID=0, Status='live', Symbol='AXIN2', Aliases=['AXIL', 'ODCRCS'], description='axin 2', other_designations='axin-2|axin-like protein|axis inhibition protein 2|conductin', map_location='17q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=65528563, end_position_on_the_genomic_accession=65561648, orientation='minus', exon_count=15, OMIM=[604025], no_hdr0=''),
    8314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8314, CurrentID=0, Status='live', Symbol='BAP1', Aliases=['HUCEP-13', 'UCHL2', 'hucep-6'], description='BRCA1 associated protein 1', other_designations='ubiquitin carboxyl-terminal hydrolase BAP1|BRCA1 associated protein-1 (ubiquitin carboxy-terminal hydrolase)|cerebral protein 6|cerebral protein-13', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52401004, end_position_on_the_genomic_accession=52410030, orientation='minus', exon_count=17, OMIM=[603089], no_hdr0=''),
    8315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8315, CurrentID=0, Status='live', Symbol='BRAP', Aliases=['BRAP2', 'IMP', 'RNF52'], description='BRCA1 associated protein', other_designations='BRCA1-associated protein|RING finger protein 52|RING-type E3 ubiquitin transferase BRAP2|galectin-2-binding protein|impedes mitogenic signal propagation|renal carcinoma antigen NY-REN-63', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111642146, end_position_on_the_genomic_accession=111686023, orientation='minus', exon_count=13, OMIM=[604986], no_hdr0=''),
    8317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8317, CurrentID=0, Status='live', Symbol='CDC7', Aliases=['CDC7L1', 'HsCDC7', 'Hsk1', 'huCDC7'], description='cell division cycle 7', other_designations='cell division cycle 7-related protein kinase|CDC7 (cell division cycle 7, S. cerevisiae, homolog)-like 1|CDC7-related kinase|cell division cycle 7 homolog|cell division cycle 7-like protein 1|epididymis secretory sperm binding protein', map_location='1p22.2-p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=91498968, end_position_on_the_genomic_accession=91525764, orientation='plus', exon_count=14, OMIM=[603311], no_hdr0=''),
    8318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8318, CurrentID=0, Status='live', Symbol='CDC45', Aliases=['CDC45LL2', 'MGORS7', 'PORC-PI-1', 'CDC45'], description='cell division cycle 45', other_designations='cell division control protein 45 homolog|CDC45 cell division cycle 45 homolog|CDC45 cell division cycle 45-like|CDC45-related protein|cell division cycle 45 homolog|cell division cycle 45-like 2|human CDC45', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19479294, end_position_on_the_genomic_accession=19520612, orientation='plus', exon_count=21, OMIM=[603465], no_hdr0=''),
    8320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8320, CurrentID=0, Status='live', Symbol='EOMES', Aliases=['TBR2'], description='eomesodermin', other_designations='eomesodermin homolog|T-box brain protein 2', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=27715953, end_position_on_the_genomic_accession=27722713, orientation='minus', exon_count=7, OMIM=[604615], no_hdr0=''),
    8321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8321, CurrentID=0, Status='live', Symbol='FZD1', Aliases=[], description='frizzled class receptor 1', other_designations='frizzled-1|Wnt receptor|frizzled 1, seven transmembrane spanning receptor|frizzled family receptor 1|frizzled homolog 1|frizzled, Drosophila, homolog of, 1|fz-1|fzE1|hFz1', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=91264433, end_position_on_the_genomic_accession=91271326, orientation='plus', exon_count=1, OMIM=[603408], no_hdr0=''),
    8322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8322, CurrentID=0, Status='live', Symbol='FZD4', Aliases=['CD344', 'EVR1', 'FEVRS', 'Fz-4', 'Fz4', 'FzE4', 'GPCR', 'hFz4', 'FZD4'], description='frizzled class receptor 4', other_designations='frizzled-4|WNT receptor frizzled-4|frizzled 4, seven transmembrane spanning receptor|frizzled family receptor 4|frizzled homolog 4', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86945679, end_position_on_the_genomic_accession=86955395, orientation='minus', exon_count=2, OMIM=[604579], no_hdr0=''),
    8323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8323, CurrentID=0, Status='live', Symbol='FZD6', Aliases=['FZ-6', 'FZ6', 'HFZ6', 'NDNC1', 'NDNC10'], description='frizzled class receptor 6', other_designations='frizzled-6|frizzled 6, seven transmembrane spanning receptor|frizzled family receptor 6|frizzled homolog 6|seven transmembrane helix receptor', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103298494, end_position_on_the_genomic_accession=103332866, orientation='plus', exon_count=8, OMIM=[603409], no_hdr0=''),
    8324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8324, CurrentID=0, Status='live', Symbol='FZD7', Aliases=['FzE3'], description='frizzled class receptor 7', other_designations='frizzled-7|Frizzled, drosophila, homolog of, 7|frizzled 7, seven transmembrane spanning receptor|frizzled family receptor 7|frizzled homolog 7|fz-7|hFz7', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202033855, end_position_on_the_genomic_accession=202038441, orientation='plus', exon_count=1, OMIM=[603410], no_hdr0=''),
    8325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8325, CurrentID=0, Status='live', Symbol='FZD8', Aliases=['FZ-8', 'hFZ8'], description='frizzled class receptor 8', other_designations='frizzled-8|frizzled 8, seven transmembrane spanning receptor|frizzled family receptor 8|frizzled homolog 8', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=35638247, end_position_on_the_genomic_accession=35642296, orientation='minus', exon_count=1, OMIM=[606146], no_hdr0=''),
    8326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8326, CurrentID=0, Status='live', Symbol='FZD9', Aliases=['CD349', 'FZD3'], description='frizzled class receptor 9', other_designations='frizzled-9|frizzled 9, seven transmembrane spanning receptor|frizzled family receptor 9|frizzled homolog 9|fz-9|fzE6|hFz9', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73433778, end_position_on_the_genomic_accession=73436120, orientation='plus', exon_count=1, OMIM=[601766], no_hdr0=''),
    8328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8328, CurrentID=0, Status='live', Symbol='GFI1B', Aliases=['BDPLT17', 'ZNF163B'], description='growth factor independent 1B transcriptional repressor', other_designations='zinc finger protein Gfi-1b|growth factor independent 1B (potential regulator of CDKN1A, translocated in CML)|growth factor independent 1B transcription repressor', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132945531, end_position_on_the_genomic_accession=132991697, orientation='plus', exon_count=14, OMIM=[604383], no_hdr0=''),
    8329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8329, CurrentID=0, Status='live', Symbol='H2AC13', Aliases=['H2A/c', 'H2AC11', 'H2AC15', 'H2AC16', 'H2AC17', 'H2AFC', 'HIST1H2AI'], description='H2A clustered histone 13', other_designations='histone H2A type 1|H2A histone family, member C|H2A.1|histone 1, H2ai|histone H2A/ptl|histone cluster 1 H2A family member i|histone cluster 1, H2ai', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27808173, end_position_on_the_genomic_accession=27808667, orientation='plus', exon_count=1, OMIM=[602787], no_hdr0=''),
    8330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8330, CurrentID=0, Status='live', Symbol='H2AC15', Aliases=['H2A.1', 'H2A/d', 'H2AC11', 'H2AC13', 'H2AC14', 'H2AC16', 'H2AC17', 'H2AFD', 'HIST1H2AK'], description='H2A clustered histone 15', other_designations='histone H2A type 1|H2A histone family, member D|histone 1, H2ak|histone H2A type 1-J|histone H2A/ptl|histone cluster 1 H2A family member k|histone cluster 1, H2ak', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27837880, end_position_on_the_genomic_accession=27838375, orientation='minus', exon_count=1, OMIM=[602788], no_hdr0=''),
    8331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8331, CurrentID=0, Status='live', Symbol='H2AC14', Aliases=['H2A/E', 'H2AFE', 'HIST1H2AJ', 'dJ160A22.4'], description='H2A clustered histone 14', other_designations='histone cluster 1, H2aj|H2A histone family, member E|histone 1, H2aj|histone cluster 1 H2A family member j', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27814302, end_position_on_the_genomic_accession=27814777, orientation='minus', exon_count=1, OMIM=[602791], no_hdr0=''),
    8332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8332, CurrentID=0, Status='live', Symbol='H2AC16', Aliases=['H2A.i', 'H2A/i', 'H2AC11', 'H2AC13', 'H2AC15', 'H2AC17', 'H2AFI', 'HIST1H2AL', 'dJ193B12.9'], description='H2A clustered histone 16', other_designations='histone H2A type 1|H2A histone family, member I|H2A.1|histone 1, H2al|histone H2A/ptl|histone cluster 1 H2A family member l|histone cluster 1, H2al', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27865317, end_position_on_the_genomic_accession=27865798, orientation='plus', exon_count=1, OMIM=[602793], no_hdr0=''),
    8334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8334, CurrentID=0, Status='live', Symbol='H2AC6', Aliases=['H2A/l', 'H2AFL', 'HIST1H2AC', 'dJ221C16.4'], description='H2A clustered histone 6', other_designations='histone H2A type 1-C|H2A histone family, member L|histone 1, H2ac|histone H2A/l|histone H2AC|histone cluster 1 H2A family member c|histone cluster 1, H2ac', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26124172, end_position_on_the_genomic_accession=26124690, orientation='plus', exon_count=1, OMIM=[602794], no_hdr0=''),
    8335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8335, CurrentID=0, Status='live', Symbol='H2AC4', Aliases=['H2A/m', 'H2AC8', 'H2AFM', 'HIST1H2AB'], description='H2A clustered histone 4', other_designations='histone H2A type 1-B/E|H2A histone family, member M|histone 1, H2ab|histone H2A/m|histone cluster 1 H2A family member b|histone cluster 1, H2ab', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26033092, end_position_on_the_genomic_accession=26033618, orientation='minus', exon_count=1, OMIM=[602795], no_hdr0=''),
    8336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8336, CurrentID=0, Status='live', Symbol='H2AC17', Aliases=['H2A.1', 'H2A/n', 'H2AC11', 'H2AC13', 'H2AC15', 'H2AC16', 'H2AFN', 'HIST1H2AM', 'dJ193B12.1'], description='H2A clustered histone 17', other_designations='histone H2A type 1|H2A histone family, member N|histone 1, H2am|histone H2A/ptl|histone cluster 1 H2A family member m|histone cluster 1, H2am', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27892699, end_position_on_the_genomic_accession=27893185, orientation='minus', exon_count=1, OMIM=[602796], no_hdr0=''),
    8337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8337, CurrentID=0, Status='live', Symbol='H2AC18', Aliases=['H2A', 'H2A.2', 'H2A/O', 'H2A/q', 'H2AC19', 'H2AFO', 'H2a-615', 'HIST2H2AA', 'HIST2H2AA3'], description='H2A clustered histone 18', other_designations='histone H2A type 2-A|H2A histone family, member O|H2A-clustered histone 19|histone 2, H2aa3|histone cluster 2 H2A family member a3|histone cluster 2, H2aa3', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149842218, end_position_on_the_genomic_accession=149842750, orientation='minus', exon_count=1, OMIM=[142720], no_hdr0=''),
    8338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8338, CurrentID=0, Status='live', Symbol='H2AC20', Aliases=['H2A', 'H2A-GL101', 'H2A/q', 'H2AFQ', 'HIST2H2AC'], description='H2A clustered histone 20', other_designations='histone H2A type 2-C|H2A histone family, member Q|histone 2, H2ac|histone H2A-GL101|histone H2A/q|histone IIa|histone cluster 2 H2A family member c|histone cluster 2, H2ac', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149886918, end_position_on_the_genomic_accession=149887411, orientation='plus', exon_count=1, OMIM=[602797], no_hdr0=''),
    8339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8339, CurrentID=0, Status='live', Symbol='H2BC8', Aliases=['H2B.1A', 'H2B/a', 'H2BC10', 'H2BC4', 'H2BC6', 'H2BC7', 'H2BFA', 'HIST1H2BG', 'dJ221C16.8'], description='H2B clustered histone 8', other_designations='histone H2B type 1-C/E/F/G/I|H2B histone family, member A|histone 1, H2bg|histone H2B.1 A|histone H2B.a|histone cluster 1 H2B family member g|histone cluster 1, H2bg', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26216200, end_position_on_the_genomic_accession=26216688, orientation='minus', exon_count=1, OMIM=[602798], no_hdr0=''),
    8340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8340, CurrentID=0, Status='live', Symbol='H2BC13', Aliases=['H2B/c', 'H2BFC', 'HIST1H2BL', 'dJ97D16.4'], description='H2B clustered histone 13', other_designations='histone H2B type 1-L|H2B histone family, member C|histone 1, H2bl|histone H2B.c|histone cluster 1 H2B family member l|histone cluster 1, H2bl', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27807479, end_position_on_the_genomic_accession=27807929, orientation='minus', exon_count=1, OMIM=[602800], no_hdr0=''),
    8341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8341, CurrentID=0, Status='live', Symbol='H2BC15', Aliases=['H2B/d', 'H2BFD', 'HIST1H2BN'], description='H2B clustered histone 15', other_designations='histone H2B type 1-N|H2B histone family, member D|histone 1, H2bn|histone H2B.d|histone cluster 1 H2B family member n|histone cluster 1, H2bn', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27838569, end_position_on_the_genomic_accession=27839110, orientation='plus', exon_count=1, OMIM=[602801], no_hdr0=''),
    8342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8342, CurrentID=0, Status='live', Symbol='H2BC14', Aliases=['H2B/e', 'H2BFE', 'HIST1H2BM', 'dJ160A22.3'], description='H2B clustered histone 14', other_designations='histone H2B type 1-M|H2B histone family, member E|histone 1, H2bm|histone H2B.e|histone cluster 1 H2B family member m|histone cluster 1, H2bm', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27815022, end_position_on_the_genomic_accession=27815489, orientation='plus', exon_count=1, OMIM=[602802], no_hdr0=''),
    8343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8343, CurrentID=0, Status='live', Symbol='H2BC7', Aliases=['H2B/g', 'H2BC10', 'H2BC4', 'H2BC6', 'H2BC8', 'H2BFG', 'HIST1H2BF'], description='H2B clustered histone 7', other_designations='histone H2B type 1-C/E/F/G/I|H2B histone family, member G|histone 1, H2bf|histone H2B.1 A|histone H2B.g|histone cluster 1 H2B family member f|histone cluster 1, H2bf', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26199516, end_position_on_the_genomic_accession=26199988, orientation='plus', exon_count=1, OMIM=[602804], no_hdr0=''),
    8344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8344, CurrentID=0, Status='live', Symbol='H2BC6', Aliases=['H2B.h', 'H2B/h', 'H2BC10', 'H2BC4', 'H2BC7', 'H2BC8', 'H2BFH', 'HIST1H2BE', 'dJ221C16.8'], description='H2B clustered histone 6', other_designations='histone H2B type 1-C/E/F/G/I|H2B histone family, member H|histone 1, H2be|histone H2B.1 A|histone H2B.h|histone cluster 1 H2B family member e|histone cluster 1, H2be', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26183761, end_position_on_the_genomic_accession=26184230, orientation='plus', exon_count=1, OMIM=[602805], no_hdr0=''),
    8345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8345, CurrentID=0, Status='live', Symbol='H2BC9', Aliases=['H2B/j', 'H2BFJ', 'HIST1H2BH'], description='H2B clustered histone 9', other_designations='histone H2B type 1-H|H2B histone family, member J|histone 1, H2bh|histone H2B.j|histone cluster 1 H2B family member h|histone cluster 1, H2bh', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26251614, end_position_on_the_genomic_accession=26252075, orientation='plus', exon_count=1, OMIM=[602806], no_hdr0=''),
    8346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8346, CurrentID=0, Status='live', Symbol='H2BC10', Aliases=['H2B/k', 'H2BC4', 'H2BC6', 'H2BC7', 'H2BC8', 'H2BFK', 'HIST1H2BI'], description='H2B clustered histone 10', other_designations='histone H2B type 1-C/E/F/G/I|H2B histone family, member K|histone 1, H2bi|histone H2B.1 A|histone H2B.k|histone cluster 1 H2B family member i|histone cluster 1, H2bi', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26272931, end_position_on_the_genomic_accession=26273412, orientation='plus', exon_count=1, OMIM=[602807], no_hdr0=''),
    8347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8347, CurrentID=0, Status='live', Symbol='H2BC4', Aliases=['H2B.1', 'H2B/l', 'H2BC10', 'H2BC6', 'H2BC7', 'H2BC8', 'H2BFL', 'HIST1H2BC', 'dJ221C16.3'], description='H2B clustered histone 4', other_designations='histone H2B type 1-C/E/F/G/I|H2B histone family, member L|histone 1, H2bc|histone H2B.1 A|histone H2B.l|histone cluster 1 H2B family member c|histone cluster 1, H2bc', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26113170, end_position_on_the_genomic_accession=26123926, orientation='minus', exon_count=2, OMIM=[602847], no_hdr0=''),
    8348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8348, CurrentID=0, Status='live', Symbol='H2BC17', Aliases=['H2B.2', 'H2B/n', 'H2BFN', 'HIST1H2BO', 'dJ193B12.2'], description='H2B clustered histone 17', other_designations='histone H2B type 1-O|H2B histone family, member N|histone 1, H2bo|histone H2B.2|histone H2B.n|histone cluster 1 H2B family member o|histone cluster 1, H2bo', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27893425, end_position_on_the_genomic_accession=27893891, orientation='plus', exon_count=1, OMIM=[602808], no_hdr0=''),
    8349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8349, CurrentID=0, Status='live', Symbol='H2BC21', Aliases=['GL105', 'H2B', 'H2B.1', 'H2BE', 'H2BFQ', 'H2BGL105', 'H2BQ', 'HIST2H2BE'], description='H2B clustered histone 21', other_designations='histone H2B type 2-E|H2B histone family, member Q|histone 2, H2be|histone H2B-GL105|histone H2B.q|histone cluster 2 H2B family member e|histone cluster 2, H2be', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149884459, end_position_on_the_genomic_accession=149886682, orientation='minus', exon_count=1, OMIM=[601831], no_hdr0=''),
    8350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8350, CurrentID=0, Status='live', Symbol='H3C1', Aliases=['H3/A0', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3FA', 'HIST1H3A', 'H3C1'], description='H3 clustered histone 1', other_designations='histone H3.1|H3 histone family, member A|histone 1, H3a|histone H3/a|histone cluster 1 H3 family member a|histone cluster 1, H3a', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26020451, end_position_on_the_genomic_accession=26020958, orientation='plus', exon_count=1, OMIM=[602810], no_hdr0=''),
    8351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8351, CurrentID=0, Status='live', Symbol='H3C4', Aliases=['H3/b', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C6', 'H3C7', 'H3C8', 'H3FB', 'HIST1H3D'], description='H3 clustered histone 4', other_designations='histone H3.1|H3 histone family, member B|histone 1, H3d|histone H3/b|histone cluster 1 H3 family member d|histone cluster 1, H3d', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26196784, end_position_on_the_genomic_accession=26199293, orientation='minus', exon_count=2, OMIM=[602811], no_hdr0=''),
    8352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8352, CurrentID=0, Status='live', Symbol='H3C3', Aliases=['H3.1', 'H3/c', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C2', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3FC', 'HIST1H3C'], description='H3 clustered histone 3', other_designations='histone H3.1|H3 histone family, member C|histone 1, H3c|histone H3/c|histone cluster 1 H3 family member c|histone cluster 1, H3c', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26045384, end_position_on_the_genomic_accession=26045869, orientation='plus', exon_count=1, OMIM=[602812], no_hdr0=''),
    8353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8353, CurrentID=0, Status='live', Symbol='H3C6', Aliases=['H3.1', 'H3/d', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C7', 'H3C8', 'H3FD', 'HIST1H3E'], description='H3 clustered histone 6', other_designations='histone H3.1|H3 histone family, member D|histone 1, H3e|histone H3/d|histone cluster 1 H3 family member e|histone cluster 1, H3e', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26224178, end_position_on_the_genomic_accession=26227473, orientation='plus', exon_count=2, OMIM=[602813], no_hdr0=''),
    8354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8354, CurrentID=0, Status='live', Symbol='H3C11', Aliases=['H3.f', 'H3/f', 'H3C1', 'H3C10', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3FF', 'HIST1H3I'], description='H3 clustered histone 11', other_designations='histone H3.1|H3 histone family, member F|histone 1, H3i|histone H3/f|histone cluster 1 H3 family member i|histone cluster 1, H3i', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27871845, end_position_on_the_genomic_accession=27872346, orientation='minus', exon_count=1, OMIM=[602814], no_hdr0=''),
    8355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8355, CurrentID=0, Status='live', Symbol='H3C8', Aliases=['H3/h', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3FH', 'HIST1H3G'], description='H3 clustered histone 8', other_designations='histone H3.1|H3 histone family, member H|histone 1, H3g|histone H3/h|histone cluster 1 H3 family member g|histone cluster 1, H3g', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26270918, end_position_on_the_genomic_accession=26271413, orientation='minus', exon_count=1, OMIM=[602815], no_hdr0=''),
    8356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8356, CurrentID=0, Status='live', Symbol='H3C12', Aliases=['H3/j', 'H3C1', 'H3C10', 'H3C11', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3FJ', 'HIST1H3J'], description='H3 clustered histone 12', other_designations='histone H3.1|H3 histone family, member J|histone 1, H3j|histone H3/j|histone cluster 1 H3 family member j|histone cluster 1, H3j', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27890315, end_position_on_the_genomic_accession=27890826, orientation='minus', exon_count=1, OMIM=[602817], no_hdr0=''),
    8357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8357, CurrentID=0, Status='live', Symbol='H3C10', Aliases=['H3/k', 'H3C1', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3F1K', 'H3FK', 'HIST1H3H'], description='H3 clustered histone 10', other_designations='histone H3.1|H3 histone family, member K|histone 1, H3h|histone H3/k|histone cluster 1 H3 family member h|histone cluster 1, H3h', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27810051, end_position_on_the_genomic_accession=27810536, orientation='plus', exon_count=1, OMIM=[602818], no_hdr0=''),
    8358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8358, CurrentID=0, Status='live', Symbol='H3C2', Aliases=['H3/l', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C3', 'H3C4', 'H3C6', 'H3C7', 'H3C8', 'H3FL', 'HIST1H3B'], description='H3 clustered histone 2', other_designations='histone H3.1|H3 histone family, member L|histone 1, H3b|histone H3/l|histone cluster 1 H3 family member b|histone cluster 1, H3b', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26031589, end_position_on_the_genomic_accession=26032099, orientation='minus', exon_count=1, OMIM=[602819], no_hdr0=''),
    8359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8359, CurrentID=0, Status='live', Symbol='H4C1', Aliases=['H4-161', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4FA', 'HIST1H4A', 'H4C1'], description='H4 clustered histone 1', other_designations='histone H4|H4 histone family, member A|histone 1, H4a|histone cluster 1 H4 family member a|histone cluster 1, H4a', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26021649, end_position_on_the_genomic_accession=26022050, orientation='plus', exon_count=1, OMIM=[602822], no_hdr0=''),
    8360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8360, CurrentID=0, Status='live', Symbol='H4C4', Aliases=['H4-16', 'H4/b', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4FB', 'HIST1H4D', 'dJ221C16.9'], description='H4 clustered histone 4', other_designations='histone H4|H4 histone family, member B|histone 1, H4d|histone cluster 1 H4 family member d|histone cluster 1, H4d', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26188710, end_position_on_the_genomic_accession=26189112, orientation='minus', exon_count=1, OMIM=[602823], no_hdr0=''),
    8361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8361, CurrentID=0, Status='live', Symbol='H4C6', Aliases=['H4', 'H4-16', 'H4/c', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C8', 'H4C9', 'H4FC', 'HIST1H4F'], description='H4 clustered histone 6', other_designations='histone H4|H4 histone family, member C|histone 1, H4f|histone cluster 1 H4 family member f|histone cluster 1, H4f', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26240393, end_position_on_the_genomic_accession=26240793, orientation='plus', exon_count=1, OMIM=[602824], no_hdr0=''),
    8362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8362, CurrentID=0, Status='live', Symbol='H4C12', Aliases=['H4-16', 'H4/d', 'H4C1', 'H4C11', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4F2iii', 'H4FD', 'HIST1H4K', 'dJ160A22.1'], description='H4 clustered histone 12', other_designations='histone H4|H4 histone family, member D|histone 1, H4k|histone cluster 1 H4 family member k|histone cluster 1, H4k', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27831174, end_position_on_the_genomic_accession=27831560, orientation='minus', exon_count=1, OMIM=[602825], no_hdr0=''),
    8363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8363, CurrentID=0, Status='live', Symbol='H4C11', Aliases=['H4-16', 'H4/e', 'H4C1', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4F2iv', 'H4FE', 'HIST1H4J', 'dJ160A22.2'], description='H4 clustered histone 11', other_designations='histone H4|H4 histone family, member E|histone 1, H4j|histone cluster 1 H4 family member j|histone cluster 1, H4j', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27824092, end_position_on_the_genomic_accession=27824480, orientation='plus', exon_count=1, OMIM=[602826], no_hdr0=''),
    8364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8364, CurrentID=0, Status='live', Symbol='H4C3', Aliases=['H4-16', 'H4/g', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4FG', 'HIST1H4C', 'dJ221C16.1'], description='H4 clustered histone 3', other_designations='histone H4|H4 histone family, member G|histone 1, H4c|histone cluster 1 H4 family member c|histone cluster 1, H4c', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26103933, end_position_on_the_genomic_accession=26104337, orientation='plus', exon_count=1, OMIM=[602827], no_hdr0=''),
    8365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8365, CurrentID=0, Status='live', Symbol='H4C8', Aliases=['H4-16', 'H4/h', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C9', 'H4FH', 'HIST1H4H'], description='H4 clustered histone 8', other_designations='histone H4|H4 histone family, member H|histone 1, H4h|histone cluster 1 H4 family member h|histone cluster 1, H4h', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26285126, end_position_on_the_genomic_accession=26285534, orientation='minus', exon_count=1, OMIM=[602828], no_hdr0=''),
    8366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8366, CurrentID=0, Status='live', Symbol='H4C2', Aliases=['H4-16', 'H4/I', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4FI', 'HIST1H4B'], description='H4 clustered histone 2', other_designations='histone H4|H4 histone family, member I|histone 1, H4b|histone cluster 1 H4 family member b|histone cluster 1, H4b', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26026896, end_position_on_the_genomic_accession=26027283, orientation='minus', exon_count=1, OMIM=[602829], no_hdr0=''),
    8367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8367, CurrentID=0, Status='live', Symbol='H4C5', Aliases=['H4-16', 'H4/j', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C6', 'H4C8', 'H4C9', 'H4FJ', 'HIST1H4E'], description='H4 clustered histone 5', other_designations='histone H4|H4 histone family, member J|histone 1, H4e|histone cluster 1 H4 family member e|histone cluster 1, H4e', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26204610, end_position_on_the_genomic_accession=26205021, orientation='plus', exon_count=1, OMIM=[602830], no_hdr0=''),
    8368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8368, CurrentID=0, Status='live', Symbol='H4C13', Aliases=['H4-16', 'H4.k', 'H4/k', 'H4C1', 'H4C11', 'H4C12', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4FK', 'HIST1H4L'], description='H4 clustered histone 13', other_designations='histone H4|H4 histone family, member K|histone 1, H4l|histone cluster 1 H4 family member l|histone cluster 1, H4l', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27873148, end_position_on_the_genomic_accession=27873534, orientation='minus', exon_count=1, OMIM=[602831], no_hdr0=''),
    8369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8369, CurrentID=0, Status='live', Symbol='H4C7', Aliases=['H4/l', 'H4FL', 'HIST1H4G'], description='H4 clustered histone 7', other_designations='histone H4-like protein type G|H4 histone family, member L|histone 1, H4g|histone cluster 1 H4 family member g|histone cluster 1, H4g', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26246611, end_position_on_the_genomic_accession=26246996, orientation='minus', exon_count=1, OMIM=[602832], no_hdr0=''),
    8370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8370, CurrentID=0, Status='live', Symbol='H4C14', Aliases=['FO108', 'H4', 'H4-16', 'H4/n', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'H4F2', 'H4FN', 'HIST2H4', 'HIST2H4A'], description='H4 clustered histone 14', other_designations='histone H4|H4 histone family, member N|H4 histone, family 2|histone 2, H4a|histone IV, family 2|histone cluster 2 H4 family member a|histone cluster 2, H4a', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149832657, end_position_on_the_genomic_accession=149833052, orientation='plus', exon_count=1, OMIM=[142750], no_hdr0=''),
    8372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8372, CurrentID=0, Status='live', Symbol='HYAL3', Aliases=['HYAL-3', 'LUCA-3', 'LUCA3'], description='hyaluronidase 3', other_designations='hyaluronidase-3|hyaluronoglucosaminidase 3|lung carcinoma protein 3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50292832, end_position_on_the_genomic_accession=50299405, orientation='minus', exon_count=5, OMIM=[604038], no_hdr0=''),
    8379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8379, CurrentID=0, Status='live', Symbol='MAD1L1', Aliases=['MAD1', 'PIG9', 'TP53I9', 'TXBP181'], description='mitotic arrest deficient 1 like 1', other_designations='mitotic spindle assembly checkpoint protein MAD1|MAD1 mitotic arrest deficient like 1|MAD1-like protein 1|mitotic arrest deficient 1-like protein 1|mitotic checkpoint MAD1 protein homolog|mitotic-arrest deficient 1, yeast, homolog-like 1|tax-binding protein 181|tumor protein p53 inducible protein 9', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1815795, end_position_on_the_genomic_accession=2232945, orientation='minus', exon_count=21, OMIM=[602686], no_hdr0=''),
    8382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8382, CurrentID=0, Status='live', Symbol='NME5', Aliases=['NM23-H5', 'NM23H5', 'RSPH23'], description='NME/NM23 family member 5', other_designations='nucleoside diphosphate kinase homolog 5|IPIA-beta|NDK-H 5|NDP kinase homolog 5|inhibitor of p53-induced apoptosis-beta|non-metastatic cells 5 protein expressed in|non-metastatic cells 5, protein expressed in (nucleoside-diphosphate kinase)|radial spoke 23 homolog|testis-specific nm23 homolog', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138115175, end_position_on_the_genomic_accession=138139471, orientation='minus', exon_count=8, OMIM=[603575], no_hdr0=''),
    8383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8383, CurrentID=0, Status='live', Symbol='OR1A1', Aliases=['OR17-7'], description='olfactory receptor family 1 subfamily A member 1', other_designations='olfactory receptor 1A1|olfactory receptor 17-7|olfactory receptor OR17-11', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3207667, end_position_on_the_genomic_accession=3218896, orientation='plus', exon_count=4, OMIM=[618046], no_hdr0=''),
    8386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8386, CurrentID=0, Status='live', Symbol='OR1D5', Aliases=['C17orf2', 'OR17-2', 'OR17-30', 'OR17-31', 'OR1D4'], description='olfactory receptor family 1 subfamily D member 5', other_designations='olfactory receptor 1D5|olfactory receptor 17-31|olfactory receptor OR17-2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3062669, end_position_on_the_genomic_accession=3063607, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    8387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8387, CurrentID=0, Status='live', Symbol='OR1E1', Aliases=['HGM071', 'OR13-66', 'OR17-2', 'OR17-32', 'OR1E5', 'OR1E6', 'OR1E8P', 'OR1E9P', 'OST547'], description='olfactory receptor family 1 subfamily E member 1', other_designations='olfactory receptor 1E1|OR5-85|olfactory receptor 13-66|olfactory receptor 17-2/17-32|olfactory receptor 1E5|olfactory receptor 1E6|olfactory receptor 5-85|olfactory receptor OR17-18|olfactory receptor OR17-4|olfactory receptor, family 1, subfamily E, member 5|olfactory receptor, family 1, subfamily E, member 6|olfactory receptor, family 1, subfamily E, member 8 pseudogene|olfactory receptor, family 1, subfamily E, member 9 pseudogene|olfactory receptor-like protein HGMP07I', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3397104, end_position_on_the_genomic_accession=3398410, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    8388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8388, CurrentID=0, Status='live', Symbol='OR1E2', Aliases=['OR17-135', 'OR17-136', 'OR17-93', 'OR1E4', 'OR1E7', 'OST529'], description='olfactory receptor family 1 subfamily E member 2', other_designations='olfactory receptor 1E2|olfactory receptor 17-93/17-135/17-136|olfactory receptor 1E4|olfactory receptor OR17-17|olfactory receptor OR17-3|olfactory receptor, family 1, subfamily E, member 4|olfactory receptor, family 1, subfamily E, member 7', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3432870, end_position_on_the_genomic_accession=3433841, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    8390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8390, CurrentID=0, Status='live', Symbol='OR1G1', Aliases=['OR17-130', 'OR17-209', 'OR1G2'], description='olfactory receptor family 1 subfamily G member 1', other_designations='olfactory receptor 1G1|olfactory receptor 17-209|olfactory receptor 1G2|olfactory receptor OR17-8|olfactory receptor, family 1, subfamily G, member 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3126610, end_position_on_the_genomic_accession=3127551, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    8392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8392, CurrentID=0, Status='live', Symbol='OR3A3', Aliases=['OR17-137', 'OR17-16', 'OR17-201', 'OR3A6', 'OR3A7', 'OR3A8P'], description='olfactory receptor family 3 subfamily A member 3', other_designations='olfactory receptor 3A3|olfactory receptor 17-201|olfactory receptor 3A6|olfactory receptor 3A7|olfactory receptor 3A8|olfactory receptor OR17-22|olfactory receptor, family 3, subfamily A, member 6|olfactory receptor, family 3, subfamily A, member 7|olfactory receptor, family 3, subfamily A, member 8 pseudogene', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3411370, end_position_on_the_genomic_accession=3424070, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    8394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8394, CurrentID=0, Status='live', Symbol='PIP5K1A', Aliases=[], description='phosphatidylinositol-4-phosphate 5-kinase type 1 alpha', other_designations='phosphatidylinositol 4-phosphate 5-kinase type-1 alpha|68 kDa type I phosphatidylinositol 4-phosphate 5-kinase alpha|PIP5K1-alpha|PIP5KIalpha|phosphatidylinositol 4-phosphate 5-kinase type I alpha|ptdIns(4)P-5-kinase 1 alpha', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151197954, end_position_on_the_genomic_accession=151249536, orientation='plus', exon_count=21, OMIM=[603275], no_hdr0=''),
    8395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8395, CurrentID=0, Status='live', Symbol='PIP5K1B', Aliases=['MSS4', 'STM7'], description='phosphatidylinositol-4-phosphate 5-kinase type 1 beta', other_designations='phosphatidylinositol 4-phosphate 5-kinase type-1 beta|PIP5K1-beta|PIP5KIbeta|phosphatidylinositol 4-phosphate 5-kinase type I beta|protein STM-7|ptdIns(4)P-5-kinase 1 beta|type I phosphatidylinositol 4-phosphate 5-kinase beta', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68705240, end_position_on_the_genomic_accession=69009176, orientation='plus', exon_count=21, OMIM=[602745], no_hdr0=''),
    8396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8396, CurrentID=0, Status='live', Symbol='PIP4K2B', Aliases=['PI5P4KB', 'PIP5K2B', 'PIP5KIIB', 'PIP5KIIbeta', 'PIP5P4KB'], description='phosphatidylinositol-5-phosphate 4-kinase type 2 beta', other_designations='phosphatidylinositol 5-phosphate 4-kinase type-2 beta|1-phosphatidylinositol 5-phosphate 4-kinase 2-beta|1-phosphatidylinositol-4-phosphate kinase|PI(5)P 4-kinase type II beta|PIP4KII-beta|PTDINS(4)P-5-kinase|diphosphoinositide kinase 2-beta|phosphatidylinositol 5-phosphate 4-kinase type II beta|phosphatidylinositol-4-phosphate 5-kinase, type II, beta', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38765691, end_position_on_the_genomic_accession=38799576, orientation='minus', exon_count=13, OMIM=[603261], no_hdr0=''),
    8398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8398, CurrentID=0, Status='live', Symbol='PLA2G6', Aliases=['CaI-PLA2', 'GVI', 'INAD1', 'IPLA2-VIA', 'NBIA2', 'NBIA2A', 'NBIA2B', 'PARK14', 'PLA2', 'PNPLA9', 'iPLA2', 'iPLA2beta'], description='phospholipase A2 group VI', other_designations='85/88 kDa calcium-independent phospholipase A2|2-lysophosphatidylcholine acylhydrolase|85 kDa calcium-independent phospholipase A2|GVI PLA2|iPLA2-beta|intracellular membrane-associated calcium-independent phospholipase A2 beta|neurodegeneration with brain iron accumulation 2|palmitoyl-CoA hydrolase|patatin-like phospholipase domain-containing protein 9|phospholipase A2, group VI (cytosolic, calcium-independent)', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38111495, end_position_on_the_genomic_accession=38181830, orientation='minus', exon_count=18, OMIM=[603604], no_hdr0=''),
    8399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8399, CurrentID=0, Status='live', Symbol='PLA2G10', Aliases=['GXPLA2', 'GXSPLA2', 'SPLA2', 'sPLA2-X'], description='phospholipase A2 group X', other_designations='group 10 secretory phospholipase A2|group X secretory phospholipase A2|phosphatidylcholine 2-acylhydrolase 10', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14672548, end_position_on_the_genomic_accession=14694662, orientation='minus', exon_count=8, OMIM=[603603], no_hdr0=''),
    8402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8402, CurrentID=0, Status='live', Symbol='SLC25A11', Aliases=['OGC', 'PGL6', 'SLC20A4'], description='solute carrier family 25 member 11', other_designations='mitochondrial 2-oxoglutarate/malate carrier protein|OGCP|solute carrier family 20 (oxoglutarate carrier), member 4|solute carrier family 25 (mitochondrial carrier; oxoglutarate carrier), member 11', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4937130, end_position_on_the_genomic_accession=4940251, orientation='minus', exon_count=8, OMIM=[604165], no_hdr0=''),
    8403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8403, CurrentID=0, Status='live', Symbol='SOX14', Aliases=['SOX28'], description='SRY-box transcription factor 14', other_designations='transcription factor SOX-14|HMG box transcription factor SOX-14|SRY (sex determining region Y)-box 14|SRY-box 14', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=137764315, end_position_on_the_genomic_accession=137766334, orientation='plus', exon_count=1, OMIM=[604747], no_hdr0=''),
    8404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8404, CurrentID=0, Status='live', Symbol='SPARCL1', Aliases=['MAST 9', 'MAST9', 'PIG33', 'SC1'], description='SPARC like 1', other_designations='SPARC-like protein 1|SPARC-like 1 (hevin)|high endothelial venule protein|proliferation-inducing protein 33', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87473335, end_position_on_the_genomic_accession=87529376, orientation='minus', exon_count=14, OMIM=[606041], no_hdr0=''),
    8405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8405, CurrentID=0, Status='live', Symbol='SPOP', Aliases=['BTBD32', 'NEDMACE', 'NEDMIDF', 'NSDVS1', 'NSDVS2', 'TEF2'], description='speckle type BTB/POZ protein', other_designations='speckle-type POZ protein|HIB homolog 1|roadkill homolog 1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49598884, end_position_on_the_genomic_accession=49678163, orientation='minus', exon_count=16, OMIM=[602650], no_hdr0=''),
    8406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8406, CurrentID=0, Status='live', Symbol='SRPX', Aliases=['DRS', 'ETX1', 'HEL-S-83p1', 'SRPX'], description='sushi repeat containing protein X-linked', other_designations='sushi repeat-containing protein SRPX|epididymis secretory sperm binding protein Li 83p|sushi-repeat-containing protein, X chromosome', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=38149339, end_position_on_the_genomic_accession=38220881, orientation='minus', exon_count=11, OMIM=[300187], no_hdr0=''),
    8407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8407, CurrentID=0, Status='live', Symbol='TAGLN2', Aliases=['HA1756'], description='transgelin 2', other_designations='transgelin-2|SM22-alpha homolog|epididymis secretory sperm binding protein|epididymis tissue protein Li 7e', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159918111, end_position_on_the_genomic_accession=159925507, orientation='minus', exon_count=7, OMIM=[604634], no_hdr0=''),
    8408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8408, CurrentID=0, Status='live', Symbol='ULK1', Aliases=['ATG1', 'ATG1A', 'UNC51', 'Unc51.1', 'hATG1'], description='unc-51 like autophagy activating kinase 1', other_designations='serine/threonine-protein kinase ULK1|ATG1 autophagy related 1 homolog|autophagy-related protein 1 homolog', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131894622, end_position_on_the_genomic_accession=131923150, orientation='plus', exon_count=28, OMIM=[603168], no_hdr0=''),
    8409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8409, CurrentID=0, Status='live', Symbol='UXT', Aliases=['ART-27', 'STAP1'], description='ubiquitously expressed prefoldin like chaperone', other_designations='protein UXT|SKP2-associated alpha PFD 1|androgen receptor trapped clone 27 protein|ubiquitously expressed transcript protein', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47651796, end_position_on_the_genomic_accession=47659180, orientation='minus', exon_count=7, OMIM=[300234], no_hdr0=''),
    8411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8411, CurrentID=0, Status='live', Symbol='EEA1', Aliases=['MST105', 'MSTP105', 'ZFYVE2'], description='early endosome antigen 1', other_designations='early endosome antigen 1|early endosome antigen 1, 162kD|early endosome-associated protein|endosome-associated protein p162|zinc finger FYVE domain-containing protein 2', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=92770637, end_position_on_the_genomic_accession=92975228, orientation='minus', exon_count=32, OMIM=[605070], no_hdr0=''),
    8412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8412, CurrentID=0, Status='live', Symbol='BCAR3', Aliases=['AND-34', 'MIG7', 'NSP2', 'SH2D3B'], description='BCAR3 adaptor protein, NSP family member', other_designations='breast cancer anti-estrogen resistance protein 3|BCAR3, NSP family adaptor protein|SH2 domain-containing protein 3B|breast cancer anti-estrogen resistance 3|breast cancer antiestrogen resistance 3 protein|dJ1033H22.2 (breast cancer anti-estrogen resistance 3)|epididymis secretory sperm binding protein|mig-7|migration inducting gene-7|novel SH2-containing protein 2', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93561741, end_position_on_the_genomic_accession=93847219, orientation='minus', exon_count=20, OMIM=[604704], no_hdr0=''),
    8416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8416, CurrentID=0, Status='live', Symbol='ANXA9', Aliases=['ANX31'], description='annexin A9', other_designations='annexin A9|annexin 31|annexin XXXI|annexin-9|pemphaxin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150982286, end_position_on_the_genomic_accession=150996063, orientation='plus', exon_count=14, OMIM=[603319], no_hdr0=''),
    8417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8417, CurrentID=0, Status='live', Symbol='STX7', Aliases=[], description='syntaxin 7', other_designations='syntaxin-7', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132445867, end_position_on_the_genomic_accession=132513472, orientation='minus', exon_count=13, OMIM=[603217], no_hdr0=''),
    8419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8419, CurrentID=0, Status='live', Symbol='BFSP2', Aliases=['CP47', 'CP49', 'CTRCT12', 'LIFL-L', 'PHAKOSIN'], description='beaded filament structural protein 2', other_designations='phakinin|49 kDa cytoskeletal protein|beaded filament protein CP49|beaded filament structural protein 2, phakinin|bfps2, Cytoskeletal protein, 49-kD|lens fiber cell beaded filament protein CP 47|lens fiber cell beaded filament protein CP 49|lens intermediate filament-like light', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133397882, end_position_on_the_genomic_accession=133475208, orientation='plus', exon_count=8, OMIM=[603212], no_hdr0=''),
    8424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8424, CurrentID=0, Status='live', Symbol='BBOX1', Aliases=['BBH', 'BBOX', 'G-BBH', 'gamma-BBH'], description='gamma-butyrobetaine hydroxylase 1', other_designations='gamma-butyrobetaine dioxygenase|butyrobetaine (gamma), 2-oxoglutarate dioxygenase (gamma-butyrobetaine hydroxylase) 1|gamma-butyrobetaine,2-oxoglutarate dioxygenase 1', map_location='11p14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=27040705, end_position_on_the_genomic_accession=27127809, orientation='plus', exon_count=11, OMIM=[603312], no_hdr0=''),
    8425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8425, CurrentID=0, Status='live', Symbol='LTBP4', Aliases=['ARCL1C', 'LTBP-4L', 'LTBP4S', 'LTBP4'], description='latent transforming growth factor beta binding protein 4', other_designations='latent-transforming growth factor beta-binding protein 4|latent transforming growth factor-beta binding protein 4L', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40593166, end_position_on_the_genomic_accession=40629820, orientation='plus', exon_count=35, OMIM=[604710], no_hdr0=''),
    8427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8427, CurrentID=0, Status='live', Symbol='ZNF282', Aliases=['HUB1'], description='zinc finger protein 282', other_designations='zinc finger protein 282|HTLV-I U5 repressive element-binding protein 1|HTLV-I U5RE-binding protein 1|HUB-1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149195495, end_position_on_the_genomic_accession=149226243, orientation='plus', exon_count=9, OMIM=[603397], no_hdr0=''),
    8428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8428, CurrentID=0, Status='live', Symbol='STK24', Aliases=['HEL-S-95', 'MST3', 'MST3B', 'STE20', 'STK3'], description='serine/threonine kinase 24', other_designations='serine/threonine-protein kinase 24|STE20-like kinase 3|STE20-like kinase MST3|epididymis secretory protein Li 95|mammalian STE20-like protein kinase 3|serine/threonine kinase 24 (STE20 homolog, yeast)|sterile 20-like kinase 3', map_location='13q32.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=98445185, end_position_on_the_genomic_accession=98577107, orientation='minus', exon_count=14, OMIM=[604984], no_hdr0=''),
    8431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8431, CurrentID=0, Status='live', Symbol='NR0B2', Aliases=['SHP', 'SHP1'], description='nuclear receptor subfamily 0 group B member 2', other_designations='nuclear receptor subfamily 0 group B member 2|nuclear receptor SHP|orphan nuclear receptor SHP|small heterodimer partner', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26911489, end_position_on_the_genomic_accession=26914110, orientation='minus', exon_count=3, OMIM=[604630], no_hdr0=''),
    8433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8433, CurrentID=0, Status='live', Symbol='UTF1', Aliases=[], description='undifferentiated embryonic cell transcription factor 1', other_designations='undifferentiated embryonic cell transcription factor 1', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133230217, end_position_on_the_genomic_accession=133231558, orientation='plus', exon_count=2, OMIM=[604130], no_hdr0=''),
    8434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8434, CurrentID=0, Status='live', Symbol='RECK', Aliases=['ST15'], description='reversion inducing cysteine rich protein with kazal motifs', other_designations='reversion-inducing cysteine-rich protein with Kazal motifs|membrane-anchored glycoprotein (metastasis and invasion)|suppression of tumorigenicity 15 (reversion-inducing-cysteine-rich protein with kazal motifs)|suppression of tumorigenicity 5 (reversion-inducing-cysteine-rich protein with kazal motifs)|suppressor of tumorigenicity 15 protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36036905, end_position_on_the_genomic_accession=36124455, orientation='plus', exon_count=25, OMIM=[605227], no_hdr0=''),
    8435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8435, CurrentID=0, Status='live', Symbol='SOAT2', Aliases=['ACACT2', 'ACAT2', 'ARGP2'], description='sterol O-acyltransferase 2', other_designations='sterol O-acyltransferase 2|ACAT-2|acyl Co-A: cholesterol acyltransferase 2|acyl coenzyme A:cholesterol acyltransferase 2|acyl-CoA:cholesterol acyltransferase 2|cholesterol acyltransferase 2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53103486, end_position_on_the_genomic_accession=53124535, orientation='plus', exon_count=15, OMIM=[601311], no_hdr0=''),
    8436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8436, CurrentID=0, Status='live', Symbol='CAVIN2', Aliases=['PS-p68', 'SDPR', 'SDR', 'cavin-2'], description='caveolae associated protein 2', other_designations='caveolae-associated protein 2|phosphatidylserine-binding protein|serum deprivation response|serum deprivation-response protein', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=191834310, end_position_on_the_genomic_accession=191847088, orientation='minus', exon_count=2, OMIM=[606728], no_hdr0=''),
    8437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8437, CurrentID=0, Status='live', Symbol='RASAL1', Aliases=['RASAL'], description='RAS protein activator like 1', other_designations='rasGAP-activating-like protein 1|GAP1 like protein|ras GTPase-activating-like protein', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113096515, end_position_on_the_genomic_accession=113136248, orientation='minus', exon_count=23, OMIM=[604118], no_hdr0=''),
    8438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8438, CurrentID=0, Status='live', Symbol='RAD54L', Aliases=['HR54', 'RAD54A', 'hHR54', 'hRAD54'], description='RAD54 like', other_designations='DNA repair and recombination protein RAD54-like|RAD54 homolog', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46247688, end_position_on_the_genomic_accession=46278477, orientation='plus', exon_count=19, OMIM=[603615], no_hdr0=''),
    8439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8439, CurrentID=0, Status='live', Symbol='NSMAF', Aliases=['FAN', 'GRAMD5'], description='neutral sphingomyelinase activation associated factor', other_designations='protein FAN|factor associated with N-SMase activation|factor associated with neutral sphingomyelinase activation|neutral sphingomyelinase (N-SMase) activation associated factor', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=58583504, end_position_on_the_genomic_accession=58659853, orientation='minus', exon_count=32, OMIM=[603043], no_hdr0=''),
    8440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8440, CurrentID=0, Status='live', Symbol='NCK2', Aliases=['GRB4', 'NCKbeta'], description='NCK adaptor protein 2', other_designations='cytoplasmic protein NCK2|SH2/SH3 adaptor protein NCK-beta|growth factor receptor-bound protein 4|noncatalytic region of tyrosine kinase, beta', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105744649, end_position_on_the_genomic_accession=105894274, orientation='plus', exon_count=9, OMIM=[604930], no_hdr0=''),
    8443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8443, CurrentID=0, Status='live', Symbol='GNPAT', Aliases=['DAP-AT', 'DAPAT', 'DHAPAT', 'RCDP2'], description='glyceronephosphate O-acyltransferase', other_designations='dihydroxyacetone phosphate acyltransferase|DHAP-AT|acyl-CoA:dihydroxyacetonephosphateacyltransferase|glycerone-phosphate O-acyltransferase', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231241210, end_position_on_the_genomic_accession=231277973, orientation='plus', exon_count=17, OMIM=[602744], no_hdr0=''),
    8444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8444, CurrentID=0, Status='live', Symbol='DYRK3', Aliases=['DYRK5', 'RED', 'REDK', 'hYAK3-2'], description='dual specificity tyrosine phosphorylation regulated kinase 3', other_designations='dual specificity tyrosine-phosphorylation-regulated kinase 3|dual specificity tyrosine-(Y)-phosphorylation regulated kinase 3|dual-specificity tyrosine-(Y)-phosphorylation regulated kinase 5|protein kinase Dyrk3|regulatory erythroid kinase', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206635536, end_position_on_the_genomic_accession=206655158, orientation='plus', exon_count=5, OMIM=[603497], no_hdr0=''),
    8445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8445, CurrentID=0, Status='live', Symbol='DYRK2', Aliases=[], description='dual specificity tyrosine phosphorylation regulated kinase 2', other_designations='dual specificity tyrosine-phosphorylation-regulated kinase 2|dual specificity tyrosine-(Y)-phosphorylation regulated kinase 2', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=67648745, end_position_on_the_genomic_accession=67665406, orientation='plus', exon_count=4, OMIM=[603496], no_hdr0=''),
    8446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8446, CurrentID=0, Status='live', Symbol='DUSP11', Aliases=['PIR1'], description='dual specificity phosphatase 11', other_designations='RNA/RNP complex-1-interacting phosphatase|RNA/RNP complex 1-interacting|RNA/RNP complex-interacting phosphatase|dual specificity protein phosphatase 11|phosphatase that interacts with RNA/RNP complex 1|serine/threonine specific protein phosphatase', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73762198, end_position_on_the_genomic_accession=73780157, orientation='minus', exon_count=9, OMIM=[603092], no_hdr0=''),
    8447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8447, CurrentID=0, Status='live', Symbol='DOC2B', Aliases=['DOC2BL'], description='double C2 domain beta', other_designations='double C2-like domain-containing protein beta|doc2-beta|double C2-like domains, beta', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=142789, end_position_on_the_genomic_accession=181650, orientation='minus', exon_count=13, OMIM=[604568], no_hdr0=''),
    8448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8448, CurrentID=0, Status='live', Symbol='DOC2A', Aliases=['Doc2'], description='double C2 domain alpha', other_designations='double C2-like domain-containing protein alpha|doc2-alpha|double C2-like domains, alpha', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30005514, end_position_on_the_genomic_accession=30023280, orientation='minus', exon_count=18, OMIM=[604567], no_hdr0=''),
    8449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8449, CurrentID=0, Status='live', Symbol='DHX16', Aliases=['DBP2', 'DDX16', 'NMOAS', 'PRO2014', 'PRP8', 'PRPF2', 'Prp2'], description='DEAH-box helicase 16', other_designations='pre-mRNA-splicing factor ATP-dependent RNA helicase DHX16|ATP-dependent RNA helicase #3|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 16|DEAD/H box 16|DEAH (Asp-Glu-Ala-His) box polypeptide 16|DEAH-box protein 16|RNA helicase|putative pre-mRNA-splicing factor ATP-dependent RNA helicase DHX16', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30653127, end_position_on_the_genomic_accession=30673006, orientation='minus', exon_count=24, OMIM=[603405], no_hdr0=''),
    8450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8450, CurrentID=0, Status='live', Symbol='CUL4B', Aliases=['CUL-4B', 'MRXHF2', 'MRXS15', 'MRXSC', 'SFM2'], description='cullin 4B', other_designations='cullin-4B', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120523858, end_position_on_the_genomic_accession=120575532, orientation='minus', exon_count=24, OMIM=[300304], no_hdr0=''),
    8451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8451, CurrentID=0, Status='live', Symbol='CUL4A', Aliases=[], description='cullin 4A', other_designations='cullin-4A|CUL-4A', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113208193, end_position_on_the_genomic_accession=113267108, orientation='plus', exon_count=25, OMIM=[603137], no_hdr0=''),
    8452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8452, CurrentID=0, Status='live', Symbol='CUL3', Aliases=['CUL-3', 'NEDAUS', 'PHA2E'], description='cullin 3', other_designations='cullin-3', map_location='2q36.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=224470150, end_position_on_the_genomic_accession=224585363, orientation='minus', exon_count=20, OMIM=[603136], no_hdr0=''),
    8453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8453, CurrentID=0, Status='live', Symbol='CUL2', Aliases=[], description='cullin 2', other_designations='cullin-2|CUL-2|testis secretory sperm-binding protein Li 238E', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=35008551, end_position_on_the_genomic_accession=35126899, orientation='minus', exon_count=29, OMIM=[603135], no_hdr0=''),
    8454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8454, CurrentID=0, Status='live', Symbol='CUL1', Aliases=[], description='cullin 1', other_designations='cullin-1|CUL-1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=148697756, end_position_on_the_genomic_accession=148801110, orientation='plus', exon_count=26, OMIM=[603134], no_hdr0=''),
    8455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8455, CurrentID=0, Status='live', Symbol='ATRN', Aliases=['DPPT-L', 'MGCA'], description='attractin', other_designations='attractin|attractin-2|mahogany homolog|mahogany protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3471018, end_position_on_the_genomic_accession=3651118, orientation='plus', exon_count=31, OMIM=[603130], no_hdr0=''),
    8456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8456, CurrentID=0, Status='live', Symbol='FOXN1', Aliases=['FKHL20', 'RONU', 'TIDAND', 'TLIND', 'WHN'], description='forkhead box N1', other_designations='forkhead box protein N1|Rowett nude|winged-helix nude|winged-helix transcription factor nude', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28506211, end_position_on_the_genomic_accession=28538900, orientation='plus', exon_count=11, OMIM=[600838], no_hdr0=''),
    8458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8458, CurrentID=0, Status='live', Symbol='TTF2', Aliases=['F2', 'HuF2', 'ZGRF6'], description='transcription termination factor 2', other_designations='transcription termination factor 2|RNA polymerase II termination factor|human factor 2|lodestar homolog|lodestar protein|transcription release factor 2|transcription termination factor, RNA polymerase II|zinc finger, GRF-type containing 6', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117060303, end_position_on_the_genomic_accession=117107453, orientation='plus', exon_count=25, OMIM=[604718], no_hdr0=''),
    8459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8459, CurrentID=0, Status='live', Symbol='TPST2', Aliases=['TANGO13B', 'TPST-2'], description='tyrosylprotein sulfotransferase 2', other_designations='protein-tyrosine sulfotransferase 2|transport and golgi organization 13 homolog B|tyrosylprotein phosphotransferase 2', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26521996, end_position_on_the_genomic_accession=26590132, orientation='minus', exon_count=10, OMIM=[603126], no_hdr0=''),
    8460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8460, CurrentID=0, Status='live', Symbol='TPST1', Aliases=['TANGO13A'], description='tyrosylprotein sulfotransferase 1', other_designations='protein-tyrosine sulfotransferase 1|TPST-1|transport and golgi organization 13 homolog A', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66205314, end_position_on_the_genomic_accession=66360443, orientation='plus', exon_count=8, OMIM=[603125], no_hdr0=''),
    8462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8462, CurrentID=0, Status='live', Symbol='KLF11', Aliases=['FKLF', 'FKLF1', 'MODY7', 'TIEG2', 'Tieg3'], description='Kruppel like factor 11', other_designations='Krueppel-like factor 11|TGFB-inducible early growth response protein 2|TIEG-2|transforming growth factor-beta-inducible early growth response protein 2', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10043550, end_position_on_the_genomic_accession=10054836, orientation='plus', exon_count=6, OMIM=[603301], no_hdr0=''),
    8463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8463, CurrentID=0, Status='live', Symbol='TEAD2', Aliases=['ETF', 'TEAD-2', 'TEF-4', 'TEF4'], description='TEA domain transcription factor 2', other_designations='transcriptional enhancer factor TEF-4|TEA domain family member 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49340595, end_position_on_the_genomic_accession=49362452, orientation='minus', exon_count=17, OMIM=[601729], no_hdr0=''),
    8464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8464, CurrentID=0, Status='live', Symbol='SUPT3H', Aliases=['SPT3', 'SPT3L'], description='SPT3 homolog, SAGA and STAGA complex component', other_designations='transcription initiation protein SPT3 homolog|SPT3-like protein|suppressor of Ty 3 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44809057, end_position_on_the_genomic_accession=45378051, orientation='minus', exon_count=22, OMIM=[602947], no_hdr0=''),
    8467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8467, CurrentID=0, Status='live', Symbol='SMARCA5', Aliases=['ISWI', 'SNF2H', 'WCRF135', 'hISWI', 'hSNF2H'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a, member 5', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily A member 5|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin A5|sucrose nonfermenting protein 2 homolog|sucrose nonfermenting-like 5', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143513501, end_position_on_the_genomic_accession=143557486, orientation='plus', exon_count=24, OMIM=[603375], no_hdr0=''),
    8468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8468, CurrentID=0, Status='live', Symbol='FKBP6', Aliases=['FKBP36'], description='FKBP prolyl isomerase family member 6 (inactive)', other_designations='inactive peptidyl-prolyl cis-trans isomerase FKBP6|36 kDa FKBP|FK506 binding protein 6, 36kDa|FK506-binding protein 6|FKBP prolyl isomerase 6|PPIase FKBP6|immunophilin FKBP36|inactive PPIase FKBP6|peptidyl-prolyl cis-trans isomerase FKBP6|rotamase', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73328154, end_position_on_the_genomic_accession=73358625, orientation='plus', exon_count=9, OMIM=[604839], no_hdr0=''),
    8470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8470, CurrentID=0, Status='live', Symbol='SORBS2', Aliases=['ARGBP2', 'PRO0618'], description='sorbin and SH3 domain containing 2', other_designations='sorbin and SH3 domain-containing protein 2|Arg binding protein 2|Arg/Abl-interacting protein 2|arg-binding protein 2', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185585523, end_position_on_the_genomic_accession=185956372, orientation='minus', exon_count=39, OMIM=[616349], no_hdr0=''),
    8471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8471, CurrentID=0, Status='live', Symbol='IRS4', Aliases=['CHNG9', 'IRS-4', 'PY160'], description='insulin receptor substrate 4', other_designations='insulin receptor substrate 4|160 kDa phosphotyrosine protein|phosphoprotein of 160 kDa|pp160', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108719946, end_position_on_the_genomic_accession=108736584, orientation='minus', exon_count=4, OMIM=[300904], no_hdr0=''),
    8473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8473, CurrentID=0, Status='live', Symbol='OGT', Aliases=['HINCUT-1', 'HRNT1', 'MRX106', 'O-GLCNAC1', 'OGT'], description='O-linked N-acetylglucosamine (GlcNAc) transferase', other_designations='UDP-N-acetylglucosamine--peptide N-acetylglucosaminyltransferase 110 kDa subunit|O-GlcNAc transferase p110 subunit|O-GlcNAc transferase subunit p110|O-linked N-acetylglucosamine (GlcNAc) transferase (UDP-N-acetylglucosamine:polypeptide-N-acetylglucosaminyl transferase)|O-linked N-acetylglucosamine transferase 110 kDa subunit|UDP-N-acetylglucosamine:polypeptide-N-acetylglucosaminyl transferase|uridinediphospho-N-acetylglucosamine:polypeptide beta-N-acetylglucosaminyl transferase', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71533104, end_position_on_the_genomic_accession=71575892, orientation='plus', exon_count=22, OMIM=[300255], no_hdr0=''),
    8476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8476, CurrentID=0, Status='live', Symbol='CDC42BPA', Aliases=['MRCK', 'MRCKA', 'PK428'], description='CDC42 binding protein kinase alpha', other_designations='serine/threonine-protein kinase MRCK alpha|CDC42 binding protein kinase alpha (DMPK-like)|CDC42 binding protein kinase beta|myotonic dystrophy kinase-related CDC42-binding protein kinase alpha|myotonic dystrophy protein kinase-like alpha|ser-thr protein kinase PK428|ser-thr protein kinase related to the myotonic dystrophy protein kinase', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226989858, end_position_on_the_genomic_accession=227318502, orientation='minus', exon_count=42, OMIM=[603412], no_hdr0=''),
    8477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8477, CurrentID=0, Status='live', Symbol='GPR65', Aliases=['TDAG8', 'hTDAG8'], description='G protein-coupled receptor 65', other_designations='psychosine receptor|T-cell death-associated gene 8 protein', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88005135, end_position_on_the_genomic_accession=88014811, orientation='plus', exon_count=2, OMIM=[604620], no_hdr0=''),
    8479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8479, CurrentID=0, Status='live', Symbol='HIRIP3', Aliases=[], description='HIRA interacting protein 3', other_designations='HIRA-interacting protein 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29992321, end_position_on_the_genomic_accession=29996096, orientation='minus', exon_count=7, OMIM=[603365], no_hdr0=''),
    8480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8480, CurrentID=0, Status='live', Symbol='RAE1', Aliases=['Gle2', 'MIG14', 'MRNP41', 'Mnrp41', 'dJ481F12.3', 'dJ800J21.1'], description='ribonucleic acid export 1', other_designations='mRNA export factor|RAE1 RNA export 1 homolog|homolog of yeast Rae1 (Bharathi) mRNA-associated protein of 41 kDa (Kraemer)|mRNA export protein|mRNA-associated protein MRNP 41|mRNA-binding protein, 41-kD|migration-inducing gene 14|rae1 protein homolog', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57351239, end_position_on_the_genomic_accession=57379202, orientation='plus', exon_count=15, OMIM=[603343], no_hdr0=''),
    8481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8481, CurrentID=0, Status='live', Symbol='OFD1', Aliases=['71-7A', 'CXorf5', 'JBTS10', 'RP23', 'SGBS2'], description='OFD1 centriole and centriolar satellite protein', other_designations='oral-facial-digital syndrome 1 protein|Joubert syndrome type 10|protein 71-7A', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13734726, end_position_on_the_genomic_accession=13773978, orientation='plus', exon_count=27, OMIM=[300170], no_hdr0=''),
    8482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8482, CurrentID=0, Status='live', Symbol='SEMA7A', Aliases=['CD108', 'CDw108', 'H-SEMA-K1', 'H-Sema-L', 'JMH', 'SEMAK1', 'SEMAL'], description='semaphorin 7A (John Milton Hagen blood group)', other_designations='semaphorin-7A|JMH blood group antigen|John Milton Hagen blood group H-Sema K1|john-Milton-Hargen human blood group Ag|sema K1|sema L|sema domain, immunoglobulin domain (Ig), and GPI membrane anchor, (semaphorin) 7A (JMH blood group)|sema domain, immunoglobulin domain (Ig), and GPI membrane anchor, 7A|semaphorin 7A, GPI membrane anchor (John Milton Hagen blood group)|semaphorin-K1|semaphorin-L', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74409289, end_position_on_the_genomic_accession=74433958, orientation='minus', exon_count=15, OMIM=[607961], no_hdr0=''),
    8483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8483, CurrentID=0, Status='live', Symbol='CILP', Aliases=['CILP-1', 'HsT18872'], description='cartilage intermediate layer protein', other_designations='cartilage intermediate layer protein 1|cartilage intermediate layer protein 1 C1|cartilage intermediate layer protein 1 C2|cartilage intermediate layer protein, nucleotide pyrophosphohydrolase', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65194760, end_position_on_the_genomic_accession=65213142, orientation='minus', exon_count=10, OMIM=[603489], no_hdr0=''),
    8484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8484, CurrentID=0, Status='live', Symbol='GALR3', Aliases=[], description='galanin receptor 3', other_designations='galanin receptor type 3|GAL3-R|GALR-3|galanin receptor, family member 3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37823382, end_position_on_the_genomic_accession=37825485, orientation='plus', exon_count=2, OMIM=[603692], no_hdr0=''),
    8487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8487, CurrentID=0, Status='live', Symbol='GEMIN2', Aliases=['SIP1', 'SIP1-delta'], description='gem nuclear organelle associated protein 2', other_designations='gem-associated protein 2|SMN interacting protein 1-delta|component of gems 2|gemin-2|survival of motor neuron protein interacting protein 1', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39114261, end_position_on_the_genomic_accession=39136973, orientation='plus', exon_count=10, OMIM=[602595], no_hdr0=''),
    8490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8490, CurrentID=0, Status='live', Symbol='RGS5', Aliases=['MST092', 'MST106', 'MST129', 'MSTP032', 'MSTP092', 'MSTP106', 'MSTP129'], description='regulator of G protein signaling 5', other_designations='regulator of G-protein signaling 5', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=163142299, end_position_on_the_genomic_accession=163321735, orientation='minus', exon_count=9, OMIM=[603276], no_hdr0=''),
    8491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8491, CurrentID=0, Status='live', Symbol='MAP4K3', Aliases=['GLK', 'MAPKKKK3', 'MEKKK 3', 'MEKKK3', 'RAB8IPL1'], description='mitogen-activated protein kinase kinase kinase kinase 3', other_designations='mitogen-activated protein kinase kinase kinase kinase 3|MAPK/ERK kinase kinase kinase 3|MEK kinase kinase 3|germinal center kinase-like kinase|germinal center kinase-related protein kinase', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=39248941, end_position_on_the_genomic_accession=39437312, orientation='minus', exon_count=35, OMIM=[604921], no_hdr0=''),
    8492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8492, CurrentID=0, Status='live', Symbol='PRSS12', Aliases=['BSSP-3', 'BSSP3', 'MRT1'], description='serine protease 12', other_designations='neurotrypsin|brain-specific serine protease 3|leydin|protease, serine 12|protease, serine, 12 (neurotrypsin, motopsin)', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=118280038, end_position_on_the_genomic_accession=118353042, orientation='minus', exon_count=15, OMIM=[606709], no_hdr0=''),
    8493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8493, CurrentID=0, Status='live', Symbol='PPM1D', Aliases=['IDDGIP', 'JDVS', 'PP2C-DELTA', 'WIP1'], description='protein phosphatase, Mg2+/Mn2+ dependent 1D', other_designations='protein phosphatase 1D|protein phosphatase Wip1|wild-type p53-induced phosphatase 1', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60600187, end_position_on_the_genomic_accession=60666280, orientation='plus', exon_count=7, OMIM=[605100], no_hdr0=''),
    8495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8495, CurrentID=0, Status='live', Symbol='PPFIBP2', Aliases=['Cclp1'], description='PPFIA binding protein 2', other_designations='liprin-beta-2|PTPRF interacting protein, binding protein 2 (liprin beta 2)|liprin beta 2|protein tyrosine phosphatase receptor type f polypeptide-interacting protein-binding protein 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7513937, end_position_on_the_genomic_accession=7666642, orientation='plus', exon_count=38, OMIM=[603142], no_hdr0=''),
    8496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8496, CurrentID=0, Status='live', Symbol='PPFIBP1', Aliases=['L2', 'SGT2', 'hSGT2', 'hSgt2p'], description='PPFIA binding protein 1', other_designations='liprin-beta-1|PTPRF interacting protein, binding protein 1 (liprin beta 1)|PTPRF-interacting protein-binding protein 1|liprin related protein|protein-tyrosine phosphatase receptor-type f polypeptide-interacting protein-binding protein 1', map_location='12p11.23-p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27524126, end_position_on_the_genomic_accession=27695564, orientation='plus', exon_count=34, OMIM=[603141], no_hdr0=''),
    8497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8497, CurrentID=0, Status='live', Symbol='PPFIA4', Aliases=[], description='PTPRF interacting protein alpha 4', other_designations='liprin-alpha-4|protein tyrosine phosphatase, receptor type, f polypeptide (PTPRF), interacting protein (liprin), alpha 4', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203026491, end_position_on_the_genomic_accession=203078736, orientation='plus', exon_count=31, OMIM=[603145], no_hdr0=''),
    8498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8498, CurrentID=0, Status='live', Symbol='RANBP3', Aliases=[], description='RAN binding protein 3', other_designations='ran-binding protein 3|epididymis secretory sperm binding protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5916139, end_position_on_the_genomic_accession=5978140, orientation='minus', exon_count=19, OMIM=[603327], no_hdr0=''),
    8499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8499, CurrentID=0, Status='live', Symbol='PPFIA2', Aliases=[], description='PTPRF interacting protein alpha 2', other_designations='liprin-alpha-2|protein tyrosine phosphatase, receptor type, f polypeptide (PTPRF), interacting protein (liprin), alpha 2', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=81257975, end_position_on_the_genomic_accession=81759749, orientation='minus', exon_count=41, OMIM=[603143], no_hdr0=''),
    8500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8500, CurrentID=0, Status='live', Symbol='PPFIA1', Aliases=['LIP.1', 'LIP1', 'LIPRIN'], description='PTPRF interacting protein alpha 1', other_designations='liprin-alpha-1|LAR-interacting protein 1|LIP-1|Liprin-alpha1|protein tyrosine phosphatase receptor type f polypeptide-interacting protein alpha-1|protein tyrosine phosphatase, receptor type, f polypeptide (PTPRF), interacting protein (liprin), alpha 1', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=70270687, end_position_on_the_genomic_accession=70384405, orientation='plus', exon_count=36, OMIM=[611054], no_hdr0=''),
    8501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8501, CurrentID=0, Status='live', Symbol='SLC43A1', Aliases=['LAT3', 'PB39', 'POV1', 'R00504'], description='solute carrier family 43 member 1', other_designations='large neutral amino acids transporter small subunit 3|L-type amino acid transporter 3|prostate cancer overexpressed gene 1 protein|solute carrier family 43 (amino acid system L transporter), member 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57484531, end_position_on_the_genomic_accession=57516561, orientation='minus', exon_count=18, OMIM=[603733], no_hdr0=''),
    8502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8502, CurrentID=0, Status='live', Symbol='PKP4', Aliases=['p0071'], description='plakophilin 4', other_designations='plakophilin-4|catenin 4', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=158456952, end_position_on_the_genomic_accession=158681429, orientation='plus', exon_count=28, OMIM=[604276], no_hdr0=''),
    8503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8503, CurrentID=0, Status='live', Symbol='PIK3R3', Aliases=['p55', 'p55-GAMMA', 'p55PIK'], description='phosphoinositide-3-kinase regulatory subunit 3', other_designations='phosphatidylinositol 3-kinase regulatory subunit gamma|PI3-kinase regulatory subunit gamma|PI3-kinase subunit p55-gamma|PI3K regulatory subunit gamma|phosphatidylinositol 3-kinase 55 kDa regulatory subunit gamma|phosphatidylinositol 3-kinase, regulatory subunit, polypeptide 3 (p55, gamma)|phosphoinositide-3-kinase, regulatory subunit 3 (gamma)|ptdIns-3-kinase regulatory subunit p55-gamma', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46040140, end_position_on_the_genomic_accession=46174901, orientation='minus', exon_count=14, OMIM=[606076], no_hdr0=''),
    8504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8504, CurrentID=0, Status='live', Symbol='PEX3', Aliases=['PBD10A', 'PBD10B', 'TRG18'], description='peroxisomal biogenesis factor 3', other_designations='peroxisomal biogenesis factor 3|peroxin-3|peroxisomal assembly protein PEX3|transformation-related protein 18', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143450805, end_position_on_the_genomic_accession=143490616, orientation='plus', exon_count=12, OMIM=[603164], no_hdr0=''),
    8505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8505, CurrentID=0, Status='live', Symbol='PARG', Aliases=['PARG99'], description='poly(ADP-ribose) glycohydrolase', other_designations='poly(ADP-ribose) glycohydrolase|mitochondrial poly(ADP-ribose) glycohydrolase', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49818279, end_position_on_the_genomic_accession=49942027, orientation='minus', exon_count=21, OMIM=[603501], no_hdr0=''),
    8506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8506, CurrentID=0, Status='live', Symbol='CNTNAP1', Aliases=['CASPR', 'CHN3', 'CNTNAP', 'NRXN4', 'P190'], description='contactin associated protein 1', other_designations='contactin-associated protein 1|caspr1|neurexin IV|neurexin-4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42679767, end_position_on_the_genomic_accession=42699993, orientation='plus', exon_count=25, OMIM=[602346], no_hdr0=''),
    8507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8507, CurrentID=0, Status='live', Symbol='ENC1', Aliases=['CCL28', 'ENC-1', 'KLHL35', 'KLHL37', 'NRPB', 'PIG10', 'TP53I10'], description='ectodermal-neural cortex 1', other_designations='ectoderm-neural cortex protein 1|ectodermal-neural cortex 1 (with BTB domain)|ectodermal-neural cortex 1 (with BTB-like domain)|kelch-like 35|kelch-like family member 37|kelch-like protein 37|nuclear matrix protein NRP/B|nuclear restricted protein, BTB domain-like (brain)|p53-induced gene 10 protein|tumor protein p53 inducible protein 10', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=74627409, end_position_on_the_genomic_accession=74640728, orientation='minus', exon_count=4, OMIM=[605173], no_hdr0=''),
    8508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8508, CurrentID=0, Status='live', Symbol='NIPSNAP1', Aliases=[], description='nipsnap homolog 1', other_designations='protein NipSnap homolog 1|4-nitrophenylphosphatase domain and non-neuronal SNAP25-like 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29554808, end_position_on_the_genomic_accession=29581113, orientation='minus', exon_count=10, OMIM=[603249], no_hdr0=''),
    8509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8509, CurrentID=0, Status='live', Symbol='NDST2', Aliases=['HSST2', 'N-HSST 2', 'NST2'], description='N-deacetylase and N-sulfotransferase 2', other_designations='bifunctional heparan sulfate N-deacetylase/N-sulfotransferase 2|N-deacetylase/N-sulfotransferase (heparan glucosaminyl) 2|N-heparan sulfate sulfotransferase 2|glucosaminyl N-deacetylase/N-sulfotransferase 2', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73801916, end_position_on_the_genomic_accession=73811820, orientation='minus', exon_count=16, OMIM=[603268], no_hdr0=''),
    8510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8510, CurrentID=0, Status='live', Symbol='MMP23B', Aliases=['MIFR', 'MIFR-1', 'MMP22', 'MMP23A'], description='matrix metallopeptidase 23B', other_designations='matrix metalloproteinase-23|MMP-21|MMP-22|MMP-23|femalysin|matrix metalloproteinase 22|matrix metalloproteinase 23B|matrix metalloproteinase in the female reproductive tract|matrix metalloproteinase-21', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1631681, end_position_on_the_genomic_accession=1635638, orientation='plus', exon_count=8, OMIM=[603321], no_hdr0=''),
    8513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8513, CurrentID=0, Status='live', Symbol='LIPF', Aliases=['GL', 'HGL', 'HLAL'], description='lipase F, gastric type', other_designations='gastric triacylglycerol lipase|gastric lipase|lipase, gastric', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88664442, end_position_on_the_genomic_accession=88678815, orientation='plus', exon_count=11, OMIM=[601980], no_hdr0=''),
    8514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8514, CurrentID=0, Status='live', Symbol='KCNAB2', Aliases=['AKR6A5', 'HKvbeta2', 'HKvbeta2.1', 'HKvbeta2.2', 'KCNA2B', 'KV-BETA-2'], description='potassium voltage-gated channel subfamily A regulatory beta subunit 2', other_designations='voltage-gated potassium channel subunit beta-2|K(+) channel subunit beta-2|potassium channel, voltage gated subfamily A regulatory beta subunit 2|potassium voltage-gated channel, shaker-related subfamily, beta member 2', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=5992639, end_position_on_the_genomic_accession=6101186, orientation='plus', exon_count=21, OMIM=[601142], no_hdr0=''),
    8515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8515, CurrentID=0, Status='live', Symbol='ITGA10', Aliases=['PRO827'], description='integrin subunit alpha 10', other_designations='integrin alpha-10', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145891208, end_position_on_the_genomic_accession=145910050, orientation='minus', exon_count=29, OMIM=[604042], no_hdr0=''),
    8516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8516, CurrentID=0, Status='live', Symbol='ITGA8', Aliases=[], description='integrin subunit alpha 8', other_designations='integrin alpha-8|integrin, alpha 8', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15513954, end_position_on_the_genomic_accession=15720329, orientation='minus', exon_count=31, OMIM=[604063], no_hdr0=''),
    8517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8517, CurrentID=0, Status='live', Symbol='IKBKG', Aliases=['AMCBX1', 'EDAID1', 'FIP-3', 'FIP3', 'Fip3p', 'IKK-gamma', 'IKKAP1', 'IKKG', 'IMD33', 'IP', 'IP1', 'IP2', 'IPD2', 'NEMO', 'ZC2HC9'], description='inhibitor of nuclear factor kappa B kinase regulatory subunit gamma', other_designations='NF-kappa-B essential modulator|I-kappa-B kinase subunit gamma|NF-kappa-B essential modifier|ikB kinase subunit gamma|ikB kinase-associated protein 1|incontinentia pigmenti|inhibitor of kappa light polypeptide gene enhancer in B-cells, kinase gamma|inhibitor of nuclear factor kappa B kinase subunit gamma', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154541238, end_position_on_the_genomic_accession=154565046, orientation='plus', exon_count=13, OMIM=[300248], no_hdr0=''),
    8518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8518, CurrentID=0, Status='live', Symbol='ELP1', Aliases=['DYS', 'FD', 'IKAP', 'IKBKAP', 'IKI3', 'TOT1'], description='elongator acetyltransferase complex subunit 1', other_designations='elongator complex protein 1|IKK complex-associated protein|ikappaB kinase complex-associated protein|inhibitor of kappa light polypeptide gene enhancer in B-cells, kinase complex-associated protein', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=108867517, end_position_on_the_genomic_accession=108934135, orientation='minus', exon_count=37, OMIM=[603722], no_hdr0=''),
    8519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8519, CurrentID=0, Status='live', Symbol='IFITM1', Aliases=['9-27', 'CD225', 'DSPA2a', 'IFI17', 'LEU13'], description='interferon induced transmembrane protein 1', other_designations='interferon-induced transmembrane protein 1|dispanin subfamily A member 2a|interferon-induced protein 17|interferon-inducible protein 9-27|leu-13 antigen', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=314040, end_position_on_the_genomic_accession=315272, orientation='plus', exon_count=2, OMIM=[604456], no_hdr0=''),
    8520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8520, CurrentID=0, Status='live', Symbol='HAT1', Aliases=['KAT1'], description='histone acetyltransferase 1', other_designations='histone acetyltransferase type B catalytic subunit', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171922425, end_position_on_the_genomic_accession=171983686, orientation='plus', exon_count=12, OMIM=[603053], no_hdr0=''),
    8521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8521, CurrentID=0, Status='live', Symbol='GCM1', Aliases=['GCMA', 'hGCMa'], description='glial cells missing transcription factor 1', other_designations='chorion-specific transcription factor GCMa|GCM motif protein 1|glial cells missing homolog 1', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53126961, end_position_on_the_genomic_accession=53262803, orientation='minus', exon_count=11, OMIM=[603715], no_hdr0=''),
    8522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8522, CurrentID=0, Status='live', Symbol='GAS7', Aliases=[], description='growth arrest specific 7', other_designations='growth arrest-specific protein 7', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9910606, end_position_on_the_genomic_accession=10198606, orientation='minus', exon_count=21, OMIM=[603127], no_hdr0=''),
    8525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8525, CurrentID=0, Status='live', Symbol='DGKZ', Aliases=['DAGK5', 'DAGK6', 'DGK-ZETA', 'hDGKzeta'], description='diacylglycerol kinase zeta', other_designations='diacylglycerol kinase zeta|DAG kinase zeta|diacylglycerol kinase, zeta 104kDa|diglyceride kinase zeta', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46332926, end_position_on_the_genomic_accession=46380554, orientation='plus', exon_count=35, OMIM=[601441], no_hdr0=''),
    8526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8526, CurrentID=0, Status='live', Symbol='DGKE', Aliases=['AHUS7', 'DAGK5', 'DAGK6', 'DGK', 'NPHS7'], description='diacylglycerol kinase epsilon', other_designations='diacylglycerol kinase epsilon|DAG kinase epsilon|DGK-epsilon|diacylglycerol kinase, epsilon 64kDa|diglyceride kinase epsilon', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56834131, end_position_on_the_genomic_accession=56869567, orientation='plus', exon_count=14, OMIM=[601440], no_hdr0=''),
    8527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8527, CurrentID=0, Status='live', Symbol='DGKD', Aliases=['DGK-delta', 'DGKdelta', 'dgkd-2'], description='diacylglycerol kinase delta', other_designations='diacylglycerol kinase delta|DAG kinase delta|diacylglycerol kinase, delta 130kDa|diglyceride kinase delta', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233354494, end_position_on_the_genomic_accession=233472098, orientation='plus', exon_count=40, OMIM=[601826], no_hdr0=''),
    8528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8528, CurrentID=0, Status='live', Symbol='DDO', Aliases=['DASOX-1', 'DDO-2', 'DDO'], description='D-aspartate oxidase', other_designations='D-aspartate oxidase|D-aspartate oxidase, DDO|aspartic oxidase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110388321, end_position_on_the_genomic_accession=110415575, orientation='minus', exon_count=8, OMIM=[124450], no_hdr0=''),
    8529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8529, CurrentID=0, Status='live', Symbol='CYP4F2', Aliases=['CPF2'], description='cytochrome P450 family 4 subfamily F member 2', other_designations='cytochrome P450 4F2|20-HETE synthase|20-hydroxyeicosatetraenoic acid synthase|CYPIVF2|arachidonic acid omega-hydroxylase|cytochrome P450, family 4, subfamily F, polypeptide 2|cytochrome P450, subfamily IVF, polypeptide 2|cytochrome P450-LTB-omega|docosahexaenoic acid omega-hydroxylase|leukotriene-B(4) 20-monooxygenase 1|leukotriene-B(4) omega-hydroxylase 1|phylloquinone omega-hydroxylase CYP4F2', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15878023, end_position_on_the_genomic_accession=15898074, orientation='minus', exon_count=13, OMIM=[604426], no_hdr0=''),
    8530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8530, CurrentID=0, Status='live', Symbol='CST7', Aliases=['CMAP'], description='cystatin F', other_designations='cystatin-F|cystatin-7|cystatin-like metastasis-associated protein|leukocystatin', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=24949269, end_position_on_the_genomic_accession=24959928, orientation='plus', exon_count=4, OMIM=[603253], no_hdr0=''),
    8531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8531, CurrentID=0, Status='live', Symbol='YBX3', Aliases=['CSDA', 'CSDA1', 'DBPA', 'ZONAB'], description='Y-box binding protein 3', other_designations='Y-box-binding protein 3|DNA-binding protein A|ZO-1-associated nucleic acid-binding protein|cold shock domain-containing protein A|cold-shock domain containing A1|cold-shock domain protein A|single-strand DNA-binding protein NF-GMB', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10699084, end_position_on_the_genomic_accession=10723442, orientation='minus', exon_count=11, OMIM=[603437], no_hdr0=''),
    8532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8532, CurrentID=0, Status='live', Symbol='CPZ', Aliases=[], description='carboxypeptidase Z', other_designations='carboxypeptidase Z|VEZT/CPZ fusion|epididymis secretory sperm binding protein|metallocarboxypeptidase Z', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8592765, end_position_on_the_genomic_accession=8619752, orientation='plus', exon_count=11, OMIM=[603105], no_hdr0=''),
    8533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8533, CurrentID=0, Status='live', Symbol='COPS3', Aliases=['CSN3', 'SGN3'], description='COP9 signalosome subunit 3', other_designations='COP9 signalosome complex subunit 3|COP9 complex subunit 3|COP9 constitutive photomorphogenic homolog subunit 3|JAB1-containing signalosome subunit 3|signalosome subunit 3', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17246616, end_position_on_the_genomic_accession=17281303, orientation='minus', exon_count=13, OMIM=[604665], no_hdr0=''),
    8534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8534, CurrentID=0, Status='live', Symbol='CHST1', Aliases=['C6ST', 'GST-1', 'KS6ST', 'KSGal6ST', 'KSST'], description='carbohydrate sulfotransferase 1', other_designations='carbohydrate sulfotransferase 1|Keratan sulfotransferase|carbohydrate (chondroitin 6/keratan) sulfotransferase 1|carbohydrate (keratan sulfate Gal-6) sulfotransferase 1|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45647689, end_position_on_the_genomic_accession=45665651, orientation='minus', exon_count=5, OMIM=[603797], no_hdr0=''),
    8535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8535, CurrentID=0, Status='live', Symbol='CBX4', Aliases=['NBP16', 'PC2'], description='chromobox 4', other_designations='E3 SUMO-protein ligase CBX4|NS5ATP1-binding protein 16|Pc class 2 homolog|chromobox homolog 4 (Pc class homolog, Drosophila)|chromobox protein homolog 4|chromobox-like protein 4|polycomb 2 homolog', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79833156, end_position_on_the_genomic_accession=79839440, orientation='minus', exon_count=6, OMIM=[603079], no_hdr0=''),
    8536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8536, CurrentID=0, Status='live', Symbol='CAMK1', Aliases=['CAMKI'], description='calcium/calmodulin dependent protein kinase I', other_designations='calcium/calmodulin-dependent protein kinase type 1|caM kinase I alpha|caM-KI|caMKI-alpha', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9757345, end_position_on_the_genomic_accession=9769987, orientation='minus', exon_count=13, OMIM=[604998], no_hdr0=''),
    8537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8537, CurrentID=0, Status='live', Symbol='BCAS1', Aliases=['AIBC1', 'NABC1', 'PMES-2'], description='brain enriched myelin associated protein 1', other_designations='breast carcinoma-amplified sequence 1|amplified and overexpressed in breast cancer|breast carcinoma amplified sequence 1|novel amplified in breast cancer 1|protein having mRNA enriched in synaptosomes 2', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=53943541, end_position_on_the_genomic_accession=54070594, orientation='minus', exon_count=14, OMIM=[602968], no_hdr0=''),
    8538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8538, CurrentID=0, Status='live', Symbol='BARX2', Aliases=[], description='BARX homeobox 2', other_designations='homeobox protein BarH-like 2|BarH-like homeobox 2', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=129375237, end_position_on_the_genomic_accession=129452279, orientation='plus', exon_count=6, OMIM=[604823], no_hdr0=''),
    8539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8539, CurrentID=0, Status='live', Symbol='API5', Aliases=['AAC-11', 'AAC11'], description='apoptosis inhibitor 5', other_designations='apoptosis inhibitor 5|FIF|antiapoptosis clone 11 protein|cell migration-inducing gene 8 protein|fibroblast growth factor 2-interacting factor 2|migration-inducing protein MIG8', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=43311970, end_position_on_the_genomic_accession=43344530, orientation='plus', exon_count=15, OMIM=[609774], no_hdr0=''),
    8540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8540, CurrentID=0, Status='live', Symbol='AGPS', Aliases=['ADAP-S', 'ADAS', 'ADHAPS', 'ADPS', 'ALDHPSY', 'RCDP3'], description='alkylglycerone phosphate synthase', other_designations='alkyldihydroxyacetonephosphate synthase, peroxisomal|aging-associated gene 5 protein|aging-associated protein 5|alkyl-DHAP synthase', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177392773, end_position_on_the_genomic_accession=177543834, orientation='plus', exon_count=21, OMIM=[603051], no_hdr0=''),
    8541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8541, CurrentID=0, Status='live', Symbol='PPFIA3', Aliases=['LPNA3'], description='PTPRF interacting protein alpha 3', other_designations='liprin-alpha-3|liprin|protein tyrosine phosphatase receptor type f polypeptide-interacting protein alpha-3|protein tyrosine phosphatase, receptor type, f polypeptide (PTPRF), interacting protein (liprin), alpha 3|protein tyrosine phosphatase, receptor type, f polypeptide, alpha 3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49119389, end_position_on_the_genomic_accession=49151030, orientation='plus', exon_count=30, OMIM=[603144], no_hdr0=''),
    8542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8542, CurrentID=0, Status='live', Symbol='APOL1', Aliases=['APO-L', 'APOL', 'APOL-I', 'FSGS4'], description='apolipoprotein L1', other_designations='apolipoprotein L1|apolipoprotein L 1|apolipoprotein L1-B3', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36253071, end_position_on_the_genomic_accession=36267531, orientation='plus', exon_count=8, OMIM=[603743], no_hdr0=''),
    8543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8543, CurrentID=0, Status='live', Symbol='LMO4', Aliases=[], description='LIM domain only 4', other_designations='LIM domain transcription factor LMO4|LIM domain only protein 4|LIM-only 4 protein|LMO-4|breast tumor autoantigen', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=87328880, end_position_on_the_genomic_accession=87348923, orientation='plus', exon_count=6, OMIM=[603129], no_hdr0=''),
    8544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8544, CurrentID=0, Status='live', Symbol='PIR', Aliases=[], description='pirin', other_designations='pirin|pirin (iron-binding nuclear protein)|probable quercetin 2,3-dioxygenase PIR|probable quercetinase', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15384799, end_position_on_the_genomic_accession=15493333, orientation='minus', exon_count=10, OMIM=[300931], no_hdr0=''),
    8545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8545, CurrentID=0, Status='live', Symbol='CGGBP1', Aliases=['CGGBP', 'p20-CGGBP'], description='CGG triplet repeat binding protein 1', other_designations='CGG triplet repeat-binding protein 1|20 kDa CGG-binding protein|CGG-binding protein 1|p20-CGG binding protein|p20-CGGBP DNA-binding protein', map_location='3p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=88051950, end_position_on_the_genomic_accession=88149870, orientation='minus', exon_count=6, OMIM=[603363], no_hdr0=''),
    8546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8546, CurrentID=0, Status='live', Symbol='AP3B1', Aliases=['ADTB3', 'ADTB3A', 'HPS', 'HPS2', 'PE'], description='adaptor related protein complex 3 subunit beta 1', other_designations='AP-3 complex subunit beta-1|AP-3 complex beta-3A subunit|adaptor protein complex AP-3 subunit beta-1|adaptor related protein complex 3 beta 1 subunit|beta-3A|beta-3A-adaptin|clathrin assembly protein complex 3 beta-1 large chain', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=78000522, end_position_on_the_genomic_accession=78294704, orientation='minus', exon_count=29, OMIM=[603401], no_hdr0=''),
    8547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8547, CurrentID=0, Status='live', Symbol='FCN3', Aliases=['FCNH', 'HAKA1'], description='ficolin 3', other_designations='ficolin-3|H-ficolin|collagen/fibrinogen domain-containing lectin 3 p35|collagen/fibrinogen domain-containing protein 3|ficolin (collagen/fibrinogen domain containing) 3 (Hakata antigen)', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27369110, end_position_on_the_genomic_accession=27374852, orientation='minus', exon_count=8, OMIM=[604973], no_hdr0=''),
    8548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8548, CurrentID=0, Status='live', Symbol='BLZF1', Aliases=['GOLGIN-45', 'JEM-1', 'JEM-1s', 'JEM1'], description='basic leucine zipper nuclear factor 1', other_designations='golgin-45|JEM-1short protein|cytoplasmic protein|leucine zipper nuclear factor|p45 basic leucine-zipper nuclear factor', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169368195, end_position_on_the_genomic_accession=169396575, orientation='plus', exon_count=8, OMIM=[608692], no_hdr0=''),
    8549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8549, CurrentID=0, Status='live', Symbol='LGR5', Aliases=['FEX', 'GPR49', 'GPR67', 'GRP49', 'HG38'], description='leucine rich repeat containing G protein-coupled receptor 5', other_designations='leucine-rich repeat-containing G-protein coupled receptor 5|G-protein coupled receptor 49|G-protein coupled receptor 67|G-protein coupled receptor HG38|orphan G protein-coupled receptor HG38', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71439798, end_position_on_the_genomic_accession=71586310, orientation='plus', exon_count=19, OMIM=[606667], no_hdr0=''),
    8550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8550, CurrentID=0, Status='live', Symbol='MAPKAPK5', Aliases=['MAPKAP-K5', 'MK-5', 'MK5', 'PRAK'], description='MAPK activated protein kinase 5', other_designations='MAP kinase-activated protein kinase 5|MAPKAP kinase 5|MAPKAPK-5|mitogen-activated protein kinase-activated protein kinase 5|p38-regulated/activated protein kinase', map_location='12q24.12-q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111842228, end_position_on_the_genomic_accession=111902222, orientation='plus', exon_count=16, OMIM=[606723], no_hdr0=''),
    8553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8553, CurrentID=0, Status='live', Symbol='BHLHE40', Aliases=['BHLHB2', 'Clast5', 'DEC1', 'HLHB2', 'SHARP-2', 'SHARP2', 'STRA13', 'Stra14'], description='basic helix-loop-helix family member e40', other_designations='class E basic helix-loop-helix protein 40|basic helix-loop-helix domain containing, class B, 2|class B basic helix-loop-helix protein 2|differentially expressed in chondrocytes 1|differentially expressed in chondrocytes protein 1|differentiated embryo chondrocyte expressed gene 1|enhancer-of-split and hairy-related protein 2|stimulated by retinoic acid gene 13 protein', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=4979420, end_position_on_the_genomic_accession=4985323, orientation='plus', exon_count=5, OMIM=[604256], no_hdr0=''),
    8554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8554, CurrentID=0, Status='live', Symbol='PIAS1', Aliases=['DDXBP1', 'GBP', 'GU/RH-II', 'ZMIZ3'], description='protein inhibitor of activated STAT 1', other_designations='E3 SUMO-protein ligase PIAS1|AR interacting protein|DEAD/H (Asp-Glu-Ala-Asp/His) box binding protein 1|DEAD/H box-binding protein 1|E3 SUMO-protein transferase PIAS1|RNA helicase II-binding protein|gu-binding protein|protein inhibitor of activated STAT protein 1|zinc finger, MIZ-type containing 3', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68054315, end_position_on_the_genomic_accession=68193847, orientation='plus', exon_count=20, OMIM=[603566], no_hdr0=''),
    8555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8555, CurrentID=0, Status='live', Symbol='CDC14B', Aliases=['CDC14B3', 'Cdc14B1', 'Cdc14B2', 'hCDC14B'], description='cell division cycle 14B', other_designations='dual specificity protein phosphatase CDC14B|CDC14 cell division cycle 14 homolog B', map_location='9q22.32-q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96492743, end_position_on_the_genomic_accession=96619843, orientation='minus', exon_count=24, OMIM=[603505], no_hdr0=''),
    8556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8556, CurrentID=0, Status='live', Symbol='CDC14A', Aliases=['DFNB105', 'DFNB32', 'DFNB35', 'cdc14', 'hCDC14'], description='cell division cycle 14A', other_designations='dual specificity protein phosphatase CDC14A|CDC10 (cell division cycle 10, S. cerevisiae, homolog)|CDC14 cell division cycle 14 homolog A', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100345001, end_position_on_the_genomic_accession=100520277, orientation='plus', exon_count=18, OMIM=[603504], no_hdr0=''),
    8557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8557, CurrentID=0, Status='live', Symbol='TCAP', Aliases=['CMD1N', 'CMH25', 'LGMD2G', 'LGMDR7', 'T-cap', 'TELE', 'telethonin'], description='titin-cap', other_designations='telethonin|19 kDa sarcomeric protein|limb girdle muscular dystrophy 2G (autosomal recessive)|teneurin C-terminal associated peptide|titin cap protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39665349, end_position_on_the_genomic_accession=39666554, orientation='plus', exon_count=2, OMIM=[604488], no_hdr0=''),
    8558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8558, CurrentID=0, Status='live', Symbol='CDK10', Aliases=['ALSAS', 'PISSLRE'], description='cyclin dependent kinase 10', other_designations='cyclin-dependent kinase 10|CDC2-related protein kinase|cell division protein kinase 10|cyclin-dependent kinase (CDC2-like) 10|cyclin-dependent kinase related protein|serine/threonine protein kinase PISSLRE', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89686612, end_position_on_the_genomic_accession=89696354, orientation='plus', exon_count=16, OMIM=[603464], no_hdr0=''),
    8559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8559, CurrentID=0, Status='live', Symbol='PRPF18', Aliases=['PRP18', 'hPrp18'], description='pre-mRNA processing factor 18', other_designations='pre-mRNA-splicing factor 18|PRP18 homolog|PRP18 pre-mRNA processing factor 18 homolog|PRP18 pre-mRNA processing factor 18 homolog(PRPF18)', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13586811, end_position_on_the_genomic_accession=13645344, orientation='plus', exon_count=12, OMIM=[604993], no_hdr0=''),
    8560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8560, CurrentID=0, Status='live', Symbol='DEGS1', Aliases=['DEGS', 'DEGS-1', 'DES1', 'Des-1', 'FADS7', 'HLD18', 'MIG15', 'MLD'], description='delta 4-desaturase, sphingolipid 1', other_designations='sphingolipid delta(4)-desaturase DES1|cell migration-inducing gene 15 protein|degenerative spermatocyte homolog 1, lipid desaturase|degenerative spermatocyte homolog, lipid desaturase|dihydroceramide desaturase 1|membrane fatty acid (lipid) desaturase|membrane lipid desaturase|migration-inducing gene 15 protein|sphingolipid delta 4 desaturase|sphingolipid delta(4)-desaturase 1', map_location='1q42.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224183240, end_position_on_the_genomic_accession=224193441, orientation='plus', exon_count=5, OMIM=[615843], no_hdr0=''),
    8562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8562, CurrentID=0, Status='live', Symbol='DENR', Aliases=['DRP', 'DRP1', 'SMAP-3'], description='density regulated re-initiation and release factor', other_designations='density-regulated protein|smooth muscle cell associated protein-3', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122752824, end_position_on_the_genomic_accession=122771064, orientation='plus', exon_count=8, OMIM=[604550], no_hdr0=''),
    8563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8563, CurrentID=0, Status='live', Symbol='THOC5', Aliases=['C22orf19', 'Fmip', 'PK1.3', 'fSAP79'], description='THO complex 5', other_designations='THO complex subunit 5 homolog|Fms-interacting protein|NF2/meningioma region protein pK1.3|PP39.2|functional spliceosome-associated protein 79|hTREX90|placental protein 39.2', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29505879, end_position_on_the_genomic_accession=29553760, orientation='minus', exon_count=23, OMIM=[612733], no_hdr0=''),
    8564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8564, CurrentID=0, Status='live', Symbol='KMO', Aliases=['dJ317G22.1'], description='kynurenine 3-monooxygenase', other_designations='kynurenine 3-monooxygenase|kynurenine 3-hydroxylase', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241531883, end_position_on_the_genomic_accession=241595642, orientation='plus', exon_count=17, OMIM=[603538], no_hdr0=''),
    8565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8565, CurrentID=0, Status='live', Symbol='YARS1', Aliases=['CMTDIC', 'IMNEPD2', 'TYRRS', 'YARS', 'YRS', 'YTS'], description='tyrosyl-tRNA synthetase 1', other_designations='tyrosine--tRNA ligase, cytoplasmic|tyrosine tRNA ligase 1, cytoplasmic|tyrosyl--tRNA ligase|tyrosyl-tRNA synthetase, cytoplasmic', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32775238, end_position_on_the_genomic_accession=32817385, orientation='minus', exon_count=14, OMIM=[603623], no_hdr0=''),
    8566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8566, CurrentID=0, Status='live', Symbol='PDXK', Aliases=['C21orf124', 'C21orf97', 'HEL-S-1a', 'HMSN6C', 'PKH', 'PNK', 'PRED79'], description='pyridoxal kinase', other_designations='pyridoxal kinase|epididymis secretory sperm binding protein Li 1a|pyridoxal (pyridoxine, vitamin B6) kinase|pyridoxamine kinase|pyridoxine kinase|vitamin B6 kinase', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43719129, end_position_on_the_genomic_accession=43762299, orientation='plus', exon_count=19, OMIM=[179020], no_hdr0=''),
    8567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8567, CurrentID=0, Status='live', Symbol='MADD', Aliases=['DEEAH', 'DENN', 'IG20', 'NEDDISH', 'RAB3GEP', 'RabGEF'], description='MAP kinase activating death domain', other_designations='MAP kinase-activating death domain protein|Rab3 GDP/GTP exchange factor|differentially expressed in normal and neoplastic cells|insulinoma glucagonoma clone 20|rab3 GDP/GTP exchange protein', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47269188, end_position_on_the_genomic_accession=47330031, orientation='plus', exon_count=42, OMIM=[603584], no_hdr0=''),
    8568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8568, CurrentID=0, Status='live', Symbol='RRP1', Aliases=['D21S2056E', 'NNP-1', 'NOP52A', 'RRP1'], description='ribosomal RNA processing 1', other_designations='ribosomal RNA processing protein 1 homolog A|Nnp1 homolog, nucleolar protein|RRP1-like protein|novel nuclear protein 1|nucleolar protein Nop52|protein NNP-1|ribosomal RNA processing 1 homolog', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43789551, end_position_on_the_genomic_accession=43805293, orientation='plus', exon_count=14, OMIM=[610653], no_hdr0=''),
    8569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8569, CurrentID=0, Status='live', Symbol='MKNK1', Aliases=['MNK1'], description='MAPK interacting serine/threonine kinase 1', other_designations='MAP kinase-interacting serine/threonine-protein kinase 1|MAP kinase interacting serine/threonine kinase 1|MAP kinase signal-integrating kinase 1|MAPK signal-integrating kinase 1', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46557407, end_position_on_the_genomic_accession=46604311, orientation='minus', exon_count=17, OMIM=[606724], no_hdr0=''),
    8570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8570, CurrentID=0, Status='live', Symbol='KHSRP', Aliases=['FBP2', 'FUBP2', 'KSRP', 'p75'], description='KH-type splicing regulatory protein', other_designations='far upstream element-binding protein 2|FUSE-binding protein 2|epididymis secretory sperm binding protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6413102, end_position_on_the_genomic_accession=6424811, orientation='minus', exon_count=20, OMIM=[603445], no_hdr0=''),
    8572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8572, CurrentID=0, Status='live', Symbol='PDLIM4', Aliases=['RIL'], description='PDZ and LIM domain 4', other_designations='PDZ and LIM domain protein 4|LIM domain protein|LIM protein RIL|enigma homolog|reversion-induced LIM protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132257671, end_position_on_the_genomic_accession=132273454, orientation='plus', exon_count=7, OMIM=[603422], no_hdr0=''),
    8573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8573, CurrentID=0, Status='live', Symbol='CASK', Aliases=['CAGH39', 'CAMGUK', 'CMG', 'FGS4', 'LIN2', 'MICPCH', 'MRXSNA', 'TNRC8', 'hCASK'], description='calcium/calmodulin dependent serine protein kinase', other_designations='peripheral plasma membrane protein CASK|calcium/calmodulin-dependent serin protein kinase|calcium/calmodulin-dependent serine protein kinase (MAGUK family)|calcium/calmodulin-dependent serine protein kinase membrane-associated guanylate kinase|protein lin-2 homolog|trinucleotide repeat containing 8', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41514934, end_position_on_the_genomic_accession=41923554, orientation='minus', exon_count=28, OMIM=[300172], no_hdr0=''),
    8574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8574, CurrentID=0, Status='live', Symbol='AKR7A2', Aliases=['AFAR', 'AFAR1', 'AFB1-AR1', 'AKR7'], description='aldo-keto reductase family 7 member A2', other_designations='aflatoxin B1 aldehyde reductase member 2|AFB1 aldehyde reductase 1|AFB1-AR 1|HEL-S-166mP|SSA reductase|aflatoxin aldehyde reductase|aflatoxin beta1 aldehyde reductase|aldoketoreductase 7|epididymis secretory sperm binding protein Li 166mP|succinic semialdehyde reductase', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19302708, end_position_on_the_genomic_accession=19312146, orientation='minus', exon_count=7, OMIM=[603418], no_hdr0=''),
    8575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8575, CurrentID=0, Status='live', Symbol='PRKRA', Aliases=['DYT16', 'HSD14', 'PACT', 'RAX'], description='protein activator of interferon induced protein kinase EIF2AK2', other_designations='interferon-inducible double-stranded RNA-dependent protein kinase activator A|PKR-associated protein X|PKR-associating protein X|protein activator of the interferon-induced protein kinase|protein kinase, interferon-inducible double-stranded RNA-dependent activator', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178431414, end_position_on_the_genomic_accession=178451175, orientation='minus', exon_count=10, OMIM=[603424], no_hdr0=''),
    8576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8576, CurrentID=0, Status='live', Symbol='STK16', Aliases=['KRCT', 'MPSK', 'PKL12', 'PSK', 'TSF1', 'hPSK'], description='serine/threonine kinase 16', other_designations='serine/threonine-protein kinase 16|TGF-beta-stimulated factor 1|myristoylated and palmitoylated serine/threonine-protein kinase|protein kinase PKL12|protein kinase expressed in day 12 fetal liver|tyrosine-protein kinase STK16', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219245469, end_position_on_the_genomic_accession=219250337, orientation='plus', exon_count=8, OMIM=[604719], no_hdr0=''),
    8577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8577, CurrentID=0, Status='live', Symbol='TMEFF1', Aliases=['C9orf2', 'CT120.1', 'H7365', 'TR-1'], description='transmembrane protein with EGF like and two follistatin like domains 1', other_designations='tomoregulin-1|cancer/testis antigen family 120, member 1|transmembrane protein with EGF-like and one follistatin-like domain', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100473149, end_position_on_the_genomic_accession=100577636, orientation='plus', exon_count=10, OMIM=[603421], no_hdr0=''),
    8578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8578, CurrentID=0, Status='live', Symbol='SCARF1', Aliases=['SREC', 'SREC-I', 'SREC1'], description='scavenger receptor class F member 1', other_designations='scavenger receptor class F member 1|acetyl LDL receptor|scavenger receptor expressed by endothelial cells 1', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1633858, end_position_on_the_genomic_accession=1645732, orientation='minus', exon_count=11, OMIM=[607873], no_hdr0=''),
    8581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8581, CurrentID=0, Status='live', Symbol='LY6D', Aliases=['E48', 'Ly-6D'], description='lymphocyte antigen 6 family member D', other_designations='lymphocyte antigen 6D|e48 antigen|lymphocyte antigen 6 complex, locus D', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142784882, end_position_on_the_genomic_accession=142786539, orientation='minus', exon_count=3, OMIM=[606204], no_hdr0=''),
    8590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8590, CurrentID=0, Status='live', Symbol='OR6A2', Aliases=['I7', 'OR11-55', 'OR6A1P', 'OR6A2'], description='olfactory receptor family 6 subfamily A member 2', other_designations='olfactory receptor 6A2|hI7 olfactory receptor|hP2 olfactory receptor|olfactory receptor 11-55|olfactory receptor 6A1|olfactory receptor OR11-83|olfactory receptor, family 6, subfamily A, member 1|olfactory receptor, family 6, subfamily A, member 2 pseudogene|seven transmembrane helix receptor', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6791736, end_position_on_the_genomic_accession=6799689, orientation='minus', exon_count=2, OMIM=[608495], no_hdr0=''),
    8600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8600, CurrentID=0, Status='live', Symbol='TNFSF11', Aliases=['CD254', 'ODF', 'OPGL', 'OPTB2', 'RANKL', 'TNLG6B', 'TRANCE', 'hRANKL2', 'sOdf'], description='TNF superfamily member 11', other_designations='tumor necrosis factor ligand superfamily member 11|TNF-related activation-induced cytokine|osteoclast differentiation factor|osteoprotegerin ligand|receptor activator of nuclear factor kappa B ligand|tumor necrosis factor (ligand) superfamily, member 11|tumor necrosis factor ligand 6B|tumor necrosis factor superfamily member 11', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=42562736, end_position_on_the_genomic_accession=42608013, orientation='plus', exon_count=11, OMIM=[602642], no_hdr0=''),
    8601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8601, CurrentID=0, Status='live', Symbol='RGS20', Aliases=['RGSZ1', 'ZGAP1', 'g(z)GAP', 'gz-GAP'], description='regulator of G protein signaling 20', other_designations='regulator of G-protein signaling 20|gz-selective GTPase-activating protein|regulator of G-protein signaling 20 variant 2|regulator of G-protein signaling Z1|regulator of G-protein signalling 20|regulator of Gz-selective protein signaling 1', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=53851795, end_position_on_the_genomic_accession=53959304, orientation='plus', exon_count=8, OMIM=[607193], no_hdr0=''),
    8602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8602, CurrentID=0, Status='live', Symbol='NOP14', Aliases=['C4orf9', 'NOL14', 'RES4-25', 'RES425', 'UTP2'], description='NOP14 nucleolar protein', other_designations='nucleolar protein 14|NOP14 nucleolar protein homolog|probable nucleolar complex protein 14', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2937936, end_position_on_the_genomic_accession=2963506, orientation='minus', exon_count=19, OMIM=[611526], no_hdr0=''),
    8603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8603, CurrentID=0, Status='live', Symbol='FAM193A', Aliases=['C4orf8', 'RES4-22'], description='family with sequence similarity 193 member A', other_designations='protein FAM193A', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2535375, end_position_on_the_genomic_accession=2732573, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    8604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8604, CurrentID=0, Status='live', Symbol='SLC25A12', Aliases=['AGC1', 'ARALAR', 'DEE39', 'EIEE39'], description='solute carrier family 25 member 12', other_designations='calcium-binding mitochondrial carrier protein Aralar1|araceli hiperlarga|calcium binding mitochondrial carrier superfamily member Aralar1|mitochondrial aspartate glutamate carrier 1|solute carrier family 25 (aspartate/glutamate carrier), member 12|solute carrier family 25 (mitochondrial carrier, Aralar), member 12', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171783405, end_position_on_the_genomic_accession=171894244, orientation='minus', exon_count=19, OMIM=[603667], no_hdr0=''),
    8605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8605, CurrentID=0, Status='live', Symbol='PLA2G4C', Aliases=['CPLA2-gamma'], description='phospholipase A2 group IVC', other_designations='cytosolic phospholipase A2 gamma|cytosolic lysophospholipase|cytosolic lysophospholipid O-acyltransferase|phospholipase A2, group IVC (cytosolic, calcium-independent)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48047846, end_position_on_the_genomic_accession=48111383, orientation='minus', exon_count=21, OMIM=[603602], no_hdr0=''),
    8607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8607, CurrentID=0, Status='live', Symbol='RUVBL1', Aliases=['ECP-54', 'ECP54', 'INO80H', 'NMP 238', 'NMP238', 'PONTIN', 'Pontin52', 'RVB1', 'TIH1', 'TIP49', 'TIP49A'], description='RuvB like AAA ATPase 1', other_designations='ruvB-like 1|49 kDa TATA box-binding protein-interacting protein|49 kDa TBP-interacting protein|54 kDa erythrocyte cytosolic protein|INO80 complex subunit H|RuvB (E coli homolog)-like 1|RuvB-like AAA ATPase|TAP54-alpha|TATA binding protein interacting protein 49 kDa|TIP60-associated protein 54-alpha|epididymis secretory sperm binding protein|nuclear matrix protein 238|pontin 52', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128064611, end_position_on_the_genomic_accession=128153914, orientation='minus', exon_count=14, OMIM=[603449], no_hdr0=''),
    8608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8608, CurrentID=0, Status='live', Symbol='RDH16', Aliases=['RODH-4', 'SDR9C8', 'hRDH-E'], description='retinol dehydrogenase 16', other_designations='retinol dehydrogenase 16|human epidermal retinol dehydrogenase|microsomal NAD+-dependent retinol dehydrogenase 4|retinol dehydrogenase 16 (all-trans and 13-cis)|retinol dehydrogenase 16 (all-trans)|short chain dehydrogenase/reductase family 9C, member 8|sterol/retinol dehydrogenase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56951431, end_position_on_the_genomic_accession=56957608, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    8609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8609, CurrentID=0, Status='live', Symbol='KLF7', Aliases=['UKLF'], description='Kruppel like factor 7', other_designations='Krueppel-like factor 7|Kruppel-like factor 7 (ubiquitous)|ubiquitous Kruppel-like factor|ubiquitous Kruppel-like transcription factor', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207074137, end_position_on_the_genomic_accession=207173851, orientation='minus', exon_count=11, OMIM=[604865], no_hdr0=''),
    8611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8611, CurrentID=0, Status='live', Symbol='PLPP1', Aliases=['LLP1a', 'LPP1', 'PAP-2a', 'PAP2', 'PPAP2A'], description='phospholipid phosphatase 1', other_designations='phospholipid phosphatase 1|lipid phosphate phosphohydrolase 1a|phosphatidate phosphohydrolase type 2a|phosphatidic acid phosphatase 2a|phosphatidic acid phosphatase type 2A|phosphatidic acid phosphohydrolase type 2a|type-2 phosphatidic acid phosphatase alpha', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55424850, end_position_on_the_genomic_accession=55535075, orientation='minus', exon_count=7, OMIM=[607124], no_hdr0=''),
    8612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8612, CurrentID=0, Status='live', Symbol='PLPP2', Aliases=['LPP2', 'PAP-2c', 'PAP2-g', 'PPAP2C'], description='phospholipid phosphatase 2', other_designations='phospholipid phosphatase 2|PAP2-gamma|PAP2c|lipid phosphate phosphohydrolase 2|phosphatidate phosphohydrolase type 2c|phosphatidic acid phosphatase 2c|phosphatidic acid phosphatase type 2C|phosphatidic acid phosphohydrolase type 2c|type-2 phosphatidic acid phosphatase-gamma', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=281043, end_position_on_the_genomic_accession=291413, orientation='minus', exon_count=7, OMIM=[607126], no_hdr0=''),
    8613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8613, CurrentID=0, Status='live', Symbol='PLPP3', Aliases=['Dri42', 'LPP3', 'PAP2B', 'PPAP2B', 'VCIP'], description='phospholipid phosphatase 3', other_designations='phospholipid phosphatase 3|PAP2 beta|lipid phosphate phosphohydrolase 3|phosphatidate phosphohydrolase type 2b|phosphatidic acid phosphatase type 2B|type-2 phosphatidic acid phosphatase-beta|vascular endothelial growth factor and type I collagen inducible', map_location='1p32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56494761, end_position_on_the_genomic_accession=56579563, orientation='minus', exon_count=6, OMIM=[607125], no_hdr0=''),
    8614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8614, CurrentID=0, Status='live', Symbol='STC2', Aliases=['STC-2', 'STCRP'], description='stanniocalcin 2', other_designations='stanniocalcin-2|STC-related protein|stanniocalcin-related protein', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173314723, end_position_on_the_genomic_accession=173328414, orientation='minus', exon_count=4, OMIM=[603665], no_hdr0=''),
    8615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8615, CurrentID=0, Status='live', Symbol='USO1', Aliases=['P115', 'TAP', 'VDP'], description='USO1 vesicle transport factor', other_designations='general vesicular transport factor p115|USO1 vesicle docking protein homolog|transcytosis associated protein|vesicle docking protein p115', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75724522, end_position_on_the_genomic_accession=75814286, orientation='plus', exon_count=26, OMIM=[603344], no_hdr0=''),
    8618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8618, CurrentID=0, Status='live', Symbol='CADPS', Aliases=['CADPS1', 'CAPS', 'CAPS1', 'UNC-31'], description='calcium dependent secretion activator', other_designations='calcium-dependent secretion activator 1|CAPS-1|Ca++-dependent secretion activator|Ca2+ dependent secretion activator|Ca2+-dependent activator protein for secretion|Ca2+-regulated cytoskeletal protein|calcium-dependent activator protein for secretion 1', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=62398348, end_position_on_the_genomic_accession=62875865, orientation='minus', exon_count=36, OMIM=[604667], no_hdr0=''),
    8620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8620, CurrentID=0, Status='live', Symbol='NPFF', Aliases=['FMRFAL'], description='neuropeptide FF-amide peptide precursor', other_designations='pro-FMRFamide-related neuropeptide FF', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53506688, end_position_on_the_genomic_accession=53507484, orientation='minus', exon_count=3, OMIM=[604643], no_hdr0=''),
    8621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8621, CurrentID=0, Status='live', Symbol='CDK13', Aliases=['CDC2L', 'CDC2L5', 'CHDFIDD', 'CHED', 'hCDK13'], description='cyclin dependent kinase 13', other_designations='cyclin-dependent kinase 13|CDC2-related protein kinase 5|cell division cycle 2-like protein kinase 5|cell division protein kinase 13|cholinesterase-related cell division controller', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=39949664, end_position_on_the_genomic_accession=40099580, orientation='plus', exon_count=16, OMIM=[603309], no_hdr0=''),
    8622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8622, CurrentID=0, Status='live', Symbol='PDE8B', Aliases=['ADSD', 'PPNAD3'], description='phosphodiesterase 8B', other_designations="high affinity cAMP-specific and IBMX-insensitive 3',5'-cyclic phosphodiesterase 8B|3',5' cyclic nucleotide phosphodiesterase 8B|cell proliferation-inducing gene 22 protein", map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77180304, end_position_on_the_genomic_accession=77428256, orientation='plus', exon_count=25, OMIM=[603390], no_hdr0=''),
    8623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8623, CurrentID=0, Status='live', Symbol='ASMTL', Aliases=['ASMTLXY', 'ASTML', 'ASMTL'], description='acetylserotonin O-methyltransferase like', other_designations='probable bifunctional dTTP/UTP pyrophosphatase/methyltransferase protein|N-acetylserotonin O-methyltransferase-like protein|acetylserotonin N-methyltransferase-like', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1403139, end_position_on_the_genomic_accession=1453794, orientation='minus', exon_count=16, OMIM=[300162, 400011], no_hdr0=''),
    8624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8624, CurrentID=0, Status='live', Symbol='PSMG1', Aliases=['C21LRP', 'DSCR2', 'LRPC21', 'PAC-1', 'PAC1'], description='proteasome assembly chaperone 1', other_designations='proteasome assembly chaperone 1|Down syndrome critical region gene 2|Down syndrome critical region protein 2|chromosome 21 leucine-rich protein|leucine rich protein C21-LRP|proteasome (prosome, macropain) assembly chaperone 1|proteasome assembling chaperone 1', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39174769, end_position_on_the_genomic_accession=39183514, orientation='minus', exon_count=7, OMIM=[605296], no_hdr0=''),
    8625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8625, CurrentID=0, Status='live', Symbol='RFXANK', Aliases=['ANKRA1', 'BLS', 'F14150_1', 'RFX-B'], description='regulatory factor X associated ankyrin containing protein', other_designations='DNA-binding protein RFXANK|RFX-Bdelta4|ankyrin repeat family A protein 1|ankyrin repeat-containing regulatory factor X-associated protein|regulatory factor X subunit B', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19192258, end_position_on_the_genomic_accession=19201869, orientation='plus', exon_count=13, OMIM=[603200], no_hdr0=''),
    8626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8626, CurrentID=0, Status='live', Symbol='TP63', Aliases=['AIS', 'B(p51A)', 'B(p51B)', 'EEC3', 'KET', 'LMS', 'NBP', 'OFC8', 'RHS', 'SHFM4', 'TP53CP', 'TP53L', 'TP73L', 'p40', 'p51', 'p53CP', 'p63', 'p73H', 'p73L'], description='tumor protein p63', other_designations='tumor protein 63|amplified in squamous cell carcinoma|chronic ulcerative stomatitis protein|keratinocyte transcription factor KET|transformation-related protein 63|tumor protein p53-competing protein', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=189596746, end_position_on_the_genomic_accession=189897276, orientation='plus', exon_count=17, OMIM=[603273], no_hdr0=''),
    8629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8629, CurrentID=0, Status='live', Symbol='JRK', Aliases=['JH8', 'jerky'], description='Jrk helix-turn-helix protein', other_designations='jerky protein homolog|Jrk homolog|jerky homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142651501, end_position_on_the_genomic_accession=142669983, orientation='minus', exon_count=7, OMIM=[603210], no_hdr0=''),
    8630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8630, CurrentID=0, Status='live', Symbol='HSD17B6', Aliases=['HSE', 'RODH', 'SDR9C6'], description='hydroxysteroid 17-beta dehydrogenase 6', other_designations='17-beta-hydroxysteroid dehydrogenase type 6|17-beta-HSD 6|17-beta-hydroxysteroid dehydrogenase type 6 variant 1|17-beta-hydroxysteroid dehydrogenase type 6 variant 2|17-beta-hydroxysteroid dehydrogenase type 6 variant 3|3(alpha->beta)-hydroxysteroid epimerase|3(alpha->beta)-hydroxysteroid epimerasel|3-alpha->beta-HSE|3-hydroxysteroid epimerase|NAD+ -dependent 3 alpha-hydroxysteroid dehydrogenase 3-hydroxysteroid epimerase|hydroxysteroid (17-beta) dehydrogenase 6 homolog|oxidative 3-alpha-hydroxysteroid-dehydrogenase|oxidoreductase|retinol dehydrogenase|short chain dehydrogenase/reductase family 9C member 6', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56752449, end_position_on_the_genomic_accession=56787790, orientation='plus', exon_count=7, OMIM=[606623], no_hdr0=''),
    8631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8631, CurrentID=0, Status='live', Symbol='SKAP1', Aliases=['HEL-S-81p', 'SCAP1', 'SKAP55'], description='src kinase associated phosphoprotein 1', other_designations='src kinase-associated phosphoprotein 1|SKAP-55|epididymis secretory sperm binding protein Li 81p|pp55|src family-associated phosphoprotein 1|src kinase-associated phosphoprotein of 55 kDa', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48133438, end_position_on_the_genomic_accession=48430250, orientation='minus', exon_count=18, OMIM=[604969], no_hdr0=''),
    8632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8632, CurrentID=0, Status='live', Symbol='DNAH17', Aliases=['DNAHL1', 'DNEL2', 'SPGF39'], description='dynein axonemal heavy chain 17', other_designations='dynein axonemal heavy chain 17|dynein heavy chain 17, axonemal|axonemal beta dynein heavy chain 17|axonemal dynein heavy chain-like protein 1|ciliary dynein heavy chain 17|ciliary dynein heavy chain-like protein 1|dynein axonemal light chain 2|dynein light chain 2, axonemal|dynein, axonemal, heavy polypeptide 17', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78423697, end_position_on_the_genomic_accession=78577436, orientation='minus', exon_count=81, OMIM=[610063], no_hdr0=''),
    8633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8633, CurrentID=0, Status='live', Symbol='UNC5C', Aliases=['UNC5H3'], description='unc-5 netrin receptor C', other_designations='netrin receptor UNC5C|protein unc-5 homolog 3|protein unc-5 homolog C|unc-5 homolog 3|unc-5 homolog C|unc5 (C.elegans homolog) c', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=95162504, end_position_on_the_genomic_accession=95549210, orientation='minus', exon_count=20, OMIM=[603610], no_hdr0=''),
    8634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8634, CurrentID=0, Status='live', Symbol='RTCA', Aliases=['RPC', 'RTC1', 'RTCD1'], description="RNA 3'-terminal phosphate cyclase", other_designations="RNA 3'-terminal phosphate cyclase|RNA terminal phosphate cyclase domain 1|RNA terminal phosphate cyclase domain-containing protein 1|RTC domain-containing protein 1", map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100266187, end_position_on_the_genomic_accession=100292769, orientation='plus', exon_count=12, OMIM=[611286], no_hdr0=''),
    8635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8635, CurrentID=0, Status='live', Symbol='RNASET2', Aliases=['RNASE6PL', 'bA514O12.3'], description='ribonuclease T2', other_designations='ribonuclease T2|ribonuclease 6', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166922113, end_position_on_the_genomic_accession=166956580, orientation='minus', exon_count=10, OMIM=[612944], no_hdr0=''),
    8636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8636, CurrentID=0, Status='live', Symbol='SSNA1', Aliases=['N14', 'NA-14', 'NA14'], description='SS nuclear autoantigen 1', other_designations="Sjoegren syndrome nuclear autoantigen 1|Sjogren syndrome nuclear autoantigen 1|Sjogren's syndrome nuclear autoantigen 1|nuclear autoantigen of 14 kDa", map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137188676, end_position_on_the_genomic_accession=137190366, orientation='plus', exon_count=3, OMIM=[610882], no_hdr0=''),
    8637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8637, CurrentID=0, Status='live', Symbol='EIF4EBP3', Aliases=['4E-BP3', '4EBP3'], description='eukaryotic translation initiation factor 4E binding protein 3', other_designations='eukaryotic translation initiation factor 4E-binding protein 3|eIF4E-binding protein 3|eukaryotic initiation factor 4E-binding protein 3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140547662, end_position_on_the_genomic_accession=140549576, orientation='plus', exon_count=3, OMIM=[603483], no_hdr0=''),
    8638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8638, CurrentID=0, Status='live', Symbol='OASL', Aliases=['OASL1d', 'TRIP-14', 'TRIP14', 'p59 OASL', 'p59-OASL', 'p59OASL', 'OASL'], description="2'-5'-oligoadenylate synthetase like", other_designations="2'-5'-oligoadenylate synthase-like protein|2'-5'-OAS-RP|2'-5'-OAS-related protein|59 kDa 2'-5'-oligoadenylate synthase-like protein|59 kDa 2'-5'-oligoadenylate synthetase-like protein|TR-interacting protein 14|thyroid receptor-interacting protein 14", map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121018882, end_position_on_the_genomic_accession=121039242, orientation='minus', exon_count=7, OMIM=[603281], no_hdr0=''),
    8639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8639, CurrentID=0, Status='live', Symbol='AOC3', Aliases=['HPAO', 'SSAO', 'VAP-1', 'VAP1'], description='amine oxidase copper containing 3', other_designations='membrane primary amine oxidase|amine oxidase, copper containing 3 (vascular adhesion protein 1)|copper amine oxidase|placenta copper monamine oxidase|semicarbazide-sensitive amine oxidase', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42851182, end_position_on_the_genomic_accession=42858130, orientation='plus', exon_count=6, OMIM=[603735], no_hdr0=''),
    8641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8641, CurrentID=0, Status='live', Symbol='PCDHGB4', Aliases=['CDH20', 'FIB2', 'PCDH-GAMMA-B4'], description='protocadherin gamma subfamily B, 4', other_designations='protocadherin gamma-B4|cadherin 20|fibroblast cadherin FIB2|fibroblast cadherin-2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141387698, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[603058], no_hdr0=''),
    8642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8642, CurrentID=0, Status='live', Symbol='DCHS1', Aliases=['CDH19', 'CDH25', 'CDHR6', 'FIB1', 'MVP2', 'PCDH16', 'VMLDS1'], description='dachsous cadherin-related 1', other_designations='protocadherin-16|cadherin-19|cadherin-25|cadherin-related family member 6|fibroblast cadherin 1|fibroblast cadherin FIB1|protein dachsous homolog 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6621330, end_position_on_the_genomic_accession=6655809, orientation='minus', exon_count=21, OMIM=[603057], no_hdr0=''),
    8643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8643, CurrentID=0, Status='live', Symbol='PTCH2', Aliases=['PTC2'], description='patched 2', other_designations='protein patched homolog 2|patched homolog 2', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44819845, end_position_on_the_genomic_accession=44843253, orientation='minus', exon_count=23, OMIM=[603673], no_hdr0=''),
    8644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8644, CurrentID=0, Status='live', Symbol='AKR1C3', Aliases=['DD3', 'DDX', 'HA1753', 'HAKRB', 'HAKRe', 'HSD17B5', 'PGFS', 'hluPGFS'], description='aldo-keto reductase family 1 member C3', other_designations='aldo-keto reductase family 1 member C3|3-alpha hydroxysteroid dehydrogenase, type II|3-alpha-HSD type II, brain|chlordecone reductase homolog HAKRb|dihydrodiol dehydrogenase 3|dihydrodiol dehydrogenase X|indanol dehydrogenase|prostaglandin F synthase|testosterone 17-beta-dehydrogenase 5|trans-1,2-dihydrobenzene-1,2-diol dehydrogenase|type IIb 3-alpha hydroxysteroid dehydrogenase', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5048781, end_position_on_the_genomic_accession=5107686, orientation='plus', exon_count=10, OMIM=[603966], no_hdr0=''),
    8645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8645, CurrentID=0, Status='live', Symbol='KCNK5', Aliases=['K2p5.1b', 'TASK-2', 'TASK2', 'KCNK5'], description='potassium two pore domain channel subfamily K member 5', other_designations='potassium channel subfamily K member 5|K2P5.1 potassium channel|TWIK-related acid-sensitive K(+) channel 2|TWIK-related acid-sensitive K+ 2|TWIK-related acid-sensitive K+ channel 2|acid-sensitive potassium channel protein TASK-2|potassium channel, subfamily K, member 1 (TASK-2)|potassium channel, subfamily, member 5 (KCNK5)|potassium channel, two pore domain subfamily K, member 5', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39188971, end_position_on_the_genomic_accession=39229475, orientation='minus', exon_count=5, OMIM=[603493], no_hdr0=''),
    8646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8646, CurrentID=0, Status='live', Symbol='CHRD', Aliases=[], description='chordin', other_designations='chordin', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184380054, end_position_on_the_genomic_accession=184390739, orientation='plus', exon_count=24, OMIM=[603475], no_hdr0=''),
    8647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8647, CurrentID=0, Status='live', Symbol='ABCB11', Aliases=['ABC16', 'BRIC2', 'BSEP', 'PFIC-2', 'PFIC2', 'PGY4', 'SPGP'], description='ATP binding cassette subfamily B member 11', other_designations='bile salt export pump|ABC member 16, MDR/TAP subfamily|ATP-binding cassette sub-family B member 11|ATP-binding cassette, sub-family B (MDR/TAP), member 11|progressive familial intrahepatic cholestasis 2|sister p-glycoprotein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=168915468, end_position_on_the_genomic_accession=169031396, orientation='minus', exon_count=30, OMIM=[603201], no_hdr0=''),
    8648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8648, CurrentID=0, Status='live', Symbol='NCOA1', Aliases=['F-SRC-1', 'KAT13A', 'RIP160', 'SRC1', 'bHLHe42', 'bHLHe74'], description='nuclear receptor coactivator 1', other_designations='nuclear receptor coactivator 1|Hin-2 protein|class E basic helix-loop-helix protein 74|renal carcinoma antigen NY-REN-52|steroid receptor coactivator-1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24491254, end_position_on_the_genomic_accession=24770702, orientation='plus', exon_count=26, OMIM=[602691], no_hdr0=''),
    8649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8649, CurrentID=0, Status='live', Symbol='LAMTOR3', Aliases=['MAP2K1IP1', 'MAPBP', 'MAPKSP1', 'MP1', 'PRO0633', 'Ragulator3'], description='late endosomal/lysosomal adaptor, MAPK and MTOR activator 3', other_designations='ragulator complex protein LAMTOR3|MAPK scaffold protein 1|MEK binding partner 1|late endosomal/lysosomal adaptor and MAPK and MTOR activator 3|mitogen-activated protein kinase kinase 1 interacting protein 1|mitogen-activated protein kinase scaffold protein 1', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99878336, end_position_on_the_genomic_accession=99894546, orientation='minus', exon_count=7, OMIM=[603296], no_hdr0=''),
    8650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8650, CurrentID=0, Status='live', Symbol='NUMB', Aliases=['C14orf41', 'S171', 'c14_5527'], description='NUMB endocytic adaptor protein', other_designations='protein numb homolog|h-Numb|numb homolog', map_location='14q24.2-q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73275216, end_position_on_the_genomic_accession=73458546, orientation='minus', exon_count=14, OMIM=[603728], no_hdr0=''),
    8651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8651, CurrentID=0, Status='live', Symbol='SOCS1', Aliases=['AISIMD', 'CIS1', 'CISH1', 'JAB', 'SOCS-1', 'SSI-1', 'SSI1', 'TIP-3', 'TIP3'], description='suppressor of cytokine signaling 1', other_designations='suppressor of cytokine signaling 1|JAK binding protein|STAT induced SH3 protein 1|STAT-induced STAT inhibitor 1|Tec-interacting protein 3|cytokine-inducible SH2 protein 1', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11254417, end_position_on_the_genomic_accession=11256204, orientation='minus', exon_count=2, OMIM=[603597], no_hdr0=''),
    8653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8653, CurrentID=0, Status='live', Symbol='DDX3Y', Aliases=['DBY'], description='DEAD-box helicase 3 Y-linked', other_designations='ATP-dependent RNA helicase DDX3Y|DEAD (Asp-Glu-Ala-Asp) box helicase 3, Y-linked|DEAD (Asp-Glu-Ala-Asp) box polypeptide 3, Y-linked|DEAD box protein 3, Y-chromosomal|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide, Y chromosome', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=12903999, end_position_on_the_genomic_accession=12920478, orientation='plus', exon_count=19, OMIM=[400010], no_hdr0=''),
    8654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8654, CurrentID=0, Status='live', Symbol='PDE5A', Aliases=['CGB-PDE', 'CN5A', 'PDE5'], description='phosphodiesterase 5A', other_designations="cGMP-specific 3',5'-cyclic phosphodiesterase|cGMP-binding cGMP-specific 3',5'-cyclic nucleotide phosphodiesterase|cGMP-specific phosphodiesterase PDE5A2|cGMP-specific phosphodiesterase type 5A|phosphodiesterase 5A, cGMP-specific|phosphodiesterase isozyme 5", map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=119494403, end_position_on_the_genomic_accession=119628804, orientation='minus', exon_count=24, OMIM=[603310], no_hdr0=''),
    8655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8655, CurrentID=0, Status='live', Symbol='DYNLL1', Aliases=['DLC1', 'DLC8', 'DNCL1', 'DNCLC1', 'LC8', 'LC8a', 'PIN', 'hdlc1'], description='dynein light chain LC8-type 1', other_designations='dynein light chain 1, cytoplasmic|8 kDa dynein light chain|cytoplasmic dynein light polypeptide|dynein, cytoplasmic, light polypeptide 1|protein inhibitor of neuronal nitric oxide synthase', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120469842, end_position_on_the_genomic_accession=120498493, orientation='plus', exon_count=4, OMIM=[601562], no_hdr0=''),
    8658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8658, CurrentID=0, Status='live', Symbol='TNKS', Aliases=['ARTD5', 'PARP-5a', 'PARP5A', 'PARPL', 'TIN1', 'TINF11', 'pART5', 'TNKS'], description='tankyrase', other_designations='poly [ADP-ribose] polymerase tankyrase-1|ADP-ribosyltransferase diphtheria toxin-like 5|TANK1|TNKS-1|TRF1-interacting ankyrin-related ADP-ribose polymerase 1|poly [ADP-ribose] polymerase 5A|protein poly-ADP-ribosyltransferase tankyrase-1|tankyrase I|tankyrase, TRF1-interacting ankyrin-related ADP-ribose polymerase|tankyrase-1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=9555230, end_position_on_the_genomic_accession=9782346, orientation='plus', exon_count=29, OMIM=[603303], no_hdr0=''),
    8659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8659, CurrentID=0, Status='live', Symbol='ALDH4A1', Aliases=['ALDH4', 'P5CD', 'P5CDh'], description='aldehyde dehydrogenase 4 family member A1', other_designations='delta-1-pyrroline-5-carboxylate dehydrogenase, mitochondrial|L-glutamate gamma-semialdehyde dehydrogenase|P5C dehydrogenase|aldehyde dehydrogenase family 4 member A1|epididymis secretory sperm binding protein|mitochondrial delta-1-pyrroline 5-carboxylate dehydrogenase', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18871430, end_position_on_the_genomic_accession=18902555, orientation='minus', exon_count=16, OMIM=[606811], no_hdr0=''),
    8660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8660, CurrentID=0, Status='live', Symbol='IRS2', Aliases=['IRS-2'], description='insulin receptor substrate 2', other_designations='insulin receptor substrate 2', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=109752695, end_position_on_the_genomic_accession=109786583, orientation='minus', exon_count=2, OMIM=[600797], no_hdr0=''),
    8661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8661, CurrentID=0, Status='live', Symbol='EIF3A', Aliases=['EIF3', 'EIF3S10', 'P167', 'TIF32', 'eIF3-p170', 'eIF3-theta', 'p180', 'p185'], description='eukaryotic translation initiation factor 3 subunit A', other_designations='eukaryotic translation initiation factor 3 subunit A|EIF3, p180 subunit|centrosomin homolog|cytoplasmic protein p167|eIF-3-theta|eIF3 p167|eIF3 p180|eIF3 p185|eukaryotic translation initiation factor 3 subunit 10|eukaryotic translation initiation factor 3, subunit 10 (theta, 150/170kD)|eukaryotic translation initiation factor 3, subunit 10 (theta, 170kD)|eukaryotic translation initiation factor 3, subunit 10 theta, 150/170kDa|eukaryotic translation initiation factor 3, subunit 10, 170kD', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119033670, end_position_on_the_genomic_accession=119080817, orientation='minus', exon_count=22, OMIM=[602039], no_hdr0=''),
    8662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8662, CurrentID=0, Status='live', Symbol='EIF3B', Aliases=['EIF3-ETA', 'EIF3-P110', 'EIF3-P116', 'EIF3S9', 'PRT1'], description='eukaryotic translation initiation factor 3 subunit B', other_designations='eukaryotic translation initiation factor 3 subunit B|eukaryotic translation initiation factor 3 subunit 9|eukaryotic translation initiation factor 3, subunit 9 (eta, 116kD)|eukaryotic translation initiation factor 3, subunit 9 eta, 116kDa|protein synthesis 1|prt1 homolog', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2354086, end_position_on_the_genomic_accession=2380745, orientation='plus', exon_count=22, OMIM=[603917], no_hdr0=''),
    8663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8663, CurrentID=0, Status='live', Symbol='EIF3C', Aliases=['EIF3CL', 'EIF3S8', 'eIF3-p110'], description='eukaryotic translation initiation factor 3 subunit C', other_designations='eukaryotic translation initiation factor 3 subunit C|cell migration-inducing protein 17|eIF3 p110|eukaryotic translation initiation factor 3 subunit 8|eukaryotic translation initiation factor 3, subunit 8 (110kD)|eukaryotic translation initiation factor 3, subunit 8, 110kDa', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28688558, end_position_on_the_genomic_accession=28735730, orientation='plus', exon_count=22, OMIM=[603916], no_hdr0=''),
    8664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8664, CurrentID=0, Status='live', Symbol='EIF3D', Aliases=['EIF3S7', 'eIF3-p66', 'eIF3-zeta'], description='eukaryotic translation initiation factor 3 subunit D', other_designations='eukaryotic translation initiation factor 3 subunit D|eIF3 p66|eukaryotic translation initiation factor 3, subunit 7 zeta, 66/67kDa|translation initiation factor eIF3 p66 subunit', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36510855, end_position_on_the_genomic_accession=36529166, orientation='minus', exon_count=15, OMIM=[603915], no_hdr0=''),
    8665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8665, CurrentID=0, Status='live', Symbol='EIF3F', Aliases=['EIF3S5', 'MRT67', 'eIF3-p47'], description='eukaryotic translation initiation factor 3 subunit F', other_designations='eukaryotic translation initiation factor 3 subunit F|deubiquitinating enzyme eIF3f|eIF-3-epsilon|eIF3-epsilon|eukaryotic translation initiation factor 3, subunit 5 (epsilon, 47kD)|eukaryotic translation initiation factor 3, subunit 5 epsilon, 47kDa', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7987337, end_position_on_the_genomic_accession=8001852, orientation='plus', exon_count=8, OMIM=[603914], no_hdr0=''),
    8666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8666, CurrentID=0, Status='live', Symbol='EIF3G', Aliases=['EIF3-P42', 'EIF3S4', 'eIF3-delta', 'eIF3-p44'], description='eukaryotic translation initiation factor 3 subunit G', other_designations='eukaryotic translation initiation factor 3 subunit G|eukaryotic translation initiation factor 3 RNA-binding subunit|eukaryotic translation initiation factor 3 subunit p42|eukaryotic translation initiation factor 3, subunit 4 delta, 44kDa', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10115014, end_position_on_the_genomic_accession=10119899, orientation='minus', exon_count=11, OMIM=[603913], no_hdr0=''),
    8667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8667, CurrentID=0, Status='live', Symbol='EIF3H', Aliases=['EIF3S3', 'eIF3-gamma', 'eIF3-p40'], description='eukaryotic translation initiation factor 3 subunit H', other_designations='eukaryotic translation initiation factor 3 subunit H|eIF-3-gamma|eIF3 p40 subunit|eukaryotic translation initiation factor 3 subunit 3|eukaryotic translation initiation factor 3, subunit 2 (beta, 36kD)|eukaryotic translation initiation factor 3, subunit 3 (gamma, 40kD)|eukaryotic translation initiation factor 3, subunit 3 gamma, 40kDa', map_location='8q23.3-q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=116642130, end_position_on_the_genomic_accession=116755823, orientation='minus', exon_count=8, OMIM=[603912], no_hdr0=''),
    8668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8668, CurrentID=0, Status='live', Symbol='EIF3I', Aliases=['EIF3S2', 'PRO2242', 'TRIP-1', 'TRIP1', 'eIF3-beta', 'eIF3-p36'], description='eukaryotic translation initiation factor 3 subunit I', other_designations='eukaryotic translation initiation factor 3 subunit I|TGF-beta receptor-interacting protein 1|TGFbeta receptor-interacting protein 1|eukaryotic translation initiation factor 3 subunit 2|eukaryotic translation initiation factor 3, subunit 2 (beta, 36kD)|eukaryotic translation initiation factor 3, subunit 2 beta, 36kDa|predicted protein of HQ2242', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32221584, end_position_on_the_genomic_accession=32236170, orientation='plus', exon_count=14, OMIM=[603911], no_hdr0=''),
    8669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8669, CurrentID=0, Status='live', Symbol='EIF3J', Aliases=['EIF3S1', 'eIF3-alpha', 'eIF3-p35'], description='eukaryotic translation initiation factor 3 subunit J', other_designations='eukaryotic translation initiation factor 3 subunit J|eukaryotic translation initiation factor 3, subunit 1 (alpha, 35kD)', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44537147, end_position_on_the_genomic_accession=44562803, orientation='plus', exon_count=8, OMIM=[603910], no_hdr0=''),
    8671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8671, CurrentID=0, Status='live', Symbol='SLC4A4', Aliases=['HNBC1', 'KNBC', 'NBC1', 'NBC2', 'NBCe1-A', 'SLC4A5', 'hhNMC', 'kNBC1', 'pNBC'], description='solute carrier family 4 member 4', other_designations='electrogenic sodium bicarbonate cotransporter 1|Na(+)/HCO3(-) cotransporter|sodium bicarbonate cotransporter 1 (sodium bicarbonate cotransporter, kidney; sodium bicarbonate cotransporter, pancreas)|solute carrier family 4 (sodium bicarbonate cotransporter), member 4|solute carrier family 4, sodium bicarbonate cotransporter, member 4, brain type|solute carrier family 4, sodium bicarbonate cotransporter, member 5', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=71062646, end_position_on_the_genomic_accession=71572083, orientation='plus', exon_count=36, OMIM=[603345], no_hdr0=''),
    8672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8672, CurrentID=0, Status='live', Symbol='EIF4G3', Aliases=['eIF-4G 3', 'eIF4G 3', 'eIF4GII'], description='eukaryotic translation initiation factor 4 gamma 3', other_designations='eukaryotic translation initiation factor 4 gamma 3|eIF-4-gamma 3|eIF-4-gamma II', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20806292, end_position_on_the_genomic_accession=21176897, orientation='minus', exon_count=42, OMIM=[603929], no_hdr0=''),
    8673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8673, CurrentID=0, Status='live', Symbol='VAMP8', Aliases=['EDB', 'VAMP-8'], description='vesicle associated membrane protein 8', other_designations='vesicle-associated membrane protein 8|vesicle-associated membrane protein 8 (endobrevin)', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85577535, end_position_on_the_genomic_accession=85582031, orientation='plus', exon_count=4, OMIM=[603177], no_hdr0=''),
    8674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8674, CurrentID=0, Status='live', Symbol='VAMP4', Aliases=['VAMP-4', 'VAMP24'], description='vesicle associated membrane protein 4', other_designations='vesicle-associated membrane protein 4|VAMP4/TAF3 fusion', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171700160, end_position_on_the_genomic_accession=171742844, orientation='minus', exon_count=9, OMIM=[606909], no_hdr0=''),
    8675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8675, CurrentID=0, Status='live', Symbol='STX16', Aliases=['SYN16'], description='syntaxin 16', other_designations='syntaxin-16', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58651283, end_position_on_the_genomic_accession=58679526, orientation='plus', exon_count=9, OMIM=[603666], no_hdr0=''),
    8676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8676, CurrentID=0, Status='live', Symbol='STX11', Aliases=['FHL4', 'HLH4', 'HPLH4'], description='syntaxin 11', other_designations='syntaxin-11', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=144140044, end_position_on_the_genomic_accession=144191939, orientation='plus', exon_count=9, OMIM=[605014], no_hdr0=''),
    8677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8677, CurrentID=0, Status='live', Symbol='STX10', Aliases=['SYN10', 'hsyn10'], description='syntaxin 10', other_designations='syntaxin-10', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13144058, end_position_on_the_genomic_accession=13150375, orientation='minus', exon_count=9, OMIM=[603765], no_hdr0=''),
    8678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8678, CurrentID=0, Status='live', Symbol='BECN1', Aliases=['ATG6', 'VPS30', 'beclin1'], description='beclin 1', other_designations='beclin-1|ATG6 autophagy related 6 homolog|beclin 1 (coiled-coil, moesin-like BCL2-interacting protein)|beclin 1, autophagy related|coiled-coil myosin-like BCL2-interacting protein|testis secretory sperm-binding protein Li 215e', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42810132, end_position_on_the_genomic_accession=42824282, orientation='minus', exon_count=13, OMIM=[604378], no_hdr0=''),
    8681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8681, CurrentID=0, Status='live', Symbol='JMJD7-PLA2G4B', Aliases=['HsT16992', 'cPLA2-beta'], description='JMJD7-PLA2G4B readthrough', other_designations='JMJD7-PLA2G4B protein|jumonji domain containing 7-phospholipase A2, group IVB (cytosolic) read-through', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41828092, end_position_on_the_genomic_accession=41848143, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    8682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8682, CurrentID=0, Status='live', Symbol='PEA15', Aliases=['HMAT1', 'HUMMAT1H', 'MAT1', 'MAT1H', 'PEA-15', 'PED', 'PED-PEA15', 'PED/PEA15'], description='proliferation and apoptosis adaptor protein 15', other_designations='astrocytic phosphoprotein PEA-15|15 kDa phosphoprotein enriched in astrocytes|homolog of mouse MAT-1 oncogene|mammary transforming gene 1, mouse, homolog of|phosphoprotein enriched in astrocytes 15|phosphoprotein enriched in diabetes|proliferation and apoptosis adaptor 15', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160205384, end_position_on_the_genomic_accession=160215376, orientation='plus', exon_count=6, OMIM=[603434], no_hdr0=''),
    8683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8683, CurrentID=0, Status='live', Symbol='SRSF9', Aliases=['SFRS9', 'SRp30c'], description='serine and arginine rich splicing factor 9', other_designations='serine/arginine-rich splicing factor 9|SR splicing factor 9|pre-mRNA-splicing factor SRp30C|splicing factor, arginine/serine-rich 9', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120461672, end_position_on_the_genomic_accession=120469748, orientation='minus', exon_count=4, OMIM=[601943], no_hdr0=''),
    8685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8685, CurrentID=0, Status='live', Symbol='MARCO', Aliases=['SCARA2', 'SR-A6'], description='macrophage receptor with collagenous structure', other_designations='macrophage receptor MARCO|scavenger receptor class A, member 2', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=118942180, end_position_on_the_genomic_accession=118994664, orientation='plus', exon_count=18, OMIM=[604870], no_hdr0=''),
    8687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8687, CurrentID=0, Status='live', Symbol='KRT38', Aliases=['HA8', 'KRTHA8', 'hHa8'], description='keratin 38', other_designations='keratin, type I cuticular Ha8|K38|hair keratin, type I Ha8|keratin 38, type I|keratin, hair, acidic, 8', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41436154, end_position_on_the_genomic_accession=41440983, orientation='minus', exon_count=7, OMIM=[604542], no_hdr0=''),
    8688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8688, CurrentID=0, Status='live', Symbol='KRT37', Aliases=['HA7', 'K37', 'KRTHA7'], description='keratin 37', other_designations='keratin, type I cuticular Ha7|hair keratin, type I Ha7|keratin 37, type I|keratin, hair, acidic, 7', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41420547, end_position_on_the_genomic_accession=41424585, orientation='minus', exon_count=7, OMIM=[604541], no_hdr0=''),
    8689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8689, CurrentID=0, Status='live', Symbol='KRT36', Aliases=['HA6', 'KRTHA6', 'hHa6'], description='keratin 36', other_designations='keratin, type I cuticular Ha6|K36|hair keratin, type I Ha6|keratin 36, type I|keratin, hair, acidic, 6', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41486136, end_position_on_the_genomic_accession=41489910, orientation='minus', exon_count=7, OMIM=[604540], no_hdr0=''),
    8690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8690, CurrentID=0, Status='live', Symbol='JRKL', Aliases=['HHMJG'], description='JRK like', other_designations='jerky protein homolog-like|human homolog of mouse jerky gene protein', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=96390013, end_position_on_the_genomic_accession=96393561, orientation='plus', exon_count=1, OMIM=[603211], no_hdr0=''),
    8692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8692, CurrentID=0, Status='live', Symbol='HYAL2', Aliases=['LUCA2'], description='hyaluronidase 2', other_designations='hyaluronidase-2|PH-20 homolog|PH20 homolog|hyal-2|hyaluronoglucosaminidase 2|lung carcinoma protein 2|lysosomal hyaluronidase', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50317802, end_position_on_the_genomic_accession=50322768, orientation='minus', exon_count=6, OMIM=[603551], no_hdr0=''),
    8693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8693, CurrentID=0, Status='live', Symbol='GALNT4', Aliases=['GALNAC-T4', 'GALNACT4'], description='polypeptide N-acetylgalactosaminyltransferase 4', other_designations='polypeptide N-acetylgalactosaminyltransferase 4|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 4|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 4 (GalNAc-T4)|polypeptide GalNAc transferase 4|pp-GaNTase 4|protein-UDP acetylgalactosaminyltransferase 4', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=89519412, end_position_on_the_genomic_accession=89524796, orientation='minus', exon_count=1, OMIM=[603565], no_hdr0=''),
    8694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8694, CurrentID=0, Status='live', Symbol='DGAT1', Aliases=['ARAT', 'ARGP1', 'DGAT', 'DIAR7'], description='diacylglycerol O-acyltransferase 1', other_designations='diacylglycerol O-acyltransferase 1|ACAT related gene product 1|acyl coenzyme A:cholesterol acyltransferase related gene 1|acyl-CoA retinol O-fatty-acyltransferase|acyl-CoA:diacylglycerol acyltransferase|diglyceride acyltransferase', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144314584, end_position_on_the_genomic_accession=144326852, orientation='minus', exon_count=18, OMIM=[604900], no_hdr0=''),
    8697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8697, CurrentID=0, Status='live', Symbol='CDC23', Aliases=['ANAPC8', 'APC8', 'CUT23'], description='cell division cycle 23', other_designations='cell division cycle protein 23 homolog|anaphase-promoting complex subunit 8|cell division cycle 23 homolog|cyclosome subunit 8', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138187650, end_position_on_the_genomic_accession=138213323, orientation='minus', exon_count=16, OMIM=[603462], no_hdr0=''),
    8698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8698, CurrentID=0, Status='live', Symbol='S1PR4', Aliases=['EDG6', 'LPC1', 'S1P4', 'SLP4'], description='sphingosine-1-phosphate receptor 4', other_designations='sphingosine 1-phosphate receptor 4|S1P receptor 4|S1P receptor Edg-6|endothelial differentiation G-protein coupled receptor 6|endothelial differentiation, lysophosphatidic acid G-protein-coupled receptor, 6|sphingosine 1-phosphate receptor Edg-6', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3178769, end_position_on_the_genomic_accession=3180332, orientation='plus', exon_count=1, OMIM=[603751], no_hdr0=''),
    8701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8701, CurrentID=0, Status='live', Symbol='DNAH11', Aliases=['CILD7', 'DNAHBL', 'DNAHC11', 'DNHBL', 'DPL11'], description='dynein axonemal heavy chain 11', other_designations='dynein axonemal heavy chain 11|axonemal beta dynein heavy chain 11|axonemal dynein heavy chain 11|ciliary dynein heavy chain 11|dynein heavy chain 11, axonemal|dynein, axonemal, heavy polypeptide 11|dynein, ciliary, heavy chain 11', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=21543039, end_position_on_the_genomic_accession=21901839, orientation='plus', exon_count=82, OMIM=[603339], no_hdr0=''),
    8702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8702, CurrentID=0, Status='live', Symbol='B4GALT4', Aliases=['B4Gal-T4', 'beta4Gal-T4'], description='beta-1,4-galactosyltransferase 4', other_designations='beta-1,4-galactosyltransferase 4|N-acetyllactosamine synthase|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 4|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase 4|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase, polypeptide 4|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 4|beta-1,4-GalTase 4|beta-N-acetylglucosaminyl-glycolipid beta-1,4-galactosyltransferase 4|lactotriaosylceramide beta-1,4-galactosyltransferase|nal synthase', map_location='3q13.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119211742, end_position_on_the_genomic_accession=119240907, orientation='minus', exon_count=13, OMIM=[604015], no_hdr0=''),
    8703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8703, CurrentID=0, Status='live', Symbol='B4GALT3', Aliases=['beta4Gal-T3'], description='beta-1,4-galactosyltransferase 3', other_designations='beta-1,4-galactosyltransferase 3|N-acetyllactosamine synthase|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 3|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase, polypeptide 3|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 3|b4Gal-T3|beta-1,4-GalTase 3|beta-N-acetylglucosaminyl-glycolipid beta-1,4-galactosyltransferase 3|beta-N-acetylglucosaminylglycopeptide beta-1,4-galactosyltransferase|epididymis secretory sperm binding protein|nal synthase|neolactotriaosylceramide beta-1,4-galactosyltransferase', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161171310, end_position_on_the_genomic_accession=161185007, orientation='minus', exon_count=9, OMIM=[604014], no_hdr0=''),
    8704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8704, CurrentID=0, Status='live', Symbol='B4GALT2', Aliases=['B4Gal-T2', 'B4Gal-T3', 'beta4Gal-T2'], description='beta-1,4-galactosyltransferase 2', other_designations='beta-1,4-galactosyltransferase 2|N-acetyllactosamine synthase|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 2|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase 2|UDP-Gal:betaGlcNAc beta 1,4-galactosyltransferase, polypeptide 2|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 2|beta-1,4-GalTase 2|beta-4-GalT2|beta-N-acetylglucosaminyl-glycolipid beta-1,4-galactosyltransferase 2|beta-N-acetylglucosaminylglycopeptide beta-1,4-galactosyltransferase|lactose synthase A protein|nal synthase', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43979210, end_position_on_the_genomic_accession=43991171, orientation='plus', exon_count=10, OMIM=[604013], no_hdr0=''),
    8705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8705, CurrentID=0, Status='live', Symbol='B3GALT4', Aliases=['BETA3GALT4', 'GALT2', 'GALT4'], description='beta-1,3-galactosyltransferase 4', other_designations='beta-1,3-galactosyltransferase 4|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase 4|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 4|UDP-galactose:beta-N-acetyl-galactosamine-beta-1,3-galactosyltransferase|b3Gal-T4|beta-1,3-GalTase 4|beta-3-galactosyltransferase 4|gal-T2|ganglioside galactosyltransferase', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33277123, end_position_on_the_genomic_accession=33278825, orientation='plus', exon_count=1, OMIM=[603095], no_hdr0=''),
    8706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8706, CurrentID=0, Status='live', Symbol='B3GALNT1', Aliases=['B3GALT3', 'GLCT3', 'GLOB', 'Gb4Cer', 'P', 'P1', 'beta3Gal-T3', 'galT3'], description='beta-1,3-N-acetylgalactosaminyltransferase 1 (globoside blood group)', other_designations='UDP-GalNAc:beta-1,3-N-acetylgalactosaminyltransferase 1|P antigen synthase|P blood group globoside|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 3 (Globoside blood group)|UDP-GalNAc:betaGlcNAc beta-1,3-galactosaminyltransferase, polypeptide 1 (Globoside blood group)|UDP-N-acetylgalactosamine:globotriaosylceramide beta-1,3-N-acetylgalactosaminyltransferase|b3Gal-T3|beta-1,3-GalNAc-T1|beta-1,3-GalTase 3|beta-1,3-galactosyltransferase 3|beta-3-Gx-T3|brainiac1|galactosylgalactosylglucosylceramide beta-D-acetyl-galactosaminyltransferase|globoside synthase|globotriaosylceramide 3-beta-N-acetylgalactosaminyltransferase', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=161083883, end_position_on_the_genomic_accession=161105469, orientation='minus', exon_count=10, OMIM=[603094], no_hdr0=''),
    8707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8707, CurrentID=0, Status='live', Symbol='B3GALT2', Aliases=['BETA3GALT2', 'GLCT2', 'beta3Gal-T2'], description='beta-1,3-galactosyltransferase 2', other_designations='beta-1,3-galactosyltransferase 2|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 2|UDP-galactose:2-acetamido-2-deoxy-D-glucose 3beta-galactosyltransferase 2|beta-1,3-GalTase 2|beta-3-galt2', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=193178730, end_position_on_the_genomic_accession=193186613, orientation='minus', exon_count=2, OMIM=[603018], no_hdr0=''),
    8708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8708, CurrentID=0, Status='live', Symbol='B3GALT1', Aliases=['beta3Gal-T1'], description='beta-1,3-galactosyltransferase 1', other_designations='beta-1,3-galactosyltransferase 1|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 1|UDP-galactose:beta-N-acetyl-glucosamine-beta-1,3-galactosyltransferase 1|beta-1,3-GalTase 1|beta3GalT1', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=167293001, end_position_on_the_genomic_accession=167874045, orientation='plus', exon_count=6, OMIM=[603093], no_hdr0=''),
    8710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8710, CurrentID=0, Status='live', Symbol='SERPINB7', Aliases=['MEGSIN', 'PPKN', 'TP55'], description='serpin family B member 7', other_designations='serpin B7|mesangium predominant gene, megsin|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 7|serpin peptidase inhibitor, clade B (ovalbumin), member 7', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63753057, end_position_on_the_genomic_accession=63805370, orientation='plus', exon_count=11, OMIM=[603357], no_hdr0=''),
    8711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8711, CurrentID=0, Status='live', Symbol='TNK1', Aliases=['KOS1'], description='tyrosine kinase non receptor 1', other_designations='non-receptor tyrosine-protein kinase TNK1|CD38 negative kinase 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7380559, end_position_on_the_genomic_accession=7389964, orientation='plus', exon_count=14, OMIM=[608076], no_hdr0=''),
    8712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8712, CurrentID=0, Status='live', Symbol='PAGE1', Aliases=['AL5', 'CT16.3', 'GAGE-9', 'GAGEB1', 'PAGE-1'], description='PAGE family member 1', other_designations='P antigen family member 1|G antigen 9|G antigen family B member 1|G antigen, family B, 1 (prostate associated)|P antigen family, member 1 (prostate associated)|prostate associated gene 1|prostate-associated gene 1 protein', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49687447, end_position_on_the_genomic_accession=49696019, orientation='minus', exon_count=6, OMIM=[300288], no_hdr0=''),
    8714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8714, CurrentID=0, Status='live', Symbol='ABCC3', Aliases=['ABC31', 'EST90757', 'MLP2', 'MOAT-D', 'MRP3', 'cMOAT2'], description='ATP binding cassette subfamily C member 3', other_designations='ATP-binding cassette sub-family C member 3|ATP-binding cassette, sub-family C (CFTR/MRP), member 3|canalicular multispecific organic anion transporter 2|canicular multispecific organic anion transporter|multi-specific organic anion transporter D|multidrug resistance associated protein|multidrug resistance-associated protein 3', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50634881, end_position_on_the_genomic_accession=50692253, orientation='plus', exon_count=31, OMIM=[604323], no_hdr0=''),
    8715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8715, CurrentID=0, Status='live', Symbol='NOL4', Aliases=['CT125', 'HRIHFB2255', 'NOLP'], description='nucleolar protein 4', other_designations='nucleolar protein 4|cancer/testis antigen 125|nucleolar localized protein', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=33851100, end_position_on_the_genomic_accession=34224957, orientation='minus', exon_count=22, OMIM=[603577], no_hdr0=''),
    8717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8717, CurrentID=0, Status='live', Symbol='TRADD', Aliases=['Hs.89862'], description='TNFRSF1A associated via death domain', other_designations='tumor necrosis factor receptor type 1-associated DEATH domain protein|TNFR1-associated death domain protein|tumor necrosis factor receptor type 1 associated death domain protein|tumor necrosis factor receptor-1-associated protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67154185, end_position_on_the_genomic_accession=67159909, orientation='minus', exon_count=6, OMIM=[603500], no_hdr0=''),
    8718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8718, CurrentID=0, Status='live', Symbol='TNFRSF25', Aliases=['APO-3', 'DDR3', 'DR3', 'GEF720', 'LARD', 'PLEKHG5', 'TNFRSF12', 'TR3', 'TRAMP', 'WSL-1', 'WSL-LR'], description='TNF receptor superfamily member 25', other_designations='tumor necrosis factor receptor superfamily member 25|Guanine nucleotide exchange factor 720|PH domain-containing family G member 5|Pleckstrin homology domain-containing family G member 5|apoptosis inducing receptor|apoptosis-inducing receptor AIR|apoptosis-mediating receptor DR3|apoptosis-mediating receptor TRAMP|death domain receptor 3 soluble form|death receptor beta|lymphocyte-associated receptor of death|protein WSL-1|tumor necrosis factor receptor superfamily, member 12 (translocating chain-association membrane protein)', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6460786, end_position_on_the_genomic_accession=6466173, orientation='minus', exon_count=10, OMIM=[603366], no_hdr0=''),
    8720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8720, CurrentID=0, Status='live', Symbol='MBTPS1', Aliases=['PCSK8', 'S1P', 'SEDKF', 'SKI-1'], description='membrane bound transcription factor peptidase, site 1', other_designations='membrane-bound transcription factor site-1 protease|endopeptidase S1P|proprotein convertase subtilisin/kexin type 8|site-1 protease|subtilisin/kexin isozyme-1', map_location='16q23.3-q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84053763, end_position_on_the_genomic_accession=84116942, orientation='minus', exon_count=24, OMIM=[603355], no_hdr0=''),
    8721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8721, CurrentID=0, Status='live', Symbol='EDF1', Aliases=['CFAP280', 'EDF-1', 'MBF1'], description='endothelial differentiation related factor 1', other_designations='endothelial differentiation-related factor 1|multiprotein bridging factor 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136862119, end_position_on_the_genomic_accession=136866308, orientation='minus', exon_count=5, OMIM=[605107], no_hdr0=''),
    8722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8722, CurrentID=0, Status='live', Symbol='CTSF', Aliases=['CATSF', 'CLN13'], description='cathepsin F', other_designations='cathepsin F', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66563463, end_position_on_the_genomic_accession=66568606, orientation='minus', exon_count=14, OMIM=[603539], no_hdr0=''),
    8723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8723, CurrentID=0, Status='live', Symbol='SNX4', Aliases=['ATG24B'], description='sorting nexin 4', other_designations='sorting nexin-4', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=125446644, end_position_on_the_genomic_accession=125520202, orientation='minus', exon_count=15, OMIM=[605931], no_hdr0=''),
    8724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8724, CurrentID=0, Status='live', Symbol='SNX3', Aliases=['Grd19', 'MCOPS8', 'SDP3'], description='sorting nexin 3', other_designations='sorting nexin-3|sorting nexin 3A', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108211222, end_position_on_the_genomic_accession=108261040, orientation='minus', exon_count=4, OMIM=[605930], no_hdr0=''),
    8725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8725, CurrentID=0, Status='live', Symbol='URI1', Aliases=['C19orf2', 'NNX3', 'PPP1R19', 'RMP', 'URI'], description='URI1 prefoldin like chaperone', other_designations='unconventional prefoldin RPB5 interactor 1|RNA polymerase II subunit 5-mediating protein|RPB5-mediating protein|protein phosphatase 1, regulatory subunit 19', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29923650, end_position_on_the_genomic_accession=30016612, orientation='plus', exon_count=14, OMIM=[603494], no_hdr0=''),
    8726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8726, CurrentID=0, Status='live', Symbol='EED', Aliases=['COGIS', 'HEED', 'WAIT1'], description='embryonic ectoderm development', other_designations='polycomb protein EED|WD protein associating with integrin cytoplasmic tails 1|embryonic ectoderm development protein', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86244753, end_position_on_the_genomic_accession=86285420, orientation='plus', exon_count=14, OMIM=[605984], no_hdr0=''),
    8727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8727, CurrentID=0, Status='live', Symbol='CTNNAL1', Aliases=['ACRP', 'CLLP', 'alpha-CATU'], description='catenin alpha like 1', other_designations='alpha-catulin|alpha-catenin-related protein|alpha2-catulin|catenin (cadherin-associated protein), alpha-like 1|catenin alpha-like protein 1', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=108942569, end_position_on_the_genomic_accession=109013535, orientation='minus', exon_count=20, OMIM=[604785], no_hdr0=''),
    8728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8728, CurrentID=0, Status='live', Symbol='ADAM19', Aliases=['FKSG34', 'MADDAM', 'MLTNB'], description='ADAM metallopeptidase domain 19', other_designations='disintegrin and metalloproteinase domain-containing protein 19|a disintegrin and metalloproteinase domain 19 (meltrin beta)|metalloprotease and disintegrin dendritic antigen marker|metalloprotease-disintegrin meltrin beta', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157477304, end_position_on_the_genomic_accession=157575775, orientation='minus', exon_count=23, OMIM=[603640], no_hdr0=''),
    8729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8729, CurrentID=0, Status='live', Symbol='GBF1', Aliases=['ARF1GEF'], description='golgi brefeldin A resistant guanine nucleotide exchange factor 1', other_designations='Golgi-specific brefeldin A-resistance guanine nucleotide exchange factor 1|BFA-resistant GEF 1', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102230643, end_position_on_the_genomic_accession=102382899, orientation='plus', exon_count=42, OMIM=[603698], no_hdr0=''),
    8731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8731, CurrentID=0, Status='live', Symbol='RNMT', Aliases=['CMT1', 'CMT1c', 'MET', 'Met', 'RG7MT1', 'cm1p', 'hCMT1', 'hMet'], description='RNA guanine-7 methyltransferase', other_designations='mRNA cap guanine-N7 methyltransferase|RNA (guanine-7-) methyltransferase|hcm1p|mRNA (guanine-7-)methyltransferase|mRNA (guanine-N(7)-)-methyltransferase|mRNA cap methyltransferase', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=13726645, end_position_on_the_genomic_accession=13764556, orientation='plus', exon_count=15, OMIM=[603514], no_hdr0=''),
    8732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8732, CurrentID=0, Status='live', Symbol='RNGTT', Aliases=['CAP1A', 'HCE', 'HCE1', 'hCAP'], description="RNA guanylyltransferase and 5'-phosphatase", other_designations='mRNA-capping enzyme|HCAP1', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=88609897, end_position_on_the_genomic_accession=88963618, orientation='minus', exon_count=19, OMIM=[603512], no_hdr0=''),
    8733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8733, CurrentID=0, Status='live', Symbol='GPAA1', Aliases=['GAA1', 'GPIBD15', 'hGAA1'], description='glycosylphosphatidylinositol anchor attachment 1', other_designations='glycosylphosphatidylinositol anchor attachment 1 protein|GAA1 protein homolog|GPAA1P anchor attachment protein 1 homolog|GPI anchor attachment protein 1|GPI transamidase subunit|anchor attachment protein 1 (Gaa1p, yeast) homolog|glycophosphatidylinositol anchor attachment 1|glycosylphosphatidylinositol anchor attachment protein 1 homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144082634, end_position_on_the_genomic_accession=144086216, orientation='plus', exon_count=12, OMIM=[603048], no_hdr0=''),
    8735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8735, CurrentID=0, Status='live', Symbol='MYH13', Aliases=['MyHC-IIL', 'MyHC-eo'], description='myosin heavy chain 13', other_designations='myosin-13|extraocular muscle myosin heavy chain|extraocular myosin heavy chain|myosin heavy chain, skeletal muscle, extraocular|myosin heavy chain, skeletal muscle, laryngeal|myosin, heavy chain 13, skeletal muscle|myosin, heavy polypeptide 13, skeletal muscle|superfast myosin', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10300865, end_position_on_the_genomic_accession=10373006, orientation='minus', exon_count=41, OMIM=[603487], no_hdr0=''),
    8736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8736, CurrentID=0, Status='live', Symbol='MYOM1', Aliases=['SKELEMIN'], description='myomesin 1', other_designations='myomesin-1|190 kDa connectin-associated protein|190 kDa titin-associated protein|EH-myomesin|myomesin (M-protein) 1 (190kD)|myomesin 1 (skelemin) 185kDa|myomesin 1 variant 1|myomesin 1, 185kDa|myomesin family member 1', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=3066807, end_position_on_the_genomic_accession=3220108, orientation='minus', exon_count=38, OMIM=[603508], no_hdr0=''),
    8737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8737, CurrentID=0, Status='live', Symbol='RIPK1', Aliases=['AIEFL', 'IMD57', 'RIP', 'RIP-1', 'RIP1'], description='receptor interacting serine/threonine kinase 1', other_designations='receptor-interacting serine/threonine-protein kinase 1|cell death protein RIP|receptor (TNFRSF)-interacting serine-threonine kinase 1|receptor-interacting protein 1|receptor-interacting protein kinase 1|serine/threonine-protein kinase RIP', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3063967, end_position_on_the_genomic_accession=3115187, orientation='plus', exon_count=16, OMIM=[603453], no_hdr0=''),
    8738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8738, CurrentID=0, Status='live', Symbol='CRADD', Aliases=['MRT34', 'RAIDD'], description='CASP2 and RIPK1 domain containing adaptor with death domain', other_designations='death domain-containing protein CRADD|CRADD/LYZ fusion|RIP-associated ICH1/CED3-homologous protein with death domain|caspase and RIP adaptor with death domain|death adaptor molecule RAIDD|death domain containing protein CRADD', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=93677342, end_position_on_the_genomic_accession=93894840, orientation='plus', exon_count=13, OMIM=[603454], no_hdr0=''),
    8739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8739, CurrentID=0, Status='live', Symbol='HRK', Aliases=['DP5', 'HARAKIRI'], description='harakiri, BCL2 interacting protein', other_designations='activator of apoptosis harakiri|BH3-interacting domain-containing protein 3|activator of apoptosis Hrk|death protein 5|harakiri, BCL2 interacting protein (contains only BH3 domain)|neuronal death protein DP5', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=116856144, end_position_on_the_genomic_accession=116881441, orientation='minus', exon_count=6, OMIM=[603447], no_hdr0=''),
    8740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8740, CurrentID=0, Status='live', Symbol='TNFSF14', Aliases=['CD258', 'HVEML', 'LIGHT', 'LTg'], description='TNF superfamily member 14', other_designations='tumor necrosis factor ligand superfamily member 14|herpesvirus entry mediator ligand|tumor necrosis factor (ligand) superfamily, member 14|tumor necrosis factor ligand 1D|tumor necrosis factor superfamily member 14', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6658126, end_position_on_the_genomic_accession=6670595, orientation='minus', exon_count=6, OMIM=[604520], no_hdr0=''),
    8741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8741, CurrentID=0, Status='live', Symbol='TNFSF13', Aliases=['APRIL', 'CD256', 'TALL-2', 'TALL2', 'TNLG7B', 'TRDL-1', 'UNQ383/PRO715', 'ZTNF2'], description='TNF superfamily member 13', other_designations='tumor necrosis factor ligand superfamily member 13|TNF- and APOL-related leukocyte expressed ligand 2|a proliferation-inducing ligand|tumor necrosis factor (ligand) superfamily, member 13|tumor necrosis factor ligand 7B|tumor necrosis factor superfamily member 13|tumor necrosis factor-like protein ZTNF2|tumor necrosis factor-related death ligand-1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7558282, end_position_on_the_genomic_accession=7561601, orientation='plus', exon_count=7, OMIM=[604472], no_hdr0=''),
    8742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8742, CurrentID=0, Status='live', Symbol='TNFSF12', Aliases=['APO3L', 'DR3LG', 'TNLG4A', 'TWEAK'], description='TNF superfamily member 12', other_designations='tumor necrosis factor ligand superfamily member 12|APO3 ligand|APO3/DR3 ligand|TNF-related WEAK inducer of apoptosis|tumor necrosis factor (ligand) superfamily, member 12|tumor necrosis factor ligand 4A|tumor necrosis factor superfamily member 12', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7549058, end_position_on_the_genomic_accession=7557881, orientation='plus', exon_count=8, OMIM=[602695], no_hdr0=''),
    8743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8743, CurrentID=0, Status='live', Symbol='TNFSF10', Aliases=['APO2L', 'Apo-2L', 'CD253', 'TL2', 'TNLG6A', 'TRAIL'], description='TNF superfamily member 10', other_designations='tumor necrosis factor ligand superfamily member 10|Apo-2 ligand|TNF-related apoptosis inducing ligand TRAIL|chemokine tumor necrosis factor ligand superfamily member 10|tumor necrosis factor (ligand) family, member 10|tumor necrosis factor (ligand) superfamily, member 10|tumor necrosis factor apoptosis-inducing ligand splice variant delta|tumor necrosis factor ligand 6A|tumor necrosis factor superfamily member 10', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172505508, end_position_on_the_genomic_accession=172523430, orientation='minus', exon_count=6, OMIM=[603598], no_hdr0=''),
    8744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8744, CurrentID=0, Status='live', Symbol='TNFSF9', Aliases=['4-1BB-L', 'CD137L', 'TNLG5A'], description='TNF superfamily member 9', other_designations='tumor necrosis factor ligand superfamily member 9|4-1BB ligand|4-1BBL|CD137 ligand|homolog of mouse 4-1BB-L|receptor 4-1BB ligand|tumor necrosis factor (ligand) superfamily, member 9|tumor necrosis factor ligand 5A|tumor necrosis factor superfamily member 9', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6531026, end_position_on_the_genomic_accession=6535924, orientation='plus', exon_count=3, OMIM=[606182], no_hdr0=''),
    8745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8745, CurrentID=0, Status='live', Symbol='ADAM23', Aliases=['MDC-3', 'MDC3'], description='ADAM metallopeptidase domain 23', other_designations='disintegrin and metalloproteinase domain-containing protein 23|metalloproteinase-like, disintegrin-like, and cysteine-rich protein 3', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206443532, end_position_on_the_genomic_accession=206621127, orientation='plus', exon_count=27, OMIM=[603710], no_hdr0=''),
    8747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8747, CurrentID=0, Status='live', Symbol='ADAM21', Aliases=['ADAM 21', 'ADAM31'], description='ADAM metallopeptidase domain 21', other_designations='disintegrin and metalloproteinase domain-containing protein 21|ADAM metallopeptidase domain 21, preproprotein|a disintegrin and metalloproteinase domain 21', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70452174, end_position_on_the_genomic_accession=70459905, orientation='plus', exon_count=2, OMIM=[603713], no_hdr0=''),
    8748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8748, CurrentID=0, Status='live', Symbol='ADAM20', Aliases=[], description='ADAM metallopeptidase domain 20', other_designations='disintegrin and metalloproteinase domain-containing protein 20|ADAM 20|a disintegrin and metalloproteinase domain 20', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70520817, end_position_on_the_genomic_accession=70564742, orientation='minus', exon_count=3, OMIM=[603712], no_hdr0=''),
    8749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8749, CurrentID=0, Status='live', Symbol='ADAM18', Aliases=['ADAM27', 'tMDCIII'], description='ADAM metallopeptidase domain 18', other_designations='disintegrin and metalloproteinase domain-containing protein 18|a disintegrin and metalloproteinase domain 18|transmembrane metalloproteinase-like, disintegrin-like, and cysteine-rich protein III', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=39584568, end_position_on_the_genomic_accession=39730065, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    8751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8751, CurrentID=0, Status='live', Symbol='ADAM15', Aliases=['MDC15'], description='ADAM metallopeptidase domain 15', other_designations='disintegrin and metalloproteinase domain-containing protein 15|MDC-15|a disintegrin and metalloproteinase domain 15 (metargidin)|metalloprotease RGD disintegrin protein|metalloproteinase-like, disintegrin-like, and cysteine-rich protein 15', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155051316, end_position_on_the_genomic_accession=155062775, orientation='plus', exon_count=24, OMIM=[605548], no_hdr0=''),
    8754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8754, CurrentID=0, Status='live', Symbol='ADAM9', Aliases=['CORD9', 'MCMP', 'MDC9', 'Mltng'], description='ADAM metallopeptidase domain 9', other_designations='disintegrin and metalloproteinase domain-containing protein 9|ADAM metallopeptidase domain 9 (meltrin gamma)|cellular disintegrin-related protein|cone rod dystrophy 9|metalloprotease/disintegrin/cysteine-rich protein 9|myeloma cell metalloproteinase', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38996767, end_position_on_the_genomic_accession=39105261, orientation='plus', exon_count=25, OMIM=[602713], no_hdr0=''),
    8756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8756, CurrentID=0, Status='live', Symbol='ADAM7', Aliases=['ADAM 7', 'ADAM-7', 'EAPI', 'GP-83', 'GP83'], description='ADAM metallopeptidase domain 7', other_designations='disintegrin and metalloproteinase domain-containing protein 7|a disintegrin and metalloproteinase domain 7|epididymal apical protein I|epididymis secretory sperm binding protein|sperm maturation-related glycoprotein GP-83', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=24441026, end_position_on_the_genomic_accession=24509565, orientation='plus', exon_count=22, OMIM=[607310], no_hdr0=''),
    8760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8760, CurrentID=0, Status='live', Symbol='CDS2', Aliases=[], description='CDP-diacylglycerol synthase 2', other_designations='phosphatidate cytidylyltransferase 2|CDP-DAG synthase 2|CDP-DG synthase 2|CDP-DG synthetase 2|CDP-diacylglycerol synthase (phosphatidate cytidylyltransferase) 2|CDP-diglyceride diphosphorylase 2|CDP-diglyceride pyrophosphorylase 2|CDP-diglyceride synthase 2|CDP-diglyceride synthetase 2|CDS 2|CTP:phosphatidate cytidylyltransferase 2', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5126844, end_position_on_the_genomic_accession=5197887, orientation='plus', exon_count=15, OMIM=[603549], no_hdr0=''),
    8761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8761, CurrentID=0, Status='live', Symbol='PABPC4', Aliases=['APP-1', 'APP1', 'PABP4', 'iPABP'], description='poly(A) binding protein cytoplasmic 4', other_designations='polyadenylate-binding protein 4|PABP-4|activated-platelet protein 1|inducible poly(A)-binding protein|poly(A) binding protein, cytoplasmic 4 (inducible form)|poly(A)-binding protein 4', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39560816, end_position_on_the_genomic_accession=39576790, orientation='minus', exon_count=16, OMIM=[603407], no_hdr0=''),
    8763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8763, CurrentID=0, Status='live', Symbol='CD164', Aliases=['DFNA66', 'MGC-24', 'MGC-24v', 'MUC-24', 'endolyn'], description='CD164 molecule', other_designations='sialomucin core protein 24|CD164 antigen, sialomucin|multi-glycosylated core protein 24', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109366514, end_position_on_the_genomic_accession=109382467, orientation='minus', exon_count=7, OMIM=[603356], no_hdr0=''),
    8764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8764, CurrentID=0, Status='live', Symbol='TNFRSF14', Aliases=['ATAR', 'CD270', 'HVEA', 'HVEM', 'LIGHTR', 'TR2'], description='TNF receptor superfamily member 14', other_designations='tumor necrosis factor receptor superfamily member 14|CD40-like protein|herpes virus entry mediator A|tumor necrosis factor receptor superfamily, member 14 (herpesvirus entry mediator)|tumor necrosis factor receptor-like gene2', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2556371, end_position_on_the_genomic_accession=2563829, orientation='plus', exon_count=8, OMIM=[602746], no_hdr0=''),
    8766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8766, CurrentID=0, Status='live', Symbol='RAB11A', Aliases=['YL8'], description='RAB11A, member RAS oncogene family', other_designations='ras-related protein Rab-11A|RAB 11A, member oncogene family|rab-11', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65869491, end_position_on_the_genomic_accession=65891989, orientation='plus', exon_count=5, OMIM=[605570], no_hdr0=''),
    8767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8767, CurrentID=0, Status='live', Symbol='RIPK2', Aliases=['CARD3', 'CARDIAK', 'CCK', 'GIG30', 'RICK', 'RIP2'], description='receptor interacting serine/threonine kinase 2', other_designations='receptor-interacting serine/threonine-protein kinase 2|CARD-carrying kinase|CARD-containing IL-1 beta ICE-kinase|CARD-containing interleukin-1 beta-converting enzyme (ICE)-associated kinase|RIP-2|growth-inhibiting gene 30|receptor-interacting protein (RIP)-like interacting caspase-like apoptosis regulatory protein (CLARP) kinase|receptor-interacting protein 2|tyrosine-protein kinase RIPK2', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=89757816, end_position_on_the_genomic_accession=89791064, orientation='plus', exon_count=12, OMIM=[603455], no_hdr0=''),
    8771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8771, CurrentID=0, Status='live', Symbol='TNFRSF6B', Aliases=['DCR3', 'DJ583P15.1.1', 'M68', 'M68E', 'TR6'], description='TNF receptor superfamily member 6b', other_designations='tumor necrosis factor receptor superfamily member 6B|decoy receptor 3 variant 1|decoy receptor 3 variant 2|decoy receptor for Fas ligand|tumor necrosis factor receptor superfamily, member 6b, decoy', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63696652, end_position_on_the_genomic_accession=63698684, orientation='plus', exon_count=3, OMIM=[603361], no_hdr0=''),
    8772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8772, CurrentID=0, Status='live', Symbol='FADD', Aliases=['GIG3', 'MORT1'], description='Fas associated via death domain', other_designations='FAS-associated death domain protein|Fas (TNFRSF6)-associated via death domain|Fas-associating death domain-containing protein|Fas-associating protein with death domain|growth-inhibiting gene 3 protein|mediator of receptor-induced toxicity', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=70203296, end_position_on_the_genomic_accession=70207390, orientation='plus', exon_count=2, OMIM=[602457], no_hdr0=''),
    8773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8773, CurrentID=0, Status='live', Symbol='SNAP23', Aliases=['HsT17016', 'SNAP-23A', 'SNAP23B', 'SNAP23'], description='synaptosome associated protein 23', other_designations='synaptosomal-associated protein 23|synaptosomal-associated protein, 23kD|synaptosomal-associated protein, 23kDa|synaptosome associated protein 23kDa|vesicle-membrane fusion protein SNAP-23', map_location='15q15.1-q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42491244, end_position_on_the_genomic_accession=42533058, orientation='plus', exon_count=11, OMIM=[602534], no_hdr0=''),
    8774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8774, CurrentID=0, Status='live', Symbol='NAPG', Aliases=['GAMMASNAP'], description='NSF attachment protein gamma', other_designations='gamma-soluble NSF attachment protein|N-ethylmaleimide-sensitive factor attachment protein, gamma|SNAP-gamma|soluble NSF attachment protein', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=10526027, end_position_on_the_genomic_accession=10552769, orientation='plus', exon_count=15, OMIM=[603216], no_hdr0=''),
    8775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8775, CurrentID=0, Status='live', Symbol='NAPA', Aliases=['SNAPA'], description='NSF attachment protein alpha', other_designations='alpha-soluble NSF attachment protein|N-ethylmaleimide-sensitive factor attachment protein, alpha|alpha-SNAP', map_location='19q13.32-q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47487637, end_position_on_the_genomic_accession=47515091, orientation='minus', exon_count=12, OMIM=[603215], no_hdr0=''),
    8776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8776, CurrentID=0, Status='live', Symbol='MTMR1', Aliases=[], description='myotubularin related protein 1', other_designations='myotubularin-related protein 1|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphate phosphatase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=150692962, end_position_on_the_genomic_accession=150765108, orientation='plus', exon_count=23, OMIM=[300171], no_hdr0=''),
    8777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8777, CurrentID=0, Status='live', Symbol='MPDZ', Aliases=['HYC2', 'MUPP1'], description='multiple PDZ domain crumbs cell polarity complex component', other_designations='multiple PDZ domain protein|multi-PDZ domain protein 1', map_location='9p23', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=13105296, end_position_on_the_genomic_accession=13279692, orientation='minus', exon_count=51, OMIM=[603785], no_hdr0=''),
    8778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8778, CurrentID=0, Status='live', Symbol='SIGLEC5', Aliases=['CD170', 'CD33L2', 'OB-BP2', 'OBBP2', 'SIGLEC-5'], description='sialic acid binding Ig like lectin 5', other_designations='sialic acid-binding Ig-like lectin 5|CD33 antigen-like 2|OB-binding protein 2|obesity-binding protein 2|sialic acid-binding immunoglobulin-like lectin 5', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51610960, end_position_on_the_genomic_accession=51630428, orientation='minus', exon_count=9, OMIM=[604200], no_hdr0=''),
    8780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8780, CurrentID=0, Status='live', Symbol='RIOK3', Aliases=['SUDD'], description='RIO kinase 3', other_designations='serine/threonine-protein kinase RIO3|homolog of the Aspergillus nidulans sudD gene product|sudD (suppressor of bimD6, Aspergillus nidulans) homolog|sudD homolog|sudD suppressor of Aspergillus nidulans bimD6 homolog|sudD suppressor of bimD6 homolog|testicular secretory protein Li 47', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23452823, end_position_on_the_genomic_accession=23483140, orientation='plus', exon_count=12, OMIM=[603579], no_hdr0=''),
    8784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8784, CurrentID=0, Status='live', Symbol='TNFRSF18', Aliases=['AITR', 'CD357', 'ENERGEN', 'GITR', 'GITR-D'], description='TNF receptor superfamily member 18', other_designations='tumor necrosis factor receptor superfamily member 18|TNF receptor superfamily activation-inducible protein|activation-inducible TNFR family receptor|glucocorticoid-induced TNFR-related protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1203508, end_position_on_the_genomic_accession=1207901, orientation='minus', exon_count=5, OMIM=[603905], no_hdr0=''),
    8785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8785, CurrentID=0, Status='live', Symbol='MATN4', Aliases=[], description='matrilin 4', other_designations='matrilin-4', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45293446, end_position_on_the_genomic_accession=45308566, orientation='minus', exon_count=9, OMIM=[603897], no_hdr0=''),
    8786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8786, CurrentID=0, Status='live', Symbol='RGS11', Aliases=['RS11'], description='regulator of G protein signaling 11', other_designations='regulator of G-protein signaling 11|regulator of G-protein signalling 11', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=268301, end_position_on_the_genomic_accession=275944, orientation='minus', exon_count=20, OMIM=[603895], no_hdr0=''),
    8787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8787, CurrentID=0, Status='live', Symbol='RGS9', Aliases=['PERRSL', 'RGS9'], description='regulator of G protein signaling 9', other_designations='regulator of G-protein signaling 9|regulator of G-protein signalling 9', map_location='17q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=65137370, end_position_on_the_genomic_accession=65227703, orientation='plus', exon_count=19, OMIM=[604067], no_hdr0=''),
    8788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8788, CurrentID=0, Status='live', Symbol='DLK1', Aliases=['DLK', 'DLK-1', 'Delta1', 'FA1', 'PREF1', 'Pref-1', 'ZOG', 'pG2'], description='delta like non-canonical Notch ligand 1', other_designations='protein delta homolog 1|delta-like 1 homolog|fetal antigen 1|preadipocyte factor 1|secredeltin', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100726892, end_position_on_the_genomic_accession=100738224, orientation='plus', exon_count=5, OMIM=[176290], no_hdr0=''),
    8789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8789, CurrentID=0, Status='live', Symbol='FBP2', Aliases=[], description='fructose-bisphosphatase 2', other_designations='fructose-1,6-bisphosphatase isozyme 2|D-fructose-1,6-bisphosphate 1-phosphohydrolase 2|FBPase 2|fructose-1,6-bisphosphatase 2|hexosediphosphatase|muscle FBPase|muscle fructose-bisphosphatase', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94558720, end_position_on_the_genomic_accession=94593824, orientation='minus', exon_count=7, OMIM=[603027], no_hdr0=''),
    8790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8790, CurrentID=0, Status='live', Symbol='FPGT', Aliases=['GFPP'], description='fucose-1-phosphate guanylyltransferase', other_designations='fucose-1-phosphate guanylyltransferase|GDP-L-fucose diphosphorylase|GDP-beta-L-fucose pyrophosphorylase|fucose-1-phosphate guanyltransferase', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74198242, end_position_on_the_genomic_accession=74208702, orientation='plus', exon_count=5, OMIM=[603609], no_hdr0=''),
    8792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8792, CurrentID=0, Status='live', Symbol='TNFRSF11A', Aliases=['CD265', 'FEO', 'LOH18CR1', 'ODFR', 'OFE', 'OPTB7', 'OSTS', 'PDB2', 'RANK', 'TRANCE-R', 'TRANCER'], description='TNF receptor superfamily member 11a', other_designations='tumor necrosis factor receptor superfamily member 11A|Paget disease of bone 2|TRANCE receptor|familial expansile osteolysis|loss of heterozygosity, 18, chromosomal region 1|osteoclast differentiation factor receptor|receptor activator of NF-KB|receptor activator of nuclear factor-kappa B|tumor necrosis factor receptor superfamily, member 11a, NFKB activator', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=62325310, end_position_on_the_genomic_accession=62391288, orientation='plus', exon_count=12, OMIM=[603499], no_hdr0=''),
    8793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8793, CurrentID=0, Status='live', Symbol='TNFRSF10D', Aliases=['CD264', 'DCR2', 'TRAIL-R4', 'TRAILR4', 'TRUNDD'], description='TNF receptor superfamily member 10d', other_designations='tumor necrosis factor receptor superfamily member 10D|TNF receptor-related receptor for TRAIL|TNF-related apoptosis-inducing ligand receptor 4|TRAIL receptor 4|TRAIL receptor with a truncated death domain|decoy receptor 2|tumor necrosis factor receptor superfamily, member 10d, decoy with truncated death domain', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23135588, end_position_on_the_genomic_accession=23164027, orientation='minus', exon_count=9, OMIM=[603614], no_hdr0=''),
    8794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8794, CurrentID=0, Status='live', Symbol='TNFRSF10C', Aliases=['CD263', 'DCR1', 'DCR1-TNFR', 'LIT', 'TRAIL-R3', 'TRAILR3', 'TRID'], description='TNF receptor superfamily member 10c', other_designations='tumor necrosis factor receptor superfamily member 10C|TNF-related apoptosis-inducing ligand receptor 3|antagonist decoy receptor for TRAIL/Apo-2L|cytotoxic TRAIL receptor-3|decoy TRAIL receptor without death domain|decoy receptor 1|lymphocyte inhibitor of TRAIL|tumor necrosis factor receptor superfamily, member 10c, decoy without an intracellular domain', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23102921, end_position_on_the_genomic_accession=23117445, orientation='plus', exon_count=5, OMIM=[603613], no_hdr0=''),
    8795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8795, CurrentID=0, Status='live', Symbol='TNFRSF10B', Aliases=['CD262', 'DR5', 'KILLER', 'KILLER/DR5', 'TRAIL-R2', 'TRAILR2', 'TRICK2', 'TRICK2A', 'TRICK2B', 'TRICKB', 'ZTNFR9'], description='TNF receptor superfamily member 10b', other_designations='tumor necrosis factor receptor superfamily member 10B|Fas-like protein|TNF-related apoptosis-inducing ligand receptor 2|apoptosis inducing protein TRICK2A/2B|apoptosis inducing receptor TRAIL-R2|cytotoxic TRAIL receptor-2|death domain containing receptor for TRAIL/Apo-2L|death receptor 5|p53-regulated DNA damage-inducible cell death receptor(killer)|tumor necrosis factor receptor superfamily, member 10b|tumor necrosis factor receptor-like protein ZTNFR9', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23020133, end_position_on_the_genomic_accession=23069031, orientation='minus', exon_count=10, OMIM=[603612], no_hdr0=''),
    8796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8796, CurrentID=0, Status='live', Symbol='SCEL', Aliases=[], description='sciellin', other_designations='sciellin', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=77535694, end_position_on_the_genomic_accession=77645263, orientation='plus', exon_count=33, OMIM=[604112], no_hdr0=''),
    8797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8797, CurrentID=0, Status='live', Symbol='TNFRSF10A', Aliases=['APO2', 'CD261', 'DR4', 'TRAILR-1', 'TRAILR1'], description='TNF receptor superfamily member 10a', other_designations='tumor necrosis factor receptor superfamily member 10A|TNF-related apoptosis-inducing ligand receptor 1|TRAIL receptor 1|TRAIL-R1|cytotoxic TRAIL receptor|death receptor 4|tumor necrosis factor receptor superfamily member 10a variant 2|tumor necrosis factor receptor superfamily, member 10a', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23190452, end_position_on_the_genomic_accession=23225102, orientation='minus', exon_count=10, OMIM=[603611], no_hdr0=''),
    8798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8798, CurrentID=0, Status='live', Symbol='DYRK4', Aliases=[], description='dual specificity tyrosine phosphorylation regulated kinase 4', other_designations='dual specificity tyrosine-phosphorylation-regulated kinase 4|dual specificity tyrosine-(Y)-phosphorylation regulated kinase 4', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4562208, end_position_on_the_genomic_accession=4613875, orientation='plus', exon_count=17, OMIM=[609181], no_hdr0=''),
    8799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8799, CurrentID=0, Status='live', Symbol='PEX11B', Aliases=['PEX11-BETA', 'PEX14B'], description='peroxisomal biogenesis factor 11 beta', other_designations='peroxisomal membrane protein 11B|peroxin-11B|peroxisomal biogenesis factor 11B|protein PEX11 homolog beta', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145911348, end_position_on_the_genomic_accession=145918717, orientation='minus', exon_count=5, OMIM=[603867], no_hdr0=''),
    8800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8800, CurrentID=0, Status='live', Symbol='PEX11A', Aliases=['PEX11-ALPHA', 'PMP28', 'hsPEX11p'], description='peroxisomal biogenesis factor 11 alpha', other_designations='peroxisomal membrane protein 11A|28 kDa peroxisomal integral membrane protein|peroxin-11A|peroxisomal biogenesis factor 11A|protein PEX11 homolog alpha', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89681535, end_position_on_the_genomic_accession=89690754, orientation='minus', exon_count=3, OMIM=[603866], no_hdr0=''),
    8801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8801, CurrentID=0, Status='live', Symbol='SUCLG2', Aliases=['G-SCS', 'GBETA', 'GTPSCS'], description='succinate-CoA ligase GDP-forming subunit beta', other_designations='succinate--CoA ligase [GDP-forming] subunit beta, mitochondrial|GTP-specific succinyl-CoA synthetase beta subunit|GTP-specific succinyl-CoA synthetase subunit beta|SCS-betaG|succinate-CoA ligase GDP-forming beta subunit|succinyl-CoA ligase [GDP-forming] subunit beta, mitochondrial|succinyl-CoA ligase, GDP-forming, beta chain, mitochondrial|succinyl-CoA synthetase, beta-G chain', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=67360460, end_position_on_the_genomic_accession=67654612, orientation='minus', exon_count=14, OMIM=[603922], no_hdr0=''),
    8802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8802, CurrentID=0, Status='live', Symbol='SUCLG1', Aliases=['GALPHA', 'MTDPS9', 'SUCLA1'], description='succinate-CoA ligase GDP/ADP-forming subunit alpha', other_designations='succinate--CoA ligase [ADP/GDP-forming] subunit alpha, mitochondrial|SCS-alpha|succinate-CoA ligase alpha subunit|succinyl-CoA ligase [ADP/GDP-forming] subunit alpha, mitochondrial|succinyl-CoA ligase [GDP-forming] subunit alpha, mitochondrial|succinyl-CoA synthetase subunit alpha', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=84423528, end_position_on_the_genomic_accession=84459280, orientation='minus', exon_count=9, OMIM=[611224], no_hdr0=''),
    8803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8803, CurrentID=0, Status='live', Symbol='SUCLA2', Aliases=['A-BETA', 'A-SCS', 'LINC00444', 'MTDPS5', 'SCS-betaA'], description='succinate-CoA ligase ADP-forming subunit beta', other_designations='succinate--CoA ligase [ADP-forming] subunit beta, mitochondrial|ATP-specific succinyl-CoA synthetase subunit beta|ATP-specific succinyl-CoA synthetase, beta subunit|long intergenic non-protein coding RNA 444|mitochondrial succinyl-CoA ligase [ADP-forming] subunit beta|renal carcinoma antigen NY-REN-39|succinate-CoA ligase ADP-forming beta subunit|succinate-CoA ligase beta subunit|succinyl-CoA ligase [ADP-forming] subunit beta, mitochondrial|succinyl-CoA synthetase beta-A chain', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=47942656, end_position_on_the_genomic_accession=48001273, orientation='minus', exon_count=11, OMIM=[603921], no_hdr0=''),
    8804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8804, CurrentID=0, Status='live', Symbol='CREG1', Aliases=['CREG'], description='cellular repressor of E1A stimulated genes 1', other_designations='protein CREG1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167541013, end_position_on_the_genomic_accession=167553762, orientation='minus', exon_count=4, OMIM=[618055], no_hdr0=''),
    8805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8805, CurrentID=0, Status='live', Symbol='TRIM24', Aliases=['PTC6', 'RNF82', 'TF1A', 'TIF1', 'TIF1A', 'TIF1ALPHA', 'hTIF1'], description='tripartite motif containing 24', other_designations='transcription intermediary factor 1-alpha|E3 ubiquitin-protein ligase TRIM24|RING finger protein 82|RING-type E3 ubiquitin transferase TIF1-alpha|TIF1-alpha|transcriptional intermediary factor 1', map_location='7q33-q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138460259, end_position_on_the_genomic_accession=138589996, orientation='plus', exon_count=20, OMIM=[603406], no_hdr0=''),
    8807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8807, CurrentID=0, Status='live', Symbol='IL18RAP', Aliases=['ACPL', 'CD218b', 'CDw218b', 'IL-18R-beta', 'IL-18RAcP', 'IL-18Rbeta', 'IL-1R-7', 'IL-1R7', 'IL-1RAcPL', 'IL18RB'], description='interleukin 18 receptor accessory protein', other_designations='interleukin-18 receptor accessory protein|CD218 antigen-like family member B|IL-18 receptor accessory protein|IL-18 receptor beta|cluster of differentiation w218b|interleukin-1 receptor 7|interleukin-18 receptor beta', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102418550, end_position_on_the_genomic_accession=102452568, orientation='plus', exon_count=15, OMIM=[604509], no_hdr0=''),
    8808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8808, CurrentID=0, Status='live', Symbol='IL1RL2', Aliases=['IL-1Rrp2', 'IL-36R', 'IL1R-rp2', 'IL1RRP2'], description='interleukin 1 receptor like 2', other_designations='interleukin-1 receptor-like 2|IL-1 receptor-related protein 2|IL-36 receptor|interleukin-1 receptor-related protein 2', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102186973, end_position_on_the_genomic_accession=102242910, orientation='plus', exon_count=15, OMIM=[604512], no_hdr0=''),
    8809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8809, CurrentID=0, Status='live', Symbol='IL18R1', Aliases=['CD218a', 'CDw218a', 'IL-18R-alpha', 'IL-18Ralpha', 'IL-1Rrp', 'IL18RA', 'IL18Ralpha2', 'IL1RRP'], description='interleukin 18 receptor 1', other_designations='interleukin-18 receptor 1|CD218 antigen-like family member A|IL1 receptor-related protein|cytokine receptor|interleukin-18 receptor alpha', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102355796, end_position_on_the_genomic_accession=102398777, orientation='plus', exon_count=13, OMIM=[604494], no_hdr0=''),
    8811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8811, CurrentID=0, Status='live', Symbol='GALR2', Aliases=['GAL2-R', 'GALNR2', 'GALR-2'], description='galanin receptor 2', other_designations='galanin receptor type 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76070824, end_position_on_the_genomic_accession=76077537, orientation='plus', exon_count=4, OMIM=[603691], no_hdr0=''),
    8812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8812, CurrentID=0, Status='live', Symbol='CCNK', Aliases=['CPR4', 'IDDHDF'], description='cyclin K', other_designations='cyclin-K', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99481409, end_position_on_the_genomic_accession=99512440, orientation='plus', exon_count=12, OMIM=[603544], no_hdr0=''),
    8813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8813, CurrentID=0, Status='live', Symbol='DPM1', Aliases=['CDGIE', 'MPDS'], description='dolichyl-phosphate mannosyltransferase subunit 1, catalytic', other_designations='dolichol-phosphate mannosyltransferase subunit 1|DPM synthase complex, catalytic subunit|DPM synthase subunit 1|MPD synthase subunit 1|dolichol monophosphate mannose synthase|dolichol-phosphate mannose synthase subunit 1|dolichyl-phosphate beta-D-mannosyltransferase subunit 1|dolichyl-phosphate mannosyltransferase polypeptide 1 catalytic subunit|mannose-P-dolichol synthase subunit 1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50934855, end_position_on_the_genomic_accession=50958564, orientation='minus', exon_count=10, OMIM=[603503], no_hdr0=''),
    8814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8814, CurrentID=0, Status='live', Symbol='CDKL1', Aliases=['KKIALRE', 'P42'], description='cyclin dependent kinase like 1', other_designations='cyclin-dependent kinase-like 1|cyclin-dependent kinase-like 1 (CDC2-related kinase)|protein kinase p42 KKIALRE|serine/threonine protein kinase KKIALRE', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50326265, end_position_on_the_genomic_accession=50397399, orientation='minus', exon_count=14, OMIM=[603441], no_hdr0=''),
    8815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8815, CurrentID=0, Status='live', Symbol='BANF1', Aliases=['BAF', 'BCRP1', 'D14S1460', 'NGPS'], description='BAF nuclear assembly factor 1', other_designations='barrier-to-autointegration factor|barrier to autointegration factor 1|breakpoint cluster region protein 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66002079, end_position_on_the_genomic_accession=66004149, orientation='plus', exon_count=4, OMIM=[603811], no_hdr0=''),
    8816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8816, CurrentID=0, Status='live', Symbol='DCAF5', Aliases=['BCRG2', 'BCRP2', 'D14S1461E', 'WDR22'], description='DDB1 and CUL4 associated factor 5', other_designations='DDB1- and CUL4-associated factor 5|WD repeat-containing protein 22|breakpoint cluster region protein, uterine leiomyoma, 2', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69050881, end_position_on_the_genomic_accession=69153393, orientation='minus', exon_count=14, OMIM=[603812], no_hdr0=''),
    8817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8817, CurrentID=0, Status='live', Symbol='FGF18', Aliases=['FGF-18', 'ZFGF5'], description='fibroblast growth factor 18', other_designations='fibroblast growth factor 18', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=171419647, end_position_on_the_genomic_accession=171457626, orientation='plus', exon_count=5, OMIM=[603726], no_hdr0=''),
    8818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8818, CurrentID=0, Status='live', Symbol='DPM2', Aliases=['CDG1U'], description='dolichyl-phosphate mannosyltransferase subunit 2, regulatory', other_designations='dolichol phosphate-mannose biosynthesis regulatory protein|DPM synthase complex subunit|DPM synthase subunit 2|dolichol-phosphate mannose synthase subunit 2|dolichyl-phosphate mannosyltransferase polypeptide 2, regulatory subunit', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127935099, end_position_on_the_genomic_accession=127937854, orientation='minus', exon_count=5, OMIM=[603564], no_hdr0=''),
    8819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8819, CurrentID=0, Status='live', Symbol='SAP30', Aliases=[], description='Sin3A associated protein 30', other_designations='histone deacetylase complex subunit SAP30|30 kDa Sin3-associated polypeptide|Sin3 corepressor complex subunit SAP30|Sin3-associated polypeptide, 30kDa|Sin3A-associated protein, 30kDa|sin3-associated polypeptide p30|sin3-associated polypeptide, 30 kDa', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=173370954, end_position_on_the_genomic_accession=173377532, orientation='plus', exon_count=4, OMIM=[603378], no_hdr0=''),
    8820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8820, CurrentID=0, Status='live', Symbol='HESX1', Aliases=['ANF', 'CPHD5', 'RPX'], description='HESX homeobox 1', other_designations='homeobox expressed in ES cells 1|Rathke pouch homeobox|homeobox protein ANF', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57197838, end_position_on_the_genomic_accession=57227643, orientation='minus', exon_count=7, OMIM=[601802], no_hdr0=''),
    8821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8821, CurrentID=0, Status='live', Symbol='INPP4B', Aliases=[], description='inositol polyphosphate-4-phosphatase type II B', other_designations='inositol polyphosphate 4-phosphatase type II|inositol polyphosphate 4-phosphatase II; 4-phosphatase II|inositol polyphosphate-4-phosphatase, type II, 105kDa|type II inositol 3,4-bisphosphate 4-phosphatase', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=142023160, end_position_on_the_genomic_accession=142846535, orientation='minus', exon_count=45, OMIM=[607494], no_hdr0=''),
    8822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8822, CurrentID=0, Status='live', Symbol='FGF17', Aliases=['FGF-13', 'FGF-17', 'HH20'], description='fibroblast growth factor 17', other_designations='fibroblast growth factor 17', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22039708, end_position_on_the_genomic_accession=22048809, orientation='plus', exon_count=7, OMIM=[603725], no_hdr0=''),
    8823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8823, CurrentID=0, Status='live', Symbol='FGF16', Aliases=['FGF-16', 'MF4'], description='fibroblast growth factor 16', other_designations='fibroblast growth factor 16|metacarpal 4-5 fusion', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77447389, end_position_on_the_genomic_accession=77457278, orientation='plus', exon_count=3, OMIM=[300827, 309630], no_hdr0=''),
    8824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8824, CurrentID=0, Status='live', Symbol='CES2', Aliases=['CE-2A1', 'PCE-2', 'iCE', 'CES2'], description='carboxylesterase 2', other_designations='cocaine esterase|carboxylesterase 2 (intestine, liver)|intestinal carboxylesterase; liver carboxylesterase-2|methylumbelliferyl-acetate deacetylase 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66934471, end_position_on_the_genomic_accession=66945096, orientation='plus', exon_count=12, OMIM=[605278], no_hdr0=''),
    8825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8825, CurrentID=0, Status='live', Symbol='LIN7A', Aliases=['LIN-7A', 'LIN7', 'MALS-1', 'MALS1', 'TIP-33', 'VELI1'], description='lin-7 homolog A, crumbs cell polarity complex component', other_designations='protein lin-7 homolog A|mammalian lin-seven protein 1|tax interaction protein 33|vertebrate LIN7 homolog 1', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80792520, end_position_on_the_genomic_accession=80937934, orientation='minus', exon_count=7, OMIM=[603380], no_hdr0=''),
    8826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8826, CurrentID=0, Status='live', Symbol='IQGAP1', Aliases=['HUMORFA01', 'SAR1', 'p195'], description='IQ motif containing GTPase activating protein 1', other_designations='ras GTPase-activating-like protein IQGAP1|RasGAP-like with IQ motifs', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90388242, end_position_on_the_genomic_accession=90502239, orientation='plus', exon_count=39, OMIM=[603379], no_hdr0=''),
    8828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8828, CurrentID=0, Status='live', Symbol='NRP2', Aliases=['NP2', 'NPN2', 'PRO2714', 'VEGF165R2'], description='neuropilin 2', other_designations='neuropilin-2|neuropilin-2a(17)|neuropilin-2a(22)|neuropilin-2b(0)|receptor for VEGF165 and semaphorins class3|vascular endothelial cell growth factor 165 receptor 2', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=205682501, end_position_on_the_genomic_accession=205798131, orientation='plus', exon_count=20, OMIM=[602070], no_hdr0=''),
    8829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8829, CurrentID=0, Status='live', Symbol='NRP1', Aliases=['BDCA4', 'CD304', 'NP1', 'NRP', 'VEGF165R'], description='neuropilin 1', other_designations='neuropilin-1|transmembrane receptor|vascular endothelial cell growth factor 165 receptor', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=33177493, end_position_on_the_genomic_accession=33334667, orientation='minus', exon_count=18, OMIM=[602069], no_hdr0=''),
    8831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8831, CurrentID=0, Status='live', Symbol='SYNGAP1', Aliases=['MRD5', 'RASA1', 'RASA5', 'SYNGAP'], description='synaptic Ras GTPase activating protein 1', other_designations='ras/Rap GTPase-activating protein SynGAP|Ras GTPase-activating protein SynGAP|neuronal RasGAP|synaptic Ras GTPase activating protein 1 homolog|synaptic Ras GTPase activating protein, 135kDa', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33420065, end_position_on_the_genomic_accession=33453689, orientation='plus', exon_count=19, OMIM=[603384], no_hdr0=''),
    8832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8832, CurrentID=0, Status='live', Symbol='CD84', Aliases=['LY9B', 'SLAMF5', 'hCD84', 'mCD84'], description='CD84 molecule', other_designations='SLAM family member 5|CD84 antigen (leukocyte antigen)|cell surface antigen MAX.3|hly9-beta|leucocyte differentiation antigen CD84|leukocyte antigen CD84|leukocyte differentiation antigen CD84|signaling lymphocytic activation molecule 5', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160541098, end_position_on_the_genomic_accession=160579515, orientation='minus', exon_count=9, OMIM=[604513], no_hdr0=''),
    8833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8833, CurrentID=0, Status='live', Symbol='GMPS', Aliases=['GATD7'], description='guanine monophosphate synthase', other_designations="GMP synthase [glutamine-hydrolyzing]|GMP synthase|GMP synthetase|MLL/GMPS fusion protein|glutamine amidotransferase|guanine monophosphate synthetase|guanosine 5'-monophosphate synthase|testicular tissue protein Li 82", map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155869430, end_position_on_the_genomic_accession=155944020, orientation='plus', exon_count=19, OMIM=[600358], no_hdr0=''),
    8834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8834, CurrentID=0, Status='live', Symbol='TMEM11', Aliases=['C17orf35', 'PM1', 'PMI'], description='transmembrane protein 11', other_designations='transmembrane protein 11, mitochondrial|putative receptor protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21197954, end_position_on_the_genomic_accession=21214161, orientation='minus', exon_count=3, OMIM=[618817], no_hdr0=''),
    8835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8835, CurrentID=0, Status='live', Symbol='SOCS2', Aliases=['CIS2', 'Cish2', 'SOCS-2', 'SSI-2', 'SSI2', 'STATI2'], description='suppressor of cytokine signaling 2', other_designations='suppressor of cytokine signaling 2|CIS-2|STAT-induced STAT inhibitor 2|cytokine-inducible SH2 protein 2', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=93569849, end_position_on_the_genomic_accession=93626236, orientation='plus', exon_count=12, OMIM=[605117], no_hdr0=''),
    8836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8836, CurrentID=0, Status='live', Symbol='GGH', Aliases=['GATD10', 'GH'], description='gamma-glutamyl hydrolase', other_designations='gamma-glutamyl hydrolase|gamma-Glu-X carboxypeptidase|gamma-glutamyl hydrolase (conjugase, folylpolygammaglutamyl hydrolase)', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=63015079, end_position_on_the_genomic_accession=63038806, orientation='minus', exon_count=10, OMIM=[601509], no_hdr0=''),
    8837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8837, CurrentID=0, Status='live', Symbol='CFLAR', Aliases=['CASH', 'CASP8AP1', 'CLARP', 'Casper', 'FLAME', 'FLAME-1', 'FLAME1', 'FLIP', 'I-FLICE', 'MRIT', 'c-FLIP', 'c-FLIPL', 'c-FLIPR', 'c-FLIPS', 'cFLIP'], description='CASP8 and FADD like apoptosis regulator', other_designations='CASP8 and FADD-like apoptosis regulator|FADD-like antiapoptotic molecule 1|MACH-related inducer of toxicity|caspase homolog|caspase-eight-related protein|caspase-like apoptosis regulatory protein|caspase-related inducer of apoptosis|cellular FLICE-like inhibitory protein|inhibitor of FLICE|testis secretory sperm-binding protein Li 233m|usurpin beta', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201116164, end_position_on_the_genomic_accession=201176687, orientation='plus', exon_count=20, OMIM=[603599], no_hdr0=''),
    8838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8838, CurrentID=0, Status='live', Symbol='CCN6', Aliases=['LIBC', 'PPAC', 'PPD', 'PPRD', 'WISP-3', 'WISP3'], description='cellular communication network factor 6', other_designations='cellular communication network factor 6|CCN family member 6|WNT1 inducible signaling pathway protein 3|epididymis secretory sperm binding protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=112052813, end_position_on_the_genomic_accession=112069686, orientation='plus', exon_count=11, OMIM=[603400], no_hdr0=''),
    8839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8839, CurrentID=0, Status='live', Symbol='CCN5', Aliases=['CT58', 'CTGF-L', 'WISP2'], description='cellular communication network factor 5', other_designations='CCN family member 5|WNT1 inducible signaling pathway protein 2|connective tissue growth factor-like protein|connective tissue growth factor-related protein 58', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44714204, end_position_on_the_genomic_accession=44728041, orientation='plus', exon_count=6, OMIM=[603399], no_hdr0=''),
    8840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8840, CurrentID=0, Status='live', Symbol='CCN4', Aliases=['WISP1', 'WISP1-OT1', 'WISP1-UT1', 'WISP1c', 'WISP1i', 'WISP1tc'], description='cellular communication network factor 4', other_designations="CCN family member 4|WISP1 3'UTR-associated RNA 1|WISP1 overlapping transcript 1 (non-protein coding)|WNT1 induced secreted protein 1|WNT1 inducible signaling pathway protein 1", map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=133190907, end_position_on_the_genomic_accession=133231690, orientation='plus', exon_count=6, OMIM=[603398], no_hdr0=''),
    8841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8841, CurrentID=0, Status='live', Symbol='HDAC3', Aliases=['HD3', 'KDAC3', 'RPD3', 'RPD3-2'], description='histone deacetylase 3', other_designations='histone deacetylase 3|SMAP45', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141620881, end_position_on_the_genomic_accession=141636849, orientation='minus', exon_count=15, OMIM=[605166], no_hdr0=''),
    8842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8842, CurrentID=0, Status='live', Symbol='PROM1', Aliases=['AC133', 'CD133', 'CORD12', 'MCDR2', 'MSTP061', 'PROML1', 'RP41', 'STGD4'], description='prominin 1', other_designations='prominin-1|antigen AC133|hProminin|hematopoietic stem cell antigen|prominin-like protein 1', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15968226, end_position_on_the_genomic_accession=16084059, orientation='minus', exon_count=35, OMIM=[604365], no_hdr0=''),
    8843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8843, CurrentID=0, Status='live', Symbol='HCAR3', Aliases=['GPR109B', 'HCA3', 'HM74', 'PUMAG', 'Puma-g'], description='hydroxycarboxylic acid receptor 3', other_designations='hydroxycarboxylic acid receptor 3|G-protein coupled receptor 109B|G-protein coupled receptor HM74|G-protein coupled receptor HM74B|GTP-binding protein|hydroxy-carboxylic acid receptor 3|niacin receptor 2|nicotinic acid receptor 2|putative chemokine receptor', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122714756, end_position_on_the_genomic_accession=122716811, orientation='minus', exon_count=1, OMIM=[606039], no_hdr0=''),
    8844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8844, CurrentID=0, Status='live', Symbol='KSR1', Aliases=['KSR', 'RSU2'], description='kinase suppressor of ras 1', other_designations='kinase suppressor of Ras 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=27456441, end_position_on_the_genomic_accession=27626438, orientation='plus', exon_count=32, OMIM=[601132], no_hdr0=''),
    8846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8846, CurrentID=0, Status='live', Symbol='ALKBH1', Aliases=['ABH', 'ABH1', 'ALKBH', 'alkB', 'hABH'], description='alkB homolog 1, histone H2A dioxygenase', other_designations='nucleic acid dioxygenase ALKBH1|DNA 6mA demethylase|DNA N6-methyl adenine demethylase ALKBH1|DNA demethylase ALKBH1|DNA lyase ABH1|DNA oxidative demethylase ALKBH1|alkB, alkylation repair homolog 1|alkylated DNA repair protein alkB homolog 1|alkylation repair, alkB homolog|alpha-ketoglutarate-dependent dioxygenase ABH1|mRNA N(3)-methylcytidine demethylase|tRNA N1-methyl adenine demethylase', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77672404, end_position_on_the_genomic_accession=77708038, orientation='minus', exon_count=6, OMIM=[605345], no_hdr0=''),
    8848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8848, CurrentID=0, Status='live', Symbol='TSC22D1', Aliases=['Ptg-2', 'TGFB1I4', 'TSC22'], description='TSC22 domain family member 1', other_designations='TSC22 domain family protein 1|TGFB-stimulated clone 22 homolog|TGFbeta-stimulated clone 22|cerebral protein 2|regulatory protein TSC-22|transcriptional regulator TSC-22|transforming growth factor beta-1-induced transcript 4 protein|transforming growth factor beta-stimulated protein TSC-22', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=44432143, end_position_on_the_genomic_accession=44576825, orientation='minus', exon_count=9, OMIM=[607715], no_hdr0=''),
    8850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8850, CurrentID=0, Status='live', Symbol='KAT2B', Aliases=['CAF', 'P/CAF', 'PCAF'], description='lysine acetyltransferase 2B', other_designations='histone acetyltransferase KAT2B|CREBBP-associated factor|K(lysine) acetyltransferase 2B|histone acetylase PCAF|histone acetyltransferase PCAF|p300/CBP-associated factor|spermidine acetyltransferase KAT2B', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=20040407, end_position_on_the_genomic_accession=20154404, orientation='plus', exon_count=19, OMIM=[602303], no_hdr0=''),
    8851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8851, CurrentID=0, Status='live', Symbol='CDK5R1', Aliases=['CDK5P35', 'CDK5R', 'NCK5A', 'p23', 'p25', 'p35', 'p35nck5a'], description='cyclin dependent kinase 5 regulatory subunit 1', other_designations='cyclin-dependent kinase 5 activator 1|CDK5 activator 1|TPKII regulatory subunit|neuronal CDK5 activator|regulatory partner for CDK5 kinase|tau protein kinase II 23kDa subunit', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32485028, end_position_on_the_genomic_accession=32491256, orientation='plus', exon_count=3, OMIM=[603460], no_hdr0=''),
    8852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8852, CurrentID=0, Status='live', Symbol='AKAP4', Aliases=['AKAP 82', 'AKAP-4', 'AKAP82', 'CT99', 'FSC1', 'HI', 'PRKA4', 'hAKAP82', 'p82'], description='A-kinase anchoring protein 4', other_designations='A-kinase anchor protein 4|A kinase (PRKA) anchor protein 4|A-kinase anchor protein 82 kDa|cancer/testis antigen 99|epididymis secretory sperm binding protein|major sperm fibrous sheath protein|protein kinase A anchoring protein 4|testis-specific gene HI', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=50190777, end_position_on_the_genomic_accession=50201007, orientation='minus', exon_count=7, OMIM=[300185], no_hdr0=''),
    8853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8853, CurrentID=0, Status='live', Symbol='ASAP2', Aliases=['AMAP2', 'CENTB3', 'DDEF2', 'PAG3', 'PAP', 'Pap-alpha', 'SHAG1'], description='ArfGAP with SH3 domain, ankyrin repeat and PH domain 2', other_designations='arf-GAP with SH3 domain, ANK repeat and PH domain-containing protein 2|PYK2 C terminus-associated protein|centaurin, beta 3|development and differentiation-enhancing factor 2|paxillin-associated protein with ARF GAP activity 3|pyk2 C-terminus-associated protein', map_location='2p24', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9206812, end_position_on_the_genomic_accession=9405678, orientation='plus', exon_count=32, OMIM=[603817], no_hdr0=''),
    8854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8854, CurrentID=0, Status='live', Symbol='ALDH1A2', Aliases=['RALDH(II)', 'RALDH2', 'RALDH2-T'], description='aldehyde dehydrogenase 1 family member A2', other_designations='retinal dehydrogenase 2|RALDH 2|retinaldehyde-specific dehydrogenase type 2', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=57953429, end_position_on_the_genomic_accession=58065711, orientation='minus', exon_count=14, OMIM=[603687], no_hdr0=''),
    8856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8856, CurrentID=0, Status='live', Symbol='NR1I2', Aliases=['BXR', 'ONR1', 'PAR', 'PAR1', 'PAR2', 'PARq', 'PRR', 'PXR', 'SAR', 'SXR'], description='nuclear receptor subfamily 1 group I member 2', other_designations='nuclear receptor subfamily 1 group I member 2|orphan nuclear receptor PAR1|orphan nuclear receptor PXR|pregnane X nuclear receptor variant 2|pregnane X receptor|steroid and xenobiotic receptor', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119782101, end_position_on_the_genomic_accession=119818487, orientation='plus', exon_count=10, OMIM=[603065], no_hdr0=''),
    8857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8857, CurrentID=0, Status='live', Symbol='FCGBP', Aliases=['FC(GAMMA)BP'], description='Fc fragment of IgG binding protein', other_designations='IgGFc-binding protein|Human Fc gamma BP|IgG Fc binding protein|fcgamma-binding protein antigen|fcgammaBP', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39863323, end_position_on_the_genomic_accession=39934626, orientation='minus', exon_count=32, OMIM=[617553], no_hdr0=''),
    8858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8858, CurrentID=0, Status='live', Symbol='PROZ', Aliases=['PZ'], description='protein Z, vitamin K dependent plasma glycoprotein', other_designations='vitamin K-dependent protein Z|vitamin K-dependent protein Z precursor variant 1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113155864, end_position_on_the_genomic_accession=113172386, orientation='plus', exon_count=12, OMIM=[176895], no_hdr0=''),
    8859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8859, CurrentID=0, Status='live', Symbol='STK19', Aliases=['D6S60', 'D6S60E', 'G11', 'HLA-RP1', 'RP1'], description='serine/threonine kinase 19', other_designations='serine/threonine-protein kinase 19|MHC class III HLA-RP1|nuclear serine/threonine protein kinase', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31971175, end_position_on_the_genomic_accession=31981446, orientation='plus', exon_count=9, OMIM=[604977], no_hdr0=''),
    8861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8861, CurrentID=0, Status='live', Symbol='LDB1', Aliases=['CLIM-2', 'CLIM2', 'LDB-1', 'NLI'], description='LIM domain binding 1', other_designations='LIM domain-binding protein 1|LIM domain-binding factor CLIM2|LIM domain-binding factor-1|carboxy terminal LIM domain protein 2|carboxyl-terminal LIM domain-binding protein 2|nuclear LIM interactor', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102102100, end_position_on_the_genomic_accession=102120368, orientation='minus', exon_count=14, OMIM=[603451], no_hdr0=''),
    8862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8862, CurrentID=0, Status='live', Symbol='APLN', Aliases=['APEL', 'XNPEP2'], description='apelin', other_designations='apelin|AGTRL1 ligand|APJ endogenous ligand', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129645259, end_position_on_the_genomic_accession=129654956, orientation='minus', exon_count=3, OMIM=[300297], no_hdr0=''),
    8863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8863, CurrentID=0, Status='live', Symbol='PER3', Aliases=['FASPS3', 'GIG13'], description='period circadian regulator 3', other_designations='period circadian protein homolog 3|cell growth-inhibiting gene 13 protein|circadian clock protein PERIOD 3|period circadian clock 3|period circadian protein 3', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=7784285, end_position_on_the_genomic_accession=7845181, orientation='plus', exon_count=25, OMIM=[603427], no_hdr0=''),
    8864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8864, CurrentID=0, Status='live', Symbol='PER2', Aliases=['FASPS', 'FASPS1'], description='period circadian regulator 2', other_designations='period circadian protein homolog 2|circadian clock protein PERIOD 2|hPER2|period 2|period circadian clock 2|period circadian protein 2|period homolog 2', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238244038, end_position_on_the_genomic_accession=238290102, orientation='minus', exon_count=25, OMIM=[603426], no_hdr0=''),
    8867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8867, CurrentID=0, Status='live', Symbol='SYNJ1', Aliases=['DEE53', 'EIEE53', 'INPP5G', 'PARK20'], description='synaptojanin 1', other_designations="synaptojanin-1|inositol 5'-phosphatase (synaptojanin 1)|inositol polyphosphate-5-phosphatase G|phosphoinositide 5-phosphatase|synaptic inositol 1,4,5-trisphosphate 5-phosphatase 1|synaptojanin-1, polyphosphoinositide phosphatase", map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32628759, end_position_on_the_genomic_accession=32731247, orientation='minus', exon_count=34, OMIM=[604297], no_hdr0=''),
    8869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8869, CurrentID=0, Status='live', Symbol='ST3GAL5', Aliases=['SATI', 'SIAT9', 'SIATGM3S', 'SPDRS', 'ST3Gal V', 'ST3GalV'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 5', other_designations='lactosylceramide alpha-2,3-sialyltransferase|CMP-NeuAc:lactosylceramide alpha-2,3-sialyltransferase|GM3 synthase|ST3 beta-galactoside alpha-23-sialyltransferase 5|alpha 2,3-sialyltransferase V|ganglioside GM3 synthase|sialyltransferase 9 (CMP-NeuAc:lactosylceramide alpha-2,3-sialyltransferase; GM3 synthase)', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85837120, end_position_on_the_genomic_accession=85889034, orientation='minus', exon_count=17, OMIM=[604402], no_hdr0=''),
    8870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8870, CurrentID=0, Status='live', Symbol='IER3', Aliases=['DIF-2', 'DIF2', 'GLY96', 'IEX-1', 'IEX-1L', 'IEX1', 'PRG1'], description='immediate early response 3', other_designations='radiation-inducible immediate-early gene IEX-1|PACAP-responsive gene 1 protein|anti-death protein|differentiation-dependent gene 2 protein|expressed in pancreatic carcinoma|gly96, mouse, homolog of|immediate early protein GLY96|immediate early response 3 protein|immediately early gene X-1|protein DIF-2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30743199, end_position_on_the_genomic_accession=30744547, orientation='minus', exon_count=2, OMIM=[602996], no_hdr0=''),
    8871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8871, CurrentID=0, Status='live', Symbol='SYNJ2', Aliases=['INPP5H'], description='synaptojanin 2', other_designations="synaptojanin-2|inositol phosphate 5'-phosphatase 2|inositol polyphosphate-5-phosphatase H|phosphoinositide 5-phosphatase|synaptic inositol 1,4,5-trisphosphate 5-phosphatase 2", map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=157981856, end_position_on_the_genomic_accession=158099176, orientation='plus', exon_count=31, OMIM=[609410], no_hdr0=''),
    8872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8872, CurrentID=0, Status='live', Symbol='CDC123', Aliases=['C10orf7', 'D123'], description='cell division cycle 123', other_designations='cell division cycle protein 123 homolog|HT-1080|PZ32|cell division cycle 123 homolog', map_location='10p14-p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12196188, end_position_on_the_genomic_accession=12250589, orientation='plus', exon_count=13, OMIM=[617708], no_hdr0=''),
    8874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8874, CurrentID=0, Status='live', Symbol='ARHGEF7', Aliases=['BETA-PIX', 'COOL-1', 'COOL1', 'Nbla10314', 'P50', 'P50BP', 'P85', 'P85COOL1', 'P85SPR', 'PAK3', 'PIXB'], description='Rho guanine nucleotide exchange factor 7', other_designations='rho guanine nucleotide exchange factor 7|PAK-interacting exchange factor beta|Rho guanine nucleotide exchange factor (GEF) 7|SH3 domain-containing proline-rich protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=111114619, end_position_on_the_genomic_accession=111305734, orientation='plus', exon_count=31, OMIM=[605477], no_hdr0=''),
    8875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8875, CurrentID=0, Status='live', Symbol='VNN2', Aliases=['FOAP-4', 'GPI-80'], description='vanin 2', other_designations='vascular non-inflammatory molecule 2|Vannin 2|glycosylphosphatidyl inositol-anchored protein GPI-80|pantetheinase', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132743503, end_position_on_the_genomic_accession=132763489, orientation='minus', exon_count=12, OMIM=[603571], no_hdr0=''),
    8876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8876, CurrentID=0, Status='live', Symbol='VNN1', Aliases=['HDLCQ8', 'Tiff66'], description='vanin 1', other_designations='pantetheinase|pantetheine hydrolase|vannin 1|vascular non-inflammatory molecule 1', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132680849, end_position_on_the_genomic_accession=132714055, orientation='minus', exon_count=7, OMIM=[603570], no_hdr0=''),
    8877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8877, CurrentID=0, Status='live', Symbol='SPHK1', Aliases=['SPHK'], description='sphingosine kinase 1', other_designations='sphingosine kinase 1|SK 1|SPK 1|acetyltransferase SPHK1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76383204, end_position_on_the_genomic_accession=76387855, orientation='plus', exon_count=7, OMIM=[603730], no_hdr0=''),
    8878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8878, CurrentID=0, Status='live', Symbol='SQSTM1', Aliases=['A170', 'DMRV', 'FTDALS3', 'NADGP', 'OSIL', 'PDB3', 'ZIP3', 'p60', 'p62', 'p62B'], description='sequestosome 1', other_designations='sequestosome-1|EBI3-associated protein of 60 kDa|EBI3-associated protein p60|EBIAP|autophagy receptor p62|oxidative stress induced like|phosphotyrosine independent ligand for the Lck SH2 domain p62|phosphotyrosine-independent ligand for the Lck SH2 domain of 62 kDa|ubiquitin-binding protein p62', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179806393, end_position_on_the_genomic_accession=179838078, orientation='plus', exon_count=11, OMIM=[601530], no_hdr0=''),
    8879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8879, CurrentID=0, Status='live', Symbol='SGPL1', Aliases=['NPHS14', 'S1PL', 'SPL'], description='sphingosine-1-phosphate lyase 1', other_designations='sphingosine-1-phosphate lyase 1|SP-lyase 1|SPL 1|hSPL|sphingosine-1-phosphate aldolase', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70815920, end_position_on_the_genomic_accession=70881184, orientation='plus', exon_count=17, OMIM=[603729], no_hdr0=''),
    8880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8880, CurrentID=0, Status='live', Symbol='FUBP1', Aliases=['FBP', 'FUBP', 'hDH V'], description='far upstream element binding protein 1', other_designations='far upstream element-binding protein 1|DNA helicase V|FUSE binding protein 1|epididymis secretory sperm binding protein|far upstream element (FUSE) binding protein 1', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77944055, end_position_on_the_genomic_accession=77979435, orientation='minus', exon_count=24, OMIM=[603444], no_hdr0=''),
    8881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8881, CurrentID=0, Status='live', Symbol='CDC16', Aliases=['ANAPC6', 'APC6Hs', 'CUT9', 'CDC16'], description='cell division cycle 16', other_designations='cell division cycle protein 16 homolog|anaphase-promoting complex, subunit 6|cell division cycle 16 homolog|cyclosome subunit 6', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=114234897, end_position_on_the_genomic_accession=114272723, orientation='plus', exon_count=21, OMIM=[603461], no_hdr0=''),
    8882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8882, CurrentID=0, Status='live', Symbol='ZPR1', Aliases=['GKAF', 'ZNF259'], description='ZPR1 zinc finger', other_designations='zinc finger protein ZPR1|zinc finger protein 259', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116773799, end_position_on_the_genomic_accession=116789272, orientation='minus', exon_count=14, OMIM=[603901], no_hdr0=''),
    8883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8883, CurrentID=0, Status='live', Symbol='NAE1', Aliases=['A-116A10.1', 'APPBP1', 'HPP1', 'ula-1'], description='NEDD8 activating enzyme E1 subunit 1', other_designations='NEDD8-activating enzyme E1 regulatory subunit|APP-BP1|NEDD8-activating enzyme E1 subunit|amyloid beta precursor protein binding protein 1, 59kDa|amyloid beta precursor protein-binding protein 1, 59 kDa|amyloid beta precursor protein-binding protein 1, 59kD|amyloid protein-binding protein 1|proto-oncogene protein 1|protooncogene protein 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66802878, end_position_on_the_genomic_accession=66830977, orientation='minus', exon_count=21, OMIM=[603385], no_hdr0=''),
    8884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8884, CurrentID=0, Status='live', Symbol='SLC5A6', Aliases=['NERIB', 'SMVT'], description='solute carrier family 5 member 6', other_designations='sodium-dependent multivitamin transporter|Na(+)-dependent multivitamin transporter|Na+-dependent multivitamin transporter|solute carrier family 5 (sodium-dependent vitamin transporter), member 6|solute carrier family 5 (sodium/multivitamin and iodide cotransporter), member 6', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27199587, end_position_on_the_genomic_accession=27212342, orientation='minus', exon_count=20, OMIM=[604024], no_hdr0=''),
    8886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8886, CurrentID=0, Status='live', Symbol='DDX18', Aliases=['Has1', 'MrDb'], description='DEAD-box helicase 18', other_designations='ATP-dependent RNA helicase DDX18|DEAD (Asp-Glu-Ala-Asp) box polypeptide 18|DEAD box protein 18|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 18 (Myc-regulated)|Myc-regulated DEAD box protein', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=117814691, end_position_on_the_genomic_accession=117832377, orientation='plus', exon_count=14, OMIM=[606355], no_hdr0=''),
    8887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8887, CurrentID=0, Status='live', Symbol='TAX1BP1', Aliases=['CALCOCO3', 'T6BP', 'TXBP151'], description='Tax1 binding protein 1', other_designations='tax1-binding protein 1|TRAF6-binding protein|Tax1 (human T-cell leukemia virus type I) binding protein 1', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27739373, end_position_on_the_genomic_accession=27829767, orientation='plus', exon_count=18, OMIM=[605326], no_hdr0=''),
    8888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8888, CurrentID=0, Status='live', Symbol='MCM3AP', Aliases=['GANP', 'MAP80', 'PNRIID', 'SAC3'], description='minichromosome maintenance complex component 3 associated protein', other_designations='germinal-center associated nuclear protein|80 kDa MCM3-associated protein|MCM3 acetylating protein|MCM3 acetyltransferase|MCM3 import protein|MCM3 minichromosome maintenance deficient 3 associated protein|germinal center-associated nuclear protein|germinal-centre associated nuclear protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46235130, end_position_on_the_genomic_accession=46286297, orientation='minus', exon_count=29, OMIM=[603294], no_hdr0=''),
    8890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8890, CurrentID=0, Status='live', Symbol='EIF2B4', Aliases=['EIF-2B', 'EIF2B', 'EIF2Bdelta'], description='eukaryotic translation initiation factor 2B subunit delta', other_designations='translation initiation factor eIF-2B subunit delta|eIF-2B GDP-GTP exchange factor subunit delta|eukaryotic translation initiation factor 2B subunit 4 delta|eukaryotic translation initiation factor 2B, subunit 4 delta, 67kDa|translation initiation factor eIF-2b delta subunit', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27364352, end_position_on_the_genomic_accession=27370341, orientation='minus', exon_count=13, OMIM=[606687], no_hdr0=''),
    8891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8891, CurrentID=0, Status='live', Symbol='EIF2B3', Aliases=['EIF-2B', 'EIF2Bgamma'], description='eukaryotic translation initiation factor 2B subunit gamma', other_designations='translation initiation factor eIF-2B subunit gamma|eIF-2B GDP-GTP exchange factor subunit gamma|eukaryotic translation initiation factor 2B, subunit 3 gamma, 58kDa', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44850522, end_position_on_the_genomic_accession=44986641, orientation='minus', exon_count=14, OMIM=[606273], no_hdr0=''),
    8892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8892, CurrentID=0, Status='live', Symbol='EIF2B2', Aliases=['EIF-2Bbeta', 'EIF2B'], description='eukaryotic translation initiation factor 2B subunit beta', other_designations='translation initiation factor eIF-2B subunit beta|S20I15|S20III15|eIF-2B GDP-GTP exchange factor subunit beta|eukaryotic translation initiation factor 2B, subunit 2 beta, 39kDa', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75002921, end_position_on_the_genomic_accession=75012366, orientation='plus', exon_count=8, OMIM=[606454], no_hdr0=''),
    8893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8893, CurrentID=0, Status='live', Symbol='EIF2B5', Aliases=['CACH', 'CLE', 'EIF-2B', 'EIF2Bepsilon', 'LVWM'], description='eukaryotic translation initiation factor 2B subunit epsilon', other_designations='translation initiation factor eIF-2B subunit epsilon|eIF-2B GDP-GTP exchange factor subunit epsilon|eukaryotic translation initiation factor 2B, subunit 5 epsilon, 82kDa', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184135023, end_position_on_the_genomic_accession=184145311, orientation='plus', exon_count=17, OMIM=[603945], no_hdr0=''),
    8894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8894, CurrentID=0, Status='live', Symbol='EIF2S2', Aliases=['EIF2', 'EIF2B', 'EIF2beta', 'PPP1R67', 'eIF-2-beta'], description='eukaryotic translation initiation factor 2 subunit beta', other_designations='eukaryotic translation initiation factor 2 subunit 2|eukaryotic translation initiation factor 2, subunit 2 beta, 38kDa|protein phosphatase 1, regulatory subunit 67', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34088309, end_position_on_the_genomic_accession=34112243, orientation='minus', exon_count=9, OMIM=[603908], no_hdr0=''),
    8895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8895, CurrentID=0, Status='live', Symbol='CPNE3', Aliases=['CPN3', 'PRO1071'], description='copine 3', other_designations='copine-3|copine III', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86514422, end_position_on_the_genomic_accession=86561498, orientation='plus', exon_count=18, OMIM=[604207], no_hdr0=''),
    8896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8896, CurrentID=0, Status='live', Symbol='BUD31', Aliases=['Cwc14', 'EDG-2', 'EDG2', 'G10', 'YCR063W', 'fSAP17'], description='BUD31 homolog', other_designations='protein BUD31 homolog|G10 maternal transcript homolog|functional spliceosome-associated protein 17|maternal G10 transcript|protein EDG-2|protein G10 homolog', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99408641, end_position_on_the_genomic_accession=99419616, orientation='plus', exon_count=6, OMIM=[603477], no_hdr0=''),
    8897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8897, CurrentID=0, Status='live', Symbol='MTMR3', Aliases=['FYVE-DSP1', 'ZFYVE10'], description='myotubularin related protein 3', other_designations='myotubularin-related protein 3|FYVE (Fab1 YGLO23 Vsp27 EEA1 domain) dual-specificity protein phosphatase|FYVE domain-containing dual specificity protein phosphatase 1|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphate phosphatase|zinc finger FYVE domain-containing protein 10|zinc finger, FYVE domain containing 10', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29883174, end_position_on_the_genomic_accession=30030868, orientation='plus', exon_count=21, OMIM=[603558], no_hdr0=''),
    8898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8898, CurrentID=0, Status='live', Symbol='MTMR2', Aliases=['CMT4B', 'CMT4B1'], description='myotubularin related protein 2', other_designations='myotubularin-related protein 2|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphatase|phosphatidylinositol-3-phosphate phosphatase|phosphoinositide-3-phosphatase', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95832880, end_position_on_the_genomic_accession=95924110, orientation='minus', exon_count=19, OMIM=[603557], no_hdr0=''),
    8899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8899, CurrentID=0, Status='live', Symbol='PRPF4B', Aliases=['PR4H', 'PRP4', 'PRP4H', 'PRP4K', 'dJ1013A10.1'], description='pre-mRNA processing factor 4B', other_designations='serine/threonine-protein kinase PRP4 homolog|PRP4 kinase|PRP4 pre-mRNA processing factor 4 homolog B|PRP4 pre-mRNA-processing factor 4 homolog|dJ1013A10.1 (PRP4 protein kinase homolog)|protein-serine/threonine kinase', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4021300, end_position_on_the_genomic_accession=4064983, orientation='plus', exon_count=23, OMIM=[602338], no_hdr0=''),
    8900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8900, CurrentID=0, Status='live', Symbol='CCNA1', Aliases=['CT146'], description='cyclin A1', other_designations='cyclin-A1|testicular tissue protein Li 34', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36430488, end_position_on_the_genomic_accession=36442870, orientation='plus', exon_count=11, OMIM=[604036], no_hdr0=''),
    8904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8904, CurrentID=0, Status='live', Symbol='CPNE1', Aliases=['COPN1', 'CPN1'], description='copine 1', other_designations='copine-1|chromobindin 17|copine I', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35626044, end_position_on_the_genomic_accession=35664900, orientation='minus', exon_count=19, OMIM=[604205], no_hdr0=''),
    8905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8905, CurrentID=0, Status='live', Symbol='AP1S2', Aliases=['DC22', 'MRX59', 'MRXS21', 'MRXS5', 'MRXSF', 'PGS', 'SIGMA1B'], description='adaptor related protein complex 1 subunit sigma 2', other_designations='AP-1 complex subunit sigma-2|adapter-related protein complex 1 sigma-1B subunit|adaptor protein complex AP-1 sigma-1B subunit|adaptor related protein complex 1 sigma 2 subunit|adaptor-related protein complex 1 subunit sigma-1B|clathrin adaptor complex AP1 sigma 1B subunit|clathrin assembly protein complex 1 sigma-1B small chain|golgi adaptor HA1/AP1 adaptin sigma-1B subunit|sigma1B-adaptin', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15825806, end_position_on_the_genomic_accession=15854966, orientation='minus', exon_count=10, OMIM=[300629], no_hdr0=''),
    8906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8906, CurrentID=0, Status='live', Symbol='AP1G2', Aliases=['G2AD'], description='adaptor related protein complex 1 subunit gamma 2', other_designations='AP-1 complex subunit gamma-like 2|adaptor related protein complex 1 gamma 2 subunit|clathrin-associated/assembly/adaptor protein, large, gamma-2|gamma2-adaptin', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23559565, end_position_on_the_genomic_accession=23567939, orientation='minus', exon_count=24, OMIM=[603534], no_hdr0=''),
    8907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8907, CurrentID=0, Status='live', Symbol='AP1M1', Aliases=['AP47', 'CLAPM2', 'CLTNM', 'MU-1A', 'mu1A'], description='adaptor related protein complex 1 subunit mu 1', other_designations='AP-1 complex subunit mu-1|AP-mu chain family member mu1A|HA1 47 kDa subunit|adapter-related protein complex 1 subunit mu-1|adaptor protein complex AP-1 mu-1 subunit|adaptor protein complex AP-1 subunit mu-1|adaptor related protein complex 1 mu 1 subunit|clathrin adaptor protein AP47|clathrin assembly protein complex 1 medium chain 1|clathrin assembly protein complex 1 mu-1 medium chain 1|clathrin assembly protein complex 1, medium chain|clathrin assembly protein complex AP1, mu subunit|clathrin coat assembly protein AP47|clathrin coat-associated protein AP47|golgi adaptor AP-1 47 kDa protein|golgi adaptor HA1/AP1 adaptin mu-1 subunit|mu-adaptin 1|mu1A-adaptin', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16197911, end_position_on_the_genomic_accession=16245906, orientation='plus', exon_count=13, OMIM=[603535], no_hdr0=''),
    8908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8908, CurrentID=0, Status='live', Symbol='GYG2', Aliases=['GN-2', 'GN2'], description='glycogenin 2', other_designations='glycogenin-2|glycogenin glucosyltransferase', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2828712, end_position_on_the_genomic_accession=2882820, orientation='plus', exon_count=14, OMIM=[300198], no_hdr0=''),
    8909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8909, CurrentID=0, Status='live', Symbol='ENDOU', Aliases=['P11', 'PP11', 'PRSS26'], description='endonuclease, poly(U) specific', other_designations='poly(U)-specific endoribonuclease|22 serine protease|26 serine protease|endonuclease, polyU-specific|placental protein 11|protein endoU|uridylate-specific endoribonuclease', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47709734, end_position_on_the_genomic_accession=47725490, orientation='minus', exon_count=10, OMIM=[606720], no_hdr0=''),
    8910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8910, CurrentID=0, Status='live', Symbol='SGCE', Aliases=['DYT11', 'ESG', 'epsilon-SG'], description='sarcoglycan epsilon', other_designations='epsilon-sarcoglycan|dystonia 11, myoclonic', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=94584980, end_position_on_the_genomic_accession=94656205, orientation='minus', exon_count=16, OMIM=[604149], no_hdr0=''),
    8911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8911, CurrentID=0, Status='live', Symbol='CACNA1I', Aliases=['Cav3.3', 'ca(v)3.3'], description='calcium voltage-gated channel subunit alpha1 I', other_designations='voltage-dependent T-type calcium channel subunit alpha-1I|calcium channel, voltage-dependent, T type, alpha 1I subunit|calcium channel, voltage-dependent, alpha 1I subunit|voltage-gated calcium channel subunit alpha Cav3.3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39570753, end_position_on_the_genomic_accession=39689737, orientation='plus', exon_count=37, OMIM=[608230], no_hdr0=''),
    8912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8912, CurrentID=0, Status='live', Symbol='CACNA1H', Aliases=['CACNA1HB', 'Cav3.2', 'ECA6', 'EIG6', 'HALD4'], description='calcium voltage-gated channel subunit alpha1 H', other_designations='voltage-dependent T-type calcium channel subunit alpha-1H|calcium channel, voltage-dependent, T type, alpha 1H subunit|calcium channel, voltage-dependent, T type, alpha 1Hb subunit|low-voltage-activated calcium channel alpha1 3.2 subunit|low-voltage-activated calcium channel alpha13.2 subunit|voltage dependent t-type calcium channel alpha-1H subunit|voltage-gated calcium channel alpha subunit Cav3.2|voltage-gated calcium channel alpha subunit CavT.2|voltage-gated calcium channel subunit alpha Cav3.2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1153106, end_position_on_the_genomic_accession=1221769, orientation='plus', exon_count=36, OMIM=[607904], no_hdr0=''),
    8913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8913, CurrentID=0, Status='live', Symbol='CACNA1G', Aliases=['Ca(V)T.1', 'Cav3.1', 'NBR13', 'SCA42', 'SCA42ND'], description='calcium voltage-gated channel subunit alpha1 G', other_designations='voltage-dependent T-type calcium channel subunit alpha-1G|calcium channel, voltage-dependent, T type, alpha 1G subunit|cav3.1c|voltage-dependent T-type calcium channel alpha 1G subunit|voltage-dependent calcium channel alpha 1G subunit|voltage-gated calcium channel subunit alpha Cav3.1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50560715, end_position_on_the_genomic_accession=50629625, orientation='plus', exon_count=38, OMIM=[604065], no_hdr0=''),
    8914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8914, CurrentID=0, Status='live', Symbol='TIMELESS', Aliases=['TIM', 'TIM1', 'hTIM'], description='timeless circadian regulator', other_designations='protein timeless homolog|Tof1 homolog|timeless circadian clock 1|timeless homolog', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56416363, end_position_on_the_genomic_accession=56449426, orientation='minus', exon_count=29, OMIM=[603887], no_hdr0=''),
    8915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8915, CurrentID=0, Status='live', Symbol='BCL10', Aliases=['CARMEN', 'CIPER', 'CLAP', 'IMD37', 'c-E10', 'mE10'], description='BCL10 immune signaling adaptor', other_designations='B-cell lymphoma/leukemia 10|B cell CLL/lymphoma 10|CARD containing molecule enhancing NF-kB|CARD-containing apoptotic signaling protein|CARD-containing molecule enhancing NF-kappa-B|CARD-containing proapoptotic protein|CED-3/ICH-1 prodomain homologous E10-like regulator|cCARMEN|caspase-recruiting domain-containing protein|cellular homolog of vCARMEN|cellular-E10|hCLAP|mammalian CARD-containing adapter molecule E10', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85265776, end_position_on_the_genomic_accession=85276632, orientation='minus', exon_count=5, OMIM=[603517], no_hdr0=''),
    8916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8916, CurrentID=0, Status='live', Symbol='HERC3', Aliases=[], description='HECT and RLD domain containing E3 ubiquitin protein ligase 3', other_designations='probable E3 ubiquitin-protein ligase HERC3|HECT domain and RCC1-like domain-containing protein 3|HECT-type E3 ubiquitin transferase HERC3|hect domain and RLD 3', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88523843, end_position_on_the_genomic_accession=88709303, orientation='plus', exon_count=31, OMIM=[605200], no_hdr0=''),
    8924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8924, CurrentID=0, Status='live', Symbol='HERC2', Aliases=['D15F37S1', 'MRT38', 'SHEP1', 'jdf2', 'p528'], description='HECT and RLD domain containing E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase HERC2|HECT-type E3 ubiquitin transferase HERC2|hect domain and RCC1-like domain-containing protein 2|hect domain and RLD 2|probable E3 ubiquitin-protein ligase HERC2', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28111040, end_position_on_the_genomic_accession=28322179, orientation='minus', exon_count=98, OMIM=[605837], no_hdr0=''),
    8925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8925, CurrentID=0, Status='live', Symbol='HERC1', Aliases=['MDFPMR', 'p532', 'p619'], description='HECT and RLD domain containing E3 ubiquitin protein ligase family member 1', other_designations='probable E3 ubiquitin-protein ligase HERC1|HECT domain and RCC1-like domain-containing protein 1|HECT-type E3 ubiquitin transferase HERC1|guanine nucleotide exchange factor p532|hect (homologous to the E6-AP (UBE3A) carboxyl terminus) domain and RCC1 (CHC1)-like domain (RLD) 1', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63608618, end_position_on_the_genomic_accession=63833948, orientation='minus', exon_count=80, OMIM=[605109], no_hdr0=''),
    8926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8926, CurrentID=0, Status='live', Symbol='SNURF', Aliases=[], description='SNRPN upstream open reading frame', other_designations='SNRPN upstream reading frame protein', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=24954987, end_position_on_the_genomic_accession=24978723, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    8927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8927, CurrentID=0, Status='live', Symbol='BSN', Aliases=['ZNF231'], description='bassoon presynaptic cytomatrix protein', other_designations='protein bassoon|neuronal double zinc finger protein|zinc finger protein 231', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49554477, end_position_on_the_genomic_accession=49671549, orientation='plus', exon_count=12, OMIM=[604020], no_hdr0=''),
    8928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8928, CurrentID=0, Status='live', Symbol='FOXH1', Aliases=['FAST-1', 'FAST1'], description='forkhead box H1', other_designations='forkhead box protein H1|TGF-beta/activin signal transducer|fast-2|forkhead activin signal transducer 2|forkhead activin signal transducer-1|hFAST-1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144473412, end_position_on_the_genomic_accession=144475849, orientation='minus', exon_count=3, OMIM=[603621], no_hdr0=''),
    8929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8929, CurrentID=0, Status='live', Symbol='PHOX2B', Aliases=['CCHS', 'NBLST2', 'NBPhox', 'PMX2B'], description='paired like homeobox 2B', other_designations='paired mesoderm homeobox protein 2B|PHOX2B homeodomain protein|neuroblastoma Phox|neuroblastoma paired-type homeobox protein|paired like homeobox2B|paired mesoderm homeobox 2b', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41744082, end_position_on_the_genomic_accession=41748725, orientation='minus', exon_count=3, OMIM=[603851], no_hdr0=''),
    8930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8930, CurrentID=0, Status='live', Symbol='MBD4', Aliases=['MED1'], description='methyl-CpG binding domain 4, DNA glycosylase', other_designations='methyl-CpG-binding domain protein 4|3,N(4)-ethenocytosine glycosylase|G/5-fluorouracil mismatch glycosylase with biphasic kinetics|G/T mismatch glycosylase|G/U mismatch glycosylase|methyl-CpG binding domain protein 4|methyl-CpG-binding endonuclease 1|methyl-CpG-binding protein MBD4|mismatch-specific DNA N-glycosylase|putative methyl-CpG binding protein', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129430947, end_position_on_the_genomic_accession=129440029, orientation='minus', exon_count=8, OMIM=[603574], no_hdr0=''),
    8932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8932, CurrentID=0, Status='live', Symbol='MBD2', Aliases=['DMTase', 'NY-CO-41'], description='methyl-CpG binding domain protein 2', other_designations='methyl-CpG-binding domain protein 2|demethylase', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54151606, end_position_on_the_genomic_accession=54224669, orientation='minus', exon_count=8, OMIM=[603547], no_hdr0=''),
    8933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8933, CurrentID=0, Status='live', Symbol='RTL8C', Aliases=['CXX1', 'FAM127A', 'MAR8C', 'MART8C', 'Mar8', 'Mart8', 'SIRH5'], description='retrotransposon Gag like 8C', other_designations='retrotransposon Gag-like protein 8C|CAAX box 1|Sushi-Ichi retrotransposon homolog 5|family with sequence similarity 127 member A|mammalian retrotransposon derived protein 8C|mammalian retrotransposon-derived 8C|protein FAM127A|retrotransposon Gag-like protein 8B', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135032355, end_position_on_the_genomic_accession=135033546, orientation='plus', exon_count=1, OMIM=[300213], no_hdr0=''),
    8934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8934, CurrentID=0, Status='live', Symbol='RAB29', Aliases=['RAB7L', 'RAB7L1'], description='RAB29, member RAS oncogene family', other_designations='ras-related protein Rab-7L1|RAB7, member RAS oncogene family-like 1|rab-7-like protein 1|ras-related protein Rab-29', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205767986, end_position_on_the_genomic_accession=205775487, orientation='minus', exon_count=6, OMIM=[603949], no_hdr0=''),
    8935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8935, CurrentID=0, Status='live', Symbol='SKAP2', Aliases=['PRAP', 'RA70', 'SAPS', 'SCAP2', 'SKAP-HOM', 'SKAP55R'], description='src kinase associated phosphoprotein 2', other_designations='src kinase-associated phosphoprotein 2|Fyn-associated phosphoprotein SKAP55 homologue|Pyk2/RAFTK-associated protein|SKAP-55HOM|SKAP55 homolog|retinoic acid-induced protein 70|src family-associated phosphoprotein 2|src kinase-associated phosphoprotein of 55-related protein|src-associated adapter protein with PH and SH3 domains', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=26654772, end_position_on_the_genomic_accession=26864623, orientation='minus', exon_count=15, OMIM=[605215], no_hdr0=''),
    8936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8936, CurrentID=0, Status='live', Symbol='WASF1', Aliases=['NEDALVS', 'SCAR1', 'WAVE', 'WAVE1'], description='WASP family member 1', other_designations='wiskott-Aldrich syndrome protein family member 1|WAS protein family member 1|WASP family protein member 1|homology of dictyostelium scar 1|protein WAVE-1|verprolin homology domain-containing protein 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110099819, end_position_on_the_genomic_accession=110179670, orientation='minus', exon_count=11, OMIM=[605035], no_hdr0=''),
    8938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8938, CurrentID=0, Status='live', Symbol='BAIAP3', Aliases=['BAP3'], description='BAI1 associated protein 3', other_designations='BAI1-associated protein 3|BAI-associated protein 3|brain-specific angiogenesis inhibitor I-associated protein 3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1333645, end_position_on_the_genomic_accession=1349439, orientation='plus', exon_count=36, OMIM=[604009], no_hdr0=''),
    8939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8939, CurrentID=0, Status='live', Symbol='FUBP3', Aliases=['FBP3'], description='far upstream element binding protein 3', other_designations='far upstream element-binding protein 3|FUSE-binding protein 3|far upstream element (FUSE) binding protein 3', map_location='9q34.11-q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130579577, end_position_on_the_genomic_accession=130638352, orientation='plus', exon_count=23, OMIM=[603536], no_hdr0=''),
    8940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8940, CurrentID=0, Status='live', Symbol='TOP3B', Aliases=['TOP3B1'], description='DNA topoisomerase III beta', other_designations='DNA topoisomerase 3-beta-1|DNA topoisomerase III beta-1|topoisomerase (DNA) III beta|topoisomerase III beta', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21957025, end_position_on_the_genomic_accession=21982787, orientation='minus', exon_count=21, OMIM=[603582], no_hdr0=''),
    8941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8941, CurrentID=0, Status='live', Symbol='CDK5R2', Aliases=['NCK5AI', 'P39', 'p39nck5ai'], description='cyclin dependent kinase 5 regulatory subunit 2', other_designations='cyclin-dependent kinase 5 activator 2|CDK5 activator 2|p39I', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218959666, end_position_on_the_genomic_accession=218962155, orientation='plus', exon_count=1, OMIM=[603764], no_hdr0=''),
    8942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8942, CurrentID=0, Status='live', Symbol='KYNU', Aliases=['KYNUU', 'VCRL2'], description='kynureninase', other_designations='kynureninase', map_location='2q22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=142877664, end_position_on_the_genomic_accession=143055833, orientation='plus', exon_count=21, OMIM=[605197], no_hdr0=''),
    8943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8943, CurrentID=0, Status='live', Symbol='AP3D1', Aliases=['ADTD', 'HPS10', 'hBLVR'], description='adaptor related protein complex 3 subunit delta 1', other_designations='AP-3 complex subunit delta-1|AP-3 complex delta subunit, partial CDS|adapter-related protein complex 3 subunit delta-1|adaptor related protein complex 3 delta 1 subunit|delta adaptin|subunit of putative vesicle coat adaptor complex AP-3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2100988, end_position_on_the_genomic_accession=2151566, orientation='minus', exon_count=32, OMIM=[607246], no_hdr0=''),
    8945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8945, CurrentID=0, Status='live', Symbol='BTRC', Aliases=['BETA-TRCP', 'FBW1A', 'FBXW1', 'FBXW1A', 'FWD1', 'bTrCP', 'bTrCP1', 'betaTrCP'], description='beta-transducin repeat containing E3 ubiquitin protein ligase', other_designations='F-box/WD repeat-containing protein 1A|E3RSIkappaB|F-box and WD repeats protein beta-TrCP|F-box and WD-repeat protein 1B|beta-TrCP1|epididymis tissue protein Li 2a|pIkappaBalpha-E3 receptor subunit', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101353808, end_position_on_the_genomic_accession=101557313, orientation='plus', exon_count=21, OMIM=[603482], no_hdr0=''),
    8968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8968, CurrentID=0, Status='live', Symbol='H3C7', Aliases=['H3/i', 'H3C1', 'H3C10', 'H3C11', 'H3C12', 'H3C2', 'H3C3', 'H3C4', 'H3C6', 'H3C8', 'H3FI', 'HIST1H3F'], description='H3 clustered histone 7', other_designations='histone H3.1|H3 histone family, member I|histone 1, H3f|histone H3/i|histone cluster 1 H3 family member f|histone cluster 1, H3f', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26250142, end_position_on_the_genomic_accession=26250635, orientation='minus', exon_count=1, OMIM=[602816], no_hdr0=''),
    8969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8969, CurrentID=0, Status='live', Symbol='H2AC11', Aliases=['H2A.1b', 'H2A/p', 'H2AC13', 'H2AC15', 'H2AC16', 'H2AC17', 'H2AFP', 'H2AG', 'HIST1H2AG', 'pH2A/f'], description='H2A clustered histone 11', other_designations='histone H2A type 1|H2A histone family, member P|histone 1, H2ag|histone H2A/p|histone H2A/ptl|histone cluster 1 H2A family member g|histone cluster 1, H2ag', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27133043, end_position_on_the_genomic_accession=27133535, orientation='plus', exon_count=1, OMIM=[615012], no_hdr0=''),
    8970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8970, CurrentID=0, Status='live', Symbol='H2BC11', Aliases=['H2B/r', 'H2BFR', 'H2BJ', 'HIST1H2BJ'], description='H2B clustered histone 11', other_designations='histone H2B type 1-J|H2B histone family, member R|histone 1, H2bj|histone H2B.1|histone H2B.r|histone cluster 1 H2B family member j|histone cluster 1, H2bj', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27132316, end_position_on_the_genomic_accession=27132795, orientation='minus', exon_count=1, OMIM=[615044], no_hdr0=''),
    8971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8971, CurrentID=0, Status='live', Symbol='H1-10', Aliases=['H1.10', 'H1FX', 'H1X'], description='H1.10 linker histone', other_designations='histone H1.10|H1 histone family member X|histone H1x', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129314771, end_position_on_the_genomic_accession=129316286, orientation='minus', exon_count=1, OMIM=[602785], no_hdr0=''),
    8972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8972, CurrentID=0, Status='live', Symbol='MGAM', Aliases=['MG', 'MGA'], description='maltase-glucoamylase', other_designations='maltase-glucoamylase, intestinal|brush border hydrolase|maltase-glucoamylase (alpha-glucosidase)', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141986517, end_position_on_the_genomic_accession=142106747, orientation='plus', exon_count=75, OMIM=[154360], no_hdr0=''),
    8973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8973, CurrentID=0, Status='live', Symbol='CHRNA6', Aliases=['CHNRA6'], description='cholinergic receptor nicotinic alpha 6 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-6|acetylcholine receptor, nicotinic, alpha 6 (neuronal)|cholinergic receptor, nicotinic alpha 6|cholinergic receptor, nicotinic, alpha 6 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 6', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42752620, end_position_on_the_genomic_accession=42768786, orientation='minus', exon_count=6, OMIM=[606888], no_hdr0=''),
    8974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8974, CurrentID=0, Status='live', Symbol='P4HA2', Aliases=['MYP25'], description='prolyl 4-hydroxylase subunit alpha 2', other_designations='prolyl 4-hydroxylase subunit alpha-2|4-PH alpha 2|C-P4Halpha(II)|collagen prolyl 4-hydroxylase alpha(II)|procollagen-proline, 2-oxoglutarate 4-dioxygenase (proline 4-hydroxylase), alpha polypeptide II|procollagen-proline,2-oxoglutarate-4-dioxygenase subunit alpha-2|prolyl 4-hydroxylase, alpha polypeptide II', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132190147, end_position_on_the_genomic_accession=132227853, orientation='minus', exon_count=17, OMIM=[600608], no_hdr0=''),
    8975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8975, CurrentID=0, Status='live', Symbol='USP13', Aliases=['ISOT3', 'IsoT-3'], description='ubiquitin specific peptidase 13', other_designations='ubiquitin carboxyl-terminal hydrolase 13|deubiquitinating enzyme 13|ubiquitin specific peptidase 13 (isopeptidase T-3)|ubiquitin specific protease 13 (isopeptidase T-3)|ubiquitin thioesterase 13|ubiquitin thiolesterase 13|ubiquitin-specific-processing protease 13', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179653040, end_position_on_the_genomic_accession=179789401, orientation='plus', exon_count=22, OMIM=[603591], no_hdr0=''),
    8976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8976, CurrentID=0, Status='live', Symbol='WASL', Aliases=['N-WASP', 'NWASP', 'WASPB'], description='WASP like actin nucleation promoting factor', other_designations='neural Wiskott-Aldrich syndrome protein|Wiskott-Aldrich syndrome like', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123681943, end_position_on_the_genomic_accession=123749003, orientation='minus', exon_count=11, OMIM=[605056], no_hdr0=''),
    8985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8985, CurrentID=0, Status='live', Symbol='PLOD3', Aliases=['LH3'], description='procollagen-lysine,2-oxoglutarate 5-dioxygenase 3', other_designations='multifunctional procollagen lysine hydroxylase and glycosyltransferase LH3|lysine hydroxylase 3|lysyl hydroxlase 3|lysyl hydroxylase 3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101205984, end_position_on_the_genomic_accession=101217581, orientation='minus', exon_count=19, OMIM=[603066], no_hdr0=''),
    8986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8986, CurrentID=0, Status='live', Symbol='RPS6KA4', Aliases=['MSK2', 'RSK-B', 'S6K-alpha-4'], description='ribosomal protein S6 kinase A4', other_designations='ribosomal protein S6 kinase alpha-4|90 kDa ribosomal protein S6 kinase 4|mitogen- and stress-activated protein kinase 2|nuclear mitogen- and stress-activated protein kinase 2|ribosomal protein S6 kinase, 90kDa, polypeptide 4|ribosomal protein kinase B', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64359162, end_position_on_the_genomic_accession=64372215, orientation='plus', exon_count=17, OMIM=[603606], no_hdr0=''),
    8987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8987, CurrentID=0, Status='live', Symbol='STBD1', Aliases=['GENEX3414', 'GENX-3414'], description='starch binding domain 1', other_designations='starch-binding domain-containing protein 1|genethonin 1|glycophagy cargo receptor STBD1', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76306733, end_position_on_the_genomic_accession=76311130, orientation='plus', exon_count=2, OMIM=[607406], no_hdr0=''),
    8988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8988, CurrentID=0, Status='live', Symbol='HSPB3', Aliases=['DHMN2C', 'HMN2C', 'HSPL27'], description='heat shock protein family B (small) member 3', other_designations='heat shock protein beta-3|HSP 17|heat shock 17 kDa protein|heat shock 27kDa protein 3|protein 3', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=54455699, end_position_on_the_genomic_accession=54456377, orientation='plus', exon_count=1, OMIM=[604624], no_hdr0=''),
    8989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8989, CurrentID=0, Status='live', Symbol='TRPA1', Aliases=['ANKTM1', 'FEPS', 'FEPS1'], description='transient receptor potential cation channel subfamily A member 1', other_designations='transient receptor potential cation channel subfamily A member 1|ankyrin-like with transmembrane domains 1|transformation-sensitive protein p120|wasabi receptor', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=72021250, end_position_on_the_genomic_accession=72094885, orientation='minus', exon_count=29, OMIM=[604775], no_hdr0=''),
    8991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8991, CurrentID=0, Status='live', Symbol='SELENBP1', Aliases=['EHMTO', 'HEL-S-134P', 'LPSB', 'MTO', 'SBP56', 'SP56', 'hSBP'], description='selenium binding protein 1', other_designations='methanethiol oxidase|56 kDa selenium-binding protein|epididymis secretory sperm binding protein Li 134P', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151364304, end_position_on_the_genomic_accession=151372725, orientation='minus', exon_count=13, OMIM=[604188], no_hdr0=''),
    8992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8992, CurrentID=0, Status='live', Symbol='ATP6V0E1', Aliases=['ATP6H', 'ATP6V0E', 'M9.2', 'Vma21', 'Vma21p'], description='ATPase H+ transporting V0 subunit e1', other_designations='V-type proton ATPase subunit e 1|ATPase, H+ transporting, lysosomal 9kDa, V0 subunit e1|H(+)-transporting two-sector ATPase, subunit H|V-ATPase 9.2 kDa membrane accessory protein|V-ATPase H subunit|V-ATPase M9.2 subunit|V-ATPase subunit e 1|vacuolar ATP synthase subunit H|vacuolar proton pump H subunit|vacuolar proton pump subunit e 1|vacuolar proton-ATPase subunit M9.2', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172983771, end_position_on_the_genomic_accession=173035445, orientation='plus', exon_count=4, OMIM=[603931], no_hdr0=''),
    8993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8993, CurrentID=0, Status='live', Symbol='PGLYRP1', Aliases=['PGLYRP', 'PGRP', 'PGRP-S', 'PGRPS', 'TAG7', 'TNFSF3L'], description='peptidoglycan recognition protein 1', other_designations='peptidoglycan recognition protein 1|TNF superfamily, member 3 (LTB)-like (peptidoglycan recognition protein)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46019153, end_position_on_the_genomic_accession=46023053, orientation='minus', exon_count=3, OMIM=[604963], no_hdr0=''),
    8994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8994, CurrentID=0, Status='live', Symbol='LIMD1', Aliases=[], description='LIM domain containing 1', other_designations='LIM domain-containing protein 1|LIM domains containing 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45594105, end_position_on_the_genomic_accession=45686341, orientation='plus', exon_count=9, OMIM=[604543], no_hdr0=''),
    8995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8995, CurrentID=0, Status='live', Symbol='TNFSF18', Aliases=['AITRL', 'GITRL', 'TL6', 'TNLG2A', 'hGITRL'], description='TNF superfamily member 18', other_designations='tumor necrosis factor ligand superfamily member 18|AITR ligand|GITR ligand|activation-inducible TNF-related ligand|glucocorticoid-induced TNF-related ligand|glucocorticoid-induced TNFR-related protein ligand|tumor necrosis factor (ligand) superfamily, member 18|tumor necrosis factor ligand 2A|tumor necrosis factor superfamily member 18', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173039202, end_position_on_the_genomic_accession=173050941, orientation='minus', exon_count=3, OMIM=[603898], no_hdr0=''),
    8996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8996, CurrentID=0, Status='live', Symbol='NOL3', Aliases=['ARC', 'FCM', 'MYOCL1', 'MYP', 'NOP', 'NOP30'], description='nucleolar protein 3', other_designations='nucleolar protein 3|muscle-enriched cytoplasmic protein|nucleolar protein 3 (apoptosis repressor with CARD domain)|nucleolar protein of 30 kDa', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67170538, end_position_on_the_genomic_accession=67175737, orientation='plus', exon_count=6, OMIM=[605235], no_hdr0=''),
    8997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8997, CurrentID=0, Status='live', Symbol='KALRN', Aliases=['ARHGEF24', 'CHD5', 'CHDS5', 'DUET', 'DUO', 'HAPIP', 'TRAD'], description='kalirin RhoGEF kinase', other_designations='kalirin|huntingtin-associated protein interacting protein (duo)|serine/threonine-protein kinase with Dbl- and pleckstrin homology domain', map_location='3q21.1-q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=124033341, end_position_on_the_genomic_accession=124726325, orientation='plus', exon_count=66, OMIM=[604605], no_hdr0=''),
    8999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=8999, CurrentID=0, Status='live', Symbol='CDKL2', Aliases=['KKIAMRE', 'P56'], description='cyclin dependent kinase like 2', other_designations='cyclin-dependent kinase-like 2|CDC2-related kinase|p56 KKIAMRE protein kinase|protein kinase p56 KKIAMRE|serine/threonine protein kinase KKIAMRE|testicular tissue protein Li 35', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75576494, end_position_on_the_genomic_accession=75630528, orientation='minus', exon_count=14, OMIM=[603442], no_hdr0=''),
    9001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9001, CurrentID=0, Status='live', Symbol='HAP1', Aliases=['HAP2', 'HIP5', 'HLP', 'hHLP1'], description='huntingtin associated protein 1', other_designations='huntingtin-associated protein 1|HAP-1|epididymis secretory sperm binding protein|huntingtin-associated protein 2|neuroan 1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41717739, end_position_on_the_genomic_accession=41734646, orientation='minus', exon_count=13, OMIM=[600947], no_hdr0=''),
    9002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9002, CurrentID=0, Status='live', Symbol='F2RL3', Aliases=['PAR4'], description='F2R like thrombin or trypsin receptor 3', other_designations='proteinase-activated receptor 4|F2R like thrombin/trypsin receptor 3|PAR-4|coagulation factor II (thrombin) receptor-like 3|protease-activated receptor-4|thrombin receptor-like 3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16888999, end_position_on_the_genomic_accession=16892606, orientation='plus', exon_count=2, OMIM=[602779], no_hdr0=''),
    9013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9013, CurrentID=0, Status='live', Symbol='TAF1C', Aliases=['MGC:39976', 'SL1', 'TAFI110', 'TAFI95'], description='TATA-box binding protein associated factor, RNA polymerase I subunit C', other_designations='TATA box-binding protein-associated factor RNA polymerase I subunit C|RNA polymerase I-specific TBP-associated factor 110 kDa|SL1, 110kD subunit|TATA box binding protein (TBP)-associated factor, RNA polymerase I, C, 110kD|TATA box binding protein (TBP)-associated factor, RNA polymerase I, C, 110kDa|TATA box-binding protein-associated factor 1C|TATA-box binding protein associated factor, RNA polymerase I, C|TBP-associated factor 1C|transcription factor SL1|transcription initiation factor SL1/TIF-IB subunit C', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84177852, end_position_on_the_genomic_accession=84187065, orientation='minus', exon_count=16, OMIM=[604905], no_hdr0=''),
    9014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9014, CurrentID=0, Status='live', Symbol='TAF1B', Aliases=['MGC:9349', 'RAF1B', 'RAFI63', 'SL1', 'TAFI63'], description='TATA-box binding protein associated factor, RNA polymerase I subunit B', other_designations='TATA box-binding protein-associated factor RNA polymerase I subunit B|RNA polymerase I-specific TBP-associated factor 63 kDa|SL1, 63kD subunit|TATA box binding protein (TBP)-associated factor, RNA polymerase I, B, 63kD|TATA box binding protein (TBP)-associated factor, RNA polymerase I, B, 63kDa|TATA box-binding protein-associated factor 1B|TATA-box binding protein associated factor, RNA polymerase I, B|TBP-associated factor 1B|transcription initiation factor SL1/TIF-IB subunit B', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9843442, end_position_on_the_genomic_accession=9934416, orientation='plus', exon_count=17, OMIM=[604904], no_hdr0=''),
    9015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9015, CurrentID=0, Status='live', Symbol='TAF1A', Aliases=['MGC:17061', 'RAFI48', 'SL1', 'TAFI48'], description='TATA-box binding protein associated factor, RNA polymerase I subunit A', other_designations='TATA box-binding protein-associated factor RNA polymerase I subunit A|RNA polymerase I-specific TBP-associated factor 48 kDa|SL1, 48kD subunit|TATA box binding protein (TBP)-associated factor, RNA polymerase I, A, 48kD|TATA box binding protein (TBP)-associated factor, RNA polymerase I, A, 48kDa|TATA box-binding protein-associated factor 1A|TATA-box binding protein associated factor, RNA polymerase I, A|TBP-associated factor 1A|transcription factor SL1|transcription initiation factor SL1/TIF-IB subunit A', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222557902, end_position_on_the_genomic_accession=222590096, orientation='minus', exon_count=14, OMIM=[604903], no_hdr0=''),
    9016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9016, CurrentID=0, Status='live', Symbol='SLC25A14', Aliases=['BMCP1', 'UCP5'], description='solute carrier family 25 member 14', other_designations='brain mitochondrial carrier protein 1|mitochondrial uncoupling protein 5', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130339892, end_position_on_the_genomic_accession=130373360, orientation='plus', exon_count=13, OMIM=[300242], no_hdr0=''),
    9019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9019, CurrentID=0, Status='live', Symbol='MPZL1', Aliases=['MPZL1b', 'PZR', 'PZR1b', 'PZRa', 'PZRb'], description='myelin protein zero like 1', other_designations='myelin protein zero-like protein 1|immunoglobulin family transmembrane protein|protein zero related', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167721982, end_position_on_the_genomic_accession=167791919, orientation='plus', exon_count=6, OMIM=[604376], no_hdr0=''),
    9020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9020, CurrentID=0, Status='live', Symbol='MAP3K14', Aliases=['FTDCR1B', 'HS', 'HSNIK', 'NIK'], description='mitogen-activated protein kinase kinase kinase 14', other_designations='mitogen-activated protein kinase kinase kinase 14|NF-kappa-beta-inducing kinase|serine/threonine-protein kinase NIK', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45263119, end_position_on_the_genomic_accession=45317048, orientation='minus', exon_count=17, OMIM=[604655], no_hdr0=''),
    9021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9021, CurrentID=0, Status='live', Symbol='SOCS3', Aliases=['ATOD4', 'CIS3', 'Cish3', 'SOCS-3', 'SSI-3', 'SSI3'], description='suppressor of cytokine signaling 3', other_designations='suppressor of cytokine signaling 3|STAT-induced STAT inhibitor 3|cytokine-inducible SH2 protein 3', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78356778, end_position_on_the_genomic_accession=78360925, orientation='minus', exon_count=4, OMIM=[604176], no_hdr0=''),
    9022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9022, CurrentID=0, Status='live', Symbol='CLIC3', Aliases=[], description='chloride intracellular channel 3', other_designations='chloride intracellular channel protein 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136994608, end_position_on_the_genomic_accession=136997929, orientation='minus', exon_count=8, OMIM=[606533], no_hdr0=''),
    9023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9023, CurrentID=0, Status='live', Symbol='CH25H', Aliases=['C25H'], description='cholesterol 25-hydroxylase', other_designations='cholesterol 25-hydroxylase|cholesterol 25-monooxygenase|h25OH', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89205629, end_position_on_the_genomic_accession=89207317, orientation='minus', exon_count=1, OMIM=[604551], no_hdr0=''),
    9024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9024, CurrentID=0, Status='live', Symbol='BRSK2', Aliases=['C11orf7', 'PEN11B', 'SAD1', 'SADA', 'STK29'], description='BR serine/threonine kinase 2', other_designations='serine/threonine-protein kinase BRSK2|BR serine/threonine-protein kinase 2|brain-selective kinase 2|brain-specific serine/threonine-protein kinase 2|protein kinase SAD1B|serine/threonine-protein kinase 29|serine/threonine-protein kinase SAD-A|testicular tissue protein Li 30', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1389934, end_position_on_the_genomic_accession=1462689, orientation='plus', exon_count=25, OMIM=[609236], no_hdr0=''),
    9025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9025, CurrentID=0, Status='live', Symbol='RNF8', Aliases=['hRNF8'], description='ring finger protein 8', other_designations='E3 ubiquitin-protein ligase RNF8|C3HC4-type zinc finger protein|RING-type E3 ubiquitin transferase RNF8|UBC13/UEV-interacting ring finger protein|ring finger protein (C3HC4 type) 8|ring finger protein 8, E3 ubiquitin protein ligase', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37353983, end_position_on_the_genomic_accession=37394734, orientation='plus', exon_count=10, OMIM=[611685], no_hdr0=''),
    9026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9026, CurrentID=0, Status='live', Symbol='HIP1R', Aliases=['HIP12', 'HIP3', 'ILWEQ'], description='huntingtin interacting protein 1 related', other_designations='huntingtin-interacting protein 1-related protein|HIP-12|HIP1-related protein|huntingtin interacting protein 12', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122834498, end_position_on_the_genomic_accession=122862961, orientation='plus', exon_count=34, OMIM=[605613], no_hdr0=''),
    9027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9027, CurrentID=0, Status='live', Symbol='NAT8', Aliases=['ATase2', 'CCNAT', 'CML1', 'GLA', 'Hcml1', 'TSC501', 'TSC510'], description='N-acetyltransferase 8 (putative)', other_designations='N-acetyltransferase 8|N-acetyltransferase 8 (GCN5-related, putative)|N-acetyltransferase 8 (camello like)|acetyltransferase 2|camello-like protein 1|cysteinyl-conjugate N-acetyltransferase|kidney- and liver-specific gene product|probable N-acetyltransferase 8', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73640723, end_position_on_the_genomic_accession=73642422, orientation='minus', exon_count=2, OMIM=[606716], no_hdr0=''),
    9028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9028, CurrentID=0, Status='live', Symbol='RHBDL1', Aliases=['RHBDL', 'RRP'], description='rhomboid like 1', other_designations='rhomboid-related protein 1|rhomboid, drosophila, homolog of|rhomboid, veinlet-like 1|rhomboid-like protein 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=675671, end_position_on_the_genomic_accession=678271, orientation='plus', exon_count=8, OMIM=[603264], no_hdr0=''),
    9031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9031, CurrentID=0, Status='live', Symbol='BAZ1B', Aliases=['WBSCR10', 'WBSCR9', 'WSTF'], description='bromodomain adjacent to zinc finger domain 1B', other_designations='tyrosine-protein kinase BAZ1B|hWALp2|transcription factor WSTF|williams syndrome transcription factor|williams-Beuren syndrome chromosomal region 10 protein|williams-Beuren syndrome chromosomal region 9 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73440406, end_position_on_the_genomic_accession=73522293, orientation='minus', exon_count=21, OMIM=[605681], no_hdr0=''),
    9032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9032, CurrentID=0, Status='live', Symbol='TM4SF5', Aliases=[], description='transmembrane 4 L six family member 5', other_designations='transmembrane 4 L6 family member 5|tetraspan transmembrane protein L6H|transmembrane 4 superfamily member 5', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4771886, end_position_on_the_genomic_accession=4783211, orientation='plus', exon_count=5, OMIM=[604657], no_hdr0=''),
    9033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9033, CurrentID=0, Status='live', Symbol='PKD2L1', Aliases=['PCL', 'PKD2L', 'PKDL', 'TRPP3'], description='polycystin 2 like 1, transient receptor potential cation channel', other_designations='polycystic kidney disease 2-like 1 protein|polycystin-2 homolog|polycystin-2L1|polycystin-L|polycystin-L1|transient receptor potential cation channel, subfamily P, member 3', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100288145, end_position_on_the_genomic_accession=100347030, orientation='minus', exon_count=20, OMIM=[604532], no_hdr0=''),
    9034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9034, CurrentID=0, Status='live', Symbol='CCRL2', Aliases=['ACKR5', 'CKRX', 'CRAM', 'CRAM-A', 'CRAM-B', 'HCR'], description='C-C motif chemokine receptor like 2', other_designations='C-C chemokine receptor-like 2|atypical chemokine receptor 5|chemokine (C-C motif) receptor-like 2|chemokine receptor CCR11|chemokine receptor X|putative MCP-1 chemokine receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46407166, end_position_on_the_genomic_accession=46409523, orientation='plus', exon_count=5, OMIM=[608379], no_hdr0=''),
    9037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9037, CurrentID=0, Status='live', Symbol='SEMA5A', Aliases=['SEMAF', 'semF'], description='semaphorin 5A', other_designations='semaphorin-5A|sema F|sema domain, seven thrombospondin repeats (type 1 and type 1-like), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 5A|semaphorin F', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=9035030, end_position_on_the_genomic_accession=9546121, orientation='minus', exon_count=28, OMIM=[609297], no_hdr0=''),
    9038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9038, CurrentID=0, Status='live', Symbol='TAAR5', Aliases=['PNR', 'taR-5'], description='trace amine associated receptor 5', other_designations='trace amine-associated receptor 5|putative neurotransmitter receptor|trace amine receptor 5', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132588592, end_position_on_the_genomic_accession=132616747, orientation='minus', exon_count=4, OMIM=[607405], no_hdr0=''),
    9039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9039, CurrentID=0, Status='live', Symbol='UBA3', Aliases=['NAE2', 'UBE1C', 'hUBA3'], description='ubiquitin like modifier activating enzyme 3', other_designations='NEDD8-activating enzyme E1 catalytic subunit|NEDD8-activating enzyme E1 subunit 2|NEDD8-activating enzyme E1C|Nedd8-activating enzyme hUba3|UBA3, ubiquitin-activating enzyme E1 homolog|ubiquitin-activating enzyme 3|ubiquitin-activating enzyme E1C (UBA3 homolog, yeast)|ubiquitin-activating enzyme E1C (homologous to yeast UBA3)', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69054730, end_position_on_the_genomic_accession=69080373, orientation='minus', exon_count=18, OMIM=[603172], no_hdr0=''),
    9040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9040, CurrentID=0, Status='live', Symbol='UBE2M', Aliases=['UBC-RS2', 'UBC12', 'hUbc12'], description='ubiquitin conjugating enzyme E2 M', other_designations='NEDD8-conjugating enzyme Ubc12|NEDD8 carrier protein|NEDD8 protein ligase|epididymis secretory sperm binding protein|ubiquitin carrier protein M|ubiquitin conjugating enzyme E2M|ubiquitin-conjugating enzyme E2M (UBC12 homolog, yeast)|ubiquitin-protein ligase M|yeast UBC12 homolog', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58555712, end_position_on_the_genomic_accession=58558611, orientation='minus', exon_count=6, OMIM=[603173], no_hdr0=''),
    9043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9043, CurrentID=0, Status='live', Symbol='SPAG9', Aliases=['CT89', 'HLC-6', 'HLC4', 'HLC6', 'JIP-4', 'JIP4', 'JLP', 'PHET', 'PIG6'], description='sperm associated antigen 9', other_designations='C-Jun-amino-terminal kinase-interacting protein 4|JNK interacting protein|JNK/SAPK-associated protein|Max-binding protein|c-Jun NH2-terminal kinase-associated leucine zipper protein|cancer/testis antigen 89|human lung cancer oncogene 6 protein|lung cancer oncogene 4|mitogen-activated protein kinase 8-interacting protein 4|proliferation-inducing gene 6|protein highly expressed in testis|sperm associated antigen 9 variant 5|sperm surface protein|sunday driver 1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50962174, end_position_on_the_genomic_accession=51120868, orientation='minus', exon_count=34, OMIM=[605430], no_hdr0=''),
    9044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9044, CurrentID=0, Status='live', Symbol='BTAF1', Aliases=['MOT1', 'TAF(II)170', 'TAF172', 'TAFII170'], description='B-TFIID TATA-box binding protein associated factor 1', other_designations='TATA-binding protein-associated factor 172|ATP-dependent helicase BTAF1|B-TFIID transcription factor-associated 170 kDa subunit|BTAF1 RNA polymerase II, B-TFIID transcription factor-associated, 170kDa (Mot1 homolog, S. cerevisiae)|Mot1 homolog|TBP-associated factor 172', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91923770, end_position_on_the_genomic_accession=92031437, orientation='plus', exon_count=44, OMIM=[605191], no_hdr0=''),
    9045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9045, CurrentID=0, Status='live', Symbol='RPL14', Aliases=['CAG-ISL-7', 'CTG-B33', 'L14', 'RL14', 'hRL14'], description='ribosomal protein L14', other_designations='60S ribosomal protein L14|large ribosomal subunit protein eL14', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40457339, end_position_on_the_genomic_accession=40468587, orientation='plus', exon_count=6, OMIM=[617414], no_hdr0=''),
    9046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9046, CurrentID=0, Status='live', Symbol='DOK2', Aliases=['p56DOK', 'p56dok-2'], description='docking protein 2', other_designations='docking protein 2|docking protein 2, 56kD|docking protein 2, 56kDa|downstream of tyrosine kinase 2|p56(dok-2)', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=21908873, end_position_on_the_genomic_accession=21913717, orientation='minus', exon_count=5, OMIM=[604997], no_hdr0=''),
    9047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9047, CurrentID=0, Status='live', Symbol='SH2D2A', Aliases=['F2771', 'SCAP', 'TSAD', 'VRAP'], description='SH2 domain containing 2A', other_designations='SH2 domain-containing protein 2A|SH2 domain protein 2A|T cell specific adapter protein TSAd|T lymphocyte specific adaptor protein|VEGF receptor-associated protein', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156806238, end_position_on_the_genomic_accession=156816853, orientation='minus', exon_count=9, OMIM=[604514], no_hdr0=''),
    9048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9048, CurrentID=0, Status='live', Symbol='ARTN', Aliases=['ART', 'ENOVIN', 'EVN', 'NBN'], description='artemin', other_designations='artemin|neublastin', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43933801, end_position_on_the_genomic_accession=43937240, orientation='plus', exon_count=5, OMIM=[603886], no_hdr0=''),
    9049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9049, CurrentID=0, Status='live', Symbol='AIP', Aliases=['ARA9', 'FKBP16', 'FKBP37', 'PITA1', 'SMTPHN', 'XAP-2', 'XAP2'], description='aryl hydrocarbon receptor interacting protein', other_designations='AH receptor-interacting protein|Ah receptor activated 9|FK506-binding protein 37|FKBP prolyl isomerase 16|HBV X-associated protein 2|X-associated protein-2|aryl hydrocarbon receptor-associated protein 9|hepatitis B virus X-associated cellular protein 2|immunophilin homolog ARA9', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67468179, end_position_on_the_genomic_accession=67491103, orientation='plus', exon_count=8, OMIM=[605555], no_hdr0=''),
    9050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9050, CurrentID=0, Status='live', Symbol='PSTPIP2', Aliases=['MAYP'], description='proline-serine-threonine phosphatase interacting protein 2', other_designations='proline-serine-threonine phosphatase-interacting protein 2|PEST phosphatase-interacting protein 2', map_location='tdb7990', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=45983536, end_position_on_the_genomic_accession=46072327, orientation='minus', exon_count=16, OMIM=[616046], no_hdr0=''),
    9051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9051, CurrentID=0, Status='live', Symbol='PSTPIP1', Aliases=['CD2BP1', 'CD2BP1L', 'CD2BP1S', 'H-PIP', 'PAPAS', 'PSTPIP'], description='proline-serine-threonine phosphatase interacting protein 1', other_designations='proline-serine-threonine phosphatase-interacting protein 1|CD2 antigen-binding protein 1|CD2 cytoplasmic tail-binding protein|CD2-binding protein 1|PEST phosphatase-interacting protein 1|truncated proline-serine-threonine phosphatase interacting protein 1', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76994680, end_position_on_the_genomic_accession=77037475, orientation='plus', exon_count=20, OMIM=[606347], no_hdr0=''),
    9052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9052, CurrentID=0, Status='live', Symbol='GPRC5A', Aliases=['GPCR5A', 'PEIG-1', 'RAI3', 'RAIG1', 'TIG1'], description='G protein-coupled receptor class C group 5 member A', other_designations='retinoic acid-induced protein 3|G-protein coupled receptor family C group 5 member A|TPA induced gene 1|orphan G-protein-coupling receptor PEIG-1|phorbol ester induced gene 1|phorbol ester induced protein-1|retinoic acid induced 3|retinoic acid responsive|retinoic acid-induced gene 1 protein', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12891562, end_position_on_the_genomic_accession=12917937, orientation='plus', exon_count=4, OMIM=[604138], no_hdr0=''),
    9053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9053, CurrentID=0, Status='live', Symbol='MAP7', Aliases=['E-MAP-115', 'EMAP115'], description='microtubule associated protein 7', other_designations='ensconsin|dJ325F22.2 (microtubule-associated protein 7 (EMAP115, E-MAP-115))|epithelial microtubule-associated protein of 115 kDa', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136342734, end_position_on_the_genomic_accession=136550422, orientation='minus', exon_count=21, OMIM=[604108], no_hdr0=''),
    9054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9054, CurrentID=0, Status='live', Symbol='NFS1', Aliases=['COXPD52', 'HUSSY-08', 'IscS', 'NIFS'], description='NFS1 cysteine desulfurase', other_designations='cysteine desulfurase, mitochondrial|NFS1 nitrogen fixation 1 homolog|nitrogen fixation 1 (S. cerevisiae, homolog)|nitrogen-fixing bacteria S-like protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35668052, end_position_on_the_genomic_accession=35699352, orientation='minus', exon_count=14, OMIM=[603485], no_hdr0=''),
    9055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9055, CurrentID=0, Status='live', Symbol='PRC1', Aliases=['ASE1'], description='protein regulator of cytokinesis 1', other_designations='protein regulator of cytokinesis 1|anaphase spindle elongation 1 homolog|protein regulating cytokinesis 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90966038, end_position_on_the_genomic_accession=90994576, orientation='minus', exon_count=15, OMIM=[603484], no_hdr0=''),
    9056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9056, CurrentID=0, Status='live', Symbol='SLC7A7', Aliases=['LAT3', 'LPI', 'MOP-2', 'Y+LAT1', 'y+LAT-1'], description='solute carrier family 7 member 7', other_designations='Y+L amino acid transporter 1|monocyte amino acid permease 2|solute carrier family 7 (amino acid transporter light chain, y+L system), member 7|solute carrier family 7 (cationic amino acid transporter, y+ system), member 7|y(+)L-type amino acid transporter 1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22773222, end_position_on_the_genomic_accession=22819796, orientation='minus', exon_count=12, OMIM=[603593], no_hdr0=''),
    9057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9057, CurrentID=0, Status='live', Symbol='SLC7A6', Aliases=['LAT-2', 'LAT3', 'y+LAT-2'], description='solute carrier family 7 member 6', other_designations='Y+L amino acid transporter 2|amino acid permease|cationic amino acid transporter, y+ system|solute carrier family 7 (amino acid transporter light chain, y+L system), member 6|solute carrier family 7 (cationic amino acid transporter, y+ system), member 6|y(+)L-type amino acid transporter 2|y+LAT2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68264510, end_position_on_the_genomic_accession=68301819, orientation='plus', exon_count=15, OMIM=[605641], no_hdr0=''),
    9058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9058, CurrentID=0, Status='live', Symbol='SLC13A2', Aliases=['NADC1', 'NaCT', 'NaDC-1', 'SDCT1'], description='solute carrier family 13 member 2', other_designations='solute carrier family 13 member 2|Na(+)-coupled citrate transporter|Na(+)/dicarboxylate cotransporter 1|renal sodium/dicarboxylate cotransporter|solute carrier family 13 (sodium-dependent dicarboxylate transporter), member 2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28473357, end_position_on_the_genomic_accession=28497781, orientation='plus', exon_count=14, OMIM=[604148], no_hdr0=''),
    9060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9060, CurrentID=0, Status='live', Symbol='PAPSS2', Aliases=['ATPSK2', 'BCYM4', 'SK2'], description="3'-phosphoadenosine 5'-phosphosulfate synthase 2", other_designations="bifunctional 3'-phosphoadenosine 5'-phosphosulfate synthase 2|3-prime-phosphoadenosine 5-prime-phosphosulfate synthase 2|ATP sulfurylase/APS kinase 2|ATP sulfurylase/adenosine 5'-phosphosulfate kinase|PAPS synthase 2|PAPS synthetase 2|SK 2|adenosine 5'-phosphosulfate kinase|adenylyl-sulfate kinase|bifunctional 3'-phosphoadenosine 5'-phosphosulfate synthethase 2|epididymis secretory sperm binding protein|sulfate adenylyltransferase", map_location='10q23.2-q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87659878, end_position_on_the_genomic_accession=87747705, orientation='plus', exon_count=13, OMIM=[603005], no_hdr0=''),
    9061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9061, CurrentID=0, Status='live', Symbol='PAPSS1', Aliases=['ATPSK1', 'PAPSS', 'SK1'], description="3'-phosphoadenosine 5'-phosphosulfate synthase 1", other_designations="bifunctional 3'-phosphoadenosine 5'-phosphosulfate synthase 1|3-prime-phosphoadenosine 5-prime-phosphosulfate synthase 1|PAPS synthase 1|PAPSS 1|SK 1|adenylyl-sulfate kinase|sulfate adenylyltransferase|sulfurylase kinase 1", map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=107613666, end_position_on_the_genomic_accession=107720234, orientation='minus', exon_count=12, OMIM=[603262], no_hdr0=''),
    9063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9063, CurrentID=0, Status='live', Symbol='PIAS2', Aliases=['ARIP3', 'DIP', 'MIZ1', 'PIASX', 'SIZ2', 'ZMIZ4'], description='protein inhibitor of activated STAT 2', other_designations='E3 SUMO-protein ligase PIAS2|DAB2-interacting protein|E3 SUMO-protein transferase PIAS2|androgen receptor-interacting protein 3|msx-interacting zinc finger protein|protein inhibitor of activated STAT X|zinc finger, MIZ-type containing 4', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46803218, end_position_on_the_genomic_accession=46920167, orientation='minus', exon_count=23, OMIM=[603567], no_hdr0=''),
    9064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9064, CurrentID=0, Status='live', Symbol='MAP3K6', Aliases=['ASK2', 'MAPKKK6', 'MEKK6'], description='mitogen-activated protein kinase kinase kinase 6', other_designations='mitogen-activated protein kinase kinase kinase 6|apoptosis signal-regulating kinase 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27355179, end_position_on_the_genomic_accession=27368037, orientation='minus', exon_count=29, OMIM=[604468], no_hdr0=''),
    9066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9066, CurrentID=0, Status='live', Symbol='SYT7', Aliases=['IPCA-7', 'IPCA7', 'PCANAP7', 'SYT-VII', 'SYTVII'], description='synaptotagmin 7', other_designations='synaptotagmin-7|prostate cancer-associated protein 7|synaptotagmin VII', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61513714, end_position_on_the_genomic_accession=61588404, orientation='minus', exon_count=18, OMIM=[604146], no_hdr0=''),
    9068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9068, CurrentID=0, Status='live', Symbol='ANGPTL1', Aliases=['ANG3', 'ANGPT3', 'ARP1', 'AngY', 'UNQ162', 'dJ595C2.2'], description='angiopoietin like 1', other_designations='angiopoietin-related protein 1|ANG-3|angioarrestin|angiopoietin 3|angiopoietin Y1|angiopoietin-like protein 1|dJ595C2.2 (angiopoietin Y1)', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=178849535, end_position_on_the_genomic_accession=178871077, orientation='minus', exon_count=7, OMIM=[603874], no_hdr0=''),
    9069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9069, CurrentID=0, Status='live', Symbol='CLDN12', Aliases=[], description='claudin 12', other_designations='claudin-12', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90403461, end_position_on_the_genomic_accession=90415954, orientation='plus', exon_count=4, OMIM=[611232], no_hdr0=''),
    9070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9070, CurrentID=0, Status='live', Symbol='ASH2L', Aliases=['ASH21', 'ASH2L2', 'Bre2', 'ASH2L'], description='ASH2 like, histone lysine methyltransferase complex subunit', other_designations='set1/Ash2 histone methyltransferase complex subunit ASH2|ASH2-like protein|ash2 (absent, small, or homeotic)-like', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38104965, end_position_on_the_genomic_accession=38140080, orientation='plus', exon_count=18, OMIM=[604782], no_hdr0=''),
    9071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9071, CurrentID=0, Status='live', Symbol='CLDN10', Aliases=['CPETRL3', 'HELIX', 'OSP-L', 'OSPL'], description='claudin 10', other_designations='claudin-10|OSP-like protein|oligodendrocyte-specific protein-like', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=95433588, end_position_on_the_genomic_accession=95579759, orientation='plus', exon_count=8, OMIM=[617579], no_hdr0=''),
    9073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9073, CurrentID=0, Status='live', Symbol='CLDN8', Aliases=['HEL-S-79'], description='claudin 8', other_designations='claudin-8|epididymis secretory protein Li 79', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30214006, end_position_on_the_genomic_accession=30216097, orientation='minus', exon_count=1, OMIM=[611231], no_hdr0=''),
    9074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9074, CurrentID=0, Status='live', Symbol='CLDN6', Aliases=[], description='claudin 6', other_designations='claudin-6|skullin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3014712, end_position_on_the_genomic_accession=3018183, orientation='minus', exon_count=2, OMIM=[615798], no_hdr0=''),
    9075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9075, CurrentID=0, Status='live', Symbol='CLDN2', Aliases=['OAZON'], description='claudin 2', other_designations='claudin-2|SP82', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106900164, end_position_on_the_genomic_accession=106930861, orientation='plus', exon_count=4, OMIM=[300520], no_hdr0=''),
    9076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9076, CurrentID=0, Status='live', Symbol='CLDN1', Aliases=['CLD1', 'ILVASC', 'SEMP1'], description='claudin 1', other_designations='claudin-1|senescence-associated epithelial membrane protein 1', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=190305707, end_position_on_the_genomic_accession=190322446, orientation='minus', exon_count=4, OMIM=[603718], no_hdr0=''),
    9077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9077, CurrentID=0, Status='live', Symbol='DIRAS3', Aliases=['ARHI', 'NOEY2'], description='DIRAS family GTPase 3', other_designations='GTP-binding protein Di-Ras3|DIRAS family, GTP-binding RAS-like 3|distinct subgroup of the Ras family member 3|ras homolog gene family, member I|rho-related GTP-binding protein RhoI', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=68045962, end_position_on_the_genomic_accession=68050627, orientation='minus', exon_count=2, OMIM=[605193], no_hdr0=''),
    9079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9079, CurrentID=0, Status='live', Symbol='LDB2', Aliases=['CLIM1', 'LDB-2', 'LDB1'], description='LIM domain binding 2', other_designations='LIM domain-binding protein 2|LIM binding domain 2|LIM domain-binding factor CLIM1|LIM domain-binding factor-2|carboxyl-terminal LIM domain-binding protein 1', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=16501541, end_position_on_the_genomic_accession=16898787, orientation='minus', exon_count=17, OMIM=[603450], no_hdr0=''),
    9080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9080, CurrentID=0, Status='live', Symbol='CLDN9', Aliases=['DFNB116'], description='claudin 9', other_designations='claudin-9', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3012923, end_position_on_the_genomic_accession=3014505, orientation='plus', exon_count=1, OMIM=[615799], no_hdr0=''),
    9081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9081, CurrentID=0, Status='live', Symbol='PRY', Aliases=['PRY1', 'PTPN13LY'], description='PTPN13 like Y-linked', other_designations='PTPN13-like protein, Y-linked|testis-specific PTP-BL-related protein on Y', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=22490291, end_position_on_the_genomic_accession=22516303, orientation='plus', exon_count=4, OMIM=[400019], no_hdr0=''),
    9083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9083, CurrentID=0, Status='live', Symbol='BPY2', Aliases=['BPY2A', 'VCY2', 'VCY2A'], description='basic charge Y-linked 2', other_designations='testis-specific basic protein Y 2|basic protein on Y chromosome 2|testis-specific basic protein on Y, 2|variable charge, Y-linked, 2|variably charged protein Y 2', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=22984263, end_position_on_the_genomic_accession=23005465, orientation='plus', exon_count=9, OMIM=[400013], no_hdr0=''),
    9084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9084, CurrentID=0, Status='live', Symbol='VCY', Aliases=['BPY11', 'VCY1A', 'VCY'], description='variable charge Y-linked', other_designations='testis-specific basic protein Y 1|basic charge, Y-linked 1|basic protein on Y chromosome, 1|testis-specific basic protein on Y, 1|variable charge, Y chromosome|variably charged protein Y', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=13985772, end_position_on_the_genomic_accession=13986473, orientation='minus', exon_count=2, OMIM=[400012], no_hdr0=''),
    9085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9085, CurrentID=0, Status='live', Symbol='CDY1', Aliases=['CDYA', 'CDY1'], description='chromodomain Y-linked 1', other_designations='testis-specific chromodomain protein Y 1|chromodomain protein, Y chromosome, 1|chromodomain protein, Y-linked, 1|testis-specific chromodomain protein on Y', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=25622095, end_position_on_the_genomic_accession=25625511, orientation='plus', exon_count=3, OMIM=[400016], no_hdr0=''),
    9086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9086, CurrentID=0, Status='live', Symbol='EIF1AY', Aliases=['eIF-4C'], description='eukaryotic translation initiation factor 1A Y-linked', other_designations='eukaryotic translation initiation factor 1A, Y-chromosomal|eukaryotic translation initiation factor 1A, Y chromosome|eukaryotic translation initiation factor 4C', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=20575776, end_position_on_the_genomic_accession=20593154, orientation='plus', exon_count=7, OMIM=[400014], no_hdr0=''),
    9087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9087, CurrentID=0, Status='live', Symbol='TMSB4Y', Aliases=['TB4Y'], description='thymosin beta 4 Y-linked', other_designations='thymosin beta-4, Y-chromosomal|thymosin, beta 4, Y chromosome', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=13703899, end_position_on_the_genomic_accession=13706024, orientation='plus', exon_count=2, OMIM=[400017], no_hdr0=''),
    9088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9088, CurrentID=0, Status='live', Symbol='PKMYT1', Aliases=['MYT1', 'PPP1R126'], description='protein kinase, membrane associated tyrosine/threonine 1', other_designations='membrane-associated tyrosine- and threonine-specific cdc2-inhibitory kinase|myt1 kinase|protein phosphatase 1, regulatory subunit 126', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2972808, end_position_on_the_genomic_accession=2980494, orientation='minus', exon_count=10, OMIM=[602474], no_hdr0=''),
    9091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9091, CurrentID=0, Status='live', Symbol='PIGQ', Aliases=['DEE77', 'EIEE77', 'GPI1', 'c407A10.1'], description='phosphatidylinositol glycan anchor biosynthesis class Q', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit Q|N-acetylglucosaminyl transferase component Gpi1|N-acetylglucosamyl transferase component GPI1|PIG-Q|c407A10.1 (GPI1 (N-acetylglucosaminyl transferase component))|phosphatidylinositol glycan, class Q|phosphatidylinositol-glycan biosynthesis class Q protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=569968, end_position_on_the_genomic_accession=584109, orientation='plus', exon_count=11, OMIM=[605754], no_hdr0=''),
    9092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9092, CurrentID=0, Status='live', Symbol='SART1', Aliases=['Ara1', 'HAF', 'HOMS1259', 'SNRNP110', 'Snu66', 'SART1'], description='spliceosome associated factor 1, recruiter of U4/U6.U5 tri-snRNP', other_designations='U4/U6.U5 tri-snRNP-associated protein 1|IgE autoantigen|SART-1|SART1(259) protein|SART1(800) protein|SART1, U4/U6.U5 tri-snRNP-associated protein 1|SNU66 homolog|U4/U6.U5 tri-snRNP-associated 110 kDa protein|hSART-1|hSnu66|hypoxia associated factor|small nuclear ribonucleoprotein 110kDa (U4/U6.U5)|squamous cell carcinoma antigen recognised by T cells|squamous cell carcinoma antigen recognized by T-cells 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65961727, end_position_on_the_genomic_accession=65980137, orientation='plus', exon_count=20, OMIM=[605941], no_hdr0=''),
    9093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9093, CurrentID=0, Status='live', Symbol='DNAJA3', Aliases=['HCA57', 'TID1', 'hTID-1'], description='DnaJ heat shock protein family (Hsp40) member A3', other_designations='dnaJ homolog subfamily A member 3, mitochondrial|DnaJ (Hsp40) homolog, subfamily A, member 3|dnaJ protein Tid-1|hepatocellular carcinoma-associated antigen 57|tumorous imaginal discs protein Tid56 homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4425868, end_position_on_the_genomic_accession=4456775, orientation='plus', exon_count=12, OMIM=[608382], no_hdr0=''),
    9094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9094, CurrentID=0, Status='live', Symbol='UNC119', Aliases=['HRG4', 'IMD13', 'POC7', 'POC7A'], description='unc-119 lipid binding chaperone', other_designations='protein unc-119 homolog A|POC7 centriolar protein homolog A|retinal protein 4|unc-119 homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28546707, end_position_on_the_genomic_accession=28552633, orientation='minus', exon_count=5, OMIM=[604011], no_hdr0=''),
    9095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9095, CurrentID=0, Status='live', Symbol='TBX19', Aliases=['TBS19', 'TPIT', 'dJ747L4.1'], description='T-box transcription factor 19', other_designations='T-box transcription factor TBX19|T-box 19|T-box factor, pituitary|T-box protein 19|TBS 19', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168280877, end_position_on_the_genomic_accession=168314426, orientation='plus', exon_count=8, OMIM=[604614], no_hdr0=''),
    9096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9096, CurrentID=0, Status='live', Symbol='TBX18', Aliases=['CAKUT2'], description='T-box transcription factor 18', other_designations='T-box transcription factor TBX18|T-box 18|T-box protein 18', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=84732496, end_position_on_the_genomic_accession=84764598, orientation='minus', exon_count=8, OMIM=[604613], no_hdr0=''),
    9097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9097, CurrentID=0, Status='live', Symbol='USP14', Aliases=['TGT'], description='ubiquitin specific peptidase 14', other_designations='ubiquitin carboxyl-terminal hydrolase 14|deubiquitinating enzyme 14|tRNA-guanine transglycosylase, 60-kD subunit|ubiquitin specific peptidase 14 (tRNA-guanine transglycosylase)|ubiquitin specific protease 14 (tRNA-guanine transglycosylase)|ubiquitin thioesterase 14|ubiquitin thiolesterase 14|ubiquitin-specific processing protease 14', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=158557, end_position_on_the_genomic_accession=214629, orientation='plus', exon_count=16, OMIM=[607274], no_hdr0=''),
    9098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9098, CurrentID=0, Status='live', Symbol='USP6', Aliases=['HRP1', 'TRE17', 'TRE2', 'TRESMCR', 'Tre-2-short', 'USP6'], description='ubiquitin specific peptidase 6', other_designations='ubiquitin carboxyl-terminal hydrolase 6|TBC1D3 and USP32 fusion|deubiquitinating enzyme 6|hyperpolymorphic gene 1|proto-oncogene TRE-2|ubiquitin specific peptidase 6 (Tre-2 oncogene)|ubiquitin specific protease 6 (Tre-2 oncogene)|ubiquitin thioesterase 6|ubiquitin thiolesterase 6|ubiquitin-specific protease USP6|ubiquitin-specific-processing protease 6', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5116032, end_position_on_the_genomic_accession=5175032, orientation='plus', exon_count=41, OMIM=[604334], no_hdr0=''),
    9099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9099, CurrentID=0, Status='live', Symbol='USP2', Aliases=['UBP41', 'USP9'], description='ubiquitin specific peptidase 2', other_designations='ubiquitin carboxyl-terminal hydrolase 2|41 kDa ubiquitin-specific protease|deubiquitinating enzyme 2|ubiquitin specific protease 12|ubiquitin specific protease 9|ubiquitin thioesterase 2|ubiquitin-specific-processing protease 2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119355215, end_position_on_the_genomic_accession=119381690, orientation='minus', exon_count=17, OMIM=[604725], no_hdr0=''),
    9100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9100, CurrentID=0, Status='live', Symbol='USP10', Aliases=['UBPO'], description='ubiquitin specific peptidase 10', other_designations='ubiquitin carboxyl-terminal hydrolase 10|deubiquitinating enzyme 10|ubiquitin specific protease 10|ubiquitin thioesterase 10|ubiquitin thiolesterase 10|ubiquitin-specific-processing protease 10', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84699977, end_position_on_the_genomic_accession=84779922, orientation='plus', exon_count=19, OMIM=[609818], no_hdr0=''),
    9101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9101, CurrentID=0, Status='live', Symbol='USP8', Aliases=['HumORF8', 'PITA4', 'SPG59', 'UBPY'], description='ubiquitin specific peptidase 8', other_designations='ubiquitin carboxyl-terminal hydrolase 8|deubiquitinating enzyme 8|ubiquitin isopeptidase Y|ubiquitin thiolesterase 8|ubiquitin-specific-processing protease 8', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50424359, end_position_on_the_genomic_accession=50514421, orientation='plus', exon_count=23, OMIM=[603158], no_hdr0=''),
    9103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9103, CurrentID=0, Status='live', Symbol='FCGR2C', Aliases=['CD32', 'CD32C', 'CDW32', 'FCG2', 'FCRIIC', 'IGFR2'], description='Fc fragment of IgG receptor IIc (gene/pseudogene)', other_designations='low affinity immunoglobulin gamma Fc region receptor II-c|Fc fragment of IgG, low affinity IIc, receptor for (CD32)|Fc gamma receptor IIC|IgG Fc receptor II-c|fc-gamma-RIIc|immunoglobulin G Fc receptor II-c', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161581339, end_position_on_the_genomic_accession=161601220, orientation='plus', exon_count=7, OMIM=[612169], no_hdr0=''),
    9104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9104, CurrentID=0, Status='live', Symbol='RGN', Aliases=['GNL', 'HEL-S-41', 'RC', 'SMP30'], description='regucalcin', other_designations='regucalcin|epididymis secretory protein Li 41|gluconolactonase|senescence marker protein 30', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47078414, end_position_on_the_genomic_accession=47093313, orientation='plus', exon_count=8, OMIM=[300212], no_hdr0=''),
    9107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9107, CurrentID=0, Status='live', Symbol='MTMR6', Aliases=[], description='myotubularin related protein 6', other_designations='myotubularin-related protein 6|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphate phosphatase', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=25246222, end_position_on_the_genomic_accession=25287512, orientation='minus', exon_count=16, OMIM=[603561], no_hdr0=''),
    9108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9108, CurrentID=0, Status='live', Symbol='MTMR7', Aliases=[], description='myotubularin related protein 7', other_designations='myotubularin-related protein 7|inositol 1,3-bisphosphate phosphatase|phosphatidylinositol-3-phosphate phosphatase', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17296128, end_position_on_the_genomic_accession=17413353, orientation='minus', exon_count=17, OMIM=[603562], no_hdr0=''),
    9110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9110, CurrentID=0, Status='live', Symbol='MTMR4', Aliases=['FYVE-DSP2', 'ZFYVE11'], description='myotubularin related protein 4', other_designations='myotubularin-related protein 4|FYVE domain-containing dual specificity protein phosphatase 2|zinc finger FYVE domain-containing protein 11|zinc finger, FYVE domain containing 11', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58489537, end_position_on_the_genomic_accession=58518109, orientation='minus', exon_count=23, OMIM=[603559], no_hdr0=''),
    9111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9111, CurrentID=0, Status='live', Symbol='NMI', Aliases=[], description='N-myc and STAT interactor', other_designations='N-myc-interactor', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151270465, end_position_on_the_genomic_accession=151289668, orientation='minus', exon_count=9, OMIM=[603525], no_hdr0=''),
    9112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9112, CurrentID=0, Status='live', Symbol='MTA1', Aliases=[], description='metastasis associated 1', other_designations='metastasis-associated protein MTA1|metastasis associated gene 1 protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105419827, end_position_on_the_genomic_accession=105470729, orientation='plus', exon_count=23, OMIM=[603526], no_hdr0=''),
    9113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9113, CurrentID=0, Status='live', Symbol='LATS1', Aliases=['WARTS', 'wts'], description='large tumor suppressor kinase 1', other_designations='serine/threonine-protein kinase LATS1|LATS (large tumor suppressor, Drosophila) homolog 1|LATS, large tumor suppressor, homolog 1|WARTS protein kinase|h-warts|large tumor suppressor homolog 1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149658153, end_position_on_the_genomic_accession=149718101, orientation='minus', exon_count=16, OMIM=[603473], no_hdr0=''),
    9114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9114, CurrentID=0, Status='live', Symbol='ATP6V0D1', Aliases=['ATP6D', 'ATP6DV', 'P39', 'VATX', 'VMA6', 'VPATPD'], description='ATPase H+ transporting V0 subunit d1', other_designations='V-type proton ATPase subunit d 1|32 kDa accessory protein|ATPase, H+ transporting, lysosomal (vacuolar proton pump), member D|ATPase, H+ transporting, lysosomal 38kDa, V0 subunit d1|H(+)-transporting two-sector ATPase, subunit D|V-ATPase 40 KDa accessory protein|V-ATPase AC39 subunit|V-ATPase subunit d 1|V-ATPase, subunit D|vacuolar proton pump subunit d 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67438019, end_position_on_the_genomic_accession=67481157, orientation='minus', exon_count=10, OMIM=[607028], no_hdr0=''),
    9117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9117, CurrentID=0, Status='live', Symbol='SEC22C', Aliases=['SEC22L3'], description='SEC22 homolog C, vesicle trafficking protein', other_designations='vesicle-trafficking protein SEC22c|SEC22 vesicle trafficking protein homolog C|SEC22 vesicle trafficking protein-like 3|SEC22 vesicle trafficking protein-like protein C|secretion deficient 22C', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42547969, end_position_on_the_genomic_accession=42603127, orientation='minus', exon_count=11, OMIM=[604028], no_hdr0=''),
    9118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9118, CurrentID=0, Status='live', Symbol='INA', Aliases=['NEF5', 'NF-66', 'TXBP-1'], description='internexin neuronal intermediate filament protein alpha', other_designations='alpha-internexin|66 kDa neurofilament protein|alpha-Inx|neurofilament 5 (66kD)|neurofilament-66, tax-binding protein', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103277138, end_position_on_the_genomic_accession=103290346, orientation='plus', exon_count=3, OMIM=[605338], no_hdr0=''),
    9119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9119, CurrentID=0, Status='live', Symbol='KRT75', Aliases=['CK-75', 'K6HF', 'K75', 'KB18', 'PFB', 'hK6hf'], description='keratin 75', other_designations='keratin, type II cytoskeletal 75|cytokeratin type II|cytokeratin-75|keratin 75, type II|keratin-6 hair follicle|type II keratin-18|type II keratin-K6hf|type-II keratin Kb18', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52424070, end_position_on_the_genomic_accession=52434371, orientation='minus', exon_count=9, OMIM=[609025], no_hdr0=''),
    9120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9120, CurrentID=0, Status='live', Symbol='SLC16A6', Aliases=['MCT6', 'MCT7'], description='solute carrier family 16 member 6', other_designations='monocarboxylate transporter 7|breast cancer protein BCY5|monocarboxylate transporter 6|solute carrier family 16, member 6 (monocarboxylic acid transporter 7)', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68267026, end_position_on_the_genomic_accession=68291439, orientation='minus', exon_count=11, OMIM=[603880], no_hdr0=''),
    9121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9121, CurrentID=0, Status='live', Symbol='SLC16A5', Aliases=['MCT5', 'MCT6'], description='solute carrier family 16 member 5', other_designations='monocarboxylate transporter 6|monocarboxylate transporter 5|solute carrier family 16 (monocarboxylate transporter), member 5|solute carrier family 16 (monocarboxylic acid transporters), member 5|solute carrier family 16, member 5 (monocarboxylic acid transporter 6)', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75087765, end_position_on_the_genomic_accession=75106162, orientation='plus', exon_count=8, OMIM=[603879], no_hdr0=''),
    9122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9122, CurrentID=0, Status='live', Symbol='SLC16A4', Aliases=['MCT4', 'MCT5'], description='solute carrier family 16 member 4', other_designations='monocarboxylate transporter 5|MCT 4|MCT 5|monocarboxylate transporter 4|solute carrier family 16 (monocarboxylic acid transporters), member 4|solute carrier family 16, member 4 (monocarboxylic acid transporter 5)', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110362856, end_position_on_the_genomic_accession=110391971, orientation='minus', exon_count=10, OMIM=[603878], no_hdr0=''),
    9123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9123, CurrentID=0, Status='live', Symbol='SLC16A3', Aliases=['MCT 3', 'MCT 4', 'MCT-3', 'MCT-4', 'MCT3', 'MCT4'], description='solute carrier family 16 member 3', other_designations='monocarboxylate transporter 4|monocarboxylate transporter 3|solute carrier family 16 (monocarboxylate transporter), member 3|solute carrier family 16 (monocarboxylic acid transporters), member 3|solute carrier family 16, member 3 (monocarboxylic acid transporter 4)', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82217951, end_position_on_the_genomic_accession=82240086, orientation='plus', exon_count=10, OMIM=[603877], no_hdr0=''),
    9124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9124, CurrentID=0, Status='live', Symbol='PDLIM1', Aliases=['CLIM1', 'CLP-36', 'CLP36', 'HEL-S-112', 'hCLIM1'], description='PDZ and LIM domain 1', other_designations='PDZ and LIM domain protein 1|LIM domain protein CLP-36|carboxyl terminal LIM domain protein 1|elfin|epididymis secretory protein Li 112', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95237569, end_position_on_the_genomic_accession=95291006, orientation='minus', exon_count=7, OMIM=[605900], no_hdr0=''),
    9125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9125, CurrentID=0, Status='live', Symbol='CNOT9', Aliases=['CAF40', 'CT129', 'RCD-1', 'RCD1', 'RQCD1'], description='CCR4-NOT transcription complex subunit 9', other_designations='CCR4-NOT transcription complex subunit 9|RCD1 required for cell differentiation1 homolog|cancer/testis antigen 129|cell differentiation protein RCD1 homolog|cell differentiation protein RQCD1 homolog|protein involved in sexual development', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218568578, end_position_on_the_genomic_accession=218597080, orientation='plus', exon_count=12, OMIM=[612054], no_hdr0=''),
    9126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9126, CurrentID=0, Status='live', Symbol='SMC3', Aliases=['BAM', 'BMH', 'CDLS3', 'CSPG6', 'HCAPL1', 'SMC3'], description='structural maintenance of chromosomes 3', other_designations='structural maintenance of chromosomes protein 3|SMC protein 3|basement membrane-associated chondroitin proteoglycan|chondroitin sulfate proteoglycan 6 (bamacan)|chromosome-associated polypeptide', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110567695, end_position_on_the_genomic_accession=110606048, orientation='plus', exon_count=29, OMIM=[606062], no_hdr0=''),
    9127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9127, CurrentID=0, Status='live', Symbol='P2RX6', Aliases=['P2RXL1', 'P2X6', 'P2XM'], description='purinergic receptor P2X 6', other_designations='P2X purinoceptor 6|ATP receptor|purinergic receptor P2X, ligand gated ion channel, 6|purinergic receptor P2X-like 1, orphan receptor|purinoceptor P2X6|purinoreceptor P2X6|skeletal muscle-expressed P2X', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21009699, end_position_on_the_genomic_accession=21028013, orientation='plus', exon_count=14, OMIM=[608077], no_hdr0=''),
    9128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9128, CurrentID=0, Status='live', Symbol='PRPF4', Aliases=['HPRP4', 'HPRP4P', 'PRP4', 'Prp4p', 'RP70', 'SNRNP60'], description='pre-mRNA processing factor 4', other_designations='U4/U6 small nuclear ribonucleoprotein Prp4|PRP4 homolog|PRP4 pre-mRNA processing factor 4 homolog|PRP4/STK/WD splicing factor|U4/U6 snRNP 60 kDa protein|WD splicing factor Prp4', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113275658, end_position_on_the_genomic_accession=113292905, orientation='plus', exon_count=14, OMIM=[607795], no_hdr0=''),
    9129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9129, CurrentID=0, Status='live', Symbol='PRPF3', Aliases=['HPRP3', 'HPRP3P', 'PRP3', 'Prp3p', 'RP18', 'SNRNP90'], description='pre-mRNA processing factor 3', other_designations='U4/U6 small nuclear ribonucleoprotein Prp3|PRP3 pre-mRNA processing factor 3 homolog|U4/U6 snRNP 90 kDa protein|U4/U6-associated RNA splicing factor|pre-mRNA-splicing factor 3', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150321468, end_position_on_the_genomic_accession=150353233, orientation='plus', exon_count=20, OMIM=[607301], no_hdr0=''),
    9130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9130, CurrentID=0, Status='live', Symbol='FAM50A', Aliases=['9F', 'DXS9928E', 'HXC-26', 'HXC26', 'MRXSA', 'XAP5'], description='family with sequence similarity 50 member A', other_designations='protein FAM50A|protein XAP-5', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154444141, end_position_on_the_genomic_accession=154450654, orientation='plus', exon_count=13, OMIM=[300453], no_hdr0=''),
    9131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9131, CurrentID=0, Status='live', Symbol='AIFM1', Aliases=['AIF', 'AUNX1', 'CMT2D', 'CMTX4', 'COWCK', 'COXPD6', 'DFNX5', 'NADMR', 'NAMSD', 'PDCD8', 'SEMDHL'], description='apoptosis inducing factor mitochondria associated 1', other_designations='apoptosis-inducing factor 1, mitochondrial|apoptosis-inducing factor, mitochondrion-associated, 1|auditory neuropathy, X-linked recessive 1|programmed cell death 8 (apoptosis-inducing factor)|striatal apoptosis-inducing factor|testicular secretory protein Li 4', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130129362, end_position_on_the_genomic_accession=130165841, orientation='minus', exon_count=18, OMIM=[300169, 300614, 310490], no_hdr0=''),
    9132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9132, CurrentID=0, Status='live', Symbol='KCNQ4', Aliases=['DFNA2', 'DFNA2A', 'KV7.4'], description='potassium voltage-gated channel subfamily Q member 4', other_designations='potassium voltage-gated channel subfamily KQT member 4|potassium channel KQT-like 4|potassium channel subunit alpha KvLQT4|potassium channel, voltage gated KQT-like subfamily Q, member 4|potassium voltage-gated channel, KQT-like subfamily, member 4', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40783787, end_position_on_the_genomic_accession=40840457, orientation='plus', exon_count=15, OMIM=[603537], no_hdr0=''),
    9133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9133, CurrentID=0, Status='live', Symbol='CCNB2', Aliases=['HsT17299'], description='cyclin B2', other_designations='G2/mitotic-specific cyclin-B2', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59105146, end_position_on_the_genomic_accession=59125045, orientation='plus', exon_count=9, OMIM=[602755], no_hdr0=''),
    9134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9134, CurrentID=0, Status='live', Symbol='CCNE2', Aliases=['CYCE2'], description='cyclin E2', other_designations='G1/S-specific cyclin-E2', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94880224, end_position_on_the_genomic_accession=94896671, orientation='minus', exon_count=15, OMIM=[603775], no_hdr0=''),
    9135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9135, CurrentID=0, Status='live', Symbol='RABEP1', Aliases=['RAB5EP', 'RABPT5'], description='rabaptin, RAB GTPase binding effector protein 1', other_designations='rab GTPase-binding effector protein 1|neurocrescin|rabaptin-4|rabaptin-5|rabaptin-5alpha|renal carcinoma antigen NY-REN-17', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5282272, end_position_on_the_genomic_accession=5386340, orientation='plus', exon_count=20, OMIM=[603616], no_hdr0=''),
    9136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9136, CurrentID=0, Status='live', Symbol='RRP9', Aliases=['RNU3IP2', 'U3-55K'], description='ribosomal RNA processing 9, U3 small nucleolar RNA binding protein', other_designations='U3 small nucleolar RNA-interacting protein 2|RNA, U3 small nucleolar interacting protein 2|RRP9 homolog|RRP9, small subunit (SSU) processome component, homolog|U3 small nucleolar ribonucleoprotein-associated 55 kDa protein|U3 snoRNP-associated 55-kDa protein|ribosomal RNA processing 9, small subunit (SSU) processome component, homolog', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51933429, end_position_on_the_genomic_accession=51941904, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    9138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9138, CurrentID=0, Status='live', Symbol='ARHGEF1', Aliases=['GEF1', 'IMD62', 'LBCL2', 'LSC', 'P115-RHOGEF', 'SUB1.5'], description='Rho guanine nucleotide exchange factor 1', other_designations='rho guanine nucleotide exchange factor 1|115 kDa guanine nucleotide exchange factor|115-kD protein|Lsc homolog|Rho guanine nucleotide exchange factor (GEF) 1|p115RhoGEF', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41883184, end_position_on_the_genomic_accession=41907452, orientation='plus', exon_count=30, OMIM=[601855], no_hdr0=''),
    9139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9139, CurrentID=0, Status='live', Symbol='CBFA2T2', Aliases=['EHT', 'MTGR1', 'ZMYND3', 'p85'], description='CBFA2/RUNX1 partner transcriptional co-repressor 2', other_designations='protein CBFA2T2|CBFA2/RUNX1 translocation partner 2|ETO homolog on chromosome 20|ETO homologous on chromosome 20|MTG8-like protein|MTG8-related protein 1|core-binding factor, runt domain, alpha subunit 2; translocated to, 2|myeloid translocation gene-related protein 1|myeloid translocation-related protein 1', map_location='20q11.21-q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33490070, end_position_on_the_genomic_accession=33650031, orientation='plus', exon_count=18, OMIM=[603672], no_hdr0=''),
    9140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9140, CurrentID=0, Status='live', Symbol='ATG12', Aliases=['APG12', 'APG12L', 'FBR93', 'HAPG12'], description='autophagy related 12', other_designations='ubiquitin-like protein ATG12|APG12 autophagy 12-like|ATG12 autophagy related 12 homolog|Apg12 (autophagy, yeast) homolog', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115828200, end_position_on_the_genomic_accession=115841565, orientation='minus', exon_count=6, OMIM=[609608], no_hdr0=''),
    9141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9141, CurrentID=0, Status='live', Symbol='PDCD5', Aliases=['TFAR19'], description='programmed cell death 5', other_designations='programmed cell death protein 5|TF-1 cell apoptosis-related protein 19|TF1 cell apoptosis-related gene 19|TFAR19 novel apoptosis-related', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32581190, end_position_on_the_genomic_accession=32587453, orientation='plus', exon_count=6, OMIM=[604583], no_hdr0=''),
    9143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9143, CurrentID=0, Status='live', Symbol='SYNGR3', Aliases=[], description='synaptogyrin 3', other_designations='synaptogyrin-3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1989970, end_position_on_the_genomic_accession=1994275, orientation='plus', exon_count=4, OMIM=[603927], no_hdr0=''),
    9144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9144, CurrentID=0, Status='live', Symbol='SYNGR2', Aliases=[], description='synaptogyrin 2', other_designations='synaptogyrin-2|cellugyrin', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78168545, end_position_on_the_genomic_accession=78172964, orientation='plus', exon_count=4, OMIM=[603926], no_hdr0=''),
    9145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9145, CurrentID=0, Status='live', Symbol='SYNGR1', Aliases=[], description='synaptogyrin 1', other_designations='synaptogyrin-1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39349991, end_position_on_the_genomic_accession=39385575, orientation='plus', exon_count=6, OMIM=[603925], no_hdr0=''),
    9146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9146, CurrentID=0, Status='live', Symbol='HGS', Aliases=['HRS'], description='hepatocyte growth factor-regulated tyrosine kinase substrate', other_designations='hepatocyte growth factor-regulated tyrosine kinase substrate|human growth factor-regulated tyrosine kinase substrate|protein pp110', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81684011, end_position_on_the_genomic_accession=81702121, orientation='plus', exon_count=22, OMIM=[604375], no_hdr0=''),
    9147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9147, CurrentID=0, Status='live', Symbol='NEMF', Aliases=['IDDSAPN', 'NY-CO-1', 'SDCCAG1'], description='nuclear export mediator factor', other_designations='nuclear export mediator factor NEMF|antigen NY-CO-1|caliban homolog|serologically defined colon cancer antigen 1', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49782083, end_position_on_the_genomic_accession=49852836, orientation='minus', exon_count=37, OMIM=[608378], no_hdr0=''),
    9148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9148, CurrentID=0, Status='live', Symbol='NEURL1', Aliases=['NEUR1', 'NEURL', 'RNF67', 'bA416N2.1', 'neu', 'neu-1'], description='neuralized E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase NEURL1|RING finger protein 67|RING-type E3 ubiquitin transferase NEURL1|h-neuralized 1|neuralized homolog|neuralized-like protein 1A', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103493705, end_position_on_the_genomic_accession=103592546, orientation='plus', exon_count=12, OMIM=[603804], no_hdr0=''),
    9149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9149, CurrentID=0, Status='live', Symbol='DYRK1B', Aliases=['AOMS3', 'MIRK'], description='dual specificity tyrosine phosphorylation regulated kinase 1B', other_designations='dual specificity tyrosine-phosphorylation-regulated kinase 1B|dual specificity tyrosine-(Y)-phosphorylation regulated kinase 1B|minibrain-related kinase|mirk protein kinase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39825350, end_position_on_the_genomic_accession=39834162, orientation='minus', exon_count=13, OMIM=[604556], no_hdr0=''),
    9150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9150, CurrentID=0, Status='live', Symbol='CTDP1', Aliases=['CCFDN', 'FCP1'], description='CTD phosphatase subunit 1', other_designations='RNA polymerase II subunit A C-terminal domain phosphatase|CTD (carboxy-terminal domain, RNA polymerase II, polypeptide A) phosphatase, subunit 1|CTD of POLR2A, phosphatase of, subunit 1|TFIIF-associating CTD phosphatase 1|serine phosphatase FCP1a|transcription factor IIF-associating CTD phosphatase 1', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79679803, end_position_on_the_genomic_accession=79756625, orientation='plus', exon_count=15, OMIM=[604927], no_hdr0=''),
    9152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9152, CurrentID=0, Status='live', Symbol='SLC6A5', Aliases=['GLYT-2', 'GLYT2', 'HKPX3', 'NET1'], description='solute carrier family 6 member 5', other_designations='sodium- and chloride-dependent glycine transporter 2|solute carrier family 6 (neurotransmitter transporter, glycine), member 5', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=20599494, end_position_on_the_genomic_accession=20659285, orientation='plus', exon_count=16, OMIM=[604159], no_hdr0=''),
    9153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9153, CurrentID=0, Status='live', Symbol='SLC28A2', Aliases=['CNT2', 'HCNT2', 'HsT17153', 'SPNT1'], description='solute carrier family 28 member 2', other_designations='sodium/nucleoside cotransporter 2|CNT 2|Na(+)/nucleoside cotransporter 2|SPNT|concentrative nucleoside transporter 2|sodium-coupled nucleoside transporter 2|sodium/purine nucleoside co-transporter|solute carrier family 28 (concentrative nucleoside transporter), member 2|solute carrier family 28 (sodium-coupled nucleoside transporter), member 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45252234, end_position_on_the_genomic_accession=45277846, orientation='plus', exon_count=18, OMIM=[606208], no_hdr0=''),
    9154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9154, CurrentID=0, Status='live', Symbol='SLC28A1', Aliases=['CNT1', 'HCNT1', 'URCTU'], description='solute carrier family 28 member 1', other_designations='sodium/nucleoside cotransporter 1|Na(+)/nucleoside cotransporter 1|concentrative nucleoside transporter 1|sodium-coupled nucleoside transporter 1|solute carrier family 28 (concentrative nucleoside transporter), member 1|solute carrier family 28 (sodium-coupled nucleoside transporter), member 1', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84884350, end_position_on_the_genomic_accession=84975649, orientation='plus', exon_count=29, OMIM=[606207], no_hdr0=''),
    9156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9156, CurrentID=0, Status='live', Symbol='EXO1', Aliases=['HEX1', 'hExoI'], description='exonuclease 1', other_designations='exonuclease 1|rad2 nuclease family member, homolog of S. cerevisiae exonuclease 1', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241847967, end_position_on_the_genomic_accession=241889939, orientation='plus', exon_count=18, OMIM=[606063], no_hdr0=''),
    9158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9158, CurrentID=0, Status='live', Symbol='FIBP', Aliases=['FGFIBP-1', 'TROFAS', 'FIBP'], description='FGF1 intracellular binding protein', other_designations='acidic fibroblast growth factor intracellular-binding protein|aFGF intracellular-binding protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65883740, end_position_on_the_genomic_accession=65888510, orientation='minus', exon_count=10, OMIM=[608296], no_hdr0=''),
    9159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9159, CurrentID=0, Status='live', Symbol='PCSK7', Aliases=['LPC', 'PC7', 'PC8', 'SPC7'], description='proprotein convertase subtilisin/kexin type 7', other_designations='proprotein convertase subtilisin/kexin type 7|lymphoma proprotein convertase|prohormone convertase 7|prohormone convertase PC7|proprotein convertase 7|proprotein convertase 8|proprotein convertase PC7|proprotein convertase subtilisin/kexin type 7 precursor variant 2|subtilisin/kexin-like protease PC7', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117201156, end_position_on_the_genomic_accession=117232525, orientation='minus', exon_count=21, OMIM=[604872], no_hdr0=''),
    9162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9162, CurrentID=0, Status='live', Symbol='DGKI', Aliases=['DGK-IOTA'], description='diacylglycerol kinase iota', other_designations='diacylglycerol kinase iota|DAG kinase iota|diglyceride kinase iota', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=137381037, end_position_on_the_genomic_accession=137846974, orientation='minus', exon_count=37, OMIM=[604072], no_hdr0=''),
    9166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9166, CurrentID=0, Status='live', Symbol='EBAG9', Aliases=['EB9', 'PDAF'], description='estrogen receptor binding site associated antigen 9', other_designations='receptor-binding cancer antigen expressed on SiSo cells|cancer-associated surface antigen RCAS1|estrogen receptor-binding fragment-associated gene 9 protein', map_location='8q23.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109539702, end_position_on_the_genomic_accession=109565996, orientation='plus', exon_count=8, OMIM=[605772], no_hdr0=''),
    9167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9167, CurrentID=0, Status='live', Symbol='COX7A2L', Aliases=['COX7AR', 'COX7RP', 'EB1', 'SCAF1', 'SCAFI', 'SIG81'], description='cytochrome c oxidase subunit 7A2 like', other_designations='cytochrome c oxidase subunit 7A-related protein, mitochondrial|COX7a-related protein|cytochrome c oxidase subunit VII-related protein|cytochrome c oxidase subunit VIIa polypeptide 2 like|cytochrome c oxidase subunit VIIa-related protein|estrogen receptor binding CpG island', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42335559, end_position_on_the_genomic_accession=42368957, orientation='minus', exon_count=6, OMIM=[605771], no_hdr0=''),
    9168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9168, CurrentID=0, Status='live', Symbol='TMSB10', Aliases=['MIG12', 'TB10'], description='thymosin beta 10', other_designations='thymosin beta-10|migration-inducing gene 12|migration-inducing protein 12', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=84905656, end_position_on_the_genomic_accession=84906671, orientation='plus', exon_count=3, OMIM=[188399], no_hdr0=''),
    9169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9169, CurrentID=0, Status='live', Symbol='SCAF11', Aliases=['CASP11', 'SFRS2IP', 'SIP1', 'SRRP129', 'SRSF2IP'], description='SR-related CTD associated factor 11', other_designations='protein SCAF11|CTD-associated SR protein 11|SC35-interacting protein 1|SFRS2-interacting protein|SR-related and CTD-associated factor 11|SRSF2-interacting protein|renal carcinoma antigen NY-REN-40|serine/arginine-rich splicing factor 2-interacting protein|splicing factor, arginine/serine-rich 2-interacting protein|splicing regulatory protein 129', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=45919131, end_position_on_the_genomic_accession=45992040, orientation='minus', exon_count=20, OMIM=[603668], no_hdr0=''),
    9170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9170, CurrentID=0, Status='live', Symbol='LPAR2', Aliases=['EDG-4', 'EDG4', 'LPA-2', 'LPA2'], description='lysophosphatidic acid receptor 2', other_designations='lysophosphatidic acid receptor 2|G protein-coupled receptor|LPA receptor 2|LPA receptor EDG4|endothelial differentiation, lysophosphatidic acid G-protein-coupled receptor, 4|lysophosphatidic acid receptor EDG4|lysophosphatidic acid receptor Edg-4', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19623655, end_position_on_the_genomic_accession=19628395, orientation='minus', exon_count=5, OMIM=[605110], no_hdr0=''),
    9172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9172, CurrentID=0, Status='live', Symbol='MYOM2', Aliases=['TTNAP'], description='myomesin 2', other_designations='myomesin-2|165 kDa connectin-associated protein|165 kDa titin-associated protein|M-band protein|M-protein|myomesin (M-protein) 2, 165kDa|myomesin family member 2|titin-associated protein, 165 kD', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=2045046, end_position_on_the_genomic_accession=2145456, orientation='plus', exon_count=37, OMIM=[603509], no_hdr0=''),
    9173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9173, CurrentID=0, Status='live', Symbol='IL1RL1', Aliases=['DER4', 'FIT-1', 'IL33R', 'ST2', 'ST2L', 'ST2V', 'T1'], description='interleukin 1 receptor like 1', other_designations='interleukin-1 receptor-like 1|growth stimulation-expressed|homolog of mouse growth stimulation-expressed|interleukin 1 receptor-related protein', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102311529, end_position_on_the_genomic_accession=102352367, orientation='plus', exon_count=13, OMIM=[601203], no_hdr0=''),
    9175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9175, CurrentID=0, Status='live', Symbol='MAP3K13', Aliases=['LZK', 'MEKK13', 'MLK'], description='mitogen-activated protein kinase kinase kinase 13', other_designations='mitogen-activated protein kinase kinase kinase 13|leucine zipper-bearing kinase|mixed lineage kinase', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185282938, end_position_on_the_genomic_accession=185489094, orientation='plus', exon_count=18, OMIM=[604915], no_hdr0=''),
    9177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9177, CurrentID=0, Status='live', Symbol='HTR3B', Aliases=['5-HT3B'], description='5-hydroxytryptamine receptor 3B', other_designations='5-hydroxytryptamine receptor 3B|5-hydroxytryptamine (serotonin) receptor 3B, ionotropic|5-hydroxytryptamine 3 receptor B subunit|serotonin-gated ion channel subunit', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113898923, end_position_on_the_genomic_accession=113949119, orientation='plus', exon_count=11, OMIM=[604654], no_hdr0=''),
    9179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9179, CurrentID=0, Status='live', Symbol='AP4M1', Aliases=['CPSQ3', 'MU-4', 'MU-ARP2', 'SPG50'], description='adaptor related protein complex 4 subunit mu 1', other_designations='AP-4 complex subunit mu-1|AP-4 adaptor complex mu subunit|adapter-related protein complex 4 mu-1 subunit|adapter-related protein complex 4 subunit mu-1|adaptor related protein complex 4 mu 1 subunit|adaptor-related protein complex AP-4 mu4 subunit|mu subunit of AP-4|mu-adaptin-related protein-2|mu4|mu4-adaptin', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100101413, end_position_on_the_genomic_accession=100109039, orientation='plus', exon_count=17, OMIM=[602296], no_hdr0=''),
    9180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9180, CurrentID=0, Status='live', Symbol='OSMR', Aliases=['IL-31R-beta', 'IL-31RBB', 'OSMRbeta', 'PLCA1', 'OSMR'], description='oncostatin M receptor', other_designations='oncostatin-M-specific receptor subunit beta|IL-31 receptor subunit beta|IL-31R subunit beta|interleukin-31 receptor subunit beta|oncostatin-M specific receptor beta subunit', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=38846012, end_position_on_the_genomic_accession=38945579, orientation='plus', exon_count=21, OMIM=[601743], no_hdr0=''),
    9181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9181, CurrentID=0, Status='live', Symbol='ARHGEF2', Aliases=['GEF', 'GEF-H1', 'GEFH1', 'LFP40', 'Lfc', 'NEDMHM', 'P40'], description='Rho/Rac guanine nucleotide exchange factor 2', other_designations='rho guanine nucleotide exchange factor 2|Rho/Rac guanine nucleotide exchange factor (GEF) 2|guanine nucleotide exchange factor H1|microtubule-regulated Rho-GEF|proliferating cell nucleolar antigen p40', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155946851, end_position_on_the_genomic_accession=155991262, orientation='minus', exon_count=34, OMIM=[607560], no_hdr0=''),
    9182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9182, CurrentID=0, Status='live', Symbol='RASSF9', Aliases=['P-CIP1', 'PAMCI', 'PCIP1'], description='Ras association domain family member 9', other_designations='ras association domain-containing protein 9|PAM COOH-terminal interactor protein 1|Ras association (RalGDS/AF-6) domain family (N-terminal) member 9|peptidylglycine alpha-amidating monooxygenase COOH-terminal interactor protein-1', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85800703, end_position_on_the_genomic_accession=85836409, orientation='minus', exon_count=3, OMIM=[610383], no_hdr0=''),
    9183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9183, CurrentID=0, Status='live', Symbol='ZW10', Aliases=['HZW10', 'KNTC1AP'], description='zw10 kinetochore protein', other_designations='centromere/kinetochore protein zw10 homolog|ZW10 homolog, centromere/kinetochore protein|ZW10, kinetochore associated, homolog|zeste white 10 homolog', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113733183, end_position_on_the_genomic_accession=113773699, orientation='minus', exon_count=16, OMIM=[603954], no_hdr0=''),
    9184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9184, CurrentID=0, Status='live', Symbol='BUB3', Aliases=['BUB3L', 'hBUB3'], description='BUB3 mitotic checkpoint protein', other_designations='mitotic checkpoint protein BUB3|BUB3 budding uninhibited by benzimidazoles 3 homolog|budding uninhibited by benomyl|budding uninhibited by benzimidazoles 3 homolog|mitotic checkpoint component|testicular tissue protein Li 27', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123154402, end_position_on_the_genomic_accession=123170467, orientation='plus', exon_count=8, OMIM=[603719], no_hdr0=''),
    9185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9185, CurrentID=0, Status='live', Symbol='REPS2', Aliases=['POB1'], description='RALBP1 associated Eps domain containing 2', other_designations='ralBP1-associated Eps domain-containing protein 2|RALBP1-interacting protein 2|partner of Ral-binding protein 1|partner of RalBP1', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16946658, end_position_on_the_genomic_accession=17220724, orientation='plus', exon_count=23, OMIM=[300317], no_hdr0=''),
    9187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9187, CurrentID=0, Status='live', Symbol='SLC24A1', Aliases=['CSNB1D', 'HsT17412', 'NCKX', 'NCKX1', 'RODX'], description='solute carrier family 24 member 1', other_designations='sodium/potassium/calcium exchanger 1|Na(+)/K(+)/Ca(2+)-exchange protein 1|retinal rod Na+/Ca+/K+ exchanger|solute carrier family 24 (sodium/potassium/calcium exchanger), member 1', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65611313, end_position_on_the_genomic_accession=65661002, orientation='plus', exon_count=17, OMIM=[603617], no_hdr0=''),
    9188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9188, CurrentID=0, Status='live', Symbol='DDX21', Aliases=['GUA', 'GURDB', 'RH-II/GU', 'RH-II/GuA'], description='DExD-box helicase 21', other_designations='nucleolar RNA helicase 2|DEAD (Asp-Glu-Ala-Asp) box helicase 21|DEAD (Asp-Glu-Ala-Asp) box polypeptide 21|DEAD box protein 21|DEAD-box helicase 21|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 21|Gu protein|RH II/Gu|RNA helicase II/Gu alpha|gu-alpha|nucleolar RNA helicase Gu|nucleolar RNA helicase II', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68956131, end_position_on_the_genomic_accession=68985068, orientation='plus', exon_count=16, OMIM=[606357], no_hdr0=''),
    9189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9189, CurrentID=0, Status='live', Symbol='ZBED1', Aliases=['ALTE', 'DREF', 'TRAMP', 'hDREF'], description='zinc finger BED-type containing 1', other_designations='E3 SUMO-protein ligase ZBED1|Ac-like transposable element|BED-type zinc finger domain-containing protein 1|DNA replication-related element binding factor|dREF homolog|zinc finger BED domain-containing protein 1', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2486435, end_position_on_the_genomic_accession=2500976, orientation='minus', exon_count=3, OMIM=[300178], no_hdr0=''),
    9191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9191, CurrentID=0, Status='live', Symbol='DEDD', Aliases=['CASP8IP11', 'DEFT', 'FLDED1', 'KE05', 'DEDD'], description='death effector domain containing', other_designations='death effector domain-containing protein|DEDPro1|FLDED-1|death effector domain-containing testicular molecule', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161120974, end_position_on_the_genomic_accession=161132783, orientation='minus', exon_count=8, OMIM=[606841], no_hdr0=''),
    9194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9194, CurrentID=0, Status='live', Symbol='SLC16A7', Aliases=['MCT2'], description='solute carrier family 16 member 7', other_designations='monocarboxylate transporter 2|solute carrier family 16 (monocarboxylate transporter), member 7|solute carrier family 16, member 7 (monocarboxylic acid transporter 2)', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=59595934, end_position_on_the_genomic_accession=59789841, orientation='plus', exon_count=14, OMIM=[603654], no_hdr0=''),
    9196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9196, CurrentID=0, Status='live', Symbol='KCNAB3', Aliases=['AKR6A9', 'KCNA3.1B', 'KCNA3B', 'KV-BETA-3'], description='potassium voltage-gated channel subfamily A regulatory beta subunit 3', other_designations='voltage-gated potassium channel subunit beta-3|K(+) channel subunit beta-3|potassium channel, voltage gated subfamily A regulatory beta subunit 3|potassium channel, voltage-dependent, beta-3 subunit|potassium voltage-gated channel, shaker-related subfamily, beta member 3', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7921859, end_position_on_the_genomic_accession=7930346, orientation='minus', exon_count=14, OMIM=[604111], no_hdr0=''),
    9197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9197, CurrentID=0, Status='live', Symbol='SLC33A1', Aliases=['ACATN', 'AT-1', 'AT1', 'CCHLND', 'SPG42'], description='solute carrier family 33 member 1', other_designations='acetyl-coenzyme A transporter 1|solute carrier family 33 (acetyl-CoA transporter), member 1', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155821024, end_position_on_the_genomic_accession=155855358, orientation='minus', exon_count=5, OMIM=[603690], no_hdr0=''),
    9200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9200, CurrentID=0, Status='live', Symbol='HACD1', Aliases=['CAP', 'PTPLA'], description='3-hydroxyacyl-CoA dehydratase 1', other_designations='very-long-chain (3R)-3-hydroxyacyl-CoA dehydratase 1|cementum attachment protein|protein tyrosine phosphatase-like (proline instead of catalytic arginine), member A|very-long-chain (3R)-3-hydroxyacyl-[acyl-carrier protein] dehydratase 1', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17589032, end_position_on_the_genomic_accession=17617374, orientation='minus', exon_count=7, OMIM=[610467], no_hdr0=''),
    9201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9201, CurrentID=0, Status='live', Symbol='DCLK1', Aliases=['CL1', 'CLICK1', 'DCAMKL1', 'DCDC3A', 'DCLK'], description='doublecortin like kinase 1', other_designations='serine/threonine-protein kinase DCLK1|doublecortin domain-containing protein 3A|doublecortin-like and CAM kinase-like 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=35768652, end_position_on_the_genomic_accession=36131939, orientation='minus', exon_count=21, OMIM=[604742], no_hdr0=''),
    9202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9202, CurrentID=0, Status='live', Symbol='ZMYM4', Aliases=['CDIR', 'MYM', 'ZNF198L3', 'ZNF262'], description='zinc finger MYM-type containing 4', other_designations='zinc finger MYM-type protein 4|cell death inhibiting RNA|zinc finger protein 262|zinc finger, MYM-type 4', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35268694, end_position_on_the_genomic_accession=35422058, orientation='plus', exon_count=33, OMIM=[613568], no_hdr0=''),
    9203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9203, CurrentID=0, Status='live', Symbol='ZMYM3', Aliases=['DXS6673E', 'MYM', 'XFIM', 'ZNF198L2', 'ZNF261'], description='zinc finger MYM-type containing 3', other_designations='zinc finger MYM-type protein 3|zinc finger protein 261|zinc finger, MYM-type 3', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71239624, end_position_on_the_genomic_accession=71255197, orientation='minus', exon_count=26, OMIM=[300061], no_hdr0=''),
    9204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9204, CurrentID=0, Status='live', Symbol='ZMYM6', Aliases=['Buster2', 'MYM', 'ZBED7', 'ZNF198L4', 'ZNF258'], description='zinc finger MYM-type containing 6', other_designations='zinc finger MYM-type protein 6|transposon-derived Buster2 transposase-like protein|zinc finger protein 258|zinc finger, BED-type containing 7|zinc finger, MYM-type 6', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34986165, end_position_on_the_genomic_accession=35031945, orientation='minus', exon_count=16, OMIM=[613567], no_hdr0=''),
    9205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9205, CurrentID=0, Status='live', Symbol='ZMYM5', Aliases=['HSPC050', 'MYM', 'ZNF198L1', 'ZNF237'], description='zinc finger MYM-type containing 5', other_designations='zinc finger MYM-type protein 5|zinc finger protein 198-like 1|zinc finger protein 237|zinc finger, MYM-type 5', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19823482, end_position_on_the_genomic_accession=19863649, orientation='minus', exon_count=9, OMIM=[616443], no_hdr0=''),
    9208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9208, CurrentID=0, Status='live', Symbol='LRRFIP1', Aliases=['FLAP-1', 'FLAP1', 'FLIIAP1', 'GCF-2', 'GCF2', 'HUFI-1', 'TRIP'], description='LRR binding FLII interacting protein 1', other_designations='leucine-rich repeat flightless-interacting protein 1|GC-binding factor 2|LRR FLII-interacting protein 1|NEDD8-conjugating enzyme|TAR RNA-interacting protein|leucine rich repeat (in FLII) interacting protein 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237627576, end_position_on_the_genomic_accession=237781643, orientation='plus', exon_count=29, OMIM=[603256], no_hdr0=''),
    9209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9209, CurrentID=0, Status='live', Symbol='LRRFIP2', Aliases=['HUFI-2'], description='LRR binding FLII interacting protein 2', other_designations='leucine-rich repeat flightless-interacting protein 2|LRR FLII-interacting protein 2|leucine rich repeat (in FLII) interacting protein 2', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37052626, end_position_on_the_genomic_accession=37176817, orientation='minus', exon_count=34, OMIM=[614043], no_hdr0=''),
    9210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9210, CurrentID=0, Status='live', Symbol='BMP15', Aliases=['GDF9B', 'ODG2', 'POF4'], description='bone morphogenetic protein 15', other_designations='bone morphogenetic protein 15|growth/differentiation factor 9B', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=50910735, end_position_on_the_genomic_accession=50916641, orientation='plus', exon_count=2, OMIM=[300247], no_hdr0=''),
    9211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9211, CurrentID=0, Status='live', Symbol='LGI1', Aliases=['ADLTE', 'ADPAEF', 'ADPEAF', 'EPITEMPIN', 'EPT', 'ETL1', 'IB1099'], description='leucine rich glioma inactivated 1', other_designations='leucine-rich glioma-inactivated protein 1|epitempin-1', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93757887, end_position_on_the_genomic_accession=93798159, orientation='plus', exon_count=9, OMIM=[604619], no_hdr0=''),
    9212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9212, CurrentID=0, Status='live', Symbol='AURKB', Aliases=['AIK2', 'AIM-1', 'AIM1', 'ARK-2', 'ARK2', 'AurB', 'IPL1', 'PPP1R48', 'STK-1', 'STK12', 'STK5', 'aurkb-sv1', 'aurkb-sv2'], description='aurora kinase B', other_designations='aurora kinase B|aurora kinase B-Sv1|aurora kinase B-Sv2|aurora- and Ipl1-like midbody-associated protein 1|aurora-1|aurora-B|aurora-related kinase 2|aurora/IPL1-related kinase 2|protein phosphatase 1, regulatory subunit 48|serine/threonine kinase 12|serine/threonine-protein kinase 12|serine/threonine-protein kinase 5|serine/threonine-protein kinase aurora-B', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8204731, end_position_on_the_genomic_accession=8210767, orientation='minus', exon_count=10, OMIM=[604970], no_hdr0=''),
    9213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9213, CurrentID=0, Status='live', Symbol='XPR1', Aliases=['IBGC6', 'SLC53A1', 'SYG1', 'X3'], description='xenotropic and polytropic retrovirus receptor 1', other_designations='xenotropic and polytropic retrovirus receptor 1|X-receptor|protein SYG1 homolog|solute carrier family 53 (phosphate exporter), member 1|xenotropic and polytropic murine leukemia virus receptor X3', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180632022, end_position_on_the_genomic_accession=180890279, orientation='plus', exon_count=15, OMIM=[605237], no_hdr0=''),
    9214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9214, CurrentID=0, Status='live', Symbol='FCMR', Aliases=['FAIM3', 'TOSO'], description='Fc fragment of IgM receptor', other_designations='fas apoptotic inhibitory molecule 3|Fc mu receptor|IgM Fc fragment receptor|IgM Fc receptor|immunoglobulin mu Fc receptor|regulator of Fas-induced apoptosis Toso', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206903282, end_position_on_the_genomic_accession=206922001, orientation='minus', exon_count=8, OMIM=[606015], no_hdr0=''),
    9215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9215, CurrentID=0, Status='live', Symbol='LARGE1', Aliases=['LARGE', 'MDC1D', 'MDDGA6', 'MDDGB6'], description='LARGE xylosyl- and glucuronyltransferase 1', other_designations='LARGE xylosyl- and glucuronyltransferase 1|acetylglucosaminyltransferase-like 1A|acetylglucosaminyltransferase-like protein|glycosyltransferase-like protein LARGE1', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=33162237, end_position_on_the_genomic_accession=33922824, orientation='minus', exon_count=24, OMIM=[603590], no_hdr0=''),
    9217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9217, CurrentID=0, Status='live', Symbol='VAPB', Aliases=['ALS8', 'VAMP-B', 'VAP-B'], description='VAMP associated protein B and C', other_designations='vesicle-associated membrane protein-associated protein B/C|VAMP (vesicle-associated membrane protein)-associated protein B and C|VAMP-associated 33 kDa protein', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58389211, end_position_on_the_genomic_accession=58451101, orientation='plus', exon_count=7, OMIM=[605704], no_hdr0=''),
    9218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9218, CurrentID=0, Status='live', Symbol='VAPA', Aliases=['VAMP-A', 'VAP-33', 'VAP-A', 'VAP33', 'hVAP-33'], description='VAMP associated protein A', other_designations='vesicle-associated membrane protein-associated protein A|33 kDa VAMP-associated protein|VAMP (vesicle-associated membrane protein)-associated protein A, 33kDa|epididymis secretory sperm binding protein', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9914016, end_position_on_the_genomic_accession=9960021, orientation='plus', exon_count=9, OMIM=[605703], no_hdr0=''),
    9219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9219, CurrentID=0, Status='live', Symbol='MTA2', Aliases=['MTA1L1', 'PID'], description='metastasis associated 1 family member 2', other_designations='metastasis-associated protein MTA2|MTA1-L1 protein|metastasis -associated gene 1-like 1|metastasis associated gene family, member 2|metastasis-associated 1-like 1|metastasis-associated protein 2|p53 target protein in deacetylase complex', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62593214, end_position_on_the_genomic_accession=62601865, orientation='minus', exon_count=19, OMIM=[603947], no_hdr0=''),
    9220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9220, CurrentID=0, Status='live', Symbol='TIAF1', Aliases=['MAJN', 'SPR210'], description='TGFB1-induced anti-apoptotic factor 1', other_designations='TGFB1-induced anti-apoptotic factor 1|12 kDa TGF-beta-1-induced antiapoptotic factor|TGF-beta-1-induced antiapoptotic factor 1|molecule associated with Jak-3 N-terminal', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29073521, end_position_on_the_genomic_accession=29075609, orientation='minus', exon_count=1, OMIM=[609517], no_hdr0=''),
    9221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9221, CurrentID=0, Status='live', Symbol='NOLC1', Aliases=['NOPP130', 'NOPP140', 'NS5ATP13', 'P130', 'Srp40'], description='nucleolar and coiled-body phosphoprotein 1', other_designations='nucleolar and coiled-body phosphoprotein 1|140 kDa nucleolar phosphoprotein|HCV NS5A trans-regulated protein 13|HCV NS5A-transactivated protein 13|hepatitis C virus NS5A-transactivated protein 13|nucleolar 130 kDa protein|nucleolar and coiled-body phosphprotein 1|nucleolar phosphoprotein p130|nucleolar protein p130', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102152370, end_position_on_the_genomic_accession=102163870, orientation='plus', exon_count=13, OMIM=[602394], no_hdr0=''),
    9223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9223, CurrentID=0, Status='live', Symbol='MAGI1', Aliases=['AIP-3', 'AIP3', 'BAIAP1', 'BAP-1', 'BAP1', 'MAGI-1', 'MAGI-1b', 'Magi1d', 'TNRC19', 'WWP3'], description='membrane associated guanylate kinase, WW and PDZ domain containing 1', other_designations='membrane-associated guanylate kinase, WW and PDZ domain-containing protein 1|BAI1-associated protein 1|WW domain-containing protein 3|atrophin-1-interacting protein 3|membrane-associated guanylate kinase inverted 1|trinucleotide repeat-containing gene 19 protein', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=65353526, end_position_on_the_genomic_accession=66038918, orientation='minus', exon_count=25, OMIM=[602625], no_hdr0=''),
    9227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9227, CurrentID=0, Status='live', Symbol='LRAT', Aliases=['LCA14'], description='lecithin retinol acyltransferase', other_designations='lecithin retinol acyltransferase|lecithin retinol acyltransferase (phosphatidylcholine--retinol O-acyltransferase)', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154740838, end_position_on_the_genomic_accession=154753120, orientation='plus', exon_count=4, OMIM=[604863], no_hdr0=''),
    9228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9228, CurrentID=0, Status='live', Symbol='DLGAP2', Aliases=['C8orf68', 'DAP2', 'ERICH1-AS1', 'SAPAP2'], description='DLG associated protein 2', other_designations='disks large-associated protein 2|ERICH1 antisense RNA 1 (non-protein coding)|ERICH1 antisense gene protein 1|PSD-95/SAP90-binding protein 2|SAP90/PSD-95-associated protein 2|discs large homolog associated protein 2|discs large-associated protein 2|putative DAP-2 like protein', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=737628, end_position_on_the_genomic_accession=1708476, orientation='plus', exon_count=17, OMIM=[605438], no_hdr0=''),
    9229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9229, CurrentID=0, Status='live', Symbol='DLGAP1', Aliases=['DAP-1', 'DAP-1-ALPHA', 'DAP-1-BETA', 'DAP1A', 'DLGAP1B', 'GKAP', 'SAPAP1', 'DLGAP1'], description='DLG associated protein 1', other_designations='disks large-associated protein 1|PSD-95/SAP90 binding protein 1|SAP90/PSD-95-associated protein 1|discs large homolog associated protein 1|guanylate kinase-associated protein', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=3496032, end_position_on_the_genomic_accession=4455441, orientation='minus', exon_count=21, OMIM=[605445], no_hdr0=''),
    9230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9230, CurrentID=0, Status='live', Symbol='RAB11B', Aliases=['H-YPT3', 'NDAGSCW'], description='RAB11B, member RAS oncogene family', other_designations='ras-related protein Rab-11B|GTP-binding protein YPT3|RAB11B, member of RAS oncogene family', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8390360, end_position_on_the_genomic_accession=8404434, orientation='plus', exon_count=5, OMIM=[604198], no_hdr0=''),
    9231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9231, CurrentID=0, Status='live', Symbol='DLG5', Aliases=['LP-DLG', 'P-DLG5', 'PDLG'], description='discs large MAGUK scaffold protein 5', other_designations='disks large homolog 5|discs large protein LP-DLG|discs large protein P-dlg|discs, large homolog 5|large type of P-DLG|placenta and prostate DLG', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=77790787, end_position_on_the_genomic_accession=77926755, orientation='minus', exon_count=43, OMIM=[604090], no_hdr0=''),
    9232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9232, CurrentID=0, Status='live', Symbol='PTTG1', Aliases=['EAP1', 'HPTTG', 'PTTG', 'TUTR1'], description='PTTG1 regulator of sister chromatid separation, securin', other_designations='securin|ESP1-associated protein 1|pituitary tumor-transforming 1|pituitary tumor-transforming gene 1 protein|tumor-transforming protein 1', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160421855, end_position_on_the_genomic_accession=160428744, orientation='plus', exon_count=6, OMIM=[604147], no_hdr0=''),
    9235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9235, CurrentID=0, Status='live', Symbol='IL32', Aliases=['IL-32alpha', 'IL-32beta', 'IL-32delta', 'IL-32gamma', 'NK4', 'TAIF', 'TAIFa', 'TAIFb', 'TAIFc', 'TAIFd'], description='interleukin 32', other_designations='interleukin-32|interleukin-32 eta|interleukin-32 small|interleukin-32 theta|natural killer cell transcript 4|natural killer cells protein 4|tumor necrosis factor alpha-inducing factor', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3065403, end_position_on_the_genomic_accession=3069530, orientation='plus', exon_count=6, OMIM=[606001], no_hdr0=''),
    9236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9236, CurrentID=0, Status='live', Symbol='CCPG1', Aliases=['CPR8'], description='cell cycle progression 1', other_designations='cell cycle progression protein 1|cell cycle progression restoration protein 8', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55355239, end_position_on_the_genomic_accession=55408359, orientation='minus', exon_count=9, OMIM=[611326], no_hdr0=''),
    9238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9238, CurrentID=0, Status='live', Symbol='TBRG4', Aliases=['CPR2', 'FASTKD4'], description='transforming growth factor beta regulator 4', other_designations='FAST kinase domain-containing protein 4|FAST kinase domains 4|H_TD2522F11.8|cell cycle progression protein 2|cell cycle progression restoration protein 2|protein TBRG4', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45100100, end_position_on_the_genomic_accession=45111697, orientation='minus', exon_count=11, OMIM=[611325], no_hdr0=''),
    9240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9240, CurrentID=0, Status='live', Symbol='PNMA1', Aliases=['MA1'], description='PNMA family member 1', other_designations='paraneoplastic antigen Ma1|37 kDa neuronal protein|neuron- and testis-specific protein 1|paraneoplastic Ma antigen 1|paraneoplastic neuronal antigen MA1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73711783, end_position_on_the_genomic_accession=73714384, orientation='minus', exon_count=1, OMIM=[604010], no_hdr0=''),
    9241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9241, CurrentID=0, Status='live', Symbol='NOG', Aliases=['SYM1', 'SYNS1', 'SYNS1A'], description='noggin', other_designations='noggin|symphalangism 1 (proximal)', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56593699, end_position_on_the_genomic_accession=56595611, orientation='plus', exon_count=1, OMIM=[602991], no_hdr0=''),
    9242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9242, CurrentID=0, Status='live', Symbol='MSC', Aliases=['ABF-1', 'ABF1', 'MYOR', 'bHLHa22'], description='musculin', other_designations='musculin|activated B-cell factor 1, homolog of mouse musculin|activated B-cell factor-1|class A basic helix-loop-helix protein 22', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=71841560, end_position_on_the_genomic_accession=71844412, orientation='minus', exon_count=2, OMIM=[603628], no_hdr0=''),
    9244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9244, CurrentID=0, Status='live', Symbol='CRLF1', Aliases=['CISS', 'CISS1', 'CLF', 'CLF-1', 'NR6', 'zcytor5'], description='cytokine receptor like factor 1', other_designations='cytokine receptor-like factor 1|class I cytokine receptor|cytokine type 1 receptor CRLP-1|cytokine-like factor 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18593237, end_position_on_the_genomic_accession=18606799, orientation='minus', exon_count=9, OMIM=[604237], no_hdr0=''),
    9245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9245, CurrentID=0, Status='live', Symbol='GCNT3', Aliases=['C2/4GnT', 'C24GNT', 'C2GNT2', 'C2GNTM', 'GNTM'], description='glucosaminyl (N-acetyl) transferase 3, mucin type', other_designations='beta-1,3-galactosyl-O-glycosyl-glycoprotein beta-1,6-N-acetylglucosaminyltransferase 3|C2GnT-mucin type|beta1,6-N-acetylglucosaminyltransferase-M|beta1,6GlcNAc-transferase|core 2/core 4 beta-1,6-N-acetylglucosaminyltransferase|hC2GnT-M|mucus-type core 2 beta-1,6-N-acetylglucosaminyltransferase', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59611783, end_position_on_the_genomic_accession=59622723, orientation='plus', exon_count=3, OMIM=[606836], no_hdr0=''),
    9246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9246, CurrentID=0, Status='live', Symbol='UBE2L6', Aliases=['RIG-B', 'UBCH8'], description='ubiquitin conjugating enzyme E2 L6', other_designations='ubiquitin/ISG15-conjugating enzyme E2 L6|E2 ubiquitin-conjugating enzyme L6|retinoic acid induced gene B protein|ubiquitin carrier protein L6|ubiquitin conjugating enzyme E2L 6|ubiquitin-protein ligase L6', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57551662, end_position_on_the_genomic_accession=57567935, orientation='minus', exon_count=5, OMIM=[603890], no_hdr0=''),
    9247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9247, CurrentID=0, Status='live', Symbol='GCM2', Aliases=['FIH2', 'GCMB', 'HRPT4', 'hGCMb'], description='glial cells missing transcription factor 2', other_designations='chorion-specific transcription factor GCMb|GCM motif protein 2|glial cells missing 2|glial cells missing homolog 2|glial cells missing homolog b|glide/gcm protein homolog', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10873223, end_position_on_the_genomic_accession=10882041, orientation='minus', exon_count=5, OMIM=[603716], no_hdr0=''),
    9248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9248, CurrentID=0, Status='live', Symbol='GPR50', Aliases=['H9', 'Mel1c'], description='G protein-coupled receptor 50', other_designations='melatonin-related receptor', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151176584, end_position_on_the_genomic_accession=151182855, orientation='plus', exon_count=2, OMIM=[300207], no_hdr0=''),
    9249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9249, CurrentID=0, Status='live', Symbol='DHRS3', Aliases=['DD83.1', 'RDH17', 'Rsdr1', 'SDR1', 'SDR16C1', 'retSDR1'], description='dehydrogenase/reductase 3', other_designations='short-chain dehydrogenase/reductase 3|dehydrogenase/reductase (SDR family) member 3|dehydrogenase/reductase member 3|retinal short-chain dehydrogenase/reductase 1|retinol dehydrogenase 17|short chain dehydrogenase/reductase family 16C member 1|short-chain dehydrogenase/reductase 1', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12567910, end_position_on_the_genomic_accession=12618210, orientation='minus', exon_count=9, OMIM=[612830], no_hdr0=''),
    9252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9252, CurrentID=0, Status='live', Symbol='RPS6KA5', Aliases=['MSK1', 'MSPK1', 'RLPK'], description='ribosomal protein S6 kinase A5', other_designations='ribosomal protein S6 kinase alpha-5|90 kDa ribosomal protein S6 kinase 5|RSK-like protein kinase|RSKL|S6K-alpha-5|nuclear mitogen- and stress-activated protein kinase 1|ribosomal protein S6 kinase, 90kDa, polypeptide 5', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90847861, end_position_on_the_genomic_accession=91060641, orientation='minus', exon_count=21, OMIM=[603607], no_hdr0=''),
    9253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9253, CurrentID=0, Status='live', Symbol='NUMBL', Aliases=['CAG3A', 'CTG3a', 'NBL', 'NUMB-RIKE', 'NUMBR', 'TNRC23', 'NUMBL'], description='NUMB like endocytic adaptor protein', other_designations='numb-like protein|numb homolog-like|numb-related protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40665905, end_position_on_the_genomic_accession=40690651, orientation='minus', exon_count=11, OMIM=[604018], no_hdr0=''),
    9254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9254, CurrentID=0, Status='live', Symbol='CACNA2D2', Aliases=['CACNA2D', 'CASVDD'], description='calcium voltage-gated channel auxiliary subunit alpha2delta 2', other_designations='voltage-dependent calcium channel subunit alpha-2/delta-2|alpha 2 delta calcium channel subunit|calcium channel, voltage-dependent, alpha 2/delta subunit 2|gene 26|voltage-gated calcium channel subunit alpha-2/delta-2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50362613, end_position_on_the_genomic_accession=50504244, orientation='minus', exon_count=40, OMIM=[607082], no_hdr0=''),
    9255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9255, CurrentID=0, Status='live', Symbol='AIMP1', Aliases=['EMAP2', 'EMAPII', 'HLD3', 'SCYE1', 'p43'], description='aminoacyl tRNA synthetase complex interacting multifunctional protein 1', other_designations='aminoacyl tRNA synthase complex-interacting multifunctional protein 1|ARS-interacting multifunctional protein 1|endothelial monocyte-activating polypeptide 2|endothelial-monocyte activating polypeptide II|multisynthase complex auxiliary component p43|multisynthetase complex auxiliary component p43|small inducible cytokine subfamily E, member 1 (endothelial monocyte-activating)', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=106315544, end_position_on_the_genomic_accession=106349456, orientation='plus', exon_count=10, OMIM=[603605], no_hdr0=''),
    9256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9256, CurrentID=0, Status='live', Symbol='TSPOAP1', Aliases=['BZRAP1', 'PBR-IP', 'PRAX-1', 'PRAX1', 'RIM-BP1', 'RIMBP1'], description='TSPO associated protein 1', other_designations='peripheral-type benzodiazepine receptor-associated protein 1|RIMS-binding protein 1|benzodiazapine receptor peripheral-associated protein 1|benzodiazepine receptor (peripheral) associated protein 1|peripheral benzodiazepine receptor-interacting protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58301231, end_position_on_the_genomic_accession=58328795, orientation='minus', exon_count=32, OMIM=[610764], no_hdr0=''),
    9258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9258, CurrentID=0, Status='live', Symbol='MFHAS1', Aliases=['LRRC65', 'MASL1', 'ROCO4'], description='multifunctional ROCO family signaling regulator 1', other_designations='malignant fibrous histiocytoma-amplified sequence 1|MFH-amplified sequences with leucine-rich tandem repeats 1|leucine rich repeat containing 65|malignant fibrous histiocytoma amplified sequence 1|malignant fibrous histiocytoma-amplified sequence with leucine-rich tandem repeats 1|malignant fibrous histiocytoma-amplified sequences with leucine-rich tandem repeats 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=8783354, end_position_on_the_genomic_accession=8893630, orientation='minus', exon_count=5, OMIM=[605352], no_hdr0=''),
    9260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9260, CurrentID=0, Status='live', Symbol='PDLIM7', Aliases=['LMP1', 'LMP3'], description='PDZ and LIM domain 7', other_designations='PDZ and LIM domain protein 7|1110003B01Rik|LIM domain protein|LMP|Lim mineralization protein 3|PDZ and LIM domain 7 (enigma)|protein enigma', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177483394, end_position_on_the_genomic_accession=177497604, orientation='minus', exon_count=15, OMIM=[605903], no_hdr0=''),
    9261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9261, CurrentID=0, Status='live', Symbol='MAPKAPK2', Aliases=['MAPKAP-K2', 'MK-2', 'MK2'], description='MAPK activated protein kinase 2', other_designations='MAP kinase-activated protein kinase 2|MAPKAP kinase 2|mitogen-activated protein kinase-activated protein kinase 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206684905, end_position_on_the_genomic_accession=206734283, orientation='plus', exon_count=11, OMIM=[602006], no_hdr0=''),
    9262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9262, CurrentID=0, Status='live', Symbol='STK17B', Aliases=['DRAK2'], description='serine/threonine kinase 17b', other_designations='serine/threonine-protein kinase 17B|DAP kinase-related apoptosis-inducing protein kinase 2|death-associated protein kinase-related 2', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196133583, end_position_on_the_genomic_accession=196176503, orientation='minus', exon_count=12, OMIM=[604727], no_hdr0=''),
    9263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9263, CurrentID=0, Status='live', Symbol='STK17A', Aliases=['DRAK1'], description='serine/threonine kinase 17a', other_designations='serine/threonine-protein kinase 17A|DAP kinase-related apoptosis-inducing protein kinase 1|death-associated protein kinase-related 1|serine/threonine kinase 17a (apoptosis-inducing)', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43583108, end_position_on_the_genomic_accession=43627379, orientation='plus', exon_count=8, OMIM=[604726], no_hdr0=''),
    9265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9265, CurrentID=0, Status='live', Symbol='CYTH3', Aliases=['ARNO3', 'GRP1', 'PSCD3', 'cytohesin-3'], description='cytohesin 3', other_designations='cytohesin-3|ARF nucleotide-binding site opener 3|PH, SEC7 and coiled-coil domain-containing protein 3|general receptor of phosphoinositides 1|pleckstrin homology, Sec7 and coiled-coil domains 3', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6161779, end_position_on_the_genomic_accession=6272624, orientation='minus', exon_count=15, OMIM=[605081], no_hdr0=''),
    9266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9266, CurrentID=0, Status='live', Symbol='CYTH2', Aliases=['ARNO', 'CTS18', 'CTS18.1', 'PSCD2', 'PSCD2L', 'SEC7L', 'Sec7p-L', 'Sec7p-like', 'cytohesin-2'], description='cytohesin 2', other_designations='cytohesin-2|ARF exchange factor|ARF nucleotide-binding site opener|CTC-273B12.8|PH, SEC7 and coiled-coil domain-containing protein 2|pleckstrin homology, Sec7 and coiled-coil domains 2|pleckstrin homology, Sec7 and coiled/coil domains 2 (cytohesin-2)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48469341, end_position_on_the_genomic_accession=48482314, orientation='plus', exon_count=13, OMIM=[602488], no_hdr0=''),
    9267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9267, CurrentID=0, Status='live', Symbol='CYTH1', Aliases=['B2-1', 'CYTOHESIN-1', 'D17S811E', 'PSCD1', 'SEC7'], description='cytohesin 1', other_designations='cytohesin-1|PH, SEC7 and coiled-coil domain-containing protein 1|SEC7 homolog B2-1|cytoadhesin 1|homolog of secretory protein SEC7|pleckstrin homology, Sec7 and coiled-coil domains 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78674048, end_position_on_the_genomic_accession=78782273, orientation='minus', exon_count=19, OMIM=[182115], no_hdr0=''),
    9270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9270, CurrentID=0, Status='live', Symbol='ITGB1BP1', Aliases=['ICAP-1A', 'ICAP-1B', 'ICAP-1alpha', 'ICAP1', 'ICAP1A', 'ICAP1B'], description='integrin subunit beta 1 binding protein 1', other_designations='integrin beta-1-binding protein 1|bodenin|integrin cytoplasmic domain-associated protein 1|integrin cytoplasmic domain-associated protein 1-alpha|integrin cytoplasmic domain-associated protein 1-beta', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9403475, end_position_on_the_genomic_accession=9423569, orientation='minus', exon_count=9, OMIM=[607153], no_hdr0=''),
    9271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9271, CurrentID=0, Status='live', Symbol='PIWIL1', Aliases=['CT80.1', 'HIWI', 'MIWI', 'PIWI'], description='piwi like RNA-mediated gene silencing 1', other_designations='piwi-like protein 1|piwi homolog', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130337887, end_position_on_the_genomic_accession=130412708, orientation='plus', exon_count=25, OMIM=[605571], no_hdr0=''),
    9274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9274, CurrentID=0, Status='live', Symbol='BCL7C', Aliases=[], description='BAF chromatin remodeling complex subunit BCL7C', other_designations='B-cell CLL/lymphoma 7 protein family member C|B-cell CLL/lymphoma 7C|BCL tumor suppressor 7C|BCL7C, BAF complex component', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30833626, end_position_on_the_genomic_accession=30894716, orientation='minus', exon_count=9, OMIM=[605847], no_hdr0=''),
    9275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9275, CurrentID=0, Status='live', Symbol='BCL7B', Aliases=[], description='BAF chromatin remodeling complex subunit BCL7B', other_designations='B-cell CLL/lymphoma 7 protein family member B|B-cell CLL/lymphoma 7B|BCL tumor suppressor 7B|BCL7B, BAF complex component', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73536356, end_position_on_the_genomic_accession=73557690, orientation='minus', exon_count=8, OMIM=[605846], no_hdr0=''),
    9276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9276, CurrentID=0, Status='live', Symbol='COPB2', Aliases=['MCPH19', "beta'-COP"], description='COPI coat complex subunit beta 2', other_designations="coatomer subunit beta'|beta'-coat protein|betaprime-COP|coatomer binding complex, beta prime subunit|coatomer protein complex subunit beta 2|coatomer protein complex subunit beta prime|coatomer protein complex, subunit beta 2 (beta prime)|p102", map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139355595, end_position_on_the_genomic_accession=139389680, orientation='minus', exon_count=22, OMIM=[606990], no_hdr0=''),
    9277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9277, CurrentID=0, Status='live', Symbol='WDR46', Aliases=['BING4', 'C6orf11', 'FP221', 'UTP7'], description='WD repeat domain 46', other_designations='WD repeat-containing protein 46|WD repeat-containing protein BING4', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33278207, end_position_on_the_genomic_accession=33289239, orientation='minus', exon_count=15, OMIM=[611440], no_hdr0=''),
    9278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9278, CurrentID=0, Status='live', Symbol='ZBTB22', Aliases=['BING1A', 'ZNF297', 'ZNF297A', 'fru', 'fruitless', 'ZBTB22'], description='zinc finger and BTB domain containing 22', other_designations='zinc finger and BTB domain-containing protein 22|zinc finger and BTB domain-containing protein 22A|zinc finger protein 297', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33314418, end_position_on_the_genomic_accession=33317942, orientation='minus', exon_count=3, OMIM=[611439], no_hdr0=''),
    9282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9282, CurrentID=0, Status='live', Symbol='MED14', Aliases=['CRSP150', 'CRSP2', 'CSRP', 'CXorf4', 'DRIP150', 'EXLM1', 'RGR1', 'TRAP170'], description='mediator complex subunit 14', other_designations='mediator of RNA polymerase II transcription subunit 14|ARC150|CRSP complex subunit 2|RGR1 homolog|activator-recruited cofactor 150 kDa component|cofactor required for Sp1 transcriptional activation, subunit 2 (150kD)|hRGR1|human homolog of yeast RGR1|thyroid hormone receptor-associated protein complex 170 kDa component|thyroid hormone receptor-associated protein complex component TRAP170|transcriptional co-activator CRSP150|vitamin D receptor-interacting protein complex component DRIP150|vitamin D3 receptor-interacting protein complex 150 kDa component', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=40648305, end_position_on_the_genomic_accession=40736122, orientation='minus', exon_count=34, OMIM=[300182], no_hdr0=''),
    9283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9283, CurrentID=0, Status='live', Symbol='GPR37L1', Aliases=['ET(B)R-LP-2', 'ETBR-LP-2', 'ETBRLP2'], description='G protein-coupled receptor 37 like 1', other_designations='G-protein coupled receptor 37-like 1|endothelin B receptor-like protein 2|endothelin type b receptor-like protein 2|prosaposin receptor GPR37L1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202118669, end_position_on_the_genomic_accession=202133592, orientation='plus', exon_count=3, OMIM=[617630], no_hdr0=''),
    9284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9284, CurrentID=0, Status='live', Symbol='NPIPA1', Aliases=['NPIP', 'NPIPA', 'morpheus'], description='nuclear pore complex interacting protein family member A1', other_designations='nuclear pore complex-interacting protein family member A1|nuclear pore complex-interacting protein A type', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14937443, end_position_on_the_genomic_accession=14952056, orientation='plus', exon_count=8, OMIM=[606406], no_hdr0=''),
    9287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9287, CurrentID=0, Status='live', Symbol='TAAR2', Aliases=['GPR58', 'taR-2'], description='trace amine associated receptor 2', other_designations='trace amine-associated receptor 2|G protein-coupled receptor 58', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132617150, end_position_on_the_genomic_accession=132624275, orientation='minus', exon_count=2, OMIM=[604849], no_hdr0=''),
    9289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9289, CurrentID=0, Status='live', Symbol='ADGRG1', Aliases=['BFPP', 'BPPR', 'GPR56', 'TM7LN4', 'TM7XN1'], description='adhesion G protein-coupled receptor G1', other_designations='adhesion G-protein coupled receptor G1|7-transmembrane protein with no EGF-like N-terminal domains-1|G protein-coupled receptor 56|testicular tissue protein Li 77', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57619535, end_position_on_the_genomic_accession=57665567, orientation='plus', exon_count=23, OMIM=[604110], no_hdr0=''),
    9290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9290, CurrentID=0, Status='live', Symbol='GPR55', Aliases=['LPIR1'], description='G protein-coupled receptor 55', other_designations='G-protein coupled receptor 55', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230907318, end_position_on_the_genomic_accession=230961270, orientation='minus', exon_count=4, OMIM=[604107], no_hdr0=''),
    9293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9293, CurrentID=0, Status='live', Symbol='GPR52', Aliases=[], description='G protein-coupled receptor 52', other_designations='G-protein coupled receptor 52|probable G-protein coupled receptor 52', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=174447964, end_position_on_the_genomic_accession=174449545, orientation='plus', exon_count=1, OMIM=[604106], no_hdr0=''),
    9294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9294, CurrentID=0, Status='live', Symbol='S1PR2', Aliases=['AGR16', 'DFNB68', 'EDG-5', 'EDG5', 'Gpcr13', 'H218', 'LPB2', 'S1P2'], description='sphingosine-1-phosphate receptor 2', other_designations='sphingosine 1-phosphate receptor 2|CTD-2369P2.2|S1P receptor 2|S1P receptor EDG5|S1P receptor Edg-5|deafness, autosomal recessive 68|endothelial differentiation G-protein coupled receptor 5|endothelial differentiation, sphingolipid G-protein-coupled receptor, 5|sphingosine 1-phosphate receptor Edg-5', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10221433, end_position_on_the_genomic_accession=10231331, orientation='minus', exon_count=2, OMIM=[605111], no_hdr0=''),
    9295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9295, CurrentID=0, Status='live', Symbol='SRSF11', Aliases=['NET2', 'SFRS11', 'dJ677H15.2', 'p54'], description='serine and arginine rich splicing factor 11', other_designations='serine/arginine-rich splicing factor 11|SR splicing factor 11|arginine-rich 54 kDa nuclear protein|splicing factor p54|splicing factor, arginine/serine-rich 11', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=70205696, end_position_on_the_genomic_accession=70253052, orientation='plus', exon_count=17, OMIM=[602010], no_hdr0=''),
    9296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9296, CurrentID=0, Status='live', Symbol='ATP6V1F', Aliases=['ATP6S14', 'VATF', 'Vma7'], description='ATPase H+ transporting V1 subunit F', other_designations='V-type proton ATPase subunit F|ATPase, H+ transporting, lysosomal 14kDa, V1 subunit F|ATPase, vacuolar, 14 kD|H(+)-transporting two-sector ATPase, 14kD subunit|V-ATPase 14 kDa subunit|V-ATPase F subunit|V-ATPase subunit F|adenosinetriphosphatase 14k chain|vacuolar ATP synthase subunit F|vacuolar proton pump F subunit|vacuolar proton pump subunit F', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128862856, end_position_on_the_genomic_accession=128865847, orientation='plus', exon_count=3, OMIM=[607160], no_hdr0=''),
    9306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9306, CurrentID=0, Status='live', Symbol='SOCS6', Aliases=['CIS-4', 'CIS4', 'HSPC060', 'SOCS-4', 'SOCS-6', 'SOCS4', 'SSI4', 'STAI4', 'STATI4'], description='suppressor of cytokine signaling 6', other_designations='suppressor of cytokine signaling 6|STAT induced STAT inhibitor-4|cytokine-inducible SH2 protein 4|suppressor of cytokine signaling 4', map_location='18q22.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=70289045, end_position_on_the_genomic_accession=70330199, orientation='plus', exon_count=5, OMIM=[605118], no_hdr0=''),
    9308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9308, CurrentID=0, Status='live', Symbol='CD83', Aliases=['BL11', 'HB15'], description='CD83 molecule', other_designations='CD83 antigen|B-cell activation protein|CD83 antigen (activated B lymphocytes, immunoglobulin superfamily)|cell surface protein HB15|cell-surface glycoprotein|hCD83', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=14117256, end_position_on_the_genomic_accession=14136918, orientation='plus', exon_count=6, OMIM=[604534], no_hdr0=''),
    9310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9310, CurrentID=0, Status='live', Symbol='ZNF235', Aliases=['ANF270', 'HZF6', 'ZFP93', 'ZNF270'], description='zinc finger protein 235', other_designations='zinc finger protein 235|zfp-93|zinc finger protein 270|zinc finger protein 6|zinc finger protein 93 homolog|zinc finger protein HZF6|zinc finger protein homologous to Zfp93 in mouse|zinc finger protein homologous to mouse Zfp93', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44286348, end_position_on_the_genomic_accession=44305707, orientation='minus', exon_count=5, OMIM=[604749], no_hdr0=''),
    9311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9311, CurrentID=0, Status='live', Symbol='ASIC3', Aliases=['ACCN3', 'DRASIC', 'SLNAC1', 'TNaC1'], description='acid sensing ion channel subunit 3', other_designations='acid-sensing ion channel 3|acid sensing (proton gated) ion channel 3|amiloride-sensitive cation channel 3, testis|modulatory subunit of ASIC2a|neuronal amiloride-sensitive cation channel 3|proton-gated cation channel subunit|testis sodium channel 1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151048292, end_position_on_the_genomic_accession=151052756, orientation='plus', exon_count=11, OMIM=[611741], no_hdr0=''),
    9312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9312, CurrentID=0, Status='live', Symbol='KCNB2', Aliases=['KV2.2'], description='potassium voltage-gated channel subfamily B member 2', other_designations='potassium voltage-gated channel subfamily B member 2|delayed rectifier potassium channel protein|potassium channel Kv2.2|potassium channel, voltage gated Shab related subfamily B, member 2|potassium voltage-gated channel, Shab-related subfamily, member 2|voltage-gated potassium channel subunit Kv2.2', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=72537225, end_position_on_the_genomic_accession=72945890, orientation='plus', exon_count=6, OMIM=[607738], no_hdr0=''),
    9313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9313, CurrentID=0, Status='live', Symbol='MMP20', Aliases=['AI2A2', 'MMP-20'], description='matrix metallopeptidase 20', other_designations='matrix metalloproteinase-20|enamel metalloproteinase|matrix metalloproteinase 20 (enamelysin)', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102576832, end_position_on_the_genomic_accession=102625332, orientation='minus', exon_count=10, OMIM=[604629], no_hdr0=''),
    9314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9314, CurrentID=0, Status='live', Symbol='KLF4', Aliases=['EZF', 'GKLF'], description='Kruppel like factor 4', other_designations='Krueppel-like factor 4|Kruppel-like factor 4 (gut)|endothelial Kruppel-like zinc finger protein|epithelial zinc finger protein EZF|gut Kruppel-like factor|gut-enriched krueppel-like factor', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=107484852, end_position_on_the_genomic_accession=107489769, orientation='minus', exon_count=4, OMIM=[602253], no_hdr0=''),
    9315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9315, CurrentID=0, Status='live', Symbol='NREP', Aliases=['C5orf13', 'D4S114', 'P311', 'PRO1873', 'PTZ17', 'SEZ17'], description='neuronal regeneration related protein', other_designations='neuronal regeneration-related protein|neuronal protein 3.1|neuronal regeneration related protein homolog|protein p311', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=111728802, end_position_on_the_genomic_accession=111976932, orientation='minus', exon_count=9, OMIM=[607332], no_hdr0=''),
    9317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9317, CurrentID=0, Status='live', Symbol='PTER', Aliases=['HPHRP', 'RPR-1'], description='phosphotriesterase related', other_designations='phosphotriesterase-related protein|parathion hydrolase-related protein|resiniferatoxin-binding, phosphotriesterase-related', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=16436943, end_position_on_the_genomic_accession=16517962, orientation='plus', exon_count=10, OMIM=[604446], no_hdr0=''),
    9318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9318, CurrentID=0, Status='live', Symbol='COPS2', Aliases=['ALIEN', 'CSN2', 'SGN2', 'TRIP15'], description='COP9 signalosome subunit 2', other_designations='COP9 signalosome complex subunit 2|COP9 constitutive photomorphogenic homolog subunit 2|JAB1-containing signalosome subunit 2|TR-interacting protein 15|TRIP-15|alien homolog|signalosome subunit 2|thyroid receptor-interacting protein 15', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49122727, end_position_on_the_genomic_accession=49155599, orientation='minus', exon_count=13, OMIM=[604508], no_hdr0=''),
    9319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9319, CurrentID=0, Status='live', Symbol='TRIP13', Aliases=['16E1BP', 'MVA3', 'OOMD9'], description='thyroid hormone receptor interactor 13', other_designations='pachytene checkpoint protein 2 homolog|16E1-BP|HPV16 E1 protein binding protein|SH3TC1/TRIP13 fusion|TR-interacting protein 13|TRIP-13|human papillomavirus type 16 E1 protein-binding protein|thyroid receptor-interacting protein 13', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=892884, end_position_on_the_genomic_accession=919348, orientation='plus', exon_count=14, OMIM=[604507], no_hdr0=''),
    9320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9320, CurrentID=0, Status='live', Symbol='TRIP12', Aliases=['MRD49', 'TRIP-12', 'TRIPC', 'ULF'], description='thyroid hormone receptor interactor 12', other_designations='E3 ubiquitin-protein ligase TRIP12|E3 ubiquitin-protein ligase for Arf|HECT-type E3 ubiquitin transferase TRIP12|TR-interacting protein 12|probable E3 ubiquitin-protein ligase TRIP12|thyroid receptor interacting protein 12', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=229763837, end_position_on_the_genomic_accession=229923234, orientation='minus', exon_count=50, OMIM=[604506], no_hdr0=''),
    9321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9321, CurrentID=0, Status='live', Symbol='TRIP11', Aliases=['ACG1A', 'CEV14', 'GMAP-210', 'GMAP210', 'ODCD', 'ODCD1', 'TRIP-11', 'TRIP230'], description='thyroid hormone receptor interactor 11', other_designations='thyroid receptor-interacting protein 11|Golgi-microtubule-associated protein of 210 kDa|TR-interacting protein 11|clonal evolution-related gene on chromosome 14 protein|golgi-associated microtubule-binding protein 210', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91965991, end_position_on_the_genomic_accession=92040134, orientation='minus', exon_count=23, OMIM=[604505], no_hdr0=''),
    9322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9322, CurrentID=0, Status='live', Symbol='TRIP10', Aliases=['CIP4', 'HSTP', 'STOT', 'STP', 'TRIP-10'], description='thyroid hormone receptor interactor 10', other_designations='cdc42-interacting protein 4|TR-interacting protein 10|protein Felic|salt tolerant protein|salt tolerator|thyroid receptor-interacting protein 10', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6739680, end_position_on_the_genomic_accession=6751530, orientation='plus', exon_count=16, OMIM=[604504], no_hdr0=''),
    9324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9324, CurrentID=0, Status='live', Symbol='HMGN3', Aliases=['PNAS-24', 'PNAS-25', 'TRIP7'], description='high mobility group nucleosomal binding domain 3', other_designations='high mobility group nucleosome-binding domain-containing protein 3|TR-interacting protein 7|thyroid hormone receptor interacting protein 7', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=79201245, end_position_on_the_genomic_accession=79234682, orientation='minus', exon_count=7, OMIM=[604502], no_hdr0=''),
    9325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9325, CurrentID=0, Status='live', Symbol='TRIP4', Aliases=['ASC-1', 'ASC1', 'HsT17391', 'MDCDC', 'SMABF1', 'ZC2HC5'], description='thyroid hormone receptor interactor 4', other_designations='activating signal cointegrator 1|TR-interacting protein 4|TRIP-4|thyroid receptor-interacting protein 4|zinc finger, C2HC5-type', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64387836, end_position_on_the_genomic_accession=64455303, orientation='plus', exon_count=13, OMIM=[604501], no_hdr0=''),
    9326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9326, CurrentID=0, Status='live', Symbol='ZNHIT3', Aliases=['Hit1', 'PEHO', 'TRIP3'], description='zinc finger HIT-type containing 3', other_designations='zinc finger HIT domain-containing protein 3|HNF-4a coactivator|TR-interacting protein 3|TRIP-3|thyroid hormone receptor interactor 3|thyroid receptor interacting protein 3|zinc finger, HIT domain containing 3|zinc finger, HIT type 3', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36486681, end_position_on_the_genomic_accession=36499312, orientation='plus', exon_count=6, OMIM=[604500], no_hdr0=''),
    9328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9328, CurrentID=0, Status='live', Symbol='GTF3C5', Aliases=['TFIIIC63', 'TFIIICepsilon', 'TFiiiC2-63'], description='general transcription factor IIIC subunit 5', other_designations='general transcription factor 3C polypeptide 5|TF3C-epsilon|TFIIIC 63 kDa subunit|general transcription factor IIIC, polypeptide 5, 63kDa|transcription factor IIIC 63 kDa subunit|transcription factor IIIC subunit epsilon|transcription factor IIIC, 63 kD', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133030689, end_position_on_the_genomic_accession=133058503, orientation='plus', exon_count=11, OMIM=[604890], no_hdr0=''),
    9329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9329, CurrentID=0, Status='live', Symbol='GTF3C4', Aliases=['KAT12', 'TF3C-delta', 'TFIII90', 'TFIIIC290', 'TFIIIC90', 'TFIIICDELTA'], description='general transcription factor IIIC subunit 4', other_designations='general transcription factor 3C polypeptide 4|TFIIIC 90 kDa subunit|general transcription factor 3C 4|general transcription factor IIIC, polypeptide 4, 90kDa|transcription factor IIIC 90 kDa subunit|transcription factor IIIC subunit delta', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132670035, end_position_on_the_genomic_accession=132694955, orientation='plus', exon_count=6, OMIM=[604892], no_hdr0=''),
    9330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9330, CurrentID=0, Status='live', Symbol='GTF3C3', Aliases=['TFIIIC102', 'TFIIICgamma', 'TFiiiC2-102'], description='general transcription factor IIIC subunit 3', other_designations='general transcription factor 3C polypeptide 3|TF3C-gamma|TFIIIC 102 kDa subunit|general transcription factor IIIC, polypeptide 3, 102kDa|transcription factor IIIC subunit gamma', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196763035, end_position_on_the_genomic_accession=196799683, orientation='minus', exon_count=18, OMIM=[604888], no_hdr0=''),
    9331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9331, CurrentID=0, Status='live', Symbol='B4GALT6', Aliases=['B4Gal-T6', 'beta4Gal-T6'], description='beta-1,4-galactosyltransferase 6', other_designations='beta-1,4-galactosyltransferase 6|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 6|UDP-Gal:betaGlcNAc beta 1,4- galactosyltransferase, polypeptide 6|UDP-Gal:glucosylceramide beta-1,4-galactosyltransferase|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 6|beta-1,4-GalTase 6|beta4GalT-VI|glucosylceramide beta-1,4-galactosyltransferase|lacCer synthase|lactosylceramide synthase', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31622246, end_position_on_the_genomic_accession=31724670, orientation='minus', exon_count=13, OMIM=[604017], no_hdr0=''),
    9332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9332, CurrentID=0, Status='live', Symbol='CD163', Aliases=['M130', 'MM130', 'SCARI1'], description='CD163 molecule', other_designations='scavenger receptor cysteine-rich type 1 protein M130|hemoglobin scavenger receptor|macrophage-associated antigen', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7470811, end_position_on_the_genomic_accession=7503808, orientation='minus', exon_count=16, OMIM=[605545], no_hdr0=''),
    9333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9333, CurrentID=0, Status='live', Symbol='TGM5', Aliases=['PSS2', 'TGASE5', 'TGASEX', 'TGM6', 'TGMX', 'TGX'], description='transglutaminase 5', other_designations='protein-glutamine gamma-glutamyltransferase 5|TG(X)|TGase X|TGase-5|transglutaminase V|transglutaminase X', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43232590, end_position_on_the_genomic_accession=43266928, orientation='minus', exon_count=15, OMIM=[603805], no_hdr0=''),
    9334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9334, CurrentID=0, Status='live', Symbol='B4GALT5', Aliases=['B4Gal-T5', 'BETA4-GALT-IV', 'beta4Gal-T5', 'beta4GalT-V', 'gt-V'], description='beta-1,4-galactosyltransferase 5', other_designations='beta-1,4-galactosyltransferase 5|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 5|UDP-Gal:betaGlcNAc beta 1,4-galactosyltransferase, polypeptide 5|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 5|beta-1,4-GalT II|beta-1,4-GalT IV|beta-1,4-GalTase 5|beta-1.4-galactosyltransferase V|beta4-GalT IV|glucosylceramide beta-1,4-galactosyltransferase|lacCer synthase|lactosylceramide synthase', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49632945, end_position_on_the_genomic_accession=49713878, orientation='minus', exon_count=9, OMIM=[604016], no_hdr0=''),
    9337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9337, CurrentID=0, Status='live', Symbol='CNOT8', Aliases=['CAF1', 'CALIF', 'Caf1b', 'POP2', 'hCAF1'], description='CCR4-NOT transcription complex subunit 8', other_designations='CCR4-NOT transcription complex subunit 8|CAF1-like protein|CAF2|CALIFp|CCR4-associated factor 8|PGK promoter directed over production', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154857952, end_position_on_the_genomic_accession=154876792, orientation='plus', exon_count=10, OMIM=[603731], no_hdr0=''),
    9338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9338, CurrentID=0, Status='live', Symbol='TCEAL1', Aliases=['SIIR', 'WEX9', 'p21', 'pp21'], description='transcription elongation factor A like 1', other_designations='transcription elongation factor A protein-like 1|TCEA-like protein 1|nuclear phosphoprotein p21/SIIR|transcription elongation factor A (SII)-like 1|transcription elongation factor S-II protein-like 1', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103628716, end_position_on_the_genomic_accession=103630953, orientation='plus', exon_count=4, OMIM=[300237], no_hdr0=''),
    9340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9340, CurrentID=0, Status='live', Symbol='GLP2R', Aliases=[], description='glucagon like peptide 2 receptor', other_designations='glucagon-like peptide 2 receptor|GLP-2 receptor|epididymis secretory sperm binding protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9825508, end_position_on_the_genomic_accession=9894163, orientation='plus', exon_count=14, OMIM=[603659], no_hdr0=''),
    9341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9341, CurrentID=0, Status='live', Symbol='VAMP3', Aliases=['CEB'], description='vesicle associated membrane protein 3', other_designations='vesicle-associated membrane protein 3|VAMP-3|cellubrevin|synaptobrevin-3', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=7771275, end_position_on_the_genomic_accession=7781432, orientation='plus', exon_count=5, OMIM=[603657], no_hdr0=''),
    9342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9342, CurrentID=0, Status='live', Symbol='SNAP29', Aliases=['CEDNIK', 'SNAP-29'], description='synaptosome associated protein 29', other_designations='synaptosomal-associated protein 29|soluble 29 kDa NSF attachment protein|synaptosomal-associated protein, 29kD|synaptosomal-associated protein, 29kDa|synaptosome associated protein 29kDa|vesicle-membrane fusion protein SNAP-29', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20859007, end_position_on_the_genomic_accession=20891214, orientation='plus', exon_count=5, OMIM=[604202], no_hdr0=''),
    9343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9343, CurrentID=0, Status='live', Symbol='EFTUD2', Aliases=['MFDGA', 'MFDM', 'SNRNP116', 'Snrp116', 'Snu114', 'U5-116KD'], description='elongation factor Tu GTP binding domain containing 2', other_designations='116 kDa U5 small nuclear ribonucleoprotein component|SNU114 homolog|U5 snRNP-specific protein, 116 kDa|elongation factor Tu GTP-binding domain-containing protein 2|hSNU114', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44849948, end_position_on_the_genomic_accession=44899445, orientation='minus', exon_count=29, OMIM=[603892], no_hdr0=''),
    9344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9344, CurrentID=0, Status='live', Symbol='TAOK2', Aliases=['MAP3K17', 'PSK', 'PSK1', 'PSK1-BETA', 'TAO1', 'TAO2'], description='TAO kinase 2', other_designations='serine/threonine-protein kinase TAO2|PSK-1|hKFC-C|kinase from chicken homolog C|prostate derived STE20-like kinase PSK|prostate-derived STE20-like kinase 1|prostate-derived sterile 20-like kinase 1|thousand and one amino acid protein kinase 2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29973868, end_position_on_the_genomic_accession=29992261, orientation='plus', exon_count=20, OMIM=[613199], no_hdr0=''),
    9348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9348, CurrentID=0, Status='live', Symbol='NDST3', Aliases=['HSST3'], description='N-deacetylase and N-sulfotransferase 3', other_designations='bifunctional heparan sulfate N-deacetylase/N-sulfotransferase 3|GlcNAc N-deacetylase/ N-sulfotransferase 3|N-deacetylase/N-sulfotransferase (heparan glucosaminyl) 3|N-deacetylase/N-sulfotransferase 3|N-heparan sulfate sulfotransferase 3|glucosaminyl N-deacetylase/N-sulfotransferase 3', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=118033322, end_position_on_the_genomic_accession=118258945, orientation='plus', exon_count=19, OMIM=[603950], no_hdr0=''),
    9349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9349, CurrentID=0, Status='live', Symbol='RPL23', Aliases=['L23', 'rpL17'], description='ribosomal protein L23', other_designations='60S ribosomal protein L23|60S ribosomal protein L17|large ribosomal subunit protein uL14|ribosomal protein L17', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38847860, end_position_on_the_genomic_accession=38853721, orientation='minus', exon_count=5, OMIM=[603662], no_hdr0=''),
    9350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9350, CurrentID=0, Status='live', Symbol='CER1', Aliases=['DAND4'], description='cerberus 1, DAN family BMP antagonist', other_designations='cerberus|DAN domain family member 4|cerberus 1, cysteine knot superfamily, homolog|cerberus-related 1|cerberus-related protein', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=14715082, end_position_on_the_genomic_accession=14724308, orientation='minus', exon_count=3, OMIM=[603777], no_hdr0=''),
    9351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9351, CurrentID=0, Status='live', Symbol='SLC9A3R2', Aliases=['E3KARP', 'NHE3RF2', 'NHERF-2', 'NHERF2', 'OCTS2', 'SIP-1', 'SIP1', 'TKA-1'], description='SLC9A3 regulator 2', other_designations='Na(+)/H(+) exchange regulatory cofactor NHE-RF2|NHE3 kinase A regulatory protein E3KARP|NHE3 regulatory factor 2|SRY-interacting protein 1|sodium/hydrogen exchanger 3 kinase A regulatory protein|solute carrier family 9 (sodium/hydrogen exchanger), member 3 regulator 2|solute carrier family 9, subfamily A (NHE3, cation proton antiporter 3), member 3 regulator 2|tyrosine kinase activator protein 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2026902, end_position_on_the_genomic_accession=2039026, orientation='plus', exon_count=10, OMIM=[606553], no_hdr0=''),
    9352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9352, CurrentID=0, Status='live', Symbol='TXNL1', Aliases=['HEL-S-114', 'TRP32', 'TXL-1', 'TXNL', 'Txl'], description='thioredoxin like 1', other_designations='thioredoxin-like protein 1|32 kDa thioredoxin-related protein|epididymis secretory protein Li 114|thioredoxin-related 32 kDa protein|thioredoxin-related protein 1', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=56597209, end_position_on_the_genomic_accession=56638635, orientation='minus', exon_count=11, OMIM=[603049], no_hdr0=''),
    9353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9353, CurrentID=0, Status='live', Symbol='SLIT2', Aliases=['SLIL3', 'Slit-2'], description='slit guidance ligand 2', other_designations='slit homolog 2 protein', map_location='4p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=20251905, end_position_on_the_genomic_accession=20620561, orientation='plus', exon_count=40, OMIM=[603746], no_hdr0=''),
    9354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9354, CurrentID=0, Status='live', Symbol='UBE4A', Aliases=['E4', 'UBOX2', 'UFD2'], description='ubiquitination factor E4A', other_designations='ubiquitin conjugation factor E4 A|RING-type E3 ubiquitin transferase E4 A|ubiquitination factor E4A (UFD2 homolog, yeast)', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118359600, end_position_on_the_genomic_accession=118399211, orientation='plus', exon_count=20, OMIM=[603753], no_hdr0=''),
    9355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9355, CurrentID=0, Status='live', Symbol='LHX2', Aliases=['LH2', 'hLhx2'], description='LIM homeobox 2', other_designations='LIM/homeobox protein Lhx2|LIM HOX gene 2|LIM homeobox protein 2|homeobox protein LH-2', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124011759, end_position_on_the_genomic_accession=124033301, orientation='plus', exon_count=6, OMIM=[603759], no_hdr0=''),
    9356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9356, CurrentID=0, Status='live', Symbol='SLC22A6', Aliases=['HOAT1', 'OAT1', 'PAHT', 'ROAT1'], description='solute carrier family 22 member 6', other_designations='solute carrier family 22 member 6|PAH transporter|hPAHT|hROAT1|organic anion transporter 1|para-aminohippurate transporter|renal organic anion transporter 1|solute carrier family 22 (organic anion transporter), member 6', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62976597, end_position_on_the_genomic_accession=62984967, orientation='minus', exon_count=10, OMIM=[607582], no_hdr0=''),
    9358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9358, CurrentID=0, Status='live', Symbol='ITGBL1', Aliases=['OSCP', 'TIED'], description='integrin subunit beta like 1', other_designations='integrin beta-like protein 1|integrin beta like 1|integrin, beta-like 1 (with EGF-like repeat domains)|osteoblast-specific cysteine-rich protein|ten integrin EGF-like repeat domain-containing protein', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=101452636, end_position_on_the_genomic_accession=101720856, orientation='plus', exon_count=13, OMIM=[604234], no_hdr0=''),
    9360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9360, CurrentID=0, Status='live', Symbol='PPIG', Aliases=['CARS-Cyp', 'CYP', 'SCAF10', 'SRCyp'], description='peptidylprolyl isomerase G', other_designations='peptidyl-prolyl cis-trans isomerase G|CARS-cyclophilin|CASP10|Clk-associating RS-cyclophilin|PPIase G|SR-cyclophilin|SR-cyp|SR-related CTD-associated factor 10|cyclophilin G|peptidyl-prolyl isomerase G (cyclophilin G)|rotamase G', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169584343, end_position_on_the_genomic_accession=169641406, orientation='plus', exon_count=16, OMIM=[606093], no_hdr0=''),
    9361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9361, CurrentID=0, Status='live', Symbol='LONP1', Aliases=['CODASS', 'LON', 'LONP', 'LonHS', 'PIM1', 'PRSS15', 'hLON'], description='lon peptidase 1, mitochondrial', other_designations='lon protease homolog, mitochondrial|hLON ATP-dependent protease|mitochondrial ATP-dependent protease Lon|mitochondrial lon protease-like protein|serine protease 15', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5691834, end_position_on_the_genomic_accession=5720452, orientation='minus', exon_count=21, OMIM=[605490], no_hdr0=''),
    9362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9362, CurrentID=0, Status='live', Symbol='CPNE6', Aliases=[], description='copine 6', other_designations='copine-6|N-copine|copine VI (neuronal)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24069833, end_position_on_the_genomic_accession=24078100, orientation='plus', exon_count=18, OMIM=[605688], no_hdr0=''),
    9363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9363, CurrentID=0, Status='live', Symbol='RAB33A', Aliases=['RabS10'], description='RAB33A, member RAS oncogene family', other_designations='ras-related protein Rab-33A|Small GTP-binding protein S10', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130110633, end_position_on_the_genomic_accession=130184873, orientation='plus', exon_count=4, OMIM=[300333], no_hdr0=''),
    9364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9364, CurrentID=0, Status='live', Symbol='RAB28', Aliases=['CORD18'], description='RAB28, member RAS oncogene family', other_designations='ras-related protein Rab-28', map_location='4p15.33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=13367724, end_position_on_the_genomic_accession=13484340, orientation='minus', exon_count=9, OMIM=[612994], no_hdr0=''),
    9365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9365, CurrentID=0, Status='live', Symbol='KL', Aliases=['HFTC3'], description='klotho', other_designations='klotho', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=33016063, end_position_on_the_genomic_accession=33066143, orientation='plus', exon_count=6, OMIM=[604824], no_hdr0=''),
    9367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9367, CurrentID=0, Status='live', Symbol='RAB9A', Aliases=['RAB9'], description='RAB9A, member RAS oncogene family', other_designations='ras-related protein Rab-9A|RAB9, member RAS oncogene family', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13689128, end_position_on_the_genomic_accession=13710504, orientation='plus', exon_count=3, OMIM=[300284], no_hdr0=''),
    9368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9368, CurrentID=0, Status='live', Symbol='SLC9A3R1', Aliases=['EBP50', 'NHERF', 'NHERF-1', 'NHERF1', 'NPHLOP2'], description='SLC9A3 regulator 1', other_designations='Na(+)/H(+) exchange regulatory cofactor NHE-RF1|Na+/H+ exchange regulatory co-factor|ezrin-radixin-moesin binding phosphoprotein-50|regulatory cofactor of Na(+)/H(+) exchanger|solute carrier family 9, subfamily A (NHE3, cation proton antiporter 3), member 3 regulator 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74748628, end_position_on_the_genomic_accession=74769353, orientation='plus', exon_count=6, OMIM=[604990], no_hdr0=''),
    9369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9369, CurrentID=0, Status='live', Symbol='NRXN3', Aliases=['C14orf60'], description='neurexin 3', other_designations='neurexin 3|neurexin III|neurexin-3-alpha', map_location='14q24.3-q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77979904, end_position_on_the_genomic_accession=79868291, orientation='plus', exon_count=34, OMIM=[600567], no_hdr0=''),
    9370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9370, CurrentID=0, Status='live', Symbol='ADIPOQ', Aliases=['ACDC', 'ACRP30', 'ADIPQTL1', 'ADPN', 'APM-1', 'APM1', 'GBP28'], description='adiponectin, C1Q and collagen domain containing', other_designations='adiponectin|30 kDa adipocyte complement-related protein|adipocyte complement-related 30 kDa protein|adipose most abundant gene transcript 1 protein|adipose specific collagen-like factor|gelatin-binding protein 28', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186842710, end_position_on_the_genomic_accession=186858463, orientation='plus', exon_count=4, OMIM=[605441], no_hdr0=''),
    9371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9371, CurrentID=0, Status='live', Symbol='KIF3B', Aliases=['FLA8', 'HH0048', 'KLP-11', 'RP89'], description='kinesin family member 3B', other_designations='kinesin-like protein KIF3B|microtubule plus end-directed kinesin motor 3B', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32277651, end_position_on_the_genomic_accession=32335011, orientation='plus', exon_count=9, OMIM=[603754], no_hdr0=''),
    9372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9372, CurrentID=0, Status='live', Symbol='ZFYVE9', Aliases=['MADHIP', 'NSP', 'PPP1R173', 'SARA', 'SMADIP'], description='zinc finger FYVE-type containing 9', other_designations='zinc finger FYVE domain-containing protein 9|MAD, mothers against decapentaplegic homolog interacting protein, receptor activation anchor|MADH-interacting protein|novel serine protease|protein phosphatase 1, regulatory subunit 173|smad anchor for receptor activation|zinc finger, FYVE domain containing 9', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52142001, end_position_on_the_genomic_accession=52348664, orientation='plus', exon_count=21, OMIM=[603755], no_hdr0=''),
    9373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9373, CurrentID=0, Status='live', Symbol='PLAA', Aliases=['DOA1', 'NDMSBA', 'PLA2P', 'PLAP'], description='phospholipase A2 activating protein', other_designations='phospholipase A-2-activating protein|DOA1 homolog', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=26903372, end_position_on_the_genomic_accession=26947267, orientation='minus', exon_count=15, OMIM=[603873], no_hdr0=''),
    9374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9374, CurrentID=0, Status='live', Symbol='PPT2', Aliases=['C6orf8', 'G14', 'PPT-2'], description='palmitoyl-protein thioesterase 2', other_designations='lysosomal thioesterase PPT2|S-thioesterase G14|VE-statin2|palmitoyl-protein hydrolase 2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32153528, end_position_on_the_genomic_accession=32163675, orientation='plus', exon_count=10, OMIM=[603298], no_hdr0=''),
    9375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9375, CurrentID=0, Status='live', Symbol='TM9SF2', Aliases=['P76'], description='transmembrane 9 superfamily member 2', other_designations='transmembrane 9 superfamily member 2|76 kDa membrane protein|dinucleotide oxidase disulfide thiol exchanger 3 superfamily member 2|epididymis secretory sperm binding protein|transmembrane protein 9 superfamily member 2', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99501472, end_position_on_the_genomic_accession=99564048, orientation='plus', exon_count=17, OMIM=[604678], no_hdr0=''),
    9376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9376, CurrentID=0, Status='live', Symbol='SLC22A8', Aliases=['OAT3'], description='solute carrier family 22 member 8', other_designations='solute carrier family 22 member 8|hOAT3|organic anion transporter 3|solute carrier family 22 (organic anion transporter), member 8', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62992824, end_position_on_the_genomic_accession=63015841, orientation='minus', exon_count=12, OMIM=[607581], no_hdr0=''),
    9377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9377, CurrentID=0, Status='live', Symbol='COX5A', Aliases=['COX', 'COX-VA', 'MC4DN20', 'VA'], description='cytochrome c oxidase subunit 5A', other_designations='cytochrome c oxidase subunit 5A, mitochondrial|cytochrome c oxidase polypeptide Va|cytochrome c oxidase polypeptide, mitochondrial|cytochrome c oxidase subunit Va|mitochondrial cytochrome c oxidase subunit Va', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74919791, end_position_on_the_genomic_accession=74938073, orientation='minus', exon_count=5, OMIM=[603773], no_hdr0=''),
    9378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9378, CurrentID=0, Status='live', Symbol='NRXN1', Aliases=['Hs.22998', 'PTHSL2', 'SCZD17'], description='neurexin 1', other_designations='neurexin-1|neurexin I', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=49918503, end_position_on_the_genomic_accession=51032132, orientation='minus', exon_count=27, OMIM=[600565], no_hdr0=''),
    9379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9379, CurrentID=0, Status='live', Symbol='NRXN2', Aliases=[], description='neurexin 2', other_designations='neurexin-2-beta|neurexin II', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64606174, end_position_on_the_genomic_accession=64723197, orientation='minus', exon_count=28, OMIM=[600566], no_hdr0=''),
    9380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9380, CurrentID=0, Status='live', Symbol='GRHPR', Aliases=['GLXR', 'GLYD', 'PH2'], description='glyoxylate and hydroxypyruvate reductase', other_designations='glyoxylate reductase/hydroxypyruvate reductase|epididymis secretory sperm binding protein|glycerate-2-dehydrogenase|glyoxylate reductase and hydroxypyruvate reductase', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37422435, end_position_on_the_genomic_accession=37438952, orientation='plus', exon_count=12, OMIM=[604296], no_hdr0=''),
    9381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9381, CurrentID=0, Status='live', Symbol='OTOF', Aliases=['AUNB1', 'DFNB6', 'DFNB9', 'FER1L2', 'NSRD9'], description='otoferlin', other_designations='otoferlin|fer-1-like family member 2|fer-1-like protein 2', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26457203, end_position_on_the_genomic_accession=26558756, orientation='minus', exon_count=48, OMIM=[603681], no_hdr0=''),
    9382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9382, CurrentID=0, Status='live', Symbol='COG1', Aliases=['CDG2G', 'LDLB'], description='component of oligomeric golgi complex 1', other_designations='conserved oligomeric Golgi complex subunit 1|COG complex subunit 1|conserved oligomeric Golgi complex protein 1|low density lipoprotein receptor defect B complementing', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73193055, end_position_on_the_genomic_accession=73208507, orientation='plus', exon_count=14, OMIM=[606973], no_hdr0=''),
    9388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9388, CurrentID=0, Status='live', Symbol='LIPG', Aliases=['EDL', 'EL', 'PRO719'], description='lipase G, endothelial type', other_designations='endothelial lipase|endothelial cell-derived lipase|lipase, endothelial|lipoprotein lipase H|phospholipase A1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49560699, end_position_on_the_genomic_accession=49599185, orientation='plus', exon_count=12, OMIM=[603684], no_hdr0=''),
    9389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9389, CurrentID=0, Status='live', Symbol='SLC22A14', Aliases=['OCTL2', 'OCTL4', 'ORCTL4'], description='solute carrier family 22 member 14', other_designations='solute carrier family 22 member 14|organic cation transporter-like 4|organic cationic transporter-like 4|solute carrier family 22 (organic cation transporter), member 14', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38281662, end_position_on_the_genomic_accession=38318575, orientation='plus', exon_count=11, OMIM=[604048], no_hdr0=''),
    9390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9390, CurrentID=0, Status='live', Symbol='SLC22A13', Aliases=['OAT10', 'OCTL1', 'OCTL3', 'ORCTL-3', 'ORCTL3'], description='solute carrier family 22 member 13', other_designations='solute carrier family 22 member 13|organic cationic transporter-like 3|organic-cation transporter like 3|solute carrier family 22 (organic anion transporter), member 13|solute carrier family 22 (organic anion/urate transporter), member 13', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38265812, end_position_on_the_genomic_accession=38278757, orientation='plus', exon_count=10, OMIM=[604047], no_hdr0=''),
    9391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9391, CurrentID=0, Status='live', Symbol='CIAO1', Aliases=['CIA1', 'WDR39'], description='cytosolic iron-sulfur assembly component 1', other_designations='probable cytosolic iron-sulfur protein assembly protein CIAO1|WD repeat domain 39|WD repeat-containing protein 39|WD40 protein Ciao1|cytosolic iron-sulfur protein assembly 1 homolog', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96266159, end_position_on_the_genomic_accession=96274173, orientation='plus', exon_count=7, OMIM=[604333], no_hdr0=''),
    9392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9392, CurrentID=0, Status='live', Symbol='TGFBRAP1', Aliases=['TRAP-1', 'TRAP1', 'VPS3'], description='transforming growth factor beta receptor associated protein 1', other_designations='transforming growth factor-beta receptor-associated protein 1|TGF-beta receptor-associated protein 1|VPS3 CORVET complex subunit', map_location='2q12.1-q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105249404, end_position_on_the_genomic_accession=105329735, orientation='minus', exon_count=14, OMIM=[606237], no_hdr0=''),
    9394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9394, CurrentID=0, Status='live', Symbol='HS6ST1', Aliases=['HH15', 'HS6ST'], description='heparan sulfate 6-O-sulfotransferase 1', other_designations='heparan-sulfate 6-O-sulfotransferase 1|HS6ST-1|heparan-sulfate 6-sulfotransferase', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=128265480, end_position_on_the_genomic_accession=128318868, orientation='minus', exon_count=2, OMIM=[604846], no_hdr0=''),
    9397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9397, CurrentID=0, Status='live', Symbol='NMT2', Aliases=[], description='N-myristoyltransferase 2', other_designations='glycylpeptide N-tetradecanoyltransferase 2|NMT 2|glycylpeptide N-tetradecanoyltransferase 2 variant 3|glycylpeptide N-tetradecanoyltransferase 2 variant 4|myristoyl-CoA:protein N-myristoyltransferase 2|peptide N-myristoyltransferase 2|type II N-myristoyltransferase', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15104588, end_position_on_the_genomic_accession=15168693, orientation='minus', exon_count=16, OMIM=[603801], no_hdr0=''),
    9398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9398, CurrentID=0, Status='live', Symbol='CD101', Aliases=['EWI-101', 'IGSF2', 'V7'], description='CD101 molecule', other_designations='immunoglobulin superfamily member 2|cell surface glycoprotein V7|glu-Trp-Ile EWI motif-containing protein 101|leukocyte surface protein', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116987997, end_position_on_the_genomic_accession=117037481, orientation='plus', exon_count=12, OMIM=[604516], no_hdr0=''),
    9399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9399, CurrentID=0, Status='live', Symbol='STOML1', Aliases=['SLP-1', 'STORP', 'hUNC-24'], description='stomatin like 1', other_designations='stomatin-like protein 1|EPB72-like 1|EPB72-like protein 1|protein unc-24 homolog|stomatin (EBP72)-like 1|stomatin (EPB72)-like 1|stomatin-related protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73978926, end_position_on_the_genomic_accession=73994636, orientation='minus', exon_count=9, OMIM=[608326], no_hdr0=''),
    9400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9400, CurrentID=0, Status='live', Symbol='RECQL5', Aliases=['RECQ5'], description='RecQ like helicase 5', other_designations='ATP-dependent DNA helicase Q5|DNA helicase, RecQ-like type 5|RecQ helicase-like 5|RecQ protein-like 5', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75626845, end_position_on_the_genomic_accession=75667202, orientation='minus', exon_count=23, OMIM=[603781], no_hdr0=''),
    9401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9401, CurrentID=0, Status='live', Symbol='RECQL4', Aliases=['RECQ4'], description='RecQ like helicase 4', other_designations='ATP-dependent DNA helicase Q4|DNA helicase, RecQ-like, type 4|RecQ helicase-like 4|RecQ protein-like 4', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144511288, end_position_on_the_genomic_accession=144517833, orientation='minus', exon_count=21, OMIM=[603780], no_hdr0=''),
    9402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9402, CurrentID=0, Status='live', Symbol='GRAP2', Aliases=['GADS', 'GRAP-2', 'GRB2L', 'GRBLG', 'GRID', 'GRPL', 'GrbX', 'Grf40', 'Mona', 'P38'], description='GRB2 related adaptor protein 2', other_designations='GRB2-related adapter protein 2|GRB-2-like protein|GRB2-related protein with insert domain|SH3-SH2-SH3 adapter Mona|SH3-SH2-SH3 adaptor molecule|adapter protein GRID|grf-40|grf40 adapter protein|growth factor receptor-binding protein|growth factor receptor-bound protein 2-related adaptor protein 2|hematopoietic cell-associated adapter protein GrpL|hematopoietic cell-associated adaptor protein GRPL', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39901073, end_position_on_the_genomic_accession=39973721, orientation='plus', exon_count=9, OMIM=[604518], no_hdr0=''),
    9403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9403, CurrentID=0, Status='live', Symbol='SELENOF', Aliases=['SEP15'], description='selenoprotein F', other_designations='selenoprotein F|15 kDa selenoprotein', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86862445, end_position_on_the_genomic_accession=86914577, orientation='minus', exon_count=6, OMIM=[606254], no_hdr0=''),
    9404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9404, CurrentID=0, Status='live', Symbol='LPXN', Aliases=['LDPL'], description='leupaxin', other_designations='leupaxin', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58526871, end_position_on_the_genomic_accession=58578239, orientation='minus', exon_count=13, OMIM=[605390], no_hdr0=''),
    9406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9406, CurrentID=0, Status='live', Symbol='ZRANB2', Aliases=['ZIS', 'ZIS1', 'ZIS2', 'ZNF265'], description='zinc finger RANBP2-type containing 2', other_designations='zinc finger Ran-binding domain-containing protein 2|zinc finger protein 265|zinc finger, RAN-binding domain containing 2|zinc-finger, splicing', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=71063291, end_position_on_the_genomic_accession=71081035, orientation='minus', exon_count=11, OMIM=[604347], no_hdr0=''),
    9407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9407, CurrentID=0, Status='live', Symbol='TMPRSS11D', Aliases=['ASP', 'HAT'], description='transmembrane serine protease 11D', other_designations='transmembrane protease serine 11D|adrenal secretory serine protease|airway trypsin-like protease|transmembrane protease, serine 11D', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67820876, end_position_on_the_genomic_accession=67885063, orientation='minus', exon_count=10, OMIM=[605369], no_hdr0=''),
    9409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9409, CurrentID=0, Status='live', Symbol='PEX16', Aliases=['PBD8A', 'PBD8B'], description='peroxisomal biogenesis factor 16', other_designations='peroxisomal biogenesis factor 16|peroxin 16|peroxisomal membrane protein PEX16|peroxisome biogenesis factor 16', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45909663, end_position_on_the_genomic_accession=45917877, orientation='minus', exon_count=11, OMIM=[603360], no_hdr0=''),
    9410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9410, CurrentID=0, Status='live', Symbol='SNRNP40', Aliases=['40K', 'HPRP8BP', 'PRP8BP', 'PRPF8BP', 'SPF38', 'WDR57'], description='small nuclear ribonucleoprotein U5 subunit 40', other_designations='U5 small nuclear ribonucleoprotein 40 kDa protein|38 kDa-splicing factor|Prp8-binding protein|U5 snRNP 40 kDa protein|U5 snRNP-specific 40 kDa protein|U5-40K|U5-40kD protein|WD repeat domain 57 (U5 snRNP specific)|WD repeat-containing protein 57|small nuclear ribonucleoprotein 40kDa (U5)|small nuclear ribonucleoprotein, U5 40kDa subunit', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31259568, end_position_on_the_genomic_accession=31296788, orientation='minus', exon_count=10, OMIM=[607797], no_hdr0=''),
    9411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9411, CurrentID=0, Status='live', Symbol='ARHGAP29', Aliases=['PARG1'], description='Rho GTPase activating protein 29', other_designations='rho GTPase-activating protein 29|PTPL1-associated RhoGAP 1 (PARG1)|PTPL1-associated RhoGAP protein 1|rho-type GTPase-activating protein 29', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94168905, end_position_on_the_genomic_accession=94275068, orientation='minus', exon_count=25, OMIM=[610496], no_hdr0=''),
    9412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9412, CurrentID=0, Status='live', Symbol='MED21', Aliases=['SRB7', 'SURB7', 'hSrb7'], description='mediator complex subunit 21', other_designations='mediator of RNA polymerase II transcription subunit 21|RNA polymerase II holoenzyme component SRB7|RNAPII complex component SRB7|SRB7 suppressor of RNA polymerase B homolog', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27022558, end_position_on_the_genomic_accession=27030673, orientation='plus', exon_count=4, OMIM=[603800], no_hdr0=''),
    9413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9413, CurrentID=0, Status='live', Symbol='FAM189A2', Aliases=['C9orf61', 'ENTREP', 'X123'], description='family with sequence similarity 189 member A2', other_designations='protein FAM189A2|Friedreich ataxia region gene X123', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69324567, end_position_on_the_genomic_accession=69392461, orientation='plus', exon_count=14, OMIM=[607710], no_hdr0=''),
    9414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9414, CurrentID=0, Status='live', Symbol='TJP2', Aliases=['C9DUPq21.11', 'DFNA51', 'DUP9q21.11', 'FHCA1', 'PFIC4', 'X104', 'ZO2'], description='tight junction protein 2', other_designations='tight junction protein ZO-2|Friedreich ataxia region gene X104 (tight junction protein ZO-2)|zona occludens 2|zonula occludens protein 2', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69121006, end_position_on_the_genomic_accession=69255208, orientation='plus', exon_count=31, OMIM=[607709], no_hdr0=''),
    9415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9415, CurrentID=0, Status='live', Symbol='FADS2', Aliases=['D6D', 'DES6', 'FADSD6', 'LLCDL2', 'SLL0262', 'TU13'], description='fatty acid desaturase 2', other_designations='acyl-CoA 6-desaturase|delta-6 fatty acid desaturase|delta-6-desaturase|linoleoyl-CoA desaturase (delta-6-desaturase)-like 2', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61816203, end_position_on_the_genomic_accession=61867354, orientation='plus', exon_count=13, OMIM=[606149], no_hdr0=''),
    9416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9416, CurrentID=0, Status='live', Symbol='DDX23', Aliases=['PRPF28', 'SNRNP100', 'U5-100K', 'U5-100KD', 'prp28'], description='DEAD-box helicase 23', other_designations='probable ATP-dependent RNA helicase DDX23|100 kDa U5 snRNP-specific protein|DEAD (Asp-Glu-Ala-Asp) box polypeptide 23|DEAD box protein 23|PRP28 homolog, yeast|PRP28p homolog|U5 snRNP 100 kD protein', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48829756, end_position_on_the_genomic_accession=48852163, orientation='minus', exon_count=17, OMIM=[612172], no_hdr0=''),
    9419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9419, CurrentID=0, Status='live', Symbol='CRIPT', Aliases=['HSPC139', 'SSMDF'], description='CXXC repeat containing interactor of PDZ3 domain', other_designations='cysteine-rich PDZ-binding protein|cysteine-rich interactor of PDZ three|cysteine-rich interactor of PDZ3|postsynaptic protein CRIPT', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46617215, end_position_on_the_genomic_accession=46630176, orientation='plus', exon_count=5, OMIM=[604594], no_hdr0=''),
    9420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9420, CurrentID=0, Status='live', Symbol='CYP7B1', Aliases=['CBAS3', 'CP7B', 'SPG5A'], description='cytochrome P450 family 7 subfamily B member 1', other_designations='cytochrome P450 7B1|24-hydroxycholesterol 7-alpha-hydroxylase|25-hydroxycholesterol 7-alpha-hydroxylase|25/26-hydroxycholesterol 7-alpha-hydroxylase|3-hydroxysteroid 7-alpha hydroxylase|cytochrome P450, subfamily VIIB (oxysterol 7 alpha-hydroxylase), polypeptide 1|oxysterol 7-alpha-hydroxylase', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=64586575, end_position_on_the_genomic_accession=64798737, orientation='minus', exon_count=10, OMIM=[603711], no_hdr0=''),
    9421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9421, CurrentID=0, Status='live', Symbol='HAND1', Aliases=['Hxt', 'Thing1', 'bHLHa27', 'eHand'], description='heart and neural crest derivatives expressed 1', other_designations='heart- and neural crest derivatives-expressed protein 1|class A basic helix-loop-helix protein 27|extraembryonic tissues, heart, autonomic nervous system and neural crest derivatives-expressed protein 1', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154474972, end_position_on_the_genomic_accession=154478227, orientation='minus', exon_count=2, OMIM=[602406], no_hdr0=''),
    9422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9422, CurrentID=0, Status='live', Symbol='ZNF264', Aliases=[], description='zinc finger protein 264', other_designations='zinc finger protein 264', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57191500, end_position_on_the_genomic_accession=57222846, orientation='plus', exon_count=4, OMIM=[604668], no_hdr0=''),
    9423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9423, CurrentID=0, Status='live', Symbol='NTN1', Aliases=['MRMV4L', 'NTN1'], description='netrin 1', other_designations='netrin-1|epididymis tissue protein Li 131P|netrin 1, mouse, homolog of', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9021510, end_position_on_the_genomic_accession=9244000, orientation='plus', exon_count=8, OMIM=[601614], no_hdr0=''),
    9424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9424, CurrentID=0, Status='live', Symbol='KCNK6', Aliases=['K2p6.1', 'KCNK8', 'TOSS', 'TWIK-2', 'TWIK2'], description='potassium two pore domain channel subfamily K member 6', other_designations='potassium channel subfamily K member 6|K2P6.1 potassium channel|TWIK-originated similarity sequence|TWIK-originated sodium similarity sequence|inward rectifying potassium channel protein TWIK-2|potassium channel, two pore domain subfamily K, member 6', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38319845, end_position_on_the_genomic_accession=38332076, orientation='plus', exon_count=5, OMIM=[603939], no_hdr0=''),
    9425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9425, CurrentID=0, Status='live', Symbol='CDYL', Aliases=['CDYL1'], description='chromodomain Y like', other_designations='chromodomain Y-like protein|CDY-like, autosomal|chromodomain protein, Y-like|crotonyl-CoA hydratase|testis-specific chromodomain Y-like protein', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4706138, end_position_on_the_genomic_accession=4955544, orientation='plus', exon_count=12, OMIM=[603778], no_hdr0=''),
    9426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9426, CurrentID=0, Status='live', Symbol='CDY2A', Aliases=['CDY', 'CDY2'], description='chromodomain Y-linked 2A', other_designations='testis-specific chromodomain protein Y 2|Y chromosome chromodomain protein 2A|chromodomain protein, Y chromosome, 2|chromodomain protein, Y-linked, 2A', map_location='Yq11.222', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=18025787, end_position_on_the_genomic_accession=18027746, orientation='plus', exon_count=1, OMIM=[400018], no_hdr0=''),
    9427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9427, CurrentID=0, Status='live', Symbol='ECEL1', Aliases=['DA5D', 'DINE', 'ECEX', 'XCE'], description='endothelin converting enzyme like 1', other_designations='endothelin-converting enzyme-like 1|X converting enzyme|damage induced neuronal endopeptidase', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232479827, end_position_on_the_genomic_accession=232487834, orientation='minus', exon_count=18, OMIM=[605896], no_hdr0=''),
    9429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9429, CurrentID=0, Status='live', Symbol='ABCG2', Aliases=['ABC15', 'ABCP', 'BCRP', 'BCRP1', 'BMDP', 'CD338', 'CDw338', 'EST157481', 'GOUT1', 'MRX', 'MXR', 'MXR-1', 'MXR1', 'UAQTL1'], description='ATP binding cassette subfamily G member 2 (Junior blood group)', other_designations='broad substrate specificity ATP-binding cassette transporter ABCG2|ABC transporter|ATP-binding cassette transporter G2|ATP-binding cassette, sub-family G (WHITE), member 2 (Junior blood group)|breast cancer resistance protein|mitoxantrone resistance-associated protein|multi drug resistance efflux transport ATP-binding cassette sub-family G (WHITE) member 2|placenta specific MDR protein|placenta-specific ATP-binding cassette transporter|urate exporter', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88090264, end_position_on_the_genomic_accession=88231626, orientation='minus', exon_count=21, OMIM=[603756], no_hdr0=''),
    9435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9435, CurrentID=0, Status='live', Symbol='CHST2', Aliases=['C6ST', 'GST-2', 'GST2', 'Gn6ST-1', 'HEL-S-75', 'glcNAc6ST-1'], description='carbohydrate sulfotransferase 2', other_designations='carbohydrate sulfotransferase 2|N-acetylglucosamine 6-O-sulfotransferase 1|carbohydrate (N-acetylglucosamine-6-O) sulfotransferase 2|carbohydrate (chondroitin 6/keratan) sulfotransferase 2|epididymis secretory protein Li 75|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 2', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=143119771, end_position_on_the_genomic_accession=143124014, orientation='plus', exon_count=2, OMIM=[603798], no_hdr0=''),
    9436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9436, CurrentID=0, Status='live', Symbol='NCR2', Aliases=['CD336', 'LY95', 'NK-p44', 'NKP44', 'dJ149M18.1'], description='natural cytotoxicity triggering receptor 2', other_designations='natural cytotoxicity triggering receptor 2|NK cell activating receptor (NKp44)|NK cell-activating receptor|lymphocyte antigen 95 (activating NK-receptor; NK-p44)|lymphocyte antigen 95 homolog (activating NK-receptor; NK-p44)|natural killer cell p44-related protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41335608, end_position_on_the_genomic_accession=41350889, orientation='plus', exon_count=6, OMIM=[604531], no_hdr0=''),
    9437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9437, CurrentID=0, Status='live', Symbol='NCR1', Aliases=['CD335', 'LY94', 'NK-p46', 'NKP46'], description='natural cytotoxicity triggering receptor 1', other_designations='natural cytotoxicity triggering receptor 1|NK cell-activating receptor|lymphocyte antigen 94 homolog (activating NK-receptor; NK-p46)|natural killer cell p46-related protein', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54906063, end_position_on_the_genomic_accession=54938211, orientation='plus', exon_count=9, OMIM=[604530], no_hdr0=''),
    9439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9439, CurrentID=0, Status='live', Symbol='MED23', Aliases=['ARC130', 'CRSP130', 'CRSP133', 'CRSP3', 'DRIP130', 'MRT18', 'SUR-2', 'SUR2'], description='mediator complex subunit 23', other_designations='mediator of RNA polymerase II transcription subunit 23|130 kDa transcriptional co-activator|133 kDa transcriptional co-activator|activator-recruited cofactor 130 kDa component|cofactor required for Sp1 transcriptional activation subunit 3|mental retardation, non-syndromic, autosomal recessive, 18|vitamin D3 receptor interacting protein', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131573966, end_position_on_the_genomic_accession=131628313, orientation='minus', exon_count=35, OMIM=[605042], no_hdr0=''),
    9440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9440, CurrentID=0, Status='live', Symbol='MED17', Aliases=['CRSP6', 'CRSP77', 'DRIP80', 'SRB4', 'TRAP80'], description='mediator complex subunit 17', other_designations='mediator of RNA polymerase II transcription subunit 17|ARC77|CRSP complex subunit 6|activator-recruited cofactor 77 kDa component|cofactor required for Sp1 transcriptional activation, subunit 6, 77kDa|epididymis secretory sperm binding protein|thyroid hormone receptor-associated protein complex 80 kDa component|transcriptional coactivator CRSP77|vitamin D3 receptor-interacting protein complex 80 kDa component', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93784282, end_position_on_the_genomic_accession=93814963, orientation='plus', exon_count=12, OMIM=[603810], no_hdr0=''),
    9441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9441, CurrentID=0, Status='live', Symbol='MED26', Aliases=['CRSP7', 'CRSP70'], description='mediator complex subunit 26', other_designations='mediator of RNA polymerase II transcription subunit 26|ARC70|CRSP complex subunit 7|activator-recruited cofactor 70 kDa component|cofactor required for Sp1 transcriptional activation subunit 7|cofactor required for Sp1 transcriptional activation, subunit 7 (70kD)|cofactor required for Sp1 transcriptional activation, subunit 7, 70kDa|transcriptional coactivator CRSP70', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16574919, end_position_on_the_genomic_accession=16628204, orientation='minus', exon_count=3, OMIM=[605043], no_hdr0=''),
    9442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9442, CurrentID=0, Status='live', Symbol='MED27', Aliases=['CRAP34', 'CRSP34', 'CRSP8', 'MED3', 'NEDSCAC', 'TRAP37'], description='mediator complex subunit 27', other_designations='mediator of RNA polymerase II transcription subunit 27|CRSP complex subunit 8|cofactor required for Sp1 transcriptional activation, subunit 8, 34kDa|epididymis secretory sperm binding protein|p37 TRAP/SMCC/PC2 subunit|transcriptional coactivator CRSP34', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131860110, end_position_on_the_genomic_accession=132079867, orientation='minus', exon_count=11, OMIM=[605044], no_hdr0=''),
    9443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9443, CurrentID=0, Status='live', Symbol='MED7', Aliases=['ARC34', 'CRSP33', 'CRSP9'], description='mediator complex subunit 7', other_designations='mediator of RNA polymerase II transcription subunit 7|CRSP complex subunit 9|RNA polymerase transcriptional regulation mediator subunit 7 homolog|activator-recruited cofactor 34 kDa component|cofactor required for Sp1 transcriptional activation subunit 9|cofactor required for Sp1 transcriptional activation, subunit 9 (33kD)|cofactor required for Sp1 transcriptional activation, subunit 9, 33kDa|transcriptional coactivator CRSP33', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157137424, end_position_on_the_genomic_accession=157142865, orientation='minus', exon_count=3, OMIM=[605045], no_hdr0=''),
    9444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9444, CurrentID=0, Status='live', Symbol='QKI', Aliases=['Hqk', 'QK', 'QK1', 'QK3', 'hqkI'], description='QKI, KH domain containing RNA binding', other_designations='protein quaking|QKI/LOC100132735 fusion|RNA binding protein HQK|homolog of mouse quaking QKI (KH domain RNA binding protein)|quaking homolog, KH domain RNA binding', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=163414486, end_position_on_the_genomic_accession=163578592, orientation='plus', exon_count=8, OMIM=[609590], no_hdr0=''),
    9445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9445, CurrentID=0, Status='live', Symbol='ITM2B', Aliases=['ABRI', 'BRI', 'BRI2', 'BRICD2B', 'E25B', 'E3-16', 'FBD', 'RDGCA', 'imBRI2'], description='integral membrane protein 2B', other_designations='integral membrane protein 2B|ABri/ADan amyloid peptide|BRICHOS domain containing 2B|epididymis secretory sperm binding protein|immature BRI2|transmembrane protein BRI', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48233206, end_position_on_the_genomic_accession=48270357, orientation='plus', exon_count=6, OMIM=[603904], no_hdr0=''),
    9446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9446, CurrentID=0, Status='live', Symbol='GSTO1', Aliases=['GSTO 1-1', 'GSTTLp28', 'HEL-S-21', 'P28', 'SPG-R'], description='glutathione S-transferase omega 1', other_designations='glutathione S-transferase omega-1|MMA(V) reductase|S-(Phenacyl)glutathione reductase|epididymis secretory protein Li 21|glutathione S-transferase omega 1-1|glutathione-S-transferase like|glutathione-dependent dehydroascorbate reductase|monomethylarsonic acid reductase', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104254173, end_position_on_the_genomic_accession=104267455, orientation='plus', exon_count=7, OMIM=[605482], no_hdr0=''),
    9447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9447, CurrentID=0, Status='live', Symbol='AIM2', Aliases=['PYHIN4'], description='absent in melanoma 2', other_designations='interferon-inducible protein AIM2', map_location='1q23.1-q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159059226, end_position_on_the_genomic_accession=159132351, orientation='minus', exon_count=11, OMIM=[604578], no_hdr0=''),
    9448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9448, CurrentID=0, Status='live', Symbol='MAP4K4', Aliases=['FLH21957', 'HEL-S-31', 'HGK', 'MEKKK4', 'NIK'], description='mitogen-activated protein kinase kinase kinase kinase 4', other_designations='mitogen-activated protein kinase kinase kinase kinase 4|HPK/GCK-like kinase HGK|MAPK/ERK kinase kinase kinase 4|MEK kinase kinase 4|Ste20 group protein kinase HGK|epididymis secretory protein Li 31|hepatocyte progenitor kinase-like/germinal center kinase-like kinase|nck-interacting kinase', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101697707, end_position_on_the_genomic_accession=101894690, orientation='plus', exon_count=33, OMIM=[604666], no_hdr0=''),
    9450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9450, CurrentID=0, Status='live', Symbol='LY86', Aliases=['MD-1', 'MD1', 'MMD-1', 'dJ80N2.1'], description='lymphocyte antigen 86', other_designations='lymphocyte antigen 86|MD-1, RP105-associated|ly-86|protein MD-1', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=6588639, end_position_on_the_genomic_accession=6654982, orientation='plus', exon_count=5, OMIM=[605241], no_hdr0=''),
    9451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9451, CurrentID=0, Status='live', Symbol='EIF2AK3', Aliases=['PEK', 'PERK', 'WRS'], description='eukaryotic translation initiation factor 2 alpha kinase 3', other_designations='eukaryotic translation initiation factor 2-alpha kinase 3|PRKR-like endoplasmic reticulum kinase|pancreatic EIF2-alpha kinase|truncated eukaryotic translation initiation factor 2 alpha kinase 3', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88556741, end_position_on_the_genomic_accession=88627464, orientation='minus', exon_count=19, OMIM=[604032], no_hdr0=''),
    9452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9452, CurrentID=0, Status='live', Symbol='ITM2A', Aliases=['BRICD2A', 'E25A'], description='integral membrane protein 2A', other_designations='integral membrane protein 2A|BRICHOS domain containing 2A', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=79360384, end_position_on_the_genomic_accession=79367334, orientation='minus', exon_count=6, OMIM=[300222], no_hdr0=''),
    9453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9453, CurrentID=0, Status='live', Symbol='GGPS1', Aliases=['GGPPS', 'GGPPS1'], description='geranylgeranyl diphosphate synthase 1', other_designations='geranylgeranyl pyrophosphate synthase|(2E,6E)-farnesyl diphosphate synthase|GGPP synthase|GGPPSase|dimethylallyltranstransferase|farnesyl diphosphate synthase|farnesyltranstransferase|geranyltranstransferase', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235327216, end_position_on_the_genomic_accession=235344532, orientation='plus', exon_count=7, OMIM=[606982], no_hdr0=''),
    9454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9454, CurrentID=0, Status='live', Symbol='HOMER3', Aliases=['HOMER-3', 'VESL3'], description='homer scaffold protein 3', other_designations='homer protein homolog 3|Homer, neuronal immediate early gene, 3|homer homolog 3|homer scaffolding protein 3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18929201, end_position_on_the_genomic_accession=18941258, orientation='minus', exon_count=12, OMIM=[604800], no_hdr0=''),
    9455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9455, CurrentID=0, Status='live', Symbol='HOMER2', Aliases=['ACPD', 'CPD', 'DFNA68', 'HOMER-2', 'VESL-2'], description='homer scaffold protein 2', other_designations='homer protein homolog 2|cupidin|homer homolog 2|homer homolog 3|homer scaffolding protein 2|homer, neuronal immediate early gene, 2', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82836946, end_position_on_the_genomic_accession=82986176, orientation='minus', exon_count=14, OMIM=[604799], no_hdr0=''),
    9456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9456, CurrentID=0, Status='live', Symbol='HOMER1', Aliases=['HOMERA', 'HOMER1B', 'HOMER1C', 'SYN47', 'Ves-1', 'HOMER1'], description='homer scaffold protein 1', other_designations='homer protein homolog 1|homer homolog 1|homer scaffolding protein 1|homer, neuronal immediate early gene, 1|homer-1', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79372636, end_position_on_the_genomic_accession=79514134, orientation='minus', exon_count=10, OMIM=[604798], no_hdr0=''),
    9457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9457, CurrentID=0, Status='live', Symbol='FHL5', Aliases=['1700027G07Rik', 'ACT', 'FHL-5', 'dJ393D12.2'], description='four and a half LIM domains 5', other_designations='four and a half LIM domains protein 5|LIM protein ACT|activator of cAMP-responsive element modulator (CREM) in testis|activator of cAMP-responsive element modulator in testis', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96562574, end_position_on_the_genomic_accession=96618626, orientation='plus', exon_count=8, OMIM=[605126], no_hdr0=''),
    9459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9459, CurrentID=0, Status='live', Symbol='ARHGEF6', Aliases=['COOL2', 'Cool-2', 'MRX46', 'PIXA', 'alpha-PIX', 'alphaPIX'], description='Rac/Cdc42 guanine nucleotide exchange factor 6', other_designations='rho guanine nucleotide exchange factor 6|PAK-interacting exchange factor, alpha|Rac/Cdc42 guanine exchange factor (GEF) 6|Rac/Cdc42 guanine nucleotide exchange factor (GEF) 6', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136665547, end_position_on_the_genomic_accession=136780945, orientation='minus', exon_count=25, OMIM=[300267], no_hdr0=''),
    9462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9462, CurrentID=0, Status='live', Symbol='RASAL2', Aliases=['NGAP'], description='RAS protein activator like 2', other_designations='ras GTPase-activating protein nGAP|RASAL2/ACVR1 fusion|Ras protein activator like 1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=178093729, end_position_on_the_genomic_accession=178478879, orientation='plus', exon_count=23, OMIM=[606136], no_hdr0=''),
    9463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9463, CurrentID=0, Status='live', Symbol='PICK1', Aliases=['PICK', 'PRKCABP'], description='protein interacting with PRKCA 1', other_designations='PRKCA-binding protein|protein interacting with C kinase 1|protein kinase C-alpha-binding protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38056311, end_position_on_the_genomic_accession=38075704, orientation='plus', exon_count=14, OMIM=[605926], no_hdr0=''),
    9464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9464, CurrentID=0, Status='live', Symbol='HAND2', Aliases=['DHAND2', 'Hed', 'Thing2', 'bHLHa26', 'dHand'], description='heart and neural crest derivatives expressed 2', other_designations='heart- and neural crest derivatives-expressed protein 2|basic helix-loop-helix transcription factor HAND2|class A basic helix-loop-helix protein 26|deciduum, heart, autonomic nervous system and neural crest derivatives-expressed protein 2', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=173526091, end_position_on_the_genomic_accession=173530229, orientation='minus', exon_count=2, OMIM=[602407], no_hdr0=''),
    9465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9465, CurrentID=0, Status='live', Symbol='AKAP7', Aliases=['AKAP15', 'AKAP18'], description='A-kinase anchoring protein 7', other_designations='A-kinase anchoring protein 7|A kinase (PRKA) anchor protein 7|A-kinase anchor protein 18 kDa|A-kinase anchor protein 9 kDa|AKAP 18', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131125698, end_position_on_the_genomic_accession=131283534, orientation='plus', exon_count=24, OMIM=[604693], no_hdr0=''),
    9466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9466, CurrentID=0, Status='live', Symbol='IL27RA', Aliases=['CRL1', 'IL-27RA', 'IL27R', 'TCCR', 'WSX1', 'zcytor1'], description='interleukin 27 receptor subunit alpha', other_designations='interleukin-27 receptor subunit alpha|IL-27 receptor subunit alpha|IL-27R subunit alpha|IL-27R-alpha|T-cell cytokine receptor type 1|class I cytokine receptor|cytokine receptor WSX-1|cytokine receptor-like 1|interleukin 27 receptor, alpha|type I T-cell cytokine receptor', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14031762, end_position_on_the_genomic_accession=14053218, orientation='plus', exon_count=14, OMIM=[605350], no_hdr0=''),
    9467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9467, CurrentID=0, Status='live', Symbol='SH3BP5', Aliases=['SAB', 'SH3BP-5'], description='SH3 domain binding protein 5', other_designations='SH3 domain-binding protein 5|SH3 domain-binding protein that preferentially associates with BTK|SH3-domain binding protein 5 (BTK-associated)', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15254353, end_position_on_the_genomic_accession=15341380, orientation='minus', exon_count=14, OMIM=[605612], no_hdr0=''),
    9468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9468, CurrentID=0, Status='live', Symbol='PCYT1B', Aliases=['CCTB', 'CTB'], description='phosphate cytidylyltransferase 1B, choline', other_designations='choline-phosphate cytidylyltransferase B|CCT B|CCT-beta|CT B|CTP:phosphocholine cytidylyltransferase b|CTP:phosphocholine cytidylyltransferase-beta|choline-phosphate cytidylyltransferase beta|phosphate cytidylyltransferase 1, choline, beta|phosphorylcholine transferase B|phosphorylcholine transferase beta', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24558087, end_position_on_the_genomic_accession=24672887, orientation='minus', exon_count=10, OMIM=[300948], no_hdr0=''),
    9469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9469, CurrentID=0, Status='live', Symbol='CHST3', Aliases=['C6ST', 'C6ST1', 'HSD'], description='carbohydrate sulfotransferase 3', other_designations='carbohydrate sulfotransferase 3|C6ST-1|GST-0|carbohydrate (chondroitin 6) sulfotransferase 3|chondroitin 6 sulfotransferase 1|chondroitin 6-O-sulfotransferase 1|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 0', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71964395, end_position_on_the_genomic_accession=72013562, orientation='plus', exon_count=5, OMIM=[603799], no_hdr0=''),
    9470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9470, CurrentID=0, Status='live', Symbol='EIF4E2', Aliases=['4E-LP', '4EHP', 'EIF4EL3', 'IF4e', 'h4EHP'], description='eukaryotic translation initiation factor 4E family member 2', other_designations='eukaryotic translation initiation factor 4E type 2|eIF-4E type 2|eIF4E-like cap-binding protein|eIF4E-like protein 4E-LP|eukaryotic translation initiation factor 4E homologous protein|eukaryotic translation initiation factor 4E-like 3|mRNA cap-binding protein type 3', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232550689, end_position_on_the_genomic_accession=232583644, orientation='plus', exon_count=10, OMIM=[605895], no_hdr0=''),
    9472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9472, CurrentID=0, Status='live', Symbol='AKAP6', Aliases=['ADAP100', 'ADAP6', 'AKAP100', 'PRKA6', 'mAKAP'], description='A-kinase anchoring protein 6', other_designations='A-kinase anchor protein 6|A kinase (PRKA) anchor protein 6|A-kinase anchor protein 100 kDa|AKAP 100|AKAP-6|protein kinase A anchoring protein 6', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=32203610, end_position_on_the_genomic_accession=32837684, orientation='plus', exon_count=24, OMIM=[604691], no_hdr0=''),
    9473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9473, CurrentID=0, Status='live', Symbol='THEMIS2', Aliases=['C1orf38', 'ICB-1', 'ICB1'], description='thymocyte selection associated family member 2', other_designations='protein THEMIS2|basement membrane-induced|induced by contact to basement membrane 1 protein|protein ICB-1|thymocyte-expressed molecule involved in selection protein 2', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27872531, end_position_on_the_genomic_accession=27886679, orientation='plus', exon_count=6, OMIM=[617856], no_hdr0=''),
    9474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9474, CurrentID=0, Status='live', Symbol='ATG5', Aliases=['APG5', 'APG5-LIKE', 'APG5L', 'ASP', 'SCAR25', 'hAPG5'], description='autophagy related 5', other_designations='autophagy protein 5|APG5 autophagy 5-like|ATG5 autophagy related 5 homolog|apoptosis-specific protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106184476, end_position_on_the_genomic_accession=106325789, orientation='minus', exon_count=10, OMIM=[604261], no_hdr0=''),
    9475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9475, CurrentID=0, Status='live', Symbol='ROCK2', Aliases=['ROCK-II'], description='Rho associated coiled-coil containing protein kinase 2', other_designations='rho-associated protein kinase 2|p164 ROCK-2|rho-associated, coiled-coil-containing protein kinase II', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11179759, end_position_on_the_genomic_accession=11345437, orientation='minus', exon_count=37, OMIM=[604002], no_hdr0=''),
    9476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9476, CurrentID=0, Status='live', Symbol='NAPSA', Aliases=['KAP', 'Kdap', 'NAP1', 'NAPA', 'SNAPA'], description='napsin A aspartic peptidase', other_designations='napsin-A|ASP4|TA01/TA02|asp 4|aspartyl protease 4|kidney-derived aspartic protease-like protein|napsin-1|pronapsin A', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50358472, end_position_on_the_genomic_accession=50369331, orientation='minus', exon_count=10, OMIM=[605631], no_hdr0=''),
    9477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9477, CurrentID=0, Status='live', Symbol='MED20', Aliases=['PRO0213', 'SRB2', 'TRFP'], description='mediator complex subunit 20', other_designations='mediator of RNA polymerase II transcription subunit 20|Trf (TATA binding protein-related factor)-proximal homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41905354, end_position_on_the_genomic_accession=41921139, orientation='minus', exon_count=6, OMIM=[612915], no_hdr0=''),
    9478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9478, CurrentID=0, Status='live', Symbol='CABP1', Aliases=['CALBRAIN', 'HCALB_BR'], description='calcium binding protein 1', other_designations='calcium-binding protein 1|calcium binding protein 5|caldendrin', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120640552, end_position_on_the_genomic_accession=120680869, orientation='plus', exon_count=9, OMIM=[605563], no_hdr0=''),
    9479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9479, CurrentID=0, Status='live', Symbol='MAPK8IP1', Aliases=['IB1', 'JIP-1', 'JIP1', 'PRKM8IP'], description='mitogen-activated protein kinase 8 interacting protein 1', other_designations='C-Jun-amino-terminal kinase-interacting protein 1|IB-1|JNK MAP kinase scaffold protein 1|JNK-interacting protein 1|PRKM8 interacting protein|islet-brain 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45885651, end_position_on_the_genomic_accession=45906465, orientation='plus', exon_count=12, OMIM=[604641], no_hdr0=''),
    9480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9480, CurrentID=0, Status='live', Symbol='ONECUT2', Aliases=['OC-2', 'OC2'], description='one cut homeobox 2', other_designations='one cut domain family member 2|HNF-6-beta|ONECUT-2 homeodomain transcription factor|hepatocyte nuclear factor 6-beta|onecut 2|transcription factor ONECUT-2', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57435374, end_position_on_the_genomic_accession=57491298, orientation='plus', exon_count=2, OMIM=[604894], no_hdr0=''),
    9481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9481, CurrentID=0, Status='live', Symbol='SLC25A27', Aliases=['UCP4'], description='solute carrier family 25 member 27', other_designations='mitochondrial uncoupling protein 4|UCP 4|uncoupling protein 4', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46652945, end_position_on_the_genomic_accession=46678190, orientation='plus', exon_count=9, OMIM=[613725], no_hdr0=''),
    9482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9482, CurrentID=0, Status='live', Symbol='STX8', Aliases=['CARB'], description='syntaxin 8', other_designations='syntaxin-8|CIP-1-associated regulator of cyclin B', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9250471, end_position_on_the_genomic_accession=9575894, orientation='minus', exon_count=10, OMIM=[604203], no_hdr0=''),
    9486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9486, CurrentID=0, Status='live', Symbol='CHST10', Aliases=['HNK-1ST', 'HNK1ST'], description='carbohydrate sulfotransferase 10', other_designations='carbohydrate sulfotransferase 10|HNK-1 sulfotransferase|huHNK-1ST', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=100391860, end_position_on_the_genomic_accession=100417668, orientation='minus', exon_count=11, OMIM=[606376], no_hdr0=''),
    9487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9487, CurrentID=0, Status='live', Symbol='PIGL', Aliases=['CHIME'], description='phosphatidylinositol glycan anchor biosynthesis class L', other_designations='N-acetylglucosaminyl-phosphatidylinositol de-N-acetylase|N-acetylglucosaminylphosphatidylinositol deacetylase|PIG-L|phosphatidylinositol glycan, class L|phosphatidylinositol-glycan biosynthesis class L protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16217209, end_position_on_the_genomic_accession=16351800, orientation='plus', exon_count=10, OMIM=[605947], no_hdr0=''),
    9488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9488, CurrentID=0, Status='live', Symbol='PIGB', Aliases=['DEE80', 'EIEE80', 'GPI-MT-III', 'PIG-B'], description='phosphatidylinositol glycan anchor biosynthesis class B', other_designations='GPI mannosyltransferase 3|GPI mannosyltransferase III|dol-P-Man dependent GPI mannosyltransferase|phosphatidylinositol glycan, class B|phosphatidylinositol-glycan biosynthesis class B protein', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55318939, end_position_on_the_genomic_accession=55355648, orientation='plus', exon_count=15, OMIM=[604122], no_hdr0=''),
    9489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9489, CurrentID=0, Status='live', Symbol='PGS1', Aliases=[], description='phosphatidylglycerophosphate synthase 1', other_designations='CDP-diacylglycerol--glycerol-3-phosphate 3-phosphatidyltransferase, mitochondrial|PGP synthase 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78378623, end_position_on_the_genomic_accession=78424659, orientation='plus', exon_count=12, OMIM=[614942], no_hdr0=''),
    9491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9491, CurrentID=0, Status='live', Symbol='PSMF1', Aliases=['PI31'], description='proteasome inhibitor subunit 1', other_designations='proteasome inhibitor PI31 subunit|proteasome (prosome, macropain) inhibitor subunit 1 (PI31)', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1113263, end_position_on_the_genomic_accession=1172246, orientation='plus', exon_count=8, OMIM=[617858], no_hdr0=''),
    9493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9493, CurrentID=0, Status='live', Symbol='KIF23', Aliases=['CHO1', 'KNSL5', 'MKLP-1', 'MKLP1'], description='kinesin family member 23', other_designations='kinesin-like protein KIF23|kinesin-like 5 (mitotic kinesin-like protein 1)', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=69414325, end_position_on_the_genomic_accession=69448427, orientation='plus', exon_count=25, OMIM=[605064], no_hdr0=''),
    9495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9495, CurrentID=0, Status='live', Symbol='AKAP5', Aliases=['AKAP75', 'AKAP79', 'H21'], description='A-kinase anchoring protein 5', other_designations='A-kinase anchor protein 5|A kinase (PRKA) anchor protein 5|A-kinase anchor protein 79 kDa|A-kinase anchoring protein 75/79|AKAP 79|cAMP-dependent protein kinase regulatory subunit II high affinity-binding protein', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64465499, end_position_on_the_genomic_accession=64474503, orientation='plus', exon_count=2, OMIM=[604688], no_hdr0=''),
    9496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9496, CurrentID=0, Status='live', Symbol='TBX4', Aliases=['ICPPS', 'PAPPAS', 'SPS'], description='T-box transcription factor 4', other_designations='T-box transcription factor TBX4|T-box 4|T-box protein 4', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61452422, end_position_on_the_genomic_accession=61485110, orientation='plus', exon_count=11, OMIM=[601719], no_hdr0=''),
    9497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9497, CurrentID=0, Status='live', Symbol='SLC4A7', Aliases=['NBC2', 'NBC3', 'NBCN1', 'SBC2', 'SLC4A6'], description='solute carrier family 4 member 7', other_designations='sodium bicarbonate cotransporter 3|bicarbonate transporter|electroneutral Na/HCO(3) cotransporter|sodium bicarbonate cotransporter 2|sodium bicarbonate cotransporter 2b|solute carrier family 4, sodium bicarbonate cotransporter, member 7', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=27372721, end_position_on_the_genomic_accession=27484420, orientation='minus', exon_count=28, OMIM=[603353], no_hdr0=''),
    9498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9498, CurrentID=0, Status='live', Symbol='SLC4A8', Aliases=['NBC3', 'NDCBE'], description='solute carrier family 4 member 8', other_designations='electroneutral sodium bicarbonate exchanger 1|electroneutral Na(+)-driven Cl-HCO3 exchanger|k-NBC3|solute carrier family 4, sodium bicarbonate cotransporter, member 8', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51391317, end_position_on_the_genomic_accession=51515763, orientation='plus', exon_count=33, OMIM=[605024], no_hdr0=''),
    9499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9499, CurrentID=0, Status='live', Symbol='MYOT', Aliases=['LGMD1', 'LGMD1A', 'MFM3', 'TTID', 'TTOD'], description='myotilin', other_designations='myotilin|57 kDa cytoskeletal protein|myofibrillar titin-like Ig domains protein|titin immunoglobulin domain protein (myotilin)', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=137867282, end_position_on_the_genomic_accession=137887851, orientation='plus', exon_count=11, OMIM=[604103], no_hdr0=''),
    9500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9500, CurrentID=0, Status='live', Symbol='MAGED1', Aliases=['DLXIN-1', 'NRAGE'], description='MAGE family member D1', other_designations='melanoma-associated antigen D1|MAGE tumor antigen CCF|MAGE-D1 antigen|melanoma antigen family D, 1|melanoma antigen family D1|neurotrophin receptor-interacting MAGE homolog', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51802998, end_position_on_the_genomic_accession=51902354, orientation='plus', exon_count=18, OMIM=[300224], no_hdr0=''),
    9501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9501, CurrentID=0, Status='live', Symbol='RPH3AL', Aliases=['NOC2'], description='rabphilin 3A like (without C2 domains)', other_designations='rab effector Noc2|no C2 domains protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=212389, end_position_on_the_genomic_accession=352807, orientation='minus', exon_count=10, OMIM=[604881], no_hdr0=''),
    9502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9502, CurrentID=0, Status='live', Symbol='XAGE2', Aliases=['CT12.2', 'GAGED3', 'XAGE-2B', 'XAGE2'], description='X antigen family member 2', other_designations='X antigen family member 2|G antigen family D member 3|X antigen family, member 2B|cancer/testis antigen 12.2|cancer/testis antigen family 12, member 2', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52368996, end_position_on_the_genomic_accession=52375683, orientation='plus', exon_count=5, OMIM=[300416], no_hdr0=''),
    9506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9506, CurrentID=0, Status='live', Symbol='PAGE4', Aliases=['CT16.7', 'GAGE-9', 'GAGEC1', 'JM-27', 'JM27', 'PAGE-1', 'PAGE-4'], description='PAGE family member 4', other_designations='P antigen family member 4|P antigen family, member 4 (prostate associated)|g antigen family C member 1|prostate-associated gene protein 4', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49829260, end_position_on_the_genomic_accession=49834264, orientation='plus', exon_count=6, OMIM=[300287], no_hdr0=''),
    9507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9507, CurrentID=0, Status='live', Symbol='ADAMTS4', Aliases=['ADAMTS-2', 'ADAMTS-4', 'ADMP-1'], description='ADAM metallopeptidase with thrombospondin type 1 motif 4', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 4|ADAM-TS 4|ADAM-TS4|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 4|aggrecanase-1|epididymis secretory sperm binding protein', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161184302, end_position_on_the_genomic_accession=161202339, orientation='minus', exon_count=10, OMIM=[603876], no_hdr0=''),
    9508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9508, CurrentID=0, Status='live', Symbol='ADAMTS3', Aliases=['ADAMTS-4', 'HKLLS3'], description='ADAM metallopeptidase with thrombospondin type 1 motif 3', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 3|ADAM-TS 3|ADAM-TS3|ADAMTS-3|PC II-NP|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 3|procollagen II N-proteinase|procollagen II amino propeptide-processing enzyme|zinc metalloendopeptidase', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=72280969, end_position_on_the_genomic_accession=72569221, orientation='minus', exon_count=24, OMIM=[605011], no_hdr0=''),
    9509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9509, CurrentID=0, Status='live', Symbol='ADAMTS2', Aliases=['ADAM-TS2', 'ADAMTS-2', 'ADAMTS-3', 'EDSDERMS', 'NPI', 'PC I-NP', 'PCI-NP', 'PCINP', 'PCPNI', 'PNPI'], description='ADAM metallopeptidase with thrombospondin type 1 motif 2', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 2|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 2|procollagen I N-proteinase|procollagen I/II amino propeptide-processing enzyme|procollagen N-endopeptidase', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179110853, end_position_on_the_genomic_accession=179345461, orientation='minus', exon_count=23, OMIM=[604539], no_hdr0=''),
    9510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9510, CurrentID=0, Status='live', Symbol='ADAMTS1', Aliases=['C3-C5', 'METH1'], description='ADAM metallopeptidase with thrombospondin type 1 motif 1', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 1|ADAM-TS 1|ADAM-TS1|ADAMTS-1|METH-1|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 1|human metalloproteinase with thrombospondin type 1 motifs', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=26835755, end_position_on_the_genomic_accession=26845409, orientation='minus', exon_count=9, OMIM=[605174], no_hdr0=''),
    9512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9512, CurrentID=0, Status='live', Symbol='PMPCB', Aliases=['Beta-MPP', 'MAS1', 'MPP11', 'MPPB', 'MPPP52', 'P-52'], description='peptidase, mitochondrial processing subunit beta', other_designations='mitochondrial-processing peptidase subunit beta|mitochondrial processing peptidase beta subunit|peptidase (mitochondrial processing) beta|peptidase, mitochondrial processing beta subunit', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103297435, end_position_on_the_genomic_accession=103329902, orientation='plus', exon_count=14, OMIM=[603131], no_hdr0=''),
    9513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9513, CurrentID=0, Status='live', Symbol='FXR2', Aliases=['FMR1L2P', 'FXR2'], description='FMR1 autosomal homolog 2', other_designations='fragile X mental retardation syndrome-related protein 2|fragile X mental retardation, autosomal homolog 2|fragile X-mental retardation 1-like 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7591230, end_position_on_the_genomic_accession=7614897, orientation='minus', exon_count=18, OMIM=[605339], no_hdr0=''),
    9514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9514, CurrentID=0, Status='live', Symbol='GAL3ST1', Aliases=['CST'], description='galactose-3-O-sulfotransferase 1', other_designations="galactosylceramide sulfotransferase|3'-phosphoadenosine-5'-phosphosulfate:GalCer sulfotransferase|cerebroside (3'-phosphoadenylylsulfate:galactosylceramide 3') sulfotransferase", map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30554635, end_position_on_the_genomic_accession=30574665, orientation='minus', exon_count=9, OMIM=[602300], no_hdr0=''),
    9515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9515, CurrentID=0, Status='live', Symbol='STXBP5L', Aliases=['LLGL4'], description='syntaxin binding protein 5L', other_designations='syntaxin-binding protein 5-like|lethal(2) giant larvae protein homolog 4|syntaxin binding protein 5 like|tomosyn-2|tomosyn-like', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120908205, end_position_on_the_genomic_accession=121424761, orientation='plus', exon_count=35, OMIM=[609381], no_hdr0=''),
    9516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9516, CurrentID=0, Status='live', Symbol='LITAF', Aliases=['PIG7', 'SIMPLE', 'TP53I7'], description='lipopolysaccharide induced TNF factor', other_designations='lipopolysaccharide-induced tumor necrosis factor-alpha factor|LPS-induced TNF-alpha factor|lipopolysaccharide-induced TNF-alpha factor|p53-induced gene 7 protein|small integral membrane protein of lysosome/late endosome|tumor protein p53 inducible protein 7', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11547722, end_position_on_the_genomic_accession=11636377, orientation='minus', exon_count=15, OMIM=[603795], no_hdr0=''),
    9517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9517, CurrentID=0, Status='live', Symbol='SPTLC2', Aliases=['HSN1C', 'LCB2', 'LCB2A', 'NSAN1C', 'SPT2', 'hLCB2a'], description='serine palmitoyltransferase long chain base subunit 2', other_designations='serine palmitoyltransferase 2|LCB 2|SPT 2|long chain base biosynthesis protein 2a|serine palmitoyltransferase, subunit II|serine-palmitoyl-CoA transferase 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77505997, end_position_on_the_genomic_accession=77616663, orientation='minus', exon_count=13, OMIM=[605713], no_hdr0=''),
    9518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9518, CurrentID=0, Status='live', Symbol='GDF15', Aliases=['GDF-15', 'MIC-1', 'MIC1', 'NAG-1', 'PDF', 'PLAB', 'PTGFB'], description='growth differentiation factor 15', other_designations='growth/differentiation factor 15|NRG-1|NSAID (nonsteroidal anti-inflammatory drug)-activated protein 1|NSAID-activated gene 1 protein|NSAID-regulated gene 1 protein|PTGF-beta|macrophage inhibitory cytokine 1|non-steroidal anti-inflammatory drug-activated gene-1|placental TGF-beta|placental bone morphogenetic protein|prostate differentiation factor', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18382170, end_position_on_the_genomic_accession=18389176, orientation='plus', exon_count=3, OMIM=[605312], no_hdr0=''),
    9519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9519, CurrentID=0, Status='live', Symbol='TBPL1', Aliases=['MGC:8389', 'MGC:9620', 'STUD', 'TLF', 'TLP', 'TRF2'], description='TATA-box binding protein like 1', other_designations='TATA box-binding protein-like 1|21-kDA TBP-like protein|TATA box-binding protein-like protein 1|TATA box-binding protein-related factor 2|TBP-like 1|TBP-related factor 2|TBP-related protein|second TBP of unique DNA protein', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=133952174, end_position_on_the_genomic_accession=133990432, orientation='plus', exon_count=9, OMIM=[605521], no_hdr0=''),
    9520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9520, CurrentID=0, Status='live', Symbol='NPEPPS', Aliases=['AAP-S', 'MP100', 'PSA'], description='aminopeptidase puromycin sensitive', other_designations='puromycin-sensitive aminopeptidase|cytosol alanyl aminopeptidase|metalloproteinase MP100', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47522933, end_position_on_the_genomic_accession=47623276, orientation='plus', exon_count=26, OMIM=[606793], no_hdr0=''),
    9521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9521, CurrentID=0, Status='live', Symbol='EEF1E1', Aliases=['AIMP3', 'P18'], description='eukaryotic translation elongation factor 1 epsilon 1', other_designations='eukaryotic translation elongation factor 1 epsilon-1|ARS-interacting multifunctional protein 3|aminoacyl tRNA synthetase complex-interacting multifunctional protein 3|multisynthase complex auxiliary component p18|p18 component of aminoacyl-tRNA synthetase complex', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=8073360, end_position_on_the_genomic_accession=8102548, orientation='minus', exon_count=5, OMIM=[609206], no_hdr0=''),
    9522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9522, CurrentID=0, Status='live', Symbol='SCAMP1', Aliases=['SCAMP', 'SCAMP37'], description='secretory carrier membrane protein 1', other_designations='secretory carrier-associated membrane protein 1', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=78360530, end_position_on_the_genomic_accession=78480739, orientation='plus', exon_count=9, OMIM=[606911], no_hdr0=''),
    9524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9524, CurrentID=0, Status='live', Symbol='TECR', Aliases=['GPSN2', 'MRT14', 'SC2', 'TER'], description='trans-2,3-enoyl-CoA reductase', other_designations='very-long-chain enoyl-CoA reductase|epididymis secretory sperm binding protein|glycoprotein, synaptic 2|synaptic glycoprotein SC2', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14527752, end_position_on_the_genomic_accession=14565980, orientation='plus', exon_count=16, OMIM=[610057], no_hdr0=''),
    9525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9525, CurrentID=0, Status='live', Symbol='VPS4B', Aliases=['MIG1', 'SKD1', 'SKD1B', 'VPS4-2'], description='vacuolar protein sorting 4 homolog B', other_designations='vacuolar protein sorting-associated protein 4B|cell migration-inducing 1|cell migration-inducing gene 1 protein|suppressor of K(+) transport growth defect 1|suppressor of K+ transport defect 1|vacuolar protein sorting 4B', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63389190, end_position_on_the_genomic_accession=63422495, orientation='minus', exon_count=12, OMIM=[609983], no_hdr0=''),
    9526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9526, CurrentID=0, Status='live', Symbol='MPDU1', Aliases=['CDGIF', 'HBEBP2BPA', 'Lec35', 'My008', 'PP3958', 'PQLC5', 'SL15', 'SLC66A5'], description='mannose-P-dolichol utilization defect 1', other_designations='mannose-P-dolichol utilization defect 1 protein|HBeAg-binding protein 2 binding protein A|suppressor of Lec15 and Lec35 glycosylation mutation homolog', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7583647, end_position_on_the_genomic_accession=7588212, orientation='plus', exon_count=7, OMIM=[604041], no_hdr0=''),
    9527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9527, CurrentID=0, Status='live', Symbol='GOSR1', Aliases=['GOLIM2', 'GOS-28', 'GOS28', 'GOS28/P28', 'GS28', 'P28'], description='golgi SNAP receptor complex member 1', other_designations='Golgi SNAP receptor complex member 1|28 kDa Golgi SNARE protein|28 kDa cis-Golgi SNARE p28|Golgi SNARE 28 kDa|cis-golgi SNARE|golgi integral membrane protein 2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30477402, end_position_on_the_genomic_accession=30527592, orientation='plus', exon_count=10, OMIM=[604026], no_hdr0=''),
    9528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9528, CurrentID=0, Status='live', Symbol='TMEM59', Aliases=['C1orf8', 'DCF1', 'HSPC001', 'PRO195', 'UNQ169'], description='transmembrane protein 59', other_designations='transmembrane protein 59|dendritic cell factor 1|liver membrane-bound protein', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54026681, end_position_on_the_genomic_accession=54053573, orientation='minus', exon_count=9, OMIM=[617084], no_hdr0=''),
    9529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9529, CurrentID=0, Status='live', Symbol='BAG5', Aliases=['BAG-5'], description='BAG cochaperone 5', other_designations='BAG family molecular chaperone regulator 5|BCL2 associated athanogene 5|bcl-2-associated athanogene 5', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103556551, end_position_on_the_genomic_accession=103562657, orientation='minus', exon_count=3, OMIM=[603885], no_hdr0=''),
    9530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9530, CurrentID=0, Status='live', Symbol='BAG4', Aliases=['BAG-4', 'SODD'], description='BAG cochaperone 4', other_designations='BAG family molecular chaperone regulator 4|BCL2 associated athanogene 4|bcl-2-associated athanogene 4|silencer of death domains', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38176855, end_position_on_the_genomic_accession=38213301, orientation='plus', exon_count=5, OMIM=[603884], no_hdr0=''),
    9531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9531, CurrentID=0, Status='live', Symbol='BAG3', Aliases=['BAG-3', 'BIS', 'CAIR-1', 'MFM6'], description='BAG cochaperone 3', other_designations='BAG family molecular chaperone regulator 3|BCL2 associated athanogene 3|BCL2-binding athanogene 3|Bcl-2-binding protein BIS transcript 2|bcl-2-binding protein Bis|docking protein CAIR-1', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119651380, end_position_on_the_genomic_accession=119677819, orientation='plus', exon_count=4, OMIM=[603883], no_hdr0=''),
    9532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9532, CurrentID=0, Status='live', Symbol='BAG2', Aliases=['BAG-2', 'dJ417I1.2'], description='BAG cochaperone 2', other_designations='BAG family molecular chaperone regulator 2|BCL2 associated athanogene 2|bcl-2-associated athanogene 2|dJ417I1.2 (BAG-family molecular chaperone regulator 2)', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=57172326, end_position_on_the_genomic_accession=57189833, orientation='plus', exon_count=5, OMIM=[603882], no_hdr0=''),
    9533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9533, CurrentID=0, Status='live', Symbol='POLR1C', Aliases=['AC40', 'HLD11', 'RPA39', 'RPA40', 'RPA5', 'RPAC1', 'RPC40', 'TCS3'], description='RNA polymerase I and III subunit C', other_designations='DNA-directed RNA polymerases I and III subunit RPAC1|DNA-directed RNA polymerase I subunit C|DNA-directed RNA polymerases I and III 40 kDa polypeptide|RNA polymerase I subunit C|RNA polymerases I and III subunit AC1|polymerase (RNA) I polypeptide C, 30kDa|polymerase (RNA) I subunit C', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43517089, end_position_on_the_genomic_accession=44461400, orientation='plus', exon_count=14, OMIM=[610060], no_hdr0=''),
    9534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9534, CurrentID=0, Status='live', Symbol='ZNF254', Aliases=['BMZF-5', 'HD-ZNF1', 'ZNF539', 'ZNF91L'], description='zinc finger protein 254', other_designations='zinc finger protein 254|CTD-2017D11.1|bone marrow zinc finger 5|hematopoietic cell-derived zinc finger protein 1|zinc finger protein 539', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=24033416, end_position_on_the_genomic_accession=24129968, orientation='plus', exon_count=12, OMIM=[604768], no_hdr0=''),
    9535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9535, CurrentID=0, Status='live', Symbol='GMFG', Aliases=['GMF-GAMMA'], description='glia maturation factor gamma', other_designations='glia maturation factor gamma', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39328359, end_position_on_the_genomic_accession=39336043, orientation='minus', exon_count=7, OMIM=[604104], no_hdr0=''),
    9536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9536, CurrentID=0, Status='live', Symbol='PTGES', Aliases=['MGST-IV', 'MGST1-L1', 'MGST1L1', 'MPGES', 'PGES', 'PIG12', 'PP102', 'PP1294', 'TP53I12', 'mPGES-1'], description='prostaglandin E synthase', other_designations='prostaglandin E synthase|MGST1-like 1|glutathione S-transferase 1-like 1|glutathione peroxidase PTGES|glutathione transferase PTGES|microsomal glutathione S-transferase 1-like 1|microsomal prostaglandin E synthase-1|p53-induced apoptosis protein 12|p53-induced gene 12 protein|tumor protein p53 inducible protein 12', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129738349, end_position_on_the_genomic_accession=129753042, orientation='minus', exon_count=3, OMIM=[605172], no_hdr0=''),
    9537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9537, CurrentID=0, Status='live', Symbol='TP53I11', Aliases=['PIG11'], description='tumor protein p53 inducible protein 11', other_designations='tumor protein p53-inducible protein 11|p53-induced gene 11 protein', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44932348, end_position_on_the_genomic_accession=44951306, orientation='minus', exon_count=13, OMIM=[617867], no_hdr0=''),
    9538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9538, CurrentID=0, Status='live', Symbol='EI24', Aliases=['EPG4', 'PIG8', 'TP53I8'], description='EI24 autophagy associated transmembrane protein', other_designations='etoposide-induced protein 2.4 homolog|ectopic P-granules autophagy protein 4 homolog|etoposide induced 2.4|p53-induced gene 8 protein|tumor protein p53 inducible protein 8', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125569216, end_position_on_the_genomic_accession=125584684, orientation='plus', exon_count=13, OMIM=[605170], no_hdr0=''),
    9540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9540, CurrentID=0, Status='live', Symbol='TP53I3', Aliases=['PIG3'], description='tumor protein p53 inducible protein 3', other_designations='quinone oxidoreductase PIG3|p53-induced gene 3 protein|quinone oxidoreductase homolog', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24077428, end_position_on_the_genomic_accession=24085767, orientation='minus', exon_count=6, OMIM=[605171], no_hdr0=''),
    9541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9541, CurrentID=0, Status='live', Symbol='CIR1', Aliases=['CIR'], description='corepressor interacting with RBPJ, CIR1', other_designations='corepressor interacting with RBPJ 1|CBF1 (RBPJ) interacting corepressor 1|CBF1-interacting corepressor|corepressor interacting with RBPJ, 1|recepin', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174348022, end_position_on_the_genomic_accession=174395712, orientation='minus', exon_count=10, OMIM=[605228], no_hdr0=''),
    9542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9542, CurrentID=0, Status='live', Symbol='NRG2', Aliases=['DON1', 'HRG2', 'NTAK'], description='neuregulin 2', other_designations='pro-neuregulin-2, membrane-bound isoform|divergent of neuregulin-1|neural- and thymus-derived activator for ErbB kinases|pro-NRG2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139846781, end_position_on_the_genomic_accession=140043675, orientation='minus', exon_count=15, OMIM=[603818], no_hdr0=''),
    9543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9543, CurrentID=0, Status='live', Symbol='IGDCC3', Aliases=['HsT18880', 'PUNC'], description='immunoglobulin superfamily DCC subclass member 3', other_designations='immunoglobulin superfamily DCC subclass member 3|putative neuronal cell adhesion molecule', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65327127, end_position_on_the_genomic_accession=65378002, orientation='minus', exon_count=16, OMIM=[604184], no_hdr0=''),
    9545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9545, CurrentID=0, Status='live', Symbol='RAB3D', Aliases=['D2-2', 'GOV', 'RAB16', 'RAD3D'], description='RAB3D, member RAS oncogene family', other_designations='ras-related protein Rab-3D|Rab3D upregulated with myeloid differentiation|epididymis secretory sperm binding protein|glioblastoma overexpressed', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11322068, end_position_on_the_genomic_accession=11339657, orientation='minus', exon_count=5, OMIM=[604350], no_hdr0=''),
    9546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9546, CurrentID=0, Status='live', Symbol='APBA3', Aliases=['MGC:15815', 'X11L2', 'mint3'], description='amyloid beta precursor protein binding family A member 3', other_designations='amyloid-beta A4 precursor protein-binding family A member 3|X11-like 2 protein|adapter protein X11gamma|amyloid beta (A4) precursor protein-binding, family A, member 3 (X11-like 2)|mint-3|neuron-specific X11L2 protein|neuronal munc18-1-interacting protein 3|phosphotyrosine-binding/-interacting domain (PTB)-bearing protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3750772, end_position_on_the_genomic_accession=3761696, orientation='minus', exon_count=10, OMIM=[604262], no_hdr0=''),
    9547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9547, CurrentID=0, Status='live', Symbol='CXCL14', Aliases=['BMAC', 'BRAK', 'KEC', 'KS1', 'MIP-2g', 'MIP2G', 'NJAC', 'SCYB14'], description='C-X-C motif chemokine ligand 14', other_designations='C-X-C motif chemokine 14|CXC chemokine in breast and kidney|MIP-2 gamma|bolekine|breast and kidney|chemokine (C-X-C motif) ligand 14|chemokine BRAK|small inducible cytokine subfamily B (Cys-X-Cys), member 14 (BRAK)|small-inducible cytokine B14|tumor-suppressing chemokine', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135570679, end_position_on_the_genomic_accession=135578991, orientation='minus', exon_count=4, OMIM=[604186], no_hdr0=''),
    9550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9550, CurrentID=0, Status='live', Symbol='ATP6V1G1', Aliases=['ATP6G', 'ATP6G1', 'ATP6GL', 'ATP6J', 'Vma10'], description='ATPase H+ transporting V1 subunit G1', other_designations='V-type proton ATPase subunit G 1|ATPase, H+ transporting, lysosomal (vacuolar proton pump), member J|ATPase, H+ transporting, lysosomal 13kDa, V1 subunit G1|V-ATPase 13 kDa subunit 1|V-ATPase subunit G 1|vacuolar ATP synthase subunit M16|vacuolar H(+)-ATPase subunit G 1|vacuolar proton pump subunit G 1|vacuolar proton pump subunit M16', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114587769, end_position_on_the_genomic_accession=114598879, orientation='plus', exon_count=3, OMIM=[607296], no_hdr0=''),
    9551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9551, CurrentID=0, Status='live', Symbol='ATP5MF', Aliases=['ATP5J2', 'ATP5JL'], description='ATP synthase membrane subunit f', other_designations='ATP synthase subunit f, mitochondrial|ATP synthase f chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit f|ATP synthase, H+ transporting, mitochondrial Fo complex subunit F2|F1F0-type ATPase subunit f|F1Fo-ATP synthase complex Fo membrane domain f subunit|F1Fo-ATPase synthase f subunit', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99458195, end_position_on_the_genomic_accession=99466167, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    9552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9552, CurrentID=0, Status='live', Symbol='SPAG7', Aliases=['ACRP', 'FSA-1'], description='sperm associated antigen 7', other_designations='sperm-associated antigen 7', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4959226, end_position_on_the_genomic_accession=4967817, orientation='minus', exon_count=8, OMIM=[610056], no_hdr0=''),
    9553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9553, CurrentID=0, Status='live', Symbol='MRPL33', Aliases=['C2orf1', 'L33mt', 'MRP-L33', 'RPL33L'], description='mitochondrial ribosomal protein L33', other_designations='39S ribosomal protein L33, mitochondrial|mitochondrial large ribosomal subunit protein bL33m', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27771719, end_position_on_the_genomic_accession=27779733, orientation='plus', exon_count=4, OMIM=[610059], no_hdr0=''),
    9554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9554, CurrentID=0, Status='live', Symbol='SEC22B', Aliases=['ERS-24', 'SEC22L1'], description='SEC22 homolog B, vesicle trafficking protein', other_designations='vesicle-trafficking protein SEC22b|ER-Golgi SNARE of 24 kDa|SEC22 vesicle trafficking protein homolog B|SEC22 vesicle trafficking protein-like 1', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=120150898, end_position_on_the_genomic_accession=120176520, orientation='minus', exon_count=6, OMIM=[604029], no_hdr0=''),
    9555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9555, CurrentID=0, Status='live', Symbol='MACROH2A1', Aliases=['H2A.y', 'H2A/y', 'H2AF12M', 'H2AFY.1', 'mH2A1', 'macroH2A1.2', 'MACROH2A1'], description='macroH2A.1 histone', other_designations='core histone macro-H2A.1|H2A histone family member Y|histone H2A.y|histone macroH2A1|histone macroH2A1.1|histone macroH2A1.2|medulloblastoma antigen MU-MB-50.205', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135334381, end_position_on_the_genomic_accession=135401998, orientation='minus', exon_count=14, OMIM=[610054], no_hdr0=''),
    9556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9556, CurrentID=0, Status='live', Symbol='ATP5MJ', Aliases=['6.8PL', 'ATP5MPL', 'C14orf2', 'MLQ', 'MP68', 'PLPM'], description='ATP synthase membrane subunit j', other_designations='ATP synthase subunit ATP5MJ, mitochondrial|6.8 kDa mitochondrial proteolipid protein|6.8-kDa proteolipid with N-terminal sequence Met-Leu-Gln (MLQ)|ATP synthase membrane subunit 6.8PL|ATP synthase subunit ATP5MPL, mitochondrial', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103912288, end_position_on_the_genomic_accession=103921529, orientation='minus', exon_count=5, OMIM=[604573], no_hdr0=''),
    9557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9557, CurrentID=0, Status='live', Symbol='CHD1L', Aliases=['ALC1', 'CHDL'], description='chromodomain helicase DNA binding protein 1 like', other_designations='chromodomain-helicase-DNA-binding protein 1-like|amplified in liver cancer 1|amplified in liver cancer protein 1', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147172747, end_position_on_the_genomic_accession=147295762, orientation='plus', exon_count=27, OMIM=[613039], no_hdr0=''),
    9559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9559, CurrentID=0, Status='live', Symbol='VPS26A', Aliases=['HB58', 'Hbeta58', 'PEP8A', 'VPS26'], description='VPS26, retromer complex component A', other_designations='vacuolar protein sorting-associated protein 26A|VPS26 retromer complex comonent A|vacuolar protein sorting 26 homolog A|vesicle protein sorting 26A', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69124178, end_position_on_the_genomic_accession=69174412, orientation='plus', exon_count=10, OMIM=[605506], no_hdr0=''),
    9560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9560, CurrentID=0, Status='live', Symbol='CCL4L2', Aliases=['AT744.2', 'CCL4L', 'SCYA4L', 'SCYQ4L2'], description='C-C motif chemokine ligand 4 like 2', other_designations='C-C motif chemokine 4-like|MIP-1-beta|chemokine (C-C motif) ligand 4-like 2|macrophage inflammatory protein 1-beta|macrophage inflammatory protein-1b2|monocyte adherence-induced protein 5-alpha', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36211063, end_position_on_the_genomic_accession=36212873, orientation='plus', exon_count=3, OMIM=[610757], no_hdr0=''),
    9562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9562, CurrentID=0, Status='live', Symbol='MINPP1', Aliases=['HIPER1', 'MINPP2', 'MIPP'], description='multiple inositol-polyphosphate phosphatase 1', other_designations='multiple inositol polyphosphate phosphatase 1|2,3-BPG phosphatase|2,3-bisphosphoglycerate 3-phosphatase|inositol (1,3,4,5)-tetrakisphosphate 3-phosphatase|ins(1,3,4,5)P(4) 3-phosphatase|multiple inositol polyphosphate histidine phosphatase, 1|multiple inositol polyphosphate phosphatase 2', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87504893, end_position_on_the_genomic_accession=87553461, orientation='plus', exon_count=7, OMIM=[605391], no_hdr0=''),
    9563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9563, CurrentID=0, Status='live', Symbol='H6PD', Aliases=['CORTRD1', 'G6PDH', 'GDHH', 'H6PD'], description='hexose-6-phosphate dehydrogenase/glucose 1-dehydrogenase', other_designations='GDH/6PGL endoplasmic bifunctional protein|6-phosphogluconolactonase|G6PD, H form|glucose 1- dehydrogenase|glucose dehydrogenase|glucose dehyrogenase|glucose-6-phosphate dehydrogenase, salivary', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9234767, end_position_on_the_genomic_accession=9271337, orientation='plus', exon_count=7, OMIM=[138090], no_hdr0=''),
    9564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9564, CurrentID=0, Status='live', Symbol='BCAR1', Aliases=['CAS', 'CAS1', 'CASS1', 'CRKAS', 'P130Cas'], description='BCAR1 scaffold protein, Cas family member', other_designations='breast cancer anti-estrogen resistance protein 1|BCAR1, Cas family scaffold protein|BCAR1, Cas family scaffolding protein|Cas scaffolding protein family member 1|Crk-associated substrate p130Cas', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75228181, end_position_on_the_genomic_accession=75268007, orientation='minus', exon_count=14, OMIM=[602941], no_hdr0=''),
    9567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9567, CurrentID=0, Status='live', Symbol='GTPBP1', Aliases=['GP-1', 'GP1', 'HSPC018'], description='GTP binding protein 1', other_designations='GTP-binding protein 1|G-protein 1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38704561, end_position_on_the_genomic_accession=38738265, orientation='plus', exon_count=17, OMIM=[602245], no_hdr0=''),
    9568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9568, CurrentID=0, Status='live', Symbol='GABBR2', Aliases=['DEE59', 'EIEE59', 'GABABR2', 'GPR51', 'GPRC3B', 'HG20', 'HRIHFB2099', 'NDPLHS'], description='gamma-aminobutyric acid type B receptor subunit 2', other_designations='gamma-aminobutyric acid type B receptor subunit 2|G-protein coupled receptor 51|GABA-B receptor 2|GABA-B receptor, R2 subunit|GABA-B-R2|GABA-BR2|gamma-aminobutyric acid (GABA) B receptor, 2|gamma-aminobutyric acid B receptor 2|gb2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98288104, end_position_on_the_genomic_accession=98708935, orientation='minus', exon_count=22, OMIM=[607340], no_hdr0=''),
    9569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9569, CurrentID=0, Status='live', Symbol='GTF2IRD1', Aliases=['BEN', 'CREAM1', 'GTF3', 'MUSTRD1', 'RBAP2', 'WBS', 'WBSCR11', 'WBSCR12', 'hMusTRD1alpha1'], description='GTF2I repeat domain containing 1', other_designations='general transcription factor II-I repeat domain-containing protein 1|USE B1-binding protein|Williams-Beuren syndrome chromosome region 11|binding factor for early enhancer|general transcription factor 3|general transcription factor III|muscle TFII-I repeat domain-containing protein 1 alpha 1|slow-muscle-fiber enhancer-binding protein|williams-Beuren syndrome chromosomal region 12 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74453906, end_position_on_the_genomic_accession=74603070, orientation='plus', exon_count=28, OMIM=[604318], no_hdr0=''),
    9570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9570, CurrentID=0, Status='live', Symbol='GOSR2', Aliases=['Bos1', 'EPM6', 'GS27'], description='golgi SNAP receptor complex member 2', other_designations='Golgi SNAP receptor complex member 2|27 kDa Golgi SNARE protein|membrin', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46923108, end_position_on_the_genomic_accession=46975519, orientation='plus', exon_count=14, OMIM=[604027], no_hdr0=''),
    9572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9572, CurrentID=0, Status='live', Symbol='NR1D1', Aliases=['EAR1', 'REVERBA', 'REVERBalpha', 'THRA1', 'THRAL', 'ear-1', 'hRev'], description='nuclear receptor subfamily 1 group D member 1', other_designations='nuclear receptor subfamily 1 group D member 1|Rev-ErbAalpha|V-erbA-related protein 1|nuclear receptor Rev-ErbA-alpha|rev-erbA-alpha', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40092793, end_position_on_the_genomic_accession=40100589, orientation='minus', exon_count=8, OMIM=[602408], no_hdr0=''),
    9573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9573, CurrentID=0, Status='live', Symbol='GDF3', Aliases=['KFS3', 'MCOP7', 'MCOPCB6'], description='growth differentiation factor 3', other_designations='growth/differentiation factor 3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7689784, end_position_on_the_genomic_accession=7695775, orientation='minus', exon_count=2, OMIM=[606522], no_hdr0=''),
    9575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9575, CurrentID=0, Status='live', Symbol='CLOCK', Aliases=['KAT13D', 'bHLHe8'], description='clock circadian regulator', other_designations='circadian locomoter output cycles protein kaput|circadian locomoter output cycles kaput protein|class E basic helix-loop-helix protein 8|clock homolog', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55427903, end_position_on_the_genomic_accession=55547138, orientation='minus', exon_count=28, OMIM=[601851], no_hdr0=''),
    9576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9576, CurrentID=0, Status='live', Symbol='SPAG6', Aliases=['CFAP194', 'CT141', 'FAP194', 'Repro-SA-1', 'pf16'], description='sperm associated antigen 6', other_designations='sperm-associated antigen 6|axoneme central apparatus protein|protein PF16 homolog|sperm flagellar protein|testicular tissue protein Li 176', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22345461, end_position_on_the_genomic_accession=22417610, orientation='plus', exon_count=15, OMIM=[605730], no_hdr0=''),
    9577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9577, CurrentID=0, Status='live', Symbol='BABAM2', Aliases=['BRCC4', 'BRCC45', 'BRE'], description='BRISC and BRCA1 A complex member 2', other_designations='BRISC and BRCA1-A complex member 2|BRCA1-A complex subunit BRE|BRCA1/BRCA2-containing complex subunit 45|BRCA1/BRCA2-containing complex, subunit 4|brain and reproductive organ-expressed (TNFRSF1A modulator)|brain and reproductive organ-expressed protein', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27888709, end_position_on_the_genomic_accession=28338901, orientation='plus', exon_count=16, OMIM=[610497], no_hdr0=''),
    9578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9578, CurrentID=0, Status='live', Symbol='CDC42BPB', Aliases=['MRCKB'], description='CDC42 binding protein kinase beta', other_designations='serine/threonine-protein kinase MRCK beta|CDC42 binding protein kinase beta (DMPK-like)|CDC42BP-beta|DMPK-like beta|MRCK beta|myotonic dystrophy kinase-related CDC42-binding kinase beta|myotonic dystrophy protein kinase-like beta', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102932380, end_position_on_the_genomic_accession=103057549, orientation='minus', exon_count=39, OMIM=[614062], no_hdr0=''),
    9580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9580, CurrentID=0, Status='live', Symbol='SOX13', Aliases=['ICA12', 'Sox-13'], description='SRY-box transcription factor 13', other_designations='transcription factor SOX-13|SRY (sex determining region Y)-box 13|SRY-box 13|SRY-related HMG-box gene 13|islet cell antibody 12|islet cell antigen 12|type 1 diabetes autoantigen ICA12', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204073096, end_position_on_the_genomic_accession=204127743, orientation='plus', exon_count=14, OMIM=[604748], no_hdr0=''),
    9581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9581, CurrentID=0, Status='live', Symbol='PREPL', Aliases=['CMS22'], description='prolyl endopeptidase like', other_designations='prolyl endopeptidase-like|putative prolyl oligopeptidase', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=44317607, end_position_on_the_genomic_accession=44361862, orientation='minus', exon_count=16, OMIM=[609557], no_hdr0=''),
    9582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9582, CurrentID=0, Status='live', Symbol='APOBEC3B', Aliases=['A3B', 'APOBEC1L', 'ARCD3', 'ARP4', 'DJ742C19.2', 'PHRBNL', 'bK150C2.2'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3B', other_designations='DNA dC->dU-editing enzyme APOBEC-3B|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3B|cytidine deaminase|phorbolin 2|phorbolin 3|phorbolin-1-related protein|phorbolin-2/3|probable DNA dC->dU-editing enzyme APOBEC-3B', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38982347, end_position_on_the_genomic_accession=38992779, orientation='plus', exon_count=8, OMIM=[607110], no_hdr0=''),
    9583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9583, CurrentID=0, Status='live', Symbol='ENTPD4', Aliases=['LALP70', 'LAP70', 'LYSAL1', 'NTPDase-4', 'UDPase'], description='ectonucleoside triphosphate diphosphohydrolase 4', other_designations='ectonucleoside triphosphate diphosphohydrolase 4|Golgi UDPase|golgi luminal UDPase|guanosine-diphosphatase like protein|lysosomal apyrase-like 1|lysosomal apyrase-like protein of 70 kDa|uridine-diphosphatase', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23429162, end_position_on_the_genomic_accession=23457647, orientation='minus', exon_count=13, OMIM=[607577], no_hdr0=''),
    9584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9584, CurrentID=0, Status='live', Symbol='RBM39', Aliases=['CAPER', 'CAPERalpha', 'FSAP59', 'HCC1', 'RNPC2'], description='RNA binding motif protein 39', other_designations='RNA-binding protein 39|CAPER alpha|RNA-binding region (RNP1, RRM) containing 2|coactivator of activating protein-1 and estrogen receptors|epididymis secretory sperm binding protein|functional spliceosome-associated protein 59|hepatocellular carcinoma protein 1|splicing factor HCC1', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35701347, end_position_on_the_genomic_accession=35742262, orientation='minus', exon_count=21, OMIM=[604739], no_hdr0=''),
    9585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9585, CurrentID=0, Status='live', Symbol='KIF20B', Aliases=['CT90', 'KRMP1', 'MPHOSPH1', 'MPP-1', 'MPP1'], description='kinesin family member 20B', other_designations='kinesin-like protein KIF20B|M-phase phosphoprotein 1|cancer/testis antigen 90|kinesin-related motor interacting with PIN1|mitotic kinesin-like protein|mitotic kinesin-related protein', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89701590, end_position_on_the_genomic_accession=89774934, orientation='plus', exon_count=33, OMIM=[605498], no_hdr0=''),
    9586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9586, CurrentID=0, Status='live', Symbol='CREB5', Aliases=['CRE-BPA', 'CREB-5', 'CREBPA'], description='cAMP responsive element binding protein 5', other_designations='cyclic AMP-responsive element-binding protein 5|cAMP response element-binding protein CRE-BPa|cAMP-response element-binding protein A', map_location='7p15.1-p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=28299321, end_position_on_the_genomic_accession=28825894, orientation='plus', exon_count=19, OMIM=[618262], no_hdr0=''),
    9587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9587, CurrentID=0, Status='live', Symbol='MAD2L1BP', Aliases=['CMT2'], description='MAD2L1 binding protein', other_designations='MAD2L1-binding protein|caught by MAD2 protein|p31(comet)', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43629540, end_position_on_the_genomic_accession=43640941, orientation='plus', exon_count=5, OMIM=[618136], no_hdr0=''),
    9588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9588, CurrentID=0, Status='live', Symbol='PRDX6', Aliases=['1-Cys', 'AOP2', 'HEL-S-128m', 'LPCAT-5', 'NSGPx', 'PRX', 'aiPLA2', 'p29'], description='peroxiredoxin 6', other_designations='peroxiredoxin-6|1-Cys PRX|1-Cys peroxiredoxin|24 kDa protein|LPC acyltransferase 5|acidic calcium-independent phospholipase A2|antioxidant protein 2|epididymis secretory sperm binding protein Li 128m|glutathione-dependent peroxiredoxin|liver 2D page spot 40|lyso-PC acyltransferase 5|lysophosphatidylcholine acyltransferase 5|non-selenium glutathione peroxidase|red blood cells page spot 12', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173477335, end_position_on_the_genomic_accession=173488815, orientation='plus', exon_count=5, OMIM=[602316], no_hdr0=''),
    9589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9589, CurrentID=0, Status='live', Symbol='WTAP', Aliases=['Mum2'], description='WT1 associated protein', other_designations="pre-mRNA-splicing regulator WTAP|PNAS-132|Wilms tumor 1 associated protein|Wilms' tumour 1-associating protein|female-lethal(2)D homolog|hFL(2)D|putative pre-mRNA splicing regulator female-lethal(2D)|wilms tumor 1-associating protein", map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159726696, end_position_on_the_genomic_accession=159756319, orientation='plus', exon_count=13, OMIM=[605442], no_hdr0=''),
    9590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9590, CurrentID=0, Status='live', Symbol='AKAP12', Aliases=['AKAP250', 'SSeCKS'], description='A-kinase anchoring protein 12', other_designations='A-kinase anchor protein 12|A kinase (PRKA) anchor protein 12|A-kinase anchor protein, 250kDa|AKAP 250|Src-Suppressed C Kinase Substrate|kinase scaffold protein gravin|myasthenia gravis autoantigen gravin', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151239815, end_position_on_the_genomic_accession=151358559, orientation='plus', exon_count=8, OMIM=[604698], no_hdr0=''),
    9592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9592, CurrentID=0, Status='live', Symbol='IER2', Aliases=['ETR101'], description='immediate early response 2', other_designations='immediate early response gene 2 protein|chxI protein homolog', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13150411, end_position_on_the_genomic_accession=13154911, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    9595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9595, CurrentID=0, Status='live', Symbol='CYTIP', Aliases=['B3-1', 'CASP', 'CYBR', 'CYTHIP', 'HE', 'PSCDBP'], description='cytohesin 1 interacting protein', other_designations='cytohesin-interacting protein|cbp HE|cytohesin binder and regulator|cytohesin binding protein HE|cytohesin-associated scaffolding protein|pleckstrin homology Sec7 and coiled-coil domains-binding protein', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157412782, end_position_on_the_genomic_accession=157444089, orientation='minus', exon_count=9, OMIM=[604448], no_hdr0=''),
    9600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9600, CurrentID=0, Status='live', Symbol='PITPNM1', Aliases=['DRES9', 'NIR2', 'PITPNM', 'RDGB', 'RDGB1', 'RDGBA', 'RDGBA1', 'Rd9'], description='phosphatidylinositol transfer protein membrane associated 1', other_designations='membrane-associated phosphatidylinositol transfer protein 1|NIR-2|PITPnm 1|PYK2 N-terminal domain-interacting receptor 2|drosophila retinal degeneration B homolog|retinal degeneration B alpha 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67491760, end_position_on_the_genomic_accession=67505372, orientation='minus', exon_count=25, OMIM=[608794], no_hdr0=''),
    9601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9601, CurrentID=0, Status='live', Symbol='PDIA4', Aliases=['ERP70', 'ERP72', 'ERp-72'], description='protein disulfide isomerase family A member 4', other_designations='protein disulfide-isomerase A4|ER protein 70|ER protein 72|endoplasmic reticulum resident protein 70|endoplasmic reticulum resident protein 72|protein disulfide isomerase related protein (calcium-binding protein, intestinal-related)|protein disulfide isomerase-associated 4|testicular tissue protein Li 137', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149003051, end_position_on_the_genomic_accession=149028505, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    9603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9603, CurrentID=0, Status='live', Symbol='NFE2L3', Aliases=['NRF3'], description='nuclear factor, erythroid 2 like 3', other_designations='nuclear factor erythroid 2-related factor 3|NF-E2-related factor 3|NFE2-related factor 3|nuclear factor, erythroid derived 2, like 3|nuclear factor-erythroid 2 p45-related factor 3', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=26152198, end_position_on_the_genomic_accession=26187137, orientation='plus', exon_count=4, OMIM=[604135], no_hdr0=''),
    9604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9604, CurrentID=0, Status='live', Symbol='RNF14', Aliases=['ARA54', 'HFB30', 'HRIHFB2038', 'TRIAD2'], description='ring finger protein 14', other_designations='E3 ubiquitin-protein ligase RNF14|androgen receptor associated protein 54', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141966807, end_position_on_the_genomic_accession=141990292, orientation='plus', exon_count=13, OMIM=[605675], no_hdr0=''),
    9605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9605, CurrentID=0, Status='live', Symbol='VPS9D1', Aliases=['ATP-BL', 'ATPBL', 'C16orf7'], description='VPS9 domain containing 1', other_designations='VPS9 domain-containing protein 1', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89707133, end_position_on_the_genomic_accession=89721231, orientation='minus', exon_count=18, OMIM=[619292], no_hdr0=''),
    9607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9607, CurrentID=0, Status='live', Symbol='CARTPT', Aliases=['CART'], description='CART prepropeptide', other_designations='cocaine- and amphetamine-regulated transcript protein', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=71719275, end_position_on_the_genomic_accession=71721045, orientation='plus', exon_count=3, OMIM=[602606], no_hdr0=''),
    9609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9609, CurrentID=0, Status='live', Symbol='RAB36', Aliases=[], description='RAB36, member RAS oncogene family', other_designations='ras-related protein Rab-36|small GTP-binding protein Rab36', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23145298, end_position_on_the_genomic_accession=23169285, orientation='plus', exon_count=16, OMIM=[605662], no_hdr0=''),
    9610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9610, CurrentID=0, Status='live', Symbol='RIN1', Aliases=[], description='Ras and Rab interactor 1', other_designations='ras and Rab interactor 1|ras inhibitor 1|ras inhibitor JC99|ras inhibitor RIN1|ras interaction/interference protein 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66330241, end_position_on_the_genomic_accession=66336774, orientation='minus', exon_count=11, OMIM=[605965], no_hdr0=''),
    9611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9611, CurrentID=0, Status='live', Symbol='NCOR1', Aliases=['N-CoR', 'N-CoR1', 'PPP1R109', 'TRAC1', 'hN-CoR'], description='nuclear receptor corepressor 1', other_designations='nuclear receptor corepressor 1|protein phosphatase 1, regulatory subunit 109|thyroid hormone- and retinoic acid receptor-associated corepressor 1', map_location='17p12-p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16029157, end_position_on_the_genomic_accession=16216475, orientation='minus', exon_count=54, OMIM=[600849], no_hdr0=''),
    9612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9612, CurrentID=0, Status='live', Symbol='NCOR2', Aliases=['CTG26', 'N-CoR2', 'SMAP270', 'SMRT', 'SMRTE', 'SMRTE-tau', 'TNRC14', 'TRAC', 'TRAC-1', 'TRAC1'], description='nuclear receptor corepressor 2', other_designations='nuclear receptor corepressor 2|CTG repeat protein 26|T3 receptor-associating factor|silencing mediator for retinoid and thyroid hormone receptors|thyroid-, retinoic-acid-receptor-associated corepressor', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124324415, end_position_on_the_genomic_accession=124567612, orientation='minus', exon_count=49, OMIM=[600848], no_hdr0=''),
    9615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9615, CurrentID=0, Status='live', Symbol='GDA', Aliases=['CYPIN', 'GAH', 'GUANASE', 'NEDASIN'], description='guanine deaminase', other_designations='guanine deaminase|cytoplasmic PSD95 interactor|guanine aminase|guanine aminohydrolase|p51-nedasin', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=72114595, end_position_on_the_genomic_accession=72256045, orientation='plus', exon_count=22, OMIM=[139260], no_hdr0=''),
    9616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9616, CurrentID=0, Status='live', Symbol='RNF7', Aliases=['CKBBP1', 'ROC2', 'SAG', 'rbx2'], description='ring finger protein 7', other_designations='RING-box protein 2|CKII beta-binding protein 1|regulator of cullins 2|sensitive to apoptosis gene protein|sensitive to apoptosis, zinc RING finger protein SAG, regulator of cullins 2|zinc RING finger protein SAG', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141738298, end_position_on_the_genomic_accession=141747560, orientation='plus', exon_count=4, OMIM=[603863], no_hdr0=''),
    9617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9617, CurrentID=0, Status='live', Symbol='MTRF1', Aliases=['MRF1', 'MTTRF1', 'RF1'], description='mitochondrial translation release factor 1', other_designations='peptide chain release factor 1, mitochondrial|MRF-1|mitochondrial translational release factor 1|mitochontrial peptide chain release factor 1|mtRF-1', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41216369, end_position_on_the_genomic_accession=41312038, orientation='minus', exon_count=21, OMIM=[604601], no_hdr0=''),
    9618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9618, CurrentID=0, Status='live', Symbol='TRAF4', Aliases=['CART1', 'MLN62', 'RNF83'], description='TNF receptor associated factor 4', other_designations='TNF receptor-associated factor 4|MLN 62|RING finger protein 83|TRAF4 variant 6|cysteine-rich domain associated with RING and Traf domains protein 1|cysteine-rich domain associated with ring and TRAF domain|malignant 62|metastatic lymph node gene 62 protein|tumor necrosis receptor-associated factor 4A', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28744004, end_position_on_the_genomic_accession=28750956, orientation='plus', exon_count=8, OMIM=[602464], no_hdr0=''),
    9619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9619, CurrentID=0, Status='live', Symbol='ABCG1', Aliases=['ABC8', 'WHITE1'], description='ATP binding cassette subfamily G member 1', other_designations='ATP-binding cassette sub-family G member 1|ABC transporter 8|ATP-binding cassette transporter 8|ATP-binding cassette transporter member 1 of subfamily G|ATP-binding cassette, sub-family G (WHITE), member 1|homolog of Drosophila white|white protein homolog (ATP-binding cassette transporter 8)', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42199689, end_position_on_the_genomic_accession=42304387, orientation='plus', exon_count=23, OMIM=[603076], no_hdr0=''),
    9620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9620, CurrentID=0, Status='live', Symbol='CELSR1', Aliases=['ADGRC1', 'CDHF9', 'FMI2', 'HFMI2', 'LMPHM9', 'ME2'], description='cadherin EGF LAG seven-pass G-type receptor 1', other_designations='cadherin EGF LAG seven-pass G-type receptor 1|adhesion G protein-coupled receptor C1|cadherin family member 9|cadherin, EGF LAG seven-pass G-type receptor 1 (flamingo homolog, Drosophila)|flamingo homolog 2|protocadherin flamingo 2', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46361174, end_position_on_the_genomic_accession=46537620, orientation='minus', exon_count=38, OMIM=[604523], no_hdr0=''),
    9622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9622, CurrentID=0, Status='live', Symbol='KLK4', Aliases=['AI2A1', 'ARM1', 'EMSP', 'EMSP1', 'KLK-L1', 'PRSS17', 'PSTS', 'kallikrein'], description='kallikrein related peptidase 4', other_designations='kallikrein-4|androgen-regulated message 1|enamel matrix serine protease 1|enamel matrix serine proteinase 1|kallikrein-like protein 1|prostase|serine protease 17', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50906351, end_position_on_the_genomic_accession=50910745, orientation='minus', exon_count=6, OMIM=[603767], no_hdr0=''),
    9623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9623, CurrentID=0, Status='live', Symbol='TCL1B', Aliases=['SYN-1', 'TML1'], description='TCL1 family AKT coactivator B', other_designations='T-cell leukemia/lymphoma protein 1B|T cell leukemia/lymphoma 1B|T-cell lymphoma/leukemia 1B|TCL1/ MTCP1-like 1|oncogene TCL-1B|syncytiotrophoblast-specific protein', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95686426, end_position_on_the_genomic_accession=95692628, orientation='plus', exon_count=4, OMIM=[603769], no_hdr0=''),
    9625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9625, CurrentID=0, Status='live', Symbol='AATK', Aliases=['AATYK', 'AATYK1', 'LMR1', 'LMTK1', 'PPP1R77', 'p35BP'], description='apoptosis associated tyrosine kinase', other_designations='serine/threonine-protein kinase LMTK1|CDK5-binding protein|brain apoptosis-associated tyrosine kinase|lemur tyrosine kinase 1|p35-binding protein|protein phosphatase 1, regulatory subunit 77', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81117295, end_position_on_the_genomic_accession=81166221, orientation='minus', exon_count=15, OMIM=[605276], no_hdr0=''),
    9626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9626, CurrentID=0, Status='live', Symbol='GUCA1C', Aliases=['GCAP3'], description='guanylate cyclase activator 1C', other_designations='guanylyl cyclase-activating protein 3|GCAP 3', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108907644, end_position_on_the_genomic_accession=108955195, orientation='minus', exon_count=5, OMIM=[605128], no_hdr0=''),
    9627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9627, CurrentID=0, Status='live', Symbol='SNCAIP', Aliases=['SYPH1', 'Sph1'], description='synuclein alpha interacting protein', other_designations='synphilin-1', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122311354, end_position_on_the_genomic_accession=122464219, orientation='plus', exon_count=22, OMIM=[603779], no_hdr0=''),
    9628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9628, CurrentID=0, Status='live', Symbol='RGS6', Aliases=['GAP', 'HA117', 'S914'], description='regulator of G protein signaling 6', other_designations='regulator of G-protein signaling 6|regulator of G-protein signalling 6', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=71867397, end_position_on_the_genomic_accession=72632478, orientation='plus', exon_count=40, OMIM=[603894], no_hdr0=''),
    9630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9630, CurrentID=0, Status='live', Symbol='GNA14', Aliases=[], description='G protein subunit alpha 14', other_designations='guanine nucleotide-binding protein subunit alpha-14|g alpha-14|guanine nucleotide binding protein (G protein), alpha 14|guanine nucleotide-binding protein 14', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=77423079, end_position_on_the_genomic_accession=77648322, orientation='minus', exon_count=9, OMIM=[604397], no_hdr0=''),
    9631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9631, CurrentID=0, Status='live', Symbol='NUP155', Aliases=['ATFB15', 'N155'], description='nucleoporin 155', other_designations='nuclear pore complex protein Nup155|155 kDa nucleoporin|nucleoporin 155kD|nucleoporin 155kDa', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=37288137, end_position_on_the_genomic_accession=37371106, orientation='minus', exon_count=36, OMIM=[606694], no_hdr0=''),
    9632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9632, CurrentID=0, Status='live', Symbol='SEC24C', Aliases=[], description='SEC24 homolog C, COPII coat complex component', other_designations='protein transport protein Sec24C|SEC24 family, member C|SEC24 related gene family, member C|SEC24-related protein C', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73744164, end_position_on_the_genomic_accession=73772167, orientation='plus', exon_count=26, OMIM=[607185], no_hdr0=''),
    9633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9633, CurrentID=0, Status='live', Symbol='TESMIN', Aliases=['CXCDC2', 'MTL5', 'MTLT'], description='testis expressed metallothionein like protein', other_designations='tesmin|CXC domain containing 2|metallothionein-like 5, testis-specific (tesmin)|testis-specific metallothionein-like protein', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68706674, end_position_on_the_genomic_accession=68751564, orientation='minus', exon_count=11, OMIM=[604374], no_hdr0=''),
    9635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9635, CurrentID=0, Status='live', Symbol='CLCA2', Aliases=['CACC', 'CACC3', 'CLCRG2', 'CaCC-3'], description='chloride channel accessory 2', other_designations='calcium-activated chloride channel regulator 2|CLCA family member 2, chloride channel regulator|calcium-activated chloride channel protein 3|chloride channel, calcium activated, family member 2', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86424144, end_position_on_the_genomic_accession=86456553, orientation='plus', exon_count=15, OMIM=[604003], no_hdr0=''),
    9636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9636, CurrentID=0, Status='live', Symbol='ISG15', Aliases=['G1P2', 'IFI15', 'IMD38', 'IP17', 'UCRP', 'hUCRP'], description='ISG15 ubiquitin like modifier', other_designations='ubiquitin-like protein ISG15|interferon, alpha-inducible protein (clone IFI-15K)|interferon-induced 17-kDa/15-kDa protein|interferon-stimulated protein, 15 kDa|ubiquitin cross-reactive protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1013497, end_position_on_the_genomic_accession=1014540, orientation='plus', exon_count=2, OMIM=[147571], no_hdr0=''),
    9637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9637, CurrentID=0, Status='live', Symbol='FEZ2', Aliases=['HUM3CL'], description='fasciculation and elongation protein zeta 2', other_designations='fasciculation and elongation protein zeta-2|pre-T/NK cell associated protein (3Cl)|zygin 2|zygin II', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=36552239, end_position_on_the_genomic_accession=36598190, orientation='minus', exon_count=10, OMIM=[604826], no_hdr0=''),
    9638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9638, CurrentID=0, Status='live', Symbol='FEZ1', Aliases=['UNC-76'], description='fasciculation and elongation protein zeta 1', other_designations='fasciculation and elongation protein zeta-1|zygin I|zygin-1', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125442881, end_position_on_the_genomic_accession=125496265, orientation='minus', exon_count=11, OMIM=[604825], no_hdr0=''),
    9639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9639, CurrentID=0, Status='live', Symbol='ARHGEF10', Aliases=['GEF10', 'SNCV'], description='Rho guanine nucleotide exchange factor 10', other_designations='rho guanine nucleotide exchange factor 10|Rho guanine nucleotide exchange factor (GEF) 10', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=1823926, end_position_on_the_genomic_accession=1958641, orientation='plus', exon_count=32, OMIM=[608136], no_hdr0=''),
    9640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9640, CurrentID=0, Status='live', Symbol='ZNF592', Aliases=['CAMOS', 'SCAR5'], description='zinc finger protein 592', other_designations='zinc finger protein 592', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84748556, end_position_on_the_genomic_accession=84806445, orientation='plus', exon_count=13, OMIM=[613624], no_hdr0=''),
    9641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9641, CurrentID=0, Status='live', Symbol='IKBKE', Aliases=['IKK-E', 'IKK-i', 'IKKE', 'IKKI'], description='inhibitor of nuclear factor kappa B kinase subunit epsilon', other_designations='inhibitor of nuclear factor kappa-B kinase subunit epsilon|I-kappa-B kinase epsilon|IKK-epsilon|IKK-related kinase epsilon|inducible I kappa-B kinase|inducible IkappaB kinase|inhibitor of kappa light polypeptide gene enhancer in B-cells, kinase epsilon', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206470243, end_position_on_the_genomic_accession=206496890, orientation='plus', exon_count=22, OMIM=[605048], no_hdr0=''),
    9643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9643, CurrentID=0, Status='live', Symbol='MORF4L2', Aliases=['MORFL2', 'MRGX'], description='mortality factor 4 like 2', other_designations='mortality factor 4-like protein 2|MORF-related gene X protein|MSL3-2 protein|protein MSL3-2|transcription factor-like protein MRGX', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103675498, end_position_on_the_genomic_accession=103688047, orientation='minus', exon_count=6, OMIM=[300409], no_hdr0=''),
    9644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9644, CurrentID=0, Status='live', Symbol='SH3PXD2A', Aliases=['FISH', 'SH3MD1', 'TKS5'], description='SH3 and PX domains 2A', other_designations='SH3 and PX domain-containing protein 2A|SH3 multiple domains 1|adapter protein TKS5|adaptor protein TKS5|five SH3 domain-containing protein|tyrosine kinase substrate with five SH3 domains', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103594027, end_position_on_the_genomic_accession=103855576, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    9645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9645, CurrentID=0, Status='live', Symbol='MICAL2', Aliases=['Ebitein1', 'MICAL-2PV1', 'MICAL2PV2', 'MICALCL', 'MICAL2'], description='microtubule associated monooxygenase, calponin and LIM domain containing 2', other_designations='[F-actin]-monooxygenase MICAL2|ERK2-binding testicular protein 1|MICAL C-terminal like|MICAL C-terminal-like protein|[F-actin]-methionine sulfoxide oxidase MICAL2|ebitein-1|flavoprotein oxidoreductase MICAL2|mical-cL|microtubule associated monoxygenase, calponin and LIM domain containing 2|molecule interacting with CasL protein 2|protein-methionine sulfoxide oxidase MICAL2', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=12110590, end_position_on_the_genomic_accession=12362140, orientation='plus', exon_count=40, OMIM=[608881], no_hdr0=''),
    9646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9646, CurrentID=0, Status='live', Symbol='CTR9', Aliases=['SH2BP1', 'TSBP', 'p150', 'p150TSP'], description='CTR9 homolog, Paf1/RNA polymerase II complex component', other_designations='RNA polymerase-associated protein CTR9 homolog|Ctr9, Paf1/RNA polymerase II complex component, homolog|SH2 domain binding protein 1 (tetratricopeptide repeat containing)|TPR-containing, SH2-binding phosphoprotein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10751246, end_position_on_the_genomic_accession=10779746, orientation='plus', exon_count=25, OMIM=[609366], no_hdr0=''),
    9647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9647, CurrentID=0, Status='live', Symbol='PPM1F', Aliases=['CAMKP', 'CaMKPase', 'FEM-2', 'POPX2', 'hFEM-2'], description='protein phosphatase, Mg2+/Mn2+ dependent 1F', other_designations='protein phosphatase 1F|Ca(2+)/calmodulin-dependent protein kinase phosphatase|CaM-kinase phosphatase|PP2C phosphatase|partner of PIX 2|protein fem-2 homolog|protein phosphatase 1F (PP2C domain containing)', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21919419, end_position_on_the_genomic_accession=21952875, orientation='minus', exon_count=9, OMIM=[619309], no_hdr0=''),
    9648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9648, CurrentID=0, Status='live', Symbol='GCC2', Aliases=['GCC185', 'RANBP2L4', 'REN53'], description='GRIP and coiled-coil domain containing 2', other_designations='GRIP and coiled-coil domain-containing protein 2|185 kDa Golgi coiled-coil protein|CLL-associated antigen KW-11|CTCL tumor antigen se1-1|GCC protein, 185-kD|Golgi coiled-coil protein GCC185|Ran-binding protein 2-like 4|renal carcinoma antigen NY-REN-53', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108448561, end_position_on_the_genomic_accession=108509415, orientation='plus', exon_count=25, OMIM=[612711], no_hdr0=''),
    9649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9649, CurrentID=0, Status='live', Symbol='RALGPS1', Aliases=['RALGEF2A', 'RALGPS1'], description='Ral GEF with PH domain and SH3 binding motif 1', other_designations='ras-specific guanine nucleotide-releasing factor RalGPS1|Ral guanine nucleotide exchange factor RalGPS1A|ral guanine nucleotide exchange factor 2|ralA exchange factor RalGPS1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=126914780, end_position_on_the_genomic_accession=127223166, orientation='plus', exon_count=29, OMIM=[614444], no_hdr0=''),
    9650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9650, CurrentID=0, Status='live', Symbol='MTFR1', Aliases=['CHPPR', 'FAM54A2'], description='mitochondrial fission regulator 1', other_designations='mitochondrial fission regulator 1|chondrocyte protein with a poly-proline region', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=65643873, end_position_on_the_genomic_accession=65771252, orientation='plus', exon_count=13, OMIM=[619414], no_hdr0=''),
    9651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9651, CurrentID=0, Status='live', Symbol='PLCH2', Aliases=['PLC-L4', 'PLC-eta2', 'PLCL4', 'PLCeta2'], description='phospholipase C eta 2', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase eta-2|phosphoinositide phospholipase C-eta-2|phosphoinositide phospholipase C-like 4|phospholipase C-eta2|phospholipase C-like 4|phospholipase C-like protein 4', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2412481, end_position_on_the_genomic_accession=2505532, orientation='plus', exon_count=27, OMIM=[612836], no_hdr0=''),
    9652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9652, CurrentID=0, Status='live', Symbol='TTC37', Aliases=['KIAA0372', 'Ski3', 'THES'], description='tetratricopeptide repeat domain 37', other_designations='tetratricopeptide repeat protein 37|SKI3 homolog|TPR repeat protein 37|thespin|tricho-hepatic-enteric syndrome protein', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95463894, end_position_on_the_genomic_accession=95554980, orientation='minus', exon_count=43, OMIM=[614589], no_hdr0=''),
    9653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9653, CurrentID=0, Status='live', Symbol='HS2ST1', Aliases=['NFSRA', 'dJ604K5.2'], description='heparan sulfate 2-O-sulfotransferase 1', other_designations='heparan sulfate 2-O-sulfotransferase 1|2-O-sulfotransferase|2OST', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86914635, end_position_on_the_genomic_accession=87109982, orientation='plus', exon_count=7, OMIM=[604844], no_hdr0=''),
    9654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9654, CurrentID=0, Status='live', Symbol='TTLL4', Aliases=[], description='tubulin tyrosine ligase like 4', other_designations='tubulin polyglutamylase TTLL4|tubulin tyrosine ligase-like family, member 4|tubulin--tyrosine ligase-like protein 4', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218710835, end_position_on_the_genomic_accession=218757484, orientation='plus', exon_count=22, OMIM=[618738], no_hdr0=''),
    9655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9655, CurrentID=0, Status='live', Symbol='SOCS5', Aliases=['CIS6', 'CISH6', 'Cish5', 'SOCS-5'], description='suppressor of cytokine signaling 5', other_designations='suppressor of cytokine signaling 5|CIS-6|cytokine-inducible SH2 protein 6|cytokine-inducible SH2-containing protein 5', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46698937, end_position_on_the_genomic_accession=46763129, orientation='plus', exon_count=3, OMIM=[607094], no_hdr0=''),
    9656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9656, CurrentID=0, Status='live', Symbol='MDC1', Aliases=['NFBD1'], description='mediator of DNA damage checkpoint 1', other_designations='mediator of DNA damage checkpoint protein 1|homologue to Drosophila photoreceptor protein calphotin|nuclear factor with BRCT domains 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30699807, end_position_on_the_genomic_accession=30717988, orientation='minus', exon_count=18, OMIM=[607593], no_hdr0=''),
    9657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9657, CurrentID=0, Status='live', Symbol='IQCB1', Aliases=['NPHP5', 'PIQ', 'SLSN5'], description='IQ motif containing B1', other_designations='IQ calmodulin-binding motif-containing protein 1|nephrocystin 5|p53 and DNA damage-regulated IQ motif protein', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121769761, end_position_on_the_genomic_accession=121835060, orientation='minus', exon_count=16, OMIM=[609237], no_hdr0=''),
    9658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9658, CurrentID=0, Status='live', Symbol='ZNF516', Aliases=['HsT287'], description='zinc finger protein 516', other_designations='zinc finger protein 516', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=76357682, end_position_on_the_genomic_accession=76495255, orientation='minus', exon_count=12, OMIM=[615114], no_hdr0=''),
    9659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9659, CurrentID=0, Status='live', Symbol='PDE4DIP', Aliases=['CMYA2', 'MMGL'], description='phosphodiesterase 4D interacting protein', other_designations='myomegalin|cardiomyopathy-associated protein 2|myomegalin/phosphodiesterase 4D interacting protein variant 8', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148808198, end_position_on_the_genomic_accession=149051277, orientation='plus', exon_count=55, OMIM=[608117], no_hdr0=''),
    9662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9662, CurrentID=0, Status='live', Symbol='CEP135', Aliases=['CEP4', 'KIAA0635', 'MCPH8'], description='centrosomal protein 135', other_designations='centrosomal protein of 135 kDa|centrosomal protein 135kDa|centrosomal protein 4|centrosome protein cep135', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55948808, end_position_on_the_genomic_accession=56033361, orientation='plus', exon_count=26, OMIM=[611423], no_hdr0=''),
    9663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9663, CurrentID=0, Status='live', Symbol='LPIN2', Aliases=[], description='lipin 2', other_designations='phosphatidate phosphatase LPIN2', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=2916994, end_position_on_the_genomic_accession=3013201, orientation='minus', exon_count=23, OMIM=[605519], no_hdr0=''),
    9665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9665, CurrentID=0, Status='live', Symbol='MARF1', Aliases=['KIAA0430', 'LKAP', 'LMKB', 'PPP1R34'], description='meiosis regulator and mRNA stability factor 1', other_designations='meiosis regulator and mRNA stability factor 1|limkain-b1|meiosis arrest female 1|meiosis arrest female protein 1|protein phosphatase 1, regulatory subunit 34', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15594387, end_position_on_the_genomic_accession=15643166, orientation='minus', exon_count=28, OMIM=[614593], no_hdr0=''),
    9666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9666, CurrentID=0, Status='live', Symbol='DZIP3', Aliases=['PPP1R66', 'UURF2', 'hRUL138'], description='DAZ interacting zinc finger protein 3', other_designations='E3 ubiquitin-protein ligase DZIP3|DAZ interacting protein 3, zinc finger|DAZ-interacting protein 3|RING-type E3 ubiquitin transferase DZIP3|RNA-binding RING-H2 protein-ubiquitin ligase|RNA-binding ubiquitin ligase of 138 kDa|UURF2 ubiquitin ligase|human RNA-binding ubiquitin ligase of 138 kDa|protein phosphatase 1, regulatory subunit 66|zinc finger DAZ interacting protein 3', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108589490, end_position_on_the_genomic_accession=108694840, orientation='plus', exon_count=36, OMIM=[608672], no_hdr0=''),
    9667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9667, CurrentID=0, Status='live', Symbol='SAFB2', Aliases=[], description='scaffold attachment factor B2', other_designations='scaffold attachment factor B2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5586993, end_position_on_the_genomic_accession=5622846, orientation='minus', exon_count=18, OMIM=[608066], no_hdr0=''),
    9668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9668, CurrentID=0, Status='live', Symbol='ZNF432', Aliases=[], description='zinc finger protein 432', other_designations='zinc finger protein 432', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52031378, end_position_on_the_genomic_accession=52048838, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    9669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9669, CurrentID=0, Status='live', Symbol='EIF5B', Aliases=['IF2'], description='eukaryotic translation initiation factor 5B', other_designations='eukaryotic translation initiation factor 5B|eIF-5B|translation initiation factor IF-2|translation initiation factor IF2', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99337389, end_position_on_the_genomic_accession=99401326, orientation='plus', exon_count=24, OMIM=[606086], no_hdr0=''),
    9670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9670, CurrentID=0, Status='live', Symbol='IPO13', Aliases=['IMP13', 'KAP13', 'LGL2', 'RANBP13'], description='importin 13', other_designations='importin-13|Ran binding protein 13|karyopherin 13|late gestation lung 2|ran-binding protein 13', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43946852, end_position_on_the_genomic_accession=43968022, orientation='plus', exon_count=21, OMIM=[610411], no_hdr0=''),
    9671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9671, CurrentID=0, Status='live', Symbol='WSCD2', Aliases=[], description='WSC domain containing 2', other_designations='WSC domain-containing protein 2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108129288, end_position_on_the_genomic_accession=108250537, orientation='plus', exon_count=13, OMIM=[619253], no_hdr0=''),
    9672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9672, CurrentID=0, Status='live', Symbol='SDC3', Aliases=['SDCN', 'SYND3'], description='syndecan 3', other_designations='syndecan-3|N-syndecan|syndecan neural type|syndecan proteoglycan 3', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=30869466, end_position_on_the_genomic_accession=30909735, orientation='minus', exon_count=8, OMIM=[186357], no_hdr0=''),
    9673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9673, CurrentID=0, Status='live', Symbol='SLC25A44', Aliases=[], description='solute carrier family 25 member 44', other_designations='solute carrier family 25 member 44', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156194089, end_position_on_the_genomic_accession=156212796, orientation='plus', exon_count=6, OMIM=[610824], no_hdr0=''),
    9674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9674, CurrentID=0, Status='live', Symbol='KIAA0040', Aliases=[], description='KIAA0040', other_designations='uncharacterized protein KIAA0040', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=175156986, end_position_on_the_genomic_accession=175193295, orientation='minus', exon_count=6, OMIM=[616696], no_hdr0=''),
    9675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9675, CurrentID=0, Status='live', Symbol='TTI1', Aliases=['KIAA0406', 'smg-10'], description='TELO2 interacting protein 1', other_designations='TELO2-interacting protein 1 homolog|TEL2-interacting protein 1 homolog|Tel two interacting protein 1|smg-10 homolog, nonsense mediated mRNA decay factor', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37983014, end_position_on_the_genomic_accession=38033461, orientation='minus', exon_count=10, OMIM=[614425], no_hdr0=''),
    9677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9677, CurrentID=0, Status='live', Symbol='PPIP5K1', Aliases=['HISPPD2A', 'IP6K', 'IPS1', 'VIP1', 'hsVIP1'], description='diphosphoinositol pentakisphosphate kinase 1', other_designations='inositol hexakisphosphate and diphosphoinositol-pentakisphosphate kinase 1|IP6 kinase|VIP1 homolog|histidine acid phosphatase domain containing 2A|histidine acid phosphatase domain-containing protein 2A|inositol pyrophosphate synthase 1|insP6 and PP-IP5 kinase 1', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43533475, end_position_on_the_genomic_accession=43590272, orientation='minus', exon_count=35, OMIM=[610979], no_hdr0=''),
    9678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9678, CurrentID=0, Status='live', Symbol='PHF14', Aliases=[], description='PHD finger protein 14', other_designations='PHD finger protein 14', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=10973872, end_position_on_the_genomic_accession=11169618, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    9679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9679, CurrentID=0, Status='live', Symbol='FAM53B', Aliases=['KIAA0140', 'bA12J10.2', 'smp'], description='family with sequence similarity 53 member B', other_designations='protein FAM53B|protein simplet|simplet homolog', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124619292, end_position_on_the_genomic_accession=124744378, orientation='minus', exon_count=5, OMIM=[617289], no_hdr0=''),
    9681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9681, CurrentID=0, Status='live', Symbol='DEPDC5', Aliases=['DEP.5', 'FFEVF', 'FFEVF1'], description='DEP domain containing 5, GATOR1 subcomplex subunit', other_designations='GATOR complex protein DEPDC5|DEP domain-containing protein 5', map_location='22q12.2-q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31753968, end_position_on_the_genomic_accession=31908033, orientation='plus', exon_count=47, OMIM=[614191], no_hdr0=''),
    9682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9682, CurrentID=0, Status='live', Symbol='KDM4A', Aliases=['JHDM3A', 'JMJD2', 'JMJD2A', 'TDRD14A'], description='lysine demethylase 4A', other_designations='lysine-specific demethylase 4A|[histone H3]-trimethyl-L-lysine(36) demethylase 4A|[histone H3]-trimethyl-L-lysine(9) demethylase 4A|jmjC domain-containing histone demethylation protein 3A|jumonji C domain-containing histone demethylase 3A|jumonji domain containing 2|jumonji domain containing 2A|jumonji domain-containing protein 2A|lysine (K)-specific demethylase 4A|tudor domain containing 14A', map_location='1p34.2-p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43650149, end_position_on_the_genomic_accession=43705518, orientation='plus', exon_count=23, OMIM=[609764], no_hdr0=''),
    9683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9683, CurrentID=0, Status='live', Symbol='N4BP1', Aliases=[], description='NEDD4 binding protein 1', other_designations='NEDD4-binding protein 1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=48538726, end_position_on_the_genomic_accession=48610214, orientation='minus', exon_count=7, OMIM=[619138], no_hdr0=''),
    9684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9684, CurrentID=0, Status='live', Symbol='LRRC14', Aliases=['LRRC14A'], description='leucine rich repeat containing 14', other_designations='leucine-rich repeat-containing protein 14', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144517965, end_position_on_the_genomic_accession=144525172, orientation='plus', exon_count=5, OMIM=[619368], no_hdr0=''),
    9685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9685, CurrentID=0, Status='live', Symbol='CLINT1', Aliases=['CLINT', 'ENTH', 'EPN4', 'EPNR'], description='clathrin interactor 1', other_designations='clathrin interactor 1|clathrin interacting protein localized in the trans-Golgi region|enthoprotin|epsin 4|epsin-related protein|epsinR', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157785747, end_position_on_the_genomic_accession=157859145, orientation='minus', exon_count=13, OMIM=[607265], no_hdr0=''),
    9686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9686, CurrentID=0, Status='live', Symbol='VGLL4', Aliases=['VGL-4'], description='vestigial like family member 4', other_designations='transcription cofactor vestigial-like protein 4|Vestigial-like 4|vestigial like 4', map_location='3p25.3-p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=11556067, end_position_on_the_genomic_accession=11720715, orientation='minus', exon_count=14, OMIM=[618692], no_hdr0=''),
    9687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9687, CurrentID=0, Status='live', Symbol='GREB1', Aliases=[], description='growth regulating estrogen receptor binding 1', other_designations='protein GREB1|gene regulated by estrogen in breast cancer|gene regulated in breast cancer 1 protein|growth regulation by estrogen in breast cancer 1', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11481675, end_position_on_the_genomic_accession=11642788, orientation='plus', exon_count=43, OMIM=[611736], no_hdr0=''),
    9688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9688, CurrentID=0, Status='live', Symbol='NUP93', Aliases=['NIC96'], description='nucleoporin 93', other_designations='nuclear pore complex protein Nup93|93 kDa nucleoporin|nucleoporin 93kDa|nucleoporin Nup93', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56730129, end_position_on_the_genomic_accession=56850286, orientation='plus', exon_count=25, OMIM=[614351], no_hdr0=''),
    9689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9689, CurrentID=0, Status='live', Symbol='BZW1', Aliases=['BZAP45', 'Nbla10236'], description='basic leucine zipper and W2 domains 1', other_designations='basic leucine zipper and W2 domain-containing protein 1|basic leucine-zipper protein BZAP45|putative protein product of Nbla10236', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200811589, end_position_on_the_genomic_accession=200827338, orientation='plus', exon_count=15, OMIM=[619252], no_hdr0=''),
    9690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9690, CurrentID=0, Status='live', Symbol='UBE3C', Aliases=['HECTH2'], description='ubiquitin protein ligase E3C', other_designations='ubiquitin-protein ligase E3C|HECT-type ubiquitin transferase E3C|ubiquitin-protein isopeptide ligase (E3)', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=157138926, end_position_on_the_genomic_accession=157269370, orientation='plus', exon_count=24, OMIM=[614454], no_hdr0=''),
    9692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9692, CurrentID=0, Status='live', Symbol='PRORP', Aliases=['KIAA0391', 'MRPP3'], description='protein only RNase P catalytic subunit', other_designations='mitochondrial ribonuclease P catalytic subunit|mitochondrial RNase P protein 3|mitochondrial RNase P subunit 3|mitochondrial ribonuclease P protein 3|proteinaceous RNase P', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35122303, end_position_on_the_genomic_accession=35277622, orientation='plus', exon_count=9, OMIM=[609947], no_hdr0=''),
    9693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9693, CurrentID=0, Status='live', Symbol='RAPGEF2', Aliases=['CNrasGEF', 'NRAPGEP', 'PDZ-GEF1', 'PDZGEF1', 'RA-GEF', 'RA-GEF-1', 'RAGEF', 'Rap-GEP', 'nRap GEP'], description='Rap guanine nucleotide exchange factor 2', other_designations='rap guanine nucleotide exchange factor 2|PDZ domain containing guanine nucleotide exchange factor (GEF) 1|PDZ domain-containing guanine nucleotide exchange factor 1|RA(Ras/Rap1A-associating)-GEF|Rap guanine nucleotide exchange factor (GEF) 2|cyclic nucleotide ras GEF|neural RAP guanine nucleotide exchange protein|ras/Rap1-associating GEF-1', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=159103079, end_position_on_the_genomic_accession=159360173, orientation='plus', exon_count=35, OMIM=[609530], no_hdr0=''),
    9694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9694, CurrentID=0, Status='live', Symbol='EMC2', Aliases=['KIAA0103', 'TTC35'], description='ER membrane protein complex subunit 2', other_designations='ER membrane protein complex subunit 2|TPR repeat protein 35|tetratricopeptide repeat domain 35|tetratricopeptide repeat protein 35', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=108443624, end_position_on_the_genomic_accession=108489196, orientation='plus', exon_count=13, OMIM=[607722], no_hdr0=''),
    9695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9695, CurrentID=0, Status='live', Symbol='EDEM1', Aliases=['EDEM'], description='ER degradation enhancing alpha-mannosidase like protein 1', other_designations='ER degradation-enhancing alpha-mannosidase-like protein 1|ER degradation enhancer, mannosidase alpha-like 1|ER degradation-enhancing alpha-mannosidase-like 1', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=5187707, end_position_on_the_genomic_accession=5219963, orientation='plus', exon_count=13, OMIM=[607673], no_hdr0=''),
    9696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9696, CurrentID=0, Status='live', Symbol='CROCC', Aliases=['ROLT', 'TAX1BP2'], description='ciliary rootlet coiled-coil, rootletin', other_designations='rootletin|Tax1-binding protein 2|ciliary rootlet coiled-coil protein|rootletin, ciliary rootlet protein', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16914082, end_position_on_the_genomic_accession=16972979, orientation='plus', exon_count=39, OMIM=[615776], no_hdr0=''),
    9697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9697, CurrentID=0, Status='live', Symbol='TRAM2', Aliases=[], description='translocation associated membrane protein 2', other_designations='translocating chain-associated membrane protein 2|TRAM-like protein', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52497405, end_position_on_the_genomic_accession=52577060, orientation='minus', exon_count=12, OMIM=[608485], no_hdr0=''),
    9698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9698, CurrentID=0, Status='live', Symbol='PUM1', Aliases=['HSPUM', 'PUMH', 'PUMH1', 'PUML1', 'SCA47'], description='pumilio RNA binding family member 1', other_designations='pumilio homolog 1|pumilio-1', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=30931506, end_position_on_the_genomic_accession=31065717, orientation='minus', exon_count=22, OMIM=[607204], no_hdr0=''),
    9699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9699, CurrentID=0, Status='live', Symbol='RIMS2', Aliases=['CRSDS', 'OBOE', 'RAB3IP3', 'RIM2'], description='regulating synaptic membrane exocytosis 2', other_designations='regulating synaptic membrane exocytosis protein 2|RAB3 interacting protein 3|Rab3-interacting protein|non-small cell lung cancer RimL3a protein|non-small cell lung cancer RimL3c protein|nuclear protein|rab-3-interacting molecule 2|rab-3-interacting protein 3|rab3-interacting molecule 2', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103499934, end_position_on_the_genomic_accession=104256094, orientation='plus', exon_count=42, OMIM=[606630], no_hdr0=''),
    9700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9700, CurrentID=0, Status='live', Symbol='ESPL1', Aliases=['ESP1', 'SEPA'], description='extra spindle pole bodies like 1, separase', other_designations='separin|caspase-like protein ESPL1|extra spindle pole bodies 1, separase|extra spindle pole bodies homolog 1|extra spindle poles like 1|extra spindle poles-like 1 protein|separin, cysteine protease', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53268257, end_position_on_the_genomic_accession=53293643, orientation='plus', exon_count=32, OMIM=[604143], no_hdr0=''),
    9701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9701, CurrentID=0, Status='live', Symbol='PPP6R2', Aliases=['KIAA0685', 'PP6R2', 'SAP190', 'SAPS2'], description='protein phosphatase 6 regulatory subunit 2', other_designations='serine/threonine-protein phosphatase 6 regulatory subunit 2|SAPS domain family, member 2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50343327, end_position_on_the_genomic_accession=50445090, orientation='plus', exon_count=29, OMIM=[610877], no_hdr0=''),
    9702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9702, CurrentID=0, Status='live', Symbol='CEP57', Aliases=['MVA2', 'PIG8', 'TSP57'], description='centrosomal protein 57', other_designations='centrosomal protein of 57 kDa|FGF2-interacting protein|centrosomal protein 57kDa|proliferation-inducing protein 8|testis-specific protein 57|translokin', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95790471, end_position_on_the_genomic_accession=95832693, orientation='plus', exon_count=13, OMIM=[607951], no_hdr0=''),
    9703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9703, CurrentID=0, Status='live', Symbol='KIAA0100', Aliases=['BCOX', 'BCOX1', 'CT101', 'FMP27'], description='KIAA0100', other_designations='protein KIAA0100|U937-associated antigen|antigen MLAA-22|breast cancer overexpressed gene 1|breast cancer-overexpressed gene 1 protein|cancer/testis antigen 101', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28614440, end_position_on_the_genomic_accession=28645159, orientation='minus', exon_count=40, OMIM=[610664], no_hdr0=''),
    9704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9704, CurrentID=0, Status='live', Symbol='DHX34', Aliases=['DDX34', 'HRH1'], description='DExH-box helicase 34', other_designations='probable ATP-dependent RNA helicase DHX34|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 34|DEAH (Asp-Glu-Ala-His) box polypeptide 34|DEAH box protein 34|DEAH-box helicase 34|probable ATP-dependent helicase DHX34', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47349315, end_position_on_the_genomic_accession=47382704, orientation='plus', exon_count=21, OMIM=[615475], no_hdr0=''),
    9705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9705, CurrentID=0, Status='live', Symbol='ST18', Aliases=['NZF-3', 'NZF3', 'ZC2H2C3', 'ZC2HC10', 'ZNF387'], description='ST18 C2H2C-type zinc finger transcription factor', other_designations='suppression of tumorigenicity 18 protein|ST18, C2H2C-type zinc finger|neural zinc finger transcription factor 3|suppression of tumorigenicity 18 (breast carcinoma) (zinc finger protein)|suppression of tumorigenicity 18, zinc finger|zinc finger protein 387', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=52110836, end_position_on_the_genomic_accession=52409879, orientation='minus', exon_count=36, OMIM=[617155], no_hdr0=''),
    9706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9706, CurrentID=0, Status='live', Symbol='ULK2', Aliases=['ATG1B', 'Unc51.2'], description='unc-51 like autophagy activating kinase 2', other_designations='serine/threonine-protein kinase ULK2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19770828, end_position_on_the_genomic_accession=19867936, orientation='minus', exon_count=29, OMIM=[608650], no_hdr0=''),
    9708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9708, CurrentID=0, Status='live', Symbol='PCDHGA8', Aliases=['PCDH-GAMMA-A8'], description='protocadherin gamma subfamily A, 8', other_designations='protocadherin gamma-A8', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141392633, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606295], no_hdr0=''),
    9709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9709, CurrentID=0, Status='live', Symbol='HERPUD1', Aliases=['HERP', 'Mif1', 'SUP'], description='homocysteine inducible ER protein with ubiquitin like domain 1', other_designations='homocysteine-responsive endoplasmic reticulum-resident ubiquitin-like domain member 1 protein|MMS-inducible|homocysteine-inducible endoplasmic reticulum stress-inducible ubiquitin-like domain member 1 protein|homocysteine-inducible, endoplasmic reticulum stress-inducible, ubiquitin-like domain member 1|methyl methanesulfonate (MMF)-inducible fragment protein 1', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56932142, end_position_on_the_genomic_accession=56944864, orientation='plus', exon_count=8, OMIM=[608070], no_hdr0=''),
    9710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9710, CurrentID=0, Status='live', Symbol='GARRE1', Aliases=['KIAA0355'], description='granule associated Rac and RHOG effector 1', other_designations='granule associated Rac and RHOG effector protein 1', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34254554, end_position_on_the_genomic_accession=34355566, orientation='plus', exon_count=14, OMIM=[619335], no_hdr0=''),
    9711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9711, CurrentID=0, Status='live', Symbol='RUBCN', Aliases=['KIAA0226', 'RUBICON', 'SCAR15'], description='rubicon autophagy regulator', other_designations='run domain Beclin-1-interacting and cysteine-rich domain-containing protein|RUN and cysteine rich domain containing beclin 1 interacting protein|RUN domain and cysteine-rich domain containing, Beclin 1-interacting protein|baron|beclin-1 associated RUN domain containing protein|rundataxin', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197668867, end_position_on_the_genomic_accession=197749820, orientation='minus', exon_count=23, OMIM=[613516], no_hdr0=''),
    9712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9712, CurrentID=0, Status='live', Symbol='USP6NL', Aliases=['RNTRE', 'TRE2NL-IT1', 'USP6NL'], description='USP6 N-terminal like', other_designations='USP6 N-terminal-like protein|related to the N-terminus of tre', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=11460510, end_position_on_the_genomic_accession=11611650, orientation='minus', exon_count=23, OMIM=[605405], no_hdr0=''),
    9715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9715, CurrentID=0, Status='live', Symbol='FAM131B', Aliases=[], description='family with sequence similarity 131 member B', other_designations='protein FAM131B', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143353400, end_position_on_the_genomic_accession=143382304, orientation='minus', exon_count=10, OMIM=[619282], no_hdr0=''),
    9716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9716, CurrentID=0, Status='live', Symbol='AQR', Aliases=['IBP160', 'fSAP164'], description='aquarius intron-binding spliceosomal factor', other_designations='RNA helicase aquarius|aquarius homolog|functional spliceosome-associated protein 164|intron-binding protein aquarius|intron-binding protein of 160 kDa', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34851782, end_position_on_the_genomic_accession=34969742, orientation='minus', exon_count=35, OMIM=[610548], no_hdr0=''),
    9717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9717, CurrentID=0, Status='live', Symbol='SEC14L5', Aliases=['PRELID4B'], description='SEC14 like lipid binding 5', other_designations='SEC14-like protein 5|SEC14-like 5', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4958306, end_position_on_the_genomic_accession=5019157, orientation='plus', exon_count=16, OMIM=[619412], no_hdr0=''),
    9718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9718, CurrentID=0, Status='live', Symbol='ECE2', Aliases=['EEF1AKMT4'], description='endothelin converting enzyme 2', other_designations='endothelin-converting enzyme 2|EEF1A lysine methyltransferase 4|EEF1AKMT4-ECE2|EEF1AKMT4-ECE2 readthrough transcript protein', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184276022, end_position_on_the_genomic_accession=184293031, orientation='plus', exon_count=19, OMIM=[610145], no_hdr0=''),
    9719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9719, CurrentID=0, Status='live', Symbol='ADAMTSL2', Aliases=['ADAMTSL-2', 'GPHYSD1'], description='ADAMTS like 2', other_designations='ADAMTS-like protein 2', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133532164, end_position_on_the_genomic_accession=133575519, orientation='plus', exon_count=20, OMIM=[612277], no_hdr0=''),
    9720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9720, CurrentID=0, Status='live', Symbol='CCDC144A', Aliases=[], description='coiled-coil domain containing 144A', other_designations='coiled-coil domain-containing protein 144A', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16666571, end_position_on_the_genomic_accession=16787421, orientation='plus', exon_count=22, OMIM=[619413], no_hdr0=''),
    9721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9721, CurrentID=0, Status='live', Symbol='GPRIN2', Aliases=['GRIN2', 'KIAA0514'], description='G protein regulated inducer of neurite outgrowth 2', other_designations='G protein-regulated inducer of neurite outgrowth 2', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46541736, end_position_on_the_genomic_accession=46557596, orientation='minus', exon_count=10, OMIM=[611240], no_hdr0=''),
    9722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9722, CurrentID=0, Status='live', Symbol='NOS1AP', Aliases=['6330408P19Rik', 'CAPON', 'NPHS22'], description='nitric oxide synthase 1 adaptor protein', other_designations='carboxyl-terminal PDZ ligand of neuronal nitric oxide synthase protein|C-terminal PDZ domain ligand of neuronal nitric oxide synthase (CAPON)|C-terminal PDZ ligand of neuronal nitric oxide synthase protein|ligand of neuronal nitric oxide synthase with carboxyl-terminal PDZ domain|nitric oxide synthase 1 (neuronal) adaptor protein', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162069691, end_position_on_the_genomic_accession=162370475, orientation='plus', exon_count=10, OMIM=[605551], no_hdr0=''),
    9723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9723, CurrentID=0, Status='live', Symbol='SEMA3E', Aliases=['M-SEMAH', 'M-SemaK', 'SEMAH', 'coll-5'], description='semaphorin 3E', other_designations='semaphorin-3E|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3E', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=83363238, end_position_on_the_genomic_accession=83649139, orientation='minus', exon_count=18, OMIM=[608166], no_hdr0=''),
    9724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9724, CurrentID=0, Status='live', Symbol='UTP14C', Aliases=['2700066J21Rik', 'KIAA0266', 'UTP14B'], description='UTP14C small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 14 homolog C|UTP14, U3 small nucleolar ribonucleoprotein, homolog C|UTP14, small subunit processome component homolog C', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52024691, end_position_on_the_genomic_accession=52033600, orientation='plus', exon_count=2, OMIM=[608969], no_hdr0=''),
    9725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9725, CurrentID=0, Status='live', Symbol='TMEM63A', Aliases=['HLD19', 'KIAA0792'], description='transmembrane protein 63A', other_designations='CSC1-like protein 1', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225840556, end_position_on_the_genomic_accession=225882720, orientation='minus', exon_count=28, OMIM=[618685], no_hdr0=''),
    9726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9726, CurrentID=0, Status='live', Symbol='ZNF646', Aliases=[], description='zinc finger protein 646', other_designations='zinc finger protein 646', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31073665, end_position_on_the_genomic_accession=31084196, orientation='plus', exon_count=3, OMIM=[619299], no_hdr0=''),
    9727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9727, CurrentID=0, Status='live', Symbol='RAB11FIP3', Aliases=['CART1', 'FIP3-Rab11', 'Rab11-FIP3'], description='RAB11 family interacting protein 3', other_designations='rab11 family-interacting protein 3|EF hands-containing Rab-interacting protein|MU-MB-17.148|RAB11 family interacting protein 3 (class II)|arfophilin-1|cytoplasmic adaptor for RAR and TR|eferin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=425621, end_position_on_the_genomic_accession=523011, orientation='plus', exon_count=19, OMIM=[608738], no_hdr0=''),
    9728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9728, CurrentID=0, Status='live', Symbol='SECISBP2L', Aliases=['SBP2L', 'SLAN'], description='SECIS binding protein 2 like', other_designations='selenocysteine insertion sequence-binding protein 2-like', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48988638, end_position_on_the_genomic_accession=49046446, orientation='minus', exon_count=18, OMIM=[615756], no_hdr0=''),
    9729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9729, CurrentID=0, Status='live', Symbol='KIAA0408', Aliases=[], description='KIAA0408', other_designations='uncharacterized protein KIAA0408', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127438406, end_position_on_the_genomic_accession=127459389, orientation='minus', exon_count=6, OMIM=[619236], no_hdr0=''),
    9730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9730, CurrentID=0, Status='live', Symbol='DCAF1', Aliases=['RIP', 'VPRBP'], description='DDB1 and CUL4 associated factor 1', other_designations='DDB1- and CUL4-associated factor 1|HIV-1 Vpr-binding protein|Vpr (HIV-1) binding protein|Vpr-binding protein|protein VPRBP|serine/threonine-protein kinase VPRBP|vpr-interacting protein', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51394261, end_position_on_the_genomic_accession=51505620, orientation='minus', exon_count=31, OMIM=[617259], no_hdr0=''),
    9731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9731, CurrentID=0, Status='live', Symbol='CEP104', Aliases=['CFAP256', 'GlyBP', 'JBTS25', 'KIAA0562', 'ROC22'], description='centrosomal protein 104', other_designations='centrosomal protein of 104 kDa|centrosomal protein 104kDa', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3812086, end_position_on_the_genomic_accession=3857233, orientation='minus', exon_count=24, OMIM=[616690], no_hdr0=''),
    9732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9732, CurrentID=0, Status='live', Symbol='DOCK4', Aliases=[], description='dedicator of cytokinesis 4', other_designations='dedicator of cytokinesis protein 4', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=111726110, end_position_on_the_genomic_accession=112206399, orientation='minus', exon_count=55, OMIM=[607679], no_hdr0=''),
    9733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9733, CurrentID=0, Status='live', Symbol='SART3', Aliases=['DSAP1', 'P100', 'RP11-13G14', 'TIP110', 'p110', 'p110(nrb)'], description='spliceosome associated factor 3, U4/U6 recycling protein', other_designations='squamous cell carcinoma antigen recognized by T-cells 3|HIV-1 Tat-interacting protein of 110kDa|PRP24 homolog|SART-3|hSART-3|p110 nuclear RNA-binding protein|squamous cell carcinoma antigen recognized by T cells 3|tat-interacting protein of 110 kDa', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108522214, end_position_on_the_genomic_accession=108561173, orientation='minus', exon_count=20, OMIM=[611684], no_hdr0=''),
    9734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9734, CurrentID=0, Status='live', Symbol='HDAC9', Aliases=['HD7', 'HD7b', 'HD9', 'HDAC', 'HDAC7', 'HDAC7BB', 'HDAC9FL', 'HDRP', 'MITR', 'HDAC9'], description='histone deacetylase 9', other_designations='histone deacetylase 9|MEF-2 interacting transcription repressor (MITR) protein|histone deacetylase 4/5-related protein|histone deacetylase 7B', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=18086825, end_position_on_the_genomic_accession=19002416, orientation='plus', exon_count=38, OMIM=[606543], no_hdr0=''),
    9735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9735, CurrentID=0, Status='live', Symbol='KNTC1', Aliases=['ROD'], description='kinetochore associated 1', other_designations='kinetochore-associated protein 1|Rough Deal homolog, centromere/kinetochore protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122527106, end_position_on_the_genomic_accession=122626409, orientation='plus', exon_count=68, OMIM=[607363], no_hdr0=''),
    9736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9736, CurrentID=0, Status='live', Symbol='USP34', Aliases=[], description='ubiquitin specific peptidase 34', other_designations='ubiquitin carboxyl-terminal hydrolase 34|deubiquitinating enzyme 34|ubiquitin specific protease 34|ubiquitin thioesterase 34|ubiquitin thiolesterase 34|ubiquitin-specific-processing protease 34', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61187463, end_position_on_the_genomic_accession=61471087, orientation='minus', exon_count=80, OMIM=[615295], no_hdr0=''),
    9737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9737, CurrentID=0, Status='live', Symbol='GPRASP1', Aliases=['GASP', 'GASP-1', 'GASP1'], description='G protein-coupled receptor associated sorting protein 1', other_designations='G-protein coupled receptor-associated sorting protein 1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102651483, end_position_on_the_genomic_accession=102659083, orientation='plus', exon_count=6, OMIM=[300417], no_hdr0=''),
    9738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9738, CurrentID=0, Status='live', Symbol='CCP110', Aliases=['CP110', 'Cep110'], description='centriolar coiled-coil protein 110', other_designations='centriolar coiled-coil protein of 110 kDa|centriolar coiled-coil protein 110kDa|centrosomal protein CP110|centrosomal protein of 110 kDa', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19523879, end_position_on_the_genomic_accession=19553408, orientation='plus', exon_count=17, OMIM=[609544], no_hdr0=''),
    9739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9739, CurrentID=0, Status='live', Symbol='SETD1A', Aliases=['EPEDD', 'KMT2F', 'NEDSID', 'Set1', 'Set1A'], description='SET domain containing 1A, histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase SETD1A|SET domain-containing protein 1A|hSET1A|lysine N-methyltransferase 2F|set1/Ash2 histone methyltransferase complex subunit SET1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30956618, end_position_on_the_genomic_accession=30984664, orientation='plus', exon_count=22, OMIM=[611052], no_hdr0=''),
    9741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9741, CurrentID=0, Status='live', Symbol='LAPTM4A', Aliases=['HUMORF13', 'LAPTM4', 'MBNT', 'Mtrp'], description='lysosomal protein transmembrane 4 alpha', other_designations='lysosomal-associated transmembrane protein 4A|golgi 4-transmembrane-spanning transporter MTP|lysosomal-associated protein transmembrane 4 alpha|membrane nucleoside transporter', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20032650, end_position_on_the_genomic_accession=20051628, orientation='minus', exon_count=7, OMIM=[618837], no_hdr0=''),
    9742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9742, CurrentID=0, Status='live', Symbol='IFT140', Aliases=['MZSDS', 'RP80', 'SRTD9', 'WDTC2', 'c305C8.4', 'c380F5.1', 'gs114'], description='intraflagellar transport 140', other_designations='intraflagellar transport protein 140 homolog|WD and tetratricopeptide repeats protein 2|intraflagellar transport 140 homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1510427, end_position_on_the_genomic_accession=1612072, orientation='minus', exon_count=40, OMIM=[614620], no_hdr0=''),
    9743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9743, CurrentID=0, Status='live', Symbol='ARHGAP32', Aliases=['GC-GAP', 'GRIT', 'PX-RICS', 'RICS', 'p200RhoGAP', 'p250GAP'], description='Rho GTPase activating protein 32', other_designations='rho GTPase-activating protein 32|GAB-associated CDC42|GAB-associated Cdc42/Rac GTPase-activating protein|GTPase regulator interacting with TrkA|GTPase-activating protein for Cdc42 and Rac1|RhoGAP involved in the -catenin-N-cadherin and NMDA receptor signaling|brain-specific Rho GTP-ase-activating protein|brain-specific Rho GTPase-activating protein|rac GTPase activating protein|rho-type GTPase-activating protein 32|rho/Cdc42/Rac GTPase-activating protein RICS|rhoGAP involved in the beta-catenin-N-cadherin and NMDA receptor signaling', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128965060, end_position_on_the_genomic_accession=129279518, orientation='minus', exon_count=30, OMIM=[608541], no_hdr0=''),
    9744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9744, CurrentID=0, Status='live', Symbol='ACAP1', Aliases=['CENTB1'], description='ArfGAP with coiled-coil, ankyrin repeat and PH domains 1', other_designations='arf-GAP with coiled-coil, ANK repeat and PH domain-containing protein 1|Arf GAP with coiled coil, ANK repeat and PH domains 1|centaurin-beta-1|cnt-b1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7336506, end_position_on_the_genomic_accession=7354944, orientation='plus', exon_count=22, OMIM=[607763], no_hdr0=''),
    9745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9745, CurrentID=0, Status='live', Symbol='ZNF536', Aliases=[], description='zinc finger protein 536', other_designations='zinc finger protein 536', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=30224236, end_position_on_the_genomic_accession=30713586, orientation='plus', exon_count=20, OMIM=[618037], no_hdr0=''),
    9746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9746, CurrentID=0, Status='live', Symbol='CLSTN3', Aliases=['CDHR14', 'CSTN3', 'alcbeta'], description='calsyntenin 3', other_designations='calsyntenin-3|alc-beta|alcadein beta|cadherin-related family member 14', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7130371, end_position_on_the_genomic_accession=7158945, orientation='plus', exon_count=18, OMIM=[611324], no_hdr0=''),
    9747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9747, CurrentID=0, Status='live', Symbol='TCAF1', Aliases=['FAM115A', 'GATD9A'], description='TRPM8 channel associated factor 1', other_designations='TRPM8 channel-associated factor 1|TRP channel-associated factor 1|family with sequence similarity 115, member A|protein FAM115A', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143851375, end_position_on_the_genomic_accession=143902198, orientation='minus', exon_count=12, OMIM=[616251], no_hdr0=''),
    9748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9748, CurrentID=0, Status='live', Symbol='SLK', Aliases=['LOSK', 'STK2', 'bA16H23.1', 'se20-9'], description='STE20 like kinase', other_designations='STE20-like serine/threonine-protein kinase|CTCL tumor antigen se20-9|Long Ste20-like Kinase|SNF1 (sucrose nonfermenting, yeast, homolog)-like kinase, SNF1 sucrose nonfermenting like kinase|SNF1 sucrose nonfermenting like kinase|STE20-related kinase|STE20-related serine/threonine-protein kinase|Ste20-related serine/threonine kinase|hSLK|serine/threonine-protein kinase 2', map_location='10q24.33-q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103967100, end_position_on_the_genomic_accession=104029233, orientation='plus', exon_count=19, OMIM=[616563], no_hdr0=''),
    9749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9749, CurrentID=0, Status='live', Symbol='PHACTR2', Aliases=['C6orf56'], description='phosphatase and actin regulator 2', other_designations='phosphatase and actin regulator 2', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143536878, end_position_on_the_genomic_accession=143831185, orientation='plus', exon_count=16, OMIM=[608724], no_hdr0=''),
    9750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9750, CurrentID=0, Status='live', Symbol='RIPOR2', Aliases=['C6orf32', 'DFNB104', 'DIFF40', 'DIFF48', 'FAM65B', 'MYONAP', 'PL48'], description='RHO family interacting cell polarization regulator 2', other_designations='rho family-interacting cell polarization regulator 2|family with sequence similarity 65 member B|myogenesis-related and NCAM-associated protein homolog|protein FAM65B', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24804284, end_position_on_the_genomic_accession=25042288, orientation='minus', exon_count=31, OMIM=[611410], no_hdr0=''),
    9751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9751, CurrentID=0, Status='live', Symbol='SNPH', Aliases=[], description='syntaphilin', other_designations='syntaphilin', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1266292, end_position_on_the_genomic_accession=1309327, orientation='plus', exon_count=7, OMIM=[604942], no_hdr0=''),
    9752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9752, CurrentID=0, Status='live', Symbol='PCDHA9', Aliases=['PCDH-ALPHA9'], description='protocadherin alpha 9', other_designations='protocadherin alpha-9|KIAA0345-like 5|PCDH-alpha-9', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140847772, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606315], no_hdr0=''),
    9753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9753, CurrentID=0, Status='live', Symbol='ZSCAN12', Aliases=['ZFP96', 'ZNF29K1', 'ZNF305', 'ZNF96', 'dJ29K1.2'], description='zinc finger and SCAN domain containing 12', other_designations='zinc finger and SCAN domain-containing protein 12|zinc finger protein 305|zinc finger protein 96', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28378821, end_position_on_the_genomic_accession=28399768, orientation='minus', exon_count=8, OMIM=[603978], no_hdr0=''),
    9754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9754, CurrentID=0, Status='live', Symbol='STARD8', Aliases=['ARHGAP38', 'DLC3', 'STARTGAP3'], description='StAR related lipid transfer domain containing 8', other_designations='stAR-related lipid transfer protein 8|START domain containing 8|StAR-related lipid transfer (START) domain containing 8|deleted in liver cancer 3 protein', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=68647666, end_position_on_the_genomic_accession=68725842, orientation='plus', exon_count=17, OMIM=[300689], no_hdr0=''),
    9755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9755, CurrentID=0, Status='live', Symbol='TBKBP1', Aliases=['ProSAPiP2', 'SINTBAD'], description='TBK1 binding protein 1', other_designations='TANK-binding kinase 1-binding protein 1', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47694063, end_position_on_the_genomic_accession=47712063, orientation='plus', exon_count=14, OMIM=[608476], no_hdr0=''),
    9757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9757, CurrentID=0, Status='live', Symbol='KMT2B', Aliases=['CXXC10', 'DYT28', 'HRX2', 'MLL1B', 'MLL2', 'MLL4', 'TRX2', 'WBP-7', 'WBP7'], description='lysine methyltransferase 2B', other_designations='histone-lysine N-methyltransferase 2B|WW domain binding protein 7|histone-lysine N-methyltransferase MLL4|lysine (K)-specific methyltransferase 2B|mixed lineage leukemia gene homolog 2|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila) 4|myeloid/lymphoid or mixed-lineage leukemia protein 4|trithorax homologue 2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35717818, end_position_on_the_genomic_accession=35738878, orientation='plus', exon_count=38, OMIM=[606834], no_hdr0=''),
    9758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9758, CurrentID=0, Status='live', Symbol='FRMPD4', Aliases=['MRX104', 'PDZD10', 'PDZK10'], description='FERM and PDZ domain containing 4', other_designations='FERM and PDZ domain-containing protein 4|PDZ domain-containing protein 10|PSD-95-interacting FERM and PDZ domain protein|PSD-95-interacting regulator of spine morphogenesis|Preso', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=11822439, end_position_on_the_genomic_accession=12724523, orientation='plus', exon_count=24, OMIM=[300838], no_hdr0=''),
    9759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9759, CurrentID=0, Status='live', Symbol='HDAC4', Aliases=['AHO3', 'BDMR', 'HA6116', 'HD4', 'HDAC-4', 'HDAC-A', 'HDACA'], description='histone deacetylase 4', other_designations='histone deacetylase 4|histone deacetylase A', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=239048168, end_position_on_the_genomic_accession=239401649, orientation='minus', exon_count=36, OMIM=[605314], no_hdr0=''),
    9760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9760, CurrentID=0, Status='live', Symbol='TOX', Aliases=['TOX1'], description='thymocyte selection associated high mobility group box', other_designations='thymocyte selection-associated high mobility group box protein TOX|thymus high mobility group box protein TOX', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=58805412, end_position_on_the_genomic_accession=59119147, orientation='minus', exon_count=9, OMIM=[606863], no_hdr0=''),
    9761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9761, CurrentID=0, Status='live', Symbol='MLEC', Aliases=['KIAA0152'], description='malectin', other_designations='malectin|oligosaccharyltransferase complex subunit (non-catalytic)', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120687149, end_position_on_the_genomic_accession=120701859, orientation='plus', exon_count=6, OMIM=[613802], no_hdr0=''),
    9762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9762, CurrentID=0, Status='live', Symbol='LZTS3', Aliases=['PROSAPIP1'], description='leucine zipper tumor suppressor family member 3', other_designations='leucine zipper putative tumor suppressor 3|ProSAP/Shank-interacting protein 1|leucine zipper, putative tumor suppressor family member 3|proline rich synapse associated protein interacting protein 1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3162617, end_position_on_the_genomic_accession=3173549, orientation='minus', exon_count=7, OMIM=[610484], no_hdr0=''),
    9764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9764, CurrentID=0, Status='live', Symbol='KIAA0513', Aliases=[], description='KIAA0513', other_designations='uncharacterized protein KIAA0513', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85027795, end_position_on_the_genomic_accession=85094230, orientation='plus', exon_count=15, OMIM=[611675], no_hdr0=''),
    9765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9765, CurrentID=0, Status='live', Symbol='ZFYVE16', Aliases=['PPP1R69'], description='zinc finger FYVE-type containing 16', other_designations='zinc finger FYVE domain-containing protein 16|endosome-associated FYVE-domain protein|protein phosphatase 1, regulatory subunit 69|zinc finger, FYVE domain containing 16', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80407615, end_position_on_the_genomic_accession=80483379, orientation='plus', exon_count=24, OMIM=[608880], no_hdr0=''),
    9766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9766, CurrentID=0, Status='live', Symbol='SUSD6', Aliases=['DRAGO', 'KIAA0247'], description='sushi domain containing 6', other_designations='sushi domain-containing protein 6|drug-activated gene overexpressed protein', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69611596, end_position_on_the_genomic_accession=69715144, orientation='plus', exon_count=6, OMIM=[616761], no_hdr0=''),
    9767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9767, CurrentID=0, Status='live', Symbol='JADE3', Aliases=['JADE-3', 'PHF16'], description='jade family PHD finger 3', other_designations='protein Jade-3|PHD finger protein 16|jade family PHD finger protein 3', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46912301, end_position_on_the_genomic_accession=47061242, orientation='plus', exon_count=12, OMIM=[300618], no_hdr0=''),
    9768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9768, CurrentID=0, Status='live', Symbol='PCLAF', Aliases=['KIAA0101', 'L5', 'NS5ATP9', 'OEATC', 'OEATC-1', 'OEATC1', 'PAF', 'PAF15', 'p15(PAF)', 'p15/PAF', 'p15PAF'], description='PCNA clamp associated factor', other_designations='PCNA-associated factor|HCV NS5A-transactivated protein 9|PCNA-associated factor of 15 kDa|hepatitis C virus NS5A-transactivated protein 9|overexpressed in anaplastic thyroid carcinoma 1', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64364304, end_position_on_the_genomic_accession=64387687, orientation='minus', exon_count=5, OMIM=[610696], no_hdr0=''),
    9770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9770, CurrentID=0, Status='live', Symbol='RASSF2', Aliases=['CENP-34', 'RASFADIN'], description='Ras association domain family member 2', other_designations='ras association domain-containing protein 2|Ras association (RalGDS/AF-6) domain family 2|Ras association (RalGDS/AF-6) domain family member 2|centromere protein 34', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4780023, end_position_on_the_genomic_accession=4823668, orientation='minus', exon_count=15, OMIM=[609492], no_hdr0=''),
    9771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9771, CurrentID=0, Status='live', Symbol='RAPGEF5', Aliases=['GFR', 'MR-GEF', 'REPAC'], description='Rap guanine nucleotide exchange factor 5', other_designations='rap guanine nucleotide exchange factor 5|M-Ras-regulated GEF|M-Ras-regulated Rap GEF|Rap guanine nucleotide exchange factor (GEF) 5|guanine nucleotide exchange factor for Rap1|related to Epac', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=22118236, end_position_on_the_genomic_accession=22357154, orientation='minus', exon_count=32, OMIM=[609527], no_hdr0=''),
    9772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9772, CurrentID=0, Status='live', Symbol='TMEM94', Aliases=['IDDCDF', 'KIAA0195'], description='transmembrane protein 94', other_designations='transmembrane protein 94', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75441159, end_position_on_the_genomic_accession=75500452, orientation='plus', exon_count=36, OMIM=[618163], no_hdr0=''),
    9774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9774, CurrentID=0, Status='live', Symbol='BCLAF1', Aliases=['BTF', 'bK211L9.1'], description='BCL2 associated transcription factor 1', other_designations='bcl-2-associated transcription factor 1|BCLAF1 and THRAP3 family member 1', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136256627, end_position_on_the_genomic_accession=136289846, orientation='minus', exon_count=18, OMIM=[612588], no_hdr0=''),
    9775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9775, CurrentID=0, Status='live', Symbol='EIF4A3', Aliases=['DDX48', 'Fal1', 'MUK34', 'NMP265', 'NUK34', 'RCPS', 'eIF-4A-III', 'eIF4A-III', 'eIF4AIII'], description='eukaryotic translation initiation factor 4A3', other_designations='eukaryotic initiation factor 4A-III|ATP-dependent RNA helicase DDX48|ATP-dependent RNA helicase eIF4A-3|DEAD (Asp-Glu-Ala-Asp) box polypeptide 48|DEAD box protein 48|NMP 265|eukaryotic initiation factor 4A-like NUK-34|nuclear matrix protein 265', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80134369, end_position_on_the_genomic_accession=80147128, orientation='minus', exon_count=12, OMIM=[608546], no_hdr0=''),
    9776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9776, CurrentID=0, Status='live', Symbol='ATG13', Aliases=['KIAA0652', 'PARATARG8'], description='autophagy related 13', other_designations='autophagy-related protein 13|ATG13 autophagy related 13 homolog', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46617527, end_position_on_the_genomic_accession=46674518, orientation='plus', exon_count=26, OMIM=[615088], no_hdr0=''),
    9777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9777, CurrentID=0, Status='live', Symbol='TM9SF4', Aliases=['dJ836N17.2'], description='transmembrane 9 superfamily member 4', other_designations='transmembrane 9 superfamily member 4|dinucleotide oxidase disulfide thiol exchanger 3 superfamily member 4|transmembrane 9 superfamily protein member 4|tumor cannibalism associated protein 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32109714, end_position_on_the_genomic_accession=32167256, orientation='plus', exon_count=19, OMIM=[617727], no_hdr0=''),
    9778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9778, CurrentID=0, Status='live', Symbol='KIAA0232', Aliases=[], description='KIAA0232', other_designations='uncharacterized protein KIAA0232', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6782727, end_position_on_the_genomic_accession=6884164, orientation='plus', exon_count=14, OMIM=[619237], no_hdr0=''),
    9779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9779, CurrentID=0, Status='live', Symbol='TBC1D5', Aliases=[], description='TBC1 domain family member 5', other_designations='TBC1 domain family member 5', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=17157162, end_position_on_the_genomic_accession=17742739, orientation='minus', exon_count=36, OMIM=[615740], no_hdr0=''),
    9780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9780, CurrentID=0, Status='live', Symbol='PIEZO1', Aliases=['DHS', 'FAM38A', 'LMPH3', 'LMPHM6', 'Mib'], description='piezo type mechanosensitive ion channel component 1', other_designations='piezo-type mechanosensitive ion channel component 1|family with sequence similarity 38, member A|membrane protein induced by beta-amyloid treatment', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88715338, end_position_on_the_genomic_accession=88785220, orientation='minus', exon_count=51, OMIM=[611184], no_hdr0=''),
    9781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9781, CurrentID=0, Status='live', Symbol='RNF144A', Aliases=['RNF144', 'UBCE7IP4', 'hUIP4'], description='ring finger protein 144A', other_designations='E3 ubiquitin-protein ligase RNF144A|UbcM4-interacting protein 4|probable E3 ubiquitin-protein ligase RNF144A|ring finger protein 144|ubiquitin conjugating enzyme 7 interacting protein 4', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=6917412, end_position_on_the_genomic_accession=7076886, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    9782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9782, CurrentID=0, Status='live', Symbol='MATR3', Aliases=['ALS21', 'MPD2', 'VCPDM'], description='matrin 3', other_designations='matrin-3|vocal cord and pharyngeal weakness with distal myopathy', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139274101, end_position_on_the_genomic_accession=139331677, orientation='plus', exon_count=19, OMIM=[164015], no_hdr0=''),
    9783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9783, CurrentID=0, Status='live', Symbol='RIMS3', Aliases=['NIM3', 'RIM 3', 'RIM3'], description='regulating synaptic membrane exocytosis 3', other_designations='regulating synaptic membrane exocytosis protein 3|RIM3 gamma|Rab-3 interacting molecule 3|rab-3-interacting molecule 3', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40620680, end_position_on_the_genomic_accession=40692104, orientation='minus', exon_count=9, OMIM=[611600], no_hdr0=''),
    9784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9784, CurrentID=0, Status='live', Symbol='SNX17', Aliases=[], description='sorting nexin 17', other_designations='sorting nexin-17', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27370616, end_position_on_the_genomic_accession=27377535, orientation='plus', exon_count=16, OMIM=[605963], no_hdr0=''),
    9785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9785, CurrentID=0, Status='live', Symbol='DHX38', Aliases=['DDX38', 'PRP16', 'PRPF16', 'RP84'], description='DEAH-box helicase 38', other_designations='pre-mRNA-splicing factor ATP-dependent RNA helicase PRP16|ATP-dependent RNA helicase DHX38|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 38|DEAH (Asp-Glu-Ala-His) box polypeptide 38|DEAH box protein 38|PRP16 homolog of S.cerevisiae', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72093665, end_position_on_the_genomic_accession=72112912, orientation='plus', exon_count=28, OMIM=[605584], no_hdr0=''),
    9786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9786, CurrentID=0, Status='live', Symbol='KIAA0586', Aliases=['JBTS23', 'SRTD14', 'Talpid3'], description='KIAA0586', other_designations='protein TALPID3', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58427400, end_position_on_the_genomic_accession=58551297, orientation='plus', exon_count=39, OMIM=[610178], no_hdr0=''),
    9787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9787, CurrentID=0, Status='live', Symbol='DLGAP5', Aliases=['DLG7', 'HURP'], description='DLG associated protein 5', other_designations='disks large-associated protein 5|DAP-5|discs large homolog associated protein 5|discs, large homolog 7|disks large-associated protein DLG7|hepatoma up-regulated protein', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55148130, end_position_on_the_genomic_accession=55191585, orientation='minus', exon_count=21, OMIM=[617859], no_hdr0=''),
    9788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9788, CurrentID=0, Status='live', Symbol='MTSS1', Aliases=['MIM', 'MIMA', 'MIMB'], description='MTSS I-BAR domain containing 1', other_designations='protein MTSS 1|MTSS1, I-BAR domain containing|metastasis suppressor 1|metastasis suppressor YGL-1|metastasis suppressor protein 1|missing in metastasis protein', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124550784, end_position_on_the_genomic_accession=124728473, orientation='minus', exon_count=19, OMIM=[608486], no_hdr0=''),
    9789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9789, CurrentID=0, Status='live', Symbol='SPCS2', Aliases=[], description='signal peptidase complex subunit 2', other_designations='signal peptidase complex subunit 2|SPase 25 kDa subunit|microsomal signal peptidase 25 kDa subunit|signal peptidase 25kDa subunit|signal peptidase complex subunit 2 homolog', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74949266, end_position_on_the_genomic_accession=74979033, orientation='plus', exon_count=5, OMIM=[619411], no_hdr0=''),
    9790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9790, CurrentID=0, Status='live', Symbol='BMS1', Aliases=['ACCL', 'BMS1'], description='BMS1 ribosome biogenesis factor', other_designations='ribosome biogenesis protein BMS1 homolog|BMS1 homolog, ribosome assembly protein|BMS1-like, ribosome assembly protein|ribosome assembly protein BMS1 homolog', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=42782775, end_position_on_the_genomic_accession=42834937, orientation='plus', exon_count=24, OMIM=[611448], no_hdr0=''),
    9791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9791, CurrentID=0, Status='live', Symbol='PTDSS1', Aliases=['LMHD', 'PSS1', 'PSSA'], description='phosphatidylserine synthase 1', other_designations='phosphatidylserine synthase 1|PSS-1|ptdSer synthase 1|serine-exchange enzyme I', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96261902, end_position_on_the_genomic_accession=96336995, orientation='plus', exon_count=13, OMIM=[612792], no_hdr0=''),
    9792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9792, CurrentID=0, Status='live', Symbol='SERTAD2', Aliases=['Sei-2', 'TRIP-Br2', 'TRIPBR2'], description='SERTA domain containing 2', other_designations='SERTA domain-containing protein 2|transcriptional regulator interacting with the PHD-bromodomain 2|transcriptional regulator interacting with the PHS-bromodomain 2', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=64631621, end_position_on_the_genomic_accession=64751086, orientation='minus', exon_count=4, OMIM=[617851], no_hdr0=''),
    9793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9793, CurrentID=0, Status='live', Symbol='CKAP5', Aliases=['CHTOG', 'MSPS', 'TOG', 'TOGp', 'ch-TOG'], description='cytoskeleton associated protein 5', other_designations='cytoskeleton-associated protein 5|colonic and hepatic tumor over-expressed gene protein|colonic and hepatic tumor overexpressed gene protein', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46743048, end_position_on_the_genomic_accession=46846280, orientation='minus', exon_count=44, OMIM=[611142], no_hdr0=''),
    9794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9794, CurrentID=0, Status='live', Symbol='MAML1', Aliases=['Mam-1', 'Mam1'], description='mastermind like transcriptional coactivator 1', other_designations='mastermind-like protein 1|mastermind homolog|mastermind-like 1', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179732822, end_position_on_the_genomic_accession=179777283, orientation='plus', exon_count=5, OMIM=[605424], no_hdr0=''),
    9796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9796, CurrentID=0, Status='live', Symbol='PHYHIP', Aliases=['DYRK1AP3', 'PAHX-AP', 'PAHXAP1'], description='phytanoyl-CoA 2-hydroxylase interacting protein', other_designations='phytanoyl-CoA hydroxylase-interacting protein|DYRK1A interacting protein 3|PAHX-AP1|phytanoyl-CoA alpha-hydroxylase associated protein|phytanoyl-CoA hydroxylase-associated protein 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22219703, end_position_on_the_genomic_accession=22232099, orientation='minus', exon_count=8, OMIM=[608511], no_hdr0=''),
    9797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9797, CurrentID=0, Status='live', Symbol='TATDN2', Aliases=[], description='TatD DNase domain containing 2', other_designations='putative deoxyribonuclease TATDN2', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10248459, end_position_on_the_genomic_accession=10281218, orientation='plus', exon_count=8, OMIM=[619330], no_hdr0=''),
    9798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9798, CurrentID=0, Status='live', Symbol='IST1', Aliases=['CHMP8', 'OLC1'], description='IST1 factor associated with ESCRT-III', other_designations='IST1 homolog|IST1, ESCRT-III associated factor|IST1, endosomal sorting complex required for transport-III component|increased sodium tolerance 1 homolog|overexpressed in lung cancer 1|putative MAPK-activating protein PM28', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71894408, end_position_on_the_genomic_accession=71931199, orientation='plus', exon_count=12, OMIM=[616434], no_hdr0=''),
    9801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9801, CurrentID=0, Status='live', Symbol='MRPL19', Aliases=['L19mt', 'MRP-L15', 'MRP-L19', 'MRPL15', 'RLX1', 'RPML15'], description='mitochondrial ribosomal protein L19', other_designations='39S ribosomal protein L19, mitochondrial|39S ribosomal protein L15, mitochondrial|L15mt|mitochondrial large ribosomal subunit protein bL19m', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=75646783, end_position_on_the_genomic_accession=75662206, orientation='plus', exon_count=6, OMIM=[611832], no_hdr0=''),
    9802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9802, CurrentID=0, Status='live', Symbol='DAZAP2', Aliases=['PRTB'], description='DAZ associated protein 2', other_designations='DAZ-associated protein 2|deleted in azoospermia associated protein 2|proline-rich transcript in brain|proline-rich transcript, brain-expressed protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51238826, end_position_on_the_genomic_accession=51246717, orientation='plus', exon_count=5, OMIM=[607431], no_hdr0=''),
    9804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9804, CurrentID=0, Status='live', Symbol='TOMM20', Aliases=['MAS20', 'MOM19', 'TOM20'], description='translocase of outer mitochondrial membrane 20', other_designations='mitochondrial import receptor subunit TOM20 homolog|mitochondrial 20 kDa outer membrane protein|outer mitochondrial membrane receptor Tom20|translocase of outer mitochondrial membrane 20 homolog type II', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235109341, end_position_on_the_genomic_accession=235128837, orientation='minus', exon_count=5, OMIM=[601848], no_hdr0=''),
    9805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9805, CurrentID=0, Status='live', Symbol='SCRN1', Aliases=['SES1'], description='secernin 1', other_designations='secernin-1', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=29920103, end_position_on_the_genomic_accession=29990289, orientation='minus', exon_count=11, OMIM=[614965], no_hdr0=''),
    9806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9806, CurrentID=0, Status='live', Symbol='SPOCK2', Aliases=['testican-2'], description='SPARC (osteonectin), cwcv and kazal like domains proteoglycan 2', other_designations='testican-2|SPARC/osteonectin, CWCV, and Kazal-like domains proteoglycan 2|SPARC/osteonectin, cwcv and kazal like domains proteoglycan 2|sparc/osteonectin, cwcv and kazal-like domains proteoglycan (testican) 2', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72059034, end_position_on_the_genomic_accession=72095313, orientation='minus', exon_count=14, OMIM=[607988], no_hdr0=''),
    9807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9807, CurrentID=0, Status='live', Symbol='IP6K1', Aliases=['IHPK1', 'PiUS'], description='inositol hexakisphosphate kinase 1', other_designations='inositol hexakisphosphate kinase 1|ATP:1D-myo-inositol-hexakisphosphate phosphotransferase|Pi uptake stimulator|inositol hexaphosphate kinase 1|insP6 kinase 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49724294, end_position_on_the_genomic_accession=49786542, orientation='minus', exon_count=7, OMIM=[606991], no_hdr0=''),
    9810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9810, CurrentID=0, Status='live', Symbol='RNF40', Aliases=['BRE1B', 'RBP95', 'STARING'], description='ring finger protein 40', other_designations='E3 ubiquitin-protein ligase BRE1B|95 kDa retinoblastoma protein binding protein|95 kDa retinoblastoma-associated protein|BRE1 E3 ubiquitin ligase homolog B|BRE1-B|RING-type E3 ubiquitin transferase BRE1B|Rb-associated protein|ring finger protein 40, E3 ubiquitin protein ligase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30761612, end_position_on_the_genomic_accession=30800231, orientation='plus', exon_count=22, OMIM=[607700], no_hdr0=''),
    9811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9811, CurrentID=0, Status='live', Symbol='CTIF', Aliases=['Gm672', 'KIAA0427'], description='cap binding complex dependent translation initiation factor', other_designations='CBP80/20-dependent translation initiation factor', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=48539031, end_position_on_the_genomic_accession=48863217, orientation='plus', exon_count=17, OMIM=[613178], no_hdr0=''),
    9812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9812, CurrentID=0, Status='live', Symbol='DELE1', Aliases=['DELE(L)', 'KIAA0141', 'DELE1'], description='DAP3 binding cell death enhancer 1', other_designations='death ligand signal enhancer|DAP3-binding cell death enhancer 1, long form', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141923871, end_position_on_the_genomic_accession=141952031, orientation='plus', exon_count=18, OMIM=[615741], no_hdr0=''),
    9813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9813, CurrentID=0, Status='live', Symbol='EFCAB14', Aliases=['KIAA0494'], description='EF-hand calcium binding domain 14', other_designations='EF-hand calcium-binding domain-containing protein 14', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46675159, end_position_on_the_genomic_accession=46719114, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    9814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9814, CurrentID=0, Status='live', Symbol='SFI1', Aliases=['PISD', 'PPP1R139', 'hSfi1p'], description='SFI1 centrin binding protein', other_designations='protein SFI1 homolog|Sfi1 homolog, spindle assembly associated|homolog of yeast Sfi1|protein phosphatase 1, regulatory subunit 139', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31496139, end_position_on_the_genomic_accession=31618588, orientation='plus', exon_count=35, OMIM=[612765], no_hdr0=''),
    9815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9815, CurrentID=0, Status='live', Symbol='GIT2', Aliases=['CAT-2', 'CAT2', 'PKL'], description='GIT ArfGAP 2', other_designations='ARF GTPase-activating protein GIT2|ARF GAP GIT2|G protein-coupled receptor kinase interacting ArfGAP 2|G protein-coupled receptor kinase-interactor 2|GRK-interacting protein 2|Paxillin kinase linker|cool-associated, tyrosine phosphorylated protein 2|cool-interacting tyrosine-phosphorylated protein 2', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109929792, end_position_on_the_genomic_accession=109996368, orientation='minus', exon_count=22, OMIM=[608564], no_hdr0=''),
    9816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9816, CurrentID=0, Status='live', Symbol='URB2', Aliases=['KIAA0133', 'NET10', 'NPA2'], description='URB2 ribosome biogenesis homolog', other_designations='unhealthy ribosome biogenesis protein 2 homolog|URB2 ribosome biogenesis 2 homolog|nucleolar preribosomal-associated protein 1|nucleolar preribosomal-associated protein 2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229626247, end_position_on_the_genomic_accession=229660200, orientation='plus', exon_count=10, OMIM=[619372], no_hdr0=''),
    9817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9817, CurrentID=0, Status='live', Symbol='KEAP1', Aliases=['INrf2', 'KLHL19'], description='kelch like ECH associated protein 1', other_designations='kelch-like ECH-associated protein 1|KEAP1 delta C|cytosolic inhibitor of Nrf2|kelch-like family member 19|kelch-like protein 19', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10486125, end_position_on_the_genomic_accession=10503356, orientation='minus', exon_count=9, OMIM=[606016], no_hdr0=''),
    9818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9818, CurrentID=0, Status='live', Symbol='NUP58', Aliases=['NUP45', 'NUPL1', 'PRO2463'], description='nucleoporin 58', other_designations='nucleoporin p58/p45|58 kDa nucleoporin|nucleoporin 58kDa|nucleoporin like 1|nucleoporin-like protein 1', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=25301084, end_position_on_the_genomic_accession=25349795, orientation='plus', exon_count=18, OMIM=[607615], no_hdr0=''),
    9819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9819, CurrentID=0, Status='live', Symbol='TSC22D2', Aliases=['TILZ4a', 'TILZ4b', 'TILZ4c'], description='TSC22 domain family member 2', other_designations='TSC22 domain family protein 2|TSC22 domain family 2|TSC22-related-inducible leucine zipper protein 4', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150408298, end_position_on_the_genomic_accession=150466422, orientation='plus', exon_count=6, OMIM=[617724], no_hdr0=''),
    9820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9820, CurrentID=0, Status='live', Symbol='CUL7', Aliases=['3M1', 'CUL-7', 'KIAA0076', 'dJ20C7.5'], description='cullin 7', other_designations='cullin-7', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43037617, end_position_on_the_genomic_accession=43053945, orientation='minus', exon_count=27, OMIM=[609577], no_hdr0=''),
    9821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9821, CurrentID=0, Status='live', Symbol='RB1CC1', Aliases=['ATG17', 'CC1', 'FIP200', 'PPP1R131'], description='RB1 inducible coiled-coil 1', other_designations='RB1-inducible coiled-coil protein 1|200 kDa FAK family kinase-interacting protein|FAK family kinase-interacting protein of 200 kDa|phosphatase 1, regulatory subunit 131', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=52622458, end_position_on_the_genomic_accession=52714466, orientation='minus', exon_count=28, OMIM=[606837], no_hdr0=''),
    9823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9823, CurrentID=0, Status='live', Symbol='ARMCX2', Aliases=['ALEX2', 'GASP9'], description='armadillo repeat containing X-linked 2', other_designations='armadillo repeat-containing X-linked protein 2|ARM protein lost in epithelial cancers on chromosome X 2|armadillo repeat protein ALEX2', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101655281, end_position_on_the_genomic_accession=101659878, orientation='minus', exon_count=6, OMIM=[300363], no_hdr0=''),
    9824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9824, CurrentID=0, Status='live', Symbol='ARHGAP11A', Aliases=['GAP (1-12)'], description='Rho GTPase activating protein 11A', other_designations='rho GTPase-activating protein 11A|rho-type GTPase-activating protein 11A', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32615144, end_position_on_the_genomic_accession=32639941, orientation='plus', exon_count=13, OMIM=[610589], no_hdr0=''),
    9825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9825, CurrentID=0, Status='live', Symbol='SPATA2', Aliases=['PD1', 'PPP1R145', 'tamo'], description='spermatogenesis associated 2', other_designations='spermatogenesis-associated protein 2|protein phosphatase 1, regulatory subunit 145|spermatogenesis associated PD1|spermatogenesis-associated protein PD1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49903391, end_position_on_the_genomic_accession=49915529, orientation='minus', exon_count=5, OMIM=[607662], no_hdr0=''),
    9826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9826, CurrentID=0, Status='live', Symbol='ARHGEF11', Aliases=['GTRAP48', 'PDZ-RHOGEF'], description='Rho guanine nucleotide exchange factor 11', other_designations='rho guanine nucleotide exchange factor 11|Rho guanine exchange factor (GEF) 11|Rho guanine nucleotide exchange factor (GEF) 11|RhoA-specific guanine nucleotide exchange factor|RhoGEF glutamate transport modulator|glutamate transporter EAAT4-associated protein 48', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156934840, end_position_on_the_genomic_accession=157046903, orientation='minus', exon_count=47, OMIM=[605708], no_hdr0=''),
    9827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9827, CurrentID=0, Status='live', Symbol='RGP1', Aliases=['KIAA0258'], description='RGP1 homolog, RAB6A GEF complex partner 1', other_designations='RAB6A-GEF complex partner protein 2|RGP1 retrograde golgi transport homolog|retrograde Golgi transport protein RGP1 homolog', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35749287, end_position_on_the_genomic_accession=35758585, orientation='plus', exon_count=9, OMIM=[615742], no_hdr0=''),
    9828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9828, CurrentID=0, Status='live', Symbol='ARHGEF17', Aliases=['P164RHOGEF', 'RHOGEF17', 'TEM4', 'p164-RhoGEF'], description='Rho guanine nucleotide exchange factor 17', other_designations='rho guanine nucleotide exchange factor 17|164 kDa Rho-specific guanine-nucleotide exchange factor|Rho guanine nucleotide exchange factor (GEF) 17|Rho-specific guanine-nucleotide exchange factor 164 kDa|tumor endothelial marker 4', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73308276, end_position_on_the_genomic_accession=73369388, orientation='plus', exon_count=21, OMIM=[617043], no_hdr0=''),
    9829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9829, CurrentID=0, Status='live', Symbol='DNAJC6', Aliases=['DJC6', 'PARK19'], description='DnaJ heat shock protein family (Hsp40) member C6', other_designations='putative tyrosine-protein phosphatase auxilin|DnaJ (Hsp40) homolog, subfamily B, member 6|DnaJ (Hsp40) homolog, subfamily C, member 6|auxilin', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65264749, end_position_on_the_genomic_accession=65415871, orientation='plus', exon_count=21, OMIM=[608375], no_hdr0=''),
    9830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9830, CurrentID=0, Status='live', Symbol='TRIM14', Aliases=[], description='tripartite motif containing 14', other_designations='tripartite motif-containing protein 14|tripartite motif protein TRIM14', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98072014, end_position_on_the_genomic_accession=98119420, orientation='minus', exon_count=13, OMIM=[606556], no_hdr0=''),
    9831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9831, CurrentID=0, Status='live', Symbol='ZNF623', Aliases=[], description='zinc finger protein 623', other_designations='zinc finger protein 623', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143636019, end_position_on_the_genomic_accession=143653730, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    9832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9832, CurrentID=0, Status='live', Symbol='JAKMIP2', Aliases=['JAMIP2', 'NECC1'], description='janus kinase and microtubule interacting protein 2', other_designations='janus kinase and microtubule-interacting protein 2|CTCL tumor antigen HD-CL-04|Jak and microtubule interacting protein 2|neuroendocrine long coiled-coil protein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147585438, end_position_on_the_genomic_accession=147782796, orientation='minus', exon_count=22, OMIM=[611197], no_hdr0=''),
    9833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9833, CurrentID=0, Status='live', Symbol='MELK', Aliases=['HPK38'], description='maternal embryonic leucine zipper kinase', other_designations='maternal embryonic leucine zipper kinase|pEg3 kinase|protein kinase Eg3|protein kinase PK38|tyrosine-protein kinase MELK', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36572870, end_position_on_the_genomic_accession=36677682, orientation='plus', exon_count=22, OMIM=[607025], no_hdr0=''),
    9836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9836, CurrentID=0, Status='live', Symbol='LCMT2', Aliases=['PPM2', 'TYW4'], description='leucine carboxyl methyltransferase 2', other_designations='tRNA wybutosine-synthesizing protein 4|p21WAF1/CIP1 promoter-interacting protein|tRNA(Phe) (7-(3-amino-3-(methoxycarbonyl)propyl)wyosine(37)-N)-methoxycarbonyltransferase|tRNA(Phe) (7-(3-amino-3-carboxypropyl)wyosine(37)-O)-methyltransferase|tRNA-Wybutosine-synthesizing protein 4|tRNA-yW synthesizing protein 4', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43323649, end_position_on_the_genomic_accession=43330573, orientation='minus', exon_count=1, OMIM=[611246], no_hdr0=''),
    9837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9837, CurrentID=0, Status='live', Symbol='GINS1', Aliases=['IMD55', 'PSF1'], description='GINS complex subunit 1', other_designations='DNA replication complex GINS protein PSF1|GINS complex subunit 1 (Psf1 homolog)|partner of sld five-1', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25407470, end_position_on_the_genomic_accession=25448568, orientation='plus', exon_count=11, OMIM=[610608], no_hdr0=''),
    9839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9839, CurrentID=0, Status='live', Symbol='ZEB2', Aliases=['HSPC082', 'SIP-1', 'SIP1', 'SMADIP1', 'ZFHX1B'], description='zinc finger E-box binding homeobox 2', other_designations='zinc finger E-box-binding homeobox 2|SMAD interacting protein 1|Smad-interacting protein 1|zinc finger homeobox 1b', map_location='2q22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=144384081, end_position_on_the_genomic_accession=144520119, orientation='minus', exon_count=11, OMIM=[605802], no_hdr0=''),
    9840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9840, CurrentID=0, Status='live', Symbol='TESPA1', Aliases=['HSPC257', 'ITPRID3', 'KIAA0748'], description='thymocyte expressed, positive selection associated 1', other_designations='protein TESPA1|thymocyte-expressed positive selection-associated protein 1', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54948015, end_position_on_the_genomic_accession=54984762, orientation='minus', exon_count=15, OMIM=[615664], no_hdr0=''),
    9841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9841, CurrentID=0, Status='live', Symbol='ZBTB24', Aliases=['BIF1', 'ICF2', 'PATZ2', 'ZNF450'], description='zinc finger and BTB domain containing 24', other_designations='zinc finger and BTB domain-containing protein 24|POZ (BTB) and AT hook containing zinc finger 2|zinc finger protein 450', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109462594, end_position_on_the_genomic_accession=109483219, orientation='minus', exon_count=7, OMIM=[614064], no_hdr0=''),
    9842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9842, CurrentID=0, Status='live', Symbol='PLEKHM1', Aliases=['AP162', 'B2', 'OPTA3', 'OPTB6'], description='pleckstrin homology and RUN domain containing M1', other_designations='pleckstrin homology domain-containing family M member 1|162 kDa adapter protein|PH domain-containing family M member 1|pleckstrin homology domain containing, family M (with RUN domain) member 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45434262, end_position_on_the_genomic_accession=45490775, orientation='minus', exon_count=17, OMIM=[611466], no_hdr0=''),
    9843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9843, CurrentID=0, Status='live', Symbol='HEPH', Aliases=['CPL'], description='hephaestin', other_designations='hephaestin', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=66162526, end_position_on_the_genomic_accession=66268863, orientation='plus', exon_count=28, OMIM=[300167], no_hdr0=''),
    9844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9844, CurrentID=0, Status='live', Symbol='ELMO1', Aliases=['CED-12', 'CED12', 'ELMO-1'], description='engulfment and cell motility 1', other_designations='engulfment and cell motility protein 1|ced-12 homolog 1', map_location='7p14.2-p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=36852906, end_position_on_the_genomic_accession=37449326, orientation='minus', exon_count=29, OMIM=[606420], no_hdr0=''),
    9846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9846, CurrentID=0, Status='live', Symbol='GAB2', Aliases=[], description='GRB2 associated binding protein 2', other_designations='GRB2-associated-binding protein 2|Grb2-associated binder 2|growth factor receptor bound protein 2-associated protein 2|pp100', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78215293, end_position_on_the_genomic_accession=78417820, orientation='minus', exon_count=14, OMIM=[606203], no_hdr0=''),
    9847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9847, CurrentID=0, Status='live', Symbol='C2CD5', Aliases=['CDP138', 'KIAA0528'], description='C2 calcium dependent domain containing 5', other_designations='C2 domain-containing protein 5|138 kDa C2 domain-containing phosphoprotein', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=22448577, end_position_on_the_genomic_accession=22544542, orientation='minus', exon_count=35, OMIM=[618044], no_hdr0=''),
    9848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9848, CurrentID=0, Status='live', Symbol='MFAP3L', Aliases=['NYD-sp9'], description='microfibril associated protein 3 like', other_designations='microfibrillar-associated protein 3-like|microfi brillar-associated protein 3-like|microfibrillar associated protein 3 like|testis development protein NYD-SP9', map_location='4q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=169986602, end_position_on_the_genomic_accession=170028741, orientation='minus', exon_count=8, OMIM=[616523], no_hdr0=''),
    9849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9849, CurrentID=0, Status='live', Symbol='ZNF518A', Aliases=['ZNF518'], description='zinc finger protein 518A', other_designations='zinc finger protein 518A|zinc finger protein 518', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96128906, end_position_on_the_genomic_accession=96205291, orientation='plus', exon_count=13, OMIM=[617733], no_hdr0=''),
    9851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9851, CurrentID=0, Status='live', Symbol='KIAA0753', Aliases=['MNR', 'OFIP'], description='KIAA0753', other_designations='protein moonraker|OFD1 and FOPNL interacting protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6578147, end_position_on_the_genomic_accession=6640730, orientation='minus', exon_count=24, OMIM=[617112], no_hdr0=''),
    9852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9852, CurrentID=0, Status='live', Symbol='EPM2AIP1', Aliases=[], description='EPM2A interacting protein 1', other_designations='EPM2A-interacting protein 1|EPM2A (laforin) interacting protein 1|laforin-interacting protein', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=36985043, end_position_on_the_genomic_accession=36993131, orientation='minus', exon_count=1, OMIM=[607911], no_hdr0=''),
    9853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9853, CurrentID=0, Status='live', Symbol='RUSC2', Aliases=['Iporin', 'MRT61'], description='RUN and SH3 domain containing 2', other_designations='iporin|RUN and SH3 domain-containing protein 2|interacting protein of Rab1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35490111, end_position_on_the_genomic_accession=35561898, orientation='plus', exon_count=13, OMIM=[611053], no_hdr0=''),
    9854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9854, CurrentID=0, Status='live', Symbol='C2CD2L', Aliases=['DLNB23', 'TMEM24'], description='C2CD2 like', other_designations='phospholipid transfer protein C2CD2L|C2 domain-containing protein 2-like|transmembrane protein 24', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119106750, end_position_on_the_genomic_accession=119118544, orientation='plus', exon_count=15, OMIM=[617582], no_hdr0=''),
    9855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9855, CurrentID=0, Status='live', Symbol='FARP2', Aliases=['FIR', 'FRG', 'PLEKHC3'], description='FERM, ARH/RhoGEF and pleckstrin domain protein 2', other_designations='FERM, ARHGEF and pleckstrin domain-containing protein 2|FERM domain including RhoGEF|FERM, RhoGEF and pleckstrin domain protein 2|FERM, RhoGEF and pleckstrin domain-containing protein 2|FGD1-related Cdc42-GEF|PH domain-containing family C member 3|pleckstrin homology domain-containing family C member 3', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241356285, end_position_on_the_genomic_accession=241494841, orientation='plus', exon_count=35, OMIM=[617586], no_hdr0=''),
    9856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9856, CurrentID=0, Status='live', Symbol='KIAA0319', Aliases=['AAVR', 'DYLX2', 'DYX2', 'NMIG'], description='KIAA0319', other_designations='dyslexia-associated protein KIAA0319|AAV receptor|dyslexia susceptibility 2|neuronal migration', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24540128, end_position_on_the_genomic_accession=24646191, orientation='minus', exon_count=26, OMIM=[609269], no_hdr0=''),
    9857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9857, CurrentID=0, Status='live', Symbol='CEP350', Aliases=['CAP350', 'GM133'], description='centrosomal protein 350', other_designations='centrosome-associated protein 350|centrosomal protein 350kDa', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179954773, end_position_on_the_genomic_accession=180114875, orientation='plus', exon_count=40, OMIM=[617870], no_hdr0=''),
    9858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9858, CurrentID=0, Status='live', Symbol='PPP1R26', Aliases=['KIAA0649', 'NRBE3'], description='protein phosphatase 1 regulatory subunit 26', other_designations='protein phosphatase 1 regulatory subunit 26|1A6/DRIM (down-regulated in metastasis) interacting protein|DRIM/UTP20 interacting protein', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135477650, end_position_on_the_genomic_accession=135488894, orientation='plus', exon_count=10, OMIM=[614056], no_hdr0=''),
    9859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9859, CurrentID=0, Status='live', Symbol='CEP170', Aliases=['FAM68A', 'KAB', 'KIAA0470'], description='centrosomal protein 170', other_designations='centrosomal protein of 170 kDa|KARP-1-binding protein|XRCC5 binding protein|centrosomal protein 170kDa', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=243124428, end_position_on_the_genomic_accession=243255796, orientation='minus', exon_count=23, OMIM=[613023], no_hdr0=''),
    9860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9860, CurrentID=0, Status='live', Symbol='LRIG2', Aliases=['LIG-2', 'LIG2', 'UFS2'], description='leucine rich repeats and immunoglobulin like domains 2', other_designations='leucine-rich repeats and immunoglobulin-like domains protein 2', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113073170, end_position_on_the_genomic_accession=113132260, orientation='plus', exon_count=21, OMIM=[608869], no_hdr0=''),
    9861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9861, CurrentID=0, Status='live', Symbol='PSMD6', Aliases=['Rpn7', 'S10', 'SGA-113M', 'p42A', 'p44S10'], description='proteasome 26S subunit, non-ATPase 6', other_designations='26S proteasome non-ATPase regulatory subunit 6|breast cancer-associated protein SGA-113M|phosphonoformate immuno-associated protein 4|proteasome (prosome, macropain) 26S subunit, non-ATPase, 6|proteasome regulatory particle subunit p44S10', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=64010551, end_position_on_the_genomic_accession=64024007, orientation='minus', exon_count=11, OMIM=[617857], no_hdr0=''),
    9862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9862, CurrentID=0, Status='live', Symbol='MED24', Aliases=['ARC100', 'CRSP100', 'CRSP4', 'DRIP100', 'MED5', 'THRAP4', 'TRAP100'], description='mediator complex subunit 24', other_designations='mediator of RNA polymerase II transcription subunit 24|CRSP complex subunit 4|activator-recruited cofactor 100 kDa component|cofactor required for Sp1 transcriptional activation subunit 4|cofactor required for Sp1 transcriptional activation, subunit 4, 100kDa|mediator of RNA polymerase II transcription, subunit 24 homolog|thyroid hormone receptor-associated protein 4|thyroid hormone receptor-associated protein complex 100 kDa component|vitamin D3 receptor-interacting protein complex 100 kDa component|vitamin D3 receptor-interacting protein complex component DRIP100', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40019104, end_position_on_the_genomic_accession=40054408, orientation='minus', exon_count=27, OMIM=[607000], no_hdr0=''),
    9863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9863, CurrentID=0, Status='live', Symbol='MAGI2', Aliases=['ACVRIP1', 'AIP-1', 'AIP1', 'ARIP1', 'MAGI-2', 'NPHS15', 'SSCAM'], description='membrane associated guanylate kinase, WW and PDZ domain containing 2', other_designations='membrane-associated guanylate kinase, WW and PDZ domain-containing protein 2|activin receptor interacting protein 1|atrophin-1-interacting protein 1|atrophin-1-interacting protein A|membrane-associated guanylate kinase inverted 2', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=78017055, end_position_on_the_genomic_accession=79453667, orientation='minus', exon_count=29, OMIM=[606382], no_hdr0=''),
    9865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9865, CurrentID=0, Status='live', Symbol='TRIL', Aliases=[], description='TLR4 interactor with leucine rich repeats', other_designations='TLR4 interactor with leucine rich repeats', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=28953358, end_position_on_the_genomic_accession=28958330, orientation='minus', exon_count=1, OMIM=[613356], no_hdr0=''),
    9866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9866, CurrentID=0, Status='live', Symbol='TRIM66', Aliases=['C11orf29', 'TIF1D', 'TIF1DELTA'], description='tripartite motif containing 66', other_designations='tripartite motif-containing protein 66|transcriptional intermediary factor 1 delta', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8612040, end_position_on_the_genomic_accession=8683231, orientation='minus', exon_count=34, OMIM=[612000], no_hdr0=''),
    9867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9867, CurrentID=0, Status='live', Symbol='PJA2', Aliases=['Neurodap1', 'RNF131'], description='praja ring finger ubiquitin ligase 2', other_designations='E3 ubiquitin-protein ligase Praja-2|RING-type E3 ubiquitin transferase Praja-2|praja 2, RING-H2 motif containing|praja ring finger 2, E3 ubiquitin protein ligase|praja2|ring finger protein 131', map_location='5q21.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=109334709, end_position_on_the_genomic_accession=109409978, orientation='minus', exon_count=11, OMIM=[619341], no_hdr0=''),
    9868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9868, CurrentID=0, Status='live', Symbol='TOMM70', Aliases=['TOMM70A', 'Tom70'], description='translocase of outer mitochondrial membrane 70', other_designations='mitochondrial import receptor subunit TOM70|mitochondrial precursor proteins import receptor|translocase of outer membrane 70 kDa subunit|translocase of outer mitochondrial membrane 70 homolog A|translocase of outer mitochondrial membrane protein 70', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100363431, end_position_on_the_genomic_accession=100401089, orientation='minus', exon_count=12, OMIM=[606081], no_hdr0=''),
    9869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9869, CurrentID=0, Status='live', Symbol='SETDB1', Aliases=['ESET', 'H3-K9-HMTase4', 'KG1T', 'KMT1E', 'TDRD21'], description='SET domain bifurcated histone lysine methyltransferase 1', other_designations='histone-lysine N-methyltransferase SETDB1|ERG-associated protein with a SET domain, ESET|SET domain bifurcated 1|histone H3-K9 methyltransferase 4|histone-lysine N-methyltransferase, H3lysine-9 specific 4|lysine N-methyltransferase 1E|tudor domain containing 21', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150926263, end_position_on_the_genomic_accession=150964737, orientation='plus', exon_count=23, OMIM=[604396], no_hdr0=''),
    9870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9870, CurrentID=0, Status='live', Symbol='AREL1', Aliases=['FIEL1', 'KIAA0317'], description='apoptosis resistant E3 ubiquitin protein ligase 1', other_designations='apoptosis-resistant E3 ubiquitin protein ligase 1|apoptosis-resistant HECT-type E3 ubiquitin transferase 1|fibrosis-inducing E3 ligase 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74661256, end_position_on_the_genomic_accession=74713118, orientation='minus', exon_count=21, OMIM=[615380], no_hdr0=''),
    9871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9871, CurrentID=0, Status='live', Symbol='SEC24D', Aliases=['CLCRP2'], description='SEC24 homolog D, COPII coat complex component', other_designations='protein transport protein Sec24D|SEC24 related gene family, member D|SEC24-related protein D', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=118722823, end_position_on_the_genomic_accession=118838683, orientation='minus', exon_count=25, OMIM=[607186], no_hdr0=''),
    9873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9873, CurrentID=0, Status='live', Symbol='FCHSD2', Aliases=['NWK', 'NWK1', 'SH3MD3'], description='FCH and double SH3 domains 2', other_designations='F-BAR and double SH3 domains protein 2|FCH and double SH3 domains protein 2|SH3 multiple domains 3|SH3 multiple domains protein 3|carom|nervous wreck homolog|protein nervous wreck 1', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72836743, end_position_on_the_genomic_accession=73142682, orientation='minus', exon_count=22, OMIM=[617556], no_hdr0=''),
    9874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9874, CurrentID=0, Status='live', Symbol='TLK1', Aliases=['PKU-beta'], description='tousled like kinase 1', other_designations='serine/threonine-protein kinase tousled-like 1|SNARE protein kinase SNAK|serine threonine protein kinase', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170990823, end_position_on_the_genomic_accession=171231293, orientation='minus', exon_count=26, OMIM=[608438], no_hdr0=''),
    9875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9875, CurrentID=0, Status='live', Symbol='URB1', Aliases=['C21orf108', 'NPA1'], description='URB1 ribosome biogenesis homolog', other_designations='nucleolar pre-ribosomal-associated protein 1|URB1 ribosome biogenesis 1 homolog|nucleolar preribosomal-associated protein 1|nucleolar protein 254 kDa', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32311018, end_position_on_the_genomic_accession=32393012, orientation='minus', exon_count=39, OMIM=[608865], no_hdr0=''),
    9877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9877, CurrentID=0, Status='live', Symbol='ZC3H11A', Aliases=['ZC3HDC11A'], description='zinc finger CCCH-type containing 11A', other_designations='zinc finger CCCH domain-containing protein 11A|zinc finger CCCH-type domain containing 11A', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203795623, end_position_on_the_genomic_accession=203854126, orientation='plus', exon_count=20, OMIM=[613513], no_hdr0=''),
    9878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9878, CurrentID=0, Status='live', Symbol='TOX4', Aliases=['C14orf92', 'KIAA0737', 'LCP1', 'MIG7'], description='TOX high mobility group box family member 4', other_designations='TOX high mobility group box family member 4|epidermal Langerhans cell protein LCP1|migration-inducing protein 7', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21477195, end_position_on_the_genomic_accession=21499170, orientation='plus', exon_count=9, OMIM=[614032], no_hdr0=''),
    9879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9879, CurrentID=0, Status='live', Symbol='DDX46', Aliases=['PRPF5', 'Prp5'], description='DEAD-box helicase 46', other_designations='probable ATP-dependent RNA helicase DDX46|DEAD (Asp-Glu-Ala-Asp) box polypeptide 46|DEAD box protein 46|PRP5 homolog|Prp5-like DEAD-box protein|RNA helicase', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134758778, end_position_on_the_genomic_accession=134831121, orientation='plus', exon_count=25, OMIM=[617848], no_hdr0=''),
    9880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9880, CurrentID=0, Status='live', Symbol='ZBTB39', Aliases=['ZNF922'], description='zinc finger and BTB domain containing 39', other_designations='zinc finger and BTB domain-containing protein 39', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56998836, end_position_on_the_genomic_accession=57006546, orientation='minus', exon_count=2, OMIM=[619384], no_hdr0=''),
    9881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9881, CurrentID=0, Status='live', Symbol='TRANK1', Aliases=['LBA1'], description='tetratricopeptide repeat and ankyrin repeat containing 1', other_designations='TPR and ankyrin repeat-containing protein 1|lupus brain antigen 1 homolog', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=36826817, end_position_on_the_genomic_accession=36945662, orientation='minus', exon_count=28, OMIM=[619316], no_hdr0=''),
    9882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9882, CurrentID=0, Status='live', Symbol='TBC1D4', Aliases=['AS160', 'NIDDM5'], description='TBC1 domain family member 4', other_designations='TBC1 domain family member 4|TBC (Tre-2, BUB2, CDC16) domain-containing protein|akt substrate of 160 kDa', map_location='13q22.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=75283503, end_position_on_the_genomic_accession=75483144, orientation='minus', exon_count=24, OMIM=[612465], no_hdr0=''),
    9883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9883, CurrentID=0, Status='live', Symbol='POM121', Aliases=['P145A', 'POM121'], description='POM121 transmembrane nucleoporin', other_designations='nuclear envelope pore membrane protein POM 121|POM121 membrane glycoprotein|nuclear envelope pore membrane protein POM 121A|nuclear pore membrane protein 121 kDa|nucleoporin Nup121', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=72879357, end_position_on_the_genomic_accession=72951459, orientation='plus', exon_count=22, OMIM=[615753], no_hdr0=''),
    9884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9884, CurrentID=0, Status='live', Symbol='LRRC37A', Aliases=['LRRC37'], description='leucine rich repeat containing 37A', other_designations='leucine-rich repeat-containing protein 37A', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46295131, end_position_on_the_genomic_accession=46337794, orientation='plus', exon_count=14, OMIM=[616555], no_hdr0=''),
    9885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9885, CurrentID=0, Status='live', Symbol='OSBPL2', Aliases=['DFNA67', 'DNFA67', 'ORP-2', 'ORP2'], description='oxysterol binding protein like 2', other_designations='oxysterol-binding protein-related protein 2|OSBP-related protein 2', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62238521, end_position_on_the_genomic_accession=62296183, orientation='plus', exon_count=15, OMIM=[606731], no_hdr0=''),
    9886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9886, CurrentID=0, Status='live', Symbol='RHOBTB1', Aliases=[], description='Rho related BTB domain containing 1', other_designations='rho-related BTB domain-containing protein 1', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=60869438, end_position_on_the_genomic_accession=61001486, orientation='minus', exon_count=21, OMIM=[607351], no_hdr0=''),
    9887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9887, CurrentID=0, Status='live', Symbol='SMG7', Aliases=['C1orf16', 'EST1C', 'SGA56M'], description='SMG7 nonsense mediated mRNA decay factor', other_designations='protein SMG7|EST1 telomerase component homolog C|EST1-like protein C|breast cancer-associated antigen SGA-56M|ever shorter telomeres 1C|smg-7 homolog, nonsense mediated mRNA decay factor', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183471993, end_position_on_the_genomic_accession=183554193, orientation='plus', exon_count=28, OMIM=[610964], no_hdr0=''),
    9889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9889, CurrentID=0, Status='live', Symbol='ZBED4', Aliases=[], description='zinc finger BED-type containing 4', other_designations='zinc finger BED domain-containing protein 4|zinc finger, BED domain containing 4', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49853844, end_position_on_the_genomic_accession=49890080, orientation='plus', exon_count=3, OMIM=[612552], no_hdr0=''),
    9890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9890, CurrentID=0, Status='live', Symbol='PLPPR4', Aliases=['LPPR4', 'LPR4', 'PHP1', 'PRG-1', 'PRG1'], description='phospholipid phosphatase related 4', other_designations='2-lysophosphatidate phosphatase PLPPR4|brain-specific phosphatidic acid phosphatase-like protein 1|lipid phosphate phosphatase-related protein type 4|phospholipid phosphatase-related protein type 4|plasticity related gene 1|plasticity-related gene 1 protein', map_location='1p21.3-p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=99262956, end_position_on_the_genomic_accession=99309584, orientation='plus', exon_count=8, OMIM=[607813], no_hdr0=''),
    9891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9891, CurrentID=0, Status='live', Symbol='NUAK1', Aliases=['ARK5'], description='NUAK family kinase 1', other_designations='NUAK family SNF1-like kinase 1|AMP-activated protein kinase family member 5|AMPK-related protein kinase 5|NUAK family, SNF1-like kinase, 1|omphalocele kinase 1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106063345, end_position_on_the_genomic_accession=106138954, orientation='minus', exon_count=7, OMIM=[608130], no_hdr0=''),
    9892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9892, CurrentID=0, Status='live', Symbol='SNAP91', Aliases=['AP180', 'CALM'], description='synaptosome associated protein 91', other_designations='clathrin coat assembly protein AP180|91 kDa synaptosomal-associated protein|assembly protein, 180kDa|clathrin coat-associated protein AP180|phosphoprotein F1-20|synaptosomal-associated protein, 91kDa homolog|synaptosome associated protein 91kDa', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83552885, end_position_on_the_genomic_accession=83709403, orientation='minus', exon_count=44, OMIM=[607923], no_hdr0=''),
    9894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9894, CurrentID=0, Status='live', Symbol='TELO2', Aliases=['CLK2', 'TEL2', 'YHFS'], description='telomere maintenance 2', other_designations='telomere length regulation protein TEL2 homolog|TEL2, telomere maintenance 2, homolog|protein clk-2 homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1493345, end_position_on_the_genomic_accession=1510459, orientation='plus', exon_count=23, OMIM=[611140], no_hdr0=''),
    9895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9895, CurrentID=0, Status='live', Symbol='TECPR2', Aliases=['KIAA0329', 'SPG49'], description='tectonin beta-propeller repeat containing 2', other_designations='tectonin beta-propeller repeat-containing protein 2', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102362941, end_position_on_the_genomic_accession=102502477, orientation='plus', exon_count=20, OMIM=[615000], no_hdr0=''),
    9896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9896, CurrentID=0, Status='live', Symbol='FIG4', Aliases=['ALS11', 'BTOP', 'CMT4J', 'KIAA0274', 'SAC3', 'YVS', 'dJ249I4.1'], description='FIG4 phosphoinositide 5-phosphatase', other_designations='polyphosphoinositide phosphatase|FIG4 homolog, SAC domain containing lipid phosphatase|FIG4 homolog, SAC1 domain containing lipid phosphatase|FIG4 homolog, SAC1 lipid phosphatase domain containing|SAC domain-containing protein 3|Sac domain-containing inositol phosphatase 3|phosphatidylinositol 3,5-bisphosphate 5-phosphatase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109691296, end_position_on_the_genomic_accession=109825431, orientation='plus', exon_count=25, OMIM=[609390], no_hdr0=''),
    9897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9897, CurrentID=0, Status='live', Symbol='WASHC5', Aliases=['KIAA0196', 'RTSC', 'RTSC1', 'SPG8'], description='WASH complex subunit 5', other_designations='WASH complex subunit 5|WASH complex subunit strumpellin|strumpellin', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=125024260, end_position_on_the_genomic_accession=125091796, orientation='minus', exon_count=31, OMIM=[610657], no_hdr0=''),
    9898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9898, CurrentID=0, Status='live', Symbol='UBAP2L', Aliases=['NICE-4', 'NICE4'], description='ubiquitin associated protein 2 like', other_designations='ubiquitin-associated protein 2-like|protein NICE-4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154220172, end_position_on_the_genomic_accession=154271510, orientation='plus', exon_count=34, OMIM=[616472], no_hdr0=''),
    9899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9899, CurrentID=0, Status='live', Symbol='SV2B', Aliases=['HsT19680'], description='synaptic vesicle glycoprotein 2B', other_designations='synaptic vesicle glycoprotein 2B|synaptic vesicle protein 2B homolog', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=91099588, end_position_on_the_genomic_accession=91302565, orientation='plus', exon_count=19, OMIM=[185861], no_hdr0=''),
    9900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9900, CurrentID=0, Status='live', Symbol='SV2A', Aliases=['SV2'], description='synaptic vesicle glycoprotein 2A', other_designations='synaptic vesicle glycoprotein 2A', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149903318, end_position_on_the_genomic_accession=149917844, orientation='minus', exon_count=13, OMIM=[185860], no_hdr0=''),
    9901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9901, CurrentID=0, Status='live', Symbol='SRGAP3', Aliases=['ARHGAP14', 'MEGAP', 'SRGAP2', 'WRP'], description='SLIT-ROBO Rho GTPase activating protein 3', other_designations='SLIT-ROBO Rho GTPase-activating protein 3|SLIT-ROBO Rho GTPase activating protein 2|WAVE-associated Rac GTPase activating protein|mental disorder-associated GAP|rho GTPase-activating protein 14', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8980591, end_position_on_the_genomic_accession=9363446, orientation='minus', exon_count=31, OMIM=[606525], no_hdr0=''),
    9902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9902, CurrentID=0, Status='live', Symbol='MRC2', Aliases=['CD280', 'CLEC13E', 'ENDO180', 'UPARAP'], description='mannose receptor C type 2', other_designations='C-type mannose receptor 2|C-type lectin domain family 13 member E|UPAR-associated protein|endocytic receptor (macrophage mannose receptor family)|endocytic receptor 180|macrophage mannose receptor 2|urokinase-type plasminogen activator receptor-associated protein', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62627670, end_position_on_the_genomic_accession=62693597, orientation='plus', exon_count=31, OMIM=[612264], no_hdr0=''),
    9903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9903, CurrentID=0, Status='live', Symbol='KLHL21', Aliases=[], description='kelch like family member 21', other_designations='kelch-like protein 21', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6590724, end_position_on_the_genomic_accession=6602869, orientation='minus', exon_count=4, OMIM=[616262], no_hdr0=''),
    9904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9904, CurrentID=0, Status='live', Symbol='RBM19', Aliases=['Mrd1'], description='RNA binding motif protein 19', other_designations='probable RNA-binding protein 19', map_location='12q24.13-q24.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113816740, end_position_on_the_genomic_accession=113966371, orientation='minus', exon_count=27, OMIM=[616444], no_hdr0=''),
    9905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9905, CurrentID=0, Status='live', Symbol='SGSM2', Aliases=['RUTBC1'], description='small G protein signaling modulator 2', other_designations='small G protein signaling modulator 2|RUN and TBC1 domain containing 1|small G protein signaling modulator 2 protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2336492, end_position_on_the_genomic_accession=2381074, orientation='plus', exon_count=28, OMIM=[611418], no_hdr0=''),
    9906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9906, CurrentID=0, Status='live', Symbol='SLC35E2A', Aliases=['SLC35E2'], description='solute carrier family 35 member E2A', other_designations='solute carrier family 35 member E2A|solute carrier family 35 member E2', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1724838, end_position_on_the_genomic_accession=1746070, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    9907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9907, CurrentID=0, Status='live', Symbol='AP5Z1', Aliases=['KIAA0415', 'SPG48', 'zeta'], description='adaptor related protein complex 5 subunit zeta 1', other_designations='AP-5 complex subunit zeta-1|adapter-related protein complex 5 zeta subunit|adaptor related protein complex 5 zeta 1 subunit|adaptor-related protein complex 5 zeta subunit|zeta5', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=4775623, end_position_on_the_genomic_accession=4794397, orientation='plus', exon_count=17, OMIM=[613653], no_hdr0=''),
    9908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9908, CurrentID=0, Status='live', Symbol='G3BP2', Aliases=[], description='G3BP stress granule assembly factor 2', other_designations='ras GTPase-activating protein-binding protein 2|G3BP-2|GAP SH3 domain-binding protein 2|GTPase activating protein (SH3 domain) binding protein 2|Ras-GTPase activating protein SH3 domain-binding protein 2', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75642782, end_position_on_the_genomic_accession=75724470, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    9909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9909, CurrentID=0, Status='live', Symbol='DENND4B', Aliases=['KIAA0476'], description='DENN domain containing 4B', other_designations='DENN domain-containing protein 4B|DENN/MADD domain containing 4B', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153929501, end_position_on_the_genomic_accession=153946718, orientation='minus', exon_count=29, OMIM=[], no_hdr0=''),
    9910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9910, CurrentID=0, Status='live', Symbol='RABGAP1L', Aliases=['HHL', 'TBC1D18'], description='RAB GTPase activating protein 1 like', other_designations='rab GTPase-activating protein 1-like|TBC1 domain family, member 18|expressed in hematopoietic cells, heart, liver (HLL)', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=174159414, end_position_on_the_genomic_accession=174995308, orientation='plus', exon_count=40, OMIM=[609238], no_hdr0=''),
    9911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9911, CurrentID=0, Status='live', Symbol='TMCC2', Aliases=['HUCEP11'], description='transmembrane and coiled-coil domain family 2', other_designations='transmembrane and coiled-coil domains protein 2|cerebral protein 11', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205227946, end_position_on_the_genomic_accession=205273343, orientation='plus', exon_count=11, OMIM=[619429], no_hdr0=''),
    9912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9912, CurrentID=0, Status='live', Symbol='ARHGAP44', Aliases=['NPC-A-10', 'RICH2'], description='Rho GTPase activating protein 44', other_designations='rho GTPase-activating protein 44|Rho-type GTPase-activating protein RICH2|RhoGAP interacting with CIP4 homologs protein 2|rho GTPase-activating protein RICH2', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=12789498, end_position_on_the_genomic_accession=12991644, orientation='plus', exon_count=22, OMIM=[617716], no_hdr0=''),
    9913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9913, CurrentID=0, Status='live', Symbol='SUPT7L', Aliases=['SPT7L', 'STAF65', 'STAF65(gamma)', 'STAF65G', 'SUPT7H'], description='SPT7 like, STAGA complex subunit gamma', other_designations='STAGA complex 65 subunit gamma|SPT7 like, STAGA complex gamma subunit|SPTF-associated factor 65 gamma|STAF65gamma|STAGA complex 65 gamma subunit|adenocarcinoma antigen ART1|suppressor of Ty 7-like', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27642568, end_position_on_the_genomic_accession=27663824, orientation='minus', exon_count=8, OMIM=[612762], no_hdr0=''),
    9914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9914, CurrentID=0, Status='live', Symbol='ATP2C2', Aliases=['SPCA2'], description='ATPase secretory pathway Ca2+ transporting 2', other_designations='calcium-transporting ATPase type 2C member 2|ATPase 2C2|ATPase, Ca++ transporting, type 2C, member 2|Ca(2+)/Mn(2+)-ATPase 2C2|secretory pathway Ca(2+)-ATPase 2|secretory pathway Ca(2+)-transporting ATPase type 2|secretory pathway calcium ATPase 2', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84368523, end_position_on_the_genomic_accession=84465777, orientation='plus', exon_count=32, OMIM=[613082], no_hdr0=''),
    9915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9915, CurrentID=0, Status='live', Symbol='ARNT2', Aliases=['WEDAS', 'bHLHe1'], description='aryl hydrocarbon receptor nuclear translocator 2', other_designations='aryl hydrocarbon receptor nuclear translocator 2|ARNT protein 2|class E basic helix-loop-helix protein 1', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80404382, end_position_on_the_genomic_accession=80597933, orientation='plus', exon_count=19, OMIM=[606036], no_hdr0=''),
    9917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9917, CurrentID=0, Status='live', Symbol='FAM20B', Aliases=['gxk1'], description='FAM20B glycosaminoglycan xylosylkinase', other_designations='glycosaminoglycan xylosylkinase|family with sequence similarity 20, member B|xylose kinase', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179025804, end_position_on_the_genomic_accession=179076567, orientation='plus', exon_count=11, OMIM=[611063], no_hdr0=''),
    9918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9918, CurrentID=0, Status='live', Symbol='NCAPD2', Aliases=['CAP-D2', 'CNAP1', 'MCPH21', 'hCAP-D2'], description='non-SMC condensin I complex subunit D2', other_designations='condensin complex subunit 1|XCAP-D2 homolog|chromosome condensation-related SMC-associated protein 1|chromosome-associated protein D2', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6494102, end_position_on_the_genomic_accession=6531955, orientation='plus', exon_count=32, OMIM=[615638], no_hdr0=''),
    9919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9919, CurrentID=0, Status='live', Symbol='SEC16A', Aliases=['KIAA0310', 'SEC16L', 'p250'], description='SEC16 homolog A, endoplasmic reticulum export factor', other_designations='protein transport protein Sec16A|protein SEC16 homolog A', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136440096, end_position_on_the_genomic_accession=136484552, orientation='minus', exon_count=36, OMIM=[612854], no_hdr0=''),
    9920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9920, CurrentID=0, Status='live', Symbol='KBTBD11', Aliases=['KLHDC7C'], description='kelch repeat and BTB domain containing 11', other_designations='kelch repeat and BTB domain-containing protein 11|chronic myelogenous leukemia-associated protein|kelch domain-containing protein 7B|kelch repeat and BTB (POZ) domain containing 11', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=1970718, end_position_on_the_genomic_accession=2006943, orientation='plus', exon_count=6, OMIM=[618794], no_hdr0=''),
    9921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9921, CurrentID=0, Status='live', Symbol='RNF10', Aliases=['RIE2'], description='ring finger protein 10', other_designations='RING finger protein 10|epididymis secretory sperm binding protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120534353, end_position_on_the_genomic_accession=120577588, orientation='plus', exon_count=19, OMIM=[615998], no_hdr0=''),
    9922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9922, CurrentID=0, Status='live', Symbol='IQSEC1', Aliases=['ARF-GEP100', 'ARFGEP100', 'BRAG2', 'GEP100', 'IDDSSBA'], description='IQ motif and Sec7 domain ArfGEF 1', other_designations='IQ motif and SEC7 domain-containing protein 1|ADP-ribosylation factors guanine nucleotide-exchange protein 100|ADP-ribosylation factors guanine nucleotide-exchange protein 2|IQ motif and Sec7 domain 1|brefeldin A-resistant ARF-GEF2|brefeldin-resistant Arf-GEF 2 protein|epididymis secretory sperm binding protein', map_location='3p25.2-p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12897043, end_position_on_the_genomic_accession=13283257, orientation='minus', exon_count=24, OMIM=[610166], no_hdr0=''),
    9923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9923, CurrentID=0, Status='live', Symbol='ZBTB40', Aliases=['ZNF923'], description='zinc finger and BTB domain containing 40', other_designations='zinc finger and BTB domain-containing protein 40', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22428838, end_position_on_the_genomic_accession=22531154, orientation='plus', exon_count=21, OMIM=[612106], no_hdr0=''),
    9924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9924, CurrentID=0, Status='live', Symbol='PAN2', Aliases=['USP52'], description='poly(A) specific ribonuclease subunit PAN2', other_designations='PAN2-PAN3 deadenylation complex catalytic subunit PAN2|PAB-dependent poly(A)-specific ribonuclease subunit 2|PAB-dependent poly(A)-specific ribonuclease subunit PAN2|PAB1P-dependent poly(A)-nuclease|PAB1P-dependent poly(A)-specific ribonuclease|PABP-dependent poly(A) nuclease 2|PAN deadenylation complex catalytic subunit 2|PAN deadenylation complex subunit 2|PAN2 poly(A) specific ribonuclease subunit homolog|inactive ubiquitin carboxyl-terminal hydrolase 52|poly(A)-nuclease deadenylation complex subunit 2|ubiquitin specific peptidase 52|ubiquitin specific protease 52', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56316936, end_position_on_the_genomic_accession=56334000, orientation='minus', exon_count=27, OMIM=[617447], no_hdr0=''),
    9925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9925, CurrentID=0, Status='live', Symbol='ZBTB5', Aliases=[], description='zinc finger and BTB domain containing 5', other_designations='zinc finger and BTB domain-containing protein 5', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37438102, end_position_on_the_genomic_accession=37465450, orientation='minus', exon_count=2, OMIM=[616590], no_hdr0=''),
    9926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9926, CurrentID=0, Status='live', Symbol='LPGAT1', Aliases=['FAM34A', 'FAM34A1', 'NET8'], description='lysophosphatidylglycerol acyltransferase 1', other_designations='acyl-CoA:lysophosphatidylglycerol acyltransferase 1|acyl-CoA:monoacylglycerol acyltransferase LPGAT1|family with sequence similarity 34, member A', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211743457, end_position_on_the_genomic_accession=211830763, orientation='minus', exon_count=12, OMIM=[610473], no_hdr0=''),
    9927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9927, CurrentID=0, Status='live', Symbol='MFN2', Aliases=['CMT2A', 'CMT2A2', 'CMT2A2A', 'CMT2A2B', 'CPRP1', 'HMSN6A', 'HSG', 'MARF'], description='mitofusin 2', other_designations='mitofusin-2|hyperplasia suppressor|mitochondrial assembly regulatory factor|transmembrane GTPase MFN2', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11980215, end_position_on_the_genomic_accession=12013508, orientation='plus', exon_count=20, OMIM=[608507], no_hdr0=''),
    9928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9928, CurrentID=0, Status='live', Symbol='KIF14', Aliases=['MCPH20', 'MKS12'], description='kinesin family member 14', other_designations='kinesin-like protein KIF14|epididymis secretory sperm binding protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200551497, end_position_on_the_genomic_accession=200620791, orientation='minus', exon_count=32, OMIM=[611279], no_hdr0=''),
    9929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9929, CurrentID=0, Status='live', Symbol='JOSD1', Aliases=['dJ508I15.2'], description='Josephin domain containing 1', other_designations='josephin-1|josephin domain-containing 1|josephin domain-containing protein 1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38683916, end_position_on_the_genomic_accession=38701403, orientation='minus', exon_count=7, OMIM=[615323], no_hdr0=''),
    9931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9931, CurrentID=0, Status='live', Symbol='HELZ', Aliases=['DHRC', 'DRHC', 'HUMORF5'], description='helicase with zinc finger', other_designations='probable helicase with zinc finger domain|down-regulated in human cancers protein|helicase with zinc finger domain', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67070444, end_position_on_the_genomic_accession=67245989, orientation='minus', exon_count=36, OMIM=[606699], no_hdr0=''),
    9933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9933, CurrentID=0, Status='live', Symbol='PUM3', Aliases=['HA-8', 'HLA-HA8', 'KIAA0020', 'PEN', 'PUF-A', 'PUF6', 'XTP5'], description='pumilio RNA binding family member 3', other_designations='pumilio homolog 3|HBV X-transactivated gene 5 protein|HBV XAg-transactivated protein 5|minor histocompatibility antigen HA-8|penguin homolog|protein 5 transactivated by hepatitis B virus X antigen (HBxAg)', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=2804152, end_position_on_the_genomic_accession=2844095, orientation='minus', exon_count=18, OMIM=[609960], no_hdr0=''),
    9934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9934, CurrentID=0, Status='live', Symbol='P2RY14', Aliases=['BPR105', 'GPR105', 'P2Y14'], description='purinergic receptor P2Y14', other_designations='P2Y purinoceptor 14|G protein coupled receptor for UDP-glucose|G-protein coupled receptor 105|P2Y(14) receptor|P2Y14 receptor|UDP-glucose receptor|purinergic receptor P2Y, G-protein coupled, 14', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151212115, end_position_on_the_genomic_accession=151279167, orientation='minus', exon_count=6, OMIM=[610116], no_hdr0=''),
    9935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9935, CurrentID=0, Status='live', Symbol='MAFB', Aliases=['DURS3', 'KRML', 'MCTO'], description='MAF bZIP transcription factor B', other_designations='transcription factor MafB|Kreisler maf-related leucine zipper homolog|MAFB/Kreisler basic region/leucine zipper transcription factor|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog B', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=40685848, end_position_on_the_genomic_accession=40689236, orientation='minus', exon_count=1, OMIM=[608968], no_hdr0=''),
    9936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9936, CurrentID=0, Status='live', Symbol='CD302', Aliases=['BIMLEC', 'CLEC13A', 'DCL-1', 'DCL1'], description='CD302 molecule', other_designations='CD302 antigen|C-type lectin domain family 13, member A|DEC205-associated C-type lectin 1|type I transmembrane C-type lectin receptor DCL-1', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159768628, end_position_on_the_genomic_accession=159798208, orientation='minus', exon_count=6, OMIM=[612246], no_hdr0=''),
    9937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9937, CurrentID=0, Status='live', Symbol='DCLRE1A', Aliases=['PSO2', 'SNM1', 'SNM1A'], description='DNA cross-link repair 1A', other_designations='DNA cross-link repair 1A protein|DNA-crosslink repair gene SNM1|SNM1 homolog A', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113834725, end_position_on_the_genomic_accession=113854394, orientation='minus', exon_count=11, OMIM=[609682], no_hdr0=''),
    9938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9938, CurrentID=0, Status='live', Symbol='ARHGAP25', Aliases=['HEL-S-308', 'KAIA0053'], description='Rho GTPase activating protein 25', other_designations='rho GTPase-activating protein 25|epididymis secretory protein Li 308|epididymis secretory sperm binding protein|rho-type GTPase-activating protein 25', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68710510, end_position_on_the_genomic_accession=68826845, orientation='plus', exon_count=18, OMIM=[610587], no_hdr0=''),
    9939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9939, CurrentID=0, Status='live', Symbol='RBM8A', Aliases=['BOV-1A', 'BOV-1B', 'BOV-1C', 'C1DELq21.1', 'DEL1q21.1', 'MDS014', 'RBM8', 'RBM8B', 'TAR', 'Y14', 'ZNRP', 'ZRNP1'], description='RNA binding motif protein 8A', other_designations='RNA-binding protein 8A|BOV-1|RNA binding motif protein 8B|RNA-binding protein Y14|binder of OVCA1|binder of OVCA1-1|ribonucleoprotein RBM8|ribonucleoprotein RBM8A', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145921556, end_position_on_the_genomic_accession=145927484, orientation='minus', exon_count=6, OMIM=[605313], no_hdr0=''),
    9940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9940, CurrentID=0, Status='live', Symbol='DLEC1', Aliases=['CFAP81', 'DLC-1', 'DLC1', 'F56', 'FAP81'], description='DLEC1 cilia and flagella associated protein', other_designations='deleted in lung and esophageal cancer protein 1|DLEC, cilia and flagella associated protein|cilia and flagella associated protein 81|deleted in lung and esophageal cancer 1', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38038595, end_position_on_the_genomic_accession=38124025, orientation='plus', exon_count=38, OMIM=[604050], no_hdr0=''),
    9941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9941, CurrentID=0, Status='live', Symbol='EXOG', Aliases=['ENDOGL1', 'ENDOGL2', 'ENGL', 'ENGL-a', 'ENGL-b', 'ENGLA', 'ENGLB'], description='exo/endonuclease G', other_designations="nuclease EXOG, mitochondrial|endo G-like 1|endo/exonuclease (5'-3'), endonuclease G-like|endonuclease G-like 1|endonuclease G-like 2", map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38496127, end_position_on_the_genomic_accession=38526304, orientation='plus', exon_count=12, OMIM=[604051], no_hdr0=''),
    9942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9942, CurrentID=0, Status='live', Symbol='XYLB', Aliases=[], description='xylulokinase', other_designations='xylulose kinase|D-xylulokinase|xylulokinase homolog (H. influenzae)', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38346785, end_position_on_the_genomic_accession=38453041, orientation='plus', exon_count=26, OMIM=[604049], no_hdr0=''),
    9943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9943, CurrentID=0, Status='live', Symbol='OXSR1', Aliases=['OSR1'], description='oxidative stress responsive kinase 1', other_designations='serine/threonine-protein kinase OSR1|oxidative stress responsive 1|oxidative stress-responsive 1 protein', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38165051, end_position_on_the_genomic_accession=38255486, orientation='plus', exon_count=23, OMIM=[604046], no_hdr0=''),
    9945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9945, CurrentID=0, Status='live', Symbol='GFPT2', Aliases=['GFAT', 'GFAT 2', 'GFAT2'], description='glutamine-fructose-6-phosphate transaminase 2', other_designations='glutamine--fructose-6-phosphate aminotransferase [isomerizing] 2|D-fructose-6-phosphate amidotransferase 2|glucosamine--fructose-6-phosphate aminotransferase [isomerizing] 2|glutamine: fructose-6-phosphate aminotransferase 2|glutamine:fructose-6-phosphate amidotransferase 2|hexosephosphate aminotransferase 2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180300698, end_position_on_the_genomic_accession=180353336, orientation='minus', exon_count=19, OMIM=[603865], no_hdr0=''),
    9946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9946, CurrentID=0, Status='live', Symbol='CRYZL1', Aliases=['4P11', 'QOH-1'], description='crystallin zeta like 1', other_designations='quinone oxidoreductase-like protein 1|crystallin, zeta (quinone reductase)-like 1|protein 4P11|quinone oxidoreductase homolog 1|quinone reductase-like 1|zeta-crystallin homolog', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33589341, end_position_on_the_genomic_accession=33641741, orientation='minus', exon_count=13, OMIM=[603920], no_hdr0=''),
    9947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9947, CurrentID=0, Status='live', Symbol='MAGEC1', Aliases=['CT7', 'CT7.1'], description='MAGE family member C1', other_designations='melanoma-associated antigen C1|MAGE-C1 antigen|cancer/testis antigen 7.1|cancer/testis antigen family 7, member 1|melanoma antigen family C, 1|melanoma antigen family C1', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141903877, end_position_on_the_genomic_accession=141909401, orientation='plus', exon_count=4, OMIM=[300223], no_hdr0=''),
    9948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9948, CurrentID=0, Status='live', Symbol='WDR1', Aliases=['AIP1', 'HEL-S-52', 'NORI-1', 'PFITS'], description='WD repeat domain 1', other_designations='WD repeat-containing protein 1|actin-interacting protein 1|epididymis secretory protein Li 52', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=10074339, end_position_on_the_genomic_accession=10116860, orientation='minus', exon_count=15, OMIM=[604734], no_hdr0=''),
    9949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9949, CurrentID=0, Status='live', Symbol='AMMECR1', Aliases=['AMMERC1', 'MFHIEN'], description='AMMECR nuclear protein 1', other_designations='AMME syndrome candidate gene 1 protein|Alport syndrome mental retardation midface hypoplasia and elliptocytosis chromosomal region protein 1|Alport syndrome, mental retardation, midface hypoplasia and elliptocytosis chromosomal region gene 1', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=110194186, end_position_on_the_genomic_accession=110440233, orientation='minus', exon_count=8, OMIM=[300195], no_hdr0=''),
    9950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9950, CurrentID=0, Status='live', Symbol='GOLGA5', Aliases=['GOLIM5', 'RFG5', 'ret-II'], description='golgin A5', other_designations='golgin subfamily A member 5|RET-fused gene 5 protein|cell proliferation-inducing gene 31 protein|golgi autoantigen, golgin subfamily a, 5|golgi integral membrane protein 5|golgin-84', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92794305, end_position_on_the_genomic_accession=92839947, orientation='plus', exon_count=13, OMIM=[606918], no_hdr0=''),
    9951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9951, CurrentID=0, Status='live', Symbol='HS3ST4', Aliases=['3-OST-4', '30ST4', '3OST4', 'h3-OST-4'], description='heparan sulfate-glucosamine 3-sulfotransferase 4', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 4|heparan sulfate (glucosamine) 3-O-sulfotransferase 4|heparan sulfate 3-O-sulfotransferase 4|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 4', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=25691959, end_position_on_the_genomic_accession=26137685, orientation='plus', exon_count=2, OMIM=[604059], no_hdr0=''),
    9953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9953, CurrentID=0, Status='live', Symbol='HS3ST3B1', Aliases=['3-OST-3B', '3OST3B1', 'h3-OST-3B'], description='heparan sulfate-glucosamine 3-sulfotransferase 3B1', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 3B1|heparan sulfate (glucosamine) 3-O-sulfotransferase 3B1|heparan sulfate 3-O-sulfotransferase 3B1|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 3B1', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=14301081, end_position_on_the_genomic_accession=14349406, orientation='plus', exon_count=4, OMIM=[604058], no_hdr0=''),
    9955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9955, CurrentID=0, Status='live', Symbol='HS3ST3A1', Aliases=['3-OST-3A', '3OST3A1'], description='heparan sulfate-glucosamine 3-sulfotransferase 3A1', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 3A1|heparan sulfate (glucosamine) 3-O-sulfotransferase 3A1|heparan sulfate 3-O-sulfotransferase 3A1|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 3A1|heparin-glucosamine 3-O-sulfotransferase', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=13494032, end_position_on_the_genomic_accession=13601929, orientation='minus', exon_count=5, OMIM=[604057], no_hdr0=''),
    9956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9956, CurrentID=0, Status='live', Symbol='HS3ST2', Aliases=['30ST2', '3OST2'], description='heparan sulfate-glucosamine 3-sulfotransferase 2', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 2|3-OST-2|h3-OST-2|heparan sulfate (glucosamine) 3-O-sulfotransferase 2|heparan sulfate 3-O-sulfotransferase 2|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 2|heparin-glucosamine 3-O-sulfotransferase', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22814162, end_position_on_the_genomic_accession=22916338, orientation='plus', exon_count=4, OMIM=[604056], no_hdr0=''),
    9957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9957, CurrentID=0, Status='live', Symbol='HS3ST1', Aliases=['3OST', '3OST1'], description='heparan sulfate-glucosamine 3-sulfotransferase 1', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 1|3-OST-1|h3-OST-1|heparan sulfate (glucosamine) 3-O-sulfotransferase 1|heparan sulfate 3-O-sulfotransferase 1|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 1|heparin-glucosamine 3-O-sulfotransferase', map_location='4p15.33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=11393150, end_position_on_the_genomic_accession=11434398, orientation='minus', exon_count=3, OMIM=[603244], no_hdr0=''),
    9958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9958, CurrentID=0, Status='live', Symbol='USP15', Aliases=['UNPH-2', 'UNPH4'], description='ubiquitin specific peptidase 15', other_designations='ubiquitin carboxyl-terminal hydrolase 15|deubiquitinating enzyme 15|ubiquitin thioesterase 15|ubiquitin thiolesterase 15|ubiquitin-specific-processing protease 15', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=62260404, end_position_on_the_genomic_accession=62416389, orientation='plus', exon_count=27, OMIM=[604731], no_hdr0=''),
    9960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9960, CurrentID=0, Status='live', Symbol='USP3', Aliases=['SIH003', 'UBP'], description='ubiquitin specific peptidase 3', other_designations='ubiquitin carboxyl-terminal hydrolase 3|deubiquitinating enzyme 3|ubiquitin thioesterase 3|ubiquitin thiolesterase 3|ubiquitin-specific-processing protease 3', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63504593, end_position_on_the_genomic_accession=63594633, orientation='plus', exon_count=21, OMIM=[604728], no_hdr0=''),
    9961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9961, CurrentID=0, Status='live', Symbol='MVP', Aliases=['LRP', 'VAULT1'], description='major vault protein', other_designations='major vault protein|lung resistance-related protein|testicular secretory protein Li 30', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29820394, end_position_on_the_genomic_accession=29848039, orientation='plus', exon_count=15, OMIM=[605088], no_hdr0=''),
    9962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9962, CurrentID=0, Status='live', Symbol='SLC23A2', Aliases=['NBTL1', 'SLC23A1', 'SVCT2', 'YSPL2'], description='solute carrier family 23 member 2', other_designations='solute carrier family 23 member 2|Na(+)/L-ascorbic acid transporter 2|nucleobase transporter-like 1 protein|sodium-dependent vitamin C transporter-2|solute carrier family 23 (ascorbic acid transporter), member 2|solute carrier family 23 (nucleobase transporters), member 1|solute carrier family 23 (nucleobase transporters), member 2|testicular secretory protein Li 48|yolk sac permease-like molecule 2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4852358, end_position_on_the_genomic_accession=5010313, orientation='minus', exon_count=18, OMIM=[603791], no_hdr0=''),
    9963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9963, CurrentID=0, Status='live', Symbol='SLC23A1', Aliases=['SLC23A2', 'SVCT1', 'YSPL3'], description='solute carrier family 23 member 1', other_designations='solute carrier family 23 member 1|Na(+)/L-ascorbic acid transporter 1|hSVCT1|sodium-dependent vitamin C transporter-1|solute carrier family 23 (ascorbic acid transporter), member 1|solute carrier family 23 (nucleobase transporters), member 1|solute carrier family 23 (nucleobase transporters), member 2|yolk sac permease-like molecule 3', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139367196, end_position_on_the_genomic_accession=139384553, orientation='minus', exon_count=17, OMIM=[603790], no_hdr0=''),
    9965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9965, CurrentID=0, Status='live', Symbol='FGF19', Aliases=[], description='fibroblast growth factor 19', other_designations='fibroblast growth factor 19|FGF-19', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69698238, end_position_on_the_genomic_accession=69704022, orientation='minus', exon_count=3, OMIM=[603891], no_hdr0=''),
    9966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9966, CurrentID=0, Status='live', Symbol='TNFSF15', Aliases=['TL1', 'TL1A', 'TNLG1B', 'VEGI', 'VEGI192A'], description='TNF superfamily member 15', other_designations='tumor necrosis factor ligand superfamily member 15|TNF ligand-related molecule 1|TNF superfamily ligand TL1A|tumor necrosis factor (ligand) superfamily, member 15|tumor necrosis factor ligand 1B|tumor necrosis factor superfamily member 15|vascular endothelial cell growth inhibitor|vascular endothelial growth inhibitor-192A', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114784635, end_position_on_the_genomic_accession=114806039, orientation='minus', exon_count=4, OMIM=[604052], no_hdr0=''),
    9967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9967, CurrentID=0, Status='live', Symbol='THRAP3', Aliases=['BCLAF2', 'TRAP150'], description='thyroid hormone receptor associated protein 3', other_designations='thyroid hormone receptor-associated protein 3|BCLAF1 and THRAP3 family member 2|TR-associated protein, 150-kDa|thyroid hormone receptor-associated protein complex 150 kDa component|thyroid hormone receptor-associated protein, 150 kDa subunit', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36224429, end_position_on_the_genomic_accession=36305357, orientation='plus', exon_count=15, OMIM=[603809], no_hdr0=''),
    9968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9968, CurrentID=0, Status='live', Symbol='MED12', Aliases=['ARC240', 'CAGH45', 'FGS1', 'HOPA', 'KtoS', 'OHDOX', 'OKS', 'OPA1', 'TNRC11', 'TRAP230', 'MED12'], description='mediator complex subunit 12', other_designations='mediator of RNA polymerase II transcription subunit 12|CAG repeat protein 45|Kohtalo homolog|OPA-containing protein|activator-recruited cofactor 240 kDa component|human opposite paired|mediator of RNA polymerase II transcription, subunit 12 homolog|putative mediator subunit 12|thyroid hormone receptor-associated protein complex 230 kDa component|thyroid hormone receptor-associated protein, 230 kDa subunit|trinucleotide repeat containing 11 (THR-associated protein, 230 kDa subunit)|trinucleotide repeat-containing gene 11 protein', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71118596, end_position_on_the_genomic_accession=71142450, orientation='plus', exon_count=45, OMIM=[300188], no_hdr0=''),
    9969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9969, CurrentID=0, Status='live', Symbol='MED13', Aliases=['ARC250', 'DRIP250', 'HSPC221', 'MRD61', 'THRAP1', 'TRAP240'], description='mediator complex subunit 13', other_designations='mediator of RNA polymerase II transcription subunit 13|activator-recruited cofactor 250 kDa component|mediator of RNA polymerase II transcription, subunit 13 homolog|thyroid hormone receptor-associated protein 1|thyroid hormone receptor-associated protein complex 240 kDa component|thyroid hormone receptor-associated protein complex component TRAP240|thyroid hormone receptor-associated protein, 240 kDa subunit|vitamin D3 receptor-interacting protein complex component DRIP250', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61942605, end_position_on_the_genomic_accession=62065983, orientation='minus', exon_count=31, OMIM=[603808], no_hdr0=''),
    9970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9970, CurrentID=0, Status='live', Symbol='NR1I3', Aliases=['CAR', 'CAR1', 'MB67'], description='nuclear receptor subfamily 1 group I member 3', other_designations='nuclear receptor subfamily 1 group I member 3|constitutive activator of retinoid response|constitutive active receptor|constitutive active response|constitutive androstane nuclear receptor variant 2|constitutive androstane nuclear receptor variant 3|constitutive androstane nuclear receptor variant 4|constitutive androstane nuclear receptor variant 5|constitutive androstane receptor|orphan nuclear hormone receptor|orphan nuclear receptor MB67', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161229666, end_position_on_the_genomic_accession=161238623, orientation='minus', exon_count=9, OMIM=[603881], no_hdr0=''),
    9971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9971, CurrentID=0, Status='live', Symbol='NR1H4', Aliases=['BAR', 'FXR', 'HRR-1', 'HRR1', 'PFIC5', 'RIP14'], description='nuclear receptor subfamily 1 group H member 4', other_designations='bile acid receptor|RXR-interacting protein 14|farnesoid X nuclear receptor|farnesoid X-activated receptor|farnesol receptor HRR-1|retinoid X receptor-interacting protein 14', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100473866, end_position_on_the_genomic_accession=100564414, orientation='plus', exon_count=14, OMIM=[603826], no_hdr0=''),
    9972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9972, CurrentID=0, Status='live', Symbol='NUP153', Aliases=['HNUP153', 'N153'], description='nucleoporin 153', other_designations='nuclear pore complex protein Nup153|153 kDa nucleoporin|nuclear pore complex protein hnup153|nucleoporin 153kD|nucleoporin 153kDa|nucleoporin Nup153', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17615036, end_position_on_the_genomic_accession=17706925, orientation='minus', exon_count=24, OMIM=[603948], no_hdr0=''),
    9973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9973, CurrentID=0, Status='live', Symbol='CCS', Aliases=[], description='copper chaperone for superoxide dismutase', other_designations='copper chaperone for superoxide dismutase|superoxide dismutase copper chaperone', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66593162, end_position_on_the_genomic_accession=66606019, orientation='plus', exon_count=8, OMIM=[603864], no_hdr0=''),
    9975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9975, CurrentID=0, Status='live', Symbol='NR1D2', Aliases=['BD73', 'EAR-1R', 'REVERBB', 'REVERBbeta', 'RVR'], description='nuclear receptor subfamily 1 group D member 2', other_designations='nuclear receptor subfamily 1 group D member 2|V-erbA-related protein 1-related|nuclear receptor Rev-ErbA beta variant 1|nuclear receptor Rev-ErbA beta variant 2|orphan nuclear hormone receptor BD73|rev-erb alpha-related receptor|rev-erb-beta|rev-erba-alpha-related receptor', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=23945286, end_position_on_the_genomic_accession=23980618, orientation='plus', exon_count=10, OMIM=[602304], no_hdr0=''),
    9976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9976, CurrentID=0, Status='live', Symbol='CLEC2B', Aliases=['AICL', 'CLECSF2', 'HP10085', 'IFNRG1'], description='C-type lectin domain family 2 member B', other_designations='C-type lectin domain family 2 member B|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 2 (activation-induced)|C-type lectin superfamily member 2|IFN-alpha-2b-inducing-related protein 1|IFN-alpha2b-inducing related protein 1|activation-induced C-type lectin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9852369, end_position_on_the_genomic_accession=9869354, orientation='minus', exon_count=5, OMIM=[603242], no_hdr0=''),
    9978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9978, CurrentID=0, Status='live', Symbol='RBX1', Aliases=['BA554C12.1', 'RNF75', 'ROC1'], description='ring-box 1', other_designations='E3 ubiquitin-protein ligase RBX1|E3 ubiquitin-protein transferase RBX1|RING finger protein 75|RING-box protein 1|ZYP protein|regulator of cullins 1|ring-box 1, E3 ubiquitin protein ligase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40951378, end_position_on_the_genomic_accession=40973309, orientation='plus', exon_count=5, OMIM=[603814], no_hdr0=''),
    9980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9980, CurrentID=0, Status='live', Symbol='DOP1B', Aliases=['21orf5', 'C21orf5', 'DOPEY2'], description='DOP1 leucine zipper like protein B', other_designations='protein dopey-2|dopey family member 2|homolog of yeast DOP1', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36156781, end_position_on_the_genomic_accession=36294274, orientation='plus', exon_count=39, OMIM=[604803], no_hdr0=''),
    9982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9982, CurrentID=0, Status='live', Symbol='FGFBP1', Aliases=['FGF-BP', 'FGF-BP1', 'FGFBP', 'FGFBP-1', 'HBP17'], description='fibroblast growth factor binding protein 1', other_designations='fibroblast growth factor-binding protein 1|17 kDa HBGF-binding protein|17 kDa heparin-binding growth factor-binding protein|FGF-binding protein 1|heparin-binding growth factor binding protein', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15935577, end_position_on_the_genomic_accession=15938740, orientation='minus', exon_count=3, OMIM=[607737], no_hdr0=''),
    9984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9984, CurrentID=0, Status='live', Symbol='THOC1', Aliases=['HPR1', 'P84', 'P84N5'], description='THO complex 1', other_designations='THO complex subunit 1|hTREX84|nuclear matrix protein p84|tho1', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=214348, end_position_on_the_genomic_accession=268047, orientation='minus', exon_count=23, OMIM=[606930], no_hdr0=''),
    9985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9985, CurrentID=0, Status='live', Symbol='REC8', Aliases=['HR21spBL1', 'Rec8p', 'REC8'], description='REC8 meiotic recombination protein', other_designations='meiotic recombination protein REC8 homolog|REC8 homolog|REC8-like 1|cohesin Rec8p|cohesion rec8p|human homolog of rad21, S. pombe|kleisin-alpha|meiotic recombination and sister chromatid cohesion phosphoprotein of the rad21p family|meiotic recombination protein REC8-like 1|recombination and sister chromatid cohesion protein homolog', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24171931, end_position_on_the_genomic_accession=24180408, orientation='plus', exon_count=19, OMIM=[608193], no_hdr0=''),
    9986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9986, CurrentID=0, Status='live', Symbol='RCE1', Aliases=['FACE2A', 'RCE1B', 'RCE1'], description='Ras converting CAAX endopeptidase 1', other_designations='CAAX prenyl protease 2|RCE1 homolog, prenyl protein peptidase|farnesylated protein-converting enzyme 2|farnesylated proteins-converting enzyme 2|prenyl protein-specific endoprotease 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66843441, end_position_on_the_genomic_accession=66846552, orientation='plus', exon_count=8, OMIM=[605385], no_hdr0=''),
    9987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9987, CurrentID=0, Status='live', Symbol='HNRNPDL', Aliases=['HNRNP', 'HNRPDL', 'JKTBP', 'JKTBP2', 'LGMD1G', 'LGMDD3', 'laAUF1'], description='heterogeneous nuclear ribonucleoprotein D like', other_designations='heterogeneous nuclear ribonucleoprotein D-like|A+U-rich element RNA binding factor|AU-rich element RNA-binding factor|JKT41-binding protein|hnRNP D-like|hnRNP DL|limb girdle muscular dystrophy 1G (autosomal dominant)|protein laAUF1', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82422564, end_position_on_the_genomic_accession=82430462, orientation='minus', exon_count=9, OMIM=[607137], no_hdr0=''),
    9988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9988, CurrentID=0, Status='live', Symbol='DMTF1', Aliases=['DMP1', 'DMTF', 'MRUL', 'hDMP1'], description='cyclin D binding myb like transcription factor 1', other_designations='cyclin-D-binding Myb-like transcription factor 1|cyclin D-binding Myb-like protein|cyclin-D-interacting Myb-like protein 1|hDMTF1', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87152421, end_position_on_the_genomic_accession=87196325, orientation='plus', exon_count=24, OMIM=[608491], no_hdr0=''),
    9989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9989, CurrentID=0, Status='live', Symbol='PPP4R1', Aliases=['MEG1', 'PP4(Rmeg)', 'PP4R1'], description='protein phosphatase 4 regulatory subunit 1', other_designations='serine/threonine-protein phosphatase 4 regulatory subunit 1|serine/threonine phosphatase 4', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9546794, end_position_on_the_genomic_accession=9615273, orientation='minus', exon_count=22, OMIM=[604908], no_hdr0=''),
    9990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9990, CurrentID=0, Status='live', Symbol='SLC12A6', Aliases=['ACCPN', 'KCC3', 'KCC3A', 'KCC3B'], description='solute carrier family 12 member 6', other_designations='solute carrier family 12 member 6|K-Cl cotransporter 3|electroneutral potassium-chloride cotransporter 3|potassium chloride cotransporter 3|potassium chloride cotransporter KCC3a-S3|potassium-chloride transporter-3a|potassium-chloride transporter-3b|solute carrier family 12 (potassium/chloride transporter), member 6|solute carrier family 12 (potassium/chloride transporters), member 6', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34229784, end_position_on_the_genomic_accession=34338057, orientation='minus', exon_count=27, OMIM=[604878], no_hdr0=''),
    9991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9991, CurrentID=0, Status='live', Symbol='PTBP3', Aliases=['ROD1'], description='polypyrimidine tract binding protein 3', other_designations='polypyrimidine tract-binding protein 3|ROD1 regulator of differentiation 1|fission yeast differentiation regulator|regulator of differentiation 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112217715, end_position_on_the_genomic_accession=112333669, orientation='minus', exon_count=16, OMIM=[607527], no_hdr0=''),
    9992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9992, CurrentID=0, Status='live', Symbol='KCNE2', Aliases=['ATFB4', 'LQT5', 'LQT6', 'MIRP1'], description='potassium voltage-gated channel subfamily E regulatory subunit 2', other_designations='potassium voltage-gated channel subfamily E member 2|cardiac voltage-gated potassium channel accessory subunit 2|minK-related peptide-1|minimum potassium ion channel-related peptide 1|potassium channel subunit beta MiRP1|potassium channel subunit, MiRP1|potassium channel, voltage gated subfamily E regulatory beta subunit 2|potassium voltage-gated channel, Isk-related family, member 2|voltage-gated K+ channel subunit MIRP1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34364006, end_position_on_the_genomic_accession=34371381, orientation='plus', exon_count=2, OMIM=[603796], no_hdr0=''),
    9993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9993, CurrentID=0, Status='live', Symbol='DGCR2', Aliases=['DGS-C', 'IDD', 'LAN', 'SEZ-12'], description='DiGeorge syndrome critical region gene 2', other_designations='integral membrane protein DGCR2/IDD|DiGeorge syndrome critical region protein 2|integral membrane protein deleted in DiGeorge syndrome', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19036286, end_position_on_the_genomic_accession=19122454, orientation='minus', exon_count=11, OMIM=[600594], no_hdr0=''),
    9994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9994, CurrentID=0, Status='live', Symbol='CASP8AP2', Aliases=['CED-4', 'FLASH', 'RIP25'], description='caspase 8 associated protein 2', other_designations='CASP8-associated protein 2|FLASH homolog RIP25|FLICE associated huge|FLICE-associated huge protein|human FLASH', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89829880, end_position_on_the_genomic_accession=89874436, orientation='plus', exon_count=10, OMIM=[606880], no_hdr0=''),
    9997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=9997, CurrentID=0, Status='live', Symbol='SCO2', Aliases=['CEMCOX1', 'ECGF1', 'Gliostatin', 'MC4DN2', 'MYP6', 'PD-ECGF', 'SCO1L', 'TP', 'TYMP', 'TdRPase'], description='synthesis of cytochrome C oxidase 2', other_designations='protein SCO2 homolog, mitochondrial|Platelet-derived endothelial cell growth factor|SCO cytochrome c oxidase assembly protein 2|SCO cytochrome oxidase deficient homolog 2|SCO2, cytochrome c oxidase assembly protein|Thymidine phosphorylase', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50523568, end_position_on_the_genomic_accession=50526442, orientation='minus', exon_count=4, OMIM=[604272], no_hdr0=''),
    10000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10000, CurrentID=0, Status='live', Symbol='AKT3', Aliases=['MPPH', 'MPPH2', 'PKB-GAMMA', 'PKBG', 'PRKBG', 'RAC-PK-gamma', 'RAC-gamma', 'STK-2'], description='AKT serine/threonine kinase 3', other_designations='RAC-gamma serine/threonine-protein kinase|PKB gamma|RAC-gamma serine/threonine protein kinase|v-akt murine thymoma viral oncogene homolog 3 (protein kinase B, gamma)', map_location='1q43-q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=243488233, end_position_on_the_genomic_accession=243851079, orientation='minus', exon_count=24, OMIM=[611223], no_hdr0=''),
    10001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10001, CurrentID=0, Status='live', Symbol='MED6', Aliases=['ARC33', 'NY-REN-28'], description='mediator complex subunit 6', other_designations='mediator of RNA polymerase II transcription subunit 6|CTD-2540L5.5|activator-recruited cofactor 33 kDa component|renal carcinoma antigen NY-REN-28', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70583221, end_position_on_the_genomic_accession=70600655, orientation='minus', exon_count=9, OMIM=[602984], no_hdr0=''),
    10002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10002, CurrentID=0, Status='live', Symbol='NR2E3', Aliases=['ESCS', 'PNR', 'RNR', 'RP37', 'rd7'], description='nuclear receptor subfamily 2 group E member 3', other_designations='photoreceptor-specific nuclear receptor|retina-specific nuclear receptor', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=71810554, end_position_on_the_genomic_accession=71818253, orientation='plus', exon_count=8, OMIM=[604485], no_hdr0=''),
    10003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10003, CurrentID=0, Status='live', Symbol='NAALAD2', Aliases=['GCPIII', 'GPCIII', 'NAADALASE2', 'NAALADASE2'], description='N-acetylated alpha-linked acidic dipeptidase 2', other_designations='N-acetylated-alpha-linked acidic dipeptidase 2|N-acetylated alpha-linked acidic dipeptidase II|NAALADase II|glutamate carboxypeptidase III', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=90131693, end_position_on_the_genomic_accession=90193577, orientation='plus', exon_count=22, OMIM=[611636], no_hdr0=''),
    10004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10004, CurrentID=0, Status='live', Symbol='NAALADL1', Aliases=['I100', 'NAALADASEL'], description='N-acetylated alpha-linked acidic dipeptidase like 1', other_designations='aminopeptidase NAALADL1|100 kDa ileum brush border membrane protein|N-acetylated-alpha-linked acidic dipeptidase-like protein|NAALADase L|ileal dipeptidylpeptidase|ileal peptidase I100|peptidase homolog', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65044818, end_position_on_the_genomic_accession=65059020, orientation='minus', exon_count=19, OMIM=[602640], no_hdr0=''),
    10005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10005, CurrentID=0, Status='live', Symbol='ACOT8', Aliases=['HNAACTE', 'NAP1', 'PTE-1', 'PTE-2', 'PTE1', 'PTE2', 'hACTE-III', 'hTE'], description='acyl-CoA thioesterase 8', other_designations='acyl-coenzyme A thioesterase 8|HIV-Nef associated acyl-CoA thioesterase|Nef (lentivirus myristoylated factor) associated protein 1|choloyl-CoA hydrolase|choloyl-coenzyme A thioesterase|long-chain fatty-acyl-CoA hydrolase|palmitoyl-CoA hydrolase|peroxisomal acyl-CoA thioesterase 1|peroxisomal acyl-CoA thioesterase 2|peroxisomal acyl-coenzyme A thioester hydrolase 1|peroxisomal long-chain acyl-CoA thioesterase 1|thioesterase II|thioesterase III', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45841721, end_position_on_the_genomic_accession=45857405, orientation='minus', exon_count=7, OMIM=[608123], no_hdr0=''),
    10006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10006, CurrentID=0, Status='live', Symbol='ABI1', Aliases=['ABI-1', 'ABLBP4', 'E3B1', 'NAP1BP', 'SSH3BP', 'SSH3BP1'], description='abl interactor 1', other_designations='abl interactor 1|Abelson interactor 1|Abl-interactor protein 1 long|abl-binding protein 4|eps8 SH3 domain-binding protein|interactor protein AblBP4|nap1 binding protein|spectrin SH3 domain-binding protein 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=26746596, end_position_on_the_genomic_accession=26860986, orientation='minus', exon_count=15, OMIM=[603050], no_hdr0=''),
    10007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10007, CurrentID=0, Status='live', Symbol='GNPDA1', Aliases=['GNP1', 'GNPDA', 'GNPI', 'GPI', 'HLN'], description='glucosamine-6-phosphate deaminase 1', other_designations='glucosamine-6-phosphate isomerase 1|GNPDA 1|glcN6P deaminase 1|oscillin', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=142000671, end_position_on_the_genomic_accession=142013027, orientation='minus', exon_count=9, OMIM=[601798], no_hdr0=''),
    10008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10008, CurrentID=0, Status='live', Symbol='KCNE3', Aliases=['BRGDA6', 'HOKPP', 'HYPP', 'MiRP2'], description='potassium voltage-gated channel subfamily E regulatory subunit 3', other_designations='potassium voltage-gated channel subfamily E member 3|cardiac voltage-gated potassium channel accessory subunit|minK-related peptide 2|minimum potassium ion channel-related peptide 2|potassium channel subunit beta MiRP2|potassium channel, voltage gated subfamily E regulatory beta subunit 3|potassium voltage-gated channel, Isk-related family, member 3|voltage-gated K+ channel subunit MIRP2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74454841, end_position_on_the_genomic_accession=74467729, orientation='minus', exon_count=6, OMIM=[604433], no_hdr0=''),
    10009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10009, CurrentID=0, Status='live', Symbol='ZBTB33', Aliases=['ZNF-kaiso', 'ZNF348'], description='zinc finger and BTB domain containing 33', other_designations='transcriptional regulator Kaiso|WUGSC:H_DJ525N14.1|kaiso transcription factor|zinc finger and BTB domain-containing protein 33', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120250812, end_position_on_the_genomic_accession=120258398, orientation='plus', exon_count=3, OMIM=[300329], no_hdr0=''),
    10010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10010, CurrentID=0, Status='live', Symbol='TANK', Aliases=['I-TRAF', 'ITRAF', 'TRAF2'], description='TRAF family member associated NFKB activator', other_designations='TRAF family member-associated NF-kappa-B activator|TRAF-interacting protein', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=161136963, end_position_on_the_genomic_accession=161236230, orientation='plus', exon_count=14, OMIM=[603893], no_hdr0=''),
    10011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10011, CurrentID=0, Status='live', Symbol='SRA1', Aliases=['SRA', 'SRAP', 'STRAA1', 'pp7684'], description='steroid receptor RNA activator 1', other_designations='steroid receptor RNA activator 1|steroid receptor RNA activator 1 (complexes with NCOA1)|steroid receptor RNA activator protein|steroid receptor coactivator', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140550067, end_position_on_the_genomic_accession=140558093, orientation='minus', exon_count=5, OMIM=[603819], no_hdr0=''),
    10013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10013, CurrentID=0, Status='live', Symbol='HDAC6', Aliases=['CPBHM', 'HD6', 'JM21', 'PPP1R90'], description='histone deacetylase 6', other_designations='histone deacetylase 6|protein phosphatase 1, regulatory subunit 90|tubulin-lysine deacetylase HDAC6', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48801398, end_position_on_the_genomic_accession=48824982, orientation='plus', exon_count=32, OMIM=[300272], no_hdr0=''),
    10014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10014, CurrentID=0, Status='live', Symbol='HDAC5', Aliases=['HD5', 'NY-CO-9'], description='histone deacetylase 5', other_designations='histone deacetylase 5|antigen NY-CO-9', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44076753, end_position_on_the_genomic_accession=44123651, orientation='minus', exon_count=30, OMIM=[605315], no_hdr0=''),
    10015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10015, CurrentID=0, Status='live', Symbol='PDCD6IP', Aliases=['AIP1', 'ALIX', 'DRIP4', 'HP95'], description='programmed cell death 6 interacting protein', other_designations='programmed cell death 6-interacting protein|ALG-2 interacting protein 1|ALG-2-interacting protein X|PDCD6-interacting protein|apoptosis-linked gene 2-interacting protein X|dopamine receptor interacting protein 4', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33798630, end_position_on_the_genomic_accession=33869703, orientation='plus', exon_count=20, OMIM=[608074], no_hdr0=''),
    10016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10016, CurrentID=0, Status='live', Symbol='PDCD6', Aliases=['ALG-2', 'ALG2', 'PEF1B'], description='programmed cell death 6', other_designations='programmed cell death protein 6|apoptosis-linked gene 2 protein homolog|probable calcium-binding protein ALG-2', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=271646, end_position_on_the_genomic_accession=314974, orientation='plus', exon_count=7, OMIM=[601057], no_hdr0=''),
    10017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10017, CurrentID=0, Status='live', Symbol='BCL2L10', Aliases=['BCL-B', 'Boo', 'Diva', 'bcl2-L-10'], description='BCL2 like 10', other_designations='bcl-2-like protein 10|BCL2-like 10 (apoptosis facilitator)|anti-apoptotic protein NrH|apoptosis regulator Bcl-B|death inducer binding to vBcl-2 and Apaf-1', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52109263, end_position_on_the_genomic_accession=52112775, orientation='minus', exon_count=2, OMIM=[606910], no_hdr0=''),
    10018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10018, CurrentID=0, Status='live', Symbol='BCL2L11', Aliases=['BAM', 'BIM', 'BOD'], description='BCL2 like 11', other_designations='bcl-2-like protein 11|BCL2-like 11 (apoptosis facilitator)|bcl-2 interacting mediator of cell death|bcl-2 interacting protein Bim|bcl-2-related ovarian death agonist', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=111120914, end_position_on_the_genomic_accession=111168445, orientation='plus', exon_count=14, OMIM=[603827], no_hdr0=''),
    10019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10019, CurrentID=0, Status='live', Symbol='SH2B3', Aliases=['IDDM20', 'LNK'], description='SH2B adaptor protein 3', other_designations='SH2B adapter protein 3|lymphocyte-specific adapter protein Lnk|signal transduction protein Lnk|truncated SH2B3', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111405107, end_position_on_the_genomic_accession=111451623, orientation='plus', exon_count=12, OMIM=[605093], no_hdr0=''),
    10020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10020, CurrentID=0, Status='live', Symbol='GNE', Aliases=['DMRV', 'GLCNE', 'IBM2', 'NM', 'Uae1'], description='glucosamine (UDP-N-acetyl)-2-epimerase/N-acetylmannosamine kinase', other_designations='bifunctional UDP-N-acetylglucosamine 2-epimerase/N-acetylmannosamine kinase|N-acylmannosamine kinase|UDP-GlcNAc-2-epimerase/ManAc kinase|UDP-N-acetylglucosamine 2-epimerase/N-acetylmannosamine kinase', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36214441, end_position_on_the_genomic_accession=36277056, orientation='minus', exon_count=14, OMIM=[603824], no_hdr0=''),
    10021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10021, CurrentID=0, Status='live', Symbol='HCN4', Aliases=['SSS2'], description='hyperpolarization activated cyclic nucleotide gated potassium channel 4', other_designations='potassium/sodium hyperpolarization-activated cyclic nucleotide-gated channel 4|hyperpolarization activated cyclic nucleotide-gated cation channel 4', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73319859, end_position_on_the_genomic_accession=73368958, orientation='minus', exon_count=9, OMIM=[605206], no_hdr0=''),
    10022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10022, CurrentID=0, Status='live', Symbol='INSL5', Aliases=['PRO182', 'UNQ156'], description='insulin like 5', other_designations='insulin-like peptide INSL5|insulin-like peptide 5|prepro-INSL5', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66797740, end_position_on_the_genomic_accession=66801276, orientation='minus', exon_count=2, OMIM=[606413], no_hdr0=''),
    10023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10023, CurrentID=0, Status='live', Symbol='FRAT1', Aliases=[], description='FRAT regulator of WNT signaling pathway 1', other_designations='proto-oncogene FRAT1|FRAT-1|FRAT1, WNT signaling pathway regulator|frequently rearranged in advanced T-cell lymphomas 1', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97319271, end_position_on_the_genomic_accession=97321915, orientation='plus', exon_count=1, OMIM=[602503], no_hdr0=''),
    10024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10024, CurrentID=0, Status='live', Symbol='TROAP', Aliases=['TASTIN'], description='trophinin associated protein', other_designations='tastin|trophinin assisting protein|trophinin-assisting protein (tastin)', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49323255, end_position_on_the_genomic_accession=49331733, orientation='plus', exon_count=16, OMIM=[603872], no_hdr0=''),
    10025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10025, CurrentID=0, Status='live', Symbol='MED16', Aliases=['DRIP92', 'THRAP5', 'TRAP95'], description='mediator complex subunit 16', other_designations='mediator of RNA polymerase II transcription subunit 16|thyroid hormone receptor-associated protein 5|thyroid hormone receptor-associated protein complex 95 kDa component|thyroid hormone receptor-associated protein, 95-kD subunit|vitamin D3 receptor-interacting protein complex 92 kDa component', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=867961, end_position_on_the_genomic_accession=893228, orientation='minus', exon_count=16, OMIM=[604062], no_hdr0=''),
    10026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10026, CurrentID=0, Status='live', Symbol='PIGK', Aliases=['GPI8', 'NEDHCAS'], description='phosphatidylinositol glycan anchor biosynthesis class K', other_designations='GPI-anchor transamidase|GPI transamidase subunit|GPI8 homolog|PIG-K|phosphatidylinositol glycan, class K|phosphatidylinositol-glycan biosynthesis class K protein', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77088989, end_position_on_the_genomic_accession=77219430, orientation='minus', exon_count=11, OMIM=[605087], no_hdr0=''),
    10036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10036, CurrentID=0, Status='live', Symbol='CHAF1A', Aliases=['CAF-1', 'CAF1', 'CAF1B', 'CAF1P150', 'P150'], description='chromatin assembly factor 1 subunit A', other_designations='chromatin assembly factor 1 subunit A|CAF-1 subunit A|CAF-I 150 kDa subunit|CAF-I p150|CTB-50L17.7|chromatin assembly factor I (150 kDa)|chromatin assembly factor I p150 subunit|hp150', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4402596, end_position_on_the_genomic_accession=4448322, orientation='plus', exon_count=18, OMIM=[601246], no_hdr0=''),
    10038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10038, CurrentID=0, Status='live', Symbol='PARP2', Aliases=['ADPRT2', 'ADPRTL2', 'ADPRTL3', 'ARTD2', 'PARP-2', 'pADPRT-2'], description='poly(ADP-ribose) polymerase 2', other_designations='poly [ADP-ribose] polymerase 2|ADP-ribosyltransferase (NAD+; poly(ADP-ribose) polymerase)-like 2|ADP-ribosyltransferase diphtheria toxin-like 2|ADPRT-2|DNA ADP-ribosyltransferase PARP2|NAD(+) ADP-ribosyltransferase 2|hPARP-2|poly (ADP-ribose) polymerase family, member 2|poly (ADP-ribosyl) transferase-like 2|poly[ADP-ribose] synthase 2|poly[ADP-ribose] synthetase 2|protein poly-ADP-ribosyltransferase PARP2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20343041, end_position_on_the_genomic_accession=20357904, orientation='plus', exon_count=16, OMIM=[607725], no_hdr0=''),
    10039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10039, CurrentID=0, Status='live', Symbol='PARP3', Aliases=['ADPRT3', 'ADPRTL2', 'ADPRTL3', 'ARTD3', 'IRT1', 'PADPRT-3'], description='poly(ADP-ribose) polymerase family member 3', other_designations='protein mono-ADP-ribosyltransferase PARP3|ADP-ribosyltransferase (NAD+; poly (ADP-ribose) polymerase)-like 2|ADP-ribosyltransferase (NAD+; poly (ADP-ribose) polymerase)-like 3|ADP-ribosyltransferase diphtheria toxin-like 3|ADPRT-3|DNA ADP-ribosyltransferase PARP3|NAD(+) ADP-ribosyltransferase 3|NAD+ ADP-ribosyltransferase 3|poly [ADP-ribose] polymerase 3|poly(ADP-ribose) synthetase-3|poly[ADP-ribose] synthase 3|poly[ADP-ribose] synthetase 3', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51942290, end_position_on_the_genomic_accession=51948867, orientation='plus', exon_count=12, OMIM=[607726], no_hdr0=''),
    10040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10040, CurrentID=0, Status='live', Symbol='TOM1L1', Aliases=['SRCASM'], description='target of myb1 like 1 membrane trafficking protein', other_designations='TOM1-like protein 1|src-activating and signaling molecule protein|target of Myb-like protein 1', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=54900807, end_position_on_the_genomic_accession=54961967, orientation='plus', exon_count=17, OMIM=[604701], no_hdr0=''),
    10042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10042, CurrentID=0, Status='live', Symbol='HMGXB4', Aliases=['HMG2L1', 'HMGBCG', 'P53N', 'THC211630'], description='HMG-box containing 4', other_designations='HMG domain-containing protein 4|HMG box domain containing 4|HMG box-containing protein 4|high mobility group protein 2-like 1', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35256697, end_position_on_the_genomic_accession=35295807, orientation='plus', exon_count=12, OMIM=[604702], no_hdr0=''),
    10043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10043, CurrentID=0, Status='live', Symbol='TOM1', Aliases=[], description='target of myb1 membrane trafficking protein', other_designations='target of Myb protein 1|target of myb 1', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35299275, end_position_on_the_genomic_accession=35347981, orientation='plus', exon_count=17, OMIM=[604700], no_hdr0=''),
    10044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10044, CurrentID=0, Status='live', Symbol='SH2D3C', Aliases=['CHAT', 'NSP3', 'PRO34088', 'SHEP1'], description='SH2 domain containing 3C', other_designations='SH2 domain-containing protein 3C|SH2 domain-containing Eph receptor-binding protein 1|cas/HEF1-associated signal transducer|chat-H|novel SH2-containing protein 3', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127738317, end_position_on_the_genomic_accession=127778666, orientation='minus', exon_count=16, OMIM=[604722], no_hdr0=''),
    10045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10045, CurrentID=0, Status='live', Symbol='SH2D3A', Aliases=['NSP1'], description='SH2 domain containing 3A', other_designations='SH2 domain-containing protein 3A|novel SH2-containing protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6752160, end_position_on_the_genomic_accession=6767513, orientation='minus', exon_count=10, OMIM=[604721], no_hdr0=''),
    10046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10046, CurrentID=0, Status='live', Symbol='MAMLD1', Aliases=['CG1', 'CXorf6', 'F18', 'HYSP2'], description='mastermind like domain containing 1', other_designations='mastermind-like domain-containing protein 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=150361564, end_position_on_the_genomic_accession=150514178, orientation='plus', exon_count=12, OMIM=[300120], no_hdr0=''),
    10047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10047, CurrentID=0, Status='live', Symbol='CST8', Aliases=['CRES', 'CTES5'], description='cystatin 8', other_designations='cystatin-8|cystatin 8 (cystatin-related epididymal specific)|cystatin-related epididymal spermatogenic protein|epididymis secretory sperm binding protein', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23491077, end_position_on_the_genomic_accession=23507124, orientation='plus', exon_count=7, OMIM=[608683], no_hdr0=''),
    10048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10048, CurrentID=0, Status='live', Symbol='RANBP9', Aliases=['BPM-L', 'BPM90', 'RANBPM', 'RanBP7'], description='RAN binding protein 9', other_designations='ran-binding protein 9|Ran Binding Protein in the Microtubule organizing center|novel centrosomal protein RanBPM|ran binding protein, centrosomal|ran-binding protein M', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13621498, end_position_on_the_genomic_accession=13711835, orientation='minus', exon_count=17, OMIM=[603854], no_hdr0=''),
    10049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10049, CurrentID=0, Status='live', Symbol='DNAJB6', Aliases=['DJ4', 'DnaJ', 'HHDJ1', 'HSJ-2', 'HSJ2', 'LGMD1D', 'LGMD1E', 'LGMDD1', 'MRJ', 'MSJ-1'], description='DnaJ heat shock protein family (Hsp40) member B6', other_designations='dnaJ homolog subfamily B member 6|DnaJ (Hsp40) homolog, subfamily B, member 6|DnaJ-like 2 protein|heat shock protein J2', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=157337004, end_position_on_the_genomic_accession=157417439, orientation='plus', exon_count=11, OMIM=[611332], no_hdr0=''),
    10050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10050, CurrentID=0, Status='live', Symbol='SLC17A4', Aliases=['KAIA2138'], description='solute carrier family 17 member 4', other_designations='probable small intestine urate exporter|Na/PO4 cotransporter|putative small intestine sodium-dependent phosphate transport protein|solute carrier family 17 (sodium phosphate), member 4', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25754673, end_position_on_the_genomic_accession=25781199, orientation='plus', exon_count=16, OMIM=[604216], no_hdr0=''),
    10051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10051, CurrentID=0, Status='live', Symbol='SMC4', Aliases=['CAP-C', 'CAPC', 'SMC-4L1', 'SMC4'], description='structural maintenance of chromosomes 4', other_designations='structural maintenance of chromosomes protein 4|SMC protein 4|SMC4 structural maintenance of chromosomes 4-like 1|chromosome-associated polypeptide C', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160399638, end_position_on_the_genomic_accession=160434953, orientation='plus', exon_count=24, OMIM=[605575], no_hdr0=''),
    10052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10052, CurrentID=0, Status='live', Symbol='GJC1', Aliases=['CX45', 'GJA7'], description='gap junction protein gamma 1', other_designations='gap junction gamma-1 protein|CTC-296K1.4|connexin-45|gap junction alpha-7 protein|gap junction protein, gamma 1, 45kDa', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44794988, end_position_on_the_genomic_accession=44831364, orientation='minus', exon_count=9, OMIM=[608655], no_hdr0=''),
    10053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10053, CurrentID=0, Status='live', Symbol='AP1M2', Aliases=['AP1-mu2', 'HSMU1B', 'MU-1B', 'MU1B', 'mu2'], description='adaptor related protein complex 1 subunit mu 2', other_designations='AP-1 complex subunit mu-2|AP-mu chain family member mu1B|HA1 47 kDa subunit 2|adaptor protein complex AP-1 mu-2 subunit|adaptor related protein complex 1 mu 2 subunit|clathrin assembly protein complex 1 mu-2 medium chain 2|clathrin coat assembly protein AP47 2|clathrin coat associated protein AP47 2|clathrin-associated adaptor medium chain mu2|golgi adaptor AP-1 47 kDa protein|golgi adaptor HA1/AP1 adaptin mu-2 subunit|mu-adaptin 2|mu1B-adaptin', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10572671, end_position_on_the_genomic_accession=10587315, orientation='minus', exon_count=12, OMIM=[607309], no_hdr0=''),
    10054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10054, CurrentID=0, Status='live', Symbol='UBA2', Aliases=['ARX', 'HRIHFB2115', 'SAE2'], description='ubiquitin like modifier activating enzyme 2', other_designations='SUMO-activating enzyme subunit 2|SUMO-1 activating enzyme subunit 2|SUMO1 activating enzyme subunit 2|UBA2, ubiquitin-activating enzyme E1 homolog|anthracycline-associated resistance ARX|ubiquitin-like 1-activating enzyme E1B', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34428176, end_position_on_the_genomic_accession=34471251, orientation='plus', exon_count=18, OMIM=[613295], no_hdr0=''),
    10055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10055, CurrentID=0, Status='live', Symbol='SAE1', Aliases=['AOS1', 'HSPC140', 'SUA1', 'UBLE1A'], description='SUMO1 activating enzyme subunit 1', other_designations='SUMO-activating enzyme subunit 1|SUMO-1 activating enzyme E1 N subunit|SUMO-1 activating enzyme subunit 1|activator of SUMO1|sentrin/SUMO-activating protein AOS1|ubiquitin-like 1-activating enzyme E1A|ubiquitin-like protein SUMO-1 activating enzyme', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47130835, end_position_on_the_genomic_accession=47210636, orientation='plus', exon_count=9, OMIM=[613294], no_hdr0=''),
    10056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10056, CurrentID=0, Status='live', Symbol='FARSB', Aliases=['FARSLB', 'FRSB', 'HSPC173', 'NEDBLLA', 'PheHB', 'PheRS', 'RILDBC', 'RILDBC1'], description='phenylalanyl-tRNA synthetase subunit beta', other_designations='phenylalanine--tRNA ligase beta subunit|phenylalanine tRNA ligase 1, beta, cytoplasmic|phenylalanine-tRNA ligase beta chain|phenylalanine-tRNA synthetase-like, beta subunit|phenylalanyl-tRNA synthetase beta chain|phenylalanyl-tRNA synthetase beta subunit|phenylalanyl-tRNA synthetase-like, beta subunit', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=222566899, end_position_on_the_genomic_accession=222656092, orientation='minus', exon_count=19, OMIM=[609690], no_hdr0=''),
    10057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10057, CurrentID=0, Status='live', Symbol='ABCC5', Aliases=['ABC33', 'EST277145', 'MOAT-C', 'MOATC', 'MRP5', 'SMRP', 'pABC11'], description='ATP binding cassette subfamily C member 5', other_designations='multidrug resistance-associated protein 5|ATP-binding cassette, sub-family C (CFTR/MRP), member 5|canalicular multispecific organic anion transporter C|multi-specific organic anion transporter C', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183919934, end_position_on_the_genomic_accession=184018010, orientation='minus', exon_count=36, OMIM=[605251], no_hdr0=''),
    10058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10058, CurrentID=0, Status='live', Symbol='ABCB6', Aliases=['ABC', 'LAN', 'MTABC3', 'PRP', 'umat'], description='ATP binding cassette subfamily B member 6 (Langereis blood group)', other_designations='ATP-binding cassette sub-family B member 6|ABC-type heme transporter ABCB6|ATP-binding cassette half-transporter|ATP-binding cassette, sub-family B (MDR/TAP), member 6 (Langereis blood group)|P-glycoprotein-related protein|mitochondrial ABC transporter 3|mt-ABC transporter 3|truncated ATP binding cassette subfamily b member 6|ubiquitously-expressed mammalian ABC half transporter', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219209772, end_position_on_the_genomic_accession=219218958, orientation='minus', exon_count=19, OMIM=[605452], no_hdr0=''),
    10059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10059, CurrentID=0, Status='live', Symbol='DNM1L', Aliases=['DLP1', 'DRP1', 'DVLP', 'DYMPLE', 'EMPF', 'EMPF1', 'HDYNIV', 'OPA5'], description='dynamin 1 like', other_designations='dynamin-1-like protein|Dnm1p/Vps1p-like protein|dynamin family member proline-rich carboxyl-terminal domain less|dynamin-like protein 4|dynamin-like protein IV|dynamin-related protein 1', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=32679296, end_position_on_the_genomic_accession=32745650, orientation='plus', exon_count=21, OMIM=[603850], no_hdr0=''),
    10060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10060, CurrentID=0, Status='live', Symbol='ABCC9', Aliases=['ABC37', 'ATFB12', 'CANTU', 'CMD1O', 'SUR2'], description='ATP binding cassette subfamily C member 9', other_designations='ATP-binding cassette sub-family C member 9|ATP-binding cassette transporter sub-family C member 9|ATP-binding cassette, sub-family C (CFTR/MRP), member 9|sulfonylurea receptor 2', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21797389, end_position_on_the_genomic_accession=21941863, orientation='minus', exon_count=42, OMIM=[601439], no_hdr0=''),
    10061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10061, CurrentID=0, Status='live', Symbol='ABCF2', Aliases=['ABC28', 'EST133090', 'HUSSY-18', 'HUSSY18'], description='ATP binding cassette subfamily F member 2', other_designations='ATP-binding cassette sub-family F member 2|ABC-type transport protein|ATP-binding cassette, sub-family F (GCN20), member 2|iron-inhibited ABC transporter 2', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151211484, end_position_on_the_genomic_accession=151227205, orientation='minus', exon_count=15, OMIM=[612510], no_hdr0=''),
    10062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10062, CurrentID=0, Status='live', Symbol='NR1H3', Aliases=['LXR-a', 'LXRA', 'RLD-1'], description='nuclear receptor subfamily 1 group H member 3', other_designations='oxysterols receptor LXR-alpha|liver X nuclear receptor alpha variant 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47248300, end_position_on_the_genomic_accession=47269033, orientation='plus', exon_count=17, OMIM=[602423], no_hdr0=''),
    10063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10063, CurrentID=0, Status='live', Symbol='COX17', Aliases=[], description='cytochrome c oxidase copper chaperone COX17', other_designations='cytochrome c oxidase copper chaperone|COX17 cytochrome c oxidase assembly homolog|COX17, cytochrome c oxidase copper chaperone|cytochrome c oxidase 17 copper chaperone|cytochrome c oxidase assembly homolog 17|human homolog of yeast mitochondrial copper recruitment', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119663975, end_position_on_the_genomic_accession=119677406, orientation='minus', exon_count=8, OMIM=[604813], no_hdr0=''),
    10066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10066, CurrentID=0, Status='live', Symbol='SCAMP2', Aliases=[], description='secretory carrier membrane protein 2', other_designations='secretory carrier-associated membrane protein 2|testis secretory sperm-binding protein Li 219p', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74843730, end_position_on_the_genomic_accession=74873365, orientation='minus', exon_count=11, OMIM=[606912], no_hdr0=''),
    10067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10067, CurrentID=0, Status='live', Symbol='SCAMP3', Aliases=['C1orf3'], description='secretory carrier membrane protein 3', other_designations='secretory carrier-associated membrane protein 3|propin 1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155255981, end_position_on_the_genomic_accession=155262360, orientation='minus', exon_count=9, OMIM=[606913], no_hdr0=''),
    10068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10068, CurrentID=0, Status='live', Symbol='IL18BP', Aliases=['FVHa', 'IL18BP'], description='interleukin 18 binding protein', other_designations='interleukin-18-binding protein|MC51L-53L-54L homolog gene product|tadekinig-alfa', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71997944, end_position_on_the_genomic_accession=72002919, orientation='plus', exon_count=8, OMIM=[604113], no_hdr0=''),
    10069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10069, CurrentID=0, Status='live', Symbol='RWDD2B', Aliases=['C21orf6', 'GL011'], description='RWD domain containing 2B', other_designations='RWD domain-containing protein 2B', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29004384, end_position_on_the_genomic_accession=29019349, orientation='minus', exon_count=6, OMIM=[617843], no_hdr0=''),
    10071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10071, CurrentID=0, Status='live', Symbol='MUC12', Aliases=['MUC-11', 'MUC-12', 'MUC11'], description='mucin 12, cell surface associated', other_designations='mucin-12|mucin-11', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100969565, end_position_on_the_genomic_accession=101018936, orientation='plus', exon_count=12, OMIM=[604609], no_hdr0=''),
    10072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10072, CurrentID=0, Status='live', Symbol='DPP3', Aliases=['DPPIII'], description='dipeptidyl peptidase 3', other_designations='dipeptidyl peptidase 3|DPP III|dipeptidyl aminopeptidase III|dipeptidyl arylamidase III|dipeptidyl peptidase III|enkephalinase B', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66480434, end_position_on_the_genomic_accession=66509657, orientation='plus', exon_count=18, OMIM=[606818], no_hdr0=''),
    10073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10073, CurrentID=0, Status='live', Symbol='SNUPN', Aliases=['KPNBL', 'RNUT1', 'Snurportin1'], description='snurportin 1', other_designations='snurportin-1|RNA U transporter 1', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75598086, end_position_on_the_genomic_accession=75626461, orientation='minus', exon_count=10, OMIM=[607902], no_hdr0=''),
    10075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10075, CurrentID=0, Status='live', Symbol='HUWE1', Aliases=['ARF-BP1', 'HECTH9', 'HSPC272', 'Ib772', 'LASU1', 'MRXST', 'MULE', 'URE-B1', 'UREB1'], description='HECT, UBA and WWE domain containing E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase HUWE1|ARF-binding protein 1|BJ-HCC-24 tumor antigen|HECT domain protein LASU1|HECT, UBA and WWE domain containing 1, E3 ubiquitin protein ligase|HECT-type E3 ubiquitin transferase HUWE1|Mcl-1 ubiquitin ligase E3|URE-binding protein 1|homologous to E6AP carboxyl terminus homologous protein 9|large structure of UREB1|upstream regulatory element-binding protein 1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53532096, end_position_on_the_genomic_accession=53686723, orientation='minus', exon_count=92, OMIM=[300697], no_hdr0=''),
    10076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10076, CurrentID=0, Status='live', Symbol='PTPRU', Aliases=['FMI', 'PCP-2', 'PTP', 'PTP-J', 'PTP-PI', 'PTP-RO', 'PTPPSI', 'PTPRO', 'PTPU2', 'R-PTP-PSI', 'R-PTP-U', 'hPTP-J'], description='protein tyrosine phosphatase receptor type U', other_designations='receptor-type tyrosine-protein phosphatase U|PTP pi|Receptor protein tyrosine phosphatase hPTP-J|pancreatic carcinoma phosphatase 2|pi R-PTP-Psi|protein-tyrosine phosphatase J|protein-tyrosine phosphatase pi|protein-tyrosine phosphatase receptor omicron|receptor-type protein-tyrosine phosphatase psi', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=29236522, end_position_on_the_genomic_accession=29326802, orientation='plus', exon_count=33, OMIM=[602454], no_hdr0=''),
    10077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10077, CurrentID=0, Status='live', Symbol='TSPAN32', Aliases=['ART1', 'PHEMX', 'PHMX', 'TSSC6'], description='tetraspanin 32', other_designations='tetraspanin-32|pan-hematopoietic expression protein|protein Phemx|tumor-suppressing STF cDNA 6|tumor-suppressing subchromosomal transferable fragment cDNA 6|tumor-suppressing subtransferable candidate 6', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2299480, end_position_on_the_genomic_accession=2318204, orientation='plus', exon_count=11, OMIM=[603853], no_hdr0=''),
    10078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10078, CurrentID=0, Status='live', Symbol='TSSC4', Aliases=[], description='tumor suppressing subtransferable candidate 4', other_designations='protein TSSC4|tumor-suppressing STF cDNA 4 protein|tumor-suppressing subchromosomal transferable fragment candidate gene 4 protein', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2398412, end_position_on_the_genomic_accession=2403878, orientation='plus', exon_count=4, OMIM=[603852], no_hdr0=''),
    10079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10079, CurrentID=0, Status='live', Symbol='ATP9A', Aliases=['ATPIIA'], description='ATPase phospholipid transporting 9A (putative)', other_designations='probable phospholipid-transporting ATPase IIA|ATPase type IV, phospholipid-transporting (P-type),(putative)|ATPase, class II, type 9A|phospholipid-transporting ATPase IIA', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=51596514, end_position_on_the_genomic_accession=51768390, orientation='minus', exon_count=29, OMIM=[609126], no_hdr0=''),
    10081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10081, CurrentID=0, Status='live', Symbol='PDCD7', Aliases=['59K', 'ES18', 'HES18'], description='programmed cell death 7', other_designations='programmed cell death protein 7|U11/U12 snRNP 59K|apoptosis-related protein ES18', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65117379, end_position_on_the_genomic_accession=65133808, orientation='minus', exon_count=5, OMIM=[608138], no_hdr0=''),
    10082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10082, CurrentID=0, Status='live', Symbol='GPC6', Aliases=['OMIMD1'], description='glypican 6', other_designations='glypican-6|glypican proteoglycan 6', map_location='13q31.3-q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=93226807, end_position_on_the_genomic_accession=94408020, orientation='plus', exon_count=15, OMIM=[604404], no_hdr0=''),
    10083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10083, CurrentID=0, Status='live', Symbol='USH1C', Aliases=['AIE-75', 'DFNB18', 'DFNB18A', 'NY-CO-37', 'NY-CO-38', 'PDZ-45', 'PDZ-73', 'PDZ-73/NY-CO-38', 'PDZ73', 'PDZD7C', 'ush1cpst'], description='USH1 protein network component harmonin', other_designations='harmonin|Usher syndrome 1C (autosomal recessive, severe)|antigen NY-CO-38/NY-CO-37|autoimmune enteropathy-related antigen AIE-75|renal carcinoma antigen NY-REN-3|usher syndrome type-1C protein', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17493895, end_position_on_the_genomic_accession=17544416, orientation='minus', exon_count=29, OMIM=[605242], no_hdr0=''),
    10084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10084, CurrentID=0, Status='live', Symbol='PQBP1', Aliases=['MRX2', 'MRX55', 'MRXS3', 'MRXS8', 'NPW38', 'RENS1', 'SHS'], description='polyglutamine binding protein 1', other_designations='polyglutamine-binding protein 1|38 kDa nuclear protein containing a WW domain|polyglutamine tract-binding protein 1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48897862, end_position_on_the_genomic_accession=48903143, orientation='plus', exon_count=8, OMIM=[300463], no_hdr0=''),
    10085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10085, CurrentID=0, Status='live', Symbol='EDIL3', Aliases=['DEL1'], description='EGF like repeats and discoidin domains 3', other_designations='EGF-like repeat and discoidin I-like domain-containing protein 3|EGF-like repeats and discoidin I-like domains 3|developmental endothelial locus-1|developmentally-regulated endothelial cell locus 1 protein|integrin-binding protein DEL1', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=83940554, end_position_on_the_genomic_accession=84384880, orientation='minus', exon_count=11, OMIM=[606018], no_hdr0=''),
    10086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10086, CurrentID=0, Status='live', Symbol='HHLA1', Aliases=['PLA2L'], description='HERV-H LTR-associating 1', other_designations='HERV-H LTR-associating protein 1', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132061480, end_position_on_the_genomic_accession=132111157, orientation='minus', exon_count=17, OMIM=[604109], no_hdr0=''),
    10087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10087, CurrentID=0, Status='live', Symbol='CERT1', Aliases=['CERT', 'CERTL', 'COL4A3BP', 'GPBP', 'MRD34', 'STARD11'], description='ceramide transporter 1', other_designations='ceramide transfer protein|StAR-related lipid transfer (START) domain containing 11|collagen type IV alpha 3 binding protein|collagen, type IV, alpha 3 (Goodpasture antigen) binding protein|lipid-transfer protein CERTL', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75368486, end_position_on_the_genomic_accession=75511981, orientation='minus', exon_count=20, OMIM=[604677], no_hdr0=''),
    10089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10089, CurrentID=0, Status='live', Symbol='KCNK7', Aliases=['K2p7.1', 'TWIK3'], description='potassium two pore domain channel subfamily K member 7', other_designations='potassium channel subfamily K member 7|potassium channel, two pore domain subfamily K, member 7|two pore domain K+ channel', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65592836, end_position_on_the_genomic_accession=65595800, orientation='minus', exon_count=4, OMIM=[603940], no_hdr0=''),
    10090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10090, CurrentID=0, Status='live', Symbol='UST', Aliases=['2OST'], description='uronyl 2-sulfotransferase', other_designations='uronyl 2-sulfotransferase|dermatan/chondroitin sulfate 2-sulfotransferase', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=148745891, end_position_on_the_genomic_accession=149076990, orientation='plus', exon_count=13, OMIM=[610752], no_hdr0=''),
    10092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10092, CurrentID=0, Status='live', Symbol='ARPC5', Aliases=['ARC16', 'dJ127C7.3', 'p16-Arc'], description='actin related protein 2/3 complex subunit 5', other_designations='actin-related protein 2/3 complex subunit 5|Arp2/3 protein complex subunit p16|actin related protein 2/3 complex, subunit 5, 16kDa|arp2/3 complex 16 kDa subunit', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183620846, end_position_on_the_genomic_accession=183635783, orientation='minus', exon_count=4, OMIM=[604227], no_hdr0=''),
    10093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10093, CurrentID=0, Status='live', Symbol='ARPC4', Aliases=['ARC20', 'P20-ARC'], description='actin related protein 2/3 complex subunit 4', other_designations='actin-related protein 2/3 complex subunit 4|actin related protein 2/3 complex, subunit 4, 20kDa|arp2/3 complex 20 kDa subunit|arp2/3 protein complex subunit p20', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9792518, end_position_on_the_genomic_accession=9807101, orientation='plus', exon_count=7, OMIM=[604226], no_hdr0=''),
    10094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10094, CurrentID=0, Status='live', Symbol='ARPC3', Aliases=['ARC21', 'p21-Arc'], description='actin related protein 2/3 complex subunit 3', other_designations='actin-related protein 2/3 complex subunit 3|ARP2/3 protein complex subunit p21|actin related protein 2/3 complex, subunit 3, 21kDa|arp2/3 complex 21 kDa subunit', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110434823, end_position_on_the_genomic_accession=110450337, orientation='minus', exon_count=7, OMIM=[604225], no_hdr0=''),
    10095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10095, CurrentID=0, Status='live', Symbol='ARPC1B', Aliases=['ARC41', 'IMD71', 'PLTEID', 'p40-ARC', 'p41-ARC'], description='actin related protein 2/3 complex subunit 1B', other_designations='actin-related protein 2/3 complex subunit 1B|ARP2/3 protein complex subunit p41|actin related protein 2/3 complex, subunit 1B, 41kDa|arp2/3 complex 41 kDa subunit', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99374254, end_position_on_the_genomic_accession=99394816, orientation='plus', exon_count=14, OMIM=[604223], no_hdr0=''),
    10096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10096, CurrentID=0, Status='live', Symbol='ACTR3', Aliases=['ARP3'], description='actin related protein 3', other_designations='actin-related protein 3|ARP3 actin related protein 3 homolog|actin-like protein 3', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113889934, end_position_on_the_genomic_accession=113962596, orientation='plus', exon_count=13, OMIM=[604222], no_hdr0=''),
    10097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10097, CurrentID=0, Status='live', Symbol='ACTR2', Aliases=['ARP2'], description='actin related protein 2', other_designations='actin-related protein 2|ARP2 actin related protein 2 homolog|actin-like protein 2', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=65227831, end_position_on_the_genomic_accession=65271253, orientation='plus', exon_count=10, OMIM=[604221], no_hdr0=''),
    10098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10098, CurrentID=0, Status='live', Symbol='TSPAN5', Aliases=['NET-4', 'NET4', 'TM4SF9', 'TSPAN-5'], description='tetraspanin 5', other_designations='tetraspanin-5|tetraspan NET-4|tetraspan TM4SF|transmembrane 4 superfamily member 9|transmembrane 4 superfamily, member 8', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=98470367, end_position_on_the_genomic_accession=98658661, orientation='minus', exon_count=8, OMIM=[613136], no_hdr0=''),
    10099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10099, CurrentID=0, Status='live', Symbol='TSPAN3', Aliases=['TM4-A', 'TM4SF8', 'TSPAN-3'], description='tetraspanin 3', other_designations='tetraspanin-3|tetraspan 3|tetraspan TM4SF|tetraspanin TM4-A|transmembrane 4 superfamily member 8', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=77041404, end_position_on_the_genomic_accession=77071109, orientation='minus', exon_count=7, OMIM=[613134], no_hdr0=''),
    10100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10100, CurrentID=0, Status='live', Symbol='TSPAN2', Aliases=['NET3', 'TSN2', 'TSPAN-2'], description='tetraspanin 2', other_designations='tetraspanin-2|new EST tetraspan 3|tetraspan 2|tetraspan NET-3|tetraspan TM4SF', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115048011, end_position_on_the_genomic_accession=115089503, orientation='minus', exon_count=8, OMIM=[613133], no_hdr0=''),
    10101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10101, CurrentID=0, Status='live', Symbol='NUBP2', Aliases=['CFD1', 'CIAO6', 'NBP 2', 'NUBP1'], description='nucleotide binding protein 2', other_designations='cytosolic Fe-S cluster assembly factor NUBP2|homolog of yeast cytosolic Fe-S cluster deficient 1|nucleotide binding protein 2 (MinD homolog, E. coli)', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1782960, end_position_on_the_genomic_accession=1789186, orientation='plus', exon_count=10, OMIM=[610779], no_hdr0=''),
    10102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10102, CurrentID=0, Status='live', Symbol='TSFM', Aliases=['EFTS', 'EFTSMT'], description='Ts translation elongation factor, mitochondrial', other_designations='elongation factor Ts, mitochondrial|mitochondrial elongation factor Ts', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57782787, end_position_on_the_genomic_accession=57802856, orientation='plus', exon_count=8, OMIM=[604723], no_hdr0=''),
    10103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10103, CurrentID=0, Status='live', Symbol='TSPAN1', Aliases=['NET1', 'TM4C', 'TM4SF'], description='tetraspanin 1', other_designations='tetraspanin-1|tetraspan 1', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46175087, end_position_on_the_genomic_accession=46196489, orientation='plus', exon_count=10, OMIM=[613170], no_hdr0=''),
    10105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10105, CurrentID=0, Status='live', Symbol='PPIF', Aliases=['CYP3', 'CyP-M', 'Cyp-D', 'CypD'], description='peptidylprolyl isomerase F', other_designations='peptidyl-prolyl cis-trans isomerase F, mitochondrial|PPIase F|cyclophilin 3|cyclophilin D|cyclophilin F|mitochondrial cyclophilin|peptidyl-prolyl cis-trans isomerase, mitochondrial|rotamase F', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79347469, end_position_on_the_genomic_accession=79355334, orientation='plus', exon_count=6, OMIM=[604486], no_hdr0=''),
    10106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10106, CurrentID=0, Status='live', Symbol='CTDSP2', Aliases=['OS4', 'PSR2', 'SCP2'], description='CTD small phosphatase 2', other_designations='carboxy-terminal domain RNA polymerase II polypeptide A small phosphatase 2|CTD (carboxy-terminal domain, RNA polymerase II, polypeptide A) small phosphatase 2|NLI-interacting factor 2|conserved gene amplified in osteosarcoma|nuclear LIM interactor-interacting factor 2|protein OS-4|small C-terminal domain phosphatase 2|small CTD phosphatase 2', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57816702, end_position_on_the_genomic_accession=57846729, orientation='minus', exon_count=8, OMIM=[608711], no_hdr0=''),
    10107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10107, CurrentID=0, Status='live', Symbol='TRIM10', Aliases=['HERF1', 'RFB30', 'RNF9'], description='tripartite motif containing 10', other_designations='tripartite motif-containing protein 10|B30-RING finger protein|Zn-finger protein|hematopoietic RING finger 1|ring finger protein 9|tripartite motif protein 10', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30151939, end_position_on_the_genomic_accession=30163216, orientation='minus', exon_count=10, OMIM=[605701], no_hdr0=''),
    10109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10109, CurrentID=0, Status='live', Symbol='ARPC2', Aliases=['ARC34', 'PNAS-139', 'PRO2446', 'p34-Arc'], description='actin related protein 2/3 complex subunit 2', other_designations='actin-related protein 2/3 complex subunit 2|ARP2/3 protein complex subunit 34|actin related protein 2/3 complex, subunit 2, 34kDa|arp2/3 complex 34 kDa subunit|testis tissue sperm-binding protein Li 53e', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218217138, end_position_on_the_genomic_accession=218254348, orientation='plus', exon_count=11, OMIM=[604224], no_hdr0=''),
    10110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10110, CurrentID=0, Status='live', Symbol='SGK2', Aliases=['H-SGK2', 'dJ138B7.2'], description='serum/glucocorticoid regulated kinase 2', other_designations='serine/threonine-protein kinase Sgk2|SGK2, serine/threonine kinase 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43559027, end_position_on_the_genomic_accession=43585627, orientation='plus', exon_count=14, OMIM=[607589], no_hdr0=''),
    10111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10111, CurrentID=0, Status='live', Symbol='RAD50', Aliases=['NBSLD2', 'hRad50', 'RAD50'], description='RAD50 double strand break repair protein', other_designations='DNA repair protein RAD50|RAD50 homolog, double strand break repair protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132556977, end_position_on_the_genomic_accession=132646349, orientation='plus', exon_count=25, OMIM=[604040], no_hdr0=''),
    10112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10112, CurrentID=0, Status='live', Symbol='KIF20A', Aliases=['MKLP2', 'RAB6KIFL'], description='kinesin family member 20A', other_designations='kinesin-like protein KIF20A|GG10_2|RAB6 interacting, kinesin-like (rabkinesin6)|mitotic kinesin-like protein 2|rab6-interacting kinesin-like protein|rabkinesin-6', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138179112, end_position_on_the_genomic_accession=138187723, orientation='plus', exon_count=19, OMIM=[605664], no_hdr0=''),
    10113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10113, CurrentID=0, Status='live', Symbol='PREB', Aliases=['SEC12'], description='prolactin regulatory element binding', other_designations='prolactin regulatory element-binding protein|mammalian guanine nucleotide exchange factor mSec12', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27130756, end_position_on_the_genomic_accession=27134642, orientation='minus', exon_count=9, OMIM=[606395], no_hdr0=''),
    10114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10114, CurrentID=0, Status='live', Symbol='HIPK3', Aliases=['DYRK6', 'FIST3', 'PKY', 'YAK1'], description='homeodomain interacting protein kinase 3', other_designations='homeodomain-interacting protein kinase 3|ANPK|FIST|androgen receptor-interacting nuclear protein kinase|fas-interacting serine/threonine-protein kinase|homolog of protein kinase YAK1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33256672, end_position_on_the_genomic_accession=33357023, orientation='plus', exon_count=19, OMIM=[604424], no_hdr0=''),
    10116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10116, CurrentID=0, Status='live', Symbol='FEM1B', Aliases=['F1A-ALPHA', 'F1AA', 'FEM1-beta'], description='fem-1 homolog B', other_designations='protein fem-1 homolog B|FEM-1-like death receptor binding protein|fem-1-like death receptor-binding protein alpha|fem-1-like in apoptotic pathway protein alpha', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68277745, end_position_on_the_genomic_accession=68295862, orientation='plus', exon_count=2, OMIM=[613539], no_hdr0=''),
    10117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10117, CurrentID=0, Status='live', Symbol='ENAM', Aliases=['ADAI', 'AI1C', 'AIH2'], description='enamelin', other_designations='enamelin|amelogenesis imperfecta 2, hypocalcification (autosomal dominant)', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70627471, end_position_on_the_genomic_accession=70646824, orientation='plus', exon_count=8, OMIM=[606585], no_hdr0=''),
    10120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10120, CurrentID=0, Status='live', Symbol='ACTR1B', Aliases=['ARP1B', 'CTRN2', 'PC3'], description='actin related protein 1B', other_designations='beta-centractin|ARP1 actin related protein 1 homolog B|ARP1 actin-related protein 1 homolog B, centractin beta|centractin beta', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97655939, end_position_on_the_genomic_accession=97664044, orientation='minus', exon_count=12, OMIM=[605144], no_hdr0=''),
    10121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10121, CurrentID=0, Status='live', Symbol='ACTR1A', Aliases=['ARP1', 'Arp1A', 'CTRN1'], description='actin related protein 1A', other_designations='alpha-centractin|ARP1 actin related protein 1 homolog A|ARP1 actin-related protein 1 homolog A, centractin alpha|actin-RPV|centractin|centrosome-associated actin homolog|epididymis secretory sperm binding protein', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102479229, end_position_on_the_genomic_accession=102502712, orientation='minus', exon_count=11, OMIM=[605143], no_hdr0=''),
    10123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10123, CurrentID=0, Status='live', Symbol='ARL4C', Aliases=['ARL7', 'LAK'], description='ADP ribosylation factor like GTPase 4C', other_designations='ADP-ribosylation factor-like protein 4C|ADP ribosylation factor-like protein 7|ADP-ribosylation factor-like 4C|ADP-ribosylation factor-like 7|ADP-ribosylation factor-like protein LAK', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=234493041, end_position_on_the_genomic_accession=234497081, orientation='minus', exon_count=1, OMIM=[604787], no_hdr0=''),
    10124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10124, CurrentID=0, Status='live', Symbol='ARL4A', Aliases=['ARL4'], description='ADP ribosylation factor like GTPase 4A', other_designations='ADP-ribosylation factor-like protein 4A|ADP-ribosylation factor-like 4|ADP-ribosylation factor-like 4A', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=12686903, end_position_on_the_genomic_accession=12690958, orientation='plus', exon_count=3, OMIM=[604786], no_hdr0=''),
    10125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10125, CurrentID=0, Status='live', Symbol='RASGRP1', Aliases=['CALDAG-GEFI', 'CALDAG-GEFII', 'IMD64', 'RASGRP'], description='RAS guanyl releasing protein 1', other_designations='RAS guanyl-releasing protein 1|RAS guanyl nucleotide-releasing protein 1|RAS guanyl releasing protein 1 (calcium and DAG-regulated)|calcium and DAG-regulated guanine nucleotide exchange factor II|calcium- and diacylglycerol-regulated guanine nucleotide exchange factor II|guanine nucleotide exchange factor, calcium- and DAG-regulated, Rap1A|ras activator RasGRP', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=38488097, end_position_on_the_genomic_accession=38564814, orientation='minus', exon_count=17, OMIM=[603962], no_hdr0=''),
    10126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10126, CurrentID=0, Status='live', Symbol='DNAL4', Aliases=['MRMV3', 'PIG27'], description='dynein axonemal light chain 4', other_designations='dynein axonemal light chain 4|dynein light chain, outer arm 4|dynein, axonemal, light polypeptide 4|proliferation-inducing gene 27|proliferation-inducing protein 27', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38778508, end_position_on_the_genomic_accession=38794143, orientation='minus', exon_count=4, OMIM=[610565], no_hdr0=''),
    10127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10127, CurrentID=0, Status='live', Symbol='ZNF263', Aliases=['FPM315', 'ZKSCAN12', 'ZSCAN44'], description='zinc finger protein 263', other_designations='zinc finger protein 263|zinc finger protein FPM315|zinc finger protein with KRAB and SCAN domains 12', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3283183, end_position_on_the_genomic_accession=3301649, orientation='plus', exon_count=8, OMIM=[604191], no_hdr0=''),
    10128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10128, CurrentID=0, Status='live', Symbol='LRPPRC', Aliases=['CLONE-23970', 'GP130', 'LRP130', 'LSFC', 'MC4DN5'], description='leucine rich pentatricopeptide repeat containing', other_designations='leucine-rich PPR motif-containing protein, mitochondrial|130 kDa leucine-rich protein|LRP 130|leucine-rich PPR-motif containing|mitochondrial leucine-rich PPR motif-containing protein', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43886224, end_position_on_the_genomic_accession=43995989, orientation='minus', exon_count=39, OMIM=[607544], no_hdr0=''),
    10129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10129, CurrentID=0, Status='live', Symbol='FRY', Aliases=['13CDNA73', '214K23.2', 'C13orf14', 'CG003', 'bA207N4.2', 'bA37E23.1'], description='FRY microtubule binding protein', other_designations='protein furry homolog|WUGSC:H_2G3A.1|furry homolog', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32031774, end_position_on_the_genomic_accession=32299125, orientation='plus', exon_count=66, OMIM=[614818], no_hdr0=''),
    10130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10130, CurrentID=0, Status='live', Symbol='PDIA6', Aliases=['ERP5', 'P5', 'TXNDC7'], description='protein disulfide isomerase family A member 6', other_designations='protein disulfide-isomerase A6|ER protein 5|endoplasmic reticulum protein 5|epididymis secretory sperm binding protein|protein disulfide isomerase P5|protein disulfide isomerase-associated 6|protein disulfide isomerase-related protein|thioredoxin domain containing 7 (protein disulfide isomerase)|thioredoxin domain-containing protein 7', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10783391, end_position_on_the_genomic_accession=10837712, orientation='minus', exon_count=18, OMIM=[611099], no_hdr0=''),
    10131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10131, CurrentID=0, Status='live', Symbol='TRAP1', Aliases=['HSP 75', 'HSP75', 'HSP90L', 'TRAP-1'], description='TNF receptor associated protein 1', other_designations='heat shock protein 75 kDa, mitochondrial|TNFR-associated protein 1|testicular tissue protein Li 209|tumor necrosis factor type 1 receptor-associated protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3658037, end_position_on_the_genomic_accession=3717524, orientation='minus', exon_count=19, OMIM=[606219], no_hdr0=''),
    10133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10133, CurrentID=0, Status='live', Symbol='OPTN', Aliases=['ALS12', 'FIP2', 'GLC1E', 'HIP7', 'HYPL', 'NRP', 'TFIIIA-INTP'], description='optineurin', other_designations='optineurin|E3-14.7K-interacting protein|FIP-2|HIP-7|Huntingtin interacting protein L|huntingtin yeast partner L|huntingtin-interacting protein 7|huntingtin-interacting protein L|nemo-related protein|optic neuropathy-inducing protein|transcription factor IIIA-interacting protein|transcrption factor IIIA-interacting protein|tumor necrosis factor alpha-inducible cellular protein containing leucine zipper domains', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13100082, end_position_on_the_genomic_accession=13138308, orientation='plus', exon_count=16, OMIM=[602432], no_hdr0=''),
    10134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10134, CurrentID=0, Status='live', Symbol='BCAP31', Aliases=['6C6-AG', 'BAP31', 'CDM', 'DDCH', 'DXS1357E'], description='B cell receptor associated protein 31', other_designations='B-cell receptor-associated protein 31|6C6-AG tumor-associated antigen|BCR-associated protein Bap31|p28 Bap31', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153700492, end_position_on_the_genomic_accession=153724746, orientation='minus', exon_count=8, OMIM=[300398], no_hdr0=''),
    10135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10135, CurrentID=0, Status='live', Symbol='NAMPT', Aliases=['1110035O14Rik', 'PBEF', 'PBEF1', 'VF', 'VISFATIN'], description='nicotinamide phosphoribosyltransferase', other_designations='nicotinamide phosphoribosyltransferase|NAmPRTase|pre-B cell-enhancing factor|pre-B-cell colony-enhancing factor 1', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=106248298, end_position_on_the_genomic_accession=106284983, orientation='minus', exon_count=11, OMIM=[608764], no_hdr0=''),
    10136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10136, CurrentID=0, Status='live', Symbol='CELA3A', Aliases=['ELA3', 'ELA3A'], description='chymotrypsin like elastase 3A', other_designations='chymotrypsin-like elastase family member 3A|chymotrypsin like elastase family member 3A|elastase 1|elastase 3A, pancreatic|elastase IIIA|elastase-3A|protease E', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22001657, end_position_on_the_genomic_accession=22012542, orientation='plus', exon_count=8, OMIM=[618693], no_hdr0=''),
    10137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10137, CurrentID=0, Status='live', Symbol='RBM12', Aliases=['HRIHFB2091', 'SCZD19', 'SWAN'], description='RNA binding motif protein 12', other_designations='RNA-binding protein 12|SH3/WW domain anchor protein in the nucleus', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35648925, end_position_on_the_genomic_accession=35664900, orientation='minus', exon_count=3, OMIM=[607179], no_hdr0=''),
    10138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10138, CurrentID=0, Status='live', Symbol='YAF2', Aliases=[], description='YY1 associated factor 2', other_designations='YY1-associated factor 2', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=42157104, end_position_on_the_genomic_accession=42238373, orientation='minus', exon_count=11, OMIM=[607534], no_hdr0=''),
    10139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10139, CurrentID=0, Status='live', Symbol='ARFRP1', Aliases=['ARL18', 'ARP', 'Arp1'], description='ADP ribosylation factor related protein 1', other_designations='ADP-ribosylation factor-related protein 1|ARF-related protein 1|SCG10 like-protein|epididymis secretory sperm binding protein|helicase-like protein NHL', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63698647, end_position_on_the_genomic_accession=63707976, orientation='minus', exon_count=10, OMIM=[604699], no_hdr0=''),
    10140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10140, CurrentID=0, Status='live', Symbol='TOB1', Aliases=['APRO5', 'APRO6', 'PIG49', 'TOB', 'TROB', 'TROB1'], description='transducer of ERBB2, 1', other_designations='protein Tob1|proliferation-inducing gene 49|transducer of erbB-2 1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50862223, end_position_on_the_genomic_accession=50867978, orientation='minus', exon_count=4, OMIM=[605523], no_hdr0=''),
    10142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10142, CurrentID=0, Status='live', Symbol='AKAP9', Aliases=['AKAP-9', 'AKAP350', 'AKAP450', 'CG-NAP', 'HYPERION', 'LQT11', 'MU-RMS-40.16A', 'PPP1R45', 'PRKA9', 'YOTIAO'], description='A-kinase anchoring protein 9', other_designations='A-kinase anchor protein 9|A kinase (PRKA) anchor protein (yotiao) 9|A kinase (PRKA) anchor protein 9|A-kinase anchor protein 350 kDa|A-kinase anchor protein 450 kDa|AKAP 120-like protein|AKAP9-BRAF fusion protein|centrosome- and Golgi-localized PKN-associated protein|centrosome- and golgi-localized protein kinase N-associated protein|kinase N-associated protein|protein hyperion|protein kinase A anchoring protein 9|protein phosphatase 1, regulatory subunit 45|protein yotiao', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=91940862, end_position_on_the_genomic_accession=92110673, orientation='plus', exon_count=51, OMIM=[604001], no_hdr0=''),
    10143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10143, CurrentID=0, Status='live', Symbol='CLEC3A', Aliases=['CLECSF1'], description='C-type lectin domain family 3 member A', other_designations='C-type lectin domain family 3 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 1 (cartilage-derived)', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=78022548, end_position_on_the_genomic_accession=78032101, orientation='plus', exon_count=3, OMIM=[613588], no_hdr0=''),
    10144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10144, CurrentID=0, Status='live', Symbol='FAM13A', Aliases=['ARHGAP481', 'FAM13A'], description='family with sequence similarity 13 member A', other_designations='protein FAM13A|FAM13A1_v2 protein|family with sequence similarity 13, member A1', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88725960, end_position_on_the_genomic_accession=89111398, orientation='minus', exon_count=32, OMIM=[613299], no_hdr0=''),
    10146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10146, CurrentID=0, Status='live', Symbol='G3BP1', Aliases=['G3BP', 'HDH-VIII'], description='G3BP stress granule assembly factor 1', other_designations='ras GTPase-activating protein-binding protein 1|ATP-dependent DNA helicase VIII|DNA helicase VIII|G3BP-1|GAP SH3 domain-binding protein 1|GAP binding protein|GTPase activating protein (SH3 domain) binding protein 1|Ras-GTPase-activating protein SH3-domain-binding protein|RasGAP-associated endoribonuclease G3BP', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151771954, end_position_on_the_genomic_accession=151812785, orientation='plus', exon_count=12, OMIM=[608431], no_hdr0=''),
    10147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10147, CurrentID=0, Status='live', Symbol='SUGP2', Aliases=['SFRS14', 'SRFS14'], description='SURP and G-patch domain containing 2', other_designations='SURP and G-patch domain-containing protein 2|arginine/serine-rich-splicing factor 14|splicing factor, arginine/serine-rich 14', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18990887, end_position_on_the_genomic_accession=19034038, orientation='minus', exon_count=14, OMIM=[607993], no_hdr0=''),
    10148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10148, CurrentID=0, Status='live', Symbol='EBI3', Aliases=['IL-27B', 'IL27B', 'IL35B'], description='Epstein-Barr virus induced 3', other_designations='interleukin-27 subunit beta|EBV-induced gene 3 protein|Epstein-Barr virus induced gene 3|IL-27 subunit beta|IL27 subunit|IL35 subunit|cytokine receptor|epstein-Barr virus-induced gene 3 protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4229196, end_position_on_the_genomic_accession=4237539, orientation='plus', exon_count=6, OMIM=[605816], no_hdr0=''),
    10149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10149, CurrentID=0, Status='live', Symbol='ADGRG2', Aliases=['CBAVDX', 'EDDM6', 'GPR64', 'HE6', 'TM7LN2'], description='adhesion G protein-coupled receptor G2', other_designations='adhesion G-protein coupled receptor G2|G protein-coupled receptor 64|G protein-coupled receptor, epididymis-specific (seven transmembrane family)|epididymal protein 6|human epididymis-specific protein 6', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18989307, end_position_on_the_genomic_accession=19122956, orientation='minus', exon_count=32, OMIM=[300572], no_hdr0=''),
    10150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10150, CurrentID=0, Status='live', Symbol='MBNL2', Aliases=['MBLL', 'MBLL39', 'PRO2032'], description='muscleblind like splicing regulator 2', other_designations='muscleblind-like protein 2|muscleblind-like 2|muscleblind-like protein 1|muscleblind-like protein-like 39', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=97141834, end_position_on_the_genomic_accession=97394120, orientation='plus', exon_count=16, OMIM=[607327], no_hdr0=''),
    10152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10152, CurrentID=0, Status='live', Symbol='ABI2', Aliases=['ABI-2B', 'AIP-1', 'AIP1', 'AblBP3', 'SSH3BP2', 'argBP1', 'argBPIA', 'argBPIB', 'ABI2'], description='abl interactor 2', other_designations='abl interactor 2|abelson interactor 2|abl binding protein 3|abl-interacting protein 1 (SH3-containing protein)|abl-interactor protein 2b|arg protein tyrosine kinase-binding protein|arg-binding protein 1', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203325013, end_position_on_the_genomic_accession=203432169, orientation='plus', exon_count=20, OMIM=[606442], no_hdr0=''),
    10153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10153, CurrentID=0, Status='live', Symbol='CEBPZ', Aliases=['CBF', 'CBF2', 'HSP-CBF', 'NOC1'], description='CCAAT enhancer binding protein zeta', other_designations='CCAAT/enhancer-binding protein zeta|CCAAT-box-binding transcription factor|CCAAT/enhancer binding protein (C/EBP), zeta|CCAAT/enhancer binding protein cebp family zeta', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37201612, end_position_on_the_genomic_accession=37231596, orientation='minus', exon_count=16, OMIM=[612828], no_hdr0=''),
    10154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10154, CurrentID=0, Status='live', Symbol='PLXNC1', Aliases=['CD232', 'PLXN-C1', 'VESPR'], description='plexin C1', other_designations='plexin-C1|plexin (semaphorin receptor)|receptor for viral semaphorin protein|receptor for virally-encoded semaphorin|virus-encoded semaphorin protein receptor', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=94148577, end_position_on_the_genomic_accession=94307675, orientation='plus', exon_count=35, OMIM=[604259], no_hdr0=''),
    10155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10155, CurrentID=0, Status='live', Symbol='TRIM28', Aliases=['KAP1', 'PPP1R157', 'RNF96', 'TF1B', 'TIF1B'], description='tripartite motif containing 28', other_designations='transcription intermediary factor 1-beta|E3 SUMO-protein ligase TRIM28|KAP-1|KRAB [Kruppel-associated box domain]-associated protein 1|KRAB-interacting protein 1|KRIP-1|RING finger protein 96|RING-type E3 ubiquitin transferase TIF1-beta|TIF1-beta|nuclear corepressor KAP-1|protein phosphatase 1, regulatory subunit 157|transcriptional intermediary factor 1-beta', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58544064, end_position_on_the_genomic_accession=58550722, orientation='plus', exon_count=17, OMIM=[601742], no_hdr0=''),
    10156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10156, CurrentID=0, Status='live', Symbol='RASA4', Aliases=['CAPRI', 'GAPL'], description='RAS p21 protein activator 4', other_designations='ras GTPase-activating protein 4|Ca2+-promoted Ras inactivator|calcium-promoted Ras inactivator|rasGAP-activating-like protein 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102579646, end_position_on_the_genomic_accession=102616758, orientation='minus', exon_count=23, OMIM=[607943], no_hdr0=''),
    10157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10157, CurrentID=0, Status='live', Symbol='AASS', Aliases=['LKR/SDH', 'LKRSDH', 'LORSDH'], description='aminoadipate-semialdehyde synthase', other_designations='alpha-aminoadipic semialdehyde synthase, mitochondrial|alpha-aminoadipate semialdehyde synthase|aminoadipic semialdehyde synthase|lysine-2-oxoglutarate reductase|lysine-ketoglutarate reductase /saccharopine dehydrogenase', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122073544, end_position_on_the_genomic_accession=122144269, orientation='minus', exon_count=25, OMIM=[605113], no_hdr0=''),
    10158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10158, CurrentID=0, Status='live', Symbol='PDZK1IP1', Aliases=['DD96', 'MAP17', 'SPAP'], description='PDZK1 interacting protein 1', other_designations='PDZK1-interacting protein 1|17 kDa membrane-associated protein|epithelial protein up-regulated in carcinoma, membrane associated protein 17|membrane-associated protein 17', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47183582, end_position_on_the_genomic_accession=47190036, orientation='minus', exon_count=4, OMIM=[607178], no_hdr0=''),
    10159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10159, CurrentID=0, Status='live', Symbol='ATP6AP2', Aliases=['APT6M8-9', 'ATP6IP2', 'ATP6M8-9', 'CDG2R', 'ELDF10', 'HT028', 'M8-9', 'MRXE', 'MRXSH', 'MSTP009', 'PRR', 'RENR', 'XMRE', 'XPDS'], description='ATPase H+ transporting accessory protein 2', other_designations='renin receptor|ATPase H(+)-transporting lysosomal-interacting protein 2|ATPase, H+ transporting, lysosomal (vacuolar proton pump) membrane sector associated protein M8-9|ATPase, H+ transporting, lysosomal accessory protein 2|ATPase, H+ transporting, lysosomal interacting protein 2|ER-localized type I transmembrane adapter|ER-localized type I transmembrane adaptor|N14F|V-ATPase M8.9 subunit|embryonic liver differentiation factor 10|prorenin receptor|renin/prorenin receptor|vacuolar ATP synthase membrane sector-associated protein M8-9|vacuolar proton ATP synthase membrane sector associated protein M8-9', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=40580970, end_position_on_the_genomic_accession=40606848, orientation='plus', exon_count=9, OMIM=[300556], no_hdr0=''),
    10160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10160, CurrentID=0, Status='live', Symbol='FARP1', Aliases=['CDEP-IT1', 'PLEKHC2', 'PPP1R75', 'FARP1'], description='FERM, ARH/RhoGEF and pleckstrin domain protein 1', other_designations='FERM, ARHGEF and pleckstrin domain-containing protein 1|FERM, RhoGEF (ARHGEF) and pleckstrin domain protein 1 (chondrocyte-derived)|FERM, RhoGEF and pleckstrin domain-containing protein 1|PH domain-containing family C member 2|chondrocyte-derived ezrin-like protein|pleckstrin homology domain-containing family C member 2|protein phosphatase 1, regulatory subunit 75', map_location='13q32.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=98142589, end_position_on_the_genomic_accession=98455176, orientation='plus', exon_count=31, OMIM=[602654], no_hdr0=''),
    10161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10161, CurrentID=0, Status='live', Symbol='LPAR6', Aliases=['ARWH1', 'HYPT8', 'LAH3', 'LPA-6', 'P2RY5', 'P2Y5'], description='lysophosphatidic acid receptor 6', other_designations='lysophosphatidic acid receptor 6|G-protein coupled purinergic receptor P2Y5|LPA receptor 6|P2Y purinoceptor 5|RB intron encoded G-protein coupled receptor|oleoyl-L-alpha-lysophosphatidic acid receptor|purinergic receptor 5|purinergic receptor P2Y G protein-coupled protein 5|purinergic receptor P2Y, G-protein coupled, 5', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48400897, end_position_on_the_genomic_accession=48444669, orientation='minus', exon_count=10, OMIM=[609239], no_hdr0=''),
    10162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10162, CurrentID=0, Status='live', Symbol='LPCAT3', Aliases=['C3F', 'LPCAT', 'LPLAT 5', 'LPSAT', 'MBOAT5', 'OACT5', 'nessy'], description='lysophosphatidylcholine acyltransferase 3', other_designations='lysophospholipid acyltransferase 5|1-acylglycerophosphocholine O-acyltransferase|1-acylglycerophosphoethanolamine O-acyltransferase|1-acylglycerophosphoserine O-acyltransferase|O-acyltransferase (membrane bound) domain containing 5|O-acyltransferase domain-containing protein 5|lyso-PC acyltransferase 3|lyso-PS acyltransferase|lysophosphatidylserine acyltransferase|membrane bound O-acyltransferase domain containing 5|membrane-bound O-acyltransferase domain-containing protein 5|putative protein similar to nessy', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6976185, end_position_on_the_genomic_accession=7018508, orientation='minus', exon_count=13, OMIM=[611950], no_hdr0=''),
    10163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10163, CurrentID=0, Status='live', Symbol='WASF2', Aliases=['IMD2', 'SCAR2', 'WASF4', 'WAVE2', 'dJ393P12.2'], description='WASP family member 2', other_designations='wiskott-Aldrich syndrome protein family member 2|WAS protein family member 2|WASP family Verprolin-homologous protein 2|WASP family protein member 2|WASP family protein member 4|protein WAVE-2|putative Wiskott-Aldrich syndrome protein family member 4|suppressor of cyclic-AMP receptor (WASP-family)|verprolin homology domain-containing protein 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27404230, end_position_on_the_genomic_accession=27490167, orientation='minus', exon_count=9, OMIM=[605875], no_hdr0=''),
    10164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10164, CurrentID=0, Status='live', Symbol='CHST4', Aliases=['GST3', 'GlcNAc6ST2', 'HECGLCNAC6ST', 'LSST'], description='carbohydrate sulfotransferase 4', other_designations='carbohydrate sulfotransferase 4|GST-3|HEC-GlcNAc6ST|L-selectin ligand sulfotransferase|N-acetylglucosamine 6-O-sulfotransferase 2|carbohydrate (N-acetylglucosamine 6-O) sulfotransferase 4|galactose/N-acetylglucosamine/N-acetylgalactosamine 6-O-sulfotransferase 3|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 3|glcNAc6ST-2|gn6st-2|high endothelial cells N-acetylglucosamine 6-O-sulfotransferase', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71526120, end_position_on_the_genomic_accession=71538748, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    10165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10165, CurrentID=0, Status='live', Symbol='SLC25A13', Aliases=['ARALAR2', 'CITRIN', 'CTLN2', 'NICCD'], description='solute carrier family 25 member 13', other_designations='calcium-binding mitochondrial carrier protein Aralar2|mitochondrial aspartate glutamate carrier 2|solute carrier family 25 (aspartate/glutamate carrier), member 13', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=96120220, end_position_on_the_genomic_accession=96322127, orientation='minus', exon_count=21, OMIM=[603859], no_hdr0=''),
    10166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10166, CurrentID=0, Status='live', Symbol='SLC25A15', Aliases=['D13S327', 'HHH', 'LNC-HC', 'ORC1', 'ORNT1'], description='solute carrier family 25 member 15', other_designations='mitochondrial ornithine transporter 1|ornithine carrier 1|ornithine transporter 1|solute carrier family 25 (mitochondrial carrier; ornithine transporter) member 15', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=40789611, end_position_on_the_genomic_accession=40812460, orientation='plus', exon_count=7, OMIM=[603861], no_hdr0=''),
    10168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10168, CurrentID=0, Status='live', Symbol='ZNF197', Aliases=['D3S1363E', 'P18', 'VHLaK', 'ZKSCAN9', 'ZNF166', 'ZNF20', 'ZSCAN41'], description='zinc finger protein 197', other_designations='zinc finger protein 197|VHL-associated KRAB-A domain-containing protein|pVHL-associated KRAB domain-containing protein|zinc finger protein 166|zinc finger protein 20|zinc finger protein with KRAB and SCAN domains 9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44625036, end_position_on_the_genomic_accession=44648471, orientation='plus', exon_count=7, OMIM=[618359], no_hdr0=''),
    10169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10169, CurrentID=0, Status='live', Symbol='SERF2', Aliases=['4F5REL', 'FAM2C', 'H4F5REL', 'HsT17089'], description='small EDRK-rich factor 2', other_designations='small EDRK-rich factor 2|gastric cancer-related protein VRG107|protein 4F5-related', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43777086, end_position_on_the_genomic_accession=43796089, orientation='plus', exon_count=6, OMIM=[605054], no_hdr0=''),
    10170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10170, CurrentID=0, Status='live', Symbol='DHRS9', Aliases=['3-alpha-HSD', '3ALPHA-HSD', 'RDH-E2', 'RDH-TBE', 'RDH15', 'RDHL', 'RDHTBE', 'RETSDR8', 'SDR9C4'], description='dehydrogenase/reductase 9', other_designations='dehydrogenase/reductase SDR family member 9|3-alpha hydroxysteroid dehydrogenase|NADP-dependent retinol dehydrogenase/reductase|dehydrogenase/reductase (SDR family) member 9|retinol dehydrogenase 15|retinol dehydrogenase homolog|short chain dehydrogenase/reductase family 9C member 4|short-chain dehydrogenase/reductase retSDR8|tracheobronchial epithelial cell-specific retinol dehydrogenase', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169067077, end_position_on_the_genomic_accession=169096167, orientation='plus', exon_count=9, OMIM=[612131], no_hdr0=''),
    10171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10171, CurrentID=0, Status='live', Symbol='RCL1', Aliases=['RNAC', 'RPCL1'], description='RNA terminal phosphate cyclase like 1', other_designations="RNA 3'-terminal phosphate cyclase-like protein|RNA cyclase homolog", map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4792944, end_position_on_the_genomic_accession=4861066, orientation='plus', exon_count=10, OMIM=[611405], no_hdr0=''),
    10172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10172, CurrentID=0, Status='live', Symbol='ZNF256', Aliases=['BMZF-3', 'BMZF3'], description='zinc finger protein 256', other_designations='zinc finger protein 256|bone marrow zinc finger 3', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57940833, end_position_on_the_genomic_accession=57947706, orientation='minus', exon_count=3, OMIM=[606956], no_hdr0=''),
    10174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10174, CurrentID=0, Status='live', Symbol='SORBS3', Aliases=['SCAM-1', 'SCAM1', 'SH3D4'], description='sorbin and SH3 domain containing 3', other_designations='vinexin|sorbin and SH3 domain-containing protein 3|vinexin beta (SH3-containing adaptor molecule-1)', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22544990, end_position_on_the_genomic_accession=22575788, orientation='plus', exon_count=25, OMIM=[610795], no_hdr0=''),
    10175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10175, CurrentID=0, Status='live', Symbol='CNIH1', Aliases=['CNIH', 'CNIH-1', 'CNIL', 'TGAM77'], description='cornichon family AMPA receptor auxiliary protein 1', other_designations='protein cornichon homolog 1|T-cell growth-associated molecule 77|cornichon homolog', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54423561, end_position_on_the_genomic_accession=54441374, orientation='minus', exon_count=5, OMIM=[611287], no_hdr0=''),
    10178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10178, CurrentID=0, Status='live', Symbol='TENM1', Aliases=['ODZ1', 'ODZ3', 'TEN-M1', 'TEN1', 'TNM', 'TNM1', 'ten-1'], description='teneurin transmembrane protein 1', other_designations='teneurin-1|odz (odd Oz/ten-m, Drosophila) homolog 3|odz, odd Oz/ten-m homolog 1(Drosophila)|protein Odd Oz/ten-m homolog 1|tenascin M1', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=124375903, end_position_on_the_genomic_accession=125204381, orientation='minus', exon_count=41, OMIM=[300588], no_hdr0=''),
    10179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10179, CurrentID=0, Status='live', Symbol='RBM7', Aliases=[], description='RNA binding motif protein 7', other_designations='RNA-binding protein 7', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114400666, end_position_on_the_genomic_accession=114410607, orientation='plus', exon_count=5, OMIM=[612413], no_hdr0=''),
    10180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10180, CurrentID=0, Status='live', Symbol='RBM6', Aliases=['3G2', 'DEF-3', 'DEF3', 'HLC-11', 'NY-LU-12', 'g16'], description='RNA binding motif protein 6', other_designations='RNA-binding protein 6|RNA-binding protein DEF-3|lung cancer antigen NY-LU-12|lung cancer protooncogene 11', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49940041, end_position_on_the_genomic_accession=50077249, orientation='plus', exon_count=26, OMIM=[606886], no_hdr0=''),
    10181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10181, CurrentID=0, Status='live', Symbol='RBM5', Aliases=['G15', 'H37', 'LUCA-15', 'LUCA15', 'RMB5'], description='RNA binding motif protein 5', other_designations='RNA-binding protein 5|putative tumor suppressor LUCA15|renal carcinoma antigen NY-REN-9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50088919, end_position_on_the_genomic_accession=50119021, orientation='plus', exon_count=25, OMIM=[606884], no_hdr0=''),
    10184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10184, CurrentID=0, Status='live', Symbol='LHFPL2', Aliases=[], description='LHFPL tetraspan subfamily member 2', other_designations='LHFPL tetraspan subfamily member 2 protein|LHFP-like protein 2|lipoma HMGIC fusion partner-like 2 protein', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=78485224, end_position_on_the_genomic_accession=78770256, orientation='minus', exon_count=14, OMIM=[609718], no_hdr0=''),
    10186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10186, CurrentID=0, Status='live', Symbol='LHFPL6', Aliases=['LHFP'], description='LHFPL tetraspan subfamily member 6', other_designations='LHFPL tetraspan subfamily member 6 protein|lipoma HMGIC fusion partner', map_location='13q13.3-q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=39342892, end_position_on_the_genomic_accession=39603193, orientation='minus', exon_count=4, OMIM=[606710], no_hdr0=''),
    10188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10188, CurrentID=0, Status='live', Symbol='TNK2', Aliases=['ACK', 'ACK-1', 'ACK1', 'p21cdc42Hs'], description='tyrosine kinase non receptor 2', other_designations='activated CDC42 kinase 1|activated Cdc42-associated kinase 1|activated p21cdc42Hs kinase|tyrosine kinase non-receptor protein 2', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195863364, end_position_on_the_genomic_accession=195908551, orientation='minus', exon_count=28, OMIM=[606994], no_hdr0=''),
    10189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10189, CurrentID=0, Status='live', Symbol='ALYREF', Aliases=['ALY', 'ALY/REF', 'BEF', 'REF', 'THOC4'], description='Aly/REF export factor', other_designations='THO complex subunit 4|THO complex 4|ally of AML-1 and LEF-1|bZIP enhancing factor|bZIP-enhancing factor BEF|tho4|transcriptional coactivator Aly/REF', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81887835, end_position_on_the_genomic_accession=81891587, orientation='minus', exon_count=7, OMIM=[604171], no_hdr0=''),
    10190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10190, CurrentID=0, Status='live', Symbol='TXNDC9', Aliases=['APACD', 'PHLP3'], description='thioredoxin domain containing 9', other_designations='thioredoxin domain-containing protein 9|ATP binding protein associated with cell differentiation|protein 1-4', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99306184, end_position_on_the_genomic_accession=99336385, orientation='minus', exon_count=6, OMIM=[612564], no_hdr0=''),
    10193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10193, CurrentID=0, Status='live', Symbol='RNF41', Aliases=['FLRF', 'NRDP1', 'SBBI03'], description='ring finger protein 41', other_designations='E3 ubiquitin-protein ligase NRDP1|RING-type E3 ubiquitin transferase NRDP1|fetal liver ring finger|neuregulin receptor degradation protein-1|ring finger protein 41, E3 ubiquitin protein ligase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56202179, end_position_on_the_genomic_accession=56221982, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    10194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10194, CurrentID=0, Status='live', Symbol='TSHZ1', Aliases=['CAA', 'NY-CO-33', 'SDCCAG33', 'TSH1'], description='teashirt zinc finger homeobox 1', other_designations='teashirt homolog 1|antigen NY-CO-33|serologically defined colon cancer antigen 33', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=75210797, end_position_on_the_genomic_accession=75289946, orientation='plus', exon_count=3, OMIM=[614427], no_hdr0=''),
    10195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10195, CurrentID=0, Status='live', Symbol='ALG3', Aliases=['CDG1D', 'CDGS4', 'CDGS6', 'D16Ertd36e', 'NOT56L', 'Not56', 'not'], description='ALG3 alpha-1,3- mannosyltransferase', other_designations='dol-P-Man:Man(5)GlcNAc(2)-PP-Dol alpha-1,3-mannosyltransferase|Not56-like protein|asparagine-linked glycosylation 3 homolog (S. cerevisiae, alpha-1,3-mannosyltransferase)|asparagine-linked glycosylation 3 homolog (yeast, alpha-1,3-mannosyltransferase)|asparagine-linked glycosylation 3, alpha-1,3- mannosyltransferase homolog|asparagine-linked glycosylation protein 3 homolog|carbohydrate deficient glycoprotein syndrome type IV|dol-P-Man-dependent alpha(1-3)-mannosyltransferase|dolichyl-P-Man:Man(5)GlcNAc(2)-PP-dolichyl mannosyltransferase|dolichyl-phosphate-mannose--glycolipid alpha-mannosyltransferase', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184242301, end_position_on_the_genomic_accession=184258301, orientation='minus', exon_count=14, OMIM=[608750], no_hdr0=''),
    10196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10196, CurrentID=0, Status='live', Symbol='PRMT3', Aliases=['HRMT1L3'], description='protein arginine methyltransferase 3', other_designations='protein arginine N-methyltransferase 3|HMT1 hnRNP methyltransferase-like 3|heterogeneous nuclear ribonucleoprotein methyltransferase-like protein 3', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=20387563, end_position_on_the_genomic_accession=20510861, orientation='plus', exon_count=18, OMIM=[603190], no_hdr0=''),
    10197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10197, CurrentID=0, Status='live', Symbol='PSME3', Aliases=['HEL-S-283', 'Ki', 'PA28-gamma', 'PA28G', 'PA28gamma', 'REG-GAMMA'], description='proteasome activator subunit 3', other_designations='proteasome activator complex subunit 3|11S regulator complex gamma subunit|11S regulator complex subunit gamma|Ki antigen|Ki nuclear autoantigen|PA28 gamma variant 5|REG gamma-3|activator of multicatalytic protease subunit 3|epididymis secretory protein Li 283|proteasome (prosome, macropain) activator subunit 3 (PA28 gamma; Ki)|proteasome activator 28 subunit gamma|proteasome activator 28-gamma', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42833397, end_position_on_the_genomic_accession=42843760, orientation='plus', exon_count=12, OMIM=[605129], no_hdr0=''),
    10198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10198, CurrentID=0, Status='live', Symbol='MPHOSPH9', Aliases=['MPP-9', 'MPP9'], description='M-phase phosphoprotein 9', other_designations='M-phase phosphoprotein 9', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123152324, end_position_on_the_genomic_accession=123244014, orientation='minus', exon_count=27, OMIM=[605501], no_hdr0=''),
    10199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10199, CurrentID=0, Status='live', Symbol='MPHOSPH10', Aliases=['CT90', 'MPP10', 'MPP10P', 'PPP1R106'], description='M-phase phosphoprotein 10', other_designations='U3 small nucleolar ribonucleoprotein protein MPP10|U3 small nucleolar ribonucleoprotein|m phase phosphoprotein 10|protein phosphatase 1, regulatory subunit 106', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71130634, end_position_on_the_genomic_accession=71150101, orientation='plus', exon_count=11, OMIM=[605503], no_hdr0=''),
    10200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10200, CurrentID=0, Status='live', Symbol='MPHOSPH6', Aliases=['MPP', 'MPP-6', 'MPP6'], description='M-phase phosphoprotein 6', other_designations='M-phase phosphoprotein 6', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=82148162, end_position_on_the_genomic_accession=82170224, orientation='minus', exon_count=6, OMIM=[605500], no_hdr0=''),
    10201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10201, CurrentID=0, Status='live', Symbol='NME6', Aliases=['IPIA-ALPHA', 'NDK 6', 'NM23-H6'], description='NME/NM23 nucleoside diphosphate kinase 6', other_designations='nucleoside diphosphate kinase 6|NDP kinase 6|inhibitor of p53-induced apoptosis-alpha|non-metastatic cells 6, protein expressed in (nucleoside-diphosphate kinase)', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48288402, end_position_on_the_genomic_accession=48302904, orientation='minus', exon_count=8, OMIM=[608294], no_hdr0=''),
    10202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10202, CurrentID=0, Status='live', Symbol='DHRS2', Aliases=['HEP27', 'SDR25C1'], description='dehydrogenase/reductase 2', other_designations='dehydrogenase/reductase SDR family member 2, mitochondrial|dehydrogenase/reductase (SDR family) member 2|dehydrogenase/reductase member 2|dicarbonyl reductase HEP27|protein D|short chain dehydrogenase/reductase family 25C member 1|short-chain alcohol dehydrogenase family member', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23630115, end_position_on_the_genomic_accession=23645639, orientation='plus', exon_count=13, OMIM=[615194], no_hdr0=''),
    10203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10203, CurrentID=0, Status='live', Symbol='CALCRL', Aliases=['CGRPR', 'CRLR', 'LMPHM8'], description='calcitonin receptor like receptor', other_designations='calcitonin gene-related peptide type 1 receptor|CGRP type 1 receptor|calcitonin receptor-like', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=187341964, end_position_on_the_genomic_accession=187448304, orientation='minus', exon_count=17, OMIM=[114190], no_hdr0=''),
    10204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10204, CurrentID=0, Status='live', Symbol='NUTF2', Aliases=['NTF-2', 'NTF2', 'PP15'], description='nuclear transport factor 2', other_designations='nuclear transport factor 2|placental protein 15', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67846933, end_position_on_the_genomic_accession=67872567, orientation='plus', exon_count=7, OMIM=[605813], no_hdr0=''),
    10205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10205, CurrentID=0, Status='live', Symbol='MPZL2', Aliases=['DFNB111', 'EVA', 'EVA1'], description='myelin protein zero like 2', other_designations='myelin protein zero-like protein 2|epithelial V-like antigen 1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118253416, end_position_on_the_genomic_accession=118264297, orientation='minus', exon_count=6, OMIM=[604873], no_hdr0=''),
    10206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10206, CurrentID=0, Status='live', Symbol='TRIM13', Aliases=['CAR', 'DLEU5', 'LEU5', 'RFP2', 'RNF77'], description='tripartite motif containing 13', other_designations='E3 ubiquitin-protein ligase TRIM13|B-cell chronic lymphocytic leukemia tumor suppressor Leu5|CLL-associated RING finger|RING finger protein 77|RING-type E3 ubiquitin transferase TRIM13|leukemia-associated protein 5|putative tumor suppressor RFP2|ret finger protein 2|tripartite motif protein 13|tripartite motif-containing protein 13', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49997042, end_position_on_the_genomic_accession=50018467, orientation='plus', exon_count=4, OMIM=[605661], no_hdr0=''),
    10207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10207, CurrentID=0, Status='live', Symbol='PATJ', Aliases=['Cipp', 'INADL', 'InaD-like', 'hINADL'], description='PATJ crumbs cell polarity complex component', other_designations='inaD-like protein|PALS1-associated tight junction protein|PDZ domain protein|channel-interacting PDZ domain protein|channel-interacting PDZ domain-containing protein|inactivation no after-potential D-like protein|inactivation-no-afterpotential D-like|protein associated to tight junctions', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=61742477, end_position_on_the_genomic_accession=62163915, orientation='plus', exon_count=52, OMIM=[603199], no_hdr0=''),
    10208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10208, CurrentID=0, Status='live', Symbol='USPL1', Aliases=['C13orf22', 'D13S106E', 'bA121O19.1'], description='ubiquitin specific peptidase like 1', other_designations='SUMO-specific isopeptidase USPL1|USP-like 1|highly charged protein|ubiquitin-specific peptidase-like protein 1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30617859, end_position_on_the_genomic_accession=30660766, orientation='plus', exon_count=10, OMIM=[617470], no_hdr0=''),
    10209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10209, CurrentID=0, Status='live', Symbol='EIF1', Aliases=['A121', 'EIF-1A', 'ISO1', 'SUI1', 'EIF1'], description='eukaryotic translation initiation factor 1', other_designations='eukaryotic translation initiation factor 1|protein translation factor SUI1 homolog|sui1iso1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41688885, end_position_on_the_genomic_accession=41692668, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    10210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10210, CurrentID=0, Status='live', Symbol='TOPORS', Aliases=['LUN', 'P53BP3', 'RP31', 'TP53BPL'], description='TOP1 binding arginine/serine rich protein, E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase Topors|RING-type E3 ubiquitin transferase Topors|SUMO1-protein E3 ligase Topors|topoisomerase I binding, arginine/serine-rich, E3 ubiquitin protein ligase|topoisomerase I-binding RING finger protein|tumor suppressor p53-binding protein 3', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32540544, end_position_on_the_genomic_accession=32552586, orientation='minus', exon_count=3, OMIM=[609507], no_hdr0=''),
    10211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10211, CurrentID=0, Status='live', Symbol='FLOT1', Aliases=[], description='flotillin 1', other_designations='flotillin-1|integral membrane component of caveolae', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30727709, end_position_on_the_genomic_accession=30742847, orientation='minus', exon_count=14, OMIM=[606998], no_hdr0=''),
    10212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10212, CurrentID=0, Status='live', Symbol='DDX39A', Aliases=['BAT1', 'BAT1L', 'DDX39', 'DDXL', 'URH49'], description='DExD-box helicase 39A', other_designations='ATP-dependent RNA helicase DDX39A|DEAD (Asp-Glu-Ala-Asp) box polypeptide 39A|DEAD box protein 39|DEAD-box helicase 39A|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 39|UAP56-related helicase, 49 kDa|nuclear RNA helicase URH49|nuclear RNA helicase, DECD variant of DEAD box family', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14408798, end_position_on_the_genomic_accession=14419383, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    10213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10213, CurrentID=0, Status='live', Symbol='PSMD14', Aliases=['PAD1', 'POH1', 'RPN11'], description='proteasome 26S subunit, non-ATPase 14', other_designations='26S proteasome non-ATPase regulatory subunit 14|26S proteasome regulatory subunit rpn11|26S proteasome-associated PAD1 homolog 1|proteasome (prosome, macropain) 26S subunit, non-ATPase, 14|testis tissue sperm-binding protein Li 69n', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=161308425, end_position_on_the_genomic_accession=161411717, orientation='plus', exon_count=12, OMIM=[607173], no_hdr0=''),
    10214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10214, CurrentID=0, Status='live', Symbol='SSX3', Aliases=['CT5.3'], description='SSX family member 3', other_designations='protein SSX3|Kruppel-associated box containing gene product SSX3|cancer/testis antigen 5.3|synovial sarcoma, X breakpoint 3', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48346427, end_position_on_the_genomic_accession=48356706, orientation='minus', exon_count=9, OMIM=[300325], no_hdr0=''),
    10215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10215, CurrentID=0, Status='live', Symbol='OLIG2', Aliases=['BHLHB1', 'OLIGO2', 'PRKCBP2', 'RACK17', 'bHLHe19'], description='oligodendrocyte transcription factor 2', other_designations='oligodendrocyte transcription factor 2|basic domain, helix-loop-helix protein, class B, 1|class B basic helix-loop-helix protein 1|class E basic helix-loop-helix protein 19|human protein kinase C-binding protein RACK17|oligodendrocyte lineage transcription factor 2|oligodendrocyte-specific bHLH transcription factor 2|protein kinase C-binding protein 2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33025935, end_position_on_the_genomic_accession=33029196, orientation='plus', exon_count=2, OMIM=[606386], no_hdr0=''),
    10216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10216, CurrentID=0, Status='live', Symbol='PRG4', Aliases=['CACP', 'HAPO', 'JCAP', 'MSF', 'SZP'], description='proteoglycan 4', other_designations='proteoglycan 4|articular superficial zone protein|hemangiopoietin|lubricin|megakaryocyte stimulating factor|superficial zone proteoglycan', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186296273, end_position_on_the_genomic_accession=186314567, orientation='plus', exon_count=13, OMIM=[604283], no_hdr0=''),
    10217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10217, CurrentID=0, Status='live', Symbol='CTDSPL', Aliases=['C3orf8', 'HYA22', 'PSR1', 'RBSP3', 'SCP3'], description='CTD small phosphatase like', other_designations='CTD small phosphatase-like protein|CTD (carboxy-terminal domain, RNA polymerase II, polypeptide A) small phosphatase-like|CTDSP-like|NIF-like protein|NLI-interacting factor 1|RB protein serine phosphatase from chromosome 3|carboxy-terminal domain RNA polymerase II polypeptide A small phosphatase 3|nuclear LIM interactor-interacting factor 1|small C-terminal domain phosphatase 3|small CTD phosphatase 3', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37861880, end_position_on_the_genomic_accession=37984469, orientation='plus', exon_count=9, OMIM=[608592], no_hdr0=''),
    10218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10218, CurrentID=0, Status='live', Symbol='ANGPTL7', Aliases=['AngX', 'CDT6', 'dJ647M16.1'], description='angiopoietin like 7', other_designations='angiopoietin-related protein 7|angiopoietin-like factor (CDT6)|angiopoietin-like protein 7|cornea-derived transcript 6 protein', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11189324, end_position_on_the_genomic_accession=11195981, orientation='plus', exon_count=6, OMIM=[618517], no_hdr0=''),
    10219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10219, CurrentID=0, Status='live', Symbol='KLRG1', Aliases=['2F1', 'CLEC15A', 'MAFA', 'MAFA-2F1', 'MAFA-L', 'MAFA-LIKE'], description='killer cell lectin like receptor G1', other_designations='killer cell lectin-like receptor subfamily G member 1|C-type lectin domain family 15 member A|ITIM-containing receptor MAFA-L|MAFA-like receptor|killer cell lectin-like receptor subfamily G, member 1|mast cell function-associated antigen (ITIM-containing)', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8950044, end_position_on_the_genomic_accession=9215657, orientation='plus', exon_count=12, OMIM=[604874], no_hdr0=''),
    10220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10220, CurrentID=0, Status='live', Symbol='GDF11', Aliases=['BMP-11', 'BMP11', 'VHO'], description='growth differentiation factor 11', other_designations='growth/differentiation factor 11|GDF-11|bone morphogenetic protein 11', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55743122, end_position_on_the_genomic_accession=55757264, orientation='plus', exon_count=3, OMIM=[603936], no_hdr0=''),
    10221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10221, CurrentID=0, Status='live', Symbol='TRIB1', Aliases=['C8FW', 'GIG-2', 'GIG2', 'SKIP1', 'TRB-1', 'TRB1'], description='tribbles pseudokinase 1', other_designations='tribbles homolog 1|G-protein-coupled receptor induced protein|G-protein-coupled receptor-induced gene 2 protein|G-protein-coupled receptor-induced protein 2|phosphoprotein regulated by mitogenic pathways|tribbles-like protein 1', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=125430290, end_position_on_the_genomic_accession=125438403, orientation='plus', exon_count=4, OMIM=[609461], no_hdr0=''),
    10223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10223, CurrentID=0, Status='live', Symbol='GPA33', Aliases=['A33'], description='glycoprotein A33', other_designations='cell surface A33 antigen|glycoprotein A33 (transmembrane)|transmembrane glycoprotein A33', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167052836, end_position_on_the_genomic_accession=167090392, orientation='minus', exon_count=8, OMIM=[602171], no_hdr0=''),
    10224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10224, CurrentID=0, Status='live', Symbol='ZNF443', Aliases=['ZK1'], description='zinc finger protein 443', other_designations='zinc finger protein 443|Kruppel-type zinc finger (C2H2)|krueppel-type zinc finger protein ZK1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12429706, end_position_on_the_genomic_accession=12441021, orientation='minus', exon_count=4, OMIM=[606697], no_hdr0=''),
    10225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10225, CurrentID=0, Status='live', Symbol='CD96', Aliases=['TACTILE'], description='CD96 molecule', other_designations='T-cell surface protein tactile|T cell activation, increased late expression|cell surface antigen CD96|t cell-activated increased late expression protein', map_location='3q13.13-q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111542118, end_position_on_the_genomic_accession=111665996, orientation='plus', exon_count=19, OMIM=[606037], no_hdr0=''),
    10226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10226, CurrentID=0, Status='live', Symbol='PLIN3', Aliases=['M6PRBP1', 'PP17', 'TIP47'], description='perilipin 3', other_designations='perilipin-3|47 kDa MPR-binding protein|cargo selection protein TIP47|mannose-6-phosphate receptor-binding protein 1|placental protein 17|tail-interacting protein, 47 kD|testicular tissue protein Li 114', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4838341, end_position_on_the_genomic_accession=4867667, orientation='minus', exon_count=8, OMIM=[602702], no_hdr0=''),
    10227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10227, CurrentID=0, Status='live', Symbol='MFSD10', Aliases=['TETRAN', 'TETTRAN'], description='major facilitator superfamily domain containing 10', other_designations='major facilitator superfamily domain-containing protein 10|tetracycline transporter-like protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2930556, end_position_on_the_genomic_accession=2934854, orientation='minus', exon_count=12, OMIM=[610977], no_hdr0=''),
    10228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10228, CurrentID=0, Status='live', Symbol='STX6', Aliases=[], description='syntaxin 6', other_designations='syntaxin-6', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180972725, end_position_on_the_genomic_accession=181022917, orientation='minus', exon_count=8, OMIM=[603944], no_hdr0=''),
    10229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10229, CurrentID=0, Status='live', Symbol='COQ7', Aliases=['CAT5', 'CLK-1', 'CLK1', 'COQ10D8'], description='coenzyme Q7, hydroxylase', other_designations='5-demethoxyubiquinone hydroxylase, mitochondrial|COQ7 coenzyme Q, 7 homolog ubiquinone|DMQ hydroxylase|coenzyme Q biosynthesis protein 7 homolog|coenzyme Q7 homolog, ubiquinone|placental protein KG-20|timing protein clk-1 homolog|ubiquinone biosynthesis monooxygenase COQ7|ubiquinone biosynthesis protein COQ7 homolog', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19067595, end_position_on_the_genomic_accession=19080095, orientation='plus', exon_count=10, OMIM=[601683], no_hdr0=''),
    10231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10231, CurrentID=0, Status='live', Symbol='RCAN2', Aliases=['CSP2', 'DSCR1L1', 'MCIP2', 'RCN2', 'ZAKI-4', 'ZAKI4'], description='regulator of calcineurin 2', other_designations='calcipressin-2|Down syndrome candidate region 1-like 1|Down syndrome critical region gene 1-like 1|myocyte-enriched calcineurin-interacting protein 2|thyroid hormone-responsive (skin fibroblasts)|thyroid hormone-responsive protein ZAKI-4', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46220731, end_position_on_the_genomic_accession=46491970, orientation='minus', exon_count=8, OMIM=[604876], no_hdr0=''),
    10232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10232, CurrentID=0, Status='live', Symbol='MSLN', Aliases=['MPF', 'SMRP'], description='mesothelin', other_designations='mesothelin|CAK1 antigen|megakaryocyte potentiating factor|pre-pro-megakaryocyte-potentiating factor|soluble MPF mesothelin related protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=760734, end_position_on_the_genomic_accession=768865, orientation='plus', exon_count=18, OMIM=[601051], no_hdr0=''),
    10233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10233, CurrentID=0, Status='live', Symbol='LRRC23', Aliases=['LRPB7'], description='leucine rich repeat containing 23', other_designations='leucine-rich repeat-containing protein 23|leucine-rich protein B7', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6904822, end_position_on_the_genomic_accession=6914229, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    10234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10234, CurrentID=0, Status='live', Symbol='LRRC17', Aliases=['P37NB'], description='leucine rich repeat containing 17', other_designations='leucine-rich repeat-containing protein 17|37 kDa leucine-rich repeat (LRR) protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102913000, end_position_on_the_genomic_accession=102945111, orientation='plus', exon_count=6, OMIM=[618749], no_hdr0=''),
    10235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10235, CurrentID=0, Status='live', Symbol='RASGRP2', Aliases=['CALDAG-GEFI', 'CDC25L'], description='RAS guanyl releasing protein 2', other_designations='RAS guanyl-releasing protein 2|F25B3.3 kinase-like protein|RAS guanyl nucleotide-releasing protein 2|RAS guanyl releasing protein 2 (calcium and DAG-regulated)|calcium and DAG-regulated guanine nucleotide exchange factor I|calcium and diacylglycerol-regulated guanine nucleotide exchange factor I|cdc25-like protein|guanine exchange factor MCG7', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64726911, end_position_on_the_genomic_accession=64745481, orientation='minus', exon_count=23, OMIM=[605577], no_hdr0=''),
    10236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10236, CurrentID=0, Status='live', Symbol='HNRNPR', Aliases=['HNRPR', 'hnRNP-R'], description='heterogeneous nuclear ribonucleoprotein R', other_designations='heterogeneous nuclear ribonucleoprotein R', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23304688, end_position_on_the_genomic_accession=23344316, orientation='minus', exon_count=11, OMIM=[607201], no_hdr0=''),
    10237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10237, CurrentID=0, Status='live', Symbol='SLC35B1', Aliases=['AXER', 'UGTREL1'], description='solute carrier family 35 member B1', other_designations='solute carrier family 35 member B1|ATP/ADP exchanger in the ER membrane|UDP-galactose transporter related|UDP-galactose transporter-related protein 1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49700943, end_position_on_the_genomic_accession=49708173, orientation='minus', exon_count=11, OMIM=[610790], no_hdr0=''),
    10238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10238, CurrentID=0, Status='live', Symbol='DCAF7', Aliases=['AN11', 'HAN11', 'SWAN-1', 'WDR68'], description='DDB1 and CUL4 associated factor 7', other_designations='DDB1- and CUL4-associated factor 7|WD repeat-containing protein 68|WD repeat-containing protein An11 homolog|human anthocyanin|seven-WD-repeat protein of the AN11 family-1', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63550477, end_position_on_the_genomic_accession=63594266, orientation='plus', exon_count=8, OMIM=[605973], no_hdr0=''),
    10239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10239, CurrentID=0, Status='live', Symbol='AP3S2', Aliases=['AP3S3', 'sigma3b'], description='adaptor related protein complex 3 subunit sigma 2', other_designations='AP-3 complex subunit sigma-2|AP-3 complex subunit sigma-3B|adapter-related protein complex 3 subunit sigma-2|adaptor complex sigma3B|adaptor related protein complex 3 sigma 2 subunit|clathrin-associated/assembly/adaptor protein, small 4, 22-kD|sigma-3B-adaptin|sigma-adaptin 3b', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89830599, end_position_on_the_genomic_accession=89893994, orientation='minus', exon_count=7, OMIM=[602416], no_hdr0=''),
    10240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10240, CurrentID=0, Status='live', Symbol='MRPS31', Aliases=['IMOGN38', 'MRP-S31', 'S31mt'], description='mitochondrial ribosomal protein S31', other_designations='28S ribosomal protein S31, mitochondrial|imogen 38|mitochondrial small ribosomal subunit protein mS31', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=40729128, end_position_on_the_genomic_accession=40771207, orientation='minus', exon_count=8, OMIM=[611992], no_hdr0=''),
    10241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10241, CurrentID=0, Status='live', Symbol='CALCOCO2', Aliases=['NDP52'], description='calcium binding and coiled-coil domain 2', other_designations='calcium-binding and coiled-coil domain-containing protein 2|antigen nuclear dot 52 kDa protein|nuclear domain 10 protein 52|nuclear domain 10 protein NDP52|nuclear dot protein 52', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48831035, end_position_on_the_genomic_accession=48865245, orientation='plus', exon_count=15, OMIM=[604587], no_hdr0=''),
    10242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10242, CurrentID=0, Status='live', Symbol='KCNMB2', Aliases=[], description='potassium calcium-activated channel subfamily M regulatory beta subunit 2', other_designations='calcium-activated potassium channel subunit beta-2|BK channel beta subunit 2|BK channel subunit beta-2|MaxiK channel beta 2 subunit|MaxiK channel beta-subunit 2|big potassium channel beta subunit 2|charybdotoxin receptor subunit beta-2|hCG1646471|hbeta2|k(VCA)beta-2|large conductance calcium-activated potassium channel beta 2 subunit|large-conductance Ca2+-activated K+ channel beta2 subunit|potassium channel subfamily M regulatory beta subunit 2|potassium large conductance calcium-activated channel, subfamily M, beta member 2|slo-beta-2', map_location='3q26.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=178536394, end_position_on_the_genomic_accession=178844429, orientation='plus', exon_count=7, OMIM=[605214], no_hdr0=''),
    10243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10243, CurrentID=0, Status='live', Symbol='GPHN', Aliases=['GEPH', 'GPH', 'GPHRYN', 'HKPX1', 'MOCODC'], description='gephyrin', other_designations='gephyrin', map_location='14q23.3-q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=66507934, end_position_on_the_genomic_accession=67181805, orientation='plus', exon_count=30, OMIM=[603930], no_hdr0=''),
    10244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10244, CurrentID=0, Status='live', Symbol='RABEPK', Aliases=['RAB9P40', 'bA65N13.1', 'p40'], description='Rab9 effector protein with kelch motifs', other_designations='rab9 effector protein with kelch motifs|40 kDa Rab9 effector protein|Rab9 effector p40', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125200493, end_position_on_the_genomic_accession=125234161, orientation='plus', exon_count=12, OMIM=[605962], no_hdr0=''),
    10245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10245, CurrentID=0, Status='live', Symbol='TIMM17B', Aliases=['DXS9822', 'JM3', 'TIM17B'], description='translocase of inner mitochondrial membrane 17B', other_designations='mitochondrial import inner membrane translocase subunit Tim17-B|inner mitochondrial membrane preprotein translocase|translocase of inner mitochondrial membrane 17 homolog B', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48893447, end_position_on_the_genomic_accession=48898143, orientation='minus', exon_count=8, OMIM=[300249], no_hdr0=''),
    10246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10246, CurrentID=0, Status='live', Symbol='SLC17A2', Aliases=['NPT3'], description='solute carrier family 17 member 2', other_designations='sodium-dependent phosphate transport protein 3|Na(+)/PI cotransporter 3|sodium phosphate transporter 3|sodium/phosphate cotransporter 3|solute carrier family 17 (vesicular glutamate transporter), member 2', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25912754, end_position_on_the_genomic_accession=25930727, orientation='minus', exon_count=12, OMIM=[611049], no_hdr0=''),
    10247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10247, CurrentID=0, Status='live', Symbol='RIDA', Aliases=['HRSP12', 'P14.5', 'PSP', 'UK114', 'hp14.5'], description='reactive intermediate imine deaminase A homolog', other_designations='2-iminobutanoate/2-iminopropanoate deaminase|14.5 kDa translational inhibitor protein|UK114 antigen homolog|heat-responsive protein 12|perchloric acid-soluble protein|ribonuclease UK114|translation inhibitor L-PSP ribonuclease|translational inhibitor p14.5|translational inhibitor protein p14.5', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98102344, end_position_on_the_genomic_accession=98117171, orientation='minus', exon_count=6, OMIM=[602487], no_hdr0=''),
    10248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10248, CurrentID=0, Status='live', Symbol='POP7', Aliases=['0610037N12Rik', 'RPP2', 'RPP20'], description='POP7 homolog, ribonuclease P/MRP subunit', other_designations='ribonuclease P protein subunit p20|POP7 (processing of precursor, S. cerevisiae) homolog|RNaseP protein p20|hPOP7|processing of precursor 7, ribonuclease P subunit|processing of precursor 7, ribonuclease P/MRP subunit|ribonucleases P/MRP protein subunit POP7 homolog', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100706121, end_position_on_the_genomic_accession=100707486, orientation='plus', exon_count=2, OMIM=[606113], no_hdr0=''),
    10249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10249, CurrentID=0, Status='live', Symbol='GLYAT', Aliases=['ACGNAT', 'CAT', 'GAT'], description='glycine-N-acyltransferase', other_designations='glycine N-acyltransferase|AAc|HRP-1(CLP)|acyl-CoA:glycine N-acyltransferase|aralkyl acyl-CoA N-acyltransferase|aralkyl acyl-CoA:amino acid N-acyltransferase|aralkyl-CoA N-acyltransferase|benzoyl-coenzyme A:glycine N-acyltransferase|epididymis secretory sperm binding protein|glycine N-benzoyltransferase', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58708757, end_position_on_the_genomic_accession=58731943, orientation='minus', exon_count=7, OMIM=[607424], no_hdr0=''),
    10250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10250, CurrentID=0, Status='live', Symbol='SRRM1', Aliases=['160-KD', 'POP101', 'SRM160'], description='serine and arginine repetitive matrix 1', other_designations='serine/arginine repetitive matrix protein 1|SR-related nuclear matrix protein of 160 kDa|Ser/Arg-related nuclear matrix protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24643273, end_position_on_the_genomic_accession=24673281, orientation='plus', exon_count=22, OMIM=[605975], no_hdr0=''),
    10251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10251, CurrentID=0, Status='live', Symbol='SPRY3', Aliases=['spry-3'], description='sprouty RTK signaling antagonist 3', other_designations='protein sprouty homolog 3|antagonist of FGF signaling|sprouty homolog 3|sprouty3', map_location='Xq28 and Yq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155612586, end_position_on_the_genomic_accession=155782459, orientation='plus', exon_count=6, OMIM=[300531], no_hdr0=''),
    10252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10252, CurrentID=0, Status='live', Symbol='SPRY1', Aliases=['hSPRY1'], description='sprouty RTK signaling antagonist 1', other_designations='protein sprouty homolog 1|sprouty homolog 1, antagonist of FGF signaling|sprouty, Drosophila, homolog of, 1 (antagonist of FGF signaling)|spry-1', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=123396795, end_position_on_the_genomic_accession=123403760, orientation='plus', exon_count=5, OMIM=[602465], no_hdr0=''),
    10253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10253, CurrentID=0, Status='live', Symbol='SPRY2', Aliases=['IGAN3', 'hSPRY2'], description='sprouty RTK signaling antagonist 2', other_designations='protein sprouty homolog 2', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=80335976, end_position_on_the_genomic_accession=80341126, orientation='minus', exon_count=4, OMIM=[602466], no_hdr0=''),
    10254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10254, CurrentID=0, Status='live', Symbol='STAM2', Aliases=['HbpA', 'STAM2B', 'STAM2'], description='signal transducing adaptor molecule 2', other_designations='signal transducing adapter molecule 2|HSE1 homolog|Hrs-binding protein|STAM-2|STAM-like protein containing SH3 and ITAM domains 2|signal transducing adaptor molecule (SH3 domain and ITAM motif) 2', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=152116801, end_position_on_the_genomic_accession=152175777, orientation='minus', exon_count=14, OMIM=[606244], no_hdr0=''),
    10256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10256, CurrentID=0, Status='live', Symbol='CNKSR1', Aliases=['CNK', 'CNK1'], description='connector enhancer of kinase suppressor of Ras 1', other_designations='connector enhancer of kinase suppressor of ras 1|CNK homolog protein 1|connector enhancer of KSR 1|connector enhancer of KSR-like', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26177491, end_position_on_the_genomic_accession=26189884, orientation='plus', exon_count=21, OMIM=[603272], no_hdr0=''),
    10257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10257, CurrentID=0, Status='live', Symbol='ABCC4', Aliases=['MOAT-B', 'MOATB', 'MRP4'], description='ATP binding cassette subfamily C member 4', other_designations='ATP-binding cassette sub-family C member 4|MRP/cMOAT-related ABC transporter|bA464I2.1 (ATP-binding cassette, sub-family C (CFTR/MRP), member 4)|canalicular multispecific organic anion transporter (ABC superfamily)|multi-specific organic anion transporter B|multidrug resistance-associated protein 4', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=95019835, end_position_on_the_genomic_accession=95301451, orientation='minus', exon_count=36, OMIM=[605250], no_hdr0=''),
    10260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10260, CurrentID=0, Status='live', Symbol='DENND4A', Aliases=['IRLB', 'MYCPBP'], description='DENN domain containing 4A', other_designations='C-myc promoter-binding protein|DENN domain-containing protein 4A|DENN/MADD domain containing 4A|c-myc promoter binding protein', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65655234, end_position_on_the_genomic_accession=65792293, orientation='minus', exon_count=34, OMIM=[600382], no_hdr0=''),
    10261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10261, CurrentID=0, Status='live', Symbol='IGSF6', Aliases=['DORA'], description='immunoglobulin superfamily member 6', other_designations='immunoglobulin superfamily member 6|down-regulated by activation (immunoglobulin superfamily)', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21639550, end_position_on_the_genomic_accession=21652608, orientation='minus', exon_count=6, OMIM=[606222], no_hdr0=''),
    10262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10262, CurrentID=0, Status='live', Symbol='SF3B4', Aliases=['AFD1', 'Hsh49', 'SAP49', 'SF3b49'], description='splicing factor 3b subunit 4', other_designations='splicing factor 3B subunit 4|SAP 49|SF3b50|pre-mRNA-splicing factor SF3b 49 kDa subunit|spliceosomal protein|spliceosome-associated protein (U2 snRNP)|spliceosome-associated protein 49|splicing factor 3b, subunit 4, 49kD|splicing factor 3b, subunit 4, 49kDa', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149923317, end_position_on_the_genomic_accession=149927803, orientation='minus', exon_count=6, OMIM=[605593], no_hdr0=''),
    10263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10263, CurrentID=0, Status='live', Symbol='CDK2AP2', Aliases=['DOC-1R', 'p14'], description='cyclin dependent kinase 2 associated protein 2', other_designations='cyclin-dependent kinase 2-associated protein 2|CDK2-associated protein 2|DOC-1-related protein|tumor suppressor deleted in oral cancer related 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67506497, end_position_on_the_genomic_accession=67508162, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    10265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10265, CurrentID=0, Status='live', Symbol='IRX5', Aliases=['HMMS', 'IRX-2a', 'IRXB2'], description='iroquois homeobox 5', other_designations='iroquois-class homeodomain protein IRX-5|homeodomain protein IRX-2A|homeodomain protein IRXB2', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=54930865, end_position_on_the_genomic_accession=54934485, orientation='plus', exon_count=4, OMIM=[606195], no_hdr0=''),
    10266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10266, CurrentID=0, Status='live', Symbol='RAMP2', Aliases=[], description='receptor activity modifying protein 2', other_designations='receptor activity-modifying protein 2|CRLR activity-modifying protein 2|calcitonin receptor-like receptor activity modifying protein 2|receptor (G protein-coupled) activity modifying protein 2|receptor (calcitonin) activity modifying protein 2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42761227, end_position_on_the_genomic_accession=42763041, orientation='plus', exon_count=4, OMIM=[605154], no_hdr0=''),
    10267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10267, CurrentID=0, Status='live', Symbol='RAMP1', Aliases=[], description='receptor activity modifying protein 1', other_designations='receptor activity-modifying protein 1|CRLR activity-modifying protein 1|calcitonin receptor-like receptor activity modifying protein 1|receptor (G protein-coupled) activity modifying protein 1|receptor (calcitonin) activity modifying protein 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237858555, end_position_on_the_genomic_accession=237912114, orientation='plus', exon_count=7, OMIM=[605153], no_hdr0=''),
    10268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10268, CurrentID=0, Status='live', Symbol='RAMP3', Aliases=[], description='receptor activity modifying protein 3', other_designations='receptor activity-modifying protein 3|CRLR activity-modifying protein 3|calcitonin receptor-like receptor activity modifying protein 3|receptor (G protein-coupled) activity modifying protein 3|receptor (calcitonin) activity modifying protein 3', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45157778, end_position_on_the_genomic_accession=45184250, orientation='plus', exon_count=6, OMIM=[605155], no_hdr0=''),
    10269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10269, CurrentID=0, Status='live', Symbol='ZMPSTE24', Aliases=['FACE-1', 'FACE1', 'HGPS', 'PRO1', 'STE24', 'Ste24p'], description='zinc metallopeptidase STE24', other_designations='CAAX prenyl protease 1 homolog|farnesylated proteins-converting enzyme 1|prenyl protein-specific endoprotease 1|zinc metallopeptidase STE24 homolog|zinc metalloproteinase Ste24 homolog', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40258078, end_position_on_the_genomic_accession=40294180, orientation='plus', exon_count=11, OMIM=[606480], no_hdr0=''),
    10270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10270, CurrentID=0, Status='live', Symbol='AKAP8', Aliases=['AKAP 95', 'AKAP-8', 'AKAP-95', 'AKAP95'], description='A-kinase anchoring protein 8', other_designations='A-kinase anchor protein 8|A kinase (PRKA) anchor protein 8|A-kinase anchor protein, 95kDa', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15353385, end_position_on_the_genomic_accession=15379787, orientation='minus', exon_count=14, OMIM=[604692], no_hdr0=''),
    10272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10272, CurrentID=0, Status='live', Symbol='FSTL3', Aliases=['FLRG', 'FSRP'], description='follistatin like 3', other_designations='follistatin-related protein 3|follistatin-like 3 (secreted glycoprotein)|follistatin-like protein 3|follistatin-related gene protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=676392, end_position_on_the_genomic_accession=683385, orientation='plus', exon_count=5, OMIM=[605343], no_hdr0=''),
    10273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10273, CurrentID=0, Status='live', Symbol='STUB1', Aliases=['CHIP', 'HSPABP2', 'NY-CO-7', 'SCA48', 'SCAR16', 'SDCCAG7', 'UBOX1'], description='STIP1 homology and U-box containing protein 1', other_designations='E3 ubiquitin-protein ligase CHIP|CLL-associated antigen KW-8|RING-type E3 ubiquitin transferase CHIP|STIP1 homology and U-box containing protein 1, E3 ubiquitin protein ligase|antigen NY-CO-7|carboxy terminus of Hsp70-interacting protein|heat shock protein A binding protein 2 (c-terminal)|serologically defined colon cancer antigen 7', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=680410, end_position_on_the_genomic_accession=682801, orientation='plus', exon_count=7, OMIM=[607207], no_hdr0=''),
    10274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10274, CurrentID=0, Status='live', Symbol='STAG1', Aliases=['MRD47', 'SA1', 'SCC3A'], description='stromal antigen 1', other_designations='cohesin subunit SA-1|SCC3 homolog 1|nuclear protein stromal antigen 1', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136336235, end_position_on_the_genomic_accession=136752412, orientation='minus', exon_count=39, OMIM=[604358], no_hdr0=''),
    10276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10276, CurrentID=0, Status='live', Symbol='NET1', Aliases=['ARHGEF8A', 'NET1'], description='neuroepithelial cell transforming 1', other_designations='neuroepithelial cell-transforming gene 1 protein|Rho guanine nucleotide exchange factor (GEF) 8|epididymis secretory sperm binding protein|guanine nucleotide regulatory protein (oncogene)|neuroepithelioma transforming gene 1|p65 Net1 proto-oncogene protein|small GTP-binding protein regulator', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5412557, end_position_on_the_genomic_accession=5459056, orientation='plus', exon_count=13, OMIM=[606450], no_hdr0=''),
    10277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10277, CurrentID=0, Status='live', Symbol='UBE4B', Aliases=['E4', 'HDNB1', 'UBOX3', 'UFD2', 'UFD2A'], description='ubiquitination factor E4B', other_designations='ubiquitin conjugation factor E4 B|RING-type E3 ubiquitin transferase E4 B|homologous to yeast UFD2|homozygously deleted in neuroblastoma-1|ubiquitin-fusion degradation protein 2|ubiquitination factor E4B (UFD2 homolog, yeast)', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10032958, end_position_on_the_genomic_accession=10181239, orientation='plus', exon_count=31, OMIM=[613565], no_hdr0=''),
    10278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10278, CurrentID=0, Status='live', Symbol='EFS', Aliases=['CAS3', 'CASS31', 'EFS2', 'HEFS', 'SIN', 'EFS'], description='embryonal Fyn-associated substrate', other_designations='embryonal Fyn-associated substrate|Cas scaffolding protein family member 3|signal transduction protein (SH3 containing)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23356402, end_position_on_the_genomic_accession=23365207, orientation='minus', exon_count=7, OMIM=[609906], no_hdr0=''),
    10279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10279, CurrentID=0, Status='live', Symbol='PRSS16', Aliases=['TSSP'], description='serine protease 16', other_designations='thymus-specific serine protease|protease, serine 16|protease, serine, 16 (thymus)|thymus specific serine peptidase', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27247701, end_position_on_the_genomic_accession=27256620, orientation='plus', exon_count=12, OMIM=[607169], no_hdr0=''),
    10280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10280, CurrentID=0, Status='live', Symbol='SIGMAR1', Aliases=['ALS16', 'DSMA2', 'OPRS1', 'SIG-1R', 'SR-BP', 'SR-BP1', 'SRBP', 'hSigmaR1', 'sigma1R'], description='sigma non-opioid intracellular receptor 1', other_designations='sigma non-opioid intracellular receptor 1|SR31747 binding protein 1|aging-associated gene 8 protein|sigma 1-type opioid receptor', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34634722, end_position_on_the_genomic_accession=34637787, orientation='minus', exon_count=4, OMIM=[601978], no_hdr0=''),
    10282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10282, CurrentID=0, Status='live', Symbol='BET1', Aliases=['HBET1'], description='Bet1 golgi vesicular membrane trafficking protein', other_designations='BET1 homolog|Bet1p homolog|Golgi vesicular membrane trafficking protein p18|blocked early in transport 1 homolog|golgi vesicular membrane-trafficking protein p18', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93962762, end_position_on_the_genomic_accession=94004355, orientation='minus', exon_count=8, OMIM=[605456], no_hdr0=''),
    10283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10283, CurrentID=0, Status='live', Symbol='CWC27', Aliases=['NY-CO-10', 'RPSKA', 'SDCCAG-10', 'SDCCAG10'], description='CWC27 spliceosome associated cyclophilin', other_designations='spliceosome-associated protein CWC27 homolog|CWC27 spliceosome associated protein homolog|PPIase CWC27|PPIase SDCCAG10|antigen NY-CO-10|peptidyl-prolyl cis-trans isomerase CWC27 homolog|peptidyl-prolyl cis-trans isomerase SDCCAG10|probable inactive peptidyl-prolyl cis-trans isomerase CWC27 homolog|serologically defined colon cancer antigen 10', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=64768918, end_position_on_the_genomic_accession=65018763, orientation='plus', exon_count=19, OMIM=[617170], no_hdr0=''),
    10284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10284, CurrentID=0, Status='live', Symbol='SAP18', Aliases=['2HOR0202P', 'SAP18'], description='Sin3A associated protein 18', other_designations='histone deacetylase complex subunit SAP18|18 kDa Sin3-associated polypeptide|Sin3A-associated protein, 18kDa|cell growth inhibiting protein 38|cell growth-inhibiting gene 38 protein|epididymis secretory sperm binding protein|histone deacetlyase complex subunit SAP18|sin3-associated polypeptide, 18 kDa|sin3-associated polypeptide, p18', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21140514, end_position_on_the_genomic_accession=21149085, orientation='plus', exon_count=5, OMIM=[602949], no_hdr0=''),
    10285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10285, CurrentID=0, Status='live', Symbol='SMNDC1', Aliases=['SMNR', 'SPF30', 'TDRD16C'], description='survival motor neuron domain containing 1', other_designations='survival of motor neuron-related-splicing factor 30|30 kDa splicing factor SMNrp|SMN-related protein|splicing factor 30, survival of motor neuron-related|survival motor neuron domain-containing protein 1|tudor domain containing 16C', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110290730, end_position_on_the_genomic_accession=110304969, orientation='minus', exon_count=7, OMIM=[603519], no_hdr0=''),
    10286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10286, CurrentID=0, Status='live', Symbol='BCAS2', Aliases=['DAM1', 'SPF27', 'Snt309'], description='BCAS2 pre-mRNA processing factor', other_designations='pre-mRNA-splicing factor SPF27|DNA amplified in mammary carcinoma 1 protein|breast carcinoma amplified sequence 2|spliceosome associated protein, amplified in breast cancer|spliceosome-associated protein SPF 27', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114567557, end_position_on_the_genomic_accession=114581615, orientation='minus', exon_count=7, OMIM=[605783], no_hdr0=''),
    10287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10287, CurrentID=0, Status='live', Symbol='RGS19', Aliases=['GAIP', 'RGSGAIP'], description='regulator of G protein signaling 19', other_designations='regulator of G-protein signaling 19|G alpha interacting protein|G protein signalling regulator 19|guanine nucleotide binding protein alpha inhibiting activity polypeptide 3 interacting protein|regulator of G-protein signalling 19', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64073181, end_position_on_the_genomic_accession=64080004, orientation='minus', exon_count=8, OMIM=[605071], no_hdr0=''),
    10288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10288, CurrentID=0, Status='live', Symbol='LILRB2', Aliases=['CD85D', 'ILT-4', 'ILT4', 'LIR-2', 'LIR2', 'MIR-10', 'MIR10'], description='leukocyte immunoglobulin like receptor B2', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 2|CD85 antigen-like family member D|Ig-like transcript 4|leucocyte Ig-like receptor B2|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 2|monocyte/macrophage immunoglobulin-like receptor 10|myeloid inhibitory receptor 10', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54273812, end_position_on_the_genomic_accession=54281110, orientation='minus', exon_count=15, OMIM=[604815], no_hdr0=''),
    10289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10289, CurrentID=0, Status='live', Symbol='EIF1B', Aliases=['GC20'], description='eukaryotic translation initiation factor 1B', other_designations='eukaryotic translation initiation factor 1b|protein translation factor SUI1 homolog GC20|translation factor sui1 homolog', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40309707, end_position_on_the_genomic_accession=40312424, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    10290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10290, CurrentID=0, Status='live', Symbol='SPEG', Aliases=['APEG-1', 'APEG1', 'BPEG', 'CNM5', 'MYLK6alpha', 'SPEGbeta', 'SPEG'], description='striated muscle enriched protein kinase', other_designations='striated muscle preferentially expressed protein kinase|SPEG complex locus|aortic preferentially expressed gene 1|aortic preferentially expressed protein 1|nuclear protein, marker for differentiated aortic smooth muscle and down-regulated with vascular injury', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219434215, end_position_on_the_genomic_accession=219493629, orientation='plus', exon_count=51, OMIM=[615950], no_hdr0=''),
    10291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10291, CurrentID=0, Status='live', Symbol='SF3A1', Aliases=['PRP21', 'PRPF21', 'SAP11420', 'SF3A1'], description='splicing factor 3a subunit 1', other_designations='splicing factor 3A subunit 1|SAP 114|pre-mRNA processing 21|pre-mRNA splicing factor SF3a (120 kDa subunit)|spliceosome-associated protein 114|splicing factor 3 subunit 1|splicing factor 3a, subunit 1, 120kD|splicing factor 3a, subunit 1, 120kDa', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30331988, end_position_on_the_genomic_accession=30356894, orientation='minus', exon_count=16, OMIM=[605595], no_hdr0=''),
    10293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10293, CurrentID=0, Status='live', Symbol='TRAIP', Aliases=['RNF206', 'SCKL9', 'TRIP'], description='TRAF interacting protein', other_designations='E3 ubiquitin-protein ligase TRAIP|RING-type E3 ubiquitin transferase TRAIP|ring finger protein 206', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49828595, end_position_on_the_genomic_accession=49856584, orientation='minus', exon_count=16, OMIM=[605958], no_hdr0=''),
    10294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10294, CurrentID=0, Status='live', Symbol='DNAJA2', Aliases=['CPR3', 'DJ3', 'DJA2', 'DNAJ', 'DNJ3', 'HIRIP4', 'PRO3015', 'RDJ2'], description='DnaJ heat shock protein family (Hsp40) member A2', other_designations='dnaJ homolog subfamily A member 2|DnaJ (Hsp40) homolog, subfamily A, member 2|HIRA interacting protein 4|cell cycle progression 3 protein|cell cycle progression restoration gene 3 protein|renal carcinoma antigen NY-REN-14', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46955362, end_position_on_the_genomic_accession=46973674, orientation='minus', exon_count=9, OMIM=[611322], no_hdr0=''),
    10295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10295, CurrentID=0, Status='live', Symbol='BCKDK', Aliases=['BCKDKD', 'BDK'], description='branched chain keto acid dehydrogenase kinase', other_designations='[3-methyl-2-oxobutanoate dehydrogenase [lipoamide]] kinase, mitochondrial|3-methyl-2-oxobutanoate dehydrogenase [lipoamide] kinase, mitochondrial|BCKD-kinase|BCKDHKIN|branched chain alpha-ketoacid dehydrogenase kinase|branched chain ketoacid dehydrogenase kinase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31108381, end_position_on_the_genomic_accession=31117651, orientation='plus', exon_count=13, OMIM=[614901], no_hdr0=''),
    10296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10296, CurrentID=0, Status='live', Symbol='MAEA', Aliases=['EMLP', 'EMP', 'GID9', 'HLC-10', 'P44EMLP', 'PIG5'], description='macrophage erythroblast attacher, E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein transferase MAEA|GID complex subunit 9, FYV10 homolog|cell proliferation-inducing gene 5 protein|erythroblast macrophage protein|human lung cancer oncogene 10 protein|lung cancer-related protein 10', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1289890, end_position_on_the_genomic_accession=1340137, orientation='plus', exon_count=13, OMIM=[606801], no_hdr0=''),
    10297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10297, CurrentID=0, Status='live', Symbol='APC2', Aliases=['APCL'], description='APC regulator of WNT signaling pathway 2', other_designations='adenomatous polyposis coli protein 2|APC2, WNT signaling pathway regulator|adenomatosis polyposis coli 2|adenomatous polyposis coli like', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1446268, end_position_on_the_genomic_accession=1473244, orientation='plus', exon_count=17, OMIM=[612034], no_hdr0=''),
    10298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10298, CurrentID=0, Status='live', Symbol='PAK4', Aliases=[], description='p21 (RAC1) activated kinase 4', other_designations='serine/threonine-protein kinase PAK 4|p21 protein (Cdc42/Rac)-activated kinase 4|p21(CDKN1A)-activated kinase 4|protein kinase related to S. cerevisiae STE20, effector for Cdc42Hs', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39125786, end_position_on_the_genomic_accession=39182816, orientation='plus', exon_count=14, OMIM=[605451], no_hdr0=''),
    10299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10299, CurrentID=0, Status='live', Symbol='MARCHF6', Aliases=['DOA10', 'FAME3', 'MARCH-VI', 'MARCH6', 'RNF176', 'TEB4'], description='membrane associated ring-CH-type finger 6', other_designations='E3 ubiquitin-protein ligase MARCHF6|E3 ubiquitin-protein ligase MARCH6|RING finger protein 176|RING-type E3 ubiquitin transferase MARCH6|RING-type E3 ubiquitin transferase MARCHF6|doa10 homolog|membrane associated ring finger 6|membrane-associated RING finger protein 6|membrane-associated RING-CH finger protein 6|membrane-associated RING-CH protein VI|membrane-associated ring finger (C3HC4) 6, E3 ubiquitin protein ligase', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10353693, end_position_on_the_genomic_accession=10440388, orientation='plus', exon_count=31, OMIM=[613297], no_hdr0=''),
    10300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10300, CurrentID=0, Status='live', Symbol='KATNB1', Aliases=['KAT', 'LIS6'], description='katanin regulatory subunit B1', other_designations='katanin p80 WD40 repeat-containing subunit B1|katanin (80 kDa)|katanin p80 (WD repeat containing) subunit B 1|katanin p80 (WD40-containing) subunit B 1|katanin p80 WD40-containing subunit B1|katanin p80 subunit B1|p80 katanin', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57735770, end_position_on_the_genomic_accession=57757244, orientation='plus', exon_count=20, OMIM=[602703], no_hdr0=''),
    10302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10302, CurrentID=0, Status='live', Symbol='SNAPC5', Aliases=['SNAP19'], description='small nuclear RNA activating complex polypeptide 5', other_designations='snRNA-activating protein complex subunit 5|SNAPc 19 kDa subunit|SNAPc subunit 5|snRNA-activating protein complex 19 kDa subunit', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66489748, end_position_on_the_genomic_accession=66497762, orientation='minus', exon_count=4, OMIM=[605979], no_hdr0=''),
    10307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10307, CurrentID=0, Status='live', Symbol='APBB3', Aliases=['FE65L2', 'SRA'], description='amyloid beta precursor protein binding family B member 3', other_designations='amyloid-beta A4 precursor protein-binding family B member 3|FE65-like protein 2|amyloid beta (A4) precursor protein-binding, family B, member 3|amyloid precursor interacting protein|protein Fe65-like 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140558268, end_position_on_the_genomic_accession=140564598, orientation='minus', exon_count=13, OMIM=[602711], no_hdr0=''),
    10308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10308, CurrentID=0, Status='live', Symbol='ZNF267', Aliases=['HZF2'], description='zinc finger protein 267', other_designations='zinc finger protein 267|zinc finger (C2H2)|zinc finger protein 2|zinc finger protein HZF2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31873807, end_position_on_the_genomic_accession=31917357, orientation='plus', exon_count=6, OMIM=[604752], no_hdr0=''),
    10309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10309, CurrentID=0, Status='live', Symbol='CCNO', Aliases=['CCNU', 'CILD29', 'UDG2'], description='cyclin O', other_designations='cyclin-O|cyclin U|cyclin domain containing', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55231152, end_position_on_the_genomic_accession=55233608, orientation='minus', exon_count=3, OMIM=[607752], no_hdr0=''),
    10311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10311, CurrentID=0, Status='live', Symbol='VPS26C', Aliases=['DCRA', 'DSCR3', 'DSCRA'], description='VPS26 endosomal protein sorting factor C', other_designations='vacuolar protein sorting-associated protein 26C|DSCR3 arrestin fold containing|Down syndrome critical region 3|Down syndrome critical region gene 3|Down syndrome critical region protein 3|Down syndrome critical region protein A', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37223420, end_position_on_the_genomic_accession=37268108, orientation='minus', exon_count=8, OMIM=[605298], no_hdr0=''),
    10312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10312, CurrentID=0, Status='live', Symbol='TCIRG1', Aliases=['ATP6N1C', 'ATP6V0A3', 'Atp6i', 'OC-116kDa', 'OC116', 'OPTB1', 'Stv1', 'TIRC7', 'Vph1', 'a3'], description='T cell immune regulator 1, ATPase H+ transporting V0 subunit a3', other_designations='V-type proton ATPase 116 kDa subunit a3|ATPase, H+ transporting, 116kD|T-cell immune response cDNA 7|T-cell, immune regulator 1, ATPase, H+ transporting, lysosomal V0 protein a|T-cell, immune regulator 1, ATPase, H+ transporting, lysosomal V0 subunit A3|V-ATPase 116 kDa subunit a3|V-ATPase 116-kDa|V-ATPase subunit a3|V-type proton ATPase 116 kDa subunit a|osteoclastic proton pump 116 kDa subunit|specific 116-kDa vacuolar proton pump subunit|vacuolar proton translocating ATPase 116 kDa subunit A', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68039000, end_position_on_the_genomic_accession=68053846, orientation='plus', exon_count=22, OMIM=[604592], no_hdr0=''),
    10313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10313, CurrentID=0, Status='live', Symbol='RTN3', Aliases=['ASYIP', 'HAP', 'NSPL2', 'NSPLII-A1', 'RTN3'], description='reticulon 3', other_designations='reticulon-3|ASY interacting protein|NSP-like protein 2|NSP-like protein II|homolog of ASY protein|neuroendocrine-specific protein-like 2|neuroendocrine-specific protein-like II', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63681315, end_position_on_the_genomic_accession=63759891, orientation='plus', exon_count=11, OMIM=[604249], no_hdr0=''),
    10314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10314, CurrentID=0, Status='live', Symbol='LANCL1', Aliases=['GPR69A', 'p40'], description='LanC like 1', other_designations='glutathione S-transferase LANCL1|40 kDa erythrocyte membrane protein|G protein-coupled receptor 69A|LanC (bacterial lantibiotic synthetase component C)-like 1|LanC (bacterial lantibiotic synthetase component)|LanC lantibiotic synthetase component C-like 1|lanC-like protein 1', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210431251, end_position_on_the_genomic_accession=210477618, orientation='minus', exon_count=11, OMIM=[604155], no_hdr0=''),
    10316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10316, CurrentID=0, Status='live', Symbol='NMUR1', Aliases=['(FM-3)', 'FM-3', 'FM3', 'GPC-R', 'GPR66', 'NMU1R'], description='neuromedin U receptor 1', other_designations='neuromedin-U receptor 1|G-protein coupled receptor 66|G-protein coupled receptor FM-3|NMU-R1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231519903, end_position_on_the_genomic_accession=231530456, orientation='minus', exon_count=5, OMIM=[604153], no_hdr0=''),
    10317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10317, CurrentID=0, Status='live', Symbol='B3GALT5', Aliases=['B3GalT-V', 'B3GalTx', 'B3T5', 'GLCT5', 'beta-1', '3-GalTase 5', 'beta-3-Gx-T5', 'beta3Gal-T5'], description='beta-1,3-galactosyltransferase 5', other_designations='beta-1,3-galactosyltransferase 5|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 5|UDP-galactose:beta-N-acetylglucosamine beta-1,3-galactosyltransferase 5|homolog of C. elegans Bt toxin resistance gene bre-5', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39612940, end_position_on_the_genomic_accession=39673137, orientation='plus', exon_count=7, OMIM=[604066], no_hdr0=''),
    10318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10318, CurrentID=0, Status='live', Symbol='TNIP1', Aliases=['ABIN-1', 'NAF1', 'VAN', 'nip40-1'], description='TNFAIP3 interacting protein 1', other_designations='TNFAIP3-interacting protein 1|A20-binding inhibitor of NF-kappa-B activation 1|HIV-1 Nef-interacting protein|Nef-associated factor 1 SNP|virion-associated nuclear shuttling protein', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151029943, end_position_on_the_genomic_accession=151087685, orientation='minus', exon_count=22, OMIM=[607714], no_hdr0=''),
    10319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10319, CurrentID=0, Status='live', Symbol='LAMC3', Aliases=['OCCM'], description='laminin subunit gamma 3', other_designations='laminin subunit gamma-3|laminin, gamma 3|laminin-12 subunit gamma|laminin-14 subunit gamma|laminin-15 subunit gamma', map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131009174, end_position_on_the_genomic_accession=131094473, orientation='plus', exon_count=29, OMIM=[604349], no_hdr0=''),
    10320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10320, CurrentID=0, Status='live', Symbol='IKZF1', Aliases=['CVID13', 'Hs.54452', 'IK1', 'IKAROS', 'LYF1', 'LyF-1', 'PPP1R92', 'PRO0758', 'ZNFN1A1'], description='IKAROS family zinc finger 1', other_designations='DNA-binding protein Ikaros|CLL-associated antigen KW-6|ikaros family zinc finger protein 1|lymphoid transcription factor LyF-1|protein phosphatase 1, regulatory subunit 92|zinc finger protein, subfamily 1A, 1 (Ikaros)', map_location='7p12.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=50303453, end_position_on_the_genomic_accession=50405101, orientation='plus', exon_count=15, OMIM=[603023], no_hdr0=''),
    10321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10321, CurrentID=0, Status='live', Symbol='CRISP3', Aliases=['Aeg2', 'CRISP-3', 'CRS3', 'SGP28', 'dJ442L6.3'], description='cysteine rich secretory protein 3', other_designations='cysteine-rich secretory protein 3|specific granule protein (28 kDa)', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49727376, end_position_on_the_genomic_accession=49744388, orientation='minus', exon_count=8, OMIM=[618062], no_hdr0=''),
    10322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10322, CurrentID=0, Status='live', Symbol='SMYD5', Aliases=['NN8-4AG', 'RAI15', 'RRG1', 'ZMYND23'], description='SMYD family member 5', other_designations='SET and MYND domain-containing protein 5|retinoic acid induced 15|retinoic acid responsive|retinoic acid-induced protein 15', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73214245, end_position_on_the_genomic_accession=73227221, orientation='plus', exon_count=13, OMIM=[619114], no_hdr0=''),
    10324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10324, CurrentID=0, Status='live', Symbol='KLHL41', Aliases=['KBTBD10', 'Krp1', 'SARCOSIN'], description='kelch like family member 41', other_designations='kelch-like protein 41|kel-like protein 23|kelch repeat and BTB (POZ) domain containing 10|kelch-related protein 1|sarcomeric muscle protein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169509702, end_position_on_the_genomic_accession=169526258, orientation='plus', exon_count=6, OMIM=[607701], no_hdr0=''),
    10325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10325, CurrentID=0, Status='live', Symbol='RRAGB', Aliases=['RAGB', 'bA465E19.1'], description='Ras related GTP binding B', other_designations='ras-related GTP-binding protein B|GTP-binding protein ragB|rag B', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55717747, end_position_on_the_genomic_accession=55760209, orientation='plus', exon_count=12, OMIM=[300725], no_hdr0=''),
    10326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10326, CurrentID=0, Status='live', Symbol='SIRPB1', Aliases=['CD172b', 'SIRP-BETA-1'], description='signal regulatory protein beta 1', other_designations='signal-regulatory protein beta-1|CD172 antigen-like family member B', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1561385, end_position_on_the_genomic_accession=1620447, orientation='minus', exon_count=15, OMIM=[603889], no_hdr0=''),
    10327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10327, CurrentID=0, Status='live', Symbol='AKR1A1', Aliases=['ALDR1', 'ALR', 'ARM', 'DD3', 'HEL-S-6'], description='aldo-keto reductase family 1 member A1', other_designations='aldo-keto reductase family 1 member A1|HEL-S-165mP|alcohol dehydrogenase|aldehyde reductase|dihydrodiol dehydrogenase 3|epididymis secretory protein Li 6|epididymis secretory sperm binding protein Li 165mP|glucuronate reductase|glucuronolactone reductase', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45550779, end_position_on_the_genomic_accession=45570051, orientation='plus', exon_count=11, OMIM=[103830], no_hdr0=''),
    10328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10328, CurrentID=0, Status='live', Symbol='EMC8', Aliases=['C16orf2', 'C16orf4', 'COX4NB', 'FAM158B', 'NOC4'], description='ER membrane protein complex subunit 8', other_designations='ER membrane protein complex subunit 8|COX4 neighbor|family with sequence similarity 158, member B|neighbor of COX4', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85778624, end_position_on_the_genomic_accession=85799555, orientation='minus', exon_count=8, OMIM=[604886], no_hdr0=''),
    10329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10329, CurrentID=0, Status='live', Symbol='RXYLT1', Aliases=['HP10481', 'MDDGA10', 'TMEM5'], description='ribitol xylosyltransferase 1', other_designations='ribitol-5-phosphate xylosyltransferase 1|UDP-D-xylose:ribitol-5-phosphate beta1,4-xylosyltransferase|transmembrane protein 5|type II membrane protein', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=63779831, end_position_on_the_genomic_accession=63809562, orientation='plus', exon_count=8, OMIM=[605862], no_hdr0=''),
    10330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10330, CurrentID=0, Status='live', Symbol='CNPY2', Aliases=['HP10390', 'MSAP', 'TMEM4', 'ZSIG9'], description='canopy FGF signaling regulator 2', other_designations='protein canopy homolog 2|MIR-interacting saposin-like protein|putative secreted protein Zsig9|transmembrane protein 4', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56309844, end_position_on_the_genomic_accession=56316346, orientation='minus', exon_count=6, OMIM=[605861], no_hdr0=''),
    10331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10331, CurrentID=0, Status='live', Symbol='B3GNT3', Aliases=['B3GAL-T8', 'B3GN-T3', 'B3GNT-3', 'HP10328', 'TMEM3', 'beta3Gn-T3'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 3', other_designations='N-acetyllactosaminide beta-1,3-N-acetylglucosaminyltransferase 3|UDP-Gal:beta-GlcNAc beta-1,3-galactosyltransferase 8|UDP-galactose:beta-N-acetylglucosamine beta-1,3-galactosyltransferase 8|beta-1,3-GalTase 8|beta-1,3-Gn-T3|beta-1,3-N-acetylglucosaminyltransferase bGnT-3|beta-1,3-galactosyl-O-glycosyl-glycoprotein beta-1,3-N-acetylglucosaminyltransferase|beta-3-Gx-T8|beta3GalT8|core 1 extending beta-1,3-N-acetylglucosaminyltransferase|core1-beta3GlcNAcT|putative type II membrane protein|transmembrane protein 3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17794828, end_position_on_the_genomic_accession=17813576, orientation='plus', exon_count=4, OMIM=[605863], no_hdr0=''),
    10332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10332, CurrentID=0, Status='live', Symbol='CLEC4M', Aliases=['CD209L', 'CD299', 'DC-SIGN2', 'DC-SIGNR', 'DCSIGNR', 'HP10347', 'L-SIGN', 'LSIGN'], description='C-type lectin domain family 4 member M', other_designations='C-type lectin domain family 4 member M|CD209 antigen-like protein 1|CD299 antigen|DC-SIGN-related protein|dendritic cell-specific ICAM-3-grabbing non-integrin 2|liver/lymph node-specific ICAM-3 grabbing non-integrin|mannose binding C-type lectin DC-SIGNR', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7763243, end_position_on_the_genomic_accession=7769605, orientation='plus', exon_count=8, OMIM=[605872], no_hdr0=''),
    10333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10333, CurrentID=0, Status='live', Symbol='TLR6', Aliases=['CD286'], description='toll like receptor 6', other_designations='toll-like receptor 6', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38822897, end_position_on_the_genomic_accession=38857755, orientation='minus', exon_count=6, OMIM=[605403], no_hdr0=''),
    10335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10335, CurrentID=0, Status='live', Symbol='IRAG1', Aliases=['IRAG', 'JAW1L', 'MRVI1'], description='inositol 1,4,5-triphosphate receptor associated 1', other_designations='inositol 1,4,5-triphosphate receptor associated 1|IP3R-associated cGMP kinase substrate|JAW1-related protein MRVI1|inositol 1,4,5-triphosphate receptor-associated cGMP kinase substrate|inositol 1,4,5-trisphosphate receptor-associated cGMP kinase substrate|murine retrovirus integration site 1 homolog', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10573095, end_position_on_the_genomic_accession=10693755, orientation='minus', exon_count=22, OMIM=[604673], no_hdr0=''),
    10336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10336, CurrentID=0, Status='live', Symbol='PCGF3', Aliases=['DONG1', 'RNF3', 'RNF3A'], description='polycomb group ring finger 3', other_designations='polycomb group RING finger protein 3|RING finger protein 3A|ring finger protein 3', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=705832, end_position_on_the_genomic_accession=770980, orientation='plus', exon_count=12, OMIM=[617543], no_hdr0=''),
    10342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10342, CurrentID=0, Status='live', Symbol='TFG', Aliases=['HMSNP', 'SPG57', 'TF6', 'TRKT3'], description='trafficking from ER to golgi regulator', other_designations='protein TFG|TRK-fused|TRK-fused gene protein|TRKT3 oncogene', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100709290, end_position_on_the_genomic_accession=100748967, orientation='plus', exon_count=10, OMIM=[602498], no_hdr0=''),
    10343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10343, CurrentID=0, Status='live', Symbol='PKDREJ', Aliases=[], description='polycystin family receptor for egg jelly', other_designations='polycystic kidney disease and receptor for egg jelly-related protein|PKD and REJ homolog|polycystic kidney disease (polycystin) and REJ homolog (sperm receptor for egg jelly homolog, sea urchin)|polycystin (PKD) family receptor for egg jelly', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46255663, end_position_on_the_genomic_accession=46263343, orientation='minus', exon_count=1, OMIM=[604670], no_hdr0=''),
    10344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10344, CurrentID=0, Status='live', Symbol='CCL26', Aliases=['IMAC', 'MIP-4a', 'MIP-4alpha', 'SCYA26', 'TSC-1'], description='C-C motif chemokine ligand 26', other_designations='C-C motif chemokine 26|CC chemokine IMAC|MIP-4-alpha|chemokine (C-C motif) ligand 26|chemokine N1|eotaxin-3|macrophage inflammatory protein 4-alpha|small inducible cytokine A26|small inducible cytokine subfamily A (Cys-Cys), member 26|thymic stroma chemokine-1', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75769524, end_position_on_the_genomic_accession=75791597, orientation='minus', exon_count=5, OMIM=[604697], no_hdr0=''),
    10345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10345, CurrentID=0, Status='live', Symbol='TRDN', Aliases=['CPVT5', 'TDN', 'TRISK'], description='triadin', other_designations='triadin|triadin in skeletal muscle', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=123216339, end_position_on_the_genomic_accession=123636950, orientation='minus', exon_count=42, OMIM=[603283], no_hdr0=''),
    10346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10346, CurrentID=0, Status='live', Symbol='TRIM22', Aliases=['GPSTAF50', 'RNF94', 'STAF50'], description='tripartite motif containing 22', other_designations='E3 ubiquitin-protein ligase TRIM22|50 kDa-stimulated trans-acting factor|RING finger protein 94|RING-type E3 ubiquitin transferase TRIM22|staf-50|stimulated trans-acting factor (50 kDa)|tripartite binding motif 22|tripartite motif protein TRIM22|tripartite motif-containing protein 22', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5689790, end_position_on_the_genomic_accession=5710863, orientation='plus', exon_count=8, OMIM=[606559], no_hdr0=''),
    10347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10347, CurrentID=0, Status='live', Symbol='ABCA7', Aliases=['ABCA-SSN', 'ABCX', 'AD9'], description='ATP binding cassette subfamily A member 7', other_designations='phospholipid-transporting ATPase ABCA7|ATP-binding cassette sub-family A member 7|ATP-binding cassette, sub-family A (ABC1), member 7|autoantigen SS-N|macrophage ABC transporter', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1040107, end_position_on_the_genomic_accession=1065572, orientation='plus', exon_count=47, OMIM=[605414], no_hdr0=''),
    10349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10349, CurrentID=0, Status='live', Symbol='ABCA10', Aliases=['EST698739'], description='ATP binding cassette subfamily A member 10', other_designations='ATP-binding cassette sub-family A member 10|ATP-binding cassette A10|ATP-binding cassette, sub-family A (ABC1), member 10', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=69148007, end_position_on_the_genomic_accession=69244848, orientation='minus', exon_count=40, OMIM=[612508], no_hdr0=''),
    10350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10350, CurrentID=0, Status='live', Symbol='ABCA9', Aliases=['EST640918'], description='ATP binding cassette subfamily A member 9', other_designations='ATP-binding cassette sub-family A member 9|ATP-binding cassette A9|ATP-binding cassette, sub-family A (ABC1), member 9', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68974488, end_position_on_the_genomic_accession=69078978, orientation='minus', exon_count=42, OMIM=[612507], no_hdr0=''),
    10351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10351, CurrentID=0, Status='live', Symbol='ABCA8', Aliases=[], description='ATP binding cassette subfamily A member 8', other_designations='ABC-type organic anion transporter ABCA8|ATP-binding cassette, sub-family A (ABC1), member 8', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68867285, end_position_on_the_genomic_accession=68955415, orientation='minus', exon_count=40, OMIM=[612505], no_hdr0=''),
    10352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10352, CurrentID=0, Status='live', Symbol='WARS2', Aliases=['NEMMLAS', 'TrpRS', 'mtTrpRS'], description='tryptophanyl tRNA synthetase 2, mitochondrial', other_designations='tryptophan--tRNA ligase, mitochondrial|(Mt)TrpRS|tryptophan tRNA ligase 2, mitochondrial', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119031216, end_position_on_the_genomic_accession=119140788, orientation='minus', exon_count=8, OMIM=[604733], no_hdr0=''),
    10360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10360, CurrentID=0, Status='live', Symbol='NPM3', Aliases=['PORMIN', 'TMEM123'], description='nucleophosmin/nucleoplasmin 3', other_designations='nucleoplasmin-3|nucleophosmin/nucleoplasmin family, member 3', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101781325, end_position_on_the_genomic_accession=101783413, orientation='minus', exon_count=6, OMIM=[606456], no_hdr0=''),
    10361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10361, CurrentID=0, Status='live', Symbol='NPM2', Aliases=[], description='nucleophosmin/nucleoplasmin 2', other_designations='nucleoplasmin-2', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22023308, end_position_on_the_genomic_accession=22036908, orientation='plus', exon_count=11, OMIM=[608073], no_hdr0=''),
    10362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10362, CurrentID=0, Status='live', Symbol='HMG20B', Aliases=['BRAF25', 'BRAF35', 'HMGX2', 'HMGXB2', 'PP7706', 'SMARCE1r', 'SOXL', 'pp8857'], description='high mobility group 20B', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily E member 1-related|BRCA2-associated factor 35|HMG box domain containing 2|HMG box-containing protein 20B|HMG domain-containing protein 2|HMG domain-containing protein HMGX2|SMARCE1-related protein|SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily E, member 1-related|Sox-like transcriptional factor|structural DNA-binding protein BRAF35', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3572916, end_position_on_the_genomic_accession=3579083, orientation='plus', exon_count=10, OMIM=[605535], no_hdr0=''),
    10363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10363, CurrentID=0, Status='live', Symbol='HMG20A', Aliases=['HMGX1', 'HMGXB1'], description='high mobility group 20A', other_designations='high mobility group protein 20A|HMG box domain containing 1|HMG box-containing protein 20A|HMG domain-containing protein 1|HMG domain-containing protein HMGX1', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=77420705, end_position_on_the_genomic_accession=77519899, orientation='plus', exon_count=13, OMIM=[605534], no_hdr0=''),
    10365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10365, CurrentID=0, Status='live', Symbol='KLF2', Aliases=['LKLF'], description='Kruppel like factor 2', other_designations='Krueppel-like factor 2|Kruppel-like factor 2 (lung)|Kruppel-like factor LKLF|lung Kruppel-like factor|lung Kruppel-like zinc finger transcription factor|lung krueppel-like factor', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16324826, end_position_on_the_genomic_accession=16328685, orientation='plus', exon_count=3, OMIM=[602016], no_hdr0=''),
    10367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10367, CurrentID=0, Status='live', Symbol='MICU1', Aliases=['CALC', 'CBARA1', 'EFHA3', 'MPXPS', 'ara CALC'], description='mitochondrial calcium uptake 1', other_designations='calcium uptake protein 1, mitochondrial|atopy-related autoantigen CALC|calcium-binding atopy-related autoantigen 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72367339, end_position_on_the_genomic_accession=72626096, orientation='minus', exon_count=17, OMIM=[605084], no_hdr0=''),
    10368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10368, CurrentID=0, Status='live', Symbol='CACNG3', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 3', other_designations='voltage-dependent calcium channel gamma-3 subunit|TARP gamma-3|calcium channel, voltage-dependent, gamma subunit 3|neuronal voltage-gated calcium channel gamma-3 subunit|transmembrane AMPAR regulatory protein gamma-3|voltage-gated calcium channel gamma subunit', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=24256335, end_position_on_the_genomic_accession=24362412, orientation='plus', exon_count=4, OMIM=[606403], no_hdr0=''),
    10369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10369, CurrentID=0, Status='live', Symbol='CACNG2', Aliases=['MRD10'], description='calcium voltage-gated channel auxiliary subunit gamma 2', other_designations='voltage-dependent calcium channel gamma-2 subunit|TARP gamma-2|neuronal voltage-gated calcium channel gamma-2 subunit|stargazin|transmembrane AMPAR regulatory protein gamma-2', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36560857, end_position_on_the_genomic_accession=36703752, orientation='minus', exon_count=6, OMIM=[602911], no_hdr0=''),
    10370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10370, CurrentID=0, Status='live', Symbol='CITED2', Aliases=['ASD8', 'MRG-1', 'MRG1', 'P35SRJ', 'VSD2'], description='Cbp/p300 interacting transactivator with Glu/Asp rich carboxy-terminal domain 2', other_designations='cbp/p300-interacting transactivator 2|MSG-related protein 1|MSG1-related gene 1|melanocyte-specific gene 1-related gene 1', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=139371807, end_position_on_the_genomic_accession=139374648, orientation='minus', exon_count=4, OMIM=[602937], no_hdr0=''),
    10371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10371, CurrentID=0, Status='live', Symbol='SEMA3A', Aliases=['COLL1', 'HH16', 'Hsema-I', 'Hsema-III', 'SEMA1', 'SEMAD', 'SEMAIII', 'SEMAL', 'SemD', 'coll-1'], description='semaphorin 3A', other_designations='semaphorin-3A|collapsin 1|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3A|semaphorin D|semaphorin III|semaphorin L', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=83955777, end_position_on_the_genomic_accession=84515189, orientation='minus', exon_count=25, OMIM=[603961], no_hdr0=''),
    10376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10376, CurrentID=0, Status='live', Symbol='TUBA1B', Aliases=['K-ALPHA-1'], description='tubulin alpha 1b', other_designations='tubulin alpha-1B chain|alpha tubulin|alpha-tubulin ubiquitous|tubulin K-alpha-1|tubulin alpha-ubiquitous chain|tubulin, alpha, ubiquitous', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49127782, end_position_on_the_genomic_accession=49131395, orientation='minus', exon_count=4, OMIM=[602530], no_hdr0=''),
    10379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10379, CurrentID=0, Status='live', Symbol='IRF9', Aliases=['IRF-9', 'ISGF3', 'ISGF3G', 'p48'], description='interferon regulatory factor 9', other_designations='interferon regulatory factor 9|IFN-alpha-responsive transcription factor subunit|ISGF-3 gamma|ISGF3 p48 subunit|interferon-stimulated gene factor 3 gamma|interferon-stimulated transcription factor 3, gamma (48kD)|interferon-stimulated transcription factor 3, gamma 48kDa|transcriptional regulator ISGF3 subunit gamma', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24161265, end_position_on_the_genomic_accession=24166565, orientation='plus', exon_count=10, OMIM=[147574], no_hdr0=''),
    10380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10380, CurrentID=0, Status='live', Symbol='BPNT1', Aliases=['HEL20', 'PIP'], description="3'(2'), 5'-bisphosphate nucleotidase 1", other_designations="3'(2'),5'-bisphosphate nucleotidase 1|BPntase|PAP-inositol-1,4-phosphatase|bisphosphate 3'-nucleotidase 1|epididymis luminal protein 20|testicular tissue protein Li 29", map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220057482, end_position_on_the_genomic_accession=220089916, orientation='minus', exon_count=11, OMIM=[604053], no_hdr0=''),
    10381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10381, CurrentID=0, Status='live', Symbol='TUBB3', Aliases=['CDCBM', 'CDCBM1', 'CFEOM3', 'CFEOM3A', 'FEOM3', 'TUBB4', 'beta-4'], description='tubulin beta 3 class III', other_designations='tubulin beta-3 chain|class III beta-tubulin|tubulin beta-4 chain|tubulin beta-III|tubulin, beta 3', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89921925, end_position_on_the_genomic_accession=89936097, orientation='plus', exon_count=5, OMIM=[602661], no_hdr0=''),
    10382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10382, CurrentID=0, Status='live', Symbol='TUBB4A', Aliases=['DYT4', 'TUBB4', 'beta-5'], description='tubulin beta 4A class IVa', other_designations='tubulin beta-4A chain|dystonia 4, torsion (autosomal dominant)|tubulin beta-4 chain|tubulin, beta 4|tubulin, beta, 5', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6494319, end_position_on_the_genomic_accession=6502848, orientation='minus', exon_count=5, OMIM=[602662], no_hdr0=''),
    10383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10383, CurrentID=0, Status='live', Symbol='TUBB4B', Aliases=['Beta2', 'LCAEOD', 'TUBB2', 'TUBB2C'], description='tubulin beta 4B class IVb', other_designations='tubulin beta-4B chain|class IVb beta tubulin|epididymis secretory sperm binding protein|tubulin beta-2 chain|tubulin beta-2C chain|tubulin, beta 2C|tubulin, beta, 2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137241287, end_position_on_the_genomic_accession=137243707, orientation='plus', exon_count=4, OMIM=[602660], no_hdr0=''),
    10384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10384, CurrentID=0, Status='live', Symbol='BTN3A3', Aliases=['BTF3', 'BTN3.3'], description='butyrophilin subfamily 3 member A3', other_designations='butyrophilin subfamily 3 member A3|butyrophilin 3', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26440504, end_position_on_the_genomic_accession=26453415, orientation='plus', exon_count=11, OMIM=[613595], no_hdr0=''),
    10385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10385, CurrentID=0, Status='live', Symbol='BTN2A2', Aliases=['BT2.2', 'BTF2', 'BTN2.2'], description='butyrophilin subfamily 2 member A2', other_designations='butyrophilin subfamily 2 member A2|butyrophilin 2', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26382893, end_position_on_the_genomic_accession=26394874, orientation='plus', exon_count=9, OMIM=[613591], no_hdr0=''),
    10388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10388, CurrentID=0, Status='live', Symbol='SYCP2', Aliases=['SCP-2', 'SCP2', 'SPGF1'], description='synaptonemal complex protein 2', other_designations='synaptonemal complex protein 2|synaptonemal complex lateral element protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59863277, end_position_on_the_genomic_accession=59933700, orientation='minus', exon_count=47, OMIM=[604105], no_hdr0=''),
    10389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10389, CurrentID=0, Status='live', Symbol='SCML2', Aliases=[], description='Scm polycomb group protein like 2', other_designations='sex comb on midleg-like protein 2|sex comb on midleg like 2', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18239313, end_position_on_the_genomic_accession=18355089, orientation='minus', exon_count=19, OMIM=[300208], no_hdr0=''),
    10390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10390, CurrentID=0, Status='live', Symbol='CEPT1', Aliases=[], description='choline/ethanolamine phosphotransferase 1', other_designations='choline/ethanolaminephosphotransferase 1|1-alkenyl-2-acylglycerol choline phosphotransferase', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111139436, end_position_on_the_genomic_accession=111185104, orientation='plus', exon_count=13, OMIM=[616751], no_hdr0=''),
    10391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10391, CurrentID=0, Status='live', Symbol='CORO2B', Aliases=['CLIPINC'], description='coronin 2B', other_designations='coronin-2B|clipin C|coronin, actin binding protein, 2B|coronin-like protein C', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68518373, end_position_on_the_genomic_accession=68727806, orientation='plus', exon_count=17, OMIM=[605002], no_hdr0=''),
    10392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10392, CurrentID=0, Status='live', Symbol='NOD1', Aliases=['CARD4', 'CLR7.1', 'NLRC1'], description='nucleotide binding oligomerization domain containing 1', other_designations='nucleotide-binding oligomerization domain-containing protein 1|NLR family, CARD domain containing 1|caspase recruitment domain family, member 4|caspase recruitment domain-containing protein 4|nucleotide-binding oligomerization domain, leucine rich repeat and CARD domain containing 1', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30424527, end_position_on_the_genomic_accession=30478840, orientation='minus', exon_count=19, OMIM=[605980], no_hdr0=''),
    10393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10393, CurrentID=0, Status='live', Symbol='ANAPC10', Aliases=['APC10', 'DOC1'], description='anaphase promoting complex subunit 10', other_designations='anaphase-promoting complex subunit 10|cyclosome subunit 10', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=144967117, end_position_on_the_genomic_accession=145098571, orientation='minus', exon_count=12, OMIM=[613745], no_hdr0=''),
    10394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10394, CurrentID=0, Status='live', Symbol='PRG3', Aliases=['MBP2', 'MBPH'], description='proteoglycan 3, pro eosinophil major basic protein 2', other_designations='proteoglycan 3|eosinophil major basic protein homolog|prepro-MBPH|prepro-major basic protein homolog', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57376769, end_position_on_the_genomic_accession=57381150, orientation='minus', exon_count=6, OMIM=[606814], no_hdr0=''),
    10395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10395, CurrentID=0, Status='live', Symbol='DLC1', Aliases=['ARHGAP7', 'HP', 'STARD12', 'p122-RhoGAP'], description='DLC1 Rho GTPase activating protein', other_designations='rho GTPase-activating protein 7|Rho-GTPase-activating protein 7|START domain-containing protein 12|StAR-related lipid transfer (START) domain containing 12|deleted in liver cancer 1 protein|deleted in liver cancer 1 variant 2|deleted in liver cancer variant 4|epididymis secretory sperm binding protein|rho-type GTPase-activating protein 7', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=13083361, end_position_on_the_genomic_accession=13604620, orientation='minus', exon_count=24, OMIM=[604258], no_hdr0=''),
    10396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10396, CurrentID=0, Status='live', Symbol='ATP8A1', Aliases=['ATPASEII', 'ATPIA', 'ATPP2'], description='ATPase phospholipid transporting 8A1', other_designations='phospholipid-transporting ATPase IA|ATPase II|ATPase class I type 8A member 1|ATPase, aminophospholipid transporter (APLT), class I, type 8A, member 1|P4-ATPase flippase complex alpha subunit ATP8A1|aminophospholipid translocase|chromaffin granule ATPase II|probable phospholipid-transporting ATPase IA', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=42408373, end_position_on_the_genomic_accession=42657105, orientation='minus', exon_count=39, OMIM=[609542], no_hdr0=''),
    10397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10397, CurrentID=0, Status='live', Symbol='NDRG1', Aliases=['CAP43', 'CMT4D', 'DRG-1', 'DRG1', 'GC4', 'HMSNL', 'NDR1', 'NMSL', 'PROXY1', 'RIT42', 'RTP', 'TARG1', 'TDD5'], description='N-myc downstream regulated 1', other_designations='protein NDRG1|N-myc downstream-regulated gene 1 protein|differentiation-related gene 1 protein|nickel-specific induction protein Cap43|protein regulated by oxygen-1|reducing agents and tunicamycin-responsive protein', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=133237175, end_position_on_the_genomic_accession=133297252, orientation='minus', exon_count=18, OMIM=[605262], no_hdr0=''),
    10398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10398, CurrentID=0, Status='live', Symbol='MYL9', Aliases=['LC20', 'MLC-2C', 'MLC2', 'MMIHS4', 'MRLC1', 'MYRL2'], description='myosin light chain 9', other_designations='myosin regulatory light polypeptide 9|20 kDa myosin light chain|epididymis secretory sperm binding protein|myosin RLC|myosin regulatory light chain 1|myosin regulatory light chain 9|myosin regulatory light chain MRLC1|myosin, light chain 9, regulatory|myosin, light polypeptide 9, regulatory', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36541519, end_position_on_the_genomic_accession=36551447, orientation='plus', exon_count=4, OMIM=[609905], no_hdr0=''),
    10399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10399, CurrentID=0, Status='live', Symbol='RACK1', Aliases=['GNB2L1', 'Gnb2-rs1', 'H12.3', 'HLC-7', 'PIG21'], description='receptor for activated C kinase 1', other_designations='receptor of activated protein C kinase 1|cell proliferation-inducing gene 21 protein|guanine nucleotide binding protein (G protein), beta polypeptide 2-like 1|guanine nucleotide binding protein beta polypeptide 2-like 1|guanine nucleotide-binding protein subunit beta-2-like 1|guanine nucleotide-binding protein subunit beta-like protein 12.3|human lung cancer oncogene 7 protein|lung cancer oncogene 7|proliferation-inducing gene 21|protein homologous to chicken B complex protein, guanine nucleotide binding|receptor of activated protein kinase C 1|small ribosomal subunit protein RACK1', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181236897, end_position_on_the_genomic_accession=181243906, orientation='minus', exon_count=8, OMIM=[176981], no_hdr0=''),
    10400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10400, CurrentID=0, Status='live', Symbol='PEMT', Aliases=['PEAMT', 'PEMPT2', 'PLMT', 'PNMT', 'PEMT'], description='phosphatidylethanolamine N-methyltransferase', other_designations='phosphatidylethanolamine N-methyltransferase|phospholipid methyltransferase', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17505561, end_position_on_the_genomic_accession=17591987, orientation='minus', exon_count=13, OMIM=[602391], no_hdr0=''),
    10401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10401, CurrentID=0, Status='live', Symbol='PIAS3', Aliases=['ZMIZ5'], description='protein inhibitor of activated STAT 3', other_designations='E3 SUMO-protein ligase PIAS3|E3 SUMO-protein transferase PIAS3|protein inhibitor of activated STAT protein 3|zinc finger, MIZ-type containing 5', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145848522, end_position_on_the_genomic_accession=145859081, orientation='minus', exon_count=14, OMIM=[605987], no_hdr0=''),
    10402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10402, CurrentID=0, Status='live', Symbol='ST3GAL6', Aliases=['SIAT10', 'ST3GALVI'], description='ST3 beta-galactoside alpha-2,3-sialyltransferase 6', other_designations='type 2 lactosamine alpha-2,3-sialyltransferase|CMP-NeuAc:beta-galactoside alpha-2,3-sialyltransferase VI|alpha2,3-sialyltransferase ST3Gal VI|sialyltransferase 10 (alpha-2,3-sialyltransferase VI)', map_location='3q12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98732262, end_position_on_the_genomic_accession=98795852, orientation='plus', exon_count=16, OMIM=[607156], no_hdr0=''),
    10403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10403, CurrentID=0, Status='live', Symbol='NDC80', Aliases=['HEC', 'HEC1', 'HsHec1', 'KNTC2', 'TID3', 'hsNDC80'], description='NDC80 kinetochore complex component', other_designations='kinetochore protein NDC80 homolog|NDC80 homolog, kinetochore complex component|NDC80 kinetochore complex component homolog|highly expressed in cancer protein|highly expressed in cancer, rich in leucine heptad repeats|kinetochore associated 2|kinetochore protein Hec1|kinetochore-associated protein 2|retinoblastoma-associated protein HEC', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=2571557, end_position_on_the_genomic_accession=2616635, orientation='plus', exon_count=17, OMIM=[607272], no_hdr0=''),
    10404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10404, CurrentID=0, Status='live', Symbol='CPQ', Aliases=['LDP', 'PGCP'], description='carboxypeptidase Q', other_designations='carboxypeptidase Q|Ser-Met dipeptidase|aminopeptidase|blood plasma glutamate carboxypeptidase|lysosomal dipeptidase', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96645242, end_position_on_the_genomic_accession=97143501, orientation='plus', exon_count=8, OMIM=[618754], no_hdr0=''),
    10406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10406, CurrentID=0, Status='live', Symbol='WFDC2', Aliases=['EDDM4', 'HE4', 'WAP5', 'dJ461P17.6'], description='WAP four-disulfide core domain 2', other_designations='WAP four-disulfide core domain protein 2|WAP domain containing protein HE4-V4|epididymal protein 4|epididymal secretory protein E4|epididymis secretory sperm binding protein|epididymis-specific, whey-acidic protein type, four-disulfide core|human epididymis protein 4|major epididymis-specific protein E4|putative protease inhibitor WAP5', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45469753, end_position_on_the_genomic_accession=45481532, orientation='plus', exon_count=4, OMIM=[617548], no_hdr0=''),
    10407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10407, CurrentID=0, Status='live', Symbol='SPAG11B', Aliases=['EDDM2B', 'EP2', 'EP2C', 'EP2D', 'HE2', 'HE2C', 'SPAG11', 'SPAG11A'], description='sperm associated antigen 11B', other_designations='sperm-associated antigen 11B|Protein EP2|Sperm-associated antigen 11A|epididymal protein 2B|human epididymis-specific protein 2|sperm antigen HE2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7447754, end_position_on_the_genomic_accession=7463542, orientation='minus', exon_count=7, OMIM=[606560], no_hdr0=''),
    10409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10409, CurrentID=0, Status='live', Symbol='BASP1', Aliases=['CAP-23', 'CAP23', 'NAP-22', 'NAP22'], description='brain abundant membrane attached signal protein 1', other_designations='brain acid soluble protein 1|22 kDa neuronal tissue-enriched acidic protein|brain acid-soluble protein 1|neuronal axonal membrane protein NAP-22|neuronal tissue-enriched acidic protein', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=17216823, end_position_on_the_genomic_accession=17276834, orientation='plus', exon_count=3, OMIM=[605940], no_hdr0=''),
    10410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10410, CurrentID=0, Status='live', Symbol='IFITM3', Aliases=['1-8U', 'DSPA2b', 'IP15'], description='interferon induced transmembrane protein 3', other_designations='interferon-induced transmembrane protein 3|dispanin subfamily A member 2b|interferon-inducible protein 1-8U', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=319676, end_position_on_the_genomic_accession=320860, orientation='minus', exon_count=2, OMIM=[605579], no_hdr0=''),
    10411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10411, CurrentID=0, Status='live', Symbol='RAPGEF3', Aliases=['CAMP-GEFI', 'EPAC', 'EPAC1', 'HSU79275', 'bcm910'], description='Rap guanine nucleotide exchange factor 3', other_designations='rap guanine nucleotide exchange factor 3|9330170P05Rik|EPAC 1|Rap guanine nucleotide exchange factor (GEF) 3|Rap1 guanine-nucleotide-exchange factor directly activated by cAMP|cAMP-regulated guanine nucleotide exchange factor I|exchange factor directly activated by cAMP 1|exchange protein directly activated by cAMP 1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47734363, end_position_on_the_genomic_accession=47758880, orientation='minus', exon_count=29, OMIM=[606057], no_hdr0=''),
    10412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10412, CurrentID=0, Status='live', Symbol='NSA2', Aliases=['CDK105', 'HCL-G1', 'HCLG1', 'HUSSY-29', 'HUSSY29', 'TINP1'], description='NSA2 ribosome biogenesis factor', other_designations='ribosome biogenesis protein NSA2 homolog|NSA2, ribosome biogenesis homolog|TGF beta-inducible nuclear protein 1|TGF-beta inducible nuclear protein|hairy cell leukemia protein 1', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=74767249, end_position_on_the_genomic_accession=74780113, orientation='plus', exon_count=7, OMIM=[612497], no_hdr0=''),
    10413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10413, CurrentID=0, Status='live', Symbol='YAP1', Aliases=['COB1', 'YAP', 'YAP2', 'YAP65', 'YKI'], description='Yes1 associated transcriptional regulator', other_designations='transcriptional coactivator YAP1|65 kDa Yes-associated protein|Yes associated protein 1|protein yorkie homolog|yes-associated protein 2|yes-associated protein YAP65 homolog|yorkie homolog', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102109957, end_position_on_the_genomic_accession=102233424, orientation='plus', exon_count=10, OMIM=[606608], no_hdr0=''),
    10417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10417, CurrentID=0, Status='live', Symbol='SPON2', Aliases=['DIL-1', 'DIL1', 'M-SPONDIN', 'MINDIN'], description='spondin 2', other_designations='spondin-2|differentially expressed in cancerous and non-cancerous lung cells 1|spondin 2, extracellular matrix protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1166932, end_position_on_the_genomic_accession=1208844, orientation='minus', exon_count=9, OMIM=[605918], no_hdr0=''),
    10418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10418, CurrentID=0, Status='live', Symbol='SPON1', Aliases=['VSGP/F-spondin', 'f-spondin'], description='spondin 1', other_designations='spondin-1|spondin 1, (f-spondin) extracellular matrix protein|spondin 1, extracellular matrix protein|vascular smooth muscle cell growth-promoting factor', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13962723, end_position_on_the_genomic_accession=14268133, orientation='plus', exon_count=16, OMIM=[604989], no_hdr0=''),
    10419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10419, CurrentID=0, Status='live', Symbol='PRMT5', Aliases=['HRMT1L5', 'HSL7', 'IBP72', 'JBP1', 'SKB1', 'SKB1Hs'], description='protein arginine methyltransferase 5', other_designations='protein arginine N-methyltransferase 5|72 kDa ICln-binding protein|HMT1 hnRNP methyltransferase-like 5|SKB1 homolog|histone-arginine N-methyltransferase PRMT5|jak-binding protein 1|shk1 kinase-binding protein 1 homolog', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22920526, end_position_on_the_genomic_accession=22929392, orientation='minus', exon_count=18, OMIM=[604045], no_hdr0=''),
    10420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10420, CurrentID=0, Status='live', Symbol='TESK2', Aliases=[], description='testis associated actin remodelling kinase 2', other_designations='dual specificity testis-specific protein kinase 2|testicular protein kinase 2|testis-specific kinase 2', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45343883, end_position_on_the_genomic_accession=45491163, orientation='minus', exon_count=11, OMIM=[604746], no_hdr0=''),
    10421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10421, CurrentID=0, Status='live', Symbol='CD2BP2', Aliases=['FWP010', 'LIN1', 'PPP1R59', 'Snu40', 'U5-52K'], description='CD2 cytoplasmic tail binding protein 2', other_designations='CD2 antigen cytoplasmic tail-binding protein 2|CD2 cytoplasmic domain-binding protein 2|U5 snRNP 52K protein|protein phosphatase 1, regulatory subunit 59', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30350773, end_position_on_the_genomic_accession=30355308, orientation='minus', exon_count=7, OMIM=[604470], no_hdr0=''),
    10422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10422, CurrentID=0, Status='live', Symbol='UBAC1', Aliases=['GBDR1', 'KPC2', 'UBADC1'], description='UBA domain containing 1', other_designations='ubiquitin-associated domain-containing protein 1|E3 ubiquitin-protein ligase subunit KPC2|Kip1 ubiquitination-promoting complex subunit 2|UBA domain-containing protein 1|glialblastoma cell differentiation-related protein 1|kip1 ubiquitination-promoting complex protein 2|putative glialblastoma cell differentiation-related protein|testicular secretory protein Li 64|ubiquitin associated domain containing 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135932969, end_position_on_the_genomic_accession=135961373, orientation='minus', exon_count=10, OMIM=[608129], no_hdr0=''),
    10423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10423, CurrentID=0, Status='live', Symbol='CDIPT', Aliases=['PIS', 'PIS1'], description='CDP-diacylglycerol--inositol 3-phosphatidyltransferase', other_designations='CDP-diacylglycerol--inositol 3-phosphatidyltransferase|PI synthase|PtdIns synthase|phosphatidylinositol synthase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29858357, end_position_on_the_genomic_accession=29863226, orientation='minus', exon_count=6, OMIM=[605893], no_hdr0=''),
    10424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10424, CurrentID=0, Status='live', Symbol='PGRMC2', Aliases=['DG6', 'PMBP'], description='progesterone receptor membrane component 2', other_designations='membrane-associated progesterone receptor component 2|progesterone membrane binding protein|steroid receptor protein DG6', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=128269242, end_position_on_the_genomic_accession=128288205, orientation='minus', exon_count=4, OMIM=[607735], no_hdr0=''),
    10425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10425, CurrentID=0, Status='live', Symbol='ARIH2', Aliases=['ARI2', 'TRIAD1'], description='ariadne RBR E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase ARIH2|RING-type E3 ubiquitin transferase ARIH2|all-trans retinoic acid inducible RING finger|ariadne homolog 2|protein ariadne-2 homolog', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48918821, end_position_on_the_genomic_accession=48986382, orientation='plus', exon_count=22, OMIM=[605615], no_hdr0=''),
    10426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10426, CurrentID=0, Status='live', Symbol='TUBGCP3', Aliases=['104p', 'ALP6', 'GCP3', 'Grip104', 'SPBC98', 'Spc98', 'Spc98p'], description='tubulin gamma complex associated protein 3', other_designations='gamma-tubulin complex component 3|gamma-ring complex protein 104 kDa|spindle pole body protein Spc98 homolog', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112485005, end_position_on_the_genomic_accession=112606469, orientation='minus', exon_count=26, OMIM=[617818], no_hdr0=''),
    10427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10427, CurrentID=0, Status='live', Symbol='SEC24B', Aliases=['SEC24'], description='SEC24 homolog B, COPII coat complex component', other_designations='protein transport protein Sec24B|SEC24 related gene family, member B|secretory protein 24', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109433815, end_position_on_the_genomic_accession=109540896, orientation='plus', exon_count=28, OMIM=[607184], no_hdr0=''),
    10428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10428, CurrentID=0, Status='live', Symbol='CFDP1', Aliases=['BCNT', 'BUCENTAUR', 'CENP-29', 'CP27', 'SWC5', 'Yeti', 'p97'], description='craniofacial development protein 1', other_designations='craniofacial development protein 1|centromere protein 29|phosphoprotein (Bucentaur)', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75293710, end_position_on_the_genomic_accession=75433503, orientation='minus', exon_count=11, OMIM=[608108], no_hdr0=''),
    10430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10430, CurrentID=0, Status='live', Symbol='TMEM147', Aliases=['NIFIE14'], description='transmembrane protein 147', other_designations='transmembrane protein 147|protein NIFIE 14|seven transmembrane domain protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35545626, end_position_on_the_genomic_accession=35547526, orientation='plus', exon_count=6, OMIM=[613585], no_hdr0=''),
    10432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10432, CurrentID=0, Status='live', Symbol='RBM14', Aliases=['COAA', 'PSP2', 'SIP', 'SYTIP1', 'TMEM137'], description='RNA binding motif protein 14', other_designations='RNA-binding protein 14|RRM-containing coactivator activator/modulator|SYT-interacting protein|paraspeckle protein 2|synaptotagmin-interacting protein|transmembrane protein 137', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66616630, end_position_on_the_genomic_accession=66629934, orientation='plus', exon_count=3, OMIM=[612409], no_hdr0=''),
    10434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10434, CurrentID=0, Status='live', Symbol='LYPLA1', Aliases=['APT-1', 'APT1', 'LPL-I', 'LPL1', 'hAPT1'], description='lysophospholipase 1', other_designations='acyl-protein thioesterase 1|lysoPLA I|lysophospholipase I|lysophospholipid-specific lysophospholipase', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=54046367, end_position_on_the_genomic_accession=54101997, orientation='minus', exon_count=11, OMIM=[605599], no_hdr0=''),
    10435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10435, CurrentID=0, Status='live', Symbol='CDC42EP2', Aliases=['BORG1', 'CEP2'], description='CDC42 effector protein 2', other_designations='cdc42 effector protein 2|CDC42 effector protein (Rho GTPase binding) 2|CRIB-containing BOGR1 protein|binder of Rho GTPases 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65314866, end_position_on_the_genomic_accession=65322417, orientation='plus', exon_count=2, OMIM=[606132], no_hdr0=''),
    10436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10436, CurrentID=0, Status='live', Symbol='EMG1', Aliases=['C2F', 'Grcc2f', 'NEP1'], description='EMG1 N1-specific pseudouridine methyltransferase', other_designations='ribosomal RNA small subunit methyltransferase NEP1|18S rRNA (pseudouridine(1248)-N1)-methyltransferase|18S rRNA (pseudouridine-N1-)-methyltransferase NEP1|18S rRNA Psi1248 methyltransferase|EMG1 nucleolar protein homolog|essential for mitotic growth 1|nucleolar essential protein 1|ribosome biogenesis protein NEP1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6970913, end_position_on_the_genomic_accession=6997428, orientation='plus', exon_count=9, OMIM=[611531], no_hdr0=''),
    10437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10437, CurrentID=0, Status='live', Symbol='IFI30', Aliases=['GILT', 'IFI-30', 'IP-30', 'IP30'], description='IFI30 lysosomal thiol reductase', other_designations='gamma-interferon-inducible lysosomal thiol reductase|gamma-interferon-inducible protein IP-30|interferon gamma-inducible protein 30 preproprotein|interferon, gamma-inducible protein 30|legumaturain', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18173813, end_position_on_the_genomic_accession=18178117, orientation='plus', exon_count=7, OMIM=[604664], no_hdr0=''),
    10438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10438, CurrentID=0, Status='live', Symbol='C1D', Aliases=['LRP1', 'Rrp47', 'SUN-CoR', 'SUNCOR', 'hC1D'], description='C1D nuclear receptor corepressor', other_designations='nuclear nucleic acid-binding protein C1D|C1D DNA-binding protein|C1D nuclear receptor co-repressor|nuclear DNA-binding protein|small unique nuclear receptor co-repressor|small unique nuclear receptor corepressor', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68041130, end_position_on_the_genomic_accession=68063004, orientation='minus', exon_count=6, OMIM=[606997], no_hdr0=''),
    10439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10439, CurrentID=0, Status='live', Symbol='OLFM1', Aliases=['AMY', 'NOE1', 'NOELIN1', 'OlfA'], description='olfactomedin 1', other_designations='noelin|neuroblastoma protein|neuronal olfactomedin-related ER localized protein|olfactomedin related ER localized protein|pancortin 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135075505, end_position_on_the_genomic_accession=135121184, orientation='plus', exon_count=9, OMIM=[605366], no_hdr0=''),
    10440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10440, CurrentID=0, Status='live', Symbol='TIMM17A', Aliases=['TIM17', 'TIM17A'], description='translocase of inner mitochondrial membrane 17A', other_designations='mitochondrial import inner membrane translocase subunit Tim17-A|inner membrane preprotein translocase Tim17a|mitochondrial inner membrane translocase|preprotein translocase|translocase of inner mitochondrial membrane 17 homolog A', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201955503, end_position_on_the_genomic_accession=201970664, orientation='plus', exon_count=6, OMIM=[605057], no_hdr0=''),
    10443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10443, CurrentID=0, Status='live', Symbol='N4BP2L2', Aliases=['92M18.3', 'CG005', 'CG016', 'PFAAP5'], description='NEDD4 binding protein 2 like 2', other_designations='NEDD4-binding protein 2-like 2|phosphonoformate immuno-associated protein 5|protein from BRCA2 region', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32432485, end_position_on_the_genomic_accession=32542710, orientation='minus', exon_count=23, OMIM=[615788], no_hdr0=''),
    10444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10444, CurrentID=0, Status='live', Symbol='ZER1', Aliases=['C9orf60', 'ZYG', 'ZYG11BL'], description='zyg-11 related cell cycle regulator', other_designations='protein zer-1 homolog|ZYG homolog|zer-1 homolog|zyg-11 homolog B-like protein|zyg11b-like protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128729786, end_position_on_the_genomic_accession=128772486, orientation='minus', exon_count=18, OMIM=[617764], no_hdr0=''),
    10445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10445, CurrentID=0, Status='live', Symbol='MCRS1', Aliases=['ICP22BP', 'INO80Q', 'MCRS2', 'MSP58', 'P78'], description='microspherule protein 1', other_designations='microspherule protein 1|58 kDa microspherule protein|INO80 complex subunit J|INO80 complex subunit Q|cell cycle-regulated factor (78 kDa)|cell cycle-regulated factor p78', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49558299, end_position_on_the_genomic_accession=49568233, orientation='minus', exon_count=16, OMIM=[609504], no_hdr0=''),
    10446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10446, CurrentID=0, Status='live', Symbol='LRRN2', Aliases=['FIGLER7', 'GAC1', 'LRANK1', 'LRRN5'], description='leucine rich repeat neuronal 2', other_designations='leucine-rich repeat neuronal protein 2|fibronectin type III, immunoglobulin and leucine rich repeat domain 7|glioma amplified on chromosome 1 protein|leucine rich and ankyrin repeats 1|leucine rich repeat neuronal 5|leucine-rich repeat neuronal protein 5', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204617170, end_position_on_the_genomic_accession=204685836, orientation='minus', exon_count=6, OMIM=[605492], no_hdr0=''),
    10447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10447, CurrentID=0, Status='live', Symbol='FAM3C', Aliases=['GS3786', 'ILEI'], description='FAM3 metabolism regulating signaling molecule C', other_designations='protein FAM3C|family with sequence similarity 3 member C|interleukin-like EMT inducer|interleukin-like epithelial-mesenchymal transition inducer|predicted osteoblast protein', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=121348851, end_position_on_the_genomic_accession=121396369, orientation='minus', exon_count=12, OMIM=[608618], no_hdr0=''),
    10449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10449, CurrentID=0, Status='live', Symbol='ACAA2', Aliases=['DSAEC'], description='acetyl-CoA acyltransferase 2', other_designations='3-ketoacyl-CoA thiolase, mitochondrial|T1|acetyl-CoA acetyltransferase|acetyl-Coenzyme A acyltransferase 2|acyl-CoA hydrolase, mitochondrial|beta ketothiolase|mitochondrial 3-oxoacyl-CoA thiolase|mitochondrial 3-oxoacyl-Coenzyme A thiolase', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49782164, end_position_on_the_genomic_accession=49813533, orientation='minus', exon_count=10, OMIM=[604770], no_hdr0=''),
    10450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10450, CurrentID=0, Status='live', Symbol='PPIE', Aliases=['CYP-33', 'CYP33'], description='peptidylprolyl isomerase E', other_designations='peptidyl-prolyl cis-trans isomerase E|PPIase E|cyclophilin-33|peptidylprolyl isomerase E (cyclophilin E)|rotamase E', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39738845, end_position_on_the_genomic_accession=39765698, orientation='plus', exon_count=12, OMIM=[602435], no_hdr0=''),
    10451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10451, CurrentID=0, Status='live', Symbol='VAV3', Aliases=[], description='vav guanine nucleotide exchange factor 3', other_designations='guanine nucleotide exchange factor VAV3|VAV-3|vav 3 guanine nucleotide exchange factor|vav 3 oncogene', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=107571161, end_position_on_the_genomic_accession=107965180, orientation='minus', exon_count=33, OMIM=[605541], no_hdr0=''),
    10452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10452, CurrentID=0, Status='live', Symbol='TOMM40', Aliases=['C19orf1', 'D19S1177E', 'PER-EC1', 'PEREC1', 'TOM40'], description='translocase of outer mitochondrial membrane 40', other_designations='mitochondrial import receptor subunit TOM40 homolog|mitochondrial outer membrane protein|p38.5|protein Haymaker|translocase of outer membrane 40 kDa subunit homolog|translocase of outer mitochondrial membrane 40 homolog', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44891226, end_position_on_the_genomic_accession=44903689, orientation='plus', exon_count=11, OMIM=[608061], no_hdr0=''),
    10454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10454, CurrentID=0, Status='live', Symbol='TAB1', Aliases=["3'-Tab1", 'MAP3K7IP1'], description='TGF-beta activated kinase 1 (MAP3K7) binding protein 1', other_designations='TGF-beta-activated kinase 1 and MAP3K7-binding protein 1|TAK1-binding protein 1|mitogen-activated protein kinase kinase kinase 7-interacting protein 1|transforming growth factor beta-activated kinase-binding protein 1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39399780, end_position_on_the_genomic_accession=39437132, orientation='plus', exon_count=12, OMIM=[602615], no_hdr0=''),
    10455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10455, CurrentID=0, Status='live', Symbol='ECI2', Aliases=['ACBD2', 'DRS-1', 'DRS1', 'HCA88', 'PECI', 'dJ1013A10.3'], description='enoyl-CoA delta isomerase 2', other_designations='enoyl-CoA delta isomerase 2|D3,D2-enoyl-CoA isomerase|DBI-related protein 1|acyl-Coenzyme A binding domain containing 2|delta(3),delta(2)-enoyl-CoA isomerase|diazepam-binding inhibitor-related protein 1|dodecenoyl-CoA isomerase|enoyl-CoA delta isomerase 2, mitochondrial|hepatocellular carcinoma-associated antigen 88|peroxisomal 3,2-trans-enoyl-CoA isomerase|peroxisomal D3,D2-enoyl-CoA isomerase|renal carcinoma antigen NY-REN-1|testicular secretory protein Li 33', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4115706, end_position_on_the_genomic_accession=4135575, orientation='minus', exon_count=12, OMIM=[608024], no_hdr0=''),
    10456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10456, CurrentID=0, Status='live', Symbol='HAX1', Aliases=['HCLSBP1', 'HS1BP1', 'SCN3'], description='HCLS1 associated protein X-1', other_designations='HCLS1-associated protein X-1|HAX-1|HCLS1 (and PKD2) associated protein|HS1 binding protein|HS1-associating protein X-1|HS1-binding protein 1|HSP1BP-1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154272629, end_position_on_the_genomic_accession=154275875, orientation='plus', exon_count=7, OMIM=[605998], no_hdr0=''),
    10457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10457, CurrentID=0, Status='live', Symbol='GPNMB', Aliases=['HGFIN', 'NMB', 'PLCA3'], description='glycoprotein nmb', other_designations='transmembrane glycoprotein NMB|glycoprotein (transmembrane) nmb|glycoprotein nmb-like protein|glycoprotein nonmetastatic melanoma protein B|hematopoietic growth factor inducible neurokinin-1 type|osteoactivin|transmembrane glycoprotein HGFIN', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23246766, end_position_on_the_genomic_accession=23275110, orientation='plus', exon_count=12, OMIM=[604368], no_hdr0=''),
    10458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10458, CurrentID=0, Status='live', Symbol='BAIAP2', Aliases=['BAP2', 'FLAF3', 'IRSP53', 'WAML'], description='BAR/IMD domain containing adaptor protein 2', other_designations='brain-specific angiogenesis inhibitor 1-associated protein 2|BAI1 associated protein 2|IRS-58|IRSp53/58|WASP and MIM like|fas ligand-associated factor 3|insulin receptor substrate of 53 kDa|insulin receptor substrate p53/p58|insulin receptor substrate protein of 53 kDa', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81035131, end_position_on_the_genomic_accession=81117434, orientation='plus', exon_count=26, OMIM=[605475], no_hdr0=''),
    10459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10459, CurrentID=0, Status='live', Symbol='MAD2L2', Aliases=['FANCV', 'MAD2B', 'POLZ2', 'REV7'], description='mitotic arrest deficient 2 like 2', other_designations='mitotic spindle assembly checkpoint protein MAD2B|MAD2 (mitotic arrest deficient, yeast, homolog)-like 2|MAD2 mitotic arrest deficient-like 2|MAD2-like protein 2|REV7 homolog|hREV7|mitotic arrest deficient 2-like protein 2|mitotic arrest deficient homolog-like 2|polymerase (DNA-directed), zeta 2, accessory subunit', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11674480, end_position_on_the_genomic_accession=11691559, orientation='minus', exon_count=10, OMIM=[604094], no_hdr0=''),
    10460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10460, CurrentID=0, Status='live', Symbol='TACC3', Aliases=['ERIC-1', 'ERIC1', 'Tacc4', 'maskin'], description='transforming acidic coiled-coil containing protein 3', other_designations='transforming acidic coiled-coil-containing protein 3', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1721497, end_position_on_the_genomic_accession=1745171, orientation='plus', exon_count=18, OMIM=[605303], no_hdr0=''),
    10461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10461, CurrentID=0, Status='live', Symbol='MERTK', Aliases=['MER', 'RP38', 'Tyro12', 'c-Eyk', 'c-mer'], description='MER proto-oncogene, tyrosine kinase', other_designations='tyrosine-protein kinase Mer|MER receptor tyrosine kinase|STK kinase|c-mer proto-oncogene tyrosine kinase|proto-oncogene c-Mer|receptor tyrosine kinase MerTK', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=111898607, end_position_on_the_genomic_accession=112029561, orientation='plus', exon_count=19, OMIM=[604705], no_hdr0=''),
    10462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10462, CurrentID=0, Status='live', Symbol='CLEC10A', Aliases=['CD301', 'CLECSF13', 'CLECSF14', 'HML', 'HML2', 'MGL'], description='C-type lectin domain containing 10A', other_designations='C-type lectin domain family 10 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 13 (macrophage-derived)|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 14 (macrophage-derived)|macrophage lectin 2 (calcium dependent)', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7074537, end_position_on_the_genomic_accession=7080307, orientation='minus', exon_count=9, OMIM=[605999], no_hdr0=''),
    10463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10463, CurrentID=0, Status='live', Symbol='SLC30A9', Aliases=['BILAPES', 'C4orf1', 'GAC63', 'HUEL', 'ZNT9'], description='solute carrier family 30 member 9', other_designations='zinc transporter 9|GRIP1-dependent nuclear receptor coactivator|expressed in human embryonic lung|human embryonic lung protein|solute carrier family 30 (zinc transporter), member 9|znT-9', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41990502, end_position_on_the_genomic_accession=42090461, orientation='plus', exon_count=18, OMIM=[604604], no_hdr0=''),
    10464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10464, CurrentID=0, Status='live', Symbol='PIBF1', Aliases=['C13orf24', 'CEP90', 'JBTS33', 'PIBF'], description='progesterone immunomodulatory binding factor 1', other_designations='progesterone-induced-blocking factor 1|centrosomal protein of 90 kDa', map_location='13q21.33-q22.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=72782133, end_position_on_the_genomic_accession=73016461, orientation='plus', exon_count=22, OMIM=[607532], no_hdr0=''),
    10465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10465, CurrentID=0, Status='live', Symbol='PPIH', Aliases=['CYP-20', 'CYPH', 'SnuCyp-20', 'USA-CYP'], description='peptidylprolyl isomerase H', other_designations='peptidyl-prolyl cis-trans isomerase H|PPIase h|U-snRNP-associated cyclophilin SnuCyp-20|U-snRNP-associated cyclophilin SunCyp-20|USA-CyP SnuCyp-20|cyclophilin H|rotamase H|small nuclear ribonucleoprotein particle-specific cyclophilin H', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42657770, end_position_on_the_genomic_accession=42681654, orientation='plus', exon_count=16, OMIM=[606095], no_hdr0=''),
    10466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10466, CurrentID=0, Status='live', Symbol='COG5', Aliases=['CDG2I', 'GOLTC1', 'GTC90'], description='component of oligomeric golgi complex 5', other_designations='conserved oligomeric Golgi complex subunit 5|13S golgi transport complex 1 90 kDa subunit|COG complex subunit 5|conserved oligomeric Golgi complex protein 5', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107201372, end_position_on_the_genomic_accession=107564361, orientation='minus', exon_count=23, OMIM=[606821], no_hdr0=''),
    10467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10467, CurrentID=0, Status='live', Symbol='ZNHIT1', Aliases=['CG1I', 'ZNFN4A1'], description='zinc finger HIT-type containing 1', other_designations='zinc finger HIT domain-containing protein 1|H_DJ0747G18.14|cyclin-G1-binding protein 1|p18 Hamlet|p18Hamlet|putative cyclin G1 interacting protein|zinc finger protein subfamily 4A member 1|zinc finger protein, subfamily 4A (HIT domain containing), member 1|zinc finger, HIT domain containing 1|zinc finger, HIT type 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101218165, end_position_on_the_genomic_accession=101224191, orientation='plus', exon_count=6, OMIM=[618617], no_hdr0=''),
    10468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10468, CurrentID=0, Status='live', Symbol='FST', Aliases=['FS'], description='follistatin', other_designations='follistatin|activin-binding protein', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=53480338, end_position_on_the_genomic_accession=53487134, orientation='plus', exon_count=9, OMIM=[136470], no_hdr0=''),
    10469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10469, CurrentID=0, Status='live', Symbol='TIMM44', Aliases=['TIM44'], description='translocase of inner mitochondrial membrane 44', other_designations='mitochondrial import inner membrane translocase subunit TIM44|translocase of inner mitochondrial membrane 44 homolog', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7926718, end_position_on_the_genomic_accession=7943666, orientation='minus', exon_count=13, OMIM=[605058], no_hdr0=''),
    10471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10471, CurrentID=0, Status='live', Symbol='PFDN6', Aliases=['H2-KE2', 'HKE2', 'KE-2', 'PFD6'], description='prefoldin subunit 6', other_designations='prefoldin subunit 6|HLA class II region expressed gene KE2|KE2 protein', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33289597, end_position_on_the_genomic_accession=33290934, orientation='plus', exon_count=4, OMIM=[605660], no_hdr0=''),
    10472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10472, CurrentID=0, Status='live', Symbol='ZBTB18', Aliases=['C2H2-171', 'MRD22', 'RP58', 'TAZ-1', 'ZNF238'], description='zinc finger and BTB domain containing 18', other_designations='zinc finger and BTB domain-containing protein 18|58 kDa repressor protein|transcriptional repressor RP58|translin-associated zinc finger protein 1|zinc finger protein 238|zinc finger protein C2H2-171', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244048653, end_position_on_the_genomic_accession=244057476, orientation='plus', exon_count=4, OMIM=[608433], no_hdr0=''),
    10473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10473, CurrentID=0, Status='live', Symbol='HMGN4', Aliases=['HMG17L3', 'NHC'], description='high mobility group nucleosomal binding domain 4', other_designations='high mobility group nucleosome-binding domain-containing protein 4|high mobility group protein N4|high-mobility group (nonhistone chromosomal) protein 17-like 3|high-mobility group protein 17-like 3|non-histone chromosomal protein HMG-17-like 3', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26538347, end_position_on_the_genomic_accession=26546933, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    10474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10474, CurrentID=0, Status='live', Symbol='TADA3', Aliases=['ADA3', 'NGG1', 'STAF54L', 'hADA3', 'TADA3'], description='transcriptional adaptor 3', other_designations='transcriptional adapter 3|ADA3 homolog|ADA3-like protein|alteration/deficiency in activation 3|epididymis secretory sperm binding protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9779967, end_position_on_the_genomic_accession=9793011, orientation='minus', exon_count=10, OMIM=[602945], no_hdr0=''),
    10475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10475, CurrentID=0, Status='live', Symbol='TRIM38', Aliases=['RNF15', 'RORET'], description='tripartite motif containing 38', other_designations='E3 ubiquitin-protein ligase TRIM38|RING-type E3 ubiquitin transferase TRIM38|Ro/SSA ribonucleoprotein homolog|ring finger protein 15|tripartite motif-containing protein 38|zinc finger protein RoRet', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25962723, end_position_on_the_genomic_accession=25991231, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    10476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10476, CurrentID=0, Status='live', Symbol='ATP5PD', Aliases=['APT5H', 'ATP5H', 'ATPQ'], description='ATP synthase peripheral stalk subunit d', other_designations='ATP synthase subunit d, mitochondrial|ATP synthase D chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit d|ATP synthase, H+ transporting, mitochondrial F1F0, subunit d|ATP synthase, H+ transporting, mitochondrial Fo complex subunit D|ATP synthase, H+ transporting, mitochondrial Fo complex, subunit d|ATPase subunit d|My032 protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75038863, end_position_on_the_genomic_accession=75046969, orientation='minus', exon_count=6, OMIM=[618121], no_hdr0=''),
    10477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10477, CurrentID=0, Status='live', Symbol='UBE2E3', Aliases=['UBCH9', 'UbcM2'], description='ubiquitin conjugating enzyme E2 E3', other_designations='ubiquitin-conjugating enzyme E2 E3|E2 ubiquitin-conjugating enzyme E3|ubiquitin carrier protein E3|ubiquitin conjugating enzyme E2E 3|ubiquitin-conjugating enzyme E2-23 kDa|ubiquitin-conjugating enzyme E2E 3 (UBC4/5 homolog, yeast)|ubiquitin-conjugating enzyme E2E 3 (homologous to yeast UBC4/5)|ubiquitin-protein ligase E3', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=180980360, end_position_on_the_genomic_accession=181063427, orientation='plus', exon_count=10, OMIM=[604151], no_hdr0=''),
    10478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10478, CurrentID=0, Status='live', Symbol='SLC25A17', Aliases=['PMP34'], description='solute carrier family 25 member 17', other_designations='peroxisomal membrane protein PMP34|solute carrier family 25 (mitochondrial carrier; peroxisomal membrane protein, 34kDa), member 17', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40769630, end_position_on_the_genomic_accession=40819346, orientation='minus', exon_count=12, OMIM=[606795], no_hdr0=''),
    10479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10479, CurrentID=0, Status='live', Symbol='SLC9A6', Aliases=['MRSA', 'NHE6'], description='solute carrier family 9 member A6', other_designations='sodium/hydrogen exchanger 6|Na(+)/H(+) exchanger 6|solute carrier family 9 (sodium/hydrogen exchanger), member 6|solute carrier family 9, subfamily A (NHE6, cation proton antiporter 6), member 6', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135974596, end_position_on_the_genomic_accession=136047269, orientation='plus', exon_count=20, OMIM=[300231], no_hdr0=''),
    10480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10480, CurrentID=0, Status='live', Symbol='EIF3M', Aliases=['B5', 'GA17', 'PCID1', 'TANGO7', 'hfl-B5'], description='eukaryotic translation initiation factor 3 subunit M', other_designations='eukaryotic translation initiation factor 3 subunit M|B5 receptor|PCI domain containing 1 (herpesvirus entry mediator)|PCI domain-containing protein 1|dendritic cell protein|fetal lung protein B5|transport and golgi organization 7 homolog', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32583816, end_position_on_the_genomic_accession=32606264, orientation='plus', exon_count=11, OMIM=[609641], no_hdr0=''),
    10481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10481, CurrentID=0, Status='live', Symbol='HOXB13', Aliases=['HPC9', 'PSGD'], description='homeobox B13', other_designations='homeobox protein Hox-B13', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48724763, end_position_on_the_genomic_accession=48728750, orientation='minus', exon_count=2, OMIM=[604607], no_hdr0=''),
    10482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10482, CurrentID=0, Status='live', Symbol='NXF1', Aliases=['MEX67', 'TAP'], description='nuclear RNA export factor 1', other_designations='nuclear RNA export factor 1|mRNA export factor TAP|tip associating protein|tip-associated protein', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62792125, end_position_on_the_genomic_accession=62805443, orientation='minus', exon_count=21, OMIM=[602647], no_hdr0=''),
    10483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10483, CurrentID=0, Status='live', Symbol='SEC23B', Aliases=['CDA-II', 'CDAII', 'CDAN2', 'CWS7', 'HEMPAS', 'hSec23B'], description='SEC23 homolog B, COPII coat complex component', other_designations='protein transport protein Sec23B|SEC23 homolog B, coat complex II component|SEC23-like protein B|SEC23-related protein B|transport protein SEC23B', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18507548, end_position_on_the_genomic_accession=18561415, orientation='plus', exon_count=22, OMIM=[610512], no_hdr0=''),
    10484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10484, CurrentID=0, Status='live', Symbol='SEC23A', Aliases=['CLSD', 'hSec23A'], description='SEC23 homolog A, COPII coat complex component', other_designations='protein transport protein Sec23A|SEC23-related protein A|Sec23 homolog A, coat complex II component', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39031919, end_position_on_the_genomic_accession=39103235, orientation='minus', exon_count=22, OMIM=[610511], no_hdr0=''),
    10486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10486, CurrentID=0, Status='live', Symbol='CAP2', Aliases=[], description='cyclase associated actin cytoskeleton regulatory protein 2', other_designations='adenylyl cyclase-associated protein 2|2810452G09Rik|CAP 2|CAP, adenylate cyclase-associated protein, 2', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17393595, end_position_on_the_genomic_accession=17557780, orientation='plus', exon_count=13, OMIM=[618385], no_hdr0=''),
    10487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10487, CurrentID=0, Status='live', Symbol='CAP1', Aliases=['CAP-PEN', 'CAP1'], description='cyclase associated actin cytoskeleton regulatory protein 1', other_designations='adenylyl cyclase-associated protein 1|CAP, adenylate cyclase-associated protein 1|adenylate cyclase associated protein 1|testis secretory sperm-binding protein Li 218p', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40040240, end_position_on_the_genomic_accession=40072648, orientation='plus', exon_count=15, OMIM=[617801], no_hdr0=''),
    10488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10488, CurrentID=0, Status='live', Symbol='CREB3', Aliases=['LUMAN', 'LZIP', 'sLZIP'], description='cAMP responsive element binding protein 3', other_designations='cyclic AMP-responsive element-binding protein 3|basic leucine zipper protein|cyclic AMP response element (CRE)-binding protein/activating transcription factor 1|leucin zipper proitein|small leucine zipper protein|transcription factor LZIP-alpha', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35732666, end_position_on_the_genomic_accession=35736999, orientation='plus', exon_count=9, OMIM=[606443], no_hdr0=''),
    10489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10489, CurrentID=0, Status='live', Symbol='LRRC41', Aliases=['MUF1', 'PP7759'], description='leucine rich repeat containing 41', other_designations='leucine-rich repeat-containing protein 41|MUF1 protein (MUF1)|elongin BC-interacting leucine-rich repeat protein|protein Muf1', map_location='1p34.1-p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46277462, end_position_on_the_genomic_accession=46303616, orientation='minus', exon_count=8, OMIM=[618753], no_hdr0=''),
    10490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10490, CurrentID=0, Status='live', Symbol='VTI1B', Aliases=['VTI1', 'VTI1-LIKE', 'VTI1L', 'VTI2', 'v-SNARE', 'vti1-rp1'], description='vesicle transport through interaction with t-SNAREs 1B', other_designations='vesicle transport through interaction with t-SNAREs homolog 1B|vesicle transport v-SNARE protein Vti1-like 1|vesicle-associated soluble NSF attachment protein receptor', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67647085, end_position_on_the_genomic_accession=67674632, orientation='minus', exon_count=6, OMIM=[603207], no_hdr0=''),
    10491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10491, CurrentID=0, Status='live', Symbol='CRTAP', Aliases=['CASP', 'LEPREL3', 'OI7', 'P3H5'], description='cartilage associated protein', other_designations='cartilage-associated protein|leprecan-like 3|prolyl 3-hydroxylase family member 5 (non-enzymatic)', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33114014, end_position_on_the_genomic_accession=33147773, orientation='plus', exon_count=7, OMIM=[605497], no_hdr0=''),
    10492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10492, CurrentID=0, Status='live', Symbol='SYNCRIP', Aliases=['GRY-RBP', 'GRYRBP', 'HNRNPQ', 'HNRPQ1', 'NSAP1', 'PP68', 'hnRNP-Q'], description='synaptotagmin binding cytoplasmic RNA interacting protein', other_designations='heterogeneous nuclear ribonucleoprotein Q|NS1-associated protein 1|glycine- and tyrosine-rich RNA-binding protein', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=85607784, end_position_on_the_genomic_accession=85643862, orientation='minus', exon_count=13, OMIM=[616686], no_hdr0=''),
    10493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10493, CurrentID=0, Status='live', Symbol='VAT1', Aliases=['VATI'], description='vesicle amine transport 1', other_designations='synaptic vesicle membrane protein VAT-1 homolog|membrane protein of cholinergic synaptic vesicles|vesicle amine transport protein 1 homolog (T. californica)', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43014607, end_position_on_the_genomic_accession=43022385, orientation='minus', exon_count=6, OMIM=[604631], no_hdr0=''),
    10494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10494, CurrentID=0, Status='live', Symbol='STK25', Aliases=['SOK1', 'YSK1'], description='serine/threonine kinase 25', other_designations='serine/threonine-protein kinase 25|Ste20, yeast homolog|ste20-like kinase|ste20/oxidant stress response kinase 1|sterile 20/oxidant stress-response kinase 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241492670, end_position_on_the_genomic_accession=241509730, orientation='minus', exon_count=14, OMIM=[602255], no_hdr0=''),
    10495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10495, CurrentID=0, Status='live', Symbol='ENOX2', Aliases=['APK1', 'COVA1', 'tNOX'], description='ecto-NOX disulfide-thiol exchanger 2', other_designations='ecto-NOX disulfide-thiol exchanger 2|APK1 antigen|cytosolic ovarian carcinoma antigen 1|ecto-NADPH oxidase disulfide-thiol exchanger 2|tumor-associated NADH oxidase|tumor-associated hydroquinone oxidase', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130622325, end_position_on_the_genomic_accession=130903317, orientation='minus', exon_count=21, OMIM=[300282], no_hdr0=''),
    10497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10497, CurrentID=0, Status='live', Symbol='UNC13B', Aliases=['MUNC13', 'UNC13', 'Unc13h2', 'munc13-2'], description='unc-13 homolog B', other_designations='protein unc-13 homolog B|homolog of rat Munc13 (diacylglycerol-binding)|unc-13-like', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35162009, end_position_on_the_genomic_accession=35405337, orientation='plus', exon_count=47, OMIM=[605836], no_hdr0=''),
    10498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10498, CurrentID=0, Status='live', Symbol='CARM1', Aliases=['PRMT4'], description='coactivator associated arginine methyltransferase 1', other_designations='histone-arginine methyltransferase CARM1|protein arginine N-methyltransferase 4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10871553, end_position_on_the_genomic_accession=10923078, orientation='plus', exon_count=18, OMIM=[603934], no_hdr0=''),
    10499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10499, CurrentID=0, Status='live', Symbol='NCOA2', Aliases=['GRIP1', 'KAT13C', 'NCoA-2', 'SRC2', 'TIF2', 'bHLHe75'], description='nuclear receptor coactivator 2', other_designations='nuclear receptor coactivator 2|class E basic helix-loop-helix protein 75|glucocorticoid receptor-interacting protein-1|p160 steroid receptor coactivator 2|transcriptional intermediary factor 2', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=70109770, end_position_on_the_genomic_accession=70405390, orientation='minus', exon_count=31, OMIM=[601993], no_hdr0=''),
    10500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10500, CurrentID=0, Status='live', Symbol='SEMA6C', Aliases=['SEMAY', 'm-SemaY', 'm-SemaY2'], description='semaphorin 6C', other_designations='semaphorin-6C|sema Y|sema domain, transmembrane domain (TM), and cytoplasmic domain, (semaphorin) 6C|semaphorin-Y', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151131707, end_position_on_the_genomic_accession=151148408, orientation='minus', exon_count=22, OMIM=[609294], no_hdr0=''),
    10501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10501, CurrentID=0, Status='live', Symbol='SEMA6B', Aliases=['EPM11', 'SEM-SEMA-Y', 'SEMA-VIB', 'SEMAN', 'semaZ'], description='semaphorin 6B', other_designations='semaphorin-6B|sema domain, transmembrane domain (TM), and cytoplasmic domain, (semaphorin) 6B|semaphorin VIB|semaphorin Z|semaphorin-6Ba', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4542588, end_position_on_the_genomic_accession=4581484, orientation='minus', exon_count=18, OMIM=[608873], no_hdr0=''),
    10505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10505, CurrentID=0, Status='live', Symbol='SEMA4F', Aliases=['M-SEMA', 'PRO2353', 'S4F', 'SEMAM', 'SEMAW', 'm-Sema-M'], description='ssemaphorin 4F', other_designations='semaphorin-4F|sema domain immunoglobulin domain transmembrane domain (TM) and short cytoplasmic domain (semaphorin) 4F|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4F|semaphorin M|semaphorin-W', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74654229, end_position_on_the_genomic_accession=74699013, orientation='plus', exon_count=17, OMIM=[603706], no_hdr0=''),
    10507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10507, CurrentID=0, Status='live', Symbol='SEMA4D', Aliases=['A8', 'BB18', 'C9orf164', 'CD100', 'COLL4', 'GR3', 'M-sema-G', 'SEMAJ', 'coll-4'], description='semaphorin 4D', other_designations='semaphorin-4D|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4D|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, 4D', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=89360787, end_position_on_the_genomic_accession=89498113, orientation='minus', exon_count=30, OMIM=[601866], no_hdr0=''),
    10509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10509, CurrentID=0, Status='live', Symbol='SEMA4B', Aliases=['SEMAC', 'SemC'], description='semaphorin 4B', other_designations='semaphorin-4B|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4B|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, 4B|semaphorin-C', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90184920, end_position_on_the_genomic_accession=90229661, orientation='plus', exon_count=17, OMIM=[617029], no_hdr0=''),
    10512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10512, CurrentID=0, Status='live', Symbol='SEMA3C', Aliases=['SEMAE', 'SemE'], description='semaphorin 3C', other_designations='semaphorin-3C|sema E|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3C|semaphorin E', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=80742538, end_position_on_the_genomic_accession=80922389, orientation='minus', exon_count=20, OMIM=[602645], no_hdr0=''),
    10513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10513, CurrentID=0, Status='live', Symbol='APPBP2', Aliases=['APP-BP2', 'HS.84084', 'PAT1'], description='amyloid beta precursor protein binding protein 2', other_designations='amyloid protein-binding protein 2|amyloid beta precursor protein (cytoplasmic tail) binding protein 2|protein interacting with APP tail 1', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60443149, end_position_on_the_genomic_accession=60526242, orientation='minus', exon_count=14, OMIM=[605324], no_hdr0=''),
    10514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10514, CurrentID=0, Status='live', Symbol='MYBBP1A', Aliases=['P160', 'PAP2', 'Pol5'], description='MYB binding protein 1a', other_designations='myb-binding protein 1A|MYB binding protein (P160) 1a|p53-activated protein-2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4538904, end_position_on_the_genomic_accession=4555384, orientation='minus', exon_count=27, OMIM=[604885], no_hdr0=''),
    10516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10516, CurrentID=0, Status='live', Symbol='FBLN5', Aliases=['ADCL2', 'ARCL1A', 'ARMD3', 'DANCE', 'EVEC', 'FIBL-5', 'HNARMD', 'UP50'], description='fibulin 5', other_designations='fibulin-5|developmental arteries and neural crest EGF-like protein|embryonic vascular EGF-like repeat-containing protein|testis tissue sperm-binding protein Li 75n|urine p50 protein', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91869411, end_position_on_the_genomic_accession=91947694, orientation='minus', exon_count=15, OMIM=[604580], no_hdr0=''),
    10517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10517, CurrentID=0, Status='live', Symbol='FBXW10', Aliases=['Fbw10', 'HREP', 'SM25H2', 'SM2SH2'], description='F-box and WD repeat domain containing 10', other_designations='F-box/WD repeat-containing protein 10|F-box and WD-40 domain protein 10|testicular tissue protein Li 69|ubiquitin ligase specificity factor', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18744024, end_position_on_the_genomic_accession=18779349, orientation='plus', exon_count=17, OMIM=[611679], no_hdr0=''),
    10518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10518, CurrentID=0, Status='live', Symbol='CIB2', Aliases=['DFNB48', 'KIP2', 'USH1J'], description='calcium and integrin binding family member 2', other_designations='calcium and integrin-binding family member 2|DNA-dependent protein kinase catalytic subunit-interacting protein 2', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78104606, end_position_on_the_genomic_accession=78131976, orientation='minus', exon_count=7, OMIM=[605564], no_hdr0=''),
    10519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10519, CurrentID=0, Status='live', Symbol='CIB1', Aliases=['CIB', 'CIBP', 'KIP1', 'PRKDCIP', 'SIP2-28'], description='calcium and integrin binding 1', other_designations='calcium and integrin-binding protein 1|DNA-PK interaction protein|DNA-PKcs-interacting protein|DNA-dependent protein kinase interacting protein|SNK-interacting protein 2-28|calcium and integrin binding 1 (calmyrin)|testicular secretory protein Li 9', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90229975, end_position_on_the_genomic_accession=90265759, orientation='minus', exon_count=8, OMIM=[602293], no_hdr0=''),
    10520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10520, CurrentID=0, Status='live', Symbol='ZNF211', Aliases=['C2H2-25', 'CH2H2-25', 'ZNF-25'], description='zinc finger protein 211', other_designations='zinc finger protein 211|zinc finger protein C2H2-25', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57633168, end_position_on_the_genomic_accession=57644041, orientation='plus', exon_count=7, OMIM=[601856], no_hdr0=''),
    10521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10521, CurrentID=0, Status='live', Symbol='DDX17', Aliases=['P72', 'RH70'], description='DEAD-box helicase 17', other_designations='probable ATP-dependent RNA helicase DDX17|DEAD (Asp-Glu-Ala-Asp) box helicase 17|DEAD (Asp-Glu-Ala-Asp) box polypeptide 17|DEAD box protein p72|DEAD box protein p82|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 17 (72kD)|RNA-dependent helicase p72', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38483438, end_position_on_the_genomic_accession=38506311, orientation='minus', exon_count=13, OMIM=[608469], no_hdr0=''),
    10522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10522, CurrentID=0, Status='live', Symbol='DEAF1', Aliases=['MRD24', 'NEDHELS', 'NUDR', 'SPN', 'VSVS', 'ZMYND5'], description='DEAF1 transcription factor', other_designations='deformed epidermal autoregulatory factor 1 homolog|nuclear DEAF-1-related transcriptional regulator|suppressin|zinc finger MYND domain-containing protein 5', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=644220, end_position_on_the_genomic_accession=707083, orientation='minus', exon_count=18, OMIM=[602635], no_hdr0=''),
    10523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10523, CurrentID=0, Status='live', Symbol='CHERP', Aliases=['DAN16', 'SCAF6', 'SRA1'], description='calcium homeostasis endoplasmic reticulum protein', other_designations='calcium homeostasis endoplasmic reticulum protein|ERPROT 213-21|ERPROT213-21|SR-related CTD associated factor 6|protein with polyglutamine repeat', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16517894, end_position_on_the_genomic_accession=16542437, orientation='minus', exon_count=17, OMIM=[618539], no_hdr0=''),
    10524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10524, CurrentID=0, Status='live', Symbol='KAT5', Aliases=['ESA1', 'HTATIP', 'HTATIP1', 'NEDFASB', 'PLIP', 'TIP', 'TIP60', 'ZC2HC5', 'cPLA2'], description='lysine acetyltransferase 5', other_designations='histone acetyltransferase KAT5|60 kDa Tat-interactive protein|HIV-1 Tat interactive protein, 60kDa|K(lysine) acetyltransferase 5|K-acetyltransferase 5|Tat interacting protein, 60kDa|cPLA(2)-interacting protein|cPLA2 interacting protein|histone acetyltransferase HTATIP', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65712018, end_position_on_the_genomic_accession=65719604, orientation='plus', exon_count=14, OMIM=[601409], no_hdr0=''),
    10525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10525, CurrentID=0, Status='live', Symbol='HYOU1', Aliases=['GRP-170', 'Grp170', 'HSP12A', 'IMD59', 'ORP-150', 'ORP150'], description='hypoxia up-regulated 1', other_designations='hypoxia up-regulated protein 1|150 kDa oxygen-regulated protein|170 kDa glucose-regulated protein|epididymis secretory sperm binding protein|oxygen regulated protein (150kD)', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119044187, end_position_on_the_genomic_accession=119057205, orientation='minus', exon_count=27, OMIM=[601746], no_hdr0=''),
    10526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10526, CurrentID=0, Status='live', Symbol='IPO8', Aliases=['RANBP8'], description='importin 8', other_designations='importin-8|RAN binding protein 8|imp8|ran-binding protein 8', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=30628981, end_position_on_the_genomic_accession=30695986, orientation='minus', exon_count=28, OMIM=[605600], no_hdr0=''),
    10527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10527, CurrentID=0, Status='live', Symbol='IPO7', Aliases=['Imp7', 'RANBP7'], description='importin 7', other_designations='importin-7|RAN-binding protein 7', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9384652, end_position_on_the_genomic_accession=9448127, orientation='plus', exon_count=25, OMIM=[605586], no_hdr0=''),
    10528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10528, CurrentID=0, Status='live', Symbol='NOP56', Aliases=['NOL5A', 'SCA36'], description='NOP56 ribonucleoprotein', other_designations='nucleolar protein 56|NOP56 ribonucleoprotein homolog|nucleolar protein 5A (56kDa with KKE/D repeat)', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2652632, end_position_on_the_genomic_accession=2658393, orientation='plus', exon_count=13, OMIM=[614154], no_hdr0=''),
    10529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10529, CurrentID=0, Status='live', Symbol='NEBL', Aliases=['C10orf113', 'LASP2', 'LNEBL', 'bA165O3.1'], description='nebulette', other_designations='nebulette|LIM and SH3 protein 2|LIM-nebulette|actin-binding Z-disk protein', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=20779973, end_position_on_the_genomic_accession=21293050, orientation='minus', exon_count=43, OMIM=[605491], no_hdr0=''),
    10531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10531, CurrentID=0, Status='live', Symbol='PITRM1', Aliases=['MP1', 'PreP', 'SCAR30'], description='pitrilysin metallopeptidase 1', other_designations='presequence protease, mitochondrial|PreP peptidasome|metalloprotease 1 (pitrilysin family)|pitrilysin metalloproteinase 1', map_location='10p15.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=3137727, end_position_on_the_genomic_accession=3172841, orientation='minus', exon_count=28, OMIM=[618211], no_hdr0=''),
    10533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10533, CurrentID=0, Status='live', Symbol='ATG7', Aliases=['APG7-LIKE', 'APG7L', 'GSA7', 'SCAR31'], description='autophagy related 7', other_designations='ubiquitin-like modifier-activating enzyme ATG7|APG7 autophagy 7-like|ATG12-activating enzyme E1 ATG7|hAGP7|ubiquitin-activating enzyme E1-like protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=11272348, end_position_on_the_genomic_accession=11564652, orientation='plus', exon_count=29, OMIM=[608760], no_hdr0=''),
    10534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10534, CurrentID=0, Status='live', Symbol='ZNRD2', Aliases=['SSSCA1', 'p27'], description='zinc ribbon domain containing 2', other_designations="protein ZNRD2|Sjogren syndrome/scleroderma autoantigen 1|Sjogren's syndrome/scleroderma autoantigen 1|autoantigen p27|centromeric autoantigen (27kD)|sjoegren syndrome/scleroderma autoantigen 1|zinc ribbon domain-containing protein 2", map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65570477, end_position_on_the_genomic_accession=65571888, orientation='plus', exon_count=3, OMIM=[606044], no_hdr0=''),
    10535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10535, CurrentID=0, Status='live', Symbol='RNASEH2A', Aliases=['AGS4', 'JUNB', 'RNASEHI', 'RNHIA', 'RNHL', 'THSD8'], description='ribonuclease H2 subunit A', other_designations='ribonuclease H2 subunit A|RNase H(35)|RNase H2 subunit A|RNase HI large subunit|aicardi-Goutieres syndrome 4 protein|ribonuclease H2, large subunit|ribonuclease HI large subunit|ribonuclease HI subunit A', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12806584, end_position_on_the_genomic_accession=12813640, orientation='plus', exon_count=8, OMIM=[606034], no_hdr0=''),
    10536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10536, CurrentID=0, Status='live', Symbol='P3H3', Aliases=['GRCB', 'HSU47926', 'LEPREL2'], description='prolyl 3-hydroxylase 3', other_designations='prolyl 3-hydroxylase 3|gene rich cluster, B|leprecan-like 2|procollagen-proline 3-dioxygenase|protein B', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6828407, end_position_on_the_genomic_accession=6839847, orientation='plus', exon_count=15, OMIM=[610342], no_hdr0=''),
    10537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10537, CurrentID=0, Status='live', Symbol='UBD', Aliases=['FAT10', 'GABBR1-3', 'UBD'], description='ubiquitin D', other_designations='ubiquitin D|diubiquitin|ubiquitin-like protein FAT10', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29555515, end_position_on_the_genomic_accession=29559732, orientation='minus', exon_count=2, OMIM=[606050], no_hdr0=''),
    10538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10538, CurrentID=0, Status='live', Symbol='BATF', Aliases=['B-ATF1', 'SFA-2', 'SFA2', 'BATF'], description='basic leucine zipper ATF-like transcription factor', other_designations='basic leucine zipper transcriptional factor ATF-like|B-cell-activating transcription factor|SF-HT-activated gene 2 protein|activating transcription factor B|basic leucine zipper transcription factor, ATF-like', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75522469, end_position_on_the_genomic_accession=75546992, orientation='plus', exon_count=3, OMIM=[612476], no_hdr0=''),
    10539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10539, CurrentID=0, Status='live', Symbol='GLRX3', Aliases=['GLRX4', 'GRX3', 'GRX4', 'PICOT', 'TXNL2', 'TXNL3'], description='glutaredoxin 3', other_designations='glutaredoxin-3|PKC-interacting cousin of thioredoxin|PKC-theta-interacting protein|PKCq-interacting protein|glutaredoxin 4|testicular tissue protein Li 75|thioredoxin-like protein 2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=130136391, end_position_on_the_genomic_accession=130182877, orientation='plus', exon_count=13, OMIM=[612754], no_hdr0=''),
    10540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10540, CurrentID=0, Status='live', Symbol='DCTN2', Aliases=['DCTN50', 'DYNAMITIN', 'HEL-S-77', 'RBP50'], description='dynactin subunit 2', other_designations='dynactin subunit 2|50 kDa dynein-associated polypeptide|dynactin 2 (p50)|dynactin complex 50 kDa subunit|epididymis secretory protein Li 77|epididymis secretory sperm binding protein|p50 dynamitin', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57530051, end_position_on_the_genomic_accession=57547216, orientation='minus', exon_count=19, OMIM=[607376], no_hdr0=''),
    10541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10541, CurrentID=0, Status='live', Symbol='ANP32B', Aliases=['APRIL', 'PHAPI2', 'SSP29'], description='acidic nuclear phosphoprotein 32 family member B', other_designations='acidic leucine-rich nuclear phosphoprotein 32 family member B|acidic (leucine-rich) nuclear phosphoprotein 32 family, member B|acidic protein rich in leucines|putative HLA-DR-associated protein I-2|silver-stainable protein SSP29', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97983341, end_position_on_the_genomic_accession=98015943, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    10542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10542, CurrentID=0, Status='live', Symbol='LAMTOR5', Aliases=['HBXIP', 'XIP'], description='late endosomal/lysosomal adaptor, MAPK and MTOR activator 5', other_designations='ragulator complex protein LAMTOR5|HBV X-interacting protein|HBx-interacting protein|hepatitis B virus x interacting protein|hepatitis B virus x-interacting protein (9.6kD)|late endosomal/lysosomal adaptor and MAPK and MTOR activator 5', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110401253, end_position_on_the_genomic_accession=110407924, orientation='minus', exon_count=4, OMIM=[608521], no_hdr0=''),
    10544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10544, CurrentID=0, Status='live', Symbol='PROCR', Aliases=['CCCA', 'CCD41', 'EPCR'], description='protein C receptor', other_designations='endothelial protein C receptor|APC receptor|CD201 antigen|activated protein C receptor|cell cycle, centrosome-associated protein|centrocyclin|protein C receptor, endothelial', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35172072, end_position_on_the_genomic_accession=35215989, orientation='plus', exon_count=5, OMIM=[600646], no_hdr0=''),
    10548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10548, CurrentID=0, Status='live', Symbol='TM9SF1', Aliases=['HMP70', 'MP70'], description='transmembrane 9 superfamily member 1', other_designations='transmembrane 9 superfamily member 1|MP70 protein family member|multispanning membrane protein (70kD)|transmembrane protein 9 superfamily member 1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24189149, end_position_on_the_genomic_accession=24195441, orientation='minus', exon_count=6, OMIM=[618965], no_hdr0=''),
    10549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10549, CurrentID=0, Status='live', Symbol='PRDX4', Aliases=['AOE37-2', 'AOE372', 'HEL-S-97n', 'PRX-4'], description='peroxiredoxin 4', other_designations='peroxiredoxin-4|antioxidant enzyme AOE372|epididymis secretory sperm binding protein Li 97n|peroxiredoxin IV|prx-IV|thioredoxin peroxidase (antioxidant enzyme)|thioredoxin peroxidase AO372|thioredoxin-dependent peroxide reductase A0372|thioredoxin-dependent peroxiredoxin 4', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23667493, end_position_on_the_genomic_accession=23686397, orientation='plus', exon_count=7, OMIM=[300927], no_hdr0=''),
    10550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10550, CurrentID=0, Status='live', Symbol='ARL6IP5', Aliases=['DERP11', 'GTRAP3-18', 'HSPC127', 'JWA', 'PRAF3', 'Yip6b', 'addicsin', 'hp22', 'jmx'], description='ADP ribosylation factor like GTPase 6 interacting protein 5', other_designations='PRA1 family protein 3|ADP-ribosylation factor GTPase 6 interacting protein 5|ADP-ribosylation factor-like 6 interacting protein 5|ADP-ribosylation factor-like protein 6-interacting protein 5|ADP-ribosylation-like factor 6 interacting protein 5|ARL-6-interacting protein 5|JM5|PRA1 domain family 3|aip-5|cytoskeleton-related vitamin A-responsive protein|dermal papilla derived protein 11|glutamate transporter EAAC1-interacting protein|glutamate transporter EEAC1-associated protein|prenylated Rab acceptor protein 2|protein JWa|putative MAPK activating protein PM27', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69084937, end_position_on_the_genomic_accession=69106092, orientation='plus', exon_count=3, OMIM=[605709], no_hdr0=''),
    10551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10551, CurrentID=0, Status='live', Symbol='AGR2', Aliases=['AG-2', 'AG2', 'GOB-4', 'HAG-2', 'HEL-S-116', 'HPC8', 'PDIA17', 'XAG-2'], description='anterior gradient 2, protein disulphide isomerase family member', other_designations='anterior gradient protein 2 homolog|anterior gradient homolog 2|epididymis secretory protein Li 116|protein disulfide isomerase family A, member 17|secreted cement gland homolog|secreted cement gland protein XAG-2 homolog', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16791811, end_position_on_the_genomic_accession=16804999, orientation='minus', exon_count=8, OMIM=[606358], no_hdr0=''),
    10552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10552, CurrentID=0, Status='live', Symbol='ARPC1A', Aliases=['Arc40', 'HEL-68', 'HEL-S-307', 'SOP2Hs', 'SOP2L'], description='actin related protein 2/3 complex subunit 1A', other_designations='actin-related protein 2/3 complex subunit 1A|SOP2-like protein|actin binding protein (Schizosaccharomyces pombe sop2-like)|actin related protein 2/3 complex, subunit 1A, 41kDa|epididymis luminal protein 68|epididymis secretory protein Li 307|epididymis secretory sperm binding protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99325898, end_position_on_the_genomic_accession=99366262, orientation='plus', exon_count=10, OMIM=[604220], no_hdr0=''),
    10553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10553, CurrentID=0, Status='live', Symbol='HTATIP2', Aliases=['CC3', 'SDR44U1', 'TIP30'], description='HIV-1 Tat interactive protein 2', other_designations='oxidoreductase HTATIP2|30 kDa HIV-1 TAT-interacting protein|HIV-1 TAT-interactive protein 2|HIV-1 Tat interactive protein 2, 30kDa|Tat-interacting protein (30kD)|short chain dehydrogenase/reductase family 44U, member 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=20363714, end_position_on_the_genomic_accession=20383782, orientation='plus', exon_count=6, OMIM=[605628], no_hdr0=''),
    10554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10554, CurrentID=0, Status='live', Symbol='AGPAT1', Aliases=['1-AGPAT1', 'G15', 'LPAAT-alpha', 'LPAATA'], description='1-acylglycerol-3-phosphate O-acyltransferase 1', other_designations='1-acyl-sn-glycerol-3-phosphate acyltransferase alpha|1-AGP acyltransferase 1|1-AGPAT 1|1-acylglycerol-3-phosphate O-acyltransferase 1 (acetoacetly Coenzyme A thiolase)|1-acylglycerol-3-phosphate O-acyltransferase 1 (lysophosphatidic acid acyltransferase, alpha)|epididymis secretory sperm binding protein|lysophosphatidic acid acyltransferase alpha|lysophospholipid acyltransferase', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32168212, end_position_on_the_genomic_accession=32178108, orientation='minus', exon_count=11, OMIM=[603099], no_hdr0=''),
    10555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10555, CurrentID=0, Status='live', Symbol='AGPAT2', Aliases=['1-AGPAT2', 'BSCL', 'BSCL1', 'LPAAB', 'LPAAT-beta'], description='1-acylglycerol-3-phosphate O-acyltransferase 2', other_designations='1-acyl-sn-glycerol-3-phosphate acyltransferase beta|1-AGP acyltransferase 2|1-AGPAT 2|1-acylglycerol-3-phosphate O-acyltransferase 2 (lysophosphatidic acid acyltransferase, beta)|lysophosphatidic acid acyltransferase-beta|testicular tissue protein Li 143', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136673143, end_position_on_the_genomic_accession=136687457, orientation='minus', exon_count=6, OMIM=[603100], no_hdr0=''),
    10556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10556, CurrentID=0, Status='live', Symbol='RPP30', Aliases=['TSG15'], description='ribonuclease P/MRP subunit p30', other_designations='ribonuclease P protein subunit p30|RNase P subunit 2|RNaseP protein p30|ribonuclease P/MRP 30kDa subunit', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=90871974, end_position_on_the_genomic_accession=90908556, orientation='plus', exon_count=14, OMIM=[606115], no_hdr0=''),
    10557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10557, CurrentID=0, Status='live', Symbol='RPP38', Aliases=[], description='ribonuclease P/MRP subunit p38', other_designations='ribonuclease P protein subunit p38|RNaseP protein p38|ribonuclease P/MRP 38kDa subunit', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15097217, end_position_on_the_genomic_accession=15104257, orientation='plus', exon_count=3, OMIM=[606116], no_hdr0=''),
    10558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10558, CurrentID=0, Status='live', Symbol='SPTLC1', Aliases=['HSAN1', 'HSN1', 'LBC1', 'LCB1', 'SPT1', 'SPTI'], description='serine palmitoyltransferase long chain base subunit 1', other_designations='serine palmitoyltransferase 1|long chain base biosynthesis protein 1|serine C-palmitoyltransferase|serine-palmitoyl-CoA transferase 1', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92031141, end_position_on_the_genomic_accession=92115413, orientation='minus', exon_count=20, OMIM=[605712], no_hdr0=''),
    10559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10559, CurrentID=0, Status='live', Symbol='SLC35A1', Aliases=['CDG2F', 'CMPST', 'CST', 'hCST'], description='solute carrier family 35 member A1', other_designations='CMP-sialic acid transporter|CMP-SA-Tr|CMP-Sia-Tr|mutated CMP-sialic acid transporter A1|solute carrier family 35 (CMP-sialic acid transporter), member 1|solute carrier family 35 (CMP-sialic acid transporter), member A1|solute carrier family 35 (UDP-galactose transporter), member 1', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87472974, end_position_on_the_genomic_accession=87512336, orientation='plus', exon_count=8, OMIM=[605634], no_hdr0=''),
    10560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10560, CurrentID=0, Status='live', Symbol='SLC19A2', Aliases=['TC1', 'THMD1', 'THT1', 'THTR1', 'TRMA'], description='solute carrier family 19 member 2', other_designations='thiamine transporter 1|high affinity thiamine transporter|reduced folate carrier protein (RFC) like|solute carrier family 19 (thiamine transporter), member 2|thTr-1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169463909, end_position_on_the_genomic_accession=169485970, orientation='minus', exon_count=6, OMIM=[603941], no_hdr0=''),
    10561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10561, CurrentID=0, Status='live', Symbol='IFI44', Aliases=['MTAP44', 'TLDC5', 'p44'], description='interferon induced protein 44', other_designations='interferon-induced protein 44|TBC/LysM-associated domain containing 5|interferon-induced, hepatitis C-associated microtubular aggregate protein (44kD)|microtubule-associated protein 44', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=78648943, end_position_on_the_genomic_accession=78664078, orientation='plus', exon_count=10, OMIM=[610468], no_hdr0=''),
    10562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10562, CurrentID=0, Status='live', Symbol='OLFM4', Aliases=['GC1', 'GW112', 'OLM4', 'OlfD', 'UNQ362', 'bA209J19.1', 'hGC-1', 'hOLfD'], description='olfactomedin 4', other_designations='olfactomedin-4|G-CSF-stimulated clone 1 protein|antiapoptotic protein GW112', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=53028813, end_position_on_the_genomic_accession=53052057, orientation='plus', exon_count=5, OMIM=[614061], no_hdr0=''),
    10563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10563, CurrentID=0, Status='live', Symbol='CXCL13', Aliases=['ANGIE', 'ANGIE2', 'BCA-1', 'BCA1', 'BLC', 'BLR1L', 'SCYB13'], description='C-X-C motif chemokine ligand 13', other_designations="C-X-C motif chemokine 13|B-cell chemoattractant|B-cell-attracting chemokine 1|B-cell-homing chemokine (ligand for Burkitt's lymphoma receptor-1)|B-lymphocyte chemoattractant|CXC chemokine BLC|b cell-attracting chemokine 1|b lymphocyte chemoattractant|chemokine (C-X-C motif) ligand 13 (B-cell chemoattractant)|small inducible cytokine B subfamily (Cys-X-Cys motif), member 13 (B-cell chemoattractant)|small-inducible cytokine B13", map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=77511753, end_position_on_the_genomic_accession=77611834, orientation='plus', exon_count=5, OMIM=[605149], no_hdr0=''),
    10564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10564, CurrentID=0, Status='live', Symbol='ARFGEF2', Aliases=['BIG2', 'PVNH2', 'dJ1164I10.1'], description='ADP ribosylation factor guanine nucleotide exchange factor 2', other_designations='brefeldin A-inhibited guanine nucleotide-exchange protein 2|ADP-ribosylation factor guanine nucleotide-exchange factor 2 (brefeldin A-inhibited)|brefeldin A-inhibited GEP 2', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=48921711, end_position_on_the_genomic_accession=49036693, orientation='plus', exon_count=39, OMIM=[605371], no_hdr0=''),
    10565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10565, CurrentID=0, Status='live', Symbol='ARFGEF1', Aliases=['ARFGEP1', 'BIG1', 'P200'], description='ADP ribosylation factor guanine nucleotide exchange factor 1', other_designations='brefeldin A-inhibited guanine nucleotide-exchange protein 1|ADP-ribosylation factor guanine nucleotide-exchange factor 1 (brefeldin A-inhibited)|p200 ARF guanine nucleotide exchange factor', map_location='8q13.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=67174298, end_position_on_the_genomic_accession=67343824, orientation='minus', exon_count=40, OMIM=[604141], no_hdr0=''),
    10566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10566, CurrentID=0, Status='live', Symbol='AKAP3', Aliases=['AKAP 110', 'AKAP110', 'CT82', 'FSP95', 'HEL159', 'PRKA3', 'SOB1'], description='A-kinase anchoring protein 3', other_designations='A-kinase anchor protein 3|A kinase (PRKA) anchor protein 3|A-kinase anchor protein, 110kDa|Fibrous Sheath Protein of 95 kDa|cancer/testis antigen 82|epididymis luminal protein 159|epididymis secretory sperm binding protein|fibrousheathin I|fibrousheathin-1|protein kinase A binding protein AKAP 110|protein kinase A-anchoring protein 3|sperm oocyte-binding protein 1', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4615518, end_position_on_the_genomic_accession=4649051, orientation='minus', exon_count=6, OMIM=[604689], no_hdr0=''),
    10567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10567, CurrentID=0, Status='live', Symbol='RABAC1', Aliases=['PRA1', 'PRAF1', 'YIP3'], description='Rab acceptor 1', other_designations='prenylated Rab acceptor protein 1|PRA1 domain family 1|PRA1 family protein 1|Rab acceptor 1 (prenylated)|prenylated Rab acceptor 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41956683, end_position_on_the_genomic_accession=41959321, orientation='minus', exon_count=5, OMIM=[604925], no_hdr0=''),
    10568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10568, CurrentID=0, Status='live', Symbol='SLC34A2', Aliases=['NAPI-3B', 'NAPI-IIb', 'NPTIIb', 'PULAM'], description='solute carrier family 34 member 2', other_designations='sodium-dependent phosphate transport protein 2B|sodium/phosphate cotransporter 2B|solute carrier family 34 (sodium phosphate), member 2|solute carrier family 34 (type II sodium/phosphate cotransporter), member 2|type II sodium-dependent phosphate transporter 3b', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25655851, end_position_on_the_genomic_accession=25678748, orientation='plus', exon_count=14, OMIM=[604217], no_hdr0=''),
    10569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10569, CurrentID=0, Status='live', Symbol='SLU7', Aliases=['9G8', 'hSlu7'], description='SLU7 homolog, splicing factor', other_designations='pre-mRNA-splicing factor SLU7|SLU7 splicing factor homolog|splicing factor|step II splicing factor SLU7|zinc knuckle motif containing', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160401641, end_position_on_the_genomic_accession=160419081, orientation='minus', exon_count=18, OMIM=[605974], no_hdr0=''),
    10570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10570, CurrentID=0, Status='live', Symbol='DPYSL4', Aliases=['CRMP3', 'DRP-4', 'ULIP4'], description='dihydropyrimidinase like 4', other_designations='dihydropyrimidinase-related protein 4|CRMP-3|ULIP-4|UNC33-like phosphoprotein 4|collapsin response mediator protein 3', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132184983, end_position_on_the_genomic_accession=132205759, orientation='plus', exon_count=17, OMIM=[608407], no_hdr0=''),
    10572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10572, CurrentID=0, Status='live', Symbol='SIVA1', Aliases=['CD27BP', 'SIVA', 'Siva-1', 'Siva-2'], description='SIVA1 apoptosis inducing factor', other_designations='apoptosis regulatory protein Siva|CD27-binding (Siva) protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104752420, end_position_on_the_genomic_accession=104759659, orientation='plus', exon_count=4, OMIM=[605567], no_hdr0=''),
    10573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10573, CurrentID=0, Status='live', Symbol='MRPL28', Aliases=['MAAT1', 'p15'], description='mitochondrial ribosomal protein L28', other_designations='39S ribosomal protein L28, mitochondrial|L28mt|MRP-L28|melanoma antigen p15|melanoma-associated antigen recognised by cytotoxic T lymphocytes|melanoma-associated antigen recognized by T-lymphocytes|mitochondrial large ribosomal subunit protein bL28m', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=366969, end_position_on_the_genomic_accession=370538, orientation='minus', exon_count=6, OMIM=[604853], no_hdr0=''),
    10574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10574, CurrentID=0, Status='live', Symbol='CCT7', Aliases=['CCTETA', 'CCTH', 'NIP7-1', 'TCP1ETA'], description='chaperonin containing TCP1 subunit 7', other_designations='T-complex protein 1 subunit eta|CCT-eta|HIV-1 Nef interacting protein|TCP-1-eta|chaperonin containing t-complex polypeptide 1, eta subunit', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73233425, end_position_on_the_genomic_accession=73253008, orientation='plus', exon_count=14, OMIM=[605140], no_hdr0=''),
    10575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10575, CurrentID=0, Status='live', Symbol='CCT4', Aliases=['CCT-DELTA', 'Cctd', 'SRB'], description='chaperonin containing TCP1 subunit 4', other_designations='T-complex protein 1 subunit delta|TCP-1-delta|chaperonin containing TCP1, subunit 4 (delta)|chaperonin containing t-complex polypeptide 1, delta subunit|stimulator of TAR RNA-binding', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61868085, end_position_on_the_genomic_accession=61888671, orientation='minus', exon_count=14, OMIM=[605142], no_hdr0=''),
    10576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10576, CurrentID=0, Status='live', Symbol='CCT2', Aliases=['99D8.1', 'CCT-beta', 'CCTB', 'HEL-S-100n', 'PRO1633', 'TCP-1-beta'], description='chaperonin containing TCP1 subunit 2', other_designations='T-complex protein 1 subunit beta|T-complex protein 1, beta subunit|chaperonin containing TCP1, subunit 2 (beta)|chaperonin containing t-complex polypeptide 1, beta subunit|chaperonin containing t-complex polypeptide 1, subunit 2|epididymis secretory sperm binding protein Li 100n', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69585459, end_position_on_the_genomic_accession=69601570, orientation='plus', exon_count=17, OMIM=[605139], no_hdr0=''),
    10577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10577, CurrentID=0, Status='live', Symbol='NPC2', Aliases=['EDDM1', 'HE1'], description='NPC intracellular cholesterol transporter 2', other_designations='NPC intracellular cholesterol transporter 2|Niemann-Pick disease type C2 protein|epididymal protein 1|epididymis secretory sperm binding protein|human epididymis-specific protein 1|tissue-specific secretory protein', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74479935, end_position_on_the_genomic_accession=74493512, orientation='minus', exon_count=4, OMIM=[601015], no_hdr0=''),
    10578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10578, CurrentID=0, Status='live', Symbol='GNLY', Aliases=['D2S69E', 'LAG-2', 'LAG2', 'NKG5', 'TLA519'], description='granulysin', other_designations='granulysin|T-cell activation protein 519|T-lymphocyte activation gene 519|lymphocyte-activation gene 2|lymphokine LAG-2', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85694294, end_position_on_the_genomic_accession=85698854, orientation='plus', exon_count=6, OMIM=[188855], no_hdr0=''),
    10579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10579, CurrentID=0, Status='live', Symbol='TACC2', Aliases=['AZU-1', 'ECTACC'], description='transforming acidic coiled-coil containing protein 2', other_designations='transforming acidic coiled-coil-containing protein 2|anti zuai-1', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=121989163, end_position_on_the_genomic_accession=122254542, orientation='plus', exon_count=32, OMIM=[605302], no_hdr0=''),
    10580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10580, CurrentID=0, Status='live', Symbol='SORBS1', Aliases=['CAP', 'FLAF2', 'R85FL', 'SH3D5', 'SH3P12', 'SORB1'], description='sorbin and SH3 domain containing 1', other_designations='sorbin and SH3 domain-containing protein 1|Fas-ligand associated factor 2|SH3 domain protein 5|c-Cbl associated protein|ponsin', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95311773, end_position_on_the_genomic_accession=95561439, orientation='minus', exon_count=39, OMIM=[605264], no_hdr0=''),
    10581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10581, CurrentID=0, Status='live', Symbol='IFITM2', Aliases=['1-8D', 'DSPA2c'], description='interferon induced transmembrane protein 2', other_designations='interferon-induced transmembrane protein 2|dispanin subfamily A member 2c|interferon-inducible protein 1-8D', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=307816, end_position_on_the_genomic_accession=309395, orientation='plus', exon_count=2, OMIM=[605578], no_hdr0=''),
    10584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10584, CurrentID=0, Status='live', Symbol='COLEC10', Aliases=['3MC3', 'CL-10', 'CL-34', 'CLL1'], description='collectin subfamily member 10', other_designations='collectin-10|collectin liver 1|collectin liver protein 1|collectin sub-family member 10 (C-type lectin)|collectin-34', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=118952233, end_position_on_the_genomic_accession=119108455, orientation='plus', exon_count=9, OMIM=[607620], no_hdr0=''),
    10585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10585, CurrentID=0, Status='live', Symbol='POMT1', Aliases=['LGMD2K', 'LGMDR11', 'MDDGA1', 'MDDGB1', 'MDDGC1', 'RT'], description='protein O-mannosyltransferase 1', other_designations='protein O-mannosyl-transferase 1|dolichyl-phosphate-mannose--protein mannosyltransferase 1|testis tissue sperm-binding protein Li 57p|truncated O-mannosyl-transferase 1 variant SV3DEL', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131502902, end_position_on_the_genomic_accession=131523803, orientation='plus', exon_count=21, OMIM=[607423], no_hdr0=''),
    10586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10586, CurrentID=0, Status='live', Symbol='MAB21L2', Aliases=['MCOPS14', 'MCSKS14'], description='mab-21 like 2', other_designations='protein mab-21-like 2', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=150582151, end_position_on_the_genomic_accession=150584693, orientation='plus', exon_count=1, OMIM=[604357], no_hdr0=''),
    10587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10587, CurrentID=0, Status='live', Symbol='TXNRD2', Aliases=['GCCD5', 'SELZ', 'TR', 'TR-BETA', 'TR3', 'TRXR2'], description='thioredoxin reductase 2', other_designations='thioredoxin reductase 2, mitochondrial|selenoprotein Z|thioredoxin reductase 3|thioredoxin reductase TR3|thioredoxin reductase beta', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19875522, end_position_on_the_genomic_accession=19941818, orientation='minus', exon_count=22, OMIM=[606448], no_hdr0=''),
    10588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10588, CurrentID=0, Status='live', Symbol='MTHFS', Aliases=['HsT19268', 'NEDMEHM'], description='methenyltetrahydrofolate synthetase', other_designations='5-formyltetrahydrofolate cyclo-ligase|5,10-methenyltetrahydrofolate synthetase (5-formyltetrahydrofolate cyclo-ligase)|methenyl-THF synthetase', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79843547, end_position_on_the_genomic_accession=79897285, orientation='minus', exon_count=4, OMIM=[604197], no_hdr0=''),
    10589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10589, CurrentID=0, Status='live', Symbol='DRAP1', Aliases=['NC2-alpha'], description='DR1 associated protein 1', other_designations='dr1-associated corepressor|negative co-factor 2-alpha|negative cofactor 2 alpha', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65919426, end_position_on_the_genomic_accession=65921563, orientation='plus', exon_count=7, OMIM=[602289], no_hdr0=''),
    10590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10590, CurrentID=0, Status='live', Symbol='SCGN', Aliases=['CALBL', 'DJ501N12.8', 'SECRET', 'SEGN', 'setagin'], description='secretagogin, EF-hand calcium binding protein', other_designations='secretagogin', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25652215, end_position_on_the_genomic_accession=25701783, orientation='plus', exon_count=12, OMIM=[609202], no_hdr0=''),
    10591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10591, CurrentID=0, Status='live', Symbol='DNPH1', Aliases=['C6orf108', 'RCL', 'dJ330M21.3'], description="2'-deoxynucleoside 5'-phosphate N-hydrolase 1", other_designations="2'-deoxynucleoside 5'-phosphate N-hydrolase 1|c-Myc-responsive protein RCL|deoxyribonucleoside 5'-monophosphate N-glycosidase|putative c-Myc-responsive", map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43225629, end_position_on_the_genomic_accession=43229481, orientation='minus', exon_count=4, OMIM=[618762], no_hdr0=''),
    10592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10592, CurrentID=0, Status='live', Symbol='SMC2', Aliases=['CAP-E', 'CAPE', 'SMC-2L1', 'SMC2'], description='structural maintenance of chromosomes 2', other_designations='structural maintenance of chromosomes protein 2|SMC protein 2|SMC2 (structural maintenance of chromosomes 2, yeast)-like 1|XCAP-E homolog|chromosome-associated protein E|structural maintenance of chromosomes (SMC) family member, chromosome-associated protein E', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104093760, end_position_on_the_genomic_accession=104141419, orientation='plus', exon_count=29, OMIM=[605576], no_hdr0=''),
    10594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10594, CurrentID=0, Status='live', Symbol='PRPF8', Aliases=['HPRP8', 'PRP8', 'PRPC8', 'RP13', 'SNRNP220'], description='pre-mRNA processing factor 8', other_designations='pre-mRNA-processing-splicing factor 8|220 kDa U5 snRNP-specific protein|PRP8 homolog|PRP8 pre-mRNA processing factor 8 homolog|U5 snRNP-specific protein (220 kD), ortholog of S. cerevisiae Prp8p|apoptosis-regulated protein 1|apoptosis-regulated protein 2|p220|precursor mRNA processing protein|splicing factor Prp8', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1650629, end_position_on_the_genomic_accession=1684880, orientation='minus', exon_count=43, OMIM=[607300], no_hdr0=''),
    10595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10595, CurrentID=0, Status='live', Symbol='ERN2', Aliases=['IRE1-BETA', 'IRE1b', 'IRE2p', 'hIRE2p'], description='endoplasmic reticulum to nucleus signaling 2', other_designations='serine/threonine-protein kinase/endoribonuclease IRE2|ER to nucleus signalling 2|IRE1 beta|IRE1, S. cerevisiae, homolog of|endoplasmic reticulum to nucleus signalling 2|inositol-requiring 1 beta|inositol-requiring protein 2', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23690310, end_position_on_the_genomic_accession=23713248, orientation='minus', exon_count=24, OMIM=[604034], no_hdr0=''),
    10597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10597, CurrentID=0, Status='live', Symbol='TRAPPC2B', Aliases=['MIP-2A', 'SEDLP', 'SEDLP1', 'TRAPPC2P1'], description='trafficking protein particle complex subunit 2B', other_designations='trafficking protein particle complex subunit 2B|MBP-1 interacting protein-2A|spondyloepiphyseal dysplasia, late, pseudogene|trafficking protein particle complex 2 pseudogene 1|trafficking protein particle complex 2B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57363551, end_position_on_the_genomic_accession=57365405, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    10598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10598, CurrentID=0, Status='live', Symbol='AHSA1', Aliases=['AHA1', 'C14orf3', 'hAha1', 'p38'], description='activator of HSP90 ATPase activity 1', other_designations='activator of 90 kDa heat shock protein ATPase homolog 1|AHA1, activator of heat shock 90kDa protein ATPase homolog 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77457867, end_position_on_the_genomic_accession=77469472, orientation='plus', exon_count=10, OMIM=[608466], no_hdr0=''),
    10599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10599, CurrentID=0, Status='live', Symbol='SLCO1B1', Aliases=['HBLRR', 'LST-1', 'LST1', 'OATP-C', 'OATP1B1', 'OATP2', 'OATPC', 'SLC21A6'], description='solute carrier organic anion transporter family member 1B1', other_designations='solute carrier organic anion transporter family member 1B1|OATP-2|liver-specific organic anion transporter 1|sodium-independent organic anion-transporting polypeptide 2|solute carrier family 21 (organic anion transporter), member 6', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21131194, end_position_on_the_genomic_accession=21239796, orientation='plus', exon_count=15, OMIM=[604843], no_hdr0=''),
    10600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10600, CurrentID=0, Status='live', Symbol='USP16', Aliases=['UBP-M', 'UBPM'], description='ubiquitin specific peptidase 16', other_designations='ubiquitin carboxyl-terminal hydrolase 16|deubiquitinating enzyme 16|ubiquitin specific protease 16|ubiquitin thioesterase 16|ubiquitin thiolesterase 16|ubiquitin-processing protease UBP-M|ubiquitin-specific processing protease 16', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29024651, end_position_on_the_genomic_accession=29054488, orientation='plus', exon_count=20, OMIM=[604735], no_hdr0=''),
    10602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10602, CurrentID=0, Status='live', Symbol='CDC42EP3', Aliases=['BORG2', 'CEP3', 'UB1'], description='CDC42 effector protein 3', other_designations='cdc42 effector protein 3|CDC42 effector protein (Rho GTPase binding) 3|CRIB-containing BORG2 protein|MSE55-related Cdc42-binding protein|MSE55-related protein|binder of Rho GTPases 2', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37641944, end_position_on_the_genomic_accession=37672949, orientation='minus', exon_count=6, OMIM=[606133], no_hdr0=''),
    10603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10603, CurrentID=0, Status='live', Symbol='SH2B2', Aliases=['APS'], description='SH2B adaptor protein 2', other_designations='SH2B adapter protein 2|SH2 and PH domain-containing adapter protein APS|adapter protein with pleckstrin homology and Src homology 2 domains', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102285141, end_position_on_the_genomic_accession=102321711, orientation='plus', exon_count=11, OMIM=[605300], no_hdr0=''),
    10605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10605, CurrentID=0, Status='live', Symbol='PAIP1', Aliases=[], description='poly(A) binding protein interacting protein 1', other_designations='polyadenylate-binding protein-interacting protein 1|PABC1-interacting protein 1|PABP-interacting protein 1|PAIP-1', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43526267, end_position_on_the_genomic_accession=43557411, orientation='minus', exon_count=13, OMIM=[605184], no_hdr0=''),
    10606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10606, CurrentID=0, Status='live', Symbol='PAICS', Aliases=['ADE2', 'ADE2H1', 'AIRC', 'PAIS'], description='phosphoribosylaminoimidazole carboxylase and phosphoribosylaminoimidazolesuccinocarboxamide synthase', other_designations='multifunctional protein ADE2|AIR carboxylase|SAICAR synthetase|multifunctional protein ADE2H1|phosphoribosylaminoimidazole carboxylase, phosphoribosylaminoimidazole succinocarboxamide synthetase|phosphoribosylaminoimidazole carboxylase; phosphoribosylaminoimidazolesuccinocarboxamide synthase', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56410507, end_position_on_the_genomic_accession=56464578, orientation='plus', exon_count=16, OMIM=[172439], no_hdr0=''),
    10607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10607, CurrentID=0, Status='live', Symbol='TBL3', Aliases=['SAZD', 'UTP13'], description='transducin beta like 3', other_designations='transducin beta-like protein 3|WD repeat-containing protein SAZD|WD-repeat protein SAZD', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1972053, end_position_on_the_genomic_accession=1982929, orientation='plus', exon_count=22, OMIM=[605915], no_hdr0=''),
    10608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10608, CurrentID=0, Status='live', Symbol='MXD4', Aliases=['MAD4', 'MST149', 'MSTP149', 'bHLHc12'], description='MAX dimerization protein 4', other_designations='max dimerization protein 4|Mad4 homolog|class C basic helix-loop-helix protein 12|max dimerizer 4|max-associated protein 4|max-interacting transcriptional repressor MAD4', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2247432, end_position_on_the_genomic_accession=2262109, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    10609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10609, CurrentID=0, Status='live', Symbol='P3H4', Aliases=['LEPREL4', 'NO55', 'NOL55', 'SC65'], description='prolyl 3-hydroxylase family member 4 (inactive)', other_designations='endoplasmic reticulum protein SC65|leprecan-like 4|leprecan-like protein 4|nucleolar autoantigen (55kD)|nucleolar autoantigen No55|nucleolar autoantigen, 55kDa|prolyl 3-hydroxylase family member 4 (non-enzymatic)|synaptonemal complex 65|synaptonemal complex protein SC65', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41801952, end_position_on_the_genomic_accession=41812710, orientation='minus', exon_count=9, OMIM=[617419], no_hdr0=''),
    10610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10610, CurrentID=0, Status='live', Symbol='ST6GALNAC2', Aliases=['SAITL1', 'SIAT7', 'SIAT7B', 'SIATL1', 'ST6GalNAII', 'STHM'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 2', other_designations='alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase 2|(alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide B|(alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase|SIAT7-B|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 2|ST6 GalNAc alpha-2,6-sialyltransferase 2|ST6GALNAC2, alpha-2,6-sialyltransferase 2|ST6GalNAc II|ST6GalNAcII|galNAc alpha-2,6-sialyltransferase II|sialyltransferase 7 ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide B|sialyltransferase 7 ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase) B|sialyltransferase 7B|sialyltransferase-like 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76565377, end_position_on_the_genomic_accession=76586128, orientation='minus', exon_count=11, OMIM=[610137], no_hdr0=''),
    10611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10611, CurrentID=0, Status='live', Symbol='PDLIM5', Aliases=['ENH', 'ENH1', 'L9', 'LIM'], description='PDZ and LIM domain 5', other_designations='PDZ and LIM domain protein 5|enigma homolog|enigma-like LIM domain protein|enigma-like PDZ and LIM domains protein', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=94451942, end_position_on_the_genomic_accession=94668223, orientation='plus', exon_count=21, OMIM=[605904], no_hdr0=''),
    10612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10612, CurrentID=0, Status='live', Symbol='TRIM3', Aliases=['BERP', 'HAC1', 'RNF22', 'RNF97'], description='tripartite motif containing 3', other_designations='tripartite motif-containing protein 3|RING finger protein 97|brain expressed ring finger|brain-expressed RING finger protein|ring finger protein 22|tripartite motif protein TRIM3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6448613, end_position_on_the_genomic_accession=6474459, orientation='minus', exon_count=14, OMIM=[605493], no_hdr0=''),
    10613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10613, CurrentID=0, Status='live', Symbol='ERLIN1', Aliases=['C10orf69', 'Erlin-1', 'KE04', 'KEO4', 'SPFH1', 'SPG62'], description='ER lipid raft associated 1', other_designations='erlin-1|Band_7 23-211 Keo4 (Interim) similar to C.elegans protein C42C1.9|SPFH domain family, member 1|SPFH domain-containing protein 1|endoplasmic reticulum lipid raft-associated protein 1|stomatin-prohibitin-flotillin-HflC/K domain-containing protein 1', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100150094, end_position_on_the_genomic_accession=100186029, orientation='minus', exon_count=13, OMIM=[611604], no_hdr0=''),
    10614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10614, CurrentID=0, Status='live', Symbol='HEXIM1', Aliases=['CLP1', 'EDG1', 'HIS1', 'MAQ1'], description='HEXIM P-TEFb complex subunit 1', other_designations='protein HEXIM1|HMBA-inducible|cardiac lineage protein 1|estrogen down-regulated gene 1 protein|hexamethylene bis-acetamide inducible 1|hexamethylene bis-acetamide-inducible protein 1|hexamethylene bisacetamide inducible 1|hexamethylene bisacetamide-inducible protein|hexamethylene-bis-acetamide-inducible transcript 1|hexamthylene bis-acetamide inducible 1|menage a quatre 1|menage a quatre protein 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45148475, end_position_on_the_genomic_accession=45152099, orientation='plus', exon_count=1, OMIM=[607328], no_hdr0=''),
    10615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10615, CurrentID=0, Status='live', Symbol='SPAG5', Aliases=['DEEPEST', 'MAP126', 'hMAP126'], description='sperm associated antigen 5', other_designations='sperm-associated antigen 5|astrin|mitotic spindle associated protein p126|mitotic spindle coiled-coil related protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28577574, end_position_on_the_genomic_accession=28599025, orientation='minus', exon_count=24, OMIM=[615562], no_hdr0=''),
    10616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10616, CurrentID=0, Status='live', Symbol='RBCK1', Aliases=['C20orf18', 'HOIL-1', 'HOIL1', 'PBMEI', 'PGBM1', 'RBCK2', 'RNF54', 'UBCE7IP3', 'XAP3', 'XAP4', 'ZRANB4'], description='RANBP2-type and C3HC4-type zinc finger containing 1', other_designations='ranBP-type and C3HC4-type zinc finger-containing protein 1|HBV-associated factor 4|RBCC protein interacting with PKC1|RING finger protein 54|RING-type E3 ubiquitin transferase HOIL-1|heme-oxidized IRP2 ubiquitin ligase 1|hepatitis B virus X-associated protein 4|ubiquitin conjugating enzyme 7 interacting protein 3', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=408299, end_position_on_the_genomic_accession=432139, orientation='plus', exon_count=15, OMIM=[610924], no_hdr0=''),
    10617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10617, CurrentID=0, Status='live', Symbol='STAMBP', Aliases=['AMSH', 'MICCAP'], description='STAM binding protein', other_designations='STAM-binding protein|associated molecule with the SH3 domain of STAM|endosome-associated ubiquitin isopeptidase|testicular secretory protein Li 54', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73828911, end_position_on_the_genomic_accession=73873656, orientation='plus', exon_count=15, OMIM=[606247], no_hdr0=''),
    10618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10618, CurrentID=0, Status='live', Symbol='TGOLN2', Aliases=['TGN38', 'TGN46', 'TGN48', 'TGN51', 'TTGN2', 'hTGN46', 'hTGN48', 'hTGN51'], description='trans-golgi network protein 2', other_designations='trans-Golgi network integral membrane protein 2|TGN38 homolog|trans-Golgi network glycoprotein 46|trans-Golgi network glycoprotein 48|trans-Golgi network glycoprotein 51|trans-Golgi network protein TGN51', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85318027, end_position_on_the_genomic_accession=85327989, orientation='minus', exon_count=5, OMIM=[603062], no_hdr0=''),
    10620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10620, CurrentID=0, Status='live', Symbol='ARID3B', Aliases=['BDP', 'DRIL2'], description='AT-rich interaction domain 3B', other_designations='AT-rich interactive domain-containing protein 3B|ARID domain-containing protein 3B|AT rich interactive domain 3B (BRIGHT- like)|bright and dead ringer protein|bright-like protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74541220, end_position_on_the_genomic_accession=74598131, orientation='plus', exon_count=9, OMIM=[612457], no_hdr0=''),
    10621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10621, CurrentID=0, Status='live', Symbol='POLR3F', Aliases=['C34', 'RPC39', 'RPC6'], description='RNA polymerase III subunit F', other_designations='DNA-directed RNA polymerase III subunit RPC6|RNA polymerase III C39 subunit|RNA polymerase III subunit C6|polymerase (RNA) III (DNA directed) polypeptide F, 39 kDa|polymerase (RNA) III subunit F', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18467390, end_position_on_the_genomic_accession=18484646, orientation='plus', exon_count=10, OMIM=[617455], no_hdr0=''),
    10622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10622, CurrentID=0, Status='live', Symbol='POLR3G', Aliases=['C31', 'RPC32', 'RPC7'], description='RNA polymerase III subunit G', other_designations='DNA-directed RNA polymerase III subunit RPC7|DNA-directed RNA polymerase III 32 kDa polypeptide|DNA-directed RNA polymerase III subunit G|RNA polymerase III 32 kDa apha subunit|RNA polymerase III 32 kDa subunit|RNA polymerase III subunit C7|RPC32-alpha|polymerase (RNA) III (DNA directed) polypeptide G (32kD)|polymerase (RNA) III subunit G', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=90473929, end_position_on_the_genomic_accession=90514557, orientation='plus', exon_count=11, OMIM=[617456], no_hdr0=''),
    10623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10623, CurrentID=0, Status='live', Symbol='POLR3C', Aliases=['C82', 'RPC3', 'RPC62'], description='RNA polymerase III subunit C', other_designations='DNA-directed RNA polymerase III subunit RPC3|DNA-directed III 62 kDa polypeptide|DNA-directed RNA polymerase III subunit C|RNA polymerase III 62 kDa subunit|RNA polymerase III subunit C3|polymerase (RNA) III (DNA directed) polypeptide C (62kD)|polymerase (RNA) III subunit C', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145823183, end_position_on_the_genomic_accession=145844402, orientation='plus', exon_count=15, OMIM=[617454], no_hdr0=''),
    10625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10625, CurrentID=0, Status='live', Symbol='IVNS1ABP', Aliases=['ARA3', 'FLARA3', 'HSPC068', 'IMD70', 'KLHL39', 'ND1', 'NS-1', 'NS1-BP', 'NS1BP'], description='influenza virus NS1A binding protein', other_designations='influenza virus NS1A-binding protein|NCX downstream gene 1|NS1-binding protein|aryl hydrocarbon receptor-associated 3|aryl hydrocarbon receptor-associated protein 3|kelch-like family member 39|kelch-like protein 39', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=185292367, end_position_on_the_genomic_accession=185317292, orientation='minus', exon_count=16, OMIM=[609209], no_hdr0=''),
    10626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10626, CurrentID=0, Status='live', Symbol='TRIM16', Aliases=['EBBP'], description='tripartite motif containing 16', other_designations='tripartite motif-containing protein 16|E3 ubiquitin-protein ligase TRIM16|estrogen-responsive B box protein', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15627966, end_position_on_the_genomic_accession=15684311, orientation='minus', exon_count=12, OMIM=[609505], no_hdr0=''),
    10627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10627, CurrentID=0, Status='live', Symbol='MYL12A', Aliases=['HEL-S-24', 'MLC-2B', 'MLCB', 'MRCL3', 'MRLC3', 'MYL2B'], description='myosin light chain 12A', other_designations='myosin regulatory light chain 12A|epididymis secretory protein Li 24|myosin RLC|myosin regulatory light chain 2, nonsarcomeric|myosin regulatory light chain 3|myosin regulatory light chain MRLC3|myosin, light chain 12A, regulatory, non-sarcomeric|myosin, light polypeptide, regulatory, non-sarcomeric (20kD)', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=3247482, end_position_on_the_genomic_accession=3256237, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    10628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10628, CurrentID=0, Status='live', Symbol='TXNIP', Aliases=['ARRDC6', 'EST01027', 'HHCPA78', 'THIF', 'VDUP1'], description='thioredoxin interacting protein', other_designations='thioredoxin-interacting protein|thioredoxin binding protein 2|upregulated by 1,25-dihydroxyvitamin D-3|vitamin D3 up-regulated protein 1', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145992435, end_position_on_the_genomic_accession=145996579, orientation='minus', exon_count=7, OMIM=[606599], no_hdr0=''),
    10629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10629, CurrentID=0, Status='live', Symbol='TAF6L', Aliases=['PAF65A'], description='TATA-box binding protein associated factor 6 like', other_designations='TAF6-like RNA polymerase II p300/CBP-associated factor-associated factor 65 kDa subunit 6L|PAF65-alpha|PCAF-associated factor 65-alpha|TAF6-like RNA polymerase II, p300/CBP-associated factor (PCAF)-associated factor, 65kDa|p300/CBP-associated factor (PCAF)-associated factor 65', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62771396, end_position_on_the_genomic_accession=62787342, orientation='plus', exon_count=11, OMIM=[602946], no_hdr0=''),
    10630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10630, CurrentID=0, Status='live', Symbol='PDPN', Aliases=['AGGRUS', 'GP36', 'GP40', 'Gp38', 'HT1A-1', 'OTS8', 'PA2.26', 'T1A', 'T1A-2', 'T1A2', 'TI1A'], description='podoplanin', other_designations='podoplanin|PA2.26 antigen|T1-alpha|glycoprotein 36|glycoprotein, 36-KD|hT1alpha-1|hT1alpha-2|lung type I cell membrane associated glycoprotein|lung type-I cell membrane-associated glycoprotein (T1A-2)', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13583757, end_position_on_the_genomic_accession=13617957, orientation='plus', exon_count=8, OMIM=[608863], no_hdr0=''),
    10631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10631, CurrentID=0, Status='live', Symbol='POSTN', Aliases=['OSF-2', 'OSF2', 'PDLPOSTN', 'PN'], description='periostin', other_designations='periostin|osteoblast specific factor 2 (fasciclin I-like)|periodontal ligament-specific periostin|periostin, osteoblast specific factor', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=37562585, end_position_on_the_genomic_accession=37598839, orientation='minus', exon_count=25, OMIM=[608777], no_hdr0=''),
    10632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10632, CurrentID=0, Status='live', Symbol='ATP5MG', Aliases=['ATP5JG', 'ATP5L'], description='ATP synthase membrane subunit g', other_designations='ATP synthase subunit g, mitochondrial|ATP synthase g chain, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit G|ATP synthase, H+ transporting, mitochondrial F1F0, subunit g|ATP synthase, H+ transporting, mitochondrial Fo complex subunit G|ATPase subunit G|F1F0-type ATP synthase subunit g|F1Fo-ATP synthase complex Fo membrane domain g subunit', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118401606, end_position_on_the_genomic_accession=118409847, orientation='plus', exon_count=4, OMIM=[617473], no_hdr0=''),
    10633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10633, CurrentID=0, Status='live', Symbol='RASL10A', Aliases=['RRP22'], description='RAS like family 10 member A', other_designations='ras-like protein family member 10A|ras-like protein RRP22|ras-related protein on chromosome 22', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29312933, end_position_on_the_genomic_accession=29319618, orientation='minus', exon_count=6, OMIM=[602220], no_hdr0=''),
    10634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10634, CurrentID=0, Status='live', Symbol='GAS2L1', Aliases=['GAR22'], description='growth arrest specific 2 like 1', other_designations='GAS2-like protein 1|GAS2-related protein on chromosome 22|epididymis secretory sperm binding protein|growth arrest-specific protein 2-like 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29306650, end_position_on_the_genomic_accession=29312787, orientation='plus', exon_count=7, OMIM=[602128], no_hdr0=''),
    10635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10635, CurrentID=0, Status='live', Symbol='RAD51AP1', Aliases=['PIR51'], description='RAD51 associated protein 1', other_designations='RAD51-associated protein 1|RAD51-interacting protein|hsRAD51AP1', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4538890, end_position_on_the_genomic_accession=4560047, orientation='plus', exon_count=10, OMIM=[603070], no_hdr0=''),
    10636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10636, CurrentID=0, Status='live', Symbol='RGS14', Aliases=[], description='regulator of G protein signaling 14', other_designations='regulator of G-protein signaling 14', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177357672, end_position_on_the_genomic_accession=177372601, orientation='plus', exon_count=15, OMIM=[602513], no_hdr0=''),
    10637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10637, CurrentID=0, Status='live', Symbol='LEFTY1', Aliases=['LEFTB', 'LEFTYB'], description='left-right determination factor 1', other_designations='left-right determination factor 1|left-right determination factor B|protein lefty-1|protein lefty-B', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225886282, end_position_on_the_genomic_accession=225889146, orientation='minus', exon_count=4, OMIM=[603037], no_hdr0=''),
    10640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10640, CurrentID=0, Status='live', Symbol='EXOC5', Aliases=['HSEC10', 'PRO1912', 'SEC10', 'SEC10L1', 'SEC10P'], description='exocyst complex component 5', other_designations='exocyst complex component 5|SEC10-like 1|exocyst complex component Sec10', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57200507, end_position_on_the_genomic_accession=57268905, orientation='minus', exon_count=18, OMIM=[604469], no_hdr0=''),
    10641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10641, CurrentID=0, Status='live', Symbol='NPRL2', Aliases=['FFEVF2', 'NPR2', 'NPR2L', 'TUSC4'], description='NPR2 like, GATOR1 complex subunit', other_designations='GATOR complex protein NPRL2|2810446G01Rik|G21 protein|NPR2-like protein|gene 21 protein|homologous to yeast nitrogen permease (candidate tumor suppressor)|nitrogen permease regulator 2-like protein|tumor suppressor candidate 4', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50347330, end_position_on_the_genomic_accession=50350821, orientation='minus', exon_count=11, OMIM=[607072], no_hdr0=''),
    10642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10642, CurrentID=0, Status='live', Symbol='IGF2BP1', Aliases=['CRD-BP', 'CRDBP', 'IMP-1', 'IMP1', 'VICKZ1', 'ZBP1'], description='insulin like growth factor 2 mRNA binding protein 1', other_designations='insulin-like growth factor 2 mRNA-binding protein 1|IGF-II mRNA-binding protein 1|IGF2 mRNA-binding protein 1|VICKZ family member 1|ZBP-1|coding region determinant-binding protein|insulin-like growth factor 2 mRNA binding protein 1 deltaN CRDBP|zipcode-binding protein 1', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48997385, end_position_on_the_genomic_accession=49056145, orientation='plus', exon_count=16, OMIM=[608288], no_hdr0=''),
    10643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10643, CurrentID=0, Status='live', Symbol='IGF2BP3', Aliases=['CT98', 'IMP-3', 'IMP3', 'KOC', 'KOC1', 'VICKZ3'], description='insulin like growth factor 2 mRNA binding protein 3', other_designations='insulin-like growth factor 2 mRNA-binding protein 3|IGF-II mRNA-binding protein 3|IGF2 mRNA-binding protein 3|KH domain containing protein overexpressed in cancer|VICKZ family member 3|cancer/testis antigen 98', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23310209, end_position_on_the_genomic_accession=23470674, orientation='minus', exon_count=18, OMIM=[608259], no_hdr0=''),
    10644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10644, CurrentID=0, Status='live', Symbol='IGF2BP2', Aliases=['IMP-2', 'IMP2', 'VICKZ2'], description='insulin like growth factor 2 mRNA binding protein 2', other_designations='insulin-like growth factor 2 mRNA-binding protein 2|IGF-II mRNA-binding protein 2|IGF2 mRNA-binding protein 2|VICKZ family member 2', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185643130, end_position_on_the_genomic_accession=185825046, orientation='minus', exon_count=24, OMIM=[608289], no_hdr0=''),
    10645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10645, CurrentID=0, Status='live', Symbol='CAMKK2', Aliases=['CAMKK', 'CAMKKB'], description='calcium/calmodulin dependent protein kinase kinase 2', other_designations='calcium/calmodulin-dependent protein kinase kinase 2|CAMKK beta protein|caM-KK 2|caM-KK beta|caM-kinase kinase 2|caM-kinase kinase beta|calcium/calmodulin-dependent protein kinase beta|calcium/calmodulin-dependent protein kinase kinase 2, beta', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121237692, end_position_on_the_genomic_accession=121297819, orientation='minus', exon_count=20, OMIM=[615002], no_hdr0=''),
    10647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10647, CurrentID=0, Status='live', Symbol='SCGB1D2', Aliases=['LIPB', 'LPHB', 'LPNB'], description='secretoglobin family 1D member 2', other_designations='secretoglobin family 1D member 2|lipophilin-B|prostatein-like lipophilin B', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62242239, end_position_on_the_genomic_accession=62244812, orientation='plus', exon_count=3, OMIM=[615061], no_hdr0=''),
    10648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10648, CurrentID=0, Status='live', Symbol='SCGB1D1', Aliases=['LIPA', 'LPHA', 'LPNA'], description='secretoglobin family 1D member 1', other_designations='secretoglobin family 1D member 1|lipophilin A (uteroglobin family member)|lipophilin-A|prostatein-like lipophilin A', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62190216, end_position_on_the_genomic_accession=62193539, orientation='plus', exon_count=3, OMIM=[615060], no_hdr0=''),
    10650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10650, CurrentID=0, Status='live', Symbol='PRELID3A', Aliases=['C18orf43', 'HFL-EDDG1', 'SLMO1'], description='PRELI domain containing 3A', other_designations='PRELI domain containing protein 3A|erythroid differentiation and denucleation factor 1|protein slowmo homolog 1|slowmo homolog 1', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12407929, end_position_on_the_genomic_accession=12432238, orientation='plus', exon_count=8, OMIM=[616545], no_hdr0=''),
    10651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10651, CurrentID=0, Status='live', Symbol='MTX2', Aliases=['MDPS', 'metaxin-2'], description='metaxin 2', other_designations='metaxin-2|mitochondrial outer membrane import complex protein 2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176269423, end_position_on_the_genomic_accession=176338025, orientation='plus', exon_count=12, OMIM=[608555], no_hdr0=''),
    10652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10652, CurrentID=0, Status='live', Symbol='YKT6', Aliases=[], description='YKT6 v-SNARE homolog', other_designations='synaptobrevin homolog YKT6|R-SNARE|SNARE protein Ykt6|YKT6 v-SNARE protein|YKT6, S. cerevisiae, homolog of', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44200978, end_position_on_the_genomic_accession=44214294, orientation='plus', exon_count=8, OMIM=[606209], no_hdr0=''),
    10653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10653, CurrentID=0, Status='live', Symbol='SPINT2', Aliases=['DIAR3', 'HAI-2', 'HAI2', 'Kop', 'PB'], description='serine peptidase inhibitor, Kunitz type 2', other_designations='kunitz-type protease inhibitor 2|hepatocyte growth factor activator inhibitor type 2|serine protease inhibitor, Kunitz type, 2|testicular tissue protein Li 183', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38264573, end_position_on_the_genomic_accession=38292615, orientation='plus', exon_count=7, OMIM=[605124], no_hdr0=''),
    10654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10654, CurrentID=0, Status='live', Symbol='PMVK', Aliases=['HUMPMKI', 'PMK', 'PMKA', 'PMKASE', 'POROK1'], description='phosphomevalonate kinase', other_designations='phosphomevalonate kinase|testis tissue sperm-binding protein Li 95mP', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154924740, end_position_on_the_genomic_accession=154942658, orientation='minus', exon_count=6, OMIM=[607622], no_hdr0=''),
    10655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10655, CurrentID=0, Status='live', Symbol='DMRT2', Aliases=['DSXL-2'], description='doublesex and mab-3 related transcription factor 2', other_designations='doublesex- and mab-3-related transcription factor 2|doublesex-like 2 protein|terra-like protein', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=1003237, end_position_on_the_genomic_accession=1057554, orientation='plus', exon_count=10, OMIM=[604935], no_hdr0=''),
    10656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10656, CurrentID=0, Status='live', Symbol='KHDRBS3', Aliases=['Etle', 'SALP', 'SLM-2', 'SLM2', 'T-STAR', 'TSTAR', 'etoile'], description='KH RNA binding domain containing, signal transduction associated 3', other_designations='KH domain-containing, RNA-binding, signal transduction-associated protein 3|KH domain containing, RNA binding, signal transduction associated 3|RNA-binding protein T-Star|Sam68-like phosphotyrosine protein, T-STAR|sam68-like mammalian protein 2', map_location='8q24.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=135457456, end_position_on_the_genomic_accession=135656516, orientation='plus', exon_count=17, OMIM=[610421], no_hdr0=''),
    10657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10657, CurrentID=0, Status='live', Symbol='KHDRBS1', Aliases=['Sam68', 'p62', 'p68'], description='KH RNA binding domain containing, signal transduction associated 1', other_designations='KH domain-containing, RNA-binding, signal transduction-associated protein 1|GAP-associated tyrosine phosphoprotein p62 (Sam68)|KH domain containing, RNA binding, signal transduction associated 1|p21 Ras GTPase-activating protein-associated p62|src-associated in mitosis 68 kDa protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32013868, end_position_on_the_genomic_accession=32060850, orientation='plus', exon_count=11, OMIM=[602489], no_hdr0=''),
    10658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10658, CurrentID=0, Status='live', Symbol='CELF1', Aliases=['BRUNOL2', 'CUG-BP', 'CUGBP', 'CUGBP1', 'EDEN-BP', 'NAB50', 'NAPOR', 'hNab50'], description='CUGBP Elav-like family member 1', other_designations='CUGBP Elav-like family member 1|50 kDa nuclear polyadenylated RNA-binding protein|CUG RNA-binding protein|CUG triplet repeat RNA-binding protein 1|CUG-BP- and ETR-3-like factor 1|EDEN-BP homolog|RNA-binding protein BRUNOL-2|bruno-like 2|bruno-like protein 2|deadenylation factor CUG-BP|embryo deadenylation element binding protein|embryo deadenylation element-binding protein homolog|nuclear polyadenylated RNA-binding protein, 50-kD', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47465937, end_position_on_the_genomic_accession=47565539, orientation='minus', exon_count=21, OMIM=[601074], no_hdr0=''),
    10659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10659, CurrentID=0, Status='live', Symbol='CELF2', Aliases=['BRUNOL3', 'CELF-2', 'CUG-BP2', 'CUGBP2', 'ETR-3', 'ETR3', 'NAPOR'], description='CUGBP Elav-like family member 2', other_designations='CUGBP Elav-like family member 2|CUG triplet repeat RNA-binding protein 2|CUG-BP- and ETR-3-like factor 2|ELAV-type RNA-binding protein 3|KDM2B/CELF2 fusion|RNA-binding protein BRUNOL-3|bruno-like protein 3|neuroblastoma apoptosis-related RNA-binding protein', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=10462515, end_position_on_the_genomic_accession=11336675, orientation='plus', exon_count=29, OMIM=[602538], no_hdr0=''),
    10660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10660, CurrentID=0, Status='live', Symbol='LBX1', Aliases=['HPX-6', 'HPX6H', 'homeobox', 'LBX1'], description='ladybird homeobox 1', other_designations='transcription factor LBX1|lady bird-like homeobox|ladybird homeobox homolog 1|ladybird homeobox protein homolog 1|transcription factor similar to D. melanogaster homeodomain protein lady bird late', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101226994, end_position_on_the_genomic_accession=101229463, orientation='minus', exon_count=2, OMIM=[604255], no_hdr0=''),
    10661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10661, CurrentID=0, Status='live', Symbol='KLF1', Aliases=['EKLF', 'EKLF/KLF1'], description='Kruppel like factor 1', other_designations='Krueppel-like factor 1|erythroid Kruppel-like factor|erythroid krueppel-like transcription factor|erythroid-specific transcription factor EKLF|truncated Kruppel-like factor 1|truncated erythroid Kruppel-like factor EKLF/KLF1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12884422, end_position_on_the_genomic_accession=12887201, orientation='minus', exon_count=3, OMIM=[600599], no_hdr0=''),
    10663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10663, CurrentID=0, Status='live', Symbol='CXCR6', Aliases=['BONZO', 'CD186', 'CDw186', 'STRL33', 'TYMSTR'], description='C-X-C motif chemokine receptor 6', other_designations='C-X-C chemokine receptor type 6|G protein-coupled receptor|G-protein coupled receptor STRL33|G-protein coupled receptor bonzo|chemokine (C-X-C motif) receptor 6', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45940915, end_position_on_the_genomic_accession=45948351, orientation='plus', exon_count=4, OMIM=[605163], no_hdr0=''),
    10664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10664, CurrentID=0, Status='live', Symbol='CTCF', Aliases=['CFAP108', 'FAP108', 'MRD21'], description='CCCTC-binding factor', other_designations='transcriptional repressor CTCF|11 zinc finger transcriptional repressor|11-zinc finger protein|CCCTC-binding factor (zinc finger protein)|CTCFL paralog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67562526, end_position_on_the_genomic_accession=67639185, orientation='plus', exon_count=13, OMIM=[604167], no_hdr0=''),
    10665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10665, CurrentID=0, Status='live', Symbol='TSBP1', Aliases=['C6orf10', 'TSBP'], description='testis expressed basic protein 1', other_designations='testis-expressed basic protein 1|testis specific basic protein|uncharacterized protein C6orf10', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32290523, end_position_on_the_genomic_accession=32371904, orientation='minus', exon_count=29, OMIM=[618151], no_hdr0=''),
    10666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10666, CurrentID=0, Status='live', Symbol='CD226', Aliases=['DNAM-1', 'DNAM1', 'PTA1', 'TLiSA1'], description='CD226 molecule', other_designations='CD226 antigen|DNAX accessory molecule-1|T lineage-specific activation antigen 1 antigen|adhesion glycoprotein|platelet and T cell activation antigen 1', map_location='18q22.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=69853274, end_position_on_the_genomic_accession=69962086, orientation='minus', exon_count=12, OMIM=[605397], no_hdr0=''),
    10667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10667, CurrentID=0, Status='live', Symbol='FARS2', Aliases=['COXPD14', 'FARS1', 'HSPC320', 'PheRS', 'SPG77', 'mtPheRS'], description='phenylalanyl-tRNA synthetase 2, mitochondrial', other_designations='phenylalanine--tRNA ligase, mitochondrial|dJ236A3.1 (phenylalanine-tRNA synthetase)|dJ520B18.2 (FARS1 (phenylalanine-tRNA synthetase))|mitochondrial PHERS|phenylalanine tRNA ligase 2, mitochondrial|phenylalanine translase|phenylalanine-tRNA synthetase 1 (mitochondrial)', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=5261007, end_position_on_the_genomic_accession=5771583, orientation='plus', exon_count=19, OMIM=[611592], no_hdr0=''),
    10668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10668, CurrentID=0, Status='live', Symbol='CGRRF1', Aliases=['CGR19', 'RNF197'], description='cell growth regulator with ring finger domain 1', other_designations='cell growth regulator with RING finger domain protein 1|RING finger protein 197|cell growth regulatory gene 19 protein', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54509896, end_position_on_the_genomic_accession=54539310, orientation='plus', exon_count=9, OMIM=[606138], no_hdr0=''),
    10669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10669, CurrentID=0, Status='live', Symbol='CGREF1', Aliases=['CGR11'], description='cell growth regulator with EF-hand domain 1', other_designations='cell growth regulator with EF hand domain protein 1|cell growth regulatory gene 11 protein|hydrophobestin', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27099353, end_position_on_the_genomic_accession=27119128, orientation='minus', exon_count=8, OMIM=[606137], no_hdr0=''),
    10670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10670, CurrentID=0, Status='live', Symbol='RRAGA', Aliases=['FIP-1', 'FIP1', 'RAGA'], description='Ras related GTP binding A', other_designations='ras-related GTP-binding protein A|adenovirus E3 14.7 kDa-interacting protein 1|adenovirus E3-14.7K interacting protein 1|rag A', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19049427, end_position_on_the_genomic_accession=19051025, orientation='plus', exon_count=1, OMIM=[612194], no_hdr0=''),
    10671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10671, CurrentID=0, Status='live', Symbol='DCTN6', Aliases=['WS-3', 'WS3', 'p27'], description='dynactin subunit 6', other_designations='dynactin subunit 6|dynactin 6|dynactin subunit p27|novel RGD-containing protein|protein WS-3', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30156369, end_position_on_the_genomic_accession=30183639, orientation='plus', exon_count=7, OMIM=[612963], no_hdr0=''),
    10672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10672, CurrentID=0, Status='live', Symbol='GNA13', Aliases=['G13'], description='G protein subunit alpha 13', other_designations='guanine nucleotide-binding protein subunit alpha-13|g alpha-13|guanine nucleotide binding protein (G protein), alpha 13', map_location='17q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=65009289, end_position_on_the_genomic_accession=65056740, orientation='minus', exon_count=6, OMIM=[604406], no_hdr0=''),
    10673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10673, CurrentID=0, Status='live', Symbol='TNFSF13B', Aliases=['BAFF', 'BLYS', 'CD257', 'DTL', 'TALL-1', 'TALL1', 'THANK', 'TNFSF20', 'TNLG7A', 'ZTNF4'], description='TNF superfamily member 13b', other_designations='tumor necrosis factor ligand superfamily member 13B|ApoL related ligand TALL-1|B-cell-activating factor|B-lymphocyte stimulator|Delta4 BAFF|TNF and ApoL-related leukocyte expressed ligand 1|TNF homolog that activates apoptosis|delta BAFF|dendritic cell-derived TNF-like molecule|epididymis secretory sperm binding protein|tumor necrosis factor (ligand) superfamily, member 13b|tumor necrosis factor (ligand) superfamily, member 20|tumor necrosis factor ligand 7A|tumor necrosis factor superfamily member 13b|tumor necrosis factor-like protein ZTNF4', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=108268240, end_position_on_the_genomic_accession=108308484, orientation='plus', exon_count=7, OMIM=[603969], no_hdr0=''),
    10675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10675, CurrentID=0, Status='live', Symbol='CSPG5', Aliases=['NGC'], description='chondroitin sulfate proteoglycan 5', other_designations='chondroitin sulfate proteoglycan 5|acidic leucine-rich EGF-like domain-containing brain protein|chondroitin sulfate proteoglycan 5 (neuroglycan C)', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47562238, end_position_on_the_genomic_accession=47580240, orientation='minus', exon_count=6, OMIM=[606775], no_hdr0=''),
    10677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10677, CurrentID=0, Status='live', Symbol='AVIL', Aliases=['ADVIL', 'DOC6', 'NPHS21', 'p92'], description='advillin', other_designations='advillin', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57797376, end_position_on_the_genomic_accession=57818734, orientation='minus', exon_count=21, OMIM=[613397], no_hdr0=''),
    10678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10678, CurrentID=0, Status='live', Symbol='B3GNT2', Aliases=['3-Gn-T1', '3-Gn-T2', 'B3GN-T2', 'B3GNT', 'B3GNT-2', 'B3GNT1', 'BETA3GNT', 'BGNT2', 'BGnT-2', 'beta-1', 'beta3Gn-T1', 'beta3Gn-T2'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 2', other_designations='N-acetyllactosaminide beta-1,3-N-acetylglucosaminyltransferase 2|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 1|beta-1,3-N-acetylglucosaminyltransferase bGnT-1|beta-1,3-N-acetylglucosaminyltransferase bGnT-2', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=62196115, end_position_on_the_genomic_accession=62224731, orientation='plus', exon_count=3, OMIM=[605581], no_hdr0=''),
    10681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10681, CurrentID=0, Status='live', Symbol='GNB5', Aliases=['GB5', 'IDDCA', 'LADCI', 'gbeta5'], description='G protein subunit beta 5', other_designations='guanine nucleotide-binding protein subunit beta-5|G protein, beta subunit 5L|guanine nucleotide binding protein (G protein), beta 5|guanine nucleotide-binding protein, beta subunit 5L|transducin beta chain 5', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52115100, end_position_on_the_genomic_accession=52191392, orientation='minus', exon_count=17, OMIM=[604447], no_hdr0=''),
    10682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10682, CurrentID=0, Status='live', Symbol='EBP', Aliases=['CDPX2', 'CHO2', 'CPX', 'CPXD', 'MEND'], description='EBP cholestenol delta-isomerase', other_designations='3-beta-hydroxysteroid-Delta(8),Delta(7)-isomerase|3-beta-hydroxysteroid-delta-8,delta-7-isomerase|Chondrodysplasia punctata-2, X-linked dominant (Happle syndrome)|D8-D7 sterol isomerase|cholestenol Delta-isomerase|delta(8)-Delta(7) sterol isomerase|emopamil binding protein (sterol isomerase)|emopamil-binding protein|sterol 8-isomerase', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48521808, end_position_on_the_genomic_accession=48528716, orientation='plus', exon_count=5, OMIM=[300205], no_hdr0=''),
    10683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10683, CurrentID=0, Status='live', Symbol='DLL3', Aliases=['SCDO1'], description='delta like canonical Notch ligand 3', other_designations='delta-like protein 3|delta-like 3|delta3|drosophila Delta homolog 3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39498947, end_position_on_the_genomic_accession=39508469, orientation='plus', exon_count=8, OMIM=[602768], no_hdr0=''),
    10686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10686, CurrentID=0, Status='live', Symbol='CLDN16', Aliases=['HOMG3', 'PCLN1'], description='claudin 16', other_designations='claudin-16|hypomagnesemia 3, with hypercalciuria and nephrocalcinosis|paracellin-1', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=190290361, end_position_on_the_genomic_accession=190412138, orientation='plus', exon_count=9, OMIM=[603959], no_hdr0=''),
    10687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10687, CurrentID=0, Status='live', Symbol='PNMA2', Aliases=['MA2', 'MM2', 'RGAG2'], description='PNMA family member 2', other_designations='paraneoplastic antigen Ma2|40 kDa neuronal protein|onconeuronal antigen MA2|paraneoplastic Ma antigen 2|paraneoplastic neuronal antigen MM2|retrotransposon gag domain containing 2', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=26504695, end_position_on_the_genomic_accession=26513872, orientation='minus', exon_count=4, OMIM=[603970], no_hdr0=''),
    10688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10688, CurrentID=0, Status='live', Symbol='CRSP5', Aliases=['CRSP85'], description='cofactor required for Sp1 transcriptional activation subunit 5', other_designations='cofactor required for Sp1 transcriptional activation subunit 5|cofactor required for Sp1 transcriptional activation, subunit 5, 85kDa', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    10690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10690, CurrentID=0, Status='live', Symbol='FUT9', Aliases=['Fuc-TIX'], description='fucosyltransferase 9', other_designations='4-galactosyl-N-acetylglucosaminide 3-alpha-L-fucosyltransferase 9|alpha-(1,3)-fucosyltransferase 9|fucT-IX|fucosyltransferase 9 (alpha (1,3) fucosyltransferase)|fucosyltransferase IX|galactoside 3-L-fucosyltransferase', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96015974, end_position_on_the_genomic_accession=96215612, orientation='plus', exon_count=5, OMIM=[606865], no_hdr0=''),
    10691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10691, CurrentID=0, Status='live', Symbol='GMEB1', Aliases=['P96PIF', 'PIF96'], description='glucocorticoid modulatory element binding protein 1', other_designations='glucocorticoid modulatory element-binding protein 1|DNA-binding protein p96PIF|PIF p96|parvovirus initiation factor p96', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28668782, end_position_on_the_genomic_accession=28719353, orientation='plus', exon_count=11, OMIM=[604409], no_hdr0=''),
    10692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10692, CurrentID=0, Status='live', Symbol='RRH', Aliases=[], description='retinal pigment epithelium-derived rhodopsin homolog', other_designations='visual pigment-like receptor peropsin|peropsin', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109827972, end_position_on_the_genomic_accession=109844942, orientation='plus', exon_count=7, OMIM=[605224], no_hdr0=''),
    10693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10693, CurrentID=0, Status='live', Symbol='CCT6B', Aliases=['CCT-zeta-2', 'CCTZ-2', 'Cctz2', 'TCP-1-zeta-2', 'TSA303'], description='chaperonin containing TCP1 subunit 6B', other_designations='T-complex protein 1 subunit zeta-2|chaperonin containing TCP1, subunit 6B (zeta 2)|chaperonin-containing T-complex polypeptide 1, subunit 6B|testis-specific Tcp20|testis-specific protein TSA303', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34927861, end_position_on_the_genomic_accession=34981222, orientation='minus', exon_count=15, OMIM=[610730], no_hdr0=''),
    10694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10694, CurrentID=0, Status='live', Symbol='CCT8', Aliases=['C21orf112', 'Cctq', 'D21S246', 'PRED71'], description='chaperonin containing TCP1 subunit 8', other_designations='T-complex protein 1 subunit theta|CCT-theta|TCP-1-theta|chaperonin containing T-complex polypeptide 1 subunit 8|chaperonin containing TCP1, subunit 8 (theta)|renal carcinoma antigen NY-REN-15', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29056326, end_position_on_the_genomic_accession=29073648, orientation='minus', exon_count=16, OMIM=[617786], no_hdr0=''),
    10695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10695, CurrentID=0, Status='live', Symbol='CNPY3', Aliases=['CAG4A', 'DEE60', 'EIEE60', 'ERDA5', 'PRAT4A', 'TNRC5'], description='canopy FGF signaling regulator 3', other_designations='protein canopy homolog 3|CAG repeat containing|CTG repeat protein 4a|expanded repeat-domain protein CAG/CTG 5|protein associated with TLR4|protein associated with Toll-like receptor 4A|trinucleotide repeat-containing gene 5 protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42928002, end_position_on_the_genomic_accession=42939294, orientation='plus', exon_count=8, OMIM=[610774], no_hdr0=''),
    10699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10699, CurrentID=0, Status='live', Symbol='CORIN', Aliases=['ATC2', 'CRN', 'Lrp4', 'PEE5', 'TMPRSS10'], description='corin, serine peptidase', other_designations='atrial natriuretic peptide-converting enzyme|heart-specific serine proteinase ATC2|pro-ANP-convertase|pro-ANP-converting enzyme|transmembrane protease serine 10', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=47594001, end_position_on_the_genomic_accession=47838067, orientation='minus', exon_count=22, OMIM=[605236], no_hdr0=''),
    10712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10712, CurrentID=0, Status='live', Symbol='FAM189B', Aliases=['C1orf2', 'COTE1'], description='family with sequence similarity 189 member B', other_designations='protein FAM189B', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155247205, end_position_on_the_genomic_accession=155255892, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    10713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10713, CurrentID=0, Status='live', Symbol='USP39', Aliases=['65K', 'CGI-21', 'HSPC332', 'SAD1', 'SNRNP65'], description='ubiquitin specific peptidase 39', other_designations='U4/U6.U5 tri-snRNP-associated protein 2|SAD1 homolog|SnRNP assembly defective 1 homolog|U4/U6.U5 tri-snRNP-associated 65 kDa protein|inactive ubiquitin-specific peptidase 39|small nuclear ribonucleoprotein 65kDa (U4/U6.U5)|ubiquitin specific protease 39', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85602843, end_position_on_the_genomic_accession=85649283, orientation='plus', exon_count=16, OMIM=[611594], no_hdr0=''),
    10714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10714, CurrentID=0, Status='live', Symbol='POLD3', Aliases=['P66', 'P68', 'PPP1R128'], description='DNA polymerase delta 3, accessory subunit', other_designations='DNA polymerase delta subunit 3|DNA polymerase delta subunit C|DNA polymerase delta subunit p66|DNA polymerase delta subunit p68|Pol delta C subunit (p66)|polymerase (DNA) delta 3, accessory subunit|polymerase (DNA-directed), delta 3, accessory subunit|protein phosphatase 1, regulatory subunit 128', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74592582, end_position_on_the_genomic_accession=74669341, orientation='plus', exon_count=14, OMIM=[611415], no_hdr0=''),
    10715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10715, CurrentID=0, Status='live', Symbol='CERS1', Aliases=['EPM8', 'GDF-1', 'GDF1', 'LAG1', 'LASS1', 'UOG1'], description='ceramide synthase 1', other_designations='ceramide synthase 1|Embryonic growth/differentiation factor 1|longevity assurance (LAG1, S. cerevisiae) homolog 1|longevity assurance gene 1 protein homolog 1|protein UOG-1|upstream of GDF1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18868545, end_position_on_the_genomic_accession=18896982, orientation='minus', exon_count=10, OMIM=[606919], no_hdr0=''),
    10716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10716, CurrentID=0, Status='live', Symbol='TBR1', Aliases=['IDDAS', 'TBR-1', 'TES-56'], description='T-box brain transcription factor 1', other_designations='T-box brain protein 1|T-box, brain 1|T-brain-1', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=161416297, end_position_on_the_genomic_accession=161425870, orientation='plus', exon_count=6, OMIM=[604616], no_hdr0=''),
    10717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10717, CurrentID=0, Status='live', Symbol='AP4B1', Aliases=['BETA-4', 'CPSQ5', 'SPG47'], description='adaptor related protein complex 4 subunit beta 1', other_designations='AP-4 complex subunit beta-1|AP-4 adaptor complex subunit beta|adaptor related protein complex 4 beta 1 subunit|beta 4 subunit of AP-4|beta4-adaptin|spastic paraplegia 47', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113894194, end_position_on_the_genomic_accession=113905067, orientation='minus', exon_count=13, OMIM=[607245], no_hdr0=''),
    10718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10718, CurrentID=0, Status='live', Symbol='NRG3', Aliases=['HRG3', 'pro-NRG3'], description='neuregulin 3', other_designations='pro-neuregulin-3, membrane-bound isoform|neuregulin-3-like polypeptide', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=81875190, end_position_on_the_genomic_accession=82989979, orientation='plus', exon_count=21, OMIM=[605533], no_hdr0=''),
    10720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10720, CurrentID=0, Status='live', Symbol='UGT2B11', Aliases=[], description='UDP glucuronosyltransferase family 2 member B11', other_designations='UDP-glucuronosyltransferase 2B11|UDP glucuronosyltransferase 2 family, polypeptide B11|UDP glycosyltransferase 2 family protein|UDP glycosyltransferase 2 family, polypeptide B11|UDPGT 2B11', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69199951, end_position_on_the_genomic_accession=69224980, orientation='minus', exon_count=8, OMIM=[603064], no_hdr0=''),
    10721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10721, CurrentID=0, Status='live', Symbol='POLQ', Aliases=['PRO0327'], description='DNA polymerase theta', other_designations='DNA polymerase theta|epididymis secretory sperm binding protein|polymerase (DNA directed), theta|polymerase (DNA) theta', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121431431, end_position_on_the_genomic_accession=121545988, orientation='minus', exon_count=30, OMIM=[604419], no_hdr0=''),
    10723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10723, CurrentID=0, Status='live', Symbol='SLC12A7', Aliases=['KCC4'], description='solute carrier family 12 member 7', other_designations='solute carrier family 12 member 7|K-Cl cotransporter 4|SUCO/SLC12A7 fusion|electroneutral potassium-chloride cotransporter 4|potassium/chloride transporter KCC4|solute carrier family 12 (potassium/chloride transporter), member 7|solute carrier family 12 (potassium/chloride transporters), member 7', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1050384, end_position_on_the_genomic_accession=1155887, orientation='minus', exon_count=32, OMIM=[604879], no_hdr0=''),
    10724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10724, CurrentID=0, Status='live', Symbol='OGA', Aliases=['MEA5', 'MGEA5', 'NCOAT'], description='O-GlcNAcase', other_designations='protein O-GlcNAcase|N-acetyl-beta-D-glucosaminidase|N-acetyl-beta-glucosaminidase|beta-N-acetylglucosaminidase|beta-N-acetylhexosaminidase|beta-hexosaminidase|bifunctional protein NCOAT|hyaluronidase in meningioma|meningioma expressed antigen 5 (hyaluronidase)|meningioma-expressed antigen 5|nuclear cytoplasmic O-GlcNAcase and acetyltransferase', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101784445, end_position_on_the_genomic_accession=101818709, orientation='minus', exon_count=17, OMIM=[604039], no_hdr0=''),
    10725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10725, CurrentID=0, Status='live', Symbol='NFAT5', Aliases=['NF-AT5', 'NFATL1', 'NFATZ', 'OREBP', 'TONEBP'], description='nuclear factor of activated T cells 5', other_designations='nuclear factor of activated T-cells 5|NFAT-like protein 1|T-cell transcription factor NFAT5|TonE-binding protein|glutamine rich protein H65|nuclear factor of activated T-cells 5, tonicity-responsive|osmotic response element-binding protein|tonicity-responsive enhancer-binding protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69565952, end_position_on_the_genomic_accession=69704654, orientation='plus', exon_count=19, OMIM=[604708], no_hdr0=''),
    10726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10726, CurrentID=0, Status='live', Symbol='NUDC', Aliases=['HNUDC', 'MNUDC', 'NPD011'], description='nuclear distribution C, dynein complex regulator', other_designations='nuclear migration protein nudC|nuclear distribution C homolog|nuclear distribution gene C homolog|nuclear distribution protein C homolog|nudC nuclear distribution protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26900569, end_position_on_the_genomic_accession=26946871, orientation='plus', exon_count=14, OMIM=[610325], no_hdr0=''),
    10728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10728, CurrentID=0, Status='live', Symbol='PTGES3', Aliases=['P23', 'TEBP', 'cPGES'], description='prostaglandin E synthase 3', other_designations='prostaglandin E synthase 3|Hsp90 co-chaperone|cytosolic prostaglandin E synthase|cytosolic prostaglandin E2 synthase|progesterone receptor complex p23|prostaglandin E synthase 3 (cytosolic)|telomerase-binding protein p23|unactive progesterone receptor, 23 kD', map_location='12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56663349, end_position_on_the_genomic_accession=56689575, orientation='minus', exon_count=9, OMIM=[607061], no_hdr0=''),
    10730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10730, CurrentID=0, Status='live', Symbol='YME1L1', Aliases=['FTSH', 'MEG4', 'OPA11', 'PAMP', 'YME1L'], description='YME1 like 1 ATPase', other_designations='ATP-dependent zinc metalloprotease YME1L1|ATP-dependent metalloprotease FtsH1 homolog|YME1-like protein 1|meg-4|presenilin-associated metalloprotease', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27110111, end_position_on_the_genomic_accession=27155051, orientation='minus', exon_count=20, OMIM=[607472], no_hdr0=''),
    10732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10732, CurrentID=0, Status='live', Symbol='TCFL5', Aliases=['CHA', 'E2BP-1', 'Figlb', 'SOSF1', 'bHLHe82'], description='transcription factor like 5', other_designations='transcription factor-like 5 protein|HPV-16 E2-binding protein 1|cha transcription factor|spermatogenesis- and oogenesis-specific bHLH-containing protein 1|transcription factor-like 5 (basic helix-loop-helix)', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62841005, end_position_on_the_genomic_accession=62861822, orientation='minus', exon_count=9, OMIM=[604745], no_hdr0=''),
    10733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10733, CurrentID=0, Status='live', Symbol='PLK4', Aliases=['MCCRP2', 'SAK', 'STK18'], description='polo like kinase 4', other_designations='serine/threonine-protein kinase PLK4|Snk akin kinase|serine/threonine-protein kinase 18|serine/threonine-protein kinase Sak', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127880893, end_position_on_the_genomic_accession=127899224, orientation='plus', exon_count=17, OMIM=[605031], no_hdr0=''),
    10734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10734, CurrentID=0, Status='live', Symbol='STAG3', Aliases=[], description='stromal antigen 3', other_designations='cohesin subunit SA-3|SCC3 homolog 3|stromalin-3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100177563, end_position_on_the_genomic_accession=100219334, orientation='plus', exon_count=37, OMIM=[608489], no_hdr0=''),
    10735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10735, CurrentID=0, Status='live', Symbol='STAG2', Aliases=['HPE13', 'MKMS', 'NEDXCF', 'SA-2', 'SA2', 'SCC3B', 'bA517O1.1'], description='stromal antigen 2', other_designations='cohesin subunit SA-2|SCC3 homolog 2', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=123960560, end_position_on_the_genomic_accession=124102656, orientation='plus', exon_count=39, OMIM=[300826], no_hdr0=''),
    10736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10736, CurrentID=0, Status='live', Symbol='SIX2', Aliases=[], description='SIX homeobox 2', other_designations='homeobox protein SIX2|sine oculis homeobox homolog 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=45005182, end_position_on_the_genomic_accession=45009645, orientation='minus', exon_count=2, OMIM=[604994], no_hdr0=''),
    10738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10738, CurrentID=0, Status='live', Symbol='RFPL3', Aliases=['RNF120'], description='ret finger protein like 3', other_designations='ret finger protein-like 3', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32354885, end_position_on_the_genomic_accession=32361161, orientation='plus', exon_count=4, OMIM=[605970], no_hdr0=''),
    10739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10739, CurrentID=0, Status='live', Symbol='RFPL2', Aliases=['RNF79'], description='ret finger protein like 2', other_designations='ret finger protein-like 2|RING finger protein 79', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32190435, end_position_on_the_genomic_accession=32205073, orientation='minus', exon_count=6, OMIM=[605969], no_hdr0=''),
    10741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10741, CurrentID=0, Status='live', Symbol='RBBP9', Aliases=['BOG', 'RBBP10'], description='RB binding protein 9, serine hydrolase', other_designations='serine hydrolase RBBP9|B5T overexpressed gene protein|RBBP-10|RBBP-9|putative hydrolase RBBP9|retinoblastoma-binding protein 10|retinoblastoma-binding protein 9|retinoma-binding protein 9', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18486540, end_position_on_the_genomic_accession=18497250, orientation='minus', exon_count=5, OMIM=[602908], no_hdr0=''),
    10742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10742, CurrentID=0, Status='live', Symbol='RAI2', Aliases=[], description='retinoic acid induced 2', other_designations='retinoic acid-induced protein 2', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=17800049, end_position_on_the_genomic_accession=17861346, orientation='minus', exon_count=5, OMIM=[300217], no_hdr0=''),
    10743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10743, CurrentID=0, Status='live', Symbol='RAI1', Aliases=['SMCR', 'SMS'], description='retinoic acid induced 1', other_designations='retinoic acid-induced protein 1|Smith-Magenis syndrome chromosome region', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17681376, end_position_on_the_genomic_accession=17811453, orientation='plus', exon_count=9, OMIM=[607642], no_hdr0=''),
    10744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10744, CurrentID=0, Status='live', Symbol='PTTG2', Aliases=[], description='pituitary tumor-transforming 2', other_designations='securin-2|pituitary tumor-transforming gene 2 protein', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37960398, end_position_on_the_genomic_accession=37961128, orientation='plus', exon_count=1, OMIM=[604231], no_hdr0=''),
    10745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10745, CurrentID=0, Status='live', Symbol='PHTF1', Aliases=['PHTF'], description='putative homeodomain transcription factor 1', other_designations='protein PHTF1', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113696831, end_position_on_the_genomic_accession=113759888, orientation='minus', exon_count=22, OMIM=[604950], no_hdr0=''),
    10746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10746, CurrentID=0, Status='live', Symbol='MAP3K2', Aliases=['MEKK2', 'MEKK2B'], description='mitogen-activated protein kinase kinase kinase 2', other_designations='mitogen-activated protein kinase kinase kinase 2|MAP/ERK kinase kinase 2|MAPK/ERK kinase kinase 2|MEK kinase 2|MEKK 2', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127298668, end_position_on_the_genomic_accession=127388465, orientation='minus', exon_count=18, OMIM=[609487], no_hdr0=''),
    10747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10747, CurrentID=0, Status='live', Symbol='MASP2', Aliases=['MAP-2', 'MAP19', 'MASP-2', 'MASP1P1', 'sMAP'], description='MBL associated serine protease 2', other_designations='mannan-binding lectin serine protease 2|MBL-associated plasma protein of 19 kD|mannan binding lectin serine peptidase 2|mannan-binding lectin serine peptidase 1 pseudogene 1|mannan-binding lectin serine protease 1 pseudogene 1|mannose-binding lectin associated protein 19|mannose-binding lectin-associated serine protease 2|mannose-binding protein-associated serine protease 2|small MBL-associated protein', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11026523, end_position_on_the_genomic_accession=11047239, orientation='minus', exon_count=12, OMIM=[605102], no_hdr0=''),
    10749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10749, CurrentID=0, Status='live', Symbol='KIF1C', Aliases=['LTXS1', 'SATX2', 'SAX2', 'SPAX2', 'SPG58'], description='kinesin family member 1C', other_designations='kinesin-like protein KIF1C|spastic ataxia 2 (autosomal recessive)', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4997950, end_position_on_the_genomic_accession=5028401, orientation='plus', exon_count=24, OMIM=[603060], no_hdr0=''),
    10750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10750, CurrentID=0, Status='live', Symbol='GRAP', Aliases=['DFNB114'], description='GRB2 related adaptor protein', other_designations='GRB2-related adapter protein|growth factor receptor-bound protein 2-related adaptor protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19020656, end_position_on_the_genomic_accession=19046957, orientation='minus', exon_count=5, OMIM=[604330], no_hdr0=''),
    10752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10752, CurrentID=0, Status='live', Symbol='CHL1', Aliases=['CALL', 'L1CAM2'], description='cell adhesion molecule L1 like', other_designations='neural cell adhesion molecule L1-like protein|L1 cell adhesion molecule 2|cell adhesion molecule with homology to L1CAM (close homolog of L1)|cell adhesion molecule with homology to L1CAM (close homologue of L1)|close homolog of L1', map_location='3p26.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196588, end_position_on_the_genomic_accession=409417, orientation='plus', exon_count=33, OMIM=[607416], no_hdr0=''),
    10753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10753, CurrentID=0, Status='live', Symbol='CAPN9', Aliases=['GC36', 'nCL-4'], description='calpain 9', other_designations='calpain-9|digestive tract-specific calpain|new calpain 4|novel calpain large subunit-4', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230747289, end_position_on_the_genomic_accession=230803356, orientation='plus', exon_count=23, OMIM=[606401], no_hdr0=''),
    10755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10755, CurrentID=0, Status='live', Symbol='GIPC1', Aliases=['C19orf3', 'GIPC', 'GLUT1CBP', 'Hs.6454', 'IIP-1', 'NIP', 'OPDM2', 'RGS19IP1', 'SEMCAP', 'SYNECTIIN', 'SYNECTIN', 'TIP-2'], description='GIPC PDZ domain containing family member 1', other_designations='PDZ domain-containing protein GIPC1|GAIP C-terminus-interacting protein|GLUT1 C-terminal binding protein|IGF-1 receptor interacting protein 1|RGS-GAIP-interacting protein|RGS19-interacting protein 1|regulator of G-protein signalling 19 interacting protein 1|tax interaction protein 2', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14477761, end_position_on_the_genomic_accession=14496133, orientation='minus', exon_count=9, OMIM=[605072], no_hdr0=''),
    10758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10758, CurrentID=0, Status='live', Symbol='TRAF3IP2', Aliases=['ACT1', 'C6orf2', 'C6orf4', 'C6orf5', 'C6orf6', 'CANDF8', 'CIKS', 'PSORS13'], description='TRAF3 interacting protein 2', other_designations='E3 ubiquitin ligase TRAF3IP2|E3 ubiquitin-protein ligase CIKS|NFkB-activating protein ACT1|adapter protein CIKS|connection to IKK and SAPK/JNK|nuclear factor NF-kappa-B activator 1|symbol withdrawn, see C6orf4', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=111555381, end_position_on_the_genomic_accession=111605878, orientation='minus', exon_count=11, OMIM=[607043], no_hdr0=''),
    10761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10761, CurrentID=0, Status='live', Symbol='PLAC1', Aliases=['CT92', 'OOSP2B', 'OOSP2L'], description='placenta enriched 1', other_designations='placenta-specific protein 1|cancer/testis antigen 92|placenta specific 1', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134565838, end_position_on_the_genomic_accession=134764322, orientation='minus', exon_count=6, OMIM=[300296], no_hdr0=''),
    10762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10762, CurrentID=0, Status='live', Symbol='NUP50', Aliases=['NPAP60', 'NPAP60L'], description='nucleoporin 50', other_designations='nuclear pore complex protein Nup50|50 kDa nucleoporin|nuclear pore-associated protein 60L|nucleoporin 50kD|nucleoporin 50kDa|nucleoporin Nup50', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45163925, end_position_on_the_genomic_accession=45188017, orientation='plus', exon_count=12, OMIM=[604646], no_hdr0=''),
    10763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10763, CurrentID=0, Status='live', Symbol='NES', Aliases=['Nbla00170'], description='nestin', other_designations='nestin', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156668763, end_position_on_the_genomic_accession=156677407, orientation='minus', exon_count=4, OMIM=[600915], no_hdr0=''),
    10765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10765, CurrentID=0, Status='live', Symbol='KDM5B', Aliases=['CT31', 'JARID1B', 'MRT65', 'PLU-1', 'PLU1', 'PPP1R98', 'PUT1', 'RBBP2H1A', 'RBP2-H1'], description='lysine demethylase 5B', other_designations='lysine-specific demethylase 5B|[histone H3]-trimethyl-L-lysine(4) demethylase 5B|cancer/testis antigen 31|histone demethylase JARID1B|jumonji, AT rich interactive domain 1B|jumonji/ARID domain-containing protein 1B|lysine (K)-specific demethylase 5B|protein phosphatase 1, regulatory subunit 98|putative DNA/chromatin binding motif|retinoblastoma-binding protein 2 homolog 1|retinoblastoma-binding protein 2, homolog 1A', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202724495, end_position_on_the_genomic_accession=202809470, orientation='minus', exon_count=30, OMIM=[605393], no_hdr0=''),
    10766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10766, CurrentID=0, Status='live', Symbol='TOB2', Aliases=['APRO5', 'TOB4', 'TOBL', 'TROB2'], description='transducer of ERBB2, 2', other_designations='protein Tob2|protein Tob4|transducer of erbB-2 2', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41433492, end_position_on_the_genomic_accession=41448230, orientation='minus', exon_count=3, OMIM=[607396], no_hdr0=''),
    10767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10767, CurrentID=0, Status='live', Symbol='HBS1L', Aliases=['EF-1a', 'ERFS', 'HBS1', 'HSPC276', 'eRF3c'], description='HBS1 like translational GTPase', other_designations='HBS1-like protein|ERF3-similar protein|Hsp70 subfamily B suppressor 1-like protein|eRF3 family member', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=134960378, end_position_on_the_genomic_accession=135054826, orientation='minus', exon_count=20, OMIM=[612450], no_hdr0=''),
    10768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10768, CurrentID=0, Status='live', Symbol='AHCYL1', Aliases=['DCAL', 'IRBIT', 'PPP1R78', 'PRO0233', 'XPVKONA'], description='adenosylhomocysteinase like 1', other_designations='S-adenosylhomocysteine hydrolase-like protein 1|DC-expressed AHCY-like molecule|IP(3)Rs binding protein released with IP(3)|S-adenosyl homocysteine hydrolase homolog|S-adenosyl-L-homocysteine hydrolase 2|adenosylhomocysteinase 2|adoHcyase 2|dendritic cell expressed AHCY-like protein|epididymis secretory sperm binding protein|inositol 1,4,5-trisphosphate receptor-binding protein|protein phosphatase 1, regulatory subunit 78|putative adenosylhomocysteinase 2', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109984765, end_position_on_the_genomic_accession=110023742, orientation='plus', exon_count=20, OMIM=[607826], no_hdr0=''),
    10769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10769, CurrentID=0, Status='live', Symbol='PLK2', Aliases=['SNK', 'hPlk2', 'hSNK'], description='polo like kinase 2', other_designations='serine/threonine-protein kinase PLK2|PLK-2|serine/threonine-protein kinase SNK|serum-inducible kinase', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=58453982, end_position_on_the_genomic_accession=58460086, orientation='minus', exon_count=14, OMIM=[607023], no_hdr0=''),
    10771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10771, CurrentID=0, Status='live', Symbol='ZMYND11', Aliases=['BRAM1', 'BS69', 'MRD30'], description='zinc finger MYND-type containing 11', other_designations='zinc finger MYND domain-containing protein 11|adenovirus 5 E1A-binding protein|bone morphogenetic protein receptor-associated molecule 1', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=130088, end_position_on_the_genomic_accession=254637, orientation='plus', exon_count=23, OMIM=[608668], no_hdr0=''),
    10772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10772, CurrentID=0, Status='live', Symbol='SRSF10', Aliases=['FUSIP1', 'FUSIP2', 'NSSR', 'PPP1R149', 'SFRS13', 'SFRS13A', 'SRp38', 'SRrp40', 'TASR', 'TASR1', 'TASR2'], description='serine and arginine rich splicing factor 10', other_designations='serine/arginine-rich splicing factor 10|40 kDa SR-repressor protein|FUS interacting protein (serine-arginine rich) 1|FUS-interacting protein (serine-arginine rich) 2|SR splicing factor 10|TLS-associated SR protein|TLS-associated protein TASR|TLS-associated protein with SR repeats|TLS-associated protein with Ser-Arg repeats|TLS-associated serine-arginine protein 1|TLS-associated serine-arginine protein 2|neural-salient SR protein|protein phosphatase 1, regulatory subunit 149|serine-arginine repressor protein (40 kDa)|splicing factor SRp38|splicing factor, arginine/serine-rich 13|splicing factor, arginine/serine-rich 13A', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23964347, end_position_on_the_genomic_accession=23980370, orientation='minus', exon_count=8, OMIM=[605221], no_hdr0=''),
    10773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10773, CurrentID=0, Status='live', Symbol='ZBTB6', Aliases=['ZID', 'ZNF482'], description='zinc finger and BTB domain containing 6', other_designations='zinc finger and BTB domain-containing protein 6|zinc finger protein 482|zinc finger protein with interaction domain', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122908056, end_position_on_the_genomic_accession=122913323, orientation='minus', exon_count=2, OMIM=[605976], no_hdr0=''),
    10775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10775, CurrentID=0, Status='live', Symbol='POP4', Aliases=['RPP29'], description='POP4 homolog, ribonuclease P/MRP subunit', other_designations='ribonuclease P protein subunit p29|hPOP4', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29606283, end_position_on_the_genomic_accession=29617237, orientation='plus', exon_count=7, OMIM=[606114], no_hdr0=''),
    10776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10776, CurrentID=0, Status='live', Symbol='ARPP19', Aliases=['ARPP-16', 'ARPP-19', 'ARPP16', 'ENSAL'], description='cAMP regulated phosphoprotein 19', other_designations='cAMP-regulated phosphoprotein 19|cAMP-regulated phosphoprotein 19kDa|cyclic AMP phosphoprotein, 19 kD', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52547045, end_position_on_the_genomic_accession=52569446, orientation='minus', exon_count=7, OMIM=[605487], no_hdr0=''),
    10777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10777, CurrentID=0, Status='live', Symbol='ARPP21', Aliases=['ARPP-21', 'R3HDM3', 'RCS', 'TARPP'], description='cAMP regulated phosphoprotein 21', other_designations='cAMP-regulated phosphoprotein 21|R3H domain containing 3|cAMP regulated phosphoprotein 21kDa|cyclic AMP-regulated phosphoprotein, 21 kD|thymocyte cAMP-regulated phosphoprotein', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=35638853, end_position_on_the_genomic_accession=35798933, orientation='plus', exon_count=35, OMIM=[605488], no_hdr0=''),
    10780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10780, CurrentID=0, Status='live', Symbol='ZNF234', Aliases=['HZF4', 'ZNF269'], description='zinc finger protein 234', other_designations='zinc finger protein 234|C2-H2 type zinc finger protein|Homo sapiens zinc finger 234|zinc finger protein 234, partial sequence|zinc finger protein 269|zinc finger protein 4|zinc finger protein HZF4', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44141530, end_position_on_the_genomic_accession=44160313, orientation='plus', exon_count=7, OMIM=[604750], no_hdr0=''),
    10781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10781, CurrentID=0, Status='live', Symbol='ZNF266', Aliases=['HZF1'], description='zinc finger protein 266', other_designations='zinc finger protein 266|zinc finger protein 1|zinc finger protein HZF1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9412429, end_position_on_the_genomic_accession=9435573, orientation='minus', exon_count=12, OMIM=[604751], no_hdr0=''),
    10782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10782, CurrentID=0, Status='live', Symbol='ZNF274', Aliases=['HFB101', 'ZF2', 'ZKSCAN19', 'ZSCAN51'], description='zinc finger protein 274', other_designations='neurotrophin receptor-interacting factor homolog|KRAB zinc finger protein HFB101|zinc finger protein HFB101|zinc finger protein with KRAB and SCAN domains 19|zinc finger protein zfp2', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58183061, end_position_on_the_genomic_accession=58213562, orientation='plus', exon_count=8, OMIM=[605467], no_hdr0=''),
    10783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10783, CurrentID=0, Status='live', Symbol='NEK6', Aliases=['SID6-1512'], description='NIMA related kinase 6', other_designations='serine/threonine-protein kinase Nek6|NIMA (never in mitosis gene a)-related kinase 6|never in mitosis A-related kinase 6|nimA-related protein kinase 6|protein kinase SID6-1512|putative serine-threonine protein kinase', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124257606, end_position_on_the_genomic_accession=124353307, orientation='plus', exon_count=17, OMIM=[604884], no_hdr0=''),
    10785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10785, CurrentID=0, Status='live', Symbol='WDR4', Aliases=['GAMOS6', 'MIGSB', 'TRM82', 'TRMT82', 'Wuho', 'hWH'], description='WD repeat domain 4', other_designations='tRNA (guanine-N(7)-)-methyltransferase non-catalytic subunit WDR4|TRM82 tRNA methyltransferase 82 homolog|WD repeat-containing protein 4|protein Wuho homolog|tRNA (guanine-N(7)-)-methyltransferase subunit WDR4', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42843075, end_position_on_the_genomic_accession=42891695, orientation='minus', exon_count=15, OMIM=[605924], no_hdr0=''),
    10786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10786, CurrentID=0, Status='live', Symbol='SLC17A3', Aliases=['GOUT4', 'NPT4', 'UAQTL4'], description='solute carrier family 17 member 3', other_designations='sodium-dependent phosphate transport protein 4|Na(+)/PI cotransporter 4|sodium/phosphate cotransporter 4|solute carrier family 17 (organic anion transporter), member 3|solute carrier family 17 (sodium phosphate), member 3', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25844856, end_position_on_the_genomic_accession=25874243, orientation='minus', exon_count=13, OMIM=[611034], no_hdr0=''),
    10787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10787, CurrentID=0, Status='live', Symbol='NCKAP1', Aliases=['HEM2', 'NAP1', 'NAP125', 'p125Nap1'], description='NCK associated protein 1', other_designations='nck-associated protein 1|membrane-associated protein HEM-2', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=182909115, end_position_on_the_genomic_accession=183038457, orientation='minus', exon_count=32, OMIM=[604891], no_hdr0=''),
    10788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10788, CurrentID=0, Status='live', Symbol='IQGAP2', Aliases=[], description='IQ motif containing GTPase activating protein 2', other_designations='ras GTPase-activating-like protein IQGAP2', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76403285, end_position_on_the_genomic_accession=76708132, orientation='plus', exon_count=41, OMIM=[605401], no_hdr0=''),
    10791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10791, CurrentID=0, Status='live', Symbol='VAMP5', Aliases=[], description='vesicle associated membrane protein 5', other_designations='vesicle-associated membrane protein 5|VAMP-5|myobrevin', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85584431, end_position_on_the_genomic_accession=85593406, orientation='plus', exon_count=3, OMIM=[607029], no_hdr0=''),
    10793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10793, CurrentID=0, Status='live', Symbol='ZNF273', Aliases=['HZF9'], description='zinc finger protein 273', other_designations='zinc finger protein 273|zinc finger protein 9|zinc finger protein HZF9', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64877603, end_position_on_the_genomic_accession=64932239, orientation='plus', exon_count=11, OMIM=[604756], no_hdr0=''),
    10794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10794, CurrentID=0, Status='live', Symbol='ZNF460', Aliases=['HZF8', 'ZNF272'], description='zinc finger protein 460', other_designations='zinc finger protein 460|zinc finger protein 272|zinc finger protein HZF8', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57279982, end_position_on_the_genomic_accession=57294069, orientation='plus', exon_count=4, OMIM=[604755], no_hdr0=''),
    10795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10795, CurrentID=0, Status='live', Symbol='ZNF268', Aliases=['HZF3'], description='zinc finger protein 268', other_designations='zinc finger protein 268|zinc finger protein 3|zinc finger protein HZF3', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133181495, end_position_on_the_genomic_accession=133214832, orientation='plus', exon_count=7, OMIM=[604753], no_hdr0=''),
    10797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10797, CurrentID=0, Status='live', Symbol='MTHFD2', Aliases=['NMDMC'], description='methylenetetrahydrofolate dehydrogenase (NADP+ dependent) 2, methenyltetrahydrofolate cyclohydrolase', other_designations='bifunctional methylenetetrahydrofolate dehydrogenase/cyclohydrolase, mitochondrial|NAD-dependent methylene tetrahydrofolate dehydrogenase cyclohydrolase', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74198591, end_position_on_the_genomic_accession=74217565, orientation='plus', exon_count=9, OMIM=[604887], no_hdr0=''),
    10798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10798, CurrentID=0, Status='live', Symbol='OR5I1', Aliases=['HSOlf1', 'OLF1'], description='olfactory receptor family 5 subfamily I member 1', other_designations='olfactory receptor 5I1|olfactory receptor OR11-159|olfactory receptor-like protein OLF1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55935456, end_position_on_the_genomic_accession=55936400, orientation='minus', exon_count=1, OMIM=[608496], no_hdr0=''),
    10799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10799, CurrentID=0, Status='live', Symbol='RPP40', Aliases=['RNASEP1', 'bA428J1.3'], description='ribonuclease P/MRP subunit p40', other_designations='ribonuclease P protein subunit p40|RNase P subunit 1|RNaseP protein p40|ribonuclease P (40 kD)|ribonuclease P, 40kD subunit|ribonuclease P/MRP 40kDa subunit|ribonuclease P1', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4992405, end_position_on_the_genomic_accession=5004058, orientation='minus', exon_count=11, OMIM=[606117], no_hdr0=''),
    10800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10800, CurrentID=0, Status='live', Symbol='CYSLTR1', Aliases=['CYSLT1', 'CYSLT1R', 'CYSLTR', 'HMTMF81'], description='cysteinyl leukotriene receptor 1', other_designations='cysteinyl leukotriene receptor 1|G-protein coupled receptor HG55|LTD4 receptor|cysteinyl leukotriene D4 receptor', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78271468, end_position_on_the_genomic_accession=78327611, orientation='minus', exon_count=5, OMIM=[300201], no_hdr0=''),
    10801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10801, CurrentID=0, Status='live', Symbol='SEPTIN9', Aliases=['AF17q25', 'MSF', 'MSF1', 'NAPB', 'PNUTL4', 'SEPT9', 'SINT1', 'SeptD1'], description='septin 9', other_designations='septin-9|MLL septin-like fusion protein MSF-A|Ov/Br septin|ovarian/breast septin|septin D1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=77281499, end_position_on_the_genomic_accession=77500596, orientation='plus', exon_count=21, OMIM=[604061], no_hdr0=''),
    10802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10802, CurrentID=0, Status='live', Symbol='SEC24A', Aliases=[], description='SEC24 homolog A, COPII coat complex component', other_designations='protein transport protein Sec24A|SEC24 family, member A|SEC24 related gene family, member A|SEC24-related protein A', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134647757, end_position_on_the_genomic_accession=134727909, orientation='plus', exon_count=26, OMIM=[607183], no_hdr0=''),
    10803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10803, CurrentID=0, Status='live', Symbol='CCR9', Aliases=['CC-CKR-9', 'CDw199', 'GPR-9-6', 'GPR28'], description='C-C motif chemokine receptor 9', other_designations='C-C chemokine receptor type 9|G protein-coupled receptor 28|chemokine (C-C motif) receptor 9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45886064, end_position_on_the_genomic_accession=45903174, orientation='plus', exon_count=6, OMIM=[604738], no_hdr0=''),
    10804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10804, CurrentID=0, Status='live', Symbol='GJB6', Aliases=['CX30', 'DFNA3', 'DFNA3B', 'DFNB1B', 'ECTD2', 'ED2', 'EDH', 'HED', 'HED2'], description='gap junction protein beta 6', other_designations='gap junction beta-6 protein|connexin 30|ectodermal dysplasia 2, hidrotic (Clouston syndrome)|gap junction protein, beta 6, 30kDa', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20221962, end_position_on_the_genomic_accession=20232319, orientation='minus', exon_count=6, OMIM=[604418], no_hdr0=''),
    10806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10806, CurrentID=0, Status='live', Symbol='SDCCAG8', Aliases=['BBS16', 'CCCAP', 'CCCAP SLSN7', 'HSPC085', 'NPHP10', 'NY-CO-8', 'SLSN7', 'hCCCAP'], description='SHH signaling and ciliogenesis regulator SDCCAG8', other_designations='serologically defined colon cancer antigen 8|Bardet-Biedl syndrome 16|antigen NY-CO-8|centrosomal colon cancer autoantigen protein|nephrocystin 10', map_location='1q43-q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=243255418, end_position_on_the_genomic_accession=243503683, orientation='plus', exon_count=27, OMIM=[613524], no_hdr0=''),
    10807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10807, CurrentID=0, Status='live', Symbol='ENTR1', Aliases=['NY-CO-3', 'SDCCAG3', 'SDDAG3'], description='endosome associated trafficking regulator 1', other_designations='endosome-associated-trafficking regulator 1|antigen NY-CO-3|serologically defined colon cancer antigen 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136401922, end_position_on_the_genomic_accession=136410614, orientation='minus', exon_count=10, OMIM=[618289], no_hdr0=''),
    10808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10808, CurrentID=0, Status='live', Symbol='HSPH1', Aliases=['HSP105', 'HSP105A', 'HSP105B', 'NY-CO-25'], description='heat shock protein family H (Hsp110) member 1', other_designations='heat shock protein 105 kDa|antigen NY-CO-25|heat shock 105kDa/110kDa protein 1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=31134973, end_position_on_the_genomic_accession=31162388, orientation='minus', exon_count=19, OMIM=[610703], no_hdr0=''),
    10809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10809, CurrentID=0, Status='live', Symbol='STARD10', Aliases=['CGI-52', 'NY-CO-28', 'PCTP2', 'SDCCAG28'], description='StAR related lipid transfer domain containing 10', other_designations='START domain-containing protein 10|PCTP-L|PCTP-like protein|START domain containing 10|StAR-related lipid transfer (START) domain containing 10|antigen NY-CO-28|serologically defined colon cancer antigen 28|stAR-related lipid transfer protein 10', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72754729, end_position_on_the_genomic_accession=72794047, orientation='minus', exon_count=7, OMIM=[617382], no_hdr0=''),
    10810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10810, CurrentID=0, Status='live', Symbol='WASF3', Aliases=['Brush-1', 'SCAR3', 'WAVE3'], description='WASP family member 3', other_designations='wiskott-Aldrich syndrome protein family member 3|WAS protein family member 3|WASP family Verprolin-homologous protein 3|protein WAVE-3|verprolin homology domain-containing protein 3', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=26539139, end_position_on_the_genomic_accession=26688948, orientation='plus', exon_count=14, OMIM=[605068], no_hdr0=''),
    10811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10811, CurrentID=0, Status='live', Symbol='NOXA1', Aliases=['NY-CO-31', 'SDCCAG31', 'p51NOX'], description='NADPH oxidase activator 1', other_designations='NADPH oxidase activator 1|NCF2-like protein|Nox activator 1|antigen NY-CO-31|inhibitory NADPH oxidase activator 1|p51-nox|p67phox-like factor|serologically defined colon cancer antigen 31', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137423372, end_position_on_the_genomic_accession=137434406, orientation='plus', exon_count=15, OMIM=[611255], no_hdr0=''),
    10813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10813, CurrentID=0, Status='live', Symbol='UTP14A', Aliases=['NYCO16', 'SDCCAG16', 'Utp14', 'dJ537K23.3'], description='UTP14A small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 14 homolog A|UTP14, U3 small nucleolar ribonucleoprotein, homolog A|UTP14A small subunit (SSU) processome component|antigen NY-CO-16|serologically defined colon cancer antigen 16', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129906131, end_position_on_the_genomic_accession=129929752, orientation='plus', exon_count=17, OMIM=[300508], no_hdr0=''),
    10814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10814, CurrentID=0, Status='live', Symbol='CPLX2', Aliases=['921-L', 'CPX-2', 'CPX2', 'Hfb1'], description='complexin 2', other_designations='complexin-2|CPX II|complexin II|synaphin 1', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=175796533, end_position_on_the_genomic_accession=175884021, orientation='plus', exon_count=8, OMIM=[605033], no_hdr0=''),
    10815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10815, CurrentID=0, Status='live', Symbol='CPLX1', Aliases=['CPX-I', 'CPX1', 'DEE63', 'EIEE63'], description='complexin 1', other_designations='complexin-1|CPX I|complexin I|synaphin 2', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=784957, end_position_on_the_genomic_accession=826129, orientation='minus', exon_count=5, OMIM=[605032], no_hdr0=''),
    10816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10816, CurrentID=0, Status='live', Symbol='SPINT3', Aliases=['HKIB9'], description='serine peptidase inhibitor, Kunitz type 3', other_designations='kunitz-type protease inhibitor 3|serine protease inhibitor, Kunitz type, 3', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45512461, end_position_on_the_genomic_accession=45515622, orientation='minus', exon_count=2, OMIM=[613941], no_hdr0=''),
    10817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10817, CurrentID=0, Status='live', Symbol='FRS3', Aliases=['FRS2-beta', 'FRS2B', 'FRS2beta', 'SNT-2', 'SNT2'], description='fibroblast growth factor receptor substrate 3', other_designations='fibroblast growth factor receptor substrate 3|FGFR substrate 3|FGFR-signaling adaptor SNT2|suc1-associated neurotrophic factor target 2 (FGFR signalling adaptor)|testicular tissue protein Li 71', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41770176, end_position_on_the_genomic_accession=41779900, orientation='minus', exon_count=9, OMIM=[607744], no_hdr0=''),
    10818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10818, CurrentID=0, Status='live', Symbol='FRS2', Aliases=['FRS1AA', 'FRS2alpha', 'SNT', 'SNT-1', 'SNT1', 'FRS2'], description='fibroblast growth factor receptor substrate 2', other_designations='fibroblast growth factor receptor substrate 2|FGFR signalling adaptor|FGFR substrate 2|FGFR-signaling adaptor SNT|epididymis secretory sperm binding protein|suc1-associated neurotrophic factor target 1', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69470371, end_position_on_the_genomic_accession=69579793, orientation='plus', exon_count=16, OMIM=[607743], no_hdr0=''),
    10825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10825, CurrentID=0, Status='live', Symbol='NEU3', Aliases=['SIAL3'], description='neuraminidase 3', other_designations='sialidase-3|N-acetyl-alpha-neuraminidase 3|ganglioside sialidase|ganglioside sialidasedis|membrane sialidase|sialidase 3 (membrane sialidase)', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74988644, end_position_on_the_genomic_accession=75010907, orientation='plus', exon_count=7, OMIM=[604617], no_hdr0=''),
    10826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10826, CurrentID=0, Status='live', Symbol='FAXDC2', Aliases=['C5orf4'], description='fatty acid hydroxylase domain containing 2', other_designations='fatty acid hydroxylase domain-containing protein 2', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154817018, end_position_on_the_genomic_accession=154850683, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    10827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10827, CurrentID=0, Status='live', Symbol='FAM114A2', Aliases=['133K02', 'C5orf3'], description='family with sequence similarity 114 member A2', other_designations='protein FAM114A2|testis tissue sperm-binding protein Li 81P', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=153990148, end_position_on_the_genomic_accession=154038936, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    10838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10838, CurrentID=0, Status='live', Symbol='ZNF275', Aliases=[], description='zinc finger protein 275', other_designations='zinc finger protein 275', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153334153, end_position_on_the_genomic_accession=153352926, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    10840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10840, CurrentID=0, Status='live', Symbol='ALDH1L1', Aliases=['10-FTHFDH', '10-fTHF', 'FDH', 'FTHFD'], description='aldehyde dehydrogenase 1 family member L1', other_designations='cytosolic 10-formyltetrahydrofolate dehydrogenase|10-formyltetrahydrofolate dehydrogenase|MER57B-ALDH1L1', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126103565, end_position_on_the_genomic_accession=126197758, orientation='minus', exon_count=27, OMIM=[600249], no_hdr0=''),
    10841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10841, CurrentID=0, Status='live', Symbol='FTCD', Aliases=['LCHC1'], description='formimidoyltransferase cyclodeaminase', other_designations='formimidoyltransferase-cyclodeaminase|formiminotransferase-cyclodeaminase', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46135981, end_position_on_the_genomic_accession=46156482, orientation='minus', exon_count=16, OMIM=[606806], no_hdr0=''),
    10842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10842, CurrentID=0, Status='live', Symbol='PPP1R17', Aliases=['C7orf16', 'GSBS'], description='protein phosphatase 1 regulatory subunit 17', other_designations='protein phosphatase 1 regulatory subunit 17|G-substrate', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31687215, end_position_on_the_genomic_accession=31710158, orientation='plus', exon_count=6, OMIM=[604088], no_hdr0=''),
    10844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10844, CurrentID=0, Status='live', Symbol='TUBGCP2', Aliases=['ALP4', 'GCP-2', 'GCP2', 'Grip103', 'PAMDDFS', 'SPBC97', 'SPC97', 'Spc97p', 'h103p', 'hGCP2', 'hSpc97'], description='tubulin gamma complex associated protein 2', other_designations='gamma-tubulin complex component 2|gamma-ring complex protein 103 kDa|hGrip103|spindle pole body protein Spc97 homolog', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133278635, end_position_on_the_genomic_accession=133312337, orientation='minus', exon_count=20, OMIM=[617817], no_hdr0=''),
    10845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10845, CurrentID=0, Status='live', Symbol='CLPX', Aliases=['EPP2'], description='caseinolytic mitochondrial matrix peptidase chaperone subunit X', other_designations='ATP-dependent Clp protease ATP-binding subunit clpX-like, mitochondrial|ClpX caseinolytic peptidase X homolog|ClpX caseinolytic protease X homolog|energy-dependent regulator of proteolysis', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65148219, end_position_on_the_genomic_accession=65185374, orientation='minus', exon_count=14, OMIM=[615611], no_hdr0=''),
    10846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10846, CurrentID=0, Status='live', Symbol='PDE10A', Aliases=['ADSD2', 'HSPDE10A', 'IOLOD', 'LINC0047319', 'PDE10A'], description='phosphodiesterase 10A', other_designations="cAMP and cAMP-inhibited cGMP 3',5'-cyclic phosphodiesterase 10A|3',5' cAMP/cGMP phosphodiesterase|dJ416F21.1 (phosphodiesterase 10A)|phosphodiesterase 10A1 (PDE10A1)|phosphodiesterase 10A7 (PDE10A7)", map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=165327287, end_position_on_the_genomic_accession=165988115, orientation='minus', exon_count=31, OMIM=[610652], no_hdr0=''),
    10847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10847, CurrentID=0, Status='live', Symbol='SRCAP', Aliases=['DOMO1', 'EAF1', 'FLHS', 'SWR1'], description='Snf2 related CREBBP activator protein', other_designations='helicase SRCAP|Snf2-related CBP activator protein|Swi2/Snf2-related ATPase homolog, domino homolog 1|domino homolog 2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30699171, end_position_on_the_genomic_accession=30741409, orientation='plus', exon_count=34, OMIM=[611421], no_hdr0=''),
    10848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10848, CurrentID=0, Status='live', Symbol='PPP1R13L', Aliases=['IASPP', 'NKIP1', 'RAI', 'RAI4'], description='protein phosphatase 1 regulatory subunit 13 like', other_designations='relA-associated inhibitor|NFkB interacting protein 1|PPP1R13B-like protein|inhibitor of ASPP protein|inhibitor of apoptosis stimulating protein of p53|protein iASPP|protein phosphatase 1, regulatory (inhibitor) subunit 13 like|retinoic acid induced 4', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45379634, end_position_on_the_genomic_accession=45406361, orientation='minus', exon_count=15, OMIM=[607463], no_hdr0=''),
    10849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10849, CurrentID=0, Status='live', Symbol='POLR1G', Aliases=['ASE-1', 'ASE1', 'CAST', 'CD3EAP', 'PAF49', 'RPA34'], description='RNA polymerase I subunit G', other_designations='DNA-directed RNA polymerase I subunit RPA34|CD3e antigen, epsilon polypeptide associated protein|CD3e molecule associated protein|CD3e molecule, epsilon associated protein|DNA-directed RNA polymerase I subunit G|RNA polymerase I-associated factor PAF49|antisense to ERCC-1 protein', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45406644, end_position_on_the_genomic_accession=45410737, orientation='plus', exon_count=3, OMIM=[107325], no_hdr0=''),
    10850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10850, CurrentID=0, Status='live', Symbol='CCL27', Aliases=['ALP', 'CTACK', 'CTAK', 'ESKINE', 'ILC', 'PESKY', 'SCYA27'], description='C-C motif chemokine ligand 27', other_designations='C-C motif chemokine 27|CC chemokine ILC|IL-11 R-alpha-locus chemokine|IL-11 Ralpha-locus chemokine|chemokine (C-C motif) ligand 27|cutaneous T-cell attracting chemokine|skinkine|small inducible cytokine subfamily A (Cys-Cys), member 27|small-inducible cytokine A27', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34661890, end_position_on_the_genomic_accession=34662657, orientation='minus', exon_count=3, OMIM=[604833], no_hdr0=''),
    10855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10855, CurrentID=0, Status='live', Symbol='HPSE', Aliases=['HPA', 'HPA1', 'HPR11', 'HSE1', 'HPSE'], description='heparanase', other_designations='heparanase|endo-glucoronidase|heparanase-1', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83292461, end_position_on_the_genomic_accession=83335153, orientation='minus', exon_count=13, OMIM=[604724], no_hdr0=''),
    10856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10856, CurrentID=0, Status='live', Symbol='RUVBL2', Aliases=['CGI-46', 'ECP-51', 'ECP51', 'INO80J', 'REPTIN', 'RVB2', 'TAP54-beta', 'TIH2', 'TIP48', 'TIP49B'], description='RuvB like AAA ATPase 2', other_designations='ruvB-like 2|48 kDa TATA box-binding protein-interacting protein|48 kDa TBP-interacting protein|51 kDa erythrocyte cytosolic protein|INO80 complex subunit J|RuvB (E coli homolog)-like 2|TIP60-associated protein 54-beta|erythrocyte cytosolic protein, 51-KD|repressing pontin 52|reptin52 protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48993448, end_position_on_the_genomic_accession=49015995, orientation='plus', exon_count=16, OMIM=[604788], no_hdr0=''),
    10857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10857, CurrentID=0, Status='live', Symbol='PGRMC1', Aliases=['Dap1', 'HPR6.6', 'IZA', 'MPR'], description='progesterone receptor membrane component 1', other_designations='membrane-associated progesterone receptor component 1|progesterone binding protein', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119236285, end_position_on_the_genomic_accession=119244466, orientation='plus', exon_count=3, OMIM=[300435], no_hdr0=''),
    10858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10858, CurrentID=0, Status='live', Symbol='CYP46A1', Aliases=['CP46', 'CYP46'], description='cytochrome P450 family 46 subfamily A member 1', other_designations='cholesterol 24-hydroxylase|CH24H|cholesterol 24-monooxygenase|cholesterol 24S-hydroxylase|cytochrome P450 46A1|cytochrome P450, family 46, subfamily A, polypeptide 1|cytochrome P450, subfamily 46 (cholesterol 24-hydroxylase)', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99684262, end_position_on_the_genomic_accession=99727321, orientation='plus', exon_count=18, OMIM=[604087], no_hdr0=''),
    10859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10859, CurrentID=0, Status='live', Symbol='LILRB1', Aliases=['CD85J', 'ILT-2', 'ILT2', 'LIR-1', 'LIR1', 'MIR-7', 'MIR7', 'PIR-B', 'PIRB'], description='leukocyte immunoglobulin like receptor B1', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 1|CD85 antigen-like family member J|Ig-like transcript 2|immunoglobulin heavy chain variable region|leucocyte Ig-like receptor B1|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 1|monocyte/macrophage immunoglobulin-like receptor 7|myeloid inhibitory receptor 7', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54616322, end_position_on_the_genomic_accession=54638022, orientation='plus', exon_count=17, OMIM=[604811], no_hdr0=''),
    10861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10861, CurrentID=0, Status='live', Symbol='SLC26A1', Aliases=['CAON', 'EDM4', 'SAT-1', 'SAT1'], description='solute carrier family 26 member 1', other_designations='sulfate anion transporter 1|solute carrier family 26 (anion exchanger), member 1|solute carrier family 26 (sulfate transporter), member 1|sulfate anion tranporter AT1|sulfate/anion transporter SAT-1 protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=979035, end_position_on_the_genomic_accession=993404, orientation='minus', exon_count=5, OMIM=[610130], no_hdr0=''),
    10863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10863, CurrentID=0, Status='live', Symbol='ADAM28', Aliases=['ADAM 28', 'MDC-L', 'MDCL', 'eMDC II', 'eMDCII'], description='ADAM metallopeptidase domain 28', other_designations='disintegrin and metalloproteinase domain-containing protein 28|epididymal metalloproteinase-like, disintegrin-like, and cysteine-rich protein II|epididymial metalloproteinase-like, disintegrin-like, and cysteine-rich protein II|epididymis secretory sperm binding protein|metalloproteinase-like, disintegrin-like, and cysteine-rich protein-L', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=24294040, end_position_on_the_genomic_accession=24359014, orientation='plus', exon_count=28, OMIM=[606188], no_hdr0=''),
    10864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10864, CurrentID=0, Status='live', Symbol='SLC22A7', Aliases=['NLT', 'OAT2', 'hOAT11'], description='solute carrier family 22 member 7', other_designations='solute carrier family 22 member 7|hOAT2|liver-specific transporter|novel liver transporter|organic anion transporter 11|organic anion transporter 2|solute carrier family 22 (organic anion transporter), member 7', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43295710, end_position_on_the_genomic_accession=43305538, orientation='plus', exon_count=14, OMIM=[604995], no_hdr0=''),
    10865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10865, CurrentID=0, Status='live', Symbol='ARID5A', Aliases=['MRF-1', 'MRF1', 'RP11-363D14'], description='AT-rich interaction domain 5A', other_designations='AT-rich interactive domain-containing protein 5A|ARID domain-containing protein 5A|AT rich interactive domain 5A (MRF1-like)|RFVG5814|modulator recognition factor 1|modulator recognition factor I', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96536752, end_position_on_the_genomic_accession=96552638, orientation='plus', exon_count=9, OMIM=[611583], no_hdr0=''),
    10867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10867, CurrentID=0, Status='live', Symbol='TSPAN9', Aliases=['NET-5', 'NET5', 'PP1057'], description='tetraspanin 9', other_designations='tetraspanin-9|new EST tetraspan 5|tetraspan NET-5|transmembrane 4 superfamily member tetraspan NET-5|tspan-9', map_location='12p13.33-p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=3077377, end_position_on_the_genomic_accession=3286561, orientation='plus', exon_count=12, OMIM=[613137], no_hdr0=''),
    10868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10868, CurrentID=0, Status='live', Symbol='USP20', Aliases=['LSFR3A', 'VDU2', 'hVDU2'], description='ubiquitin specific peptidase 20', other_designations='ubiquitin carboxyl-terminal hydrolase 20|deubiquitinating enzyme 20|pVHL-interacting deubiquitinating enzyme 2|ubiquitin thioesterase 20|ubiquitin thiolesterase 20|ubiquitin-specific-processing protease 20', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129835429, end_position_on_the_genomic_accession=129881836, orientation='plus', exon_count=27, OMIM=[615143], no_hdr0=''),
    10869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10869, CurrentID=0, Status='live', Symbol='USP19', Aliases=['ZMYND9'], description='ubiquitin specific peptidase 19', other_designations='ubiquitin carboxyl-terminal hydrolase 19|deubiquitinating enzyme 19|ubiquitin specific protease 19|ubiquitin thioesterase 19|ubiquitin thiolesterase 19|ubiquitin-specific-processing protease 19|zinc finger MYND domain-containing protein 9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49108050, end_position_on_the_genomic_accession=49120933, orientation='minus', exon_count=29, OMIM=[614471], no_hdr0=''),
    10870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10870, CurrentID=0, Status='live', Symbol='HCST', Aliases=['DAP10', 'KAP10', 'PIK3AP'], description='hematopoietic cell signal transducer', other_designations='hematopoietic cell signal transducer|DNAX-activation protein 10|kinase assoc pro of ~10kDa|kinase assoc protein|membrane protein DAP10|phosphoinositide-3-kinase adaptor protein|transmembrane adapter protein KAP10', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35902365, end_position_on_the_genomic_accession=35904377, orientation='plus', exon_count=4, OMIM=[604089], no_hdr0=''),
    10871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10871, CurrentID=0, Status='live', Symbol='CD300C', Aliases=['CLM-6', 'CMRF-35', 'CMRF-35A', 'CMRF35', 'CMRF35-A1', 'CMRF35A', 'CMRF35A1', 'IGSF16', 'LIR'], description='CD300c molecule', other_designations='CMRF35-like molecule 6|CD300 antigen-like family member C|CD300c antigen|CMRF35 antigen|CMRF35 leukocyte immunoglobulin-like receptor|CMRF35A leukocyte immunoglobulin-like receptor|immunoglobulin superfamily member 16', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74534359, end_position_on_the_genomic_accession=74546115, orientation='minus', exon_count=7, OMIM=[606786], no_hdr0=''),
    10873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10873, CurrentID=0, Status='live', Symbol='ME3', Aliases=['NADP-ME'], description='malic enzyme 3', other_designations='NADP-dependent malic enzyme, mitochondrial|malate dehydrogenase (oxaloacetate-decarboxylating) (NADP(+))|malic enzyme 3, NADP(+)-dependent, mitochondrial|malic enzyme, NADP+-dependent, mitochondrial|mitochondrial NADP(+)-dependent malic enzyme 3|pyruvic-malic carboxylase', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86441108, end_position_on_the_genomic_accession=86674746, orientation='minus', exon_count=22, OMIM=[604626], no_hdr0=''),
    10874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10874, CurrentID=0, Status='live', Symbol='NMU', Aliases=[], description='neuromedin U', other_designations='neuromedin-U|neuromedin U precursor-related peptide/neuromedin U preproprotein|prepro-NMU', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55595231, end_position_on_the_genomic_accession=55636793, orientation='minus', exon_count=13, OMIM=[605103], no_hdr0=''),
    10875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10875, CurrentID=0, Status='live', Symbol='FGL2', Aliases=['T49', 'pT49'], description='fibrinogen like 2', other_designations='fibroleukin|fibrinogen-like protein 2', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77193369, end_position_on_the_genomic_accession=77199819, orientation='minus', exon_count=2, OMIM=[605351], no_hdr0=''),
    10876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10876, CurrentID=0, Status='live', Symbol='EDDM3A', Aliases=['EP3A', 'FAM12A', 'HE3-ALPHA', 'HE3A', 'HE3ALPHA', 'RAM1'], description='epididymal protein 3A', other_designations='epididymal secretory protein E3-alpha|epididymis secretory sperm binding protein|epididymis-specific 3 alpha|family with sequence similarity 12, member A|human epididymis-specific 3 alpha|human epididymis-specific protein 3-alpha|ribonuclease A M1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20722391, end_position_on_the_genomic_accession=20748380, orientation='plus', exon_count=4, OMIM=[611580], no_hdr0=''),
    10877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10877, CurrentID=0, Status='live', Symbol='CFHR4', Aliases=['CFHL4', 'FHR-4', 'FHR4'], description='complement factor H related 4', other_designations='complement factor H-related protein 4', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196888051, end_position_on_the_genomic_accession=196918911, orientation='plus', exon_count=11, OMIM=[605337], no_hdr0=''),
    10878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10878, CurrentID=0, Status='live', Symbol='CFHR3', Aliases=['CFHL3', 'DOWN16', 'FHR-3', 'FHR3', 'HLF4'], description='complement factor H related 3', other_designations='complement factor H-related protein 3|H factor-like 4|H factor-like protein 3', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196774816, end_position_on_the_genomic_accession=196795407, orientation='plus', exon_count=6, OMIM=[605336], no_hdr0=''),
    10879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10879, CurrentID=0, Status='live', Symbol='SMR3B', Aliases=['P-B', 'PBII', 'PRL3', 'PROL3', 'SMR1B'], description='submaxillary gland androgen regulated protein 3B', other_designations='submaxillary gland androgen-regulated protein 3B|proline rich 3|proline-rich peptide P-B|proline-rich protein 3|salivary proline-rich protein|submaxillary gland androgen regulated protein 3 homolog B', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70383131, end_position_on_the_genomic_accession=70390244, orientation='plus', exon_count=3, OMIM=[611593], no_hdr0=''),
    10880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10880, CurrentID=0, Status='live', Symbol='ACTL7B', Aliases=['Tact1'], description='actin like 7B', other_designations='actin-like protein 7B|actin-like 7-beta|testis tissue sperm-binding protein Li 43a', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=108854588, end_position_on_the_genomic_accession=108855986, orientation='minus', exon_count=1, OMIM=[604304], no_hdr0=''),
    10881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10881, CurrentID=0, Status='live', Symbol='ACTL7A', Aliases=[], description='actin like 7A', other_designations='actin-like protein 7A|actin-like 7-alpha|testicular secretory protein Li 3', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=108862266, end_position_on_the_genomic_accession=108863756, orientation='plus', exon_count=1, OMIM=[604303], no_hdr0=''),
    10882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10882, CurrentID=0, Status='live', Symbol='C1QL1', Aliases=['C1QRF', 'C1QTNF14', 'CRF', 'CTRP14'], description='complement C1q like 1', other_designations='C1q-related factor|C1q and tumor necrosis factor-related protein 14|C1q/TNF-related protein 14|complement component 1, q subcomponent-like 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44959693, end_position_on_the_genomic_accession=44968303, orientation='minus', exon_count=2, OMIM=[611586], no_hdr0=''),
    10884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10884, CurrentID=0, Status='live', Symbol='MRPS30', Aliases=['MRP-S30', 'PAP', 'PDCD9', 'S30mt'], description='mitochondrial ribosomal protein S30', other_designations='39S ribosomal protein S30, mitochondrial|28S ribosomal protein S30, mitochondrial|mitochondrial large ribosomal subunit protein mL65|mitochondrial large ribosomal subunit protein mS30|programmed cell death 9', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=44808947, end_position_on_the_genomic_accession=44815514, orientation='plus', exon_count=5, OMIM=[611991], no_hdr0=''),
    10885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10885, CurrentID=0, Status='live', Symbol='WDR3', Aliases=['DIP2', 'UTP12'], description='WD repeat domain 3', other_designations='WD repeat-containing protein 3|dJ776P7.2 (WD repeat domain 3)', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117929739, end_position_on_the_genomic_accession=117966543, orientation='plus', exon_count=27, OMIM=[604737], no_hdr0=''),
    10886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10886, CurrentID=0, Status='live', Symbol='NPFFR2', Aliases=['GPR74', 'HLWAR77', 'NPFF2', 'NPGPR'], description='neuropeptide FF receptor 2', other_designations='neuropeptide FF receptor 2|G-protein coupled receptor 74|G-protein coupled receptor HLWAR77|neuropeptide FF 2|neuropeptide G-protein coupled receptor', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=72032000, end_position_on_the_genomic_accession=72148305, orientation='plus', exon_count=6, OMIM=[607449], no_hdr0=''),
    10887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10887, CurrentID=0, Status='live', Symbol='PROKR1', Aliases=['GPR73', 'GPR73a', 'PK-R1', 'PKR1', 'ZAQ'], description='prokineticin receptor 1', other_designations='prokineticin receptor 1|G protein-coupled receptor 73|G protein-coupled receptor ZAQ', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68643579, end_position_on_the_genomic_accession=68658251, orientation='plus', exon_count=3, OMIM=[607122], no_hdr0=''),
    10888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10888, CurrentID=0, Status='live', Symbol='GPR83', Aliases=['GIR', 'GPR72'], description='G protein-coupled receptor 83', other_designations='probable G-protein coupled receptor 83|G-protein coupled receptor 72|glucocorticoid induced receptor', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94377316, end_position_on_the_genomic_accession=94401419, orientation='minus', exon_count=4, OMIM=[605569], no_hdr0=''),
    10890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10890, CurrentID=0, Status='live', Symbol='RAB10', Aliases=[], description='RAB10, member RAS oncogene family', other_designations='ras-related protein Rab-10|GTP-binding protein RAB10|ras-related GTP-binding protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26034084, end_position_on_the_genomic_accession=26137454, orientation='plus', exon_count=7, OMIM=[612672], no_hdr0=''),
    10891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10891, CurrentID=0, Status='live', Symbol='PPARGC1A', Aliases=['LEM6', 'PGC-1(alpha)', 'PGC-1alpha', 'PGC-1v', 'PGC1', 'PGC1A', 'PPARGC1'], description='PPARG coactivator 1 alpha', other_designations='peroxisome proliferator-activated receptor gamma coactivator 1-alpha|L-PGC-1alpha|PGC-1-alpha|PPAR gamma coactivator variant form|PPARGC-1-alpha|PPARgamma coactivator 1alpha|ligand effect modulator-6|peroxisome proliferator-activated receptor gamma coactivator 1 alpha transcript variant B4-3ext|peroxisome proliferator-activated receptor gamma coactivator 1 alpha transcript variant B4-8a|peroxisome proliferator-activated receptor gamma coactivator 1 alpha transcript variant B5-NT', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=23792021, end_position_on_the_genomic_accession=24472905, orientation='minus', exon_count=24, OMIM=[604517], no_hdr0=''),
    10892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10892, CurrentID=0, Status='live', Symbol='MALT1', Aliases=['IMD12', 'MLT', 'MLT1', 'PCASP1'], description='MALT1 paracaspase', other_designations='mucosa-associated lymphoid tissue lymphoma translocation protein 1|MALT1 protease|caspase-like protein|mucosa associated lymphoid tissue lymphoma translocation gene 1|paracaspase-1', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=58671420, end_position_on_the_genomic_accession=58754477, orientation='plus', exon_count=19, OMIM=[604860], no_hdr0=''),
    10893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10893, CurrentID=0, Status='live', Symbol='MMP24', Aliases=['MMP-24', 'MMP25', 'MT-MMP 5', 'MT-MMP5', 'MT5-MMP', 'MT5MMP', 'MTMMP5'], description='matrix metallopeptidase 24', other_designations='matrix metalloproteinase-24|matrix metallopeptidase 24 (membrane-inserted)|matrix metalloproteinase 24 (membrane-inserted)|membrane-type 5 matrix metalloproteinase|membrane-type matrix metalloproteinase 5', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35226690, end_position_on_the_genomic_accession=35276998, orientation='plus', exon_count=10, OMIM=[604871], no_hdr0=''),
    10894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10894, CurrentID=0, Status='live', Symbol='LYVE1', Aliases=['CRSBP-1', 'HAR', 'LYVE-1', 'XLKD1'], description='lymphatic vessel endothelial hyaluronan receptor 1', other_designations='lymphatic vessel endothelial hyaluronic acid receptor 1|cell surface retention sequence binding protein-1|extracellular link domain-containing 1|extracellular link domain-containing protein 1|hyaluronic acid receptor', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10556966, end_position_on_the_genomic_accession=10568665, orientation='minus', exon_count=6, OMIM=[605702], no_hdr0=''),
    10897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10897, CurrentID=0, Status='live', Symbol='YIF1A', Aliases=['54TM', 'FinGER7', 'YIF1', 'YIF1P'], description='Yip1 interacting factor homolog A, membrane trafficking protein', other_designations='protein YIF1A|54TMp|YIP1-interacting factor homolog A|Yip1p-interacting factor|putative Rab5-interacting protein|putative transmembrane protein 54TMp', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66284580, end_position_on_the_genomic_accession=66289143, orientation='minus', exon_count=8, OMIM=[611484], no_hdr0=''),
    10898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10898, CurrentID=0, Status='live', Symbol='CPSF4', Aliases=['CPSF30', 'NAR', 'NEB-1', 'NEB1'], description='cleavage and polyadenylation specific factor 4', other_designations='cleavage and polyadenylation specificity factor subunit 4|CPSF 30 kDa subunit|NS1 effector domain-binding protein 1|cleavage and polyadenylation specific factor 4, 30kDa|cleavage and polyadenylation specificity factor 30 kDa subunit|no arches homolog|no arches-like zinc finger protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99438912, end_position_on_the_genomic_accession=99457373, orientation='plus', exon_count=9, OMIM=[603052], no_hdr0=''),
    10899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10899, CurrentID=0, Status='live', Symbol='JTB', Aliases=['HJTB', 'HSPC222', 'PAR', 'hJT'], description='jumping translocation breakpoint', other_designations='protein JTB|jumping translocation breakpoint protein|prostate androgen-regulated protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153974269, end_position_on_the_genomic_accession=153977674, orientation='minus', exon_count=5, OMIM=[604671], no_hdr0=''),
    10900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10900, CurrentID=0, Status='live', Symbol='RUNDC3A', Aliases=['RAP2IP', 'RPIP-8', 'RPIP8'], description='RUN domain containing 3A', other_designations='RUN domain-containing protein 3A|RaP2 interacting protein 8|rap2-interacting protein 8', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44308559, end_position_on_the_genomic_accession=44318670, orientation='plus', exon_count=13, OMIM=[605448], no_hdr0=''),
    10901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10901, CurrentID=0, Status='live', Symbol='DHRS4', Aliases=['CR', 'NRDR', 'PHCR', 'PSCD', 'SCAD-SRL', 'SDR-SRL', 'SDR25C1', 'SDR25C2'], description='dehydrogenase/reductase 4', other_designations='dehydrogenase/reductase SDR family member 4|NADPH-dependent carbonyl reductase/NADP-retinol dehydrogenase|NADPH-dependent retinol dehydrogenase/reductase|dehydrogenase/reductase (SDR family) member 4 like 2A|peroxisomal short-chain alcohol dehydrogenase|short chain dehydrogenase/reductase family 25C member 2|short chain dehydrogenase/reductase family 25C, member 1|short-chain dehydrogenase/reductase family member 4', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23953735, end_position_on_the_genomic_accession=23969279, orientation='plus', exon_count=9, OMIM=[611596], no_hdr0=''),
    10902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10902, CurrentID=0, Status='live', Symbol='BRD8', Aliases=['SMAP', 'SMAP2', 'p120'], description='bromodomain containing 8', other_designations='bromodomain-containing protein 8|skeletal muscle abundant protein 2|thyroid hormone receptor coactivating protein of 120 kDa|trCP120', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138139770, end_position_on_the_genomic_accession=138178630, orientation='minus', exon_count=29, OMIM=[602848], no_hdr0=''),
    10903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10903, CurrentID=0, Status='live', Symbol='MTMR11', Aliases=['CRA'], description='myotubularin related protein 11', other_designations='myotubularin-related protein 11|cisplatin resistance associated|cisplatin resistance-associated protein|hCRA|inactive phosphatidylinositol 3-phosphatase 11', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149928651, end_position_on_the_genomic_accession=149938329, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    10904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10904, CurrentID=0, Status='live', Symbol='BLCAP', Aliases=['BC10'], description='BLCAP apoptosis inducing factor', other_designations='bladder cancer-associated protein|bladder cancer associated protein|bladder cancer related protein (10kD)', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37517417, end_position_on_the_genomic_accession=37527876, orientation='minus', exon_count=7, OMIM=[613110], no_hdr0=''),
    10905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10905, CurrentID=0, Status='live', Symbol='MAN1A2', Aliases=['MAN1B'], description='mannosidase alpha class 1A member 2', other_designations='mannosyl-oligosaccharide 1,2-alpha-mannosidase IB|alpha-1,2-mannosidase IB|alpha1,2-mannosidase|processing alpha-1,2-mannosidase IB', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117367393, end_position_on_the_genomic_accession=117528872, orientation='plus', exon_count=14, OMIM=[604345], no_hdr0=''),
    10906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10906, CurrentID=0, Status='live', Symbol='TRAFD1', Aliases=['FLN29'], description='TRAF-type zinc finger domain containing 1', other_designations='TRAF-type zinc finger domain-containing protein 1|FLN29 gene product', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112125560, end_position_on_the_genomic_accession=112153604, orientation='plus', exon_count=12, OMIM=[613197], no_hdr0=''),
    10907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10907, CurrentID=0, Status='live', Symbol='TXNL4A', Aliases=['BMKS', 'DIB1', 'DIM1', 'SNRNP15', 'TXNL4', 'U5-15kD'], description='thioredoxin like 4A', other_designations='thioredoxin-like protein 4A|DIM1 protein homolog|spliceosomal U5 snRNP-specific 15 kDa protein|thioredoxin-like 4|thioredoxin-like U5 snRNP protein U5-15kD', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79970813, end_position_on_the_genomic_accession=80033936, orientation='minus', exon_count=7, OMIM=[611595], no_hdr0=''),
    10908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10908, CurrentID=0, Status='live', Symbol='PNPLA6', Aliases=['BNHS', 'LNMS', 'NTE', 'NTEMND', 'OMCS', 'SPG39', 'iPLA2delta', 'sws'], description='patatin like phospholipase domain containing 6', other_designations='patatin-like phospholipase domain-containing protein 6|neuropathy target esterase', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7534164, end_position_on_the_genomic_accession=7561767, orientation='plus', exon_count=37, OMIM=[603197], no_hdr0=''),
    10910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10910, CurrentID=0, Status='live', Symbol='SUGT1', Aliases=['SGT1'], description='SGT1 homolog, MIS12 kinetochore complex assembly cochaperone', other_designations='protein SGT1 homolog|SGT1, suppressor of G2 allele of SKP1|putative 40-6-3 protein|suppressor of G2 allele of SKP1, S. cerevisiae, homolog of', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52652703, end_position_on_the_genomic_accession=52700909, orientation='plus', exon_count=16, OMIM=[604098], no_hdr0=''),
    10911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10911, CurrentID=0, Status='live', Symbol='UTS2', Aliases=['PRO1068', 'U-II', 'UCN2', 'UII'], description='urotensin 2', other_designations='urotensin-2|prepro U-II|urotensin II', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=7846345, end_position_on_the_genomic_accession=7913615, orientation='minus', exon_count=7, OMIM=[604097], no_hdr0=''),
    10912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10912, CurrentID=0, Status='live', Symbol='GADD45G', Aliases=['CR6', 'DDIT2', 'GADD45gamma', 'GRP17'], description='growth arrest and DNA damage inducible gamma', other_designations='growth arrest and DNA damage-inducible protein GADD45 gamma|DDIT-2|DNA damage-inducible transcript 2 protein|GADD45-gamma|cytokine-responsive protein CR6|gadd-related protein, 17 kD', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=89605009, end_position_on_the_genomic_accession=89606555, orientation='plus', exon_count=4, OMIM=[604949], no_hdr0=''),
    10913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10913, CurrentID=0, Status='live', Symbol='EDAR', Aliases=['DL', 'ECTD10A', 'ECTD10B', 'ED1R', 'ED3', 'ED5', 'EDA-A1R', 'EDA1R', 'EDA3', 'HRM1'], description='ectodysplasin A receptor', other_designations='tumor necrosis factor receptor superfamily member EDAR|EDA-A1 receptor|anhidrotic ectodysplasin receptor 1|downless homolog|downless, mouse, homolog of|ectodermal dysplasia receptor|ectodysplasin 1, anhidrotic receptor', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108894471, end_position_on_the_genomic_accession=108989256, orientation='minus', exon_count=12, OMIM=[604095], no_hdr0=''),
    10914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10914, CurrentID=0, Status='live', Symbol='PAPOLA', Aliases=['PAP', 'PAP-alpha'], description='poly(A) polymerase alpha', other_designations='poly(A) polymerase alpha|polynucleotide adenylyltransferase alpha', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96502376, end_position_on_the_genomic_accession=96567116, orientation='plus', exon_count=23, OMIM=[605553], no_hdr0=''),
    10915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10915, CurrentID=0, Status='live', Symbol='TCERG1', Aliases=['CA150', 'TAF2S', 'Urn1'], description='transcription elongation regulator 1', other_designations='transcription elongation regulator 1|TATA box binding protein (TBP)-associated factor, RNA polymerase II, S, 150kD|TATA box-binding protein-associated factor 2S|co-activator of 150 kDa|transcription factor CA150', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146447330, end_position_on_the_genomic_accession=146511961, orientation='plus', exon_count=26, OMIM=[605409], no_hdr0=''),
    10916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10916, CurrentID=0, Status='live', Symbol='MAGED2', Aliases=['11B6', 'BARTS5', 'BCG-1', 'BCG1', 'HCA10', 'MAGE-D2'], description='MAGE family member D2', other_designations='melanoma-associated antigen D2|MAGE-D2 antigen|breast cancer-associated gene 1 protein|hepatocellular carcinoma-associated protein JCL-1|melanoma antigen family D, 2|melanoma antigen family D2', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54807745, end_position_on_the_genomic_accession=54816015, orientation='plus', exon_count=15, OMIM=[300470], no_hdr0=''),
    10917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10917, CurrentID=0, Status='live', Symbol='BTNL3', Aliases=['BTN9.1', 'BTNLR'], description='butyrophilin like 3', other_designations='butyrophilin-like protein 3|butyrophilin-like receptor', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180988846, end_position_on_the_genomic_accession=181006727, orientation='plus', exon_count=8, OMIM=[606192], no_hdr0=''),
    10919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10919, CurrentID=0, Status='live', Symbol='EHMT2', Aliases=['BAT8', 'C6orf30', 'G9A', 'GAT8', 'KMT1C', 'NG36'], description='euchromatic histone lysine methyltransferase 2', other_designations='histone-lysine N-methyltransferase EHMT2|G9A histone methyltransferase|H3-K9-HMTase 3|HLA-B associated transcript 8|ankyrin repeat-containing protein|euchromatic histone-lysine N-methyltransferase 2|histone H3-K9 methyltransferase 3|histone-lysine N-methyltransferase, H3 lysine-9 specific 3|lysine N-methyltransferase 1C', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31879759, end_position_on_the_genomic_accession=31897698, orientation='minus', exon_count=29, OMIM=[604599], no_hdr0=''),
    10920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10920, CurrentID=0, Status='live', Symbol='COPS8', Aliases=['COP9', 'CSN8', 'SGN8'], description='COP9 signalosome subunit 8', other_designations='COP9 signalosome complex subunit 8|COP9 constitutive photomorphogenic homolog subunit 8|COP9 homolog|JAB1-containing signalosome subunit 8|hCOP9|signalosome subunit 8', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237085889, end_position_on_the_genomic_accession=237100474, orientation='plus', exon_count=9, OMIM=[616011], no_hdr0=''),
    10921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10921, CurrentID=0, Status='live', Symbol='RNPS1', Aliases=['E5.1'], description='RNA binding protein with serine rich domain 1', other_designations='RNA-binding protein with serine-rich domain 1|RNA binding protein with serine-rich domain|RNA-binding protein S1, serine-rich domain|SR protein|SR-related protein LDC2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2253116, end_position_on_the_genomic_accession=2268126, orientation='minus', exon_count=11, OMIM=[606447], no_hdr0=''),
    10922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10922, CurrentID=0, Status='live', Symbol='FASTK', Aliases=['FAST'], description='Fas activated serine/threonine kinase', other_designations='fas-activated serine/threonine kinase|FAST kinase', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151076621, end_position_on_the_genomic_accession=151080861, orientation='minus', exon_count=11, OMIM=[606965], no_hdr0=''),
    10923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10923, CurrentID=0, Status='live', Symbol='SUB1', Aliases=['P15', 'PC4', 'p14'], description='SUB1 regulator of transcription', other_designations='activated RNA polymerase II transcriptional coactivator p15|SUB1 homolog, transcriptional regulator|activated RNA polymerase II transcription cofactor 4|positive cofactor 4', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=32531778, end_position_on_the_genomic_accession=32604079, orientation='plus', exon_count=9, OMIM=[600503], no_hdr0=''),
    10924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10924, CurrentID=0, Status='live', Symbol='SMPDL3A', Aliases=['ASM3A', 'ASML3a', 'yR36GH4.1'], description='sphingomyelin phosphodiesterase acid like 3A', other_designations='acid sphingomyelinase-like phosphodiesterase 3a|0610010C24Rik|ASM-like phosphodiesterase 3a', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122788456, end_position_on_the_genomic_accession=122809720, orientation='plus', exon_count=9, OMIM=[610728], no_hdr0=''),
    10926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10926, CurrentID=0, Status='live', Symbol='DBF4', Aliases=['ASK', 'CHIFA', 'ZDBF1', 'DBF4'], description='DBF4 zinc finger', other_designations='protein DBF4 homolog A|DBF4 homolog|DBF4 zinc finger A|DBF4-type zinc finger-containing protein 1|activator of S phase kinase|chiffon homolog A|zinc finger, DBF-type containing 1', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87876493, end_position_on_the_genomic_accession=87909553, orientation='plus', exon_count=12, OMIM=[604281], no_hdr0=''),
    10927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10927, CurrentID=0, Status='live', Symbol='SPIN1', Aliases=['SPIN', 'TDRD24'], description='spindlin 1', other_designations='spindlin-1|ovarian cancer-related protein|spindlin1', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=88388444, end_position_on_the_genomic_accession=88478694, orientation='plus', exon_count=6, OMIM=[609936], no_hdr0=''),
    10928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10928, CurrentID=0, Status='live', Symbol='RALBP1', Aliases=['RIP1', 'RLIP1', 'RLIP76'], description='ralA binding protein 1', other_designations='ralA-binding protein 1|76 kDa Ral-interacting protein|DNP-SG ATPase|dinitrophenyl S-glutathione ATPase|ral-interacting protein 1', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9475513, end_position_on_the_genomic_accession=9538114, orientation='plus', exon_count=10, OMIM=[605801], no_hdr0=''),
    10929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10929, CurrentID=0, Status='live', Symbol='SRSF8', Aliases=['DSM-1', 'SFRS2B', 'SRP46'], description='serine and arginine rich splicing factor 8', other_designations='serine/arginine-rich splicing factor 8|SR splicing factor 8|pre-mRNA-splicing factor SRP46|splicing factor, arginine/serine-rich 2B|splicing factor, arginine/serine-rich, 46kD', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95066877, end_position_on_the_genomic_accession=95071225, orientation='plus', exon_count=2, OMIM=[603269], no_hdr0=''),
    10930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10930, CurrentID=0, Status='live', Symbol='APOBEC2', Aliases=['ARCD1', 'ARP1'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 2', other_designations='C->U-editing enzyme APOBEC-2|apolipoprotein B mRNA editing enzyme, catalytic polypeptide 2|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 2|mRNA(cytosine(6666)) deaminase 2|probable C->U-editing enzyme APOBEC-2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41053202, end_position_on_the_genomic_accession=41064891, orientation='plus', exon_count=3, OMIM=[604797], no_hdr0=''),
    10933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10933, CurrentID=0, Status='live', Symbol='MORF4L1', Aliases=['Eaf3', 'FWP006', 'HsT17725', 'MEAF3', 'MORFRG15', 'MRG15', 'S863-6'], description='mortality factor 4 like 1', other_designations='mortality factor 4-like protein 1|Esa1p-associated factor 3 homolog|MORF-related gene 15 protein|MORF-related gene on chromosome 15|protein MSL3-1|transcription factor-like protein MRG15', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78872890, end_position_on_the_genomic_accession=78898139, orientation='plus', exon_count=13, OMIM=[607303], no_hdr0=''),
    10935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10935, CurrentID=0, Status='live', Symbol='PRDX3', Aliases=['AOP-1', 'AOP1', 'HBC189', 'MER5', 'PRO1748', 'SP-22', 'prx-III'], description='peroxiredoxin 3', other_designations='thioredoxin-dependent peroxide reductase, mitochondrial|antioxidant protein 1|epididymis secretory sperm binding protein|peroxiredoxin III|protein MER5 homolog|thioredoxin-dependent peroxiredoxin 3', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119167720, end_position_on_the_genomic_accession=119178812, orientation='minus', exon_count=7, OMIM=[604769], no_hdr0=''),
    10936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10936, CurrentID=0, Status='live', Symbol='GPR75', Aliases=['GPRchr2', 'WI31133'], description='G protein-coupled receptor 75', other_designations='probable G-protein coupled receptor 75', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53852912, end_position_on_the_genomic_accession=53859967, orientation='minus', exon_count=2, OMIM=[606704], no_hdr0=''),
    10938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10938, CurrentID=0, Status='live', Symbol='EHD1', Aliases=['H-PAST', 'HPAST1', 'PAST', 'PAST1'], description='EH domain containing 1', other_designations='EH domain-containing protein 1|PAST homolog 1|testilin', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64851642, end_position_on_the_genomic_accession=64879693, orientation='minus', exon_count=7, OMIM=[605888], no_hdr0=''),
    10939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10939, CurrentID=0, Status='live', Symbol='AFG3L2', Aliases=['OPA12', 'SCA28', 'SPAX5'], description='AFG3 like matrix AAA peptidase subunit 2', other_designations='AFG3-like protein 2|AFG3 ATPase family gene 3-like 2|AFG3 ATPase family member 3-like 2|AFG3 like AAA ATPase 2|ATPase family gene 3, yeast|paraplegin-like protein', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12328944, end_position_on_the_genomic_accession=12377309, orientation='minus', exon_count=17, OMIM=[604581], no_hdr0=''),
    10940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10940, CurrentID=0, Status='live', Symbol='POP1', Aliases=['ANXD2'], description='POP1 homolog, ribonuclease P/MRP subunit', other_designations='ribonucleases P/MRP protein subunit POP1|hPOP1|processing of precursor 1, ribonuclease P/MRP subunit|processing of precursors 1', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98117293, end_position_on_the_genomic_accession=98159835, orientation='plus', exon_count=18, OMIM=[602486], no_hdr0=''),
    10941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10941, CurrentID=0, Status='live', Symbol='UGT2A1', Aliases=['UDPGT2A1'], description='UDP glucuronosyltransferase family 2 member A1 complex locus', other_designations='UDP-glucuronosyltransferase 2A1|UDP glucuronosyltransferase 2 family, polypeptide A1, complex locus|UDP glycosyltransferase 2 family, polypeptide A1|uridine diphosphate glycosyltransferase 2 family, member A1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69588417, end_position_on_the_genomic_accession=69653247, orientation='minus', exon_count=9, OMIM=[604716], no_hdr0=''),
    10942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10942, CurrentID=0, Status='live', Symbol='PRSS21', Aliases=['ESP-1', 'ESP1', 'TEST1', 'TESTISIN'], description='serine protease 21', other_designations='testisin|eosinophil serine protease 1|protease, serine 21|serine protease from eosinophils', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2817237, end_position_on_the_genomic_accession=2821719, orientation='plus', exon_count=6, OMIM=[608159], no_hdr0=''),
    10943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10943, CurrentID=0, Status='live', Symbol='MSL3', Aliases=['MRSXBA', 'MRXS36', 'MRXSBAL1', 'MSL3'], description='MSL complex subunit 3', other_designations='male-specific lethal 3 homolog|MSL3-like 1|male-specific lethal-3 protein-like 1', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=11758159, end_position_on_the_genomic_accession=11775772, orientation='plus', exon_count=14, OMIM=[300609], no_hdr0=''),
    10944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10944, CurrentID=0, Status='live', Symbol='C11orf58', Aliases=['IMAGE145052', 'SMAP'], description='chromosome 11 open reading frame 58', other_designations='small acidic protein', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=16738647, end_position_on_the_genomic_accession=16758340, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    10945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10945, CurrentID=0, Status='live', Symbol='KDELR1', Aliases=['ERD2', 'ERD2.1', 'HDEL', 'PM23'], description='KDEL endoplasmic reticulum protein retention receptor 1', other_designations='ER lumen protein-retaining receptor 1|KDEL (Lys-Asp-Glu-Leu) endoplasmic reticulum protein retention receptor 1|KDEL receptor 1|putative MAPK-activating protein PM23', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48382575, end_position_on_the_genomic_accession=48391551, orientation='minus', exon_count=5, OMIM=[131235], no_hdr0=''),
    10946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10946, CurrentID=0, Status='live', Symbol='SF3A3', Aliases=['PRP9', 'PRPF9', 'SAP61', 'SF3a60'], description='splicing factor 3a subunit 3', other_designations='splicing factor 3A subunit 3|SAP 61|pre-mRNA splicing factor SF3a (60kD)|spliceosome associated protein 61|splicing factor 3a, subunit 3, 60kD|splicing factor 3a, subunit 3, 60kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37956975, end_position_on_the_genomic_accession=37990022, orientation='minus', exon_count=17, OMIM=[605596], no_hdr0=''),
    10947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10947, CurrentID=0, Status='live', Symbol='AP3M2', Aliases=['AP47B', 'CLA20', 'P47B'], description='adaptor related protein complex 3 subunit mu 2', other_designations='AP-3 complex subunit mu-2|HA1 47 kDa subunit homolog 2|HA1 47kDA subunit homolog 2|adapter-related protein complex 3 mu-2 subunit|adapter-related protein complex 3 subunit mu-2|adaptor related protein complex 3 mu 2 subunit|clathrin assembly protein assembly protein complex 1 medium chain homolog 2|clathrin assembly protein assembly protein complex 3 mu-2 medium chain|clathrin coat assembly protein AP47 homolog 2|clathrin coat-associated protein AP47 homolog 2|clathrin-associated protein AP47 homolog 2|epididymis secretory sperm binding protein|golgi adaptor AP-1 47 kDA protein homolog 2|mu3B-adaptin', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42153035, end_position_on_the_genomic_accession=42171183, orientation='plus', exon_count=10, OMIM=[610469], no_hdr0=''),
    10948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10948, CurrentID=0, Status='live', Symbol='STARD3', Aliases=['CAB1', 'MLN64', 'es64'], description='StAR related lipid transfer domain containing 3', other_designations='stAR-related lipid transfer protein 3|MLN 64|START domain-containing protein 3|StAR-related lipid transfer (START) domain containing 3|metastatic lymph node gene 64 protein|metastatic lymph node protein 64|steroidogenic acute regulatory protein related', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39637144, end_position_on_the_genomic_accession=39664201, orientation='plus', exon_count=16, OMIM=[607048], no_hdr0=''),
    10949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10949, CurrentID=0, Status='live', Symbol='HNRNPA0', Aliases=['HNRPA0'], description='heterogeneous nuclear ribonucleoprotein A0', other_designations='heterogeneous nuclear ribonucleoprotein A0|hnRNA binding protein|hnRNP A0', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=137745651, end_position_on_the_genomic_accession=137754363, orientation='minus', exon_count=1, OMIM=[609409], no_hdr0=''),
    10950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10950, CurrentID=0, Status='live', Symbol='BTG3', Aliases=['ANA', 'ANA/BTG3', 'APRO4', 'TOB5', 'TOB55', 'TOFA'], description='BTG anti-proliferation factor 3', other_designations='protein BTG3|B-cell translocation gene 3|BTG family member 3|abundant in neuroepithelium area protein|protein Tob5', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=17593653, end_position_on_the_genomic_accession=17612940, orientation='minus', exon_count=7, OMIM=[605674], no_hdr0=''),
    10951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10951, CurrentID=0, Status='live', Symbol='CBX1', Aliases=['CBX', 'HP1-BETA', 'HP1Hs-beta', 'HP1Hsbeta', 'M31', 'MOD1', 'p25beta'], description='chromobox 1', other_designations='chromobox protein homolog 1|HP1 beta homolog|chromobox homolog 1 (HP1 beta homolog Drosophila )|heterochromatin protein 1 homolog beta|heterochromatin protein 1-beta|heterochromatin protein p25 beta|modifier 1 protein', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48070059, end_position_on_the_genomic_accession=48101478, orientation='minus', exon_count=6, OMIM=[604511], no_hdr0=''),
    10952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10952, CurrentID=0, Status='live', Symbol='SEC61B', Aliases=[], description='SEC61 translocon subunit beta', other_designations='protein transport protein Sec61 subunit beta|SEC61 translocon beta subunit|Sec61 beta subunit|Sec61 complex, beta subunit|protein translocation complex beta|protein transport protein SEC61 beta subunit', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99222282, end_position_on_the_genomic_accession=99230615, orientation='plus', exon_count=4, OMIM=[609214], no_hdr0=''),
    10953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10953, CurrentID=0, Status='live', Symbol='TOMM34', Aliases=['HTOM34P', 'TOM34', 'URCC3'], description='translocase of outer mitochondrial membrane 34', other_designations='mitochondrial import receptor subunit TOM34|hTom34|outer mitochondrial membrane translocase (34kD)|translocase of outer membrane 34 kDa subunit', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44942130, end_position_on_the_genomic_accession=44960425, orientation='minus', exon_count=9, OMIM=[616049], no_hdr0=''),
    10954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10954, CurrentID=0, Status='live', Symbol='PDIA5', Aliases=['PDIR'], description='protein disulfide isomerase family A member 5', other_designations='protein disulfide-isomerase A5|protein disulfide isomerase-associated 5|protein disulfide isomerase-related protein', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123067025, end_position_on_the_genomic_accession=123162104, orientation='plus', exon_count=17, OMIM=[616942], no_hdr0=''),
    10955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10955, CurrentID=0, Status='live', Symbol='SERINC3', Aliases=['AIGP1', 'DIFF33', 'SBBI99', 'TDE', 'TDE1', 'TMS-1'], description='serine incorporator 3', other_designations='serine incorporator 3|tumor differentially expressed protein 1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44496221, end_position_on_the_genomic_accession=44522070, orientation='minus', exon_count=11, OMIM=[607165], no_hdr0=''),
    10956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10956, CurrentID=0, Status='live', Symbol='OS9', Aliases=['ERLEC2', 'OS-9'], description='OS9 endoplasmic reticulum lectin', other_designations='protein OS-9|amplified in osteosarcoma 9|endoplasmic reticulum lectin 2|erlectin 2|osteosarcoma amplified 9, endoplasmic reticulum associated protein|osteosarcoma amplified 9, endoplasmic reticulum lectin', map_location='12q13.3-q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57694132, end_position_on_the_genomic_accession=57721557, orientation='plus', exon_count=15, OMIM=[609677], no_hdr0=''),
    10957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10957, CurrentID=0, Status='live', Symbol='PNRC1', Aliases=['B4-2', 'PNAS-145', 'PROL2', 'PRR2'], description='proline rich nuclear receptor coactivator 1', other_designations='proline-rich nuclear receptor coactivator 1|proline rich 2 protein|proline-rich polypeptide 2|proline-rich protein 2|proline-rich protein with nuclear targeting signal|protein B4-2', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89080749, end_position_on_the_genomic_accession=89085160, orientation='plus', exon_count=3, OMIM=[606714], no_hdr0=''),
    10959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10959, CurrentID=0, Status='live', Symbol='TMED2', Aliases=['P24A', 'RNP24', 'p24', 'p24b1', 'p24beta1'], description='transmembrane p24 trafficking protein 2', other_designations='transmembrane emp24 domain-containing protein 2|coated vesicle membrane protein|membrane protein p24A|p24 family protein beta-1|transmembrane emp24 domain trafficking protein 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123584552, end_position_on_the_genomic_accession=123598582, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    10960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10960, CurrentID=0, Status='live', Symbol='LMAN2', Aliases=['C5orf8', 'GP36B', 'VIP36'], description='lectin, mannose binding 2', other_designations='vesicular integral-membrane protein VIP36|epididymis secretory sperm binding protein|glycoprotein GP36b|vesicular integral protein of 36 kDa|vesicular integral-membrane protein 36', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177331567, end_position_on_the_genomic_accession=177351668, orientation='minus', exon_count=8, OMIM=[609551], no_hdr0=''),
    10961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10961, CurrentID=0, Status='live', Symbol='ERP29', Aliases=['C12orf8', 'ERp28', 'ERp31', 'HEL-S-107', 'PDI-DB', 'PDIA9'], description='endoplasmic reticulum protein 29', other_designations='endoplasmic reticulum resident protein 29|endoplasmic reticulum lumenal protein ERp28|endoplasmic reticulum resident protein 28|endoplasmic reticulum resident protein 31|epididymis secretory protein Li 107|protein disulfide isomerase family A, member 9', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112013340, end_position_on_the_genomic_accession=112023449, orientation='plus', exon_count=3, OMIM=[602287], no_hdr0=''),
    10962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10962, CurrentID=0, Status='live', Symbol='MLLT11', Aliases=['AF1Q'], description='MLLT11 transcription factor 7 cofactor', other_designations='protein AF1q|ALL1 fused gene from chromosome 1q|myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 11|myeloid/lymphoid or mixed-lineage leukemia; translocated to, 11', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151060397, end_position_on_the_genomic_accession=151069544, orientation='plus', exon_count=2, OMIM=[604684], no_hdr0=''),
    10963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10963, CurrentID=0, Status='live', Symbol='STIP1', Aliases=['HEL-S-94n', 'HOP', 'IEF-SSP-3521', 'P60', 'STI1', 'STI1L'], description='stress induced phosphoprotein 1', other_designations='stress-induced-phosphoprotein 1|Hsp70/Hsp90-organizing protein|NY-REN-11 antigen|epididymis secretory sperm binding protein Li 94n|hsc70/Hsp90-organizing protein|renal carcinoma antigen NY-REN-11|transformation-sensitive protein IEF SSP 3521', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64185272, end_position_on_the_genomic_accession=64204543, orientation='plus', exon_count=15, OMIM=[605063], no_hdr0=''),
    10964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10964, CurrentID=0, Status='live', Symbol='IFI44L', Aliases=['C1orf29', 'GS3686', 'TLDC5B'], description='interferon induced protein 44 like', other_designations='interferon-induced protein 44-like', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=78620412, end_position_on_the_genomic_accession=78646145, orientation='plus', exon_count=10, OMIM=[613975], no_hdr0=''),
    10965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10965, CurrentID=0, Status='live', Symbol='ACOT2', Aliases=['CTE-IA', 'CTE1A', 'MTE1', 'PTE2', 'PTE2A', 'ZAP128'], description='acyl-CoA thioesterase 2', other_designations='acyl-coenzyme A thioesterase 2, mitochondrial|acyl-coenzyme A thioester hydrolase 2a|long-chain acyl-CoA thioesterase 2|mitochondrial acyl-CoA thioesterase 1|peroxisomal long-chain acyl-coA thioesterase 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73567620, end_position_on_the_genomic_accession=73575658, orientation='plus', exon_count=5, OMIM=[609972], no_hdr0=''),
    10966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10966, CurrentID=0, Status='live', Symbol='RAB40B', Aliases=['RAR', 'SEC4L'], description='RAB40B, member RAS oncogene family', other_designations='ras-related protein Rab-40B|GTP-binding protein homologous to Saccharomyces cerevisiae SEC4|SOCS box-containing protein RAR|protein Rar', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82654973, end_position_on_the_genomic_accession=82698702, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    10969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10969, CurrentID=0, Status='live', Symbol='EBNA1BP2', Aliases=['EBP2', 'NOBP', 'P40'], description='EBNA1 binding protein 2', other_designations='probable rRNA-processing protein EBP2|nuclear FGF3 binding protein|nucleolar protein p40|nucleolar protein p40; homolog of yeast EBNA1-binding protein', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43164174, end_position_on_the_genomic_accession=43172570, orientation='minus', exon_count=9, OMIM=[614443], no_hdr0=''),
    10970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10970, CurrentID=0, Status='live', Symbol='CKAP4', Aliases=['CLIMP-63', 'CLIMP63', 'ERGIC-63', 'p63'], description='cytoskeleton associated protein 4', other_designations='cytoskeleton-associated protein 4|63 kDa membrane protein|63-kDa cytoskeleton-linking membrane protein|transmembrane protein (63kD), endoplasmic reticulum/Golgi intermediate compartment|type-II transmembrane protein p63', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106237881, end_position_on_the_genomic_accession=106248020, orientation='minus', exon_count=2, OMIM=[618595], no_hdr0=''),
    10971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10971, CurrentID=0, Status='live', Symbol='YWHAQ', Aliases=['14-3-3', '1C5', 'HS1'], description='tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein theta', other_designations='14-3-3 protein theta|14-3-3 protein T-cell|14-3-3 protein tau|14-3-3 theta|protein, theta|tyrosine 3-monooxygenase/tryptophan 5-monooxygenase activation protein, theta polypeptide', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9583967, end_position_on_the_genomic_accession=9630997, orientation='minus', exon_count=6, OMIM=[609009], no_hdr0=''),
    10972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10972, CurrentID=0, Status='live', Symbol='TMED10', Aliases=['P24(DELTA)', 'S31I125', 'S31III125', 'TMP21', 'Tmp-21-I', 'p23', 'p24d1'], description='transmembrane p24 trafficking protein 10', other_designations='transmembrane emp24 domain-containing protein 10|21 kDa transmembrane trafficking protein|p24 family protein delta-1|p24delta|p24delta1|testicular tissue protein Li 206|transmembrane emp24-like trafficking protein 10|transmembrane protein Tmp21', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75131469, end_position_on_the_genomic_accession=75176612, orientation='minus', exon_count=5, OMIM=[605406], no_hdr0=''),
    10973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10973, CurrentID=0, Status='live', Symbol='ASCC3', Aliases=['ASC1p200', 'HELIC1', 'RNAH'], description='activating signal cointegrator 1 complex subunit 3', other_designations='activating signal cointegrator 1 complex subunit 3|ASC-1 complex subunit P200|RNA helicase family|helicase, ATP binding 1|trip4 complex subunit p200', map_location='6q16.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=100508194, end_position_on_the_genomic_accession=100884455, orientation='minus', exon_count=44, OMIM=[614217], no_hdr0=''),
    10974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10974, CurrentID=0, Status='live', Symbol='ADIRF', Aliases=['AFRO', 'APM2', 'C10orf116', 'apM-2'], description='adipogenesis regulatory factor', other_designations='adipogenesis regulatory factor|adipogenesis factor rich in obesity|adipose most abundant gene transcript 2 protein|adipose specific 2|adipose-specific protein 2', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86968482, end_position_on_the_genomic_accession=86970915, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    10975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10975, CurrentID=0, Status='live', Symbol='UQCR11', Aliases=['0710008D09Rik', 'QCR10', 'UQCR'], description='ubiquinol-cytochrome c reductase, complex III subunit XI', other_designations='cytochrome b-c1 complex subunit 10|complex III subunit 10|complex III subunit XI|ubiquinol-cytochrome c reductase complex 6.4 kDa protein|ubiquinol-cytochrome c reductase, 6.4kDa subunit', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1597169, end_position_on_the_genomic_accession=1605462, orientation='minus', exon_count=3, OMIM=[609711], no_hdr0=''),
    10978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10978, CurrentID=0, Status='live', Symbol='CLP1', Aliases=['HEAB', 'hClp1'], description='cleavage factor polyribonucleotide kinase subunit 1', other_designations="polyribonucleotide 5'-hydroxyl-kinase Clp1|ATP/GTP-binding protein|cleavage and polyadenylation factor I subunit 1|homolog of yeast CFIA subunit Clp1p|polyadenylation factor Clp1|polynucleotide kinase Clp1|pre-mRNA cleavage complex II protein Clp1", map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57657762, end_position_on_the_genomic_accession=57661865, orientation='plus', exon_count=3, OMIM=[608757], no_hdr0=''),
    10979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10979, CurrentID=0, Status='live', Symbol='FERMT2', Aliases=['KIND2', 'MIG2', 'PLEKHC1', 'UNC112', 'UNC112B', 'mig-2'], description='FERM domain containing kindlin 2', other_designations='fermitin family homolog 2|PH domain-containing family C member 1|fermitin family member 2|kindlin 2|mitogen inducible gene 2 protein|mitogen inducible gene-2|pleckstrin homology domain containing, family C (with FERM domain) member 1|pleckstrin homology domain containing, family C member 1', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52857271, end_position_on_the_genomic_accession=52951050, orientation='minus', exon_count=18, OMIM=[607746], no_hdr0=''),
    10980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10980, CurrentID=0, Status='live', Symbol='COPS6', Aliases=['CSN6', 'MOV34-34KD'], description='COP9 signalosome subunit 6', other_designations='COP9 signalosome complex subunit 6|COP9 constitutive photomorphogenic homolog subunit 6|H_NH0506M12.12|JAB1-containing signalosome subunit 6|MOV34 homolog, 34 kD|SGN6|hVIP|vpr-interacting protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100088969, end_position_on_the_genomic_accession=100092187, orientation='plus', exon_count=10, OMIM=[614729], no_hdr0=''),
    10981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10981, CurrentID=0, Status='live', Symbol='RAB32', Aliases=[], description='RAB32, member RAS oncogene family', other_designations='ras-related protein Rab-32', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=146543833, end_position_on_the_genomic_accession=146554953, orientation='plus', exon_count=3, OMIM=[612906], no_hdr0=''),
    10982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10982, CurrentID=0, Status='live', Symbol='MAPRE2', Aliases=['CSCSC2', 'EB1', 'EB2', 'RP1'], description='microtubule associated protein RP/EB family member 2', other_designations='microtubule-associated protein RP/EB family member 2|APC-binding protein EB1|APC-binding protein EB2|T-cell activation protein, EB1 family|end-binding protein 2', map_location='18q12.1-q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=34977027, end_position_on_the_genomic_accession=35143470, orientation='plus', exon_count=10, OMIM=[605789], no_hdr0=''),
    10983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10983, CurrentID=0, Status='live', Symbol='CCNI', Aliases=['CCNI1', 'CYC1', 'CYI'], description='cyclin I', other_designations='cyclin-I|cyclin ITI', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=77047155, end_position_on_the_genomic_accession=77075989, orientation='minus', exon_count=8, OMIM=[618783], no_hdr0=''),
    10985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10985, CurrentID=0, Status='live', Symbol='GCN1', Aliases=['GCN1LL1', 'PRIC295', 'GCN1'], description='GCN1 activator of EIF2AK4', other_designations='eIF-2-alpha kinase activator GCN1|GCN1 (general control of amino-acid synthesis 1, yeast)-like 1|GCN1 eIF-2-alpha kinase activator homolog|GCN1 general control of amino-acid synthesis 1-like 1|GCN1, eIF2 alpha kinase activator homolog|GCN1-like protein 1|general control of amino-acid synthesis 1-like protein 1|hsGCN1|peroxisome proliferator activated receptor interacting complex protein|translational activator GCN1', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120127202, end_position_on_the_genomic_accession=120194715, orientation='minus', exon_count=58, OMIM=[605614], no_hdr0=''),
    10987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10987, CurrentID=0, Status='live', Symbol='COPS5', Aliases=['CSN5', 'JAB1', 'MOV-34', 'SGN5'], description='COP9 signalosome subunit 5', other_designations='COP9 signalosome complex subunit 5|38 kDa Mov34 homolog|COP9 constitutive photomorphogenic homolog subunit 5|jun activation domain-binding protein 1|signalosome subunit 5|testis secretory sperm-binding protein Li 231m', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=67043079, end_position_on_the_genomic_accession=67062133, orientation='minus', exon_count=8, OMIM=[604850], no_hdr0=''),
    10988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10988, CurrentID=0, Status='live', Symbol='METAP2', Aliases=['MAP2', 'MNPEP', 'p67eIF2'], description='methionyl aminopeptidase 2', other_designations='methionine aminopeptidase 2|eIF-2-associated p67 homolog|initiation factor 2-associated 67 kDa glycoprotein|peptidase M 2|testicular tissue protein Li 17', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95474152, end_position_on_the_genomic_accession=95515839, orientation='plus', exon_count=11, OMIM=[601870], no_hdr0=''),
    10989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10989, CurrentID=0, Status='live', Symbol='IMMT', Aliases=['HMP', 'MICOS60', 'MINOS2', 'Mic60', 'P87', 'P87/89', 'P89', 'PIG4', 'PIG52'], description='inner membrane mitochondrial protein', other_designations='MICOS complex subunit MIC60|cell proliferation-inducing gene 4/52 protein|cell proliferation-inducing protein 52|heart muscle protein|mitochondrial contact site and cristae organizing system subunit 60|mitochondrial inner membrane organizing system 2|mitochondrial inner membrane protein|mitofilin|motor protein|proliferation-inducing gene 4', map_location='2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86143932, end_position_on_the_genomic_accession=86195463, orientation='minus', exon_count=15, OMIM=[600378], no_hdr0=''),
    10990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10990, CurrentID=0, Status='live', Symbol='LILRB5', Aliases=['CD85C', 'LIR-8', 'LIR8'], description='leukocyte immunoglobulin like receptor B5', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 5|CD85 antigen-like family member C|leucocyte Ig-like receptor B5|leukocyte immunoglobulin-like receptor 8|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 5', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54249421, end_position_on_the_genomic_accession=54257292, orientation='minus', exon_count=13, OMIM=[604814], no_hdr0=''),
    10991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10991, CurrentID=0, Status='live', Symbol='SLC38A3', Aliases=['G17', 'NAT1', 'SN1', 'SNAT3'], description='solute carrier family 38 member 3', other_designations='sodium-coupled neutral amino acid transporter 3|N-system amino acid transporter 1|Na(+)-coupled neutral amino acid transporter 3|system N amino acid transporter 1|system N1 Na+ and H+-coupled glutamine transporter', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50205268, end_position_on_the_genomic_accession=50221486, orientation='plus', exon_count=17, OMIM=[604437], no_hdr0=''),
    10992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10992, CurrentID=0, Status='live', Symbol='SF3B2', Aliases=['Cus1', 'SAP145', 'SF3B145', 'SF3b1', 'SF3b150'], description='splicing factor 3b subunit 2', other_designations='splicing factor 3B subunit 2|SAP 145|pre-mRNA splicing factor SF3b 145 kDa subunit|spliceosome associated protein 145|splicing factor 3b, subunit 2, 145kD|splicing factor 3b, subunit 2, 145kDa', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66052361, end_position_on_the_genomic_accession=66069308, orientation='plus', exon_count=22, OMIM=[605591], no_hdr0=''),
    10993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10993, CurrentID=0, Status='live', Symbol='SDS', Aliases=['SDH'], description='serine dehydratase', other_designations='L-serine dehydratase/L-threonine deaminase|L-serine ammonia-lyase|L-serine deaminase|L-serine dehydratase|L-threonine dehydratase|TDH', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113392445, end_position_on_the_genomic_accession=113403887, orientation='minus', exon_count=8, OMIM=[182128], no_hdr0=''),
    10994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10994, CurrentID=0, Status='live', Symbol='ILVBL', Aliases=['209L8', 'AHAS', 'HACL1L', 'ILV2H'], description='ilvB acetolactate synthase like', other_designations='2-hydroxyacyl-CoA lyase 2|2-hydroxyacyl-CoA lyase 1 like|acetolactate synthase homolog|acetolactate synthase-like protein|ilvB (bacterial acetolactate synthase)-like|ilvB-like protein', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15114982, end_position_on_the_genomic_accession=15125786, orientation='minus', exon_count=16, OMIM=[605770], no_hdr0=''),
    10998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10998, CurrentID=0, Status='live', Symbol='SLC27A5', Aliases=['ACSB', 'ACSVL6', 'BACS', 'BAL', 'FACVL3', 'FATP-5', 'FATP5', 'VLACSR', 'VLCS-H2', 'VLCSH2'], description='solute carrier family 27 member 5', other_designations='bile acyl-CoA synthetase|BA-CoA ligase|VLACS-related|bile acid-CoA ligase|cholate--CoA ligase|fatty acid transport protein 5|fatty-acid-Coenzyme A ligase, very long-chain 3|solute carrier family 27 (fatty acid transporter), member 5|very long-chain acyl-CoA synthetase homolog 2|very long-chain acyl-CoA synthetase-related protein', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58498333, end_position_on_the_genomic_accession=58512028, orientation='minus', exon_count=11, OMIM=[603314], no_hdr0=''),
    10999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=10999, CurrentID=0, Status='live', Symbol='SLC27A4', Aliases=['ACSVL4', 'FATP4', 'IPS'], description='solute carrier family 27 member 4', other_designations='long-chain fatty acid transport protein 4|arachidonate--CoA ligase|long-chain-fatty-acid--CoA ligase|solute carrier family 27 (fatty acid transporter), member 4|very long-chain acyl-CoA synthetase 4', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128340516, end_position_on_the_genomic_accession=128361470, orientation='plus', exon_count=14, OMIM=[604194], no_hdr0=''),
    11000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11000, CurrentID=0, Status='live', Symbol='SLC27A3', Aliases=['ACSVL3', 'FATP3', 'VLCS-3'], description='solute carrier family 27 member 3', other_designations='solute carrier family 27 member 3|arachidonate--CoA ligase|long-chain fatty acid transport protein 3|solute carrier family 27 (fatty acid transporter), member 3|very long-chain acyl-CoA synthetase homolog 3', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153775407, end_position_on_the_genomic_accession=153780157, orientation='plus', exon_count=10, OMIM=[604193], no_hdr0=''),
    11001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11001, CurrentID=0, Status='live', Symbol='SLC27A2', Aliases=['ACSVL1', 'FACVL1', 'FATP2', 'HsT17226', 'VLACS', 'VLCS', 'hFACVL1'], description='solute carrier family 27 member 2', other_designations='very long-chain acyl-CoA synthetase|FATP-2|THCA-CoA ligase|arachidonate--CoA ligase|fatty acid transport protein 2|fatty-acid-coenzyme A ligase, very long-chain 1|long-chain-fatty-acid--CoA ligase|phytanate--CoA ligase|solute carrier family 27 (fatty acid transporter), member 2|very long-chain fatty-acid-coenzyme A ligase 1|very long-chain-fatty-acid-CoA ligase', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50182196, end_position_on_the_genomic_accession=50236385, orientation='plus', exon_count=10, OMIM=[603247], no_hdr0=''),
    11004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11004, CurrentID=0, Status='live', Symbol='KIF2C', Aliases=['CT139', 'KNSL6', 'MCAK'], description='kinesin family member 2C', other_designations='kinesin-like protein KIF2C|kinesin-like protein 6|mitotic centromere-associated kinesin|testis tissue sperm-binding protein Li 68n', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44739704, end_position_on_the_genomic_accession=44767767, orientation='plus', exon_count=22, OMIM=[604538], no_hdr0=''),
    11005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11005, CurrentID=0, Status='live', Symbol='SPINK5', Aliases=['LEKTI', 'LETKI', 'NETS', 'NS', 'VAKTI'], description='serine peptidase inhibitor Kazal type 5', other_designations='serine protease inhibitor Kazal-type 5|lympho-epithelial Kazal-type-related inhibitor|lymphoepithelial Kazal-type-related inhibitor', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148063980, end_position_on_the_genomic_accession=148137382, orientation='plus', exon_count=34, OMIM=[605010], no_hdr0=''),
    11006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11006, CurrentID=0, Status='live', Symbol='LILRB4', Aliases=['CD85K', 'ILT-3', 'ILT3', 'LIR-5', 'LIR5'], description='leukocyte immunoglobulin like receptor B4', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 4|CD85 antigen-like family member K|immunoglobulin-like transcript 3|leucocyte Ig-like receptor B4|leukocyte immunoglobulin-like receptor 5|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 4|monocyte inhibitory receptor HM18', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54662524, end_position_on_the_genomic_accession=54668718, orientation='plus', exon_count=13, OMIM=[604821], no_hdr0=''),
    11007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11007, CurrentID=0, Status='live', Symbol='CCDC85B', Aliases=['DIPA'], description='coiled-coil domain containing 85B', other_designations='coiled-coil domain-containing protein 85B|delta-interacting protein A|hepatitis delta antigen-interacting protein A', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65890673, end_position_on_the_genomic_accession=65891635, orientation='plus', exon_count=1, OMIM=[605360], no_hdr0=''),
    11009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11009, CurrentID=0, Status='live', Symbol='IL24', Aliases=['C49A', 'FISP', 'IL10B', 'MDA7', 'MOB5', 'ST16'], description='interleukin 24', other_designations='interleukin-24|IL-4-induced secreted protein|melanocyte-associated Mda-7|melanoma differentiation-associated gene 7 protein|suppression of tumorigenicity 16 (melanoma differentiation)', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206897404, end_position_on_the_genomic_accession=206904139, orientation='plus', exon_count=7, OMIM=[604136], no_hdr0=''),
    11010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11010, CurrentID=0, Status='live', Symbol='GLIPR1', Aliases=['CRISP7', 'GLIPR', 'RTVP1'], description='GLI pathogenesis related 1', other_designations='glioma pathogenesis-related protein 1|GLI pathogenesis-related 1 (glioma)|gliPR 1|protein RTVP-1|related to testis-specific, vespid, and pathogenesis proteins 1|testes-specific vespid and pathogenesis protein 1', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75480754, end_position_on_the_genomic_accession=75503863, orientation='plus', exon_count=7, OMIM=[602692], no_hdr0=''),
    11011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11011, CurrentID=0, Status='live', Symbol='TLK2', Aliases=['HsHPK', 'MRD57', 'PKU-ALPHA'], description='tousled like kinase 2', other_designations='serine/threonine-protein kinase tousled-like 2', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62470908, end_position_on_the_genomic_accession=62615481, orientation='plus', exon_count=31, OMIM=[608439], no_hdr0=''),
    11012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11012, CurrentID=0, Status='live', Symbol='KLK11', Aliases=['PRSS20', 'TLSP'], description='kallikrein related peptidase 11', other_designations='kallikrein-11|hK11|hippostasin|serine protease 20|trypsin-like protease', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51022231, end_position_on_the_genomic_accession=51027991, orientation='minus', exon_count=10, OMIM=[604434], no_hdr0=''),
    11013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11013, CurrentID=0, Status='live', Symbol='TMSB15A', Aliases=['TMSB15', 'TMSB15B', 'TMSL8', 'TMSNB', 'Tb15', 'TbNB'], description='thymosin beta 15A', other_designations='thymosin beta-15A|NB thymosin beta|Thymosin beta-15B|thymosin, beta, identified in neuroblastoma cells|thymosin-like 8|thymosin-like protein 8', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102513682, end_position_on_the_genomic_accession=102516739, orientation='minus', exon_count=3, OMIM=[300939], no_hdr0=''),
    11014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11014, CurrentID=0, Status='live', Symbol='KDELR2', Aliases=['ELP-1', 'ELP1', 'ERD2.2', 'OI21'], description='KDEL endoplasmic reticulum protein retention receptor 2', other_designations='ER lumen protein-retaining receptor 2|(Lys-Asp-Glu-Leu) endoplasmic reticulum protein retention receptor 2|ERD-2-like protein|ERD2-like protein 1|KDEL (Lys-Asp-Glu-Leu) endoplasmic reticulum protein retention receptor 2|KDEL receptor 2', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6461089, end_position_on_the_genomic_accession=6484152, orientation='minus', exon_count=5, OMIM=[609024], no_hdr0=''),
    11015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11015, CurrentID=0, Status='live', Symbol='KDELR3', Aliases=['ERD2L3'], description='KDEL endoplasmic reticulum protein retention receptor 3', other_designations='ER lumen protein-retaining receptor 3|KDEL (Lys-Asp-Glu-Leu) endoplasmic reticulum protein retention receptor 3|KDEL receptor 3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38468096, end_position_on_the_genomic_accession=38483447, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    11016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11016, CurrentID=0, Status='live', Symbol='ATF7', Aliases=['ATFA'], description='activating transcription factor 7', other_designations='cyclic AMP-dependent transcription factor ATF-7|transcription factor ATF-A', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53507856, end_position_on_the_genomic_accession=53626382, orientation='minus', exon_count=14, OMIM=[606371], no_hdr0=''),
    11017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11017, CurrentID=0, Status='live', Symbol='SNRNP27', Aliases=['27K', 'RY1'], description='small nuclear ribonucleoprotein U4/U6.U5 subunit 27', other_designations='U4/U6.U5 small nuclear ribonucleoprotein 27 kDa protein|U4/U6.U5 tri-snRNP-associated 27 kDa protein|U4/U6.U5 tri-snRNP-associated protein 3|U4/U6.U5-27K|putative nucleic acid binding protein RY-1|small nuclear ribonucleoprotein 27kDa (U4/U6.U5)|small nuclear ribonucleoprotein, U4/U6.U5 27kDa subunit', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69893956, end_position_on_the_genomic_accession=69905236, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    11018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11018, CurrentID=0, Status='live', Symbol='TMED1', Aliases=['IL1RL1LG', 'Il1rl1l', 'Tp24', 'p24g1'], description='transmembrane p24 trafficking protein 1', other_designations='transmembrane emp24 domain-containing protein 1|IL1RL1-binding protein|interleukin 1 receptor-like 1 ligand|p24 family protein gamma-1|putative T1/ST2 receptor-binding protein|transmembrane emp24 protein transport domain containing 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10832067, end_position_on_the_genomic_accession=10836212, orientation='minus', exon_count=6, OMIM=[605395], no_hdr0=''),
    11019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11019, CurrentID=0, Status='live', Symbol='LIAS', Aliases=['HGCLAS', 'HUSSY-01', 'LAS', 'LIP1', 'LS', 'PDHLD'], description='lipoic acid synthetase', other_designations='lipoyl synthase, mitochondrial|lip-syn|lipoate synthase', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39459056, end_position_on_the_genomic_accession=39479506, orientation='plus', exon_count=11, OMIM=[607031], no_hdr0=''),
    11020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11020, CurrentID=0, Status='live', Symbol='IFT27', Aliases=['BBS19', 'FAP156', 'RABL4', 'RAYL'], description='intraflagellar transport 27', other_designations='intraflagellar transport protein 27 homolog|RAB, member of RAS oncogene family-like 4|rab-like protein 4', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36758208, end_position_on_the_genomic_accession=36776119, orientation='minus', exon_count=9, OMIM=[615870], no_hdr0=''),
    11021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11021, CurrentID=0, Status='live', Symbol='RAB35', Aliases=['H-ray', 'RAB1C', 'RAY'], description='RAB35, member RAS oncogene family', other_designations='ras-related protein Rab-35|GTP-binding protein RAY|ras-related protein rab-1c (GTP-binding protein ray)', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120095094, end_position_on_the_genomic_accession=120117469, orientation='minus', exon_count=6, OMIM=[604199], no_hdr0=''),
    11022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11022, CurrentID=0, Status='live', Symbol='TDRKH', Aliases=['TDRD2'], description='tudor and KH domain containing', other_designations='tudor and KH domain-containing protein|putative RNA binding protein|tudor domain containing 2|tudor domain-containing protein 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151769433, end_position_on_the_genomic_accession=151790534, orientation='minus', exon_count=16, OMIM=[609501], no_hdr0=''),
    11023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11023, CurrentID=0, Status='live', Symbol='VAX1', Aliases=['MCOPS11'], description='ventral anterior homeobox 1', other_designations='ventral anterior homeobox 1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=117128520, end_position_on_the_genomic_accession=117138270, orientation='minus', exon_count=5, OMIM=[604294], no_hdr0=''),
    11024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11024, CurrentID=0, Status='live', Symbol='LILRA1', Aliases=['CD85I', 'LIR-6', 'LIR6'], description='leukocyte immunoglobulin like receptor A1', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 1|CD85 antigen-like family member I|leucocyte Ig-like receptor A1|leukocyte immunoglobulin-like receptor 6|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54593632, end_position_on_the_genomic_accession=54602381, orientation='plus', exon_count=9, OMIM=[604810], no_hdr0=''),
    11025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11025, CurrentID=0, Status='live', Symbol='LILRB3', Aliases=['CD85A', 'HL9', 'ILT-5', 'ILT5', 'LILRA6', 'LIR-3', 'LIR3', 'PIR-B', 'PIRB'], description='leukocyte immunoglobulin like receptor B3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3|CD85 antigen-like family member A|immunoglobulin-like transcript 5|leucocyte Ig-like receptor B3|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 6|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 3|monocyte inhibitory receptor HL9', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54216278, end_position_on_the_genomic_accession=54223087, orientation='minus', exon_count=15, OMIM=[604820], no_hdr0=''),
    11026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11026, CurrentID=0, Status='live', Symbol='LILRA3', Aliases=['CD85E', 'HM31', 'HM43', 'ILT-6', 'ILT6', 'LIR-4', 'LIR4'], description='leukocyte immunoglobulin like receptor A3', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 3|CD85 antigen-like family member E|immunoglobulin-like transcript 6|leucocyte Ig-like receptor A3|leukocyte immunoglobulin-like receptor 4|leukocyte immunoglobulin-like receptor, subfamily A (without TM domain), member 3|monocyte inhibitory receptor HM43/HM31', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604818], no_hdr0=''),
    11027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11027, CurrentID=0, Status='live', Symbol='LILRA2', Aliases=['CD85H', 'ILT1', 'LIR-7', 'LIR7'], description='leukocyte immunoglobulin like receptor A2', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 2|CD85 antigen-like family member H|immunoglobulin-like transcript 1|leucocyte Ig-like receptor A2|leukocyte immunoglobulin-like receptor 7|leukocyte immunoglobulin-like receptor subfamily A member 2 soluble|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 2', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54572988, end_position_on_the_genomic_accession=54590287, orientation='plus', exon_count=10, OMIM=[604812], no_hdr0=''),
    11030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11030, CurrentID=0, Status='live', Symbol='RBPMS', Aliases=['HERMES'], description='RNA binding protein, mRNA processing factor', other_designations='RNA-binding protein with multiple splicing|RNA binding protein with multiple splicing|heart and RRM expressed sequence', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30384541, end_position_on_the_genomic_accession=30572261, orientation='plus', exon_count=20, OMIM=[601558], no_hdr0=''),
    11031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11031, CurrentID=0, Status='live', Symbol='RAB31', Aliases=['Rab22B'], description='RAB31, member RAS oncogene family', other_designations='ras-related protein Rab-31|ras-related protein Rab-22B', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9708187, end_position_on_the_genomic_accession=9862551, orientation='plus', exon_count=8, OMIM=[605694], no_hdr0=''),
    11033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11033, CurrentID=0, Status='live', Symbol='ADAP1', Aliases=['CENTA1', 'GCS1L', 'p42IP4'], description='ArfGAP with dual PH domains 1', other_designations='arf-GAP with dual PH domain-containing protein 1|centaurin-alpha|centaurin-alpha-1|cnt-a1|putative MAPK-activating protein PM25', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=897900, end_position_on_the_genomic_accession=955407, orientation='minus', exon_count=15, OMIM=[608114], no_hdr0=''),
    11034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11034, CurrentID=0, Status='live', Symbol='DSTN', Aliases=['ACTDP', 'ADF', 'HEL32', 'bA462D18.2'], description='destrin, actin depolymerizing factor', other_designations='destrin|actin-depolymerizing factor|bA462D18.2 (destrin (actin depolymerizing factor ADF) (ACTDP))|epididymis luminal protein 32|epididymis secretory sperm binding protein', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17569173, end_position_on_the_genomic_accession=17609919, orientation='plus', exon_count=6, OMIM=[609114], no_hdr0=''),
    11035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11035, CurrentID=0, Status='live', Symbol='RIPK3', Aliases=['RIP3'], description='receptor interacting serine/threonine kinase 3', other_designations='receptor-interacting serine/threonine-protein kinase 3|RIP-3|RIP-like protein kinase 3|receptor interacting protein 3', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24336025, end_position_on_the_genomic_accession=24339991, orientation='minus', exon_count=10, OMIM=[605817], no_hdr0=''),
    11036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11036, CurrentID=0, Status='live', Symbol='GTF2A1L', Aliases=['ALF'], description='general transcription factor IIA subunit 1 like', other_designations='TFIIA-alpha and beta-like factor|GTF2A1-like factor|TFIIA-alpha/beta-like factor|general transcription factor II A, 1-like factor|general transcription factor IIA 1-like|testis secretory sperm-binding protein Li 230m', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48617856, end_position_on_the_genomic_accession=48679604, orientation='plus', exon_count=9, OMIM=[605358], no_hdr0=''),
    11037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11037, CurrentID=0, Status='live', Symbol='STON1', Aliases=['SALF', 'SBLF', 'STN1', 'STNB1'], description='stonin 1', other_designations='stonin-1|stoned B homolog 1|stoned B-like factor|stoned-b1', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48530154, end_position_on_the_genomic_accession=48598513, orientation='plus', exon_count=5, OMIM=[605357], no_hdr0=''),
    11040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11040, CurrentID=0, Status='live', Symbol='PIM2', Aliases=[], description='Pim-2 proto-oncogene, serine/threonine kinase', other_designations='serine/threonine-protein kinase pim-2|pim-2 oncogene|pim-2h|proto-oncogene Pim-2 (serine threonine kinase)', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48913182, end_position_on_the_genomic_accession=48919024, orientation='minus', exon_count=6, OMIM=[300295], no_hdr0=''),
    11041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11041, CurrentID=0, Status='live', Symbol='B4GAT1', Aliases=['B3GN-T1', 'B3GNT1', 'B3GNT6', 'BETA3GNTI', 'MDDGA13', 'iGAT', 'iGNT'], description='beta-1,4-glucuronyltransferase 1', other_designations='beta-1,4-glucuronyltransferase 1|N-acetyllactosaminide beta-1,3-N-acetylglucosaminyltransferase|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 1|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 6|beta-1,3-N-acetylglucosaminyltransferase bGnT-6|i-beta-1,3-N-acetylglucosaminyltransferase|poly-N-acetyllactosamine extension enzyme', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66345374, end_position_on_the_genomic_accession=66347629, orientation='minus', exon_count=2, OMIM=[605517], no_hdr0=''),
    11043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11043, CurrentID=0, Status='live', Symbol='MID2', Aliases=['FXY2', 'MRX101', 'RNF60', 'TRIM1'], description='midline 2', other_designations='probable E3 ubiquitin-protein ligase MID2|RING finger protein 60|RING-type E3 ubiquitin transferase MID2|midin 2|midline defect 2|tripartite motif protein 1|tripartite motif-containing protein 1', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107825735, end_position_on_the_genomic_accession=107931637, orientation='plus', exon_count=11, OMIM=[300204], no_hdr0=''),
    11044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11044, CurrentID=0, Status='live', Symbol='TENT4A', Aliases=['LAK-1', 'LAK1', 'PAPD7', 'POLK', 'POLS', 'TRF4', 'TRF4-1', 'TRF41', 'TUTASE5'], description='terminal nucleotidyltransferase 4A', other_designations='terminal nucleotidyltransferase 4A|DNA polymerase kappa|DNA polymerase sigma|PAP-associated domain-containing protein 7|TRAMP-like complex polyadenylate polymerase|non-canonical poly(A) RNA polymerase PAPD7|poly(A) RNA polymerase D7, non-canonical|polymerase (DNA directed) sigma|terminal guanylyltransferase|terminal uridylyltransferase 5|topoisomerase-related function protein 4-1', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=6713432, end_position_on_the_genomic_accession=6757045, orientation='plus', exon_count=15, OMIM=[605198], no_hdr0=''),
    11045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11045, CurrentID=0, Status='live', Symbol='UPK1A', Aliases=['TSPAN21', 'UP1A', 'UPIA', 'UPKA'], description='uroplakin 1A', other_designations='uroplakin-1a|tetraspanin-21|tspan-21|uroplakin Ia', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35666517, end_position_on_the_genomic_accession=35678481, orientation='plus', exon_count=9, OMIM=[611557], no_hdr0=''),
    11046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11046, CurrentID=0, Status='live', Symbol='SLC35D2', Aliases=['HFRC1', 'SQV7L', 'UGTrel8', 'hfrc'], description='solute carrier family 35 member D2', other_designations='UDP-N-acetylglucosamine/UDP-glucose/GDP-mannose transporter|SQV7-like protein|UDP-N-acetylglucosamine transporter|UDP-galactose transporter-related protein 8|fringe connection|homolog of Fringe connection protein 1|solute carrier family 35 (UDP-GlcNAc/UDP-glucose transporter), member D2', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96313437, end_position_on_the_genomic_accession=96383711, orientation='minus', exon_count=13, OMIM=[609182], no_hdr0=''),
    11047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11047, CurrentID=0, Status='live', Symbol='ADRM1', Aliases=['ARM-1', 'ARM1', 'GP110', 'PSMD16'], description='ADRM1 26S proteasome ubiquitin receptor', other_designations='proteasomal ubiquitin receptor ADRM1|110 kDa cell membrane glycoprotein|M(r) 110,000 surface antigen|adhesion regulating molecule 1|proteasome regulatory particle non-ATPase 13|proteasome ubiquitin receptor|rpn13 homolog', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62302061, end_position_on_the_genomic_accession=62308862, orientation='plus', exon_count=10, OMIM=[610650], no_hdr0=''),
    11051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11051, CurrentID=0, Status='live', Symbol='NUDT21', Aliases=['CFIM25', 'CPSF5'], description='nudix hydrolase 21', other_designations='cleavage and polyadenylation specificity factor subunit 5|CPSF 25 kDa subunit|cleavage and polyadenylation specific factor 5, 25 kD subunit|cleavage and polyadenylation specific factor 5, 25 kDa|cleavage and polyadenylation specificity factor 25 kDa subunit|cleavage factor Im complex 25 kDa subunit|nucleoside diphosphate-linked moiety X motif 21|nudix (nucleoside diphosphate linked moiety X)-type motif 21|nudix motif 21|pre-mRNA cleavage factor Im (25kD)|pre-mRNA cleavage factor Im 25 kDa subunit|pre-mRNA cleavage factor Im 68 kDa subunit|pre-mRNA cleavage factor Im, 25kD subunit', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56429133, end_position_on_the_genomic_accession=56451332, orientation='minus', exon_count=7, OMIM=[604978], no_hdr0=''),
    11052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11052, CurrentID=0, Status='live', Symbol='CPSF6', Aliases=['CFIM', 'CFIM68', 'CFIM72', 'HPBRII-4', 'HPBRII-7'], description='cleavage and polyadenylation specific factor 6', other_designations='cleavage and polyadenylation specificity factor subunit 6|CPSF 68 kDa subunit|cleavage and polyadenylation specific factor 6, 68kDa|cleavage and polyadenylation specificity factor 68 kDa subunit|cleavage factor Im complex 68 kDa subunit|pre-mRNA cleavage factor I, 68kD subunit|pre-mRNA cleavage factor Im (68kD)|pre-mRNA cleavage factor Im 68 kDa subunit|protein HPBRII-4/7', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69239568, end_position_on_the_genomic_accession=69274358, orientation='plus', exon_count=11, OMIM=[604979], no_hdr0=''),
    11054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11054, CurrentID=0, Status='live', Symbol='OGFR', Aliases=[], description='opioid growth factor receptor', other_designations='opioid growth factor receptor|protein 7-60|zeta-type opioid receptor', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62804835, end_position_on_the_genomic_accession=62814000, orientation='plus', exon_count=7, OMIM=[606459], no_hdr0=''),
    11055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11055, CurrentID=0, Status='live', Symbol='ZPBP', Aliases=['ZPBP1'], description='zona pellucida binding protein', other_designations='zona pellucida-binding protein 1|inner acrosomal membrane IAM38', map_location='7p12.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=49846355, end_position_on_the_genomic_accession=50093258, orientation='minus', exon_count=13, OMIM=[608498], no_hdr0=''),
    11056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11056, CurrentID=0, Status='live', Symbol='DDX52', Aliases=['HUSSY19', 'ROK1'], description='DExD-box helicase 52', other_designations='probable ATP-dependent RNA helicase DDX52|DEAD (Asp-Glu-Ala-Asp) box polypeptide 52|DEAD box protein 52|DEAD-box helicase 52', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37609739, end_position_on_the_genomic_accession=37643448, orientation='minus', exon_count=16, OMIM=[612500], no_hdr0=''),
    11057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11057, CurrentID=0, Status='live', Symbol='ABHD2', Aliases=['HS1-2', 'LABH2', 'PHPS1-2'], description='abhydrolase domain containing 2, acylglycerol lipase', other_designations='monoacylglycerol lipase ABHD2|2-arachidonoylglycerol hydrolase|abhydrolase domain-containing protein 2|acetylesterase|alpha/beta hydrolase domain containing protein 2|lung alpha/beta hydrolase 2|progesterone-sensitive lipase|protein PHPS1-2|testicular tissue protein Li 6', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89088422, end_position_on_the_genomic_accession=89202355, orientation='plus', exon_count=17, OMIM=[612196], no_hdr0=''),
    11059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11059, CurrentID=0, Status='live', Symbol='WWP1', Aliases=['AIP5', 'Tiul1', 'hSDRP1'], description='WW domain containing E3 ubiquitin protein ligase 1', other_designations='NEDD4-like E3 ubiquitin-protein ligase WWP1|HECT-type E3 ubiquitin transferase WWP1|Nedd-4-like ubiquitin-protein ligase|TGIF-interacting ubiquitin ligase 1|WW domain-containing protein 1|atrophin-1 interacting protein 5', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86342547, end_position_on_the_genomic_accession=86468503, orientation='plus', exon_count=25, OMIM=[602307], no_hdr0=''),
    11060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11060, CurrentID=0, Status='live', Symbol='WWP2', Aliases=['AIP2', 'WWp2-like'], description='WW domain containing E3 ubiquitin protein ligase 2', other_designations='NEDD4-like E3 ubiquitin-protein ligase WWP2|HECT-type E3 ubiquitin transferase WWP2|atrophin-1 interacting protein 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69762301, end_position_on_the_genomic_accession=69941741, orientation='plus', exon_count=30, OMIM=[602308], no_hdr0=''),
    11061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11061, CurrentID=0, Status='live', Symbol='CNMD', Aliases=['BRICD3', 'CHM-I', 'CHM1', 'LECT1', 'MYETS1'], description='chondromodulin', other_designations='leukocyte cell-derived chemotaxin 1|BRICHOS domain containing 3|chondromodulin-1|chondromodulin-I|leukocyte cell derived chemotaxin 1|multiple myeloma tumor suppressor 1', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52703264, end_position_on_the_genomic_accession=52739820, orientation='minus', exon_count=7, OMIM=[605147], no_hdr0=''),
    11062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11062, CurrentID=0, Status='live', Symbol='DUS4L', Aliases=['DUS4', 'PP35'], description='dihydrouridine synthase 4 like', other_designations='tRNA-dihydrouridine(20a/20b) synthase [NAD(P)+]-like|protein similar to E.coli yhdg and R. capsulatus nifR3', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107563971, end_position_on_the_genomic_accession=107578523, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    11063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11063, CurrentID=0, Status='live', Symbol='SOX30', Aliases=[], description='SRY-box transcription factor 30', other_designations='transcription factor SOX-30|SRY (sex determining region Y)-box 30|SRY-box 30|Sox30 protein type II', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157625679, end_position_on_the_genomic_accession=157671480, orientation='minus', exon_count=7, OMIM=[606698], no_hdr0=''),
    11064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11064, CurrentID=0, Status='live', Symbol='CNTRL', Aliases=['CEP1', 'CEP110', 'FAN', 'bA165P4.1'], description='centriolin', other_designations='centriolin|110 kDa centrosomal protein|bA165P4.1 (ortholog of mouse Ma2a8)|bA165P4.2 (centrosomal protein 1)|centriole associated protein|centrosomal protein 110kDa|centrosomal protein of 110 kDa', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121074892, end_position_on_the_genomic_accession=121177610, orientation='plus', exon_count=48, OMIM=[605496], no_hdr0=''),
    11065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11065, CurrentID=0, Status='live', Symbol='UBE2C', Aliases=['UBCH10', 'dJ447F3.2'], description='ubiquitin conjugating enzyme E2 C', other_designations='ubiquitin-conjugating enzyme E2 C|(E3-independent) E2 ubiquitin-conjugating enzyme C|E2 ubiquitin-conjugating enzyme C|cyclin-selective ubiquitin carrier protein|mitotic-specific ubiquitin-conjugating enzyme|ubiquitin conjugating enzyme E2C|ubiquitin-protein ligase C', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45812644, end_position_on_the_genomic_accession=45816952, orientation='plus', exon_count=8, OMIM=[605574], no_hdr0=''),
    11066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11066, CurrentID=0, Status='live', Symbol='SNRNP35', Aliases=['HM-1', 'U1SNRNPBP'], description='small nuclear ribonucleoprotein U11/U12 subunit 35', other_designations='U11/U12 small nuclear ribonucleoprotein 35 kDa protein|U1 snRNP-binding protein homolog|U11/U12 snRNP 35 kDa protein|U11/U12 snRNP 35K|U11/U12-35K|protein HM-1|small nuclear ribonucleoprotein 35kDa (U11/U12)|small nuclear ribonucleoprotein, U11/U12 35kDa subunit', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123458101, end_position_on_the_genomic_accession=123473154, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    11067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11067, CurrentID=0, Status='live', Symbol='DEPP1', Aliases=['C10orf10', 'DEPP', 'FIG', 'Fseg'], description='DEPP1 autophagy regulator', other_designations='protein DEPP1|decidual protein induced by progesterone|fasting induced|fasting-induced gene protein|fasting-induced protein|fat-specific expressed|protein DEPP', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=44976128, end_position_on_the_genomic_accession=44978809, orientation='minus', exon_count=2, OMIM=[611309], no_hdr0=''),
    11068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11068, CurrentID=0, Status='live', Symbol='CYB561D2', Aliases=['101F6', 'TSP10', 'XXcos-LUCA11.4'], description='cytochrome b561 family member D2', other_designations='transmembrane reductase CYB561D2|cytochrome b561 domain-containing protein 2|putative tumor suppressor protein 101F6|transmembrane ascorbate ferrireductase', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50350862, end_position_on_the_genomic_accession=50368197, orientation='plus', exon_count=7, OMIM=[607068], no_hdr0=''),
    11069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11069, CurrentID=0, Status='live', Symbol='RAPGEF4', Aliases=['CAMP-GEFII', 'CGEF2', 'EPAC', 'EPAC 2', 'EPAC2', 'Nbla00496'], description='Rap guanine nucleotide exchange factor 4', other_designations='rap guanine nucleotide exchange factor 4|RAP guanine-nucleotide-exchange factor (GEF) 4|Rap guanine nucleotide exchange factor (GEF) 4|cAMP-regulated guanine nucleotide exchange factor II|exchange factor directly activated by cAMP 2|exchange protein directly activated by cAMP 2|putative protein product of Nbla00496', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=172735282, end_position_on_the_genomic_accession=173052893, orientation='plus', exon_count=37, OMIM=[606058], no_hdr0=''),
    11070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11070, CurrentID=0, Status='live', Symbol='TMEM115', Aliases=['PL6'], description='transmembrane protein 115', other_designations='transmembrane protein 115|PP6|placental protein 6|testicular tissue protein Li 201', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50354750, end_position_on_the_genomic_accession=50359521, orientation='minus', exon_count=2, OMIM=[607069], no_hdr0=''),
    11072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11072, CurrentID=0, Status='live', Symbol='DUSP14', Aliases=['MKP-L', 'MKP6'], description='dual specificity phosphatase 14', other_designations='dual specificity protein phosphatase 14|MAP kinase phosphatase 6|MKP-1-like protein tyrosine phosphatase|MKP-6|mitogen-activated protein kinase phosphatase 6', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37488561, end_position_on_the_genomic_accession=37513501, orientation='plus', exon_count=5, OMIM=[606618], no_hdr0=''),
    11073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11073, CurrentID=0, Status='live', Symbol='TOPBP1', Aliases=['Dpb11', 'TOP2BP1'], description='DNA topoisomerase II binding protein 1', other_designations='DNA topoisomerase 2-binding protein 1|DNA topoisomerase II-beta-binding protein 1|topoisomerase (DNA) II binding protein 1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133600238, end_position_on_the_genomic_accession=133661968, orientation='minus', exon_count=28, OMIM=[607760], no_hdr0=''),
    11074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11074, CurrentID=0, Status='live', Symbol='TRIM31', Aliases=['C6orf13', 'HCG1', 'HCGI', 'RNF'], description='tripartite motif containing 31', other_designations='E3 ubiquitin-protein ligase TRIM31|RING-type E3 ubiquitin transferase TRIM31|tripartite motif-containing protein 31', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30102892, end_position_on_the_genomic_accession=30113090, orientation='minus', exon_count=10, OMIM=[609316], no_hdr0=''),
    11075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11075, CurrentID=0, Status='live', Symbol='STMN2', Aliases=['SCG10', 'SCGN10'], description='stathmin 2', other_designations='stathmin-2|neuron-specific growth-associated protein|neuronal growth-associated protein (silencer element)|stathmin-like 2|superior cervical ganglia, neural specific 10|superior cervical ganglion-10 protein', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=79611117, end_position_on_the_genomic_accession=79666162, orientation='plus', exon_count=8, OMIM=[600621], no_hdr0=''),
    11076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11076, CurrentID=0, Status='live', Symbol='TPPP', Aliases=['TPPP/p251', 'p24', 'p25', 'p25alpha', 'TPPP'], description='tubulin polymerization promoting protein', other_designations='tubulin polymerization-promoting protein|25 kDa brain-specific protein|brain specific protein p25 alpha|glycogen synthase kinase 3 (GSK3) inhibitor p24|p25-alpha', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=659862, end_position_on_the_genomic_accession=700727, orientation='minus', exon_count=7, OMIM=[608773], no_hdr0=''),
    11077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11077, CurrentID=0, Status='live', Symbol='HSF2BP', Aliases=['MEILB2', 'POF19'], description='heat shock transcription factor 2 binding protein', other_designations='heat shock factor 2-binding protein|meiotic localizer of BRCA2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43453987, end_position_on_the_genomic_accession=43659499, orientation='minus', exon_count=13, OMIM=[604554], no_hdr0=''),
    11078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11078, CurrentID=0, Status='live', Symbol='TRIOBP', Aliases=['DFNB28', 'HRIHFB2122', 'TAP68', 'TARA', 'dJ37E16.4'], description='TRIO and F-actin binding protein', other_designations='TRIO and F-actin-binding protein|protein Tara|tara-like protein|trio-associated repeat on actin', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37697048, end_position_on_the_genomic_accession=37776556, orientation='plus', exon_count=26, OMIM=[609761], no_hdr0=''),
    11079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11079, CurrentID=0, Status='live', Symbol='RER1', Aliases=[], description='retention in endoplasmic reticulum sorting receptor 1', other_designations='protein RER1|RER1 retention in endoplasmic reticulum 1 homolog', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2391841, end_position_on_the_genomic_accession=2405436, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    11080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11080, CurrentID=0, Status='live', Symbol='DNAJB4', Aliases=['DNAJW', 'DjB4', 'HLJ1'], description='DnaJ heat shock protein family (Hsp40) member B4', other_designations='dnaJ homolog subfamily B member 4|DnaJ (Hsp40) homolog, subfamily B, member 4|DnaJ-like heat shock protein 40|HSP40 homolog|heat shock 40 kDa protein 1 homolog|heat shock protein 40 homolog|human liver DnaJ-like protein', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77979175, end_position_on_the_genomic_accession=78017964, orientation='plus', exon_count=6, OMIM=[611327], no_hdr0=''),
    11081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11081, CurrentID=0, Status='live', Symbol='KERA', Aliases=['CNA2', 'KTN', 'SLRR2B'], description='keratocan', other_designations='keratocan|keratan sulfate proteoglycan keratocan', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=91050491, end_position_on_the_genomic_accession=91058024, orientation='minus', exon_count=3, OMIM=[603288], no_hdr0=''),
    11082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11082, CurrentID=0, Status='live', Symbol='ESM1', Aliases=['endocan'], description='endothelial cell specific molecule 1', other_designations='endothelial cell-specific molecule 1|ESM-1', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=54977867, end_position_on_the_genomic_accession=54985593, orientation='minus', exon_count=3, OMIM=[601521], no_hdr0=''),
    11083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11083, CurrentID=0, Status='live', Symbol='DIDO1', Aliases=['BYE1', 'C20orf158', 'DATF-1', 'DATF1', 'DIDO2', 'DIDO3', 'DIO-1', 'DIO1', 'dJ885L7.8'], description='death inducer-obliterator 1', other_designations='death-inducer obliterator 1|death-associated transcription factor 1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62877743, end_position_on_the_genomic_accession=62937933, orientation='minus', exon_count=19, OMIM=[604140], no_hdr0=''),
    11085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11085, CurrentID=0, Status='live', Symbol='ADAM30', Aliases=['svph4'], description='ADAM metallopeptidase domain 30', other_designations='disintegrin and metalloproteinase domain-containing protein 30|a disintegrin and metalloproteinase domain 30', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119893533, end_position_on_the_genomic_accession=119896515, orientation='minus', exon_count=1, OMIM=[604779], no_hdr0=''),
    11086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11086, CurrentID=0, Status='live', Symbol='ADAM29', Aliases=['CT73', 'svph1'], description='ADAM metallopeptidase domain 29', other_designations='disintegrin and metalloproteinase domain-containing protein 29|a disintegrin and metalloproteinase domain 29|cancer/testis antigen 73|epididymis secretory sperm binding protein|metallaproteinase-disintegrin (ADAM29)|testis secretory sperm-binding protein Li 207a', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=174918358, end_position_on_the_genomic_accession=174978180, orientation='plus', exon_count=9, OMIM=[604778], no_hdr0=''),
    11091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11091, CurrentID=0, Status='live', Symbol='WDR5', Aliases=['BIG-3', 'CFAP89', 'SWD3'], description='WD repeat domain 5', other_designations='WD repeat-containing protein 5|BMP2-induced 3-kb gene protein|SWD3, Set1c WD40 repeat protein, homolog|cilia and flagella associated protein 89', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134135199, end_position_on_the_genomic_accession=134159968, orientation='plus', exon_count=17, OMIM=[609012], no_hdr0=''),
    11092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11092, CurrentID=0, Status='live', Symbol='SPACA9', Aliases=['C9orf9', 'Mast'], description='sperm acrosome associated 9', other_designations='sperm acrosome-associated protein 9|Rsb66 homolog', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132878320, end_position_on_the_genomic_accession=132890314, orientation='plus', exon_count=7, OMIM=[618552], no_hdr0=''),
    11093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11093, CurrentID=0, Status='live', Symbol='ADAMTS13', Aliases=['ADAM-TS13', 'ADAMTS-13', 'C9orf8', 'VWFCP', 'vWF-CP'], description='ADAM metallopeptidase with thrombospondin type 1 motif 13', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 13|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 13|vWF-cleaving protease|von Willebrand factor-cleaving protease', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133414337, end_position_on_the_genomic_accession=133459403, orientation='plus', exon_count=31, OMIM=[604134], no_hdr0=''),
    11094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11094, CurrentID=0, Status='live', Symbol='CACFD1', Aliases=['C9orf7', 'D9S2135', 'FLOWER'], description='calcium channel flower domain containing 1', other_designations='calcium channel flower homolog|calcium channel flower domain-containing protein 1', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133459978, end_position_on_the_genomic_accession=133470848, orientation='plus', exon_count=7, OMIM=[613104], no_hdr0=''),
    11095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11095, CurrentID=0, Status='live', Symbol='ADAMTS8', Aliases=['ADAM-TS8', 'METH2'], description='ADAM metallopeptidase with thrombospondin type 1 motif 8', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 8|ADAMTS-8|METH-2|METH-8|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 8', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130404923, end_position_on_the_genomic_accession=130428609, orientation='minus', exon_count=9, OMIM=[605175], no_hdr0=''),
    11096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11096, CurrentID=0, Status='live', Symbol='ADAMTS5', Aliases=['ADAM-TS 11', 'ADAM-TS 5', 'ADAM-TS5', 'ADAMTS-11', 'ADAMTS-5', 'ADAMTS11', 'ADMP-2'], description='ADAM metallopeptidase with thrombospondin type 1 motif 5', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 5|a disintegrin and metalloproteinase with thrombospondin motifs 11|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 5 (aggrecanase-2)|aggrecanase-2', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=26917922, end_position_on_the_genomic_accession=26967758, orientation='minus', exon_count=9, OMIM=[605007], no_hdr0=''),
    11097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11097, CurrentID=0, Status='live', Symbol='NUP42', Aliases=['CG1', 'NLP-1', 'NLP_1', 'NUPL2', 'hCG1'], description='nucleoporin 42', other_designations='nucleoporin NUP42|H_RG271G13.9|NUP42 homolog|nucleoporin hCG1|nucleoporin like 2|nucleoporin-like protein 1|nucleoporin-like protein 2', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23181298, end_position_on_the_genomic_accession=23201011, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    11098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11098, CurrentID=0, Status='live', Symbol='PRSS23', Aliases=['SIG13', 'SPUVE', 'ZSIG13'], description='serine protease 23', other_designations='serine protease 23|protease, serine 23|putative secreted protein Zsig13|serine protease, umbilical endothelium', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86791071, end_position_on_the_genomic_accession=86952910, orientation='plus', exon_count=8, OMIM=[618376], no_hdr0=''),
    11099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11099, CurrentID=0, Status='live', Symbol='PTPN21', Aliases=['PTPD1', 'PTPRL10'], description='protein tyrosine phosphatase non-receptor type 21', other_designations='tyrosine-protein phosphatase non-receptor type 21|dJ1175B15.2 (protein tyrosine phosphatase, non-receptor type 21)|protein-tyrosine phosphatase D1', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88465778, end_position_on_the_genomic_accession=88555007, orientation='minus', exon_count=23, OMIM=[603271], no_hdr0=''),
    11100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11100, CurrentID=0, Status='live', Symbol='HNRNPUL1', Aliases=['E1B-AP5', 'E1BAP5', 'HNRPUL1'], description='heterogeneous nuclear ribonucleoprotein U like 1', other_designations='heterogeneous nuclear ribonucleoprotein U-like protein 1|E1B 55kDa associated protein 5|E1B-55 kDa-associated protein 5|adenovirus early region 1B-associated protein 5', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41262519, end_position_on_the_genomic_accession=41307787, orientation='plus', exon_count=18, OMIM=[605800], no_hdr0=''),
    11101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11101, CurrentID=0, Status='live', Symbol='ATE1', Aliases=[], description='arginyltransferase 1', other_designations='arginyl-tRNA--protein transferase 1|R-transferase 1|arginine-tRNA--protein transferase 1|arginyl-tRNA-protein transferase', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=121740424, end_position_on_the_genomic_accession=121928801, orientation='minus', exon_count=16, OMIM=[607103], no_hdr0=''),
    11102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11102, CurrentID=0, Status='live', Symbol='RPP14', Aliases=['P14'], description='ribonuclease P/MRP subunit p14', other_designations='ribonuclease P protein subunit p14|ribonuclease P/MRP 14kDa subunit', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58306245, end_position_on_the_genomic_accession=58320193, orientation='plus', exon_count=7, OMIM=[606112], no_hdr0=''),
    11103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11103, CurrentID=0, Status='live', Symbol='KRR1', Aliases=['HRB2', 'RIP-1'], description='KRR1 small subunit processome component homolog', other_designations='KRR1 small subunit processome component homolog|HIV-1 Rev-binding protein 2|HIV-1 rev binding protein 2|KRR-R motif-containing protein 1|KRR1, small subunit (SSU) processome component, homolog|Rev interacting protein|rev-interacting protein 1', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75490863, end_position_on_the_genomic_accession=75511609, orientation='minus', exon_count=10, OMIM=[612817], no_hdr0=''),
    11104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11104, CurrentID=0, Status='live', Symbol='KATNA1', Aliases=[], description='katanin catalytic subunit A1', other_designations='katanin p60 ATPase-containing subunit A1|katanin p60 (ATPase containing) subunit A 1|katanin p60 subunit A1|p60 katanin', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149594873, end_position_on_the_genomic_accession=149649018, orientation='minus', exon_count=14, OMIM=[606696], no_hdr0=''),
    11105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11105, CurrentID=0, Status='live', Symbol='PRDM7', Aliases=['PFM4', 'ZNF910'], description='PR/SET domain 7', other_designations='probable histone-lysine N-methyltransferase PRDM7|PR domain 7|PR domain containing 7|PR domain zinc finger protein 7|PR-domain family protein 4', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=90056566, end_position_on_the_genomic_accession=90077339, orientation='minus', exon_count=11, OMIM=[609759], no_hdr0=''),
    11107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11107, CurrentID=0, Status='live', Symbol='PRDM5', Aliases=['BCS2', 'PFM2'], description='PR/SET domain 5', other_designations='PR domain zinc finger protein 5|PR domain 5|PR domain containing 5', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=120684906, end_position_on_the_genomic_accession=120922849, orientation='minus', exon_count=23, OMIM=[614161], no_hdr0=''),
    11108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11108, CurrentID=0, Status='live', Symbol='PRDM4', Aliases=['PFM1'], description='PR/SET domain 4', other_designations='PR domain zinc finger protein 4|PR domain 4|PR domain containing 4|PR domain-containing protein 4|PR-domain zinc-finger protein PFM1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=107732866, end_position_on_the_genomic_accession=107761272, orientation='minus', exon_count=12, OMIM=[605780], no_hdr0=''),
    11112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11112, CurrentID=0, Status='live', Symbol='HIBADH', Aliases=['NS5ATP1'], description='3-hydroxyisobutyrate dehydrogenase', other_designations="3-hydroxyisobutyrate dehydrogenase, mitochondrial|3'-hydroxyisobutyrate dehydrogenase|epididymis secretory sperm binding protein", map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27525440, end_position_on_the_genomic_accession=27662903, orientation='minus', exon_count=9, OMIM=[608475], no_hdr0=''),
    11113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11113, CurrentID=0, Status='live', Symbol='CIT', Aliases=['CITK', 'CRIK', 'MCPH17', 'STK21'], description='citron rho-interacting serine/threonine kinase', other_designations='citron Rho-interacting kinase|citron (rho-interacting, serine/threonine kinase 21)|serine/threonine kinase 21|serine/threonine-protein kinase 21', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119685791, end_position_on_the_genomic_accession=119877320, orientation='minus', exon_count=50, OMIM=[605629], no_hdr0=''),
    11116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11116, CurrentID=0, Status='live', Symbol='CEP43', Aliases=['FGFR1OP', 'FOP'], description='centrosomal protein 43', other_designations='centrosomal protein 43|FGFR1 oncogene partner|fibroblast growth factor receptor 1 oncogene partner', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166999397, end_position_on_the_genomic_accession=167052718, orientation='plus', exon_count=13, OMIM=[605392], no_hdr0=''),
    11117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11117, CurrentID=0, Status='live', Symbol='EMILIN1', Aliases=['EMI', 'EMILIN', 'gp115'], description='elastin microfibril interfacer 1', other_designations='EMILIN-1|elastin microfibril interface-located protein 1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27078615, end_position_on_the_genomic_accession=27086403, orientation='plus', exon_count=8, OMIM=[130660], no_hdr0=''),
    11118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11118, CurrentID=0, Status='live', Symbol='BTN3A2', Aliases=['BT3.2', 'BTF4', 'BTN3.2', 'CD277'], description='butyrophilin subfamily 3 member A2', other_designations='butyrophilin subfamily 3 member A2|butyrophilin protein', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26365170, end_position_on_the_genomic_accession=26378320, orientation='plus', exon_count=12, OMIM=[613594], no_hdr0=''),
    11119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11119, CurrentID=0, Status='live', Symbol='BTN3A1', Aliases=['BT3.1', 'BTF5', 'BTN3.1', 'CD277'], description='butyrophilin subfamily 3 member A1', other_designations='butyrophilin subfamily 3 member A1|dJ45P21.3 (butyrophilin, subfamily 3, member A1)', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26402269, end_position_on_the_genomic_accession=26415216, orientation='plus', exon_count=11, OMIM=[613593], no_hdr0=''),
    11120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11120, CurrentID=0, Status='live', Symbol='BTN2A1', Aliases=['BK14H9.1', 'BT2.1', 'BTF1', 'BTN2.1', 'DJ3E1.1'], description='butyrophilin subfamily 2 member A1', other_designations='butyrophilin subfamily 2 member A1', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26457955, end_position_on_the_genomic_accession=26476622, orientation='plus', exon_count=9, OMIM=[613590], no_hdr0=''),
    11122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11122, CurrentID=0, Status='live', Symbol='PTPRT', Aliases=['R-PTP-T', 'RPTP-rho', 'RPTPrho'], description='protein tyrosine phosphatase receptor type T', other_designations='receptor-type tyrosine-protein phosphatase T|receptor protein tyrosine phosphatase|receptor-type tyrosine-protein phosphatase rho', map_location='20q12-q13.11', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=42029959, end_position_on_the_genomic_accession=43189906, orientation='minus', exon_count=37, OMIM=[608712], no_hdr0=''),
    11123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11123, CurrentID=0, Status='live', Symbol='RCAN3', Aliases=['DSCR1L2', 'MCIP3', 'RCN3', 'hRCN3'], description='RCAN family member 3', other_designations='calcipressin-3|Down syndrome candidate region 1-like 2|Down syndrome critical region gene 1-like 2|down syndrome candidate region 1-like protein 2|myocyte-enriched calcineurin-interacting protein 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24502344, end_position_on_the_genomic_accession=24541040, orientation='plus', exon_count=7, OMIM=[605860], no_hdr0=''),
    11124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11124, CurrentID=0, Status='live', Symbol='FAF1', Aliases=['CGI-03', 'HFAF1s', 'UBXD12', 'UBXN3A', 'hFAF1'], description='Fas associated factor 1', other_designations='FAS-associated factor 1|Fas (TNFRSF6) associated factor 1|TNFRSF6-associated factor 1|UBX domain protein 3A|UBX domain-containing protein 12|UBX domain-containing protein 3A', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=50437028, end_position_on_the_genomic_accession=50960267, orientation='minus', exon_count=21, OMIM=[604460], no_hdr0=''),
    11126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11126, CurrentID=0, Status='live', Symbol='CD160', Aliases=['BY55', 'NK1', 'NK28'], description='CD160 molecule', other_designations='CD160 antigen|CD160-delta Ig|natural killer cell receptor BY55|natural killer cell receptor, immunoglobulin superfamily member', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145719312, end_position_on_the_genomic_accession=145739288, orientation='plus', exon_count=6, OMIM=[604463], no_hdr0=''),
    11127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11127, CurrentID=0, Status='live', Symbol='KIF3A', Aliases=['FLA10', 'KLP-20'], description='kinesin family member 3A', other_designations='kinesin-like protein KIF3A|kinesin family protein 3A|microtubule plus end-directed kinesin motor 3A', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132688808, end_position_on_the_genomic_accession=132737563, orientation='minus', exon_count=20, OMIM=[604683], no_hdr0=''),
    11128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11128, CurrentID=0, Status='live', Symbol='POLR3A', Aliases=['ADDH', 'C160', 'HLD7', 'RPC1', 'RPC155', 'WDRTS', 'hRPC155'], description='RNA polymerase III subunit A', other_designations='DNA-directed RNA polymerase III subunit RPC1|DNA-directed RNA polymerase III largest subunit|DNA-directed RNA polymerase III subunit A|RNA polymerase III 155 kDa subunit|RNA polymerase III subunit C1|RNA polymerase III subunit C160|RNA polymerase III subunit RPC155-D|polymerase (RNA) III (DNA directed) polypeptide A, 155kDa|polymerase (RNA) III subunit A', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=77975149, end_position_on_the_genomic_accession=78029515, orientation='minus', exon_count=31, OMIM=[614258], no_hdr0=''),
    11129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11129, CurrentID=0, Status='live', Symbol='CLASRP', Aliases=['CLASP', 'SFRS16', 'SWAP2'], description='CLK4 associating serine/arginine rich protein', other_designations='CLK4-associating serine/arginine rich protein|Clk4 associating SR-related protein|splicing factor, arginine/serine-rich 16 (suppressor-of-white-apricot homolog, Drosophila)|suppressor of white apricot homolog 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45039045, end_position_on_the_genomic_accession=45070956, orientation='plus', exon_count=21, OMIM=[618532], no_hdr0=''),
    11130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11130, CurrentID=0, Status='live', Symbol='ZWINT', Aliases=['HZwint-1', 'KNTC2AP', 'SIP301', 'ZWINT'], description='ZW10 interacting kinetochore protein', other_designations='ZW10 interactor|SNAP25 interacting protein of 30 kDa|ZW10 interactor, kinetochore protein|human ZW10 interacting protein-1|zwint-1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=56357227, end_position_on_the_genomic_accession=56361273, orientation='minus', exon_count=9, OMIM=[609177], no_hdr0=''),
    11131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11131, CurrentID=0, Status='live', Symbol='CAPN11', Aliases=['calpain11'], description='calpain 11', other_designations='calpain-11|CANP 11|calcium-activated neutral proteinase 11', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44158811, end_position_on_the_genomic_accession=44184401, orientation='plus', exon_count=25, OMIM=[604822], no_hdr0=''),
    11132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11132, CurrentID=0, Status='live', Symbol='CAPN10', Aliases=['CANP10', 'NIDDM1'], description='calpain 10', other_designations='calpain-10|calcium-activated neutral proteinase 10|calpain-like protease CAPN10', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240586734, end_position_on_the_genomic_accession=240599104, orientation='plus', exon_count=12, OMIM=[605286], no_hdr0=''),
    11133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11133, CurrentID=0, Status='live', Symbol='KPTN', Aliases=['2E4', 'KICS4', 'MRT41'], description='kaptin, actin binding protein', other_designations='KICSTOR complex protein kaptin|actin-associated protein 2E4|epididymis secretory sperm binding protein', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47475141, end_position_on_the_genomic_accession=47486792, orientation='minus', exon_count=17, OMIM=[615620], no_hdr0=''),
    11135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11135, CurrentID=0, Status='live', Symbol='CDC42EP1', Aliases=['BORG5', 'CEP1', 'MSE55'], description='CDC42 effector protein 1', other_designations='cdc42 effector protein 1|55 kDa bone marrow stromal/endothelial cell protein|CDC42 effector protein (Rho GTPase binding) 1|binder of Rho GTPases 5|serum constituent protein|serum protein MSE55', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37560480, end_position_on_the_genomic_accession=37569405, orientation='plus', exon_count=3, OMIM=[606084], no_hdr0=''),
    11136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11136, CurrentID=0, Status='live', Symbol='SLC7A9', Aliases=['BAT1', 'CSNU3'], description='solute carrier family 7 member 9', other_designations='B(0,+)-type amino acid transporter 1|b(0,+)AT|glycoprotein-associated amino acid transporter b0,+AT1|solute carrier family 7 (amino acid transporter light chain, bo,+ system), member 9|solute carrier family 7 (cationic amino acid transporter, y+ system), member 9|solute carrier family 7 (glycoprotein-associated amino acid transporter light chain, bo,+ system), member 9', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32830511, end_position_on_the_genomic_accession=32870957, orientation='minus', exon_count=13, OMIM=[604144], no_hdr0=''),
    11137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11137, CurrentID=0, Status='live', Symbol='PWP1', Aliases=['IEF-SSP-9502'], description='PWP1 homolog, endonuclein', other_designations='periodic tryptophan protein 1 homolog|endonuclein|keratinocyte protein IEF SSP 9502|nuclear phosphoprotein similar to S. cerevisiae PWP1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=107685799, end_position_on_the_genomic_accession=107713162, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    11138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11138, CurrentID=0, Status='live', Symbol='TBC1D8', Aliases=['AD3', 'GRAMD8', 'HBLP1A', 'VRP', 'TBC1D8'], description='TBC1 domain family member 8', other_designations='TBC1 domain family member 8|BUB2-like protein 1|TBC1 domain family, member 8 (with GRAM domain)|TBC1 domain family, member 8A|vascular Rab-GAP/TBC-containing protein', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101006435, end_position_on_the_genomic_accession=101195321, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    11140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11140, CurrentID=0, Status='live', Symbol='CDC37', Aliases=['P50CDC37'], description='cell division cycle 37, HSP90 cochaperone', other_designations='hsp90 co-chaperone Cdc37|CDC37 (cell division cycle 37, S. cerevisiae, homolog)|CDC37 cell division cycle 37 homolog|cell division cycle 37 homolog|hsp90 chaperone protein kinase-targeting subunit', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10391128, end_position_on_the_genomic_accession=10403568, orientation='minus', exon_count=8, OMIM=[605065], no_hdr0=''),
    11141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11141, CurrentID=0, Status='live', Symbol='IL1RAPL1', Aliases=['IL-1-RAPL-1', 'IL-1RAPL-1', 'IL1R8', 'IL1RAPL', 'IL1RAPL-1', 'MRX10', 'MRX21', 'MRX34', 'OPHN4', 'TIGIRR-2'], description='interleukin 1 receptor accessory protein like 1', other_designations='interleukin-1 receptor accessory protein-like 1|X-linked interleukin-1 receptor accessory protein-like 1|interleukin 1 receptor-8|mental retardation, X-linked 10|oligophrenin-4|three immunoglobulin domain-containing IL-1 receptor-related 2', map_location='Xp21.3-p21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=28587446, end_position_on_the_genomic_accession=29956718, orientation='plus', exon_count=13, OMIM=[300206], no_hdr0=''),
    11142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11142, CurrentID=0, Status='live', Symbol='PKIG', Aliases=['PKI-gamma'], description='cAMP-dependent protein kinase inhibitor gamma', other_designations='cAMP-dependent protein kinase inhibitor gamma|protein kinase (cAMP-dependent, catalytic) inhibitor gamma', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44531875, end_position_on_the_genomic_accession=44619037, orientation='plus', exon_count=9, OMIM=[604932], no_hdr0=''),
    11143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11143, CurrentID=0, Status='live', Symbol='KAT7', Aliases=['HBO1', 'HBOA', 'MYST2', 'ZC2HC7'], description='lysine acetyltransferase 7', other_designations='histone acetyltransferase KAT7|K(lysine) acetyltransferase 7|MOZ, YBF2/SAS3, SAS2 and TIP60 protein 2|MYST histone acetyltransferase 2|histone acetyltransferase MYST2|histone acetyltransferase binding to ORC1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49788681, end_position_on_the_genomic_accession=49835026, orientation='plus', exon_count=16, OMIM=[609880], no_hdr0=''),
    11144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11144, CurrentID=0, Status='live', Symbol='DMC1', Aliases=['DMC1H', 'LIM15', 'dJ199H16.1'], description='DNA meiotic recombinase 1', other_designations='meiotic recombination protein DMC1/LIM15 homolog|DMC1 dosage suppressor of mck1 homolog, meiosis-specific homologous recombination|disrupted meiotic cDNA1, yeast, homolog of', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38509154, end_position_on_the_genomic_accession=38570286, orientation='minus', exon_count=16, OMIM=[602721], no_hdr0=''),
    11145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11145, CurrentID=0, Status='live', Symbol='PLAAT3', Aliases=['AdPLA', 'H-REV107', 'H-REV107-1', 'HRASLS3', 'HREV107', 'HREV107-1', 'HREV107-3', 'HRSL3', 'PLA2G16', 'PLAAT-3'], description='phospholipase A and acyltransferase 3', other_designations='phospholipase A and acyltransferase 3|Ca-independent phospholipase A1/2|H-rev 107 protein homolog|HRAS-like suppressor 1|HRAS-like suppressor 3|adipose-specific PLA2|adipose-specific phospholipase A2|group XVI phospholipase A1/A2|group XVI phospholipase A2|phospholipase A/acyltransferase-3|phospholipase A2 group XVI|renal carcinoma antigen NY-REN-65', map_location='11q12.3-q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63574462, end_position_on_the_genomic_accession=63616926, orientation='minus', exon_count=6, OMIM=[613867], no_hdr0=''),
    11146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11146, CurrentID=0, Status='live', Symbol='GLMN', Aliases=['FAP', 'FAP48', 'FAP68', 'FKBPAP', 'GLML', 'GVM', 'VMGLOM'], description='glomulin, FKBP associated protein', other_designations='glomulin|FK506-binding protein-associated protein|FKBP-associated protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92245786, end_position_on_the_genomic_accession=92441936, orientation='minus', exon_count=24, OMIM=[601749], no_hdr0=''),
    11148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11148, CurrentID=0, Status='live', Symbol='HHLA2', Aliases=['B7-H5', 'B7-H7', 'B7H7', 'B7y'], description='HERV-H LTR-associating 2', other_designations='HERV-H LTR-associating protein 2|human endogenous retrovirus-H long terminal repeat-associating protein 2', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108296490, end_position_on_the_genomic_accession=108378285, orientation='plus', exon_count=13, OMIM=[604371], no_hdr0=''),
    11149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11149, CurrentID=0, Status='live', Symbol='BVES', Aliases=['CARICK', 'HBVES', 'LGMD2X', 'LGMDR25', 'POP1', 'POPDC1'], description='blood vessel epicardial substance', other_designations='blood vessel epicardial substance|popeye domain-containing protein 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=105096822, end_position_on_the_genomic_accession=105137157, orientation='minus', exon_count=11, OMIM=[604577], no_hdr0=''),
    11151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11151, CurrentID=0, Status='live', Symbol='CORO1A', Aliases=['CLABP', 'CLIPINA', 'HCORO1', 'IMD8', 'TACO', 'p57'], description='coronin 1A', other_designations='coronin-1A|clipin-A|coronin, actin binding protein, 1A|coronin-1|coronin-like protein A|coronin-like protein p57|tryptophan aspartate-containing coat protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30183602, end_position_on_the_genomic_accession=30189076, orientation='plus', exon_count=12, OMIM=[605000], no_hdr0=''),
    11152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11152, CurrentID=0, Status='live', Symbol='WDR45', Aliases=['JM5', 'NBIA4', 'NBIA5', 'WDRX1', 'WIPI-4', 'WIPI4'], description='WD repeat domain 45', other_designations='WD repeat domain phosphoinositide-interacting protein 4|WD repeat domain, X-linked 1|WD repeat-containing protein 45|WD45 repeat protein interacting with phosphoinositides 4|neurodegeneration with brain iron accumulation 4|neurodegeneration with brain iron accumulation 5', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49074442, end_position_on_the_genomic_accession=49101178, orientation='minus', exon_count=13, OMIM=[300526], no_hdr0=''),
    11153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11153, CurrentID=0, Status='live', Symbol='FICD', Aliases=['HIP13', 'HYPE', 'UNQ3041'], description='FIC domain protein adenylyltransferase', other_designations='protein adenylyltransferase FICD|AMPylator FICD|FIC domain containing|FIC domain-containing protein|HIP-13|Huntingtin interacting protein E|adenosine monophosphate-protein transferase FICD|de-AMPylase FICD|fic S-phase protein cell division homolog|huntingtin interactor protein E|huntingtin yeast partner E|huntingtin-interacting protein 13|huntingtin-interacting protein E', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108515277, end_position_on_the_genomic_accession=108521210, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    11154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11154, CurrentID=0, Status='live', Symbol='AP4S1', Aliases=['AP47B', 'CLA20', 'CLAPS4', 'CPSQ6', 'SPG52'], description='adaptor related protein complex 4 subunit sigma 1', other_designations='AP-4 complex subunit sigma-1|AP-4 adapter complex subunit sigma-1|AP-4 adaptor complex subunit sigma-1|adaptor related protein complex 4 sigma 1 subunit|clathrin-associated/assembly/adaptor protein, sigma 4|sigma-4-adaptin', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31025106, end_position_on_the_genomic_accession=31096450, orientation='plus', exon_count=11, OMIM=[607243], no_hdr0=''),
    11155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11155, CurrentID=0, Status='live', Symbol='LDB3', Aliases=['CMD1C', 'CMH24', 'CMPD3', 'CYPHERZ1', 'LDB3Z4', 'LVNC3', 'MFM4', 'ORACLE', 'PDLIM6', 'ZASP', 'LDB3'], description='LIM domain binding 3', other_designations='LIM domain-binding protein 3|LIM domain-binding protein 3 isoform|PDZ and LIM domain 6|Z-band alternatively spliced PDZ-motif protein|cardiomyopathy, dilated 1C (autosomal dominant)|protein cypher', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86666788, end_position_on_the_genomic_accession=86736072, orientation='plus', exon_count=18, OMIM=[605906], no_hdr0=''),
    11156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11156, CurrentID=0, Status='live', Symbol='PTP4A3', Aliases=['PRL-3', 'PRL-R', 'PRL3'], description='protein tyrosine phosphatase 4A3', other_designations='protein tyrosine phosphatase type IVA 3|phosphatase of regenerating liver 3|potentially prenylated protein tyrosine phosphatase|protein tyrosine phosphatase type IVA, member 3|protein-tyrosine phosphatase of regenerating liver 3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=141391995, end_position_on_the_genomic_accession=141432454, orientation='plus', exon_count=10, OMIM=[606449], no_hdr0=''),
    11157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11157, CurrentID=0, Status='live', Symbol='LSM6', Aliases=['YDR378C'], description='LSM6 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm6|LSM6 U6 small nuclear RNA and mRNA degradation associated|LSM6 homolog, U6 small nuclear RNA associated|Sm protein F', map_location='4q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=146175703, end_position_on_the_genomic_accession=146204436, orientation='plus', exon_count=8, OMIM=[607286], no_hdr0=''),
    11158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11158, CurrentID=0, Status='live', Symbol='RABL2B', Aliases=[], description='RAB, member of RAS oncogene family like 2B', other_designations='rab-like protein 2B', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50767500, end_position_on_the_genomic_accession=50783705, orientation='minus', exon_count=11, OMIM=[605413], no_hdr0=''),
    11159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11159, CurrentID=0, Status='live', Symbol='RABL2A', Aliases=[], description='RAB, member of RAS oncogene family like 2A', other_designations='rab-like protein 2A', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113627218, end_position_on_the_genomic_accession=113643392, orientation='plus', exon_count=9, OMIM=[605412], no_hdr0=''),
    11160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11160, CurrentID=0, Status='live', Symbol='ERLIN2', Aliases=['C8orf2', 'Erlin-2', 'NET32', 'SPFH2', 'SPG18'], description='ER lipid raft associated 2', other_designations='erlin-2|SPFH domain family, member 2|endoplasmic reticulum lipid raft-associated protein 2|epididymis secretory sperm binding protein|spastic paraplegia 18 (autosomal dominant)|stomatin-prohibitin-flotillin-HflC/K domain-containing protein 2', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37736627, end_position_on_the_genomic_accession=37758422, orientation='plus', exon_count=14, OMIM=[611605], no_hdr0=''),
    11161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11161, CurrentID=0, Status='live', Symbol='ERG28', Aliases=['C14orf1', 'NET51'], description='ergosterol biosynthesis 28 homolog', other_designations='ergosterol biosynthetic protein 28 homolog|probable ergosterol biosynthetic protein 28', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75649791, end_position_on_the_genomic_accession=75660876, orientation='minus', exon_count=5, OMIM=[604576], no_hdr0=''),
    11162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11162, CurrentID=0, Status='live', Symbol='NUDT6', Aliases=['ASFGF2', 'FGF-AS', 'FGF2AS', 'GFG-1', 'GFG1'], description='nudix hydrolase 6', other_designations='nucleoside diphosphate-linked moiety X motif 6|antisense basic fibroblast growth factor|nudix (nucleoside diphosphate linked moiety X)-type motif 6', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122892577, end_position_on_the_genomic_accession=122922968, orientation='minus', exon_count=6, OMIM=[606261], no_hdr0=''),
    11163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11163, CurrentID=0, Status='live', Symbol='NUDT4', Aliases=['DIPP-2B', 'DIPP2', 'DIPP2alpha', 'DIPP2beta', 'HDCMB47PB', 'NUDT4'], description='nudix hydrolase 4', other_designations="diphosphoinositol polyphosphate phosphohydrolase 2|DIPP-2|Diphosphoinositol polyphosphate phosphohydrolase NUDT4B|Nucleoside diphosphate-linked moiety X motif 4B|Nudix hydrolase 4B|Nudix motif 4B|diadenosine 5',5'''-P1,P6-hexaphosphate hydrolase 2|diphosphoinositol polyphosphate phosphohydrolase type 2|nudix (nucleoside diphosphate linked moiety X)-type motif 4", map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=93377925, end_position_on_the_genomic_accession=93408146, orientation='plus', exon_count=8, OMIM=[609229], no_hdr0=''),
    11164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11164, CurrentID=0, Status='live', Symbol='NUDT5', Aliases=['YSA1', 'YSA1H', 'YSAH1', 'hNUDT5'], description='nudix hydrolase 5', other_designations='ADP-sugar pyrophosphatase|8-oxo-dGDP phosphatase|nuclear ATP-synthesis protein NUDIX5|nudix (nucleoside diphosphate linked moiety X)-type motif 5', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12165330, end_position_on_the_genomic_accession=12195891, orientation='minus', exon_count=11, OMIM=[609230], no_hdr0=''),
    11165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11165, CurrentID=0, Status='live', Symbol='NUDT3', Aliases=['DIPP', 'DIPP-1', 'DIPP1'], description='nudix hydrolase 3', other_designations="diphosphoinositol polyphosphate phosphohydrolase 1|diadenosine 5',5'''-P1,P6-hexaphosphate hydrolase 1|nucleoside diphosphate-linked moiety X motif 3|nudix (nucleoside diphosphate linked moiety X)-type motif 3|nudix motif 3", map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34279679, end_position_on_the_genomic_accession=34392669, orientation='minus', exon_count=5, OMIM=[609228], no_hdr0=''),
    11166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11166, CurrentID=0, Status='live', Symbol='SOX21', Aliases=['SOX25'], description='SRY-box transcription factor 21', other_designations='transcription factor SOX-21|SOX-A|SRY (sex determining region Y)-box 21|SRY-box 21', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=94709622, end_position_on_the_genomic_accession=94712545, orientation='minus', exon_count=1, OMIM=[604974], no_hdr0=''),
    11167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11167, CurrentID=0, Status='live', Symbol='FSTL1', Aliases=['FRP', 'FSL1', 'MIR198', 'OCC-1', 'OCC1', 'tsc36'], description='follistatin like 1', other_designations='follistatin-related protein 1|follistatin-like protein 1', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120392293, end_position_on_the_genomic_accession=120450993, orientation='minus', exon_count=10, OMIM=[605547], no_hdr0=''),
    11168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11168, CurrentID=0, Status='live', Symbol='PSIP1', Aliases=['DFS70', 'LEDGF', 'PAIP', 'PSIP2', 'p52', 'p75'], description='PC4 and SFRS1 interacting protein 1', other_designations='PC4 and SFRS1-interacting protein|CLL-associated antigen KW-7|dense fine speckles 70 kDa protein|lens epithelium-derived growth factor|transcriptional coactivator p52/p75', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=15464066, end_position_on_the_genomic_accession=15511004, orientation='minus', exon_count=17, OMIM=[603620], no_hdr0=''),
    11169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11169, CurrentID=0, Status='live', Symbol='WDHD1', Aliases=['AND-1', 'AND1', 'CHTF4', 'CTF4'], description='WD repeat and HMG-box DNA binding protein 1', other_designations='WD repeat and HMG-box DNA-binding protein 1|Acidic nucleoplasmic DNA-binding protein 1|CTF4, chromosome transmission fidelity factor 4 homolog', map_location='14q22.2-q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54938949, end_position_on_the_genomic_accession=55027106, orientation='minus', exon_count=26, OMIM=[608126], no_hdr0=''),
    11170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11170, CurrentID=0, Status='live', Symbol='FAM107A', Aliases=['DRR1', 'TU3A'], description='family with sequence similarity 107 member A', other_designations='actin-associated protein FAM107A|down-regulated in renal cell carcinoma 1|protein FAM107A', map_location='3p14.3-p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58564117, end_position_on_the_genomic_accession=58627610, orientation='minus', exon_count=8, OMIM=[608295], no_hdr0=''),
    11171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11171, CurrentID=0, Status='live', Symbol='STRAP', Aliases=['MAWD', 'PT-WD', 'UNRIP'], description='serine/threonine kinase receptor associated protein', other_designations='serine-threonine kinase receptor-associated protein|MAP activator with WD repeats|MAPK activator with WD repeats|WD-40 repeat protein PT-WD|mitogen-activated protein kinase activator with WD repeats|unr-interacting protein', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=15882382, end_position_on_the_genomic_accession=15903478, orientation='plus', exon_count=10, OMIM=[605986], no_hdr0=''),
    11172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11172, CurrentID=0, Status='live', Symbol='INSL6', Aliases=['RIF1'], description='insulin like 6', other_designations='insulin-like peptide INSL6|insulin-like peptide 5|insulin-like peptide 6|relaxin/insulin-like factor 1', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4992409, end_position_on_the_genomic_accession=5185707, orientation='minus', exon_count=3, OMIM=[606414], no_hdr0=''),
    11173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11173, CurrentID=0, Status='live', Symbol='ADAMTS7', Aliases=['ADAM-TS 7', 'ADAM-TS7', 'ADAMTS-7'], description='ADAM metallopeptidase with thrombospondin type 1 motif 7', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 7|COMPase|a disintegrin and metalloprotease with thrombospondin motifs-7 preproprotein|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 7', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78759203, end_position_on_the_genomic_accession=78811476, orientation='minus', exon_count=25, OMIM=[605009], no_hdr0=''),
    11174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11174, CurrentID=0, Status='live', Symbol='ADAMTS6', Aliases=['ADAM-TS 6', 'ADAM-TS6', 'ADAMTS-6'], description='ADAM metallopeptidase with thrombospondin type 1 motif 6', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 6|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 6', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65148736, end_position_on_the_genomic_accession=65482663, orientation='minus', exon_count=33, OMIM=[605008], no_hdr0=''),
    11176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11176, CurrentID=0, Status='live', Symbol='BAZ2A', Aliases=['TIP5', 'WALp3'], description='bromodomain adjacent to zinc finger domain 2A', other_designations='bromodomain adjacent to zinc finger domain protein 2A|TTF-I interacting peptide 5|TTF-I-interacting protein 5|transcription termination factor I-interacting protein 5', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56595596, end_position_on_the_genomic_accession=56636816, orientation='minus', exon_count=35, OMIM=[605682], no_hdr0=''),
    11177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11177, CurrentID=0, Status='live', Symbol='BAZ1A', Aliases=['ACF1', 'WALp1', 'WCRF180', 'hACF1'], description='bromodomain adjacent to zinc finger domain 1A', other_designations='bromodomain adjacent to zinc finger domain protein 1A|ATP-dependent chromatin remodeling protein|ATP-utilizing chromatin assembly and remodeling factor 1|CHRAC subunit ACF1|hWALp1|williams syndrome transcription factor-related chromatin-remodeling factor 180', map_location='14q13.1-q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34752731, end_position_on_the_genomic_accession=34875360, orientation='minus', exon_count=29, OMIM=[605680], no_hdr0=''),
    11178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11178, CurrentID=0, Status='live', Symbol='LZTS1', Aliases=['F37', 'FEZ1'], description='leucine zipper tumor suppressor 1', other_designations='leucine zipper putative tumor suppressor 1|F37/Esophageal cancer-related gene-coding leucine-zipper motif|leucine zipper, putative tumor suppressor 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=20246165, end_position_on_the_genomic_accession=20303963, orientation='minus', exon_count=8, OMIM=[606551], no_hdr0=''),
    11179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11179, CurrentID=0, Status='live', Symbol='ZNF277', Aliases=['NRIF4P', 'ZNF277'], description='zinc finger protein 277', other_designations='zinc finger protein 277|nuclear receptor-interacting factor 4|zinc finger protein (C2H2 type) 277|zinc finger protein 277 pseudogene', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=112206612, end_position_on_the_genomic_accession=112343934, orientation='plus', exon_count=12, OMIM=[605465], no_hdr0=''),
    11180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11180, CurrentID=0, Status='live', Symbol='WDR6', Aliases=[], description='WD repeat domain 6', other_designations='WD repeat-containing protein 6', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49007391, end_position_on_the_genomic_accession=49015951, orientation='plus', exon_count=7, OMIM=[606031], no_hdr0=''),
    11181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11181, CurrentID=0, Status='live', Symbol='TREH', Aliases=['TRE', 'TREAD', 'TREH'], description='trehalase', other_designations='trehalase|alpha,alpha-trehalose glucohydrolase|trehalase (brush-border membrane glycoprotein)', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118657316, end_position_on_the_genomic_accession=118679650, orientation='minus', exon_count=15, OMIM=[275360], no_hdr0=''),
    11182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11182, CurrentID=0, Status='live', Symbol='SLC2A6', Aliases=['GLUT6', 'GLUT9', 'HSA011372'], description='solute carrier family 2 member 6', other_designations='solute carrier family 2, facilitated glucose transporter member 6|GLUT-6|GLUT-9|glucose transporter type 6|glucose transporter type 9|solute carrier family 2 (facilitated glucose transporter), member 6', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133471094, end_position_on_the_genomic_accession=133479127, orientation='minus', exon_count=10, OMIM=[606813], no_hdr0=''),
    11183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11183, CurrentID=0, Status='live', Symbol='MAP4K5', Aliases=['GCKR', 'KHS', 'KHS1', 'MAPKKKK5'], description='mitogen-activated protein kinase kinase kinase kinase 5', other_designations='mitogen-activated protein kinase kinase kinase kinase 5|MAPK/ERK kinase kinase kinase 5|MEK kinase kinase 5|MEKKK 5|germinal center kinase-related|kinase homologous to SPS1/STE20', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50418492, end_position_on_the_genomic_accession=50561126, orientation='minus', exon_count=37, OMIM=[604923], no_hdr0=''),
    11184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11184, CurrentID=0, Status='live', Symbol='MAP4K1', Aliases=['HPK1'], description='mitogen-activated protein kinase kinase kinase kinase 1', other_designations='mitogen-activated protein kinase kinase kinase kinase 1|MAPK/ERK kinase kinase kinase 1|MEK kinase kinase 1|MEKKK 1|hematopoietic progenitor kinase 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38587641, end_position_on_the_genomic_accession=38617953, orientation='minus', exon_count=33, OMIM=[601983], no_hdr0=''),
    11185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11185, CurrentID=0, Status='live', Symbol='INMT', Aliases=['TEMT'], description='indolethylamine N-methyltransferase', other_designations='indolethylamine N-methyltransferase|amine N-methyltransferase|aromatic alkylamine N-methyltransferase|arylamine N-methyltransferase|indolamine N-methyltransferase|nicotine N-methyltransferase|thioether S-methyltransferase', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30752135, end_position_on_the_genomic_accession=30757602, orientation='plus', exon_count=3, OMIM=[604854], no_hdr0=''),
    11186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11186, CurrentID=0, Status='live', Symbol='RASSF1', Aliases=['123F2', 'NORE2AA', 'RDA32', 'REH3P21', 'RASSF1'], description='Ras association domain family member 1', other_designations='ras association domain-containing protein 1|Ras association (RalGDS/AF-6) domain family member 1|WUGSC:H_LUCA12.5|cardiac-specific ras association domain family 1 protein|pancreas-specific ras association domain family 1 protein|tumor suppressor protein RDA32', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50329786, end_position_on_the_genomic_accession=50340836, orientation='minus', exon_count=8, OMIM=[605082], no_hdr0=''),
    11187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11187, CurrentID=0, Status='live', Symbol='PKP3', Aliases=[], description='plakophilin 3', other_designations='plakophilin-3|plakophilin 3b', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=392596, end_position_on_the_genomic_accession=404908, orientation='plus', exon_count=14, OMIM=[605561], no_hdr0=''),
    11188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11188, CurrentID=0, Status='live', Symbol='NISCH', Aliases=['I-1', 'IR1', 'IRAS', 'hIRAS'], description='nischarin', other_designations='nischarin|I-1 receptor candidate protein|I1R candidate protein|imidazoline receptor 1|imidazoline receptor antisera selected', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52455603, end_position_on_the_genomic_accession=52493068, orientation='plus', exon_count=22, OMIM=[615507], no_hdr0=''),
    11189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11189, CurrentID=0, Status='live', Symbol='CELF3', Aliases=['BRUNOL1', 'CAGH4', 'ERDA4', 'ETR-1', 'TNRC4'], description='CUGBP Elav-like family member 3', other_designations='CUGBP Elav-like family member 3|CAG repeat domain|CAG repeat protein 4|CUG-BP- and ETR-3-like factor 3|ELAV-type RNA-binding protein 1|RNA-binding protein BRUNOL-1|bruno-like protein 1|expanded repeat domain protein CAG/CTG 4|expanded repeat domain, CAG/CTG 4|trinucleotide repeat containing 4|trinucleotide repeat-containing gene 4 protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151700058, end_position_on_the_genomic_accession=151716803, orientation='minus', exon_count=13, OMIM=[612678], no_hdr0=''),
    11190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11190, CurrentID=0, Status='live', Symbol='CEP250', Aliases=['C-NAP1', 'CEP2', 'CNAP1', 'CRDHL2'], description='centrosomal protein 250', other_designations='centrosome-associated protein CEP250|250 kDa centrosomal protein|centrosomal Nek2-associated protein 1', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35455137, end_position_on_the_genomic_accession=35519280, orientation='plus', exon_count=40, OMIM=[609689], no_hdr0=''),
    11193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11193, CurrentID=0, Status='live', Symbol='WBP4', Aliases=['FBP21'], description='WW domain binding protein 4', other_designations='WW domain-binding protein 4|WBP-4|WW domain-containing binding protein 4|domain-containing binding protein 4|formin binding protein 21', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41061509, end_position_on_the_genomic_accession=41084006, orientation='plus', exon_count=11, OMIM=[604981], no_hdr0=''),
    11194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11194, CurrentID=0, Status='live', Symbol='ABCB8', Aliases=['EST328128', 'M-ABC1', 'MABC1', 'MITOSUR'], description='ATP binding cassette subfamily B member 8', other_designations='mitochondrial potassium channel ATP-binding subunit|ATP-binding cassette sub-family B member 8, mitochondrial|ATP-binding cassette, sub-family B (MDR/TAP), member 8|mitochondrial ABC protein|mitochondrial ATP-binding cassette 1|mitochondrial sulfonylurea-receptor', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151028450, end_position_on_the_genomic_accession=151047782, orientation='plus', exon_count=17, OMIM=[605464], no_hdr0=''),
    11196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11196, CurrentID=0, Status='live', Symbol='SEC23IP', Aliases=['MSTP053', 'P125', 'P125A', 'iPLA1beta'], description='SEC23 interacting protein', other_designations='SEC23-interacting protein|intracellular phospholipase A1 beta', map_location='10q26.11-q26.12', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119892696, end_position_on_the_genomic_accession=119944657, orientation='plus', exon_count=20, OMIM=[617852], no_hdr0=''),
    11197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11197, CurrentID=0, Status='live', Symbol='WIF1', Aliases=['WIF-1'], description='WNT inhibitory factor 1', other_designations='wnt inhibitory factor 1', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=65050626, end_position_on_the_genomic_accession=65121305, orientation='minus', exon_count=10, OMIM=[605186], no_hdr0=''),
    11198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11198, CurrentID=0, Status='live', Symbol='SUPT16H', Aliases=['CDC68', 'FACTP140', 'SPT16', 'SPT16/CDC68'], description='SPT16 homolog, facilitates chromatin remodeling subunit', other_designations='FACT complex subunit SPT16|FACT 140 kDa subunit|chromatin-specific transcription elongation factor 140 kDa subunit|facilitates chromatin remodeling 140 kDa subunit|facilitates chromatin transcription complex subunit SPT16|hSPT16|suppressor of Ty 16 homolog', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21351472, end_position_on_the_genomic_accession=21384019, orientation='minus', exon_count=27, OMIM=[605012], no_hdr0=''),
    11199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11199, CurrentID=0, Status='live', Symbol='ANXA10', Aliases=['ANX14'], description='annexin A10', other_designations='annexin A10|annexin 14|annexin-10', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=168092525, end_position_on_the_genomic_accession=168187736, orientation='plus', exon_count=13, OMIM=[608008], no_hdr0=''),
    11200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11200, CurrentID=0, Status='live', Symbol='CHEK2', Aliases=['CDS1', 'CHK2', 'HuCds1', 'LFS2', 'PP1425', 'RAD53', 'hCds1'], description='checkpoint kinase 2', other_designations='serine/threonine-protein kinase Chk2|CHK2 checkpoint homolog|cds1 homolog|checkpoint-like protein CHK2', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=28687743, end_position_on_the_genomic_accession=28741866, orientation='minus', exon_count=22, OMIM=[604373], no_hdr0=''),
    11201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11201, CurrentID=0, Status='live', Symbol='POLI', Aliases=['RAD30B', 'RAD3OB', 'eta2'], description='DNA polymerase iota', other_designations='DNA polymerase iota|RAD30 homolog B|polymerase (DNA directed) iota|polymerase (DNA) iota|polymerase (DNA-directed), iota', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54269479, end_position_on_the_genomic_accession=54321266, orientation='plus', exon_count=13, OMIM=[605252], no_hdr0=''),
    11202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11202, CurrentID=0, Status='live', Symbol='KLK8', Aliases=['HNP', 'NP', 'NRPN', 'PRSS19', 'TADG14'], description='kallikrein related peptidase 8', other_designations='kallikrein-8|ovasin|serine protease 19|serine protease TADG-14|tumor-associated differentially expressed gene 14 protein', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50996008, end_position_on_the_genomic_accession=51001604, orientation='minus', exon_count=6, OMIM=[605644], no_hdr0=''),
    11211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11211, CurrentID=0, Status='live', Symbol='FZD10', Aliases=['CD350', 'FZ-10', 'Fz10', 'FzE7', 'hFz10'], description='frizzled class receptor 10', other_designations='frizzled-10|frizzled 10, seven transmembrane spanning receptor|frizzled family receptor 10|frizzled homolog 10', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130162464, end_position_on_the_genomic_accession=130165740, orientation='plus', exon_count=1, OMIM=[606147], no_hdr0=''),
    11212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11212, CurrentID=0, Status='live', Symbol='PLPBP', Aliases=['EPVB6D', 'PROSC'], description='pyridoxal phosphate binding protein', other_designations='pyridoxal phosphate homeostasis protein|PLP homeostasis protein|proline synthase co-transcribed bacterial homolog protein|proline synthetase co-transcribed bacterial homolog protein', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37762546, end_position_on_the_genomic_accession=37779768, orientation='plus', exon_count=9, OMIM=[604436], no_hdr0=''),
    11213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11213, CurrentID=0, Status='live', Symbol='IRAK3', Aliases=['ASRT5', 'IRAKM'], description='interleukin 1 receptor associated kinase 3', other_designations='interleukin-1 receptor-associated kinase 3|IL-1 receptor-associated kinase M|inactive IL-1 receptor-associated kinase 3', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66189214, end_position_on_the_genomic_accession=66254622, orientation='plus', exon_count=12, OMIM=[604459], no_hdr0=''),
    11214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11214, CurrentID=0, Status='live', Symbol='AKAP13', Aliases=['AKAP-13', 'AKAP-Lbc', 'ARHGEF13', 'BRX', 'HA-3', 'Ht31', 'LBC', 'PRKA13', 'PROTO-LB', 'PROTO-LBC', 'c-lbc', 'p47'], description='A-kinase anchoring protein 13', other_designations='A-kinase anchor protein 13|A kinase (PRKA) anchor protein 13|LBC oncogene|breast cancer nuclear receptor-binding auxiliary protein|guanine nucleotide exchange factor Lbc|human thyroid-anchoring protein 31|lymphoid blast crisis oncogene|non-oncogenic Rho GTPase-specific GTP exchange factor|protein kinase A-anchoring protein 13', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=85380603, end_position_on_the_genomic_accession=85749358, orientation='plus', exon_count=39, OMIM=[604686], no_hdr0=''),
    11215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11215, CurrentID=0, Status='live', Symbol='AKAP11', Aliases=['AKAP-11', 'AKAP220', 'PPP1R44', 'PRKA11'], description='A-kinase anchoring protein 11', other_designations='A-kinase anchor protein 11|A kinase (PRKA) anchor protein 11|A-kinase anchor protein 220 kDa|A-kinase anchoring protein, 220kDa|a kinase anchor protein 220 kDa|protein kinase A anchoring protein 11|protein phosphatase 1, regulatory subunit 44', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=42271470, end_position_on_the_genomic_accession=42323266, orientation='plus', exon_count=16, OMIM=[604696], no_hdr0=''),
    11216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11216, CurrentID=0, Status='live', Symbol='AKAP10', Aliases=['AKAP-10', 'D-AKAP-2', 'D-AKAP2', 'PRKA10'], description='A-kinase anchoring protein 10', other_designations='A-kinase anchor protein 10, mitochondrial|A kinase (PRKA) anchor protein 10|dual specificity A kinase-anchoring protein 2|mitochondrial A kinase PPKA anchor protein 10|protein kinase A anchoring protein 10', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19904302, end_position_on_the_genomic_accession=19977828, orientation='minus', exon_count=16, OMIM=[604694], no_hdr0=''),
    11218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11218, CurrentID=0, Status='live', Symbol='DDX20', Aliases=['DP103', 'GEMIN3'], description='DEAD-box helicase 20', other_designations='probable ATP-dependent RNA helicase DDX20|DEAD (Asp-Glu-Ala-Asp) box polypeptide 20|DEAD box protein 20|DEAD box protein DP 103|DEAD-box protein DP103|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 20, 103kD|SMN-interacting protein|component of gems 3|gemin-3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111755901, end_position_on_the_genomic_accession=111768000, orientation='plus', exon_count=11, OMIM=[606168], no_hdr0=''),
    11219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11219, CurrentID=0, Status='live', Symbol='TREX2', Aliases=[], description='three prime repair exonuclease 2', other_designations="three prime repair exonuclease 2|3'-5' exonuclease TREX2 long form", map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153444473, end_position_on_the_genomic_accession=153446056, orientation='minus', exon_count=2, OMIM=[300370], no_hdr0=''),
    11221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11221, CurrentID=0, Status='live', Symbol='DUSP10', Aliases=['MKP-5', 'MKP5'], description='dual specificity phosphatase 10', other_designations='dual specificity protein phosphatase 10|dual specificity phosphatase MKP-5|map kinase phosphatase 5|mitogen-activated protein kinase phosphatase 5|serine/threonine specific protein phosphatase', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=221701424, end_position_on_the_genomic_accession=221742091, orientation='minus', exon_count=5, OMIM=[608867], no_hdr0=''),
    11222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11222, CurrentID=0, Status='live', Symbol='MRPL3', Aliases=['COXPD9', 'MRL3', 'RPML3'], description='mitochondrial ribosomal protein L3', other_designations='39S ribosomal protein L3, mitochondrial|L3mt|MRP-L3|mitochondrial 60S ribosomal protein L3|mitochondrial large ribosomal subunit protein uL3m', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=131462212, end_position_on_the_genomic_accession=131502971, orientation='minus', exon_count=10, OMIM=[607118], no_hdr0=''),
    11224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11224, CurrentID=0, Status='live', Symbol='RPL35', Aliases=['DBA19', 'L35'], description='ribosomal protein L35', other_designations='60S ribosomal protein L35|large ribosomal subunit protein uL29', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124857883, end_position_on_the_genomic_accession=124861957, orientation='minus', exon_count=4, OMIM=[618315], no_hdr0=''),
    11226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11226, CurrentID=0, Status='live', Symbol='GALNT6', Aliases=['GALNAC-T6', 'GalNAcT6'], description='polypeptide N-acetylgalactosaminyltransferase 6', other_designations='polypeptide N-acetylgalactosaminyltransferase 6|GalNAc transferase 6|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 6|UDP-N-acetyl-alpha-D-galactosamine: polypeptide N-acetylgalactosaminyltransferase 6|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 6 (GalNAc-T6)|polypeptide GalNAc transferase 6|pp-GaNTase 6|protein-UDP acetylgalactosaminyltransferase 6', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51351252, end_position_on_the_genomic_accession=51391955, orientation='minus', exon_count=16, OMIM=[605148], no_hdr0=''),
    11227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11227, CurrentID=0, Status='live', Symbol='GALNT5', Aliases=['GALNAC-T5', 'GALNACT5'], description='polypeptide N-acetylgalactosaminyltransferase 5', other_designations='polypeptide N-acetylgalactosaminyltransferase 5|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 5|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 5 (GalNAc-T5)|polypeptide GalNAc transferase 5|pp-GaNTase 5|protein-UDP acetylgalactosaminyltransferase 5', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157257656, end_position_on_the_genomic_accession=157318491, orientation='plus', exon_count=11, OMIM=[615129], no_hdr0=''),
    11228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11228, CurrentID=0, Status='live', Symbol='RASSF8', Aliases=['C12orf2', 'HOJ1'], description='Ras association domain family member 8', other_designations='ras association domain-containing protein 8|Ras association (RalGDS/AF-6) domain family (N-terminal) member 8|carcinoma-associated protein HOJ-1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=25958232, end_position_on_the_genomic_accession=26079889, orientation='plus', exon_count=12, OMIM=[608231], no_hdr0=''),
    11230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11230, CurrentID=0, Status='live', Symbol='PRAF2', Aliases=['JM4', 'Yip6a'], description='PRA1 domain family member 2', other_designations='PRA1 family protein 2|Jena-Muenchen 4', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49071161, end_position_on_the_genomic_accession=49074002, orientation='minus', exon_count=3, OMIM=[300840], no_hdr0=''),
    11231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11231, CurrentID=0, Status='live', Symbol='SEC63', Aliases=['DNAJC23', 'ERdj2', 'PCLD2', 'PRO2507L', 'SEC63'], description='SEC63 homolog, protein translocation regulator', other_designations='translocation protein SEC63 homolog|SEC63 protein translocation regulator|SEC63-like protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107867756, end_position_on_the_genomic_accession=107958208, orientation='minus', exon_count=21, OMIM=[608648], no_hdr0=''),
    11232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11232, CurrentID=0, Status='live', Symbol='POLG2', Aliases=['HP55', 'MTDPS16', 'MTPOLB', 'PEOA4', 'POLB', 'POLG-BETA', 'POLGB'], description='DNA polymerase gamma 2, accessory subunit', other_designations='DNA polymerase subunit gamma-2, mitochondrial|DNA polymerase gamma accessory 55 kDa subunit|mitochondrial DNA polymerase subunit gamma-2|mitochondrial DNA polymerase, accessory subunit|p55|polymerase (DNA directed), gamma 2, accessory subunit|polymerase (DNA) gamma 2, accessory subunit', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64477785, end_position_on_the_genomic_accession=64497054, orientation='minus', exon_count=8, OMIM=[604983], no_hdr0=''),
    11234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11234, CurrentID=0, Status='live', Symbol='HPS5', Aliases=['AIBP63', 'BLOC2S2'], description='HPS5 biogenesis of lysosomal organelles complex 2 subunit 2', other_designations='Hermansky-Pudlak syndrome 5 protein|alpha integrin binding protein 63|ruby-eye protein 2 homolog', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18278670, end_position_on_the_genomic_accession=18322498, orientation='minus', exon_count=24, OMIM=[607521], no_hdr0=''),
    11235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11235, CurrentID=0, Status='live', Symbol='PDCD10', Aliases=['CCM3', 'TFAR15'], description='programmed cell death 10', other_designations='programmed cell death protein 10|TF-1 cell apoptosis-related protein 15|apoptosis-related protein 15|cerebral cavernous malformations 3 protein', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=167683298, end_position_on_the_genomic_accession=167735810, orientation='minus', exon_count=12, OMIM=[609118], no_hdr0=''),
    11236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11236, CurrentID=0, Status='live', Symbol='RNF139', Aliases=['HRCA1', 'RCA1', 'TRC8'], description='ring finger protein 139', other_designations='E3 ubiquitin-protein ligase RNF139|RING-type E3 ubiquitin transferase RNF139|multiple membrane spanning receptor TRC8|patched related protein translocated in renal cancer|translocation in renal carcinoma on chromosome 8 protein|translocation in renal carcinoma, chromosome 8', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124474880, end_position_on_the_genomic_accession=124488618, orientation='plus', exon_count=2, OMIM=[603046], no_hdr0=''),
    11237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11237, CurrentID=0, Status='live', Symbol='RNF24', Aliases=['G1L'], description='ring finger protein 24', other_designations='RING finger protein 24', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3927311, end_position_on_the_genomic_accession=4015588, orientation='minus', exon_count=10, OMIM=[612489], no_hdr0=''),
    11238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11238, CurrentID=0, Status='live', Symbol='CA5B', Aliases=['CA-VB', 'CAVB'], description='carbonic anhydrase 5B', other_designations='carbonic anhydrase 5B, mitochondrial|carbonate dehydratase VB|carbonic anhydrase VB, mitochondrial|carbonic dehydratase', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15738270, end_position_on_the_genomic_accession=15788411, orientation='plus', exon_count=8, OMIM=[300230], no_hdr0=''),
    11240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11240, CurrentID=0, Status='live', Symbol='PADI2', Aliases=['PAD-H19', 'PAD2', 'PDI2'], description='peptidyl arginine deiminase 2', other_designations='protein-arginine deiminase type-2|peptidyl arginine deiminase, type II|protein-arginine deiminase type II', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17066761, end_position_on_the_genomic_accession=17119453, orientation='minus', exon_count=17, OMIM=[607935], no_hdr0=''),
    11243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11243, CurrentID=0, Status='live', Symbol='PMF1', Aliases=[], description='polyamine modulated factor 1', other_designations='polyamine-modulated factor 1|Est1p-like protein B (EST1B)', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156213007, end_position_on_the_genomic_accession=156240042, orientation='plus', exon_count=6, OMIM=[609176], no_hdr0=''),
    11244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11244, CurrentID=0, Status='live', Symbol='ZHX1', Aliases=[], description='zinc fingers and homeoboxes 1', other_designations='zinc fingers and homeoboxes protein 1|zinc finger and homeodomain protein 1|zinc fingers and homeobox 1', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123248456, end_position_on_the_genomic_accession=123275541, orientation='minus', exon_count=5, OMIM=[604764], no_hdr0=''),
    11245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11245, CurrentID=0, Status='live', Symbol='GPR176', Aliases=['HB-954'], description='G protein-coupled receptor 176', other_designations='G-protein coupled receptor 176|probable G-protein coupled receptor 176', map_location='15q14-q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=39795049, end_position_on_the_genomic_accession=39920939, orientation='minus', exon_count=10, OMIM=[612183], no_hdr0=''),
    11247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11247, CurrentID=0, Status='live', Symbol='NXPH4', Aliases=['NPH4'], description='neurexophilin 4', other_designations='neurexophilin-4|alternative protein NXPH4', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57216794, end_position_on_the_genomic_accession=57226449, orientation='plus', exon_count=2, OMIM=[604637], no_hdr0=''),
    11248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11248, CurrentID=0, Status='live', Symbol='NXPH3', Aliases=['NPH3'], description='neurexophilin 3', other_designations='neurexophilin-3', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49575871, end_position_on_the_genomic_accession=49583827, orientation='plus', exon_count=2, OMIM=[604636], no_hdr0=''),
    11249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11249, CurrentID=0, Status='live', Symbol='NXPH2', Aliases=['NPH2'], description='neurexophilin 2', other_designations='neurexophilin-2', map_location='2q22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=138669157, end_position_on_the_genomic_accession=138780390, orientation='minus', exon_count=2, OMIM=[604635], no_hdr0=''),
    11250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11250, CurrentID=0, Status='live', Symbol='GPR45', Aliases=['PSP24', 'PSP24(ALPHA)', 'PSP24A'], description='G protein-coupled receptor 45', other_designations='probable G-protein coupled receptor 45|PSP24-1|PSP24-alpha|high-affinity lysophosphatidic acid receptor', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105241743, end_position_on_the_genomic_accession=105243467, orientation='plus', exon_count=1, OMIM=[604838], no_hdr0=''),
    11251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11251, CurrentID=0, Status='live', Symbol='PTGDR2', Aliases=['CD294', 'CRTH2', 'DL1R', 'DP2', 'GPR44'], description='prostaglandin D2 receptor 2', other_designations='prostaglandin D2 receptor 2|G-protein coupled receptor 44|chemoattractant receptor homologous molecule expressed on T helper type 2 cells|chemoattractant receptor-homologous molecule expressed on TH2 cells|putative G-protein coupled receptor 44', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60850933, end_position_on_the_genomic_accession=60855950, orientation='minus', exon_count=2, OMIM=[604837], no_hdr0=''),
    11252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11252, CurrentID=0, Status='live', Symbol='PACSIN2', Aliases=['SDPII'], description='protein kinase C and casein kinase substrate in neurons 2', other_designations='protein kinase C and casein kinase substrate in neurons protein 2|cytoplasmic phosphoprotein PACSIN2|syndapin-2|syndapin-II|syndapin2', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42869766, end_position_on_the_genomic_accession=43015149, orientation='minus', exon_count=15, OMIM=[604960], no_hdr0=''),
    11253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11253, CurrentID=0, Status='live', Symbol='MAN1B1', Aliases=['ERMAN1', 'ERManI', 'MANA-ER', 'MRT15'], description='mannosidase alpha class 1B member 1', other_designations='endoplasmic reticulum mannosyl-oligosaccharide 1,2-alpha-mannosidase|ER alpha 1,2-mannosidase|Man9GlcNAc2-specific processing alpha-mannosidase|endoplasmic Reticulum Class I alpha-mannosidase|endoplasmic reticulum mannosyl-oligosaccharide 1,2-alpha-mannosidase 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137086941, end_position_on_the_genomic_accession=137109183, orientation='plus', exon_count=14, OMIM=[604346], no_hdr0=''),
    11254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11254, CurrentID=0, Status='live', Symbol='SLC6A14', Aliases=['BMIQ11'], description='solute carrier family 6 member 14', other_designations='sodium- and chloride-dependent neutral and basic amino acid transporter B(0+)|amino acid transporter ATB0+|amino acid transporter B0+|solute carrier family 6 (amino acid transporter), member 14|solute carrier family 6 (neurotransmitter transporter), member 14', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=116436606, end_position_on_the_genomic_accession=116461458, orientation='plus', exon_count=14, OMIM=[300444], no_hdr0=''),
    11255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11255, CurrentID=0, Status='live', Symbol='HRH3', Aliases=['GPCR97', 'HH3R'], description='histamine receptor H3', other_designations='histamine H3 receptor|G protein-coupled receptor 97|H3R', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62213845, end_position_on_the_genomic_accession=62220278, orientation='minus', exon_count=4, OMIM=[604525], no_hdr0=''),
    11258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11258, CurrentID=0, Status='live', Symbol='DCTN3', Aliases=['DCTN-22', 'DCTN22'], description='dynactin subunit 3', other_designations='dynactin subunit 3|dynactin 3 (p22)|dynactin complex subunit 22 kDa subunit|dynactin light chain', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34613546, end_position_on_the_genomic_accession=34620518, orientation='minus', exon_count=7, OMIM=[607387], no_hdr0=''),
    11259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11259, CurrentID=0, Status='live', Symbol='FILIP1L', Aliases=['DOC-1', 'DOC1', 'GIP130', 'GIP90'], description='filamin A interacting protein 1 like', other_designations='filamin A-interacting protein 1-like|130 kDa GPBP-interacting protein|90 kDa GPBP-interacting protein|protein down-regulated in ovarian cancer 1', map_location='3q12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=99828811, end_position_on_the_genomic_accession=100114501, orientation='minus', exon_count=10, OMIM=[612993], no_hdr0=''),
    11260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11260, CurrentID=0, Status='live', Symbol='XPOT', Aliases=['XPO3'], description='exportin for tRNA', other_designations='exportin-T|exportin(tRNA)|exportin, tRNA (nuclear export receptor for tRNAs)|tRNA exportin', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64404392, end_position_on_the_genomic_accession=64451125, orientation='plus', exon_count=26, OMIM=[603180], no_hdr0=''),
    11261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11261, CurrentID=0, Status='live', Symbol='CHP1', Aliases=['CHP', 'SLC9A1BP', 'SPAX9', 'Sid470p', 'p22', 'p24'], description='calcineurin like EF-hand protein 1', other_designations='calcineurin B homologous protein 1|EF-hand calcium-binding domain-containing protein p22|SLC9A1 binding protein|calcineurin B homolog|calcineurin B-like protein|calcineurin homologous protein|calcium binding protein P22|calcium-binding protein CHP|calcium-binding protein p22', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41231156, end_position_on_the_genomic_accession=41281887, orientation='plus', exon_count=8, OMIM=[606988], no_hdr0=''),
    11262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11262, CurrentID=0, Status='live', Symbol='SP140', Aliases=['LYSP100', 'LYSP100-A', 'LYSP100-B'], description='SP140 nuclear body protein', other_designations='nuclear body protein SP140|lymphoid-restricted homolog of Sp100|lymphoid-specific SP100 homolog|nuclear autoantigen Sp-140|speckled 140 kDa', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230202743, end_position_on_the_genomic_accession=230316571, orientation='plus', exon_count=34, OMIM=[608602], no_hdr0=''),
    11264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11264, CurrentID=0, Status='live', Symbol='PXMP4', Aliases=['PMP24'], description='peroxisomal membrane protein 4', other_designations='peroxisomal membrane protein 4|24 kDa peroxisomal intrinsic membrane protein|peroxisomal membrane protein 4, 24kDa', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33702758, end_position_on_the_genomic_accession=33720310, orientation='minus', exon_count=4, OMIM=[616397], no_hdr0=''),
    11266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11266, CurrentID=0, Status='live', Symbol='DUSP12', Aliases=['DUSP1', 'YVH1'], description='dual specificity phosphatase 12', other_designations='dual specificity protein phosphatase 12|YVH1 protein-tyrosine phosphatase ortholog|dual specificity tyrosine phosphatase YVH1|serine/threonine specific protein phosphatase', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161749786, end_position_on_the_genomic_accession=161757238, orientation='plus', exon_count=6, OMIM=[604835], no_hdr0=''),
    11267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11267, CurrentID=0, Status='live', Symbol='SNF8', Aliases=['Dot3', 'EAP30', 'VPS22'], description='SNF8 subunit of ESCRT-II', other_designations='vacuolar-sorting protein SNF8|EAP30 subunit of ELL complex|ELL-associated protein of 30 kDa|ESCRT-II complex subunit VPS22|SNF8, ESCRT-II complex subunit, homolog', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48929316, end_position_on_the_genomic_accession=48944842, orientation='minus', exon_count=10, OMIM=[610904], no_hdr0=''),
    11269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11269, CurrentID=0, Status='live', Symbol='DDX19B', Aliases=['DBP5', 'DDX19', 'RNAh'], description='DEAD-box helicase 19B', other_designations='ATP-dependent RNA helicase DDX19B|ATP-dependent RNA helicase DDX19|DEAD (Asp-Glu-Ala-As) box polypeptide 19B|DEAD (Asp-Glu-Ala-Asp) box polypeptide 19B|DEAD box protein 19B|DEAD-box RNA helicase DEAD5|DEAD-box protein 5|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 19 (Dbp5, yeast, homolog)|yeast Dbp5 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70289767, end_position_on_the_genomic_accession=70335305, orientation='plus', exon_count=14, OMIM=[605812], no_hdr0=''),
    11270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11270, CurrentID=0, Status='live', Symbol='NRM', Aliases=['NRM29'], description='nurim', other_designations='nurim|nuclear rim protein|nurim (nuclear envelope membrane protein)', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30688047, end_position_on_the_genomic_accession=30691420, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    11272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11272, CurrentID=0, Status='live', Symbol='PRR4', Aliases=['LPRP', 'PROL4'], description='proline rich 4', other_designations='proline-rich protein 4|lacrimal proline-rich protein|nasopharyngeal carcinoma-associated proline-rich protein 4|proline rich 4 (lacrimal)|proline-rich polypeptide 4', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10845849, end_position_on_the_genomic_accession=10849475, orientation='minus', exon_count=4, OMIM=[605359], no_hdr0=''),
    11273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11273, CurrentID=0, Status='live', Symbol='ATXN2L', Aliases=['A2D', 'A2LG', 'A2LP', 'A2RP'], description='ataxin 2 like', other_designations='ataxin-2-like protein|ataxin 2 related protein|ataxin-2 domain protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28822999, end_position_on_the_genomic_accession=28837237, orientation='plus', exon_count=26, OMIM=[607931], no_hdr0=''),
    11274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11274, CurrentID=0, Status='live', Symbol='USP18', Aliases=['ISG43', 'PTORCH2', 'UBP43'], description='ubiquitin specific peptidase 18', other_designations='ubl carboxyl-terminal hydrolase 18|43 kDa ISG15-specific protease|ISG15-specific-processing protease|ubiquitin specific protease 18|ubl thioesterase 18|ubl thiolesterase 18', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18149855, end_position_on_the_genomic_accession=18177397, orientation='plus', exon_count=11, OMIM=[607057], no_hdr0=''),
    11275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11275, CurrentID=0, Status='live', Symbol='KLHL2', Aliases=['ABP-KELCH', 'MAV', 'MAYVEN'], description='kelch like family member 2', other_designations='kelch-like protein 2|actin-binding protein Mayven|kelch-like 2, Mayven', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165207561, end_position_on_the_genomic_accession=165323156, orientation='plus', exon_count=21, OMIM=[605774], no_hdr0=''),
    11276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11276, CurrentID=0, Status='live', Symbol='SYNRG', Aliases=['AP1GBP1', 'SYNG'], description='synergin gamma', other_designations='synergin gamma|AP1 gamma subunit binding protein 1|AP1 subunit gamma-binding protein 1|adaptor-related protein complex 1 gamma subunit-binding protein 1|gamma-synergin', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37514807, end_position_on_the_genomic_accession=37609496, orientation='minus', exon_count=26, OMIM=[607291], no_hdr0=''),
    11277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11277, CurrentID=0, Status='live', Symbol='TREX1', Aliases=['AGS1', 'CRV', 'DRN3', 'HERNS', 'RVCLS'], description='three prime repair exonuclease 1', other_designations="three-prime repair exonuclease 1|3' repair exonuclease 1|3'-5' exonuclease TREX1|DNase III|deoxyribonuclease III", map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48465830, end_position_on_the_genomic_accession=48467645, orientation='plus', exon_count=3, OMIM=[606609], no_hdr0=''),
    11278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11278, CurrentID=0, Status='live', Symbol='KLF12', Aliases=['AP-2rep', 'AP2REP', 'HSPC122'], description='Kruppel like factor 12', other_designations='Krueppel-like factor 12|AP-2 repressor|AP-2rep transcription factor|KLF12 zinc finger transcriptional repressor|transcriptional repressor AP-2rep', map_location='13q22.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=73686089, end_position_on_the_genomic_accession=74168295, orientation='minus', exon_count=16, OMIM=[607531], no_hdr0=''),
    11279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11279, CurrentID=0, Status='live', Symbol='KLF8', Aliases=['BKLF3', 'ZNF741'], description='Kruppel like factor 8', other_designations='Krueppel-like factor 8|basic krueppel-like factor 3|basic kruppel-like factor 3|zinc finger protein 741', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55908123, end_position_on_the_genomic_accession=56291531, orientation='plus', exon_count=7, OMIM=[300286], no_hdr0=''),
    11280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11280, CurrentID=0, Status='live', Symbol='SCN11A', Aliases=['FEPS3', 'HSAN7', 'NAV1.9', 'NaN', 'PN5', 'SCN12A', 'SNS-2'], description='sodium voltage-gated channel alpha subunit 11', other_designations='sodium channel protein type 11 subunit alpha|peripheral nerve sodium channel 5|sensory neuron sodium channel 2|sodium channel protein type XI subunit alpha|sodium channel, voltage-gated, type XI, alpha polypeptide|sodium channel, voltage-gated, type XI, alpha subunit|sodium channel, voltage-gated, type XII, alpha polypeptide|voltage-gated sodium channel subunit alpha Nav1.9', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=38845764, end_position_on_the_genomic_accession=39051944, orientation='minus', exon_count=37, OMIM=[604385], no_hdr0=''),
    11281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11281, CurrentID=0, Status='live', Symbol='POU6F2', Aliases=['RPF-1', 'WT5', 'WTSL'], description='POU class 6 homeobox 2', other_designations='POU domain, class 6, transcription factor 2|Wilms tumor suppressor locus|retina-derived POU-domain factor-1', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38977909, end_position_on_the_genomic_accession=39468601, orientation='plus', exon_count=11, OMIM=[609062], no_hdr0=''),
    11282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11282, CurrentID=0, Status='live', Symbol='MGAT4B', Aliases=['GNT-IV', 'GNT-IVB'], description='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase B', other_designations='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase B|N-acetylglucosaminyltransferase IVb|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase IVb|UDP-N-acetylglucosamine: alpha-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IV|UDP-N-acetylglucosamine: alpha-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IVb|alpha-1,3-mannosyl-glycoprotein beta-1,4-N-acetylglucosaminyltransferase|aminyltransferase|glcNAc-T IVb|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase, isoenzyme B|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase, isozyme B', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179797597, end_position_on_the_genomic_accession=179806977, orientation='minus', exon_count=15, OMIM=[604561], no_hdr0=''),
    11283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11283, CurrentID=0, Status='live', Symbol='CYP4F8', Aliases=['CPF8', 'CYPIVF8'], description='cytochrome P450 family 4 subfamily F member 8', other_designations='cytochrome P450 4F8|cytochrome P450, family 4, subfamily F, polypeptide 8|cytochrome P450, subfamily IVF, polypeptide 8|flavoprotein-linked monooxygenase|microsomal monooxygenase', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15615207, end_position_on_the_genomic_accession=15630639, orientation='plus', exon_count=13, OMIM=[611545], no_hdr0=''),
    11284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11284, CurrentID=0, Status='live', Symbol='PNKP', Aliases=['AOA4', 'CMT2B2', 'EIEE10', 'MCSZ', 'PNK'], description="polynucleotide kinase 3'-phosphatase", other_designations="bifunctional polynucleotide phosphatase/kinase|DNA 5'-kinase/3'-phosphatase|Homo sapiens polynucleotide kinase 3'-phosphatase (PNKP)", map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49861204, end_position_on_the_genomic_accession=49867576, orientation='minus', exon_count=17, OMIM=[605610], no_hdr0=''),
    11285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11285, CurrentID=0, Status='live', Symbol='B4GALT7', Aliases=['EDSP1', 'EDSSLA', 'EDSSPD1', 'XGALT1', 'XGPT', 'XGPT1'], description='beta-1,4-galactosyltransferase 7', other_designations='beta-1,4-galactosyltransferase 7|UDP-Gal:beta-GlcNAc beta-1,4-galactosyltransferase 7|UDP-galactose:beta-N-acetylglucosamine beta-1,4-galactosyltransferase 7|UDP-galactose:beta-xylose beta-1,4-galactosyltransferase|beta-1,4-GalTase 7|beta-1,4-galactosyltransferase VII|beta4Gal-T7|beta4GalT-VII|galactosyltransferase I|proteoglycan UDP-galactose:beta-xylose beta1,4-galactosyltransferase I|xylosylprotein 4-beta-galactosyltransferase|xylosylprotein beta 1,4-galactosyltransferase, polypeptide 7|xylosylprotein beta-1,4-galactosyltransferase', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177600102, end_position_on_the_genomic_accession=177610330, orientation='plus', exon_count=7, OMIM=[604327], no_hdr0=''),
    11309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11309, CurrentID=0, Status='live', Symbol='SLCO2B1', Aliases=['OATP-B', 'OATP2B1', 'OATPB', 'SLC21A9'], description='solute carrier organic anion transporter family member 2B1', other_designations='solute carrier organic anion transporter family member 2B1|OATP-RP2|organic anion transporter B|organic anion transporter polypeptide-related protein 2|solute carrier family 21 (organic anion transporter), member 9', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75151107, end_position_on_the_genomic_accession=75206549, orientation='plus', exon_count=16, OMIM=[604988], no_hdr0=''),
    11311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11311, CurrentID=0, Status='live', Symbol='VPS45', Aliases=['H1', 'H1VPS45', 'SCN5A', 'VPS45B', 'VPS54A', 'VSP45', 'VSP45A', 'VPS45'], description='vacuolar protein sorting 45 homolog', other_designations='vacuolar protein sorting-associated protein 45|leucocyte vacuolar protein sorting 45|vacuolar protein sorting 45A', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150067279, end_position_on_the_genomic_accession=150145329, orientation='plus', exon_count=18, OMIM=[610035], no_hdr0=''),
    11313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11313, CurrentID=0, Status='live', Symbol='LYPLA2', Aliases=['APT-2', 'APT2', 'DJ886K2.4'], description='lysophospholipase 2', other_designations='acyl-protein thioesterase 2|LPL-II|lysoPLA II|lysophospholipase II|testicular tissue protein Li 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23790789, end_position_on_the_genomic_accession=23795539, orientation='plus', exon_count=9, OMIM=[616143], no_hdr0=''),
    11314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11314, CurrentID=0, Status='live', Symbol='CD300A', Aliases=['CLM-8', 'CMRF-35-H9', 'CMRF-35H', 'CMRF35-H', 'CMRF35-H9', 'CMRF35H', 'CMRF35H9', 'IGSF12', 'IRC1', 'IRC1/IRC2', 'IRC2', 'IRp60'], description='CD300a molecule', other_designations='CMRF35-like molecule 8|CD300 antigen-like family member A|CD300a antigen|CMRF35H leukocyte immunoglobulin-like receptor|NK inhibitory receptor|immunoglobulin superfamily member 12|inhibitory receptor protein 60|leukocyte membrane antigen', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74466373, end_position_on_the_genomic_accession=74484798, orientation='plus', exon_count=8, OMIM=[606790], no_hdr0=''),
    11315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11315, CurrentID=0, Status='live', Symbol='PARK7', Aliases=['DJ-1', 'DJ1', 'GATD2', 'HEL-S-67p'], description='Parkinsonism associated deglycase', other_designations='Parkinson disease protein 7|Parkinson disease (autosomal recessive, early onset) 7|epididymis secretory sperm binding protein Li 67p|maillard deglycase|oncogene DJ1|parkinson protein 7|protein DJ-1|protein deglycase DJ-1|protein/nucleic acid deglycase DJ-1', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=7961711, end_position_on_the_genomic_accession=7985505, orientation='plus', exon_count=8, OMIM=[602533], no_hdr0=''),
    11316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11316, CurrentID=0, Status='live', Symbol='COPE', Aliases=['epsilon-COP'], description='COPI coat complex subunit epsilon', other_designations='coatomer subunit epsilon|coatomer epsilon subunit|coatomer protein complex subunit epsilon|epsilon coat protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18899514, end_position_on_the_genomic_accession=18919387, orientation='minus', exon_count=11, OMIM=[606942], no_hdr0=''),
    11317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11317, CurrentID=0, Status='live', Symbol='RBPJL', Aliases=['RBPL', 'RBPSUHL', 'SUHL'], description='recombination signal binding protein for immunoglobulin kappa J region like', other_designations='recombining binding protein suppressor of hairless-like protein|transcription factor RBP-L', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45306836, end_position_on_the_genomic_accession=45319677, orientation='plus', exon_count=13, OMIM=[616104], no_hdr0=''),
    11318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11318, CurrentID=0, Status='live', Symbol='GPR182', Aliases=['7TMR', 'ADMR', 'AM-R', 'AMR', 'G10D', 'L1-R', 'gamrh', 'hrhAMR'], description='G protein-coupled receptor 182', other_designations='G-protein coupled receptor 182|adrenomedullin receptor', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56993590, end_position_on_the_genomic_accession=56998447, orientation='plus', exon_count=3, OMIM=[605307], no_hdr0=''),
    11319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11319, CurrentID=0, Status='live', Symbol='ECD', Aliases=['GCR2', 'HSGT1', 'SGT1'], description='ecdysoneless cell cycle regulator', other_designations='protein ecdysoneless homolog|ecdysoneless homolog|human suppressor of GCR two|protein SGT1|suppressor of GCR2|suppressor of S. cerevisiae gcr2', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73133668, end_position_on_the_genomic_accession=73168095, orientation='minus', exon_count=15, OMIM=[616464], no_hdr0=''),
    11320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11320, CurrentID=0, Status='live', Symbol='MGAT4A', Aliases=['GNT-IV', 'GNT-IVA', 'GnT-4a'], description='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase A', other_designations='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase A|N-acetylglucosaminyltransferase IVa|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase IVa|UDP-GlcNAc:a-1,3-D-mannoside b-1,4-acetylglucosaminyltransferase IV|UDP-N-acetylglucosamine: alpha-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IVa|UDP-N-acetylglucosamine:alpha1,3-d-mannoside beta1,4-N-acetylglucosaminyltransferase|alpha-1,3-mannosyl-glycoprotein beta-1,4-N-acetylglucosaminyltransferase|glcNAc-T IVa|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase, isoenzyme A|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase, isozyme A', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98619106, end_position_on_the_genomic_accession=98731132, orientation='minus', exon_count=17, OMIM=[604623], no_hdr0=''),
    11321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11321, CurrentID=0, Status='live', Symbol='GPN1', Aliases=['ATPBD1A', 'MBDIN', 'NTPBP', 'RPAP4', 'XAB1'], description='GPN-loop GTPase 1', other_designations='GPN-loop GTPase 1|ATP(GTP)-binding protein|MBD2-interacting protein|RNA polymerase II associated protein 4|RNAPII-associated protein 4|XPA binding protein 1, GTPase', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27628247, end_position_on_the_genomic_accession=27651511, orientation='plus', exon_count=16, OMIM=[611479], no_hdr0=''),
    11322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11322, CurrentID=0, Status='live', Symbol='TMC6', Aliases=['EV1', 'EVER1', 'EVIN1', 'LAK-4P', 'TNRC6C-AS1', 'lnc'], description='transmembrane channel like 6', other_designations='transmembrane channel-like protein 6|TNRC6C antisense RNA 1|epidermodysplasia verruciformis 1|epidermodysplasia verruciformis protein 1|expressed in activated T/LAK lymphocytes|protein LAK-4', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78107397, end_position_on_the_genomic_accession=78132427, orientation='minus', exon_count=24, OMIM=[605828], no_hdr0=''),
    11325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11325, CurrentID=0, Status='live', Symbol='DDX42', Aliases=['DDX42P', 'RHELP', 'RNAHP', 'SF3B8', 'SF3b125'], description='DEAD-box helicase 42', other_designations='ATP-dependent RNA helicase DDX42|DEAD (Asp-Glu-Ala-Asp) box helicase 42|DEAD (Asp-Glu-Ala-Asp) box polypeptide 42|SF3b DEAD box protein|splicing factor 3B-associated 125 kDa protein|splicing factor 3b, subunit 8', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63773856, end_position_on_the_genomic_accession=63819317, orientation='plus', exon_count=20, OMIM=[613369], no_hdr0=''),
    11326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11326, CurrentID=0, Status='live', Symbol='VSIG4', Aliases=['CRIg', 'Z39IG'], description='V-set and immunoglobulin domain containing 4', other_designations='V-set and immunoglobulin domain-containing protein 4|Ig superfamily protein|complement receptor of the immunoglobulin superfamily|protein Z39Ig', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=66021738, end_position_on_the_genomic_accession=66040092, orientation='minus', exon_count=8, OMIM=[300353], no_hdr0=''),
    11328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11328, CurrentID=0, Status='live', Symbol='FKBP9', Aliases=['FKBP60', 'FKBP63', 'PPIase'], description='FKBP prolyl isomerase 9', other_designations='peptidyl-prolyl cis-trans isomerase FKBP9|63 kDa FK506-binding protein|63 kDa FKBP|FK506 binding protein 9, 63 kDa|FK506-binding protein 9|FKBP-63|FKBP-9|PPIase FKBP9|rotamase', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=32957427, end_position_on_the_genomic_accession=33006928, orientation='plus', exon_count=13, OMIM=[616257], no_hdr0=''),
    11329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11329, CurrentID=0, Status='live', Symbol='STK38', Aliases=['NDR', 'NDR1'], description='serine/threonine kinase 38', other_designations='serine/threonine-protein kinase 38|NDR1 protein kinase|Ndr Ser/Thr kinase-like protein|nuclear Dbf2-related kinase 1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36493889, end_position_on_the_genomic_accession=36547479, orientation='minus', exon_count=15, OMIM=[606964], no_hdr0=''),
    11330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11330, CurrentID=0, Status='live', Symbol='CTRC', Aliases=['CLCR', 'ELA4'], description='chymotrypsin C', other_designations='chymotrypsin-C|caldecrin|elastase 4|elastase IV|serum calcium decreasing factor', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15438442, end_position_on_the_genomic_accession=15449247, orientation='plus', exon_count=8, OMIM=[601405], no_hdr0=''),
    11331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11331, CurrentID=0, Status='live', Symbol='PHB2', Aliases=['BAP', 'BCAP37', 'Bap37', 'PNAS-141', 'REA', 'hBAP', 'p22'], description='prohibitin 2', other_designations='prohibitin-2|B cell receptor associated protein 37|B-cell associated protein|B-cell receptor-associated protein BAP37|D-prohibitin|repressor of estrogen receptor activity', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6965327, end_position_on_the_genomic_accession=6970753, orientation='minus', exon_count=10, OMIM=[610704], no_hdr0=''),
    11332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11332, CurrentID=0, Status='live', Symbol='ACOT7', Aliases=['ACH1', 'ACT', 'BACH', 'CTE-II', 'LACH', 'LACH1', 'hBACH'], description='acyl-CoA thioesterase 7', other_designations='cytosolic acyl coenzyme A thioester hydrolase|CTE-IIa|acyl-CoA thioesterase 2|acyl-CoA thioesterase, long chain|brain acyl-CoA hydrolase|long chain acyl-CoA thioester hydrolase', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6264272, end_position_on_the_genomic_accession=6393767, orientation='minus', exon_count=12, OMIM=[602587], no_hdr0=''),
    11333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11333, CurrentID=0, Status='live', Symbol='PDAP1', Aliases=['HASPP28', 'PAP', 'PAP1'], description='PDGFA associated protein 1', other_designations='28 kDa heat- and acid-stable phosphoprotein|PDGF-associated protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99394673, end_position_on_the_genomic_accession=99408597, orientation='minus', exon_count=6, OMIM=[607075], no_hdr0=''),
    11334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11334, CurrentID=0, Status='live', Symbol='TUSC2', Aliases=['C3orf11', 'FUS1', 'PAP', 'PDAP2'], description='tumor suppressor 2, mitochondrial calcium regulator', other_designations='tumor suppressor candidate 2|PDGFA-associated protein 2|fus-1 protein|fusion 1 protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50324909, end_position_on_the_genomic_accession=50328223, orientation='minus', exon_count=3, OMIM=[607052], no_hdr0=''),
    11335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11335, CurrentID=0, Status='live', Symbol='CBX3', Aliases=['HECH', 'HP1-GAMMA', 'HP1Hs-gamma'], description='chromobox 3', other_designations='chromobox protein homolog 3|HP1 gamma homolog|chromobox homolog 3 (HP1 gamma homolog, Drosophila)|heterochromatin protein 1 homolog gamma|heterochromatin protein HP1 gamma|heterochromatin-like protein 1|modifier 2 protein', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=26201443, end_position_on_the_genomic_accession=26213607, orientation='plus', exon_count=7, OMIM=[604477], no_hdr0=''),
    11336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11336, CurrentID=0, Status='live', Symbol='EXOC3', Aliases=['SEC6', 'SEC6L1', 'Sec6p'], description='exocyst complex component 3', other_designations='exocyst complex component 3|SEC6-like 1|Sec 6 homolog|exocyst complex component Sec6', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=443176, end_position_on_the_genomic_accession=467290, orientation='plus', exon_count=13, OMIM=[608186], no_hdr0=''),
    11337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11337, CurrentID=0, Status='live', Symbol='GABARAP', Aliases=['ATG8A-a', 'MM46', 'GABARAP'], description='GABA type A receptor-associated protein', other_designations='gamma-aminobutyric acid receptor-associated protein|GABA(A) receptor-associated protein|epididymis secretory sperm binding protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7240008, end_position_on_the_genomic_accession=7242449, orientation='minus', exon_count=4, OMIM=[605125], no_hdr0=''),
    11338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11338, CurrentID=0, Status='live', Symbol='U2AF2', Aliases=['U2AF65'], description='U2 small nuclear RNA auxiliary factor 2', other_designations='splicing factor U2AF 65 kDa subunit|U2 (RNU2) small nuclear RNA auxiliary factor 2|U2 auxiliary factor 65 kDa subunit|U2 small nuclear ribonucleoprotein auxiliary factor (65kD)|U2 snRNP auxiliary factor large subunit|hU2AF65', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55654132, end_position_on_the_genomic_accession=55674716, orientation='plus', exon_count=14, OMIM=[191318], no_hdr0=''),
    11339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11339, CurrentID=0, Status='live', Symbol='OIP5', Aliases=['5730547N13Rik', 'CT86', 'LINT-25', 'MIS18B', 'MIS18beta', 'hMIS18beta'], description='Opa interacting protein 5', other_designations='protein Mis18-beta|LAP2alpha interactor-25|MIS18 kinetochore protein homolog B|cancer/testis antigen 86|opa-interacting protein 5', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41309273, end_position_on_the_genomic_accession=41332591, orientation='minus', exon_count=5, OMIM=[606020], no_hdr0=''),
    11340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11340, CurrentID=0, Status='live', Symbol='EXOSC8', Aliases=['CIP3', 'EAP2', 'OIP2', 'PCH1C', 'RRP43', 'Rrp43p', 'bA421P11.3', 'p9'], description='exosome component 8', other_designations='exosome complex component RRP43|CBP-interacting protein 3|OIP-2|Opa interacting protein 2|exosome complex exonuclease RRP43|ribosomal RNA-processing protein 43', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=37000373, end_position_on_the_genomic_accession=37009614, orientation='plus', exon_count=12, OMIM=[606019], no_hdr0=''),
    11341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11341, CurrentID=0, Status='live', Symbol='SCRG1', Aliases=['SCRG-1'], description='stimulator of chondrogenesis 1', other_designations='scrapie-responsive protein 1|scrapie responsive gene 1|scrapie-responsive gene 1 protein', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=173384701, end_position_on_the_genomic_accession=173519144, orientation='minus', exon_count=5, OMIM=[603163], no_hdr0=''),
    11342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11342, CurrentID=0, Status='live', Symbol='RNF13', Aliases=['DEE73', 'EIEE73', 'RZF'], description='ring finger protein 13', other_designations='E3 ubiquitin-protein ligase RNF13|RING zinc finger protein|RING-type E3 ubiquitin transferase RNF13', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149812688, end_position_on_the_genomic_accession=149962139, orientation='plus', exon_count=16, OMIM=[609247], no_hdr0=''),
    11343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11343, CurrentID=0, Status='live', Symbol='MGLL', Aliases=['HU-K5', 'HUK5', 'MAGL', 'MGL'], description='monoglyceride lipase', other_designations='monoglyceride lipase|lysophospholipase homolog|monoacylglycerol lipase', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127689066, end_position_on_the_genomic_accession=127823185, orientation='minus', exon_count=13, OMIM=[609699], no_hdr0=''),
    11344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11344, CurrentID=0, Status='live', Symbol='TWF2', Aliases=['A6RP', 'A6r', 'MSTP011', 'PTK9L'], description='twinfilin actin binding protein 2', other_designations='twinfilin-2|A6-related protein|PTK9L protein tyrosine kinase 9-like (A6-related protein)|protein tyrosine kinase 9-like (A6-related protein)|twinfilin, actin-binding protein, homolog 2|twinfilin-1-like protein', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52228612, end_position_on_the_genomic_accession=52239158, orientation='minus', exon_count=9, OMIM=[607433], no_hdr0=''),
    11345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11345, CurrentID=0, Status='live', Symbol='GABARAPL2', Aliases=['ATG8', 'ATG8C', 'GATE-16', 'GATE16', 'GEF-2', 'GEF2'], description='GABA type A receptor associated protein like 2', other_designations='gamma-aminobutyric acid receptor-associated protein-like 2|GABA(A) receptor-associated protein-like 2|MAP1 light chain 3 related protein|ganglioside expression factor 2|general protein transport factor p16|golgi-associated ATPase enhancer of 16 kDa', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75566379, end_position_on_the_genomic_accession=75577881, orientation='plus', exon_count=4, OMIM=[607452], no_hdr0=''),
    11346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=11346, CurrentID=0, Status='live', Symbol='SYNPO', Aliases=[], description='synaptopodin', other_designations='synaptopodin', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150586026, end_position_on_the_genomic_accession=150659214, orientation='plus', exon_count=11, OMIM=[608155], no_hdr0=''),
    22794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22794, CurrentID=0, Status='live', Symbol='CASC3', Aliases=['BTZ', 'MLN51'], description='CASC3 exon junction complex subunit', other_designations='protein CASC3|MLN 51|barentsz|cancer susceptibility 3|cancer susceptibility candidate 3|cancer susceptibility candidate gene 3 protein|metastatic lymph node 51|metastatic lymph node gene 51 protein|protein barentsz', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40140506, end_position_on_the_genomic_accession=40172172, orientation='plus', exon_count=14, OMIM=[606504], no_hdr0=''),
    22795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22795, CurrentID=0, Status='live', Symbol='NID2', Aliases=['NID-2'], description='nidogen 2', other_designations='nidogen-2|osteonidogen', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52004809, end_position_on_the_genomic_accession=52069059, orientation='minus', exon_count=22, OMIM=[605399], no_hdr0=''),
    22796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22796, CurrentID=0, Status='live', Symbol='COG2', Aliases=['CDG2Q', 'LDLC'], description='component of oligomeric golgi complex 2', other_designations='conserved oligomeric Golgi complex subunit 2|COG complex subunit 2|brefeldin A-sensitive, peripheral Golgi protein|conserved oligomeric Golgi complex protein 2|low density lipoprotein receptor defect C complementing|low density lipoprotein receptor defect C-complementing protein', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230642481, end_position_on_the_genomic_accession=230693982, orientation='plus', exon_count=18, OMIM=[606974], no_hdr0=''),
    22797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22797, CurrentID=0, Status='live', Symbol='TFEC', Aliases=['TCFEC', 'TFE-C-L', 'TFECL', 'bHLHe34', 'hTFEC-L', 'TFEC'], description='transcription factor EC', other_designations='transcription factor EC|class E basic helix-loop-helix protein 34', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=115935152, end_position_on_the_genomic_accession=116159891, orientation='minus', exon_count=18, OMIM=[604732], no_hdr0=''),
    22798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22798, CurrentID=0, Status='live', Symbol='LAMB4', Aliases=[], description='laminin subunit beta 4', other_designations='laminin subunit beta-4|laminin beta-1-related protein', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=108011662, end_position_on_the_genomic_accession=108130361, orientation='minus', exon_count=41, OMIM=[616380], no_hdr0=''),
    22800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22800, CurrentID=0, Status='live', Symbol='RRAS2', Aliases=['NS12', 'TC21'], description='RAS related 2', other_designations='ras-related protein R-Ras2|ras-like protein TC21|related RAS viral (r-ras) oncogene homolog 2|teratocarcinoma oncogene', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14277920, end_position_on_the_genomic_accession=14364506, orientation='minus', exon_count=9, OMIM=[600098], no_hdr0=''),
    22801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22801, CurrentID=0, Status='live', Symbol='ITGA11', Aliases=['HsT18964'], description='integrin subunit alpha 11', other_designations='integrin alpha-11', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68296532, end_position_on_the_genomic_accession=68432312, orientation='minus', exon_count=31, OMIM=[604789], no_hdr0=''),
    22802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22802, CurrentID=0, Status='live', Symbol='CLCA4', Aliases=['CaCC', 'CaCC2'], description='chloride channel accessory 4', other_designations='calcium-activated chloride channel regulator 4|caCC-2|calcium-activated chloride channel family member 4|calcium-activated chloride channel protein 2|chloride channel regulator 4|chloride channel, calcium activated, family member 4|hCLCA4|hCaCC-2', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86547078, end_position_on_the_genomic_accession=86580758, orientation='plus', exon_count=15, OMIM=[616857], no_hdr0=''),
    22803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22803, CurrentID=0, Status='live', Symbol='XRN2', Aliases=[], description="5'-3' exoribonuclease 2", other_designations="5'-3' exoribonuclease 2|DHM1-like protein|DHP protein", map_location='20p11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=21303313, end_position_on_the_genomic_accession=21389825, orientation='plus', exon_count=32, OMIM=[608851], no_hdr0=''),
    22806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22806, CurrentID=0, Status='live', Symbol='IKZF3', Aliases=['AIO', 'AIOLOS', 'ZNFN1A3'], description='IKAROS family zinc finger 3', other_designations='zinc finger protein Aiolos|zinc finger DNA binding protein Aiolos|zinc finger protein, subfamily 1A, 3 (Aiolos)', map_location='17q12-q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39757715, end_position_on_the_genomic_accession=39864312, orientation='minus', exon_count=9, OMIM=[606221], no_hdr0=''),
    22807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22807, CurrentID=0, Status='live', Symbol='IKZF2', Aliases=['ANF1A2', 'HELIOS', 'ZNF1A2', 'ZNFN1A2'], description='IKAROS family zinc finger 2', other_designations='zinc finger protein Helios|ikaros family zinc finger protein 2|zinc finger DNA binding protein Helios|zinc finger protein, subfamily 1A, 2 (Helios)', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=212999692, end_position_on_the_genomic_accession=213155297, orientation='minus', exon_count=15, OMIM=[606234], no_hdr0=''),
    22808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22808, CurrentID=0, Status='live', Symbol='MRAS', Aliases=['M-RAs', 'NS11', 'R-RAS3', 'RRAS3'], description='muscle RAS oncogene homolog', other_designations='ras-related protein M-Ras|muscle and microspikes RAS|ras-related protein R-Ras3', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138347648, end_position_on_the_genomic_accession=138405535, orientation='plus', exon_count=10, OMIM=[608435], no_hdr0=''),
    22809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22809, CurrentID=0, Status='live', Symbol='ATF5', Aliases=['ATFX', 'HMFN0395'], description='activating transcription factor 5', other_designations='cyclic AMP-dependent transcription factor ATF-5|cAMP-dependent transcription factor ATF-5|transcription factor ATFx', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49928906, end_position_on_the_genomic_accession=49933935, orientation='plus', exon_count=5, OMIM=[606398], no_hdr0=''),
    22817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22817, CurrentID=0, Status='live', Symbol='NR1I4', Aliases=['CAR2'], description='nuclear receptor subfamily 1 group I member 4', other_designations='nuclear receptor subfamily 1 group I member 4', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    22818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22818, CurrentID=0, Status='live', Symbol='COPZ1', Aliases=['CGI-120', 'COPZ', 'HSPC181', 'zeta-COP', 'zeta1-COP'], description='COPI coat complex subunit zeta 1', other_designations='coatomer subunit zeta-1|coatomer protein complex subunit zeta 1|coatomer protein complex, subunit zeta|zeta-1 COP|zeta-1-coat protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54325109, end_position_on_the_genomic_accession=54351850, orientation='plus', exon_count=9, OMIM=[615472], no_hdr0=''),
    22820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22820, CurrentID=0, Status='live', Symbol='COPG1', Aliases=['COPG'], description='COPI coat complex subunit gamma 1', other_designations='coatomer subunit gamma-1|coat protein gamma-cop|coatomer protein complex subunit gamma 1|coatomer protein complex, subunit gamma|coatomer subunit gamma|gamma-1-COP|gamma-1-coat protein|gamma-COP|gamma-coat protein', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129249575, end_position_on_the_genomic_accession=129277773, orientation='plus', exon_count=25, OMIM=[615525], no_hdr0=''),
    22821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22821, CurrentID=0, Status='live', Symbol='RASA3', Aliases=['GAP1IP4BP', 'GAPIII'], description='RAS p21 protein activator 3', other_designations='ras GTPase-activating protein 3|GTPase activating protein III|GTPase-activating protein 1 family, inositol 1,3,4,5-tetrakisphosphate-binding protein|Ins(1,3,4,5)P4-binding protein|ins P4-binding protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113977783, end_position_on_the_genomic_accession=114132623, orientation='minus', exon_count=29, OMIM=[605182], no_hdr0=''),
    22822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22822, CurrentID=0, Status='live', Symbol='PHLDA1', Aliases=['DT1P1B11', 'PHRIP', 'TDAG51'], description='pleckstrin homology like domain family A member 1', other_designations='pleckstrin homology-like domain family A member 1|PQ-rich protein|PQR protein|T-cell death-associated gene 51 protein|apoptosis-associated nuclear protein|proline- and glutamine-rich protein|proline- and histidine-rich protein|proline-histidine rich protein', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76025447, end_position_on_the_genomic_accession=76031776, orientation='minus', exon_count=2, OMIM=[605335], no_hdr0=''),
    22823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22823, CurrentID=0, Status='live', Symbol='MTF2', Aliases=['M96', 'PCL2', 'TDRD19A', 'dJ976O13.2'], description='metal response element binding transcription factor 2', other_designations='metal-response element-binding transcription factor 2|hPCl2|metal regulatory transcription factor 2|metal-response element DNA-binding protein M96|polycomb-like 2|polycomb-like protein 2|putative DNA binding protein|tudor domain containing 19A', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93079283, end_position_on_the_genomic_accession=93139076, orientation='plus', exon_count=15, OMIM=[609882], no_hdr0=''),
    22824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22824, CurrentID=0, Status='live', Symbol='HSPA4L', Aliases=['APG-1', 'APG1', 'HSPH3', 'Osp94'], description='heat shock protein family A (Hsp70) member 4 like', other_designations='heat shock 70 kDa protein 4L|HSPA4-like protein|heat shock 70 kDa protein 4-like protein|heat shock 70-related protein APG-1|heat shock 70kDa protein 4-like|heat shock protein (hsp110 family)|heat-shock protein family A member 4-like protein|osmotic stress protein 94|testis tissue sperm-binding protein Li 64n', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127781796, end_position_on_the_genomic_accession=127840733, orientation='plus', exon_count=22, OMIM=[619077], no_hdr0=''),
    22826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22826, CurrentID=0, Status='live', Symbol='DNAJC8', Aliases=['HSPC331', 'SPF31'], description='DnaJ heat shock protein family (Hsp40) member C8', other_designations='dnaJ homolog subfamily C member 8|DnaJ (Hsp40) homolog, subfamily C, member 8|splicing protein spf31', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28200278, end_position_on_the_genomic_accession=28233029, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    22827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22827, CurrentID=0, Status='live', Symbol='PUF60', Aliases=['FIR', 'RoBPI', 'SIAHBP1', 'VRJS'], description='poly(U) binding splicing factor 60', other_designations='poly(U)-binding-splicing factor PUF60|FBP interacting repressor|FUSE-binding protein-interacting repressor|Ro ribonucleoprotein-binding protein 1|Siah binding protein 1|poly(U) binding splicing factor 60KDa|pyrimidine tract binding splicing factor', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143816344, end_position_on_the_genomic_accession=143829315, orientation='minus', exon_count=15, OMIM=[604819], no_hdr0=''),
    22828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22828, CurrentID=0, Status='live', Symbol='SCAF8', Aliases=['RBM16'], description='SR-related CTD associated factor 8', other_designations='SR-related and CTD-associated factor 8|CDC5L complex-associated protein 7|RNA-binding motif protein 16|SR-like CTD-associated factor 8|protein SCAF8', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=154733378, end_position_on_the_genomic_accession=154834244, orientation='plus', exon_count=22, OMIM=[616024], no_hdr0=''),
    22829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22829, CurrentID=0, Status='live', Symbol='NLGN4Y', Aliases=['HNL4Y'], description='neuroligin 4 Y-linked', other_designations='neuroligin-4, Y-linked|alternative HNL4Y', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=14522616, end_position_on_the_genomic_accession=14845654, orientation='plus', exon_count=16, OMIM=[400028], no_hdr0=''),
    22832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22832, CurrentID=0, Status='live', Symbol='CEP162', Aliases=['C6orf84', 'KIAA1009', 'QN1'], description='centrosomal protein 162', other_designations='centrosomal protein of 162 kDa|centrosomal protein 162kDa|protein QN1 homolog', map_location='6q14.2-q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=84124250, end_position_on_the_genomic_accession=84227889, orientation='minus', exon_count=32, OMIM=[610201], no_hdr0=''),
    22834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22834, CurrentID=0, Status='live', Symbol='ZNF652', Aliases=[], description='zinc finger protein 652', other_designations='zinc finger protein 652', map_location='17q21.32-q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49289206, end_position_on_the_genomic_accession=49362473, orientation='minus', exon_count=10, OMIM=[613907], no_hdr0=''),
    22835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22835, CurrentID=0, Status='live', Symbol='ZFP30', Aliases=['ZNF745'], description='ZFP30 zinc finger protein', other_designations='zinc finger protein 30 homolog|zinc finger protein 745', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37631006, end_position_on_the_genomic_accession=37656261, orientation='minus', exon_count=7, OMIM=[617317], no_hdr0=''),
    22836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22836, CurrentID=0, Status='live', Symbol='RHOBTB3', Aliases=[], description='Rho related BTB domain containing 3', other_designations='rho-related BTB domain-containing protein 3', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95713522, end_position_on_the_genomic_accession=95796361, orientation='plus', exon_count=14, OMIM=[607353], no_hdr0=''),
    22837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22837, CurrentID=0, Status='live', Symbol='COBLL1', Aliases=['COBLR1'], description='cordon-bleu WH2 repeat protein like 1', other_designations='cordon-bleu protein-like 1|COBL-like 1', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=164657931, end_position_on_the_genomic_accession=164842076, orientation='minus', exon_count=20, OMIM=[610318], no_hdr0=''),
    22838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22838, CurrentID=0, Status='live', Symbol='RNF44', Aliases=[], description='ring finger protein 44', other_designations='RING finger protein 44', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176526704, end_position_on_the_genomic_accession=176544206, orientation='minus', exon_count=14, OMIM=[619283], no_hdr0=''),
    22839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22839, CurrentID=0, Status='live', Symbol='DLGAP4', Aliases=['DAP-4', 'DAP4', 'DLP4', 'SAPAP-4', 'SAPAP4'], description='DLG associated protein 4', other_designations='disks large-associated protein 4|PSD-95/SAP90-binding protein 4|SAP90/PSD-95-associated protein 4|discs large homolog associated protein 4', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36306339, end_position_on_the_genomic_accession=36528634, orientation='plus', exon_count=18, OMIM=[616191], no_hdr0=''),
    22841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22841, CurrentID=0, Status='live', Symbol='RAB11FIP2', Aliases=['Rab11-FIP2', 'nRip11'], description='RAB11 family interacting protein 2', other_designations='rab11 family-interacting protein 2|RAB11 family interacting protein 2 (class I)', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=118004916, end_position_on_the_genomic_accession=118046941, orientation='minus', exon_count=7, OMIM=[608599], no_hdr0=''),
    22843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22843, CurrentID=0, Status='live', Symbol='PPM1E', Aliases=['CAMKPN', 'CaMKP-N', 'POPX1', 'PP2CH', 'caMKN'], description='protein phosphatase, Mg2+/Mn2+ dependent 1E', other_designations='protein phosphatase 1E|ca(2+)/calmodulin-dependent protein kinase phosphatase N|caMKP-nucleus|nuclear calmodulin-dependent protein kinase phosphatase|partner of PIX 1|partner of PIX-alpha|partner of PIXA|protein phosphatase 1E (PP2C domain containing)', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58755854, end_position_on_the_genomic_accession=58985617, orientation='plus', exon_count=9, OMIM=[619308], no_hdr0=''),
    22844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22844, CurrentID=0, Status='live', Symbol='FRMPD1', Aliases=['FRMD2'], description='FERM and PDZ domain containing 1', other_designations='FERM and PDZ domain-containing protein 1|FERM domain-containing protein 2', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37603229, end_position_on_the_genomic_accession=37746904, orientation='plus', exon_count=22, OMIM=[616919], no_hdr0=''),
    22845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22845, CurrentID=0, Status='live', Symbol='DOLK', Aliases=['CDG1M', 'DK', 'DK1', 'SEC59', 'TMEM15'], description='dolichol kinase', other_designations='dolichol kinase|SEC59 homolog|dolichol kinase 1|transmembrane protein 15', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128945530, end_position_on_the_genomic_accession=128947603, orientation='minus', exon_count=1, OMIM=[610746], no_hdr0=''),
    22846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22846, CurrentID=0, Status='live', Symbol='VASH1', Aliases=['KIAA1036', 'TTCP 1'], description='vasohibin 1', other_designations='tubulinyl-Tyr carboxypeptidase 1|tubulin carboxypeptidase 1|tyrosine carboxypeptidase 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=76761457, end_position_on_the_genomic_accession=76783017, orientation='plus', exon_count=9, OMIM=[609011], no_hdr0=''),
    22847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22847, CurrentID=0, Status='live', Symbol='ZNF507', Aliases=['Zfp507'], description='zinc finger protein 507', other_designations='zinc finger protein 507', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32345610, end_position_on_the_genomic_accession=32387667, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    22848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22848, CurrentID=0, Status='live', Symbol='AAK1', Aliases=[], description='AP2 associated kinase 1', other_designations='AP2-associated protein kinase 1|adaptor-associated kinase 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69457997, end_position_on_the_genomic_accession=69643739, orientation='minus', exon_count=22, OMIM=[616405], no_hdr0=''),
    22849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22849, CurrentID=0, Status='live', Symbol='CPEB3', Aliases=[], description='cytoplasmic polyadenylation element binding protein 3', other_designations='cytoplasmic polyadenylation element-binding protein 3|CPE-BP3|CPE-binding protein 3|hCPEB-3', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92046692, end_position_on_the_genomic_accession=92291499, orientation='minus', exon_count=17, OMIM=[610606], no_hdr0=''),
    22850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22850, CurrentID=0, Status='live', Symbol='ADNP2', Aliases=['ZNF508'], description='ADNP homeobox 2', other_designations='activity-dependent neuroprotector homeobox protein 2|ADNP homeobox protein 2|zinc finger protein 508', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=80109251, end_position_on_the_genomic_accession=80140346, orientation='plus', exon_count=5, OMIM=[617422], no_hdr0=''),
    22852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22852, CurrentID=0, Status='live', Symbol='ANKRD26', Aliases=['THC2', 'bA145E8.1'], description='ankyrin repeat domain 26', other_designations='ankyrin repeat domain-containing protein 26|GNS/ANKRD26/NCKAP1L fusion', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=26938195, end_position_on_the_genomic_accession=27100498, orientation='minus', exon_count=46, OMIM=[610855], no_hdr0=''),
    22853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22853, CurrentID=0, Status='live', Symbol='LMTK2', Aliases=['AATYK2', 'BREK', 'KPI-2', 'KPI2', 'LMR2', 'PPP1R100', 'cprk', 'hBREK'], description='lemur tyrosine kinase 2', other_designations='serine/threonine-protein kinase LMTK2|CDK5/p35-regulated kinase|apoptosis-associated tyrosine kinase 2|brain-enriched kinase|cyclin-dependent kinase 5/p35-regulated kinase|kinase/phosphatase/inhibitor 2|protein phosphatase 1, regulatory subunit 100|serine/threonine-protein kinase KPI-2', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98106862, end_position_on_the_genomic_accession=98209638, orientation='plus', exon_count=14, OMIM=[610989], no_hdr0=''),
    22854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22854, CurrentID=0, Status='live', Symbol='NTNG1', Aliases=['Lmnt1'], description='netrin G1', other_designations='netrin-G1|axon guidance molecule|laminet 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=107140017, end_position_on_the_genomic_accession=107484923, orientation='plus', exon_count=12, OMIM=[608818], no_hdr0=''),
    22856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22856, CurrentID=0, Status='live', Symbol='CHSY1', Aliases=['CHSY', 'CSS1', 'ChSy-1', 'TPBS'], description='chondroitin sulfate synthase 1', other_designations='chondroitin sulfate synthase 1|N-acetylgalactosaminyl-proteoglycan 3-beta-glucuronosyltransferase 1|N-acetylgalactosaminyltransferase II|carbohydrate synthase 1|chondroitin glucuronyltransferase 1|chondroitin glucuronyltransferase II|chondroitin synthase 1|glucuronosyl-N-acetylgalactosaminyl-proteoglycan 4-beta-N-acetylgalactosaminyltransferase 1', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101175727, end_position_on_the_genomic_accession=101252048, orientation='minus', exon_count=7, OMIM=[608183], no_hdr0=''),
    22858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22858, CurrentID=0, Status='live', Symbol='CILK1', Aliases=['ECO', 'EJM10', 'ICK', 'LCK2', 'MRK', 'hICK'], description='ciliogenesis associated kinase 1', other_designations='serine/threonine-protein kinase ICK|MAK-related kinase|iciliogenesis associated kinase 1|intestinal cell (MAK-like) kinase|intestinal cell kinase|laryngeal cancer kinase 2|serine/threonine protein kinase', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53001299, end_position_on_the_genomic_accession=53061824, orientation='minus', exon_count=18, OMIM=[612325], no_hdr0=''),
    22859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22859, CurrentID=0, Status='live', Symbol='ADGRL1', Aliases=['CIRL1', 'CL1', 'LEC2', 'LPHN1'], description='adhesion G protein-coupled receptor L1', other_designations='adhesion G protein-coupled receptor L1|CIRL-1|calcium-independent alpha-latrotoxin receptor 1|latrophilin-1|lectomedin-2', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14147737, end_position_on_the_genomic_accession=14206245, orientation='minus', exon_count=27, OMIM=[616416], no_hdr0=''),
    22861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22861, CurrentID=0, Status='live', Symbol='NLRP1', Aliases=['AIADK', 'CARD7', 'CIDED', 'CLR17.1', 'DEFCAP', 'DEFCAP-L/S', 'JRRP', 'MSPC', 'NAC', 'NALP1', 'PP1044', 'SLEV1', 'VAMAS1'], description='NLR family pyrin domain containing 1', other_designations='NACHT, LRR and PYD domains-containing protein 1|NACHT, LRR and PYD containing protein 1|NACHT, leucine rich repeat and PYD (pyrin domain) containing 1|NACHT, leucine rich repeat and PYD containing 1|caspase recruitment domain protein 7|caspase recruitment domain-containing protein 7|death effector filament-forming Ced-4-like apoptosis protein|nucleotide-binding domain and caspase recruitment domain|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5501396, end_position_on_the_genomic_accession=5584509, orientation='minus', exon_count=18, OMIM=[606636], no_hdr0=''),
    22862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22862, CurrentID=0, Status='live', Symbol='FNDC3A', Aliases=['FNDC3', 'HUGO', 'bA203I16.1', 'bA203I16.5'], description='fibronectin type III domain containing 3A', other_designations='fibronectin type-III domain-containing protein 3A|human gene expressed in odontoblasts', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48975241, end_position_on_the_genomic_accession=49209779, orientation='plus', exon_count=34, OMIM=[615794], no_hdr0=''),
    22863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22863, CurrentID=0, Status='live', Symbol='ATG14', Aliases=['ATG14L', 'BARKOR', 'KIAA0831'], description='autophagy related 14', other_designations='beclin 1-associated autophagy-related key regulator|ATG14 autophagy related 14 homolog|Beclin 1-Interacting protein|autophagy-related protein 14-like protein', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55366391, end_position_on_the_genomic_accession=55411830, orientation='minus', exon_count=11, OMIM=[613515], no_hdr0=''),
    22864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22864, CurrentID=0, Status='live', Symbol='R3HDM2', Aliases=['CAG6', 'PR01365'], description='R3H domain containing 2', other_designations='R3H domain-containing protein 2', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57253764, end_position_on_the_genomic_accession=57431043, orientation='minus', exon_count=32, OMIM=[], no_hdr0=''),
    22865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22865, CurrentID=0, Status='live', Symbol='SLITRK3', Aliases=[], description='SLIT and NTRK like family member 3', other_designations='SLIT and NTRK-like protein 3|slit and trk like gene 3', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=165186720, end_position_on_the_genomic_accession=165197109, orientation='minus', exon_count=4, OMIM=[609679], no_hdr0=''),
    22866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22866, CurrentID=0, Status='live', Symbol='CNKSR2', Aliases=['CNK2', 'KSR2', 'MAGUIN', 'MRXSHG'], description='connector enhancer of kinase suppressor of Ras 2', other_designations='connector enhancer of kinase suppressor of ras 2|CNK homolog protein 2|connector enhancer of KSR2|membrane-associated guanylate kinase-interacting protein', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21374418, end_position_on_the_genomic_accession=21654689, orientation='plus', exon_count=23, OMIM=[300724], no_hdr0=''),
    22868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22868, CurrentID=0, Status='live', Symbol='FASTKD2', Aliases=['COXPD44', 'KIAA0971'], description='FAST kinase domains 2', other_designations='FAST kinase domain-containing protein 2, mitochondrial', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206765606, end_position_on_the_genomic_accession=206796189, orientation='plus', exon_count=12, OMIM=[612322], no_hdr0=''),
    22869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22869, CurrentID=0, Status='live', Symbol='ZNF510', Aliases=[], description='zinc finger protein 510', other_designations='zinc finger protein 510', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96754553, end_position_on_the_genomic_accession=96778549, orientation='minus', exon_count=7, OMIM=[619385], no_hdr0=''),
    22870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22870, CurrentID=0, Status='live', Symbol='PPP6R1', Aliases=['KIAA1115', 'PP6R1', 'SAP190', 'SAPS1'], description='protein phosphatase 6 regulatory subunit 1', other_designations='serine/threonine-protein phosphatase 6 regulatory subunit 1|SAPS domain family, member 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55229779, end_position_on_the_genomic_accession=55259017, orientation='minus', exon_count=24, OMIM=[610875], no_hdr0=''),
    22871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22871, CurrentID=0, Status='live', Symbol='NLGN1', Aliases=['NL1'], description='neuroligin 1', other_designations='neuroligin-1', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=173395929, end_position_on_the_genomic_accession=174294372, orientation='plus', exon_count=14, OMIM=[600568], no_hdr0=''),
    22872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22872, CurrentID=0, Status='live', Symbol='SEC31A', Aliases=['ABP125', 'ABP130', 'HSPC275', 'HSPC334', 'NEDSOSB', 'SEC31L1'], description='SEC31 homolog A, COPII coat complex component', other_designations='protein transport protein Sec31A|SEC31 homolog A, COPII coating complex component|SEC31-like protein 1|SEC31-related protein A|web1-like protein|yeast Sec31p homolog', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82818509, end_position_on_the_genomic_accession=82900569, orientation='minus', exon_count=30, OMIM=[610257], no_hdr0=''),
    22873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22873, CurrentID=0, Status='live', Symbol='DZIP1', Aliases=['DZIP', 'DZIPt1', 'MVP3', 'SPGF47'], description='DAZ interacting zinc finger protein 1', other_designations='zinc finger protein DZIP1|DAZ interacting protein 1|DAZ interacting protein testis1|DAZ-interacting protein 1/2|zinc finger DAZ interacting protein 1|zinc-finger protein DZIPt1', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=95578202, end_position_on_the_genomic_accession=95644706, orientation='minus', exon_count=24, OMIM=[608671], no_hdr0=''),
    22874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22874, CurrentID=0, Status='live', Symbol='PLEKHA6', Aliases=['PEPP-3', 'PEPP3'], description='pleckstrin homology domain containing A6', other_designations='pleckstrin homology domain-containing family A member 6|PH domain-containing family A member 6|phosphoinositol 3-phosphate-binding protein 3', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204218853, end_position_on_the_genomic_accession=204378377, orientation='minus', exon_count=36, OMIM=[607771], no_hdr0=''),
    22875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22875, CurrentID=0, Status='live', Symbol='ENPP4', Aliases=['NPP4'], description='ectonucleotide pyrophosphatase/phosphodiesterase 4', other_designations="bis(5'-adenosyl)-triphosphatase ENPP4|AP3A hydrolase|AP3Aase|E-NPP 4|NPP-4|ectonucleotide pyrophosphatase/phosphodiesterase 4 (putative function)|ectonucleotide pyrophosphatase/phosphodiesterase 4 (putative)|ectonucleotide pyrophosphatase/phosphodiesterase family member 4", map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46129989, end_position_on_the_genomic_accession=46146688, orientation='plus', exon_count=4, OMIM=[617000], no_hdr0=''),
    22876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22876, CurrentID=0, Status='live', Symbol='INPP5F', Aliases=['MSTP007', 'MSTPO47', 'SAC2', 'hSAC2'], description='inositol polyphosphate-5-phosphatase F', other_designations='phosphatidylinositide phosphatase SAC2|Sac domain-containing inositol phosphatase 2|sac domain-containing phosphoinositide 4-phosphatase 2|sac domain-containing phosphoinositide 5-phosphatase 2', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119704395, end_position_on_the_genomic_accession=119830482, orientation='plus', exon_count=27, OMIM=[609389], no_hdr0=''),
    22877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22877, CurrentID=0, Status='live', Symbol='MLXIP', Aliases=['MIR', 'MONDOA', 'bHLHe36'], description='MLX interacting protein', other_designations='MLX-interacting protein|Mlx interactor|class E basic helix-loop-helix protein 36|transcriptional activator MondoA', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122078744, end_position_on_the_genomic_accession=122147344, orientation='plus', exon_count=19, OMIM=[608090], no_hdr0=''),
    22878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22878, CurrentID=0, Status='live', Symbol='TRAPPC8', Aliases=['GSG1', 'HsT2706', 'KIAA1012', 'TRS85'], description='trafficking protein particle complex subunit 8', other_designations='trafficking protein particle complex subunit 8|general sporulation gene 1 homolog|protein TRS85 homolog|trafficking protein particle complex 8', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31829197, end_position_on_the_genomic_accession=31943128, orientation='minus', exon_count=32, OMIM=[614136], no_hdr0=''),
    22879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22879, CurrentID=0, Status='live', Symbol='MON1B', Aliases=['HSRG1', 'SAND2', 'SRG1'], description='MON1 homolog B, secretory trafficking associated', other_designations='vacuolar fusion protein MON1 homolog B|HSV-1 stimulation-related gene 1 protein|HSV-I stimulating-related protein|MON1 secretory trafficking family member B', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77191190, end_position_on_the_genomic_accession=77202398, orientation='plus', exon_count=6, OMIM=[608954], no_hdr0=''),
    22880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22880, CurrentID=0, Status='live', Symbol='MORC2', Aliases=['CMT2Z', 'DIGFAN', 'ZCW3', 'ZCWCC1'], description='MORC family CW-type zinc finger 2', other_designations='ATPase MORC2|zinc finger CW-type coiled-coil domain protein 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30925130, end_position_on_the_genomic_accession=30968774, orientation='minus', exon_count=27, OMIM=[616661], no_hdr0=''),
    22881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22881, CurrentID=0, Status='live', Symbol='ANKRD6', Aliases=[], description='ankyrin repeat domain 6', other_designations='ankyrin repeat domain-containing protein 6|diego homolog|diversin|epididymis secretory sperm binding protein', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89433152, end_position_on_the_genomic_accession=89633834, orientation='plus', exon_count=20, OMIM=[610583], no_hdr0=''),
    22882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22882, CurrentID=0, Status='live', Symbol='ZHX2', Aliases=['AFR1', 'RAF'], description='zinc fingers and homeoboxes 2', other_designations='zinc fingers and homeoboxes protein 2|AFP regulator 1|alpha-fetoprotein regulator 1|regulator of AFP|transcription factor ZHX2|zinc finger and homeodomain protein 2', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=122781655, end_position_on_the_genomic_accession=122974514, orientation='plus', exon_count=6, OMIM=[609185], no_hdr0=''),
    22883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22883, CurrentID=0, Status='live', Symbol='CLSTN1', Aliases=['ALC-ALPHA', 'CDHR12', 'CST-1', 'CSTN1', 'PIK3CD', 'XB31alpha', 'alcalpha1', 'alcalpha2'], description='calsyntenin 1', other_designations='calsyntenin-1|alcadein-alpha|alzheimer-related cadherin-like protein|cadherin-related family member 12|non-classical cadherin XB31alpha', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9728926, end_position_on_the_genomic_accession=9824526, orientation='minus', exon_count=19, OMIM=[611321], no_hdr0=''),
    22884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22884, CurrentID=0, Status='live', Symbol='WDR37', Aliases=['NOCGUS'], description='WD repeat domain 37', other_designations='WD repeat-containing protein 37', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=1056385, end_position_on_the_genomic_accession=1132372, orientation='plus', exon_count=14, OMIM=[618586], no_hdr0=''),
    22885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22885, CurrentID=0, Status='live', Symbol='ABLIM3', Aliases=['HMFN1661'], description='actin binding LIM protein family member 3', other_designations='actin-binding LIM protein 3|abLIM-3', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149141493, end_position_on_the_genomic_accession=149260542, orientation='plus', exon_count=25, OMIM=[611305], no_hdr0=''),
    22887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22887, CurrentID=0, Status='live', Symbol='FOXJ3', Aliases=[], description='forkhead box J3', other_designations='forkhead box protein J3', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42176539, end_position_on_the_genomic_accession=42336805, orientation='minus', exon_count=19, OMIM=[616035], no_hdr0=''),
    22888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22888, CurrentID=0, Status='live', Symbol='UBOX5', Aliases=['RNF37', 'UBCE7IP5', 'UIP5', 'hUIP5'], description='U-box domain containing 5', other_designations='RING finger protein 37|RING-type E3 ubiquitin transferase RNF37|U-box domain-containing protein 5|ubcM4-interacting protein 5|ubiquitin conjugating enzyme 7 interacting protein 5', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3107573, end_position_on_the_genomic_accession=3159865, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    22889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22889, CurrentID=0, Status='live', Symbol='KHDC4', Aliases=['BLOM7', 'KIAA0907', 'SNORA80EHG'], description='KH domain containing 4, pre-mRNA splicing factor', other_designations='KH homology domain-containing protein 4|brings lots of money 7|pre-mRNA splicing factor protein KHDC4|protein BLOM7', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155913045, end_position_on_the_genomic_accession=155934413, orientation='minus', exon_count=14, OMIM=[619370], no_hdr0=''),
    22890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22890, CurrentID=0, Status='live', Symbol='ZBTB1', Aliases=['ZNF909'], description='zinc finger and BTB domain containing 1', other_designations='zinc finger and BTB domain-containing protein 1', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64504726, end_position_on_the_genomic_accession=64533693, orientation='plus', exon_count=5, OMIM=[616578], no_hdr0=''),
    22891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22891, CurrentID=0, Status='live', Symbol='ZNF365', Aliases=['Su48', 'UAND', 'ZNF365'], description='zinc finger protein 365', other_designations='protein ZNF365|DISC1-binding zinc-finger protein|protein su48|talanin', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=62374369, end_position_on_the_genomic_accession=62544262, orientation='plus', exon_count=8, OMIM=[607818], no_hdr0=''),
    22893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22893, CurrentID=0, Status='live', Symbol='BAHD1', Aliases=[], description='bromo adjacent homology domain containing 1', other_designations='bromo adjacent homology domain-containing 1 protein|BAH domain-containing protein 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40439757, end_position_on_the_genomic_accession=40468237, orientation='plus', exon_count=9, OMIM=[613880], no_hdr0=''),
    22894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22894, CurrentID=0, Status='live', Symbol='DIS3', Aliases=['2810028N01Rik', 'EXOSC11', 'KIAA1008', 'RRP44', 'dis3p'], description="DIS3 homolog, exosome endoribonuclease and 3'-5' exoribonuclease", other_designations="exosome complex exonuclease RRP44|DIS3 exosome endoribonuclease and 3'-5' exoribonuclease|DIS3 mitotic control homolog|exosome component 11|mitotic control protein dis3 homolog|ribosomal RNA-processing protein 44", map_location='13q21.33', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=72752169, end_position_on_the_genomic_accession=72781900, orientation='minus', exon_count=22, OMIM=[607533], no_hdr0=''),
    22895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22895, CurrentID=0, Status='live', Symbol='RPH3A', Aliases=[], description='rabphilin 3A', other_designations='rabphilin-3A|exophilin-1|rabphilin 3A homolog', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112575236, end_position_on_the_genomic_accession=112898881, orientation='plus', exon_count=27, OMIM=[612159], no_hdr0=''),
    22897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22897, CurrentID=0, Status='live', Symbol='CEP164', Aliases=['NPHP15'], description='centrosomal protein 164', other_designations='centrosomal protein of 164 kDa|centrosomal protein 164kDa', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117316346, end_position_on_the_genomic_accession=117413266, orientation='plus', exon_count=40, OMIM=[614848], no_hdr0=''),
    22898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22898, CurrentID=0, Status='live', Symbol='DENND3', Aliases=[], description='DENN domain containing 3', other_designations='DENN domain-containing protein 3|DENN/MADD domain containing 3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=141128562, end_position_on_the_genomic_accession=141195804, orientation='plus', exon_count=33, OMIM=[617503], no_hdr0=''),
    22899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22899, CurrentID=0, Status='live', Symbol='ARHGEF15', Aliases=['ARGEF15', 'E5', 'Ephexin5', 'Vsm-RhoGEF'], description='Rho guanine nucleotide exchange factor 15', other_designations='rho guanine nucleotide exchange factor 15|Rho guanine nucleotide exchange factor (GEF) 15|ephexin-5', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8310241, end_position_on_the_genomic_accession=8322516, orientation='plus', exon_count=18, OMIM=[608504], no_hdr0=''),
    22900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22900, CurrentID=0, Status='live', Symbol='CARD8', Aliases=['CARDINAL', 'DACAR', 'DAKAR', 'NDPP', 'NDPP1', 'TUCAN'], description='caspase recruitment domain family member 8', other_designations='caspase recruitment domain-containing protein 8|CARD inhibitor of NF-kappaB-activating ligands|apoptotic protein NDPP1|tumor up-regulated CARD-containing antagonist of CASP9|tumor up-regulated CARD-containing antagonist of caspase nine', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48203148, end_position_on_the_genomic_accession=48256264, orientation='minus', exon_count=21, OMIM=[609051], no_hdr0=''),
    22901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22901, CurrentID=0, Status='live', Symbol='ARSG', Aliases=['USH4'], description='arylsulfatase G', other_designations='arylsulfatase G|ASG', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68259170, end_position_on_the_genomic_accession=68452019, orientation='plus', exon_count=22, OMIM=[610008], no_hdr0=''),
    22902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22902, CurrentID=0, Status='live', Symbol='RUFY3', Aliases=['RIPX', 'SINGAR1', 'ZFYVE30'], description='RUN and FYVE domain containing 3', other_designations='protein RUFY3|rap2 interacting protein x|single axon-regulated protein|single axon-related 1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70704204, end_position_on_the_genomic_accession=70808619, orientation='plus', exon_count=24, OMIM=[611194], no_hdr0=''),
    22903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22903, CurrentID=0, Status='live', Symbol='BTBD3', Aliases=['dJ742J24.1'], description='BTB domain containing 3', other_designations='BTB/POZ domain-containing protein 3|BTB (POZ) domain containing 3', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=11890723, end_position_on_the_genomic_accession=11926595, orientation='plus', exon_count=6, OMIM=[615566], no_hdr0=''),
    22904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22904, CurrentID=0, Status='live', Symbol='SBNO2', Aliases=['KIAA0963', 'SNO', 'STNO'], description='strawberry notch homolog 2', other_designations='protein strawberry notch homolog 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1107637, end_position_on_the_genomic_accession=1174268, orientation='minus', exon_count=33, OMIM=[615729], no_hdr0=''),
    22905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22905, CurrentID=0, Status='live', Symbol='EPN2', Aliases=['EHB21'], description='epsin 2', other_designations='epsin-2|EPS-15-interacting protein 2|Eps15 binding protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19237366, end_position_on_the_genomic_accession=19336715, orientation='plus', exon_count=11, OMIM=[607263], no_hdr0=''),
    22906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22906, CurrentID=0, Status='live', Symbol='TRAK1', Aliases=['DEE68', 'EIEE68', 'MILT1', 'OIP106'], description='trafficking kinesin protein 1', other_designations='trafficking kinesin-binding protein 1|106 kDa O-GlcNAc transferase-interacting protein|O-linked N-acetylglucosamine transferase interacting protein 106|OGT(O-Glc-NAc transferase)-interacting protein 106 KDa|milton homolog 1|protein Milton|trafficking protein, kinesin binding 1', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42013802, end_position_on_the_genomic_accession=42225890, orientation='plus', exon_count=26, OMIM=[608112], no_hdr0=''),
    22907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22907, CurrentID=0, Status='live', Symbol='DHX30', Aliases=['DDX30', 'NEDMIAL', 'RETCOR'], description='DExH-box helicase 30', other_designations='ATP-dependent RNA helicase DHX30|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 30|DEAH (Asp-Glu-Ala-His) box helicase 30|DEAH (Asp-Glu-Ala-His) box polypeptide 30|DEAH box protein 30|DEAH-box helicase 30|putative ATP-dependent RNA helicase DHX30|retina co-repressor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47802990, end_position_on_the_genomic_accession=47850193, orientation='plus', exon_count=26, OMIM=[616423], no_hdr0=''),
    22908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22908, CurrentID=0, Status='live', Symbol='SACM1L', Aliases=['SAC1'], description='SAC1 like phosphatidylinositide phosphatase', other_designations='phosphatidylinositol-3-phosphatase SAC1|SAC1 suppressor of actin mutations 1 like|phosphatidylinositide phosphatase SAC1|phosphatidylinositol-4-phosphate phosphatase|suppressor of actin 1|suppressor of actin mutations 1-like protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45689362, end_position_on_the_genomic_accession=45745409, orientation='plus', exon_count=21, OMIM=[606569], no_hdr0=''),
    22909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22909, CurrentID=0, Status='live', Symbol='FAN1', Aliases=['KIAA1018', 'KMIN', 'MTMR15', 'hFAN1'], description='FANCD2 and FANCI associated nuclease 1', other_designations='fanconi-associated nuclease 1|FANCD2/FANCI-associated nuclease 1|coiled-coil domain-containing protein MTMR15|fanconi anemia associated nuclease 1|myotubularin-related protein 15', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30903852, end_position_on_the_genomic_accession=30943108, orientation='plus', exon_count=16, OMIM=[613534], no_hdr0=''),
    22911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22911, CurrentID=0, Status='live', Symbol='WDR47', Aliases=[], description='WD repeat domain 47', other_designations='WD repeat-containing protein 47|nemitin|neuronal enriched MAP-interacting protein', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108970211, end_position_on_the_genomic_accession=109042113, orientation='minus', exon_count=17, OMIM=[615734], no_hdr0=''),
    22913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22913, CurrentID=0, Status='live', Symbol='RALY', Aliases=['HNRPCL2', 'P542'], description='RALY heterogeneous nuclear ribonucleoprotein', other_designations='RNA-binding protein Raly|RNA binding protein, autoantigenic (hnRNP-associated with lethal yellow homolog)|RNA-binding protein (autoantigenic)|RNA-binding protein (autoantigenic, hnRNP-associated with lethal yellow)|autoantigen p542|heterogeneous nuclear ribonucleoprotein C-like 2|hnRNP associated with lethal yellow protein homolog|hnRNP core protein C-like 2', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33993659, end_position_on_the_genomic_accession=34084884, orientation='plus', exon_count=15, OMIM=[614663], no_hdr0=''),
    22914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22914, CurrentID=0, Status='live', Symbol='KLRK1', Aliases=['CD314', 'D12S2489E', 'KLR', 'NKG2-D', 'NKG2D'], description='killer cell lectin like receptor K1', other_designations='NKG2-D type II integral membrane protein|NK cell receptor D|NKG2-D-activating NK receptor|killer cell lectin-like receptor subfamily K, member 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10372353, end_position_on_the_genomic_accession=10390041, orientation='minus', exon_count=8, OMIM=[611817], no_hdr0=''),
    22915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22915, CurrentID=0, Status='live', Symbol='MMRN1', Aliases=['ECM', 'EMILIN4', 'GPIa*', 'MMRN'], description='multimerin 1', other_designations='multimerin-1|EMILIN-4|elastin microfibril interface located protein 4|elastin microfibril interfacer 4|endothelial cell multimerin|glycoprotein Ia*', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=89879511, end_position_on_the_genomic_accession=89954629, orientation='plus', exon_count=9, OMIM=[601456], no_hdr0=''),
    22916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22916, CurrentID=0, Status='live', Symbol='NCBP2', Aliases=['CBC2', 'CBP20', 'NIP1', 'PIG55'], description='nuclear cap binding protein subunit 2', other_designations='nuclear cap-binding protein subunit 2|20 kDa nuclear cap-binding protein|NCBP 20 kDa subunit|NCBP interacting protein 1|cell proliferation-inducing gene 55 protein|nuclear cap binding protein subunit 2, 20kD|nuclear cap binding protein subunit 2, 20kDa', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196932729, end_position_on_the_genomic_accession=196942528, orientation='minus', exon_count=5, OMIM=[605133], no_hdr0=''),
    22917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22917, CurrentID=0, Status='live', Symbol='ZP1', Aliases=['HEL163', 'OOMD', 'OOMD1'], description='zona pellucida glycoprotein 1', other_designations='zona pellucida sperm-binding protein 1|epididymis luminal protein 163|zona pellucida glycoprotein 1 (sperm receptor)', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60867542, end_position_on_the_genomic_accession=60875693, orientation='plus', exon_count=13, OMIM=[195000], no_hdr0=''),
    22918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22918, CurrentID=0, Status='live', Symbol='CD93', Aliases=['C1QR1', 'C1qR(P)', 'C1qRP', 'CDw93', 'ECSM3', 'MXRA4', 'dJ737E23.1'], description='CD93 molecule', other_designations='complement component C1q receptor|C1q receptor 1|C1q/MBL/SPA receptor|C1qR|CD93 antigen|complement component 1 q subcomponent receptor 1|matrix-remodeling-associated protein 4|matrix-remodelling associated 4', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23076554, end_position_on_the_genomic_accession=23086830, orientation='minus', exon_count=3, OMIM=[120577], no_hdr0=''),
    22919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22919, CurrentID=0, Status='live', Symbol='MAPRE1', Aliases=['EB1'], description='microtubule associated protein RP/EB family member 1', other_designations='microtubule-associated protein RP/EB family member 1|APC-binding protein EB1|adenomatous polyposis coli-binding protein EB1|end-binding protein 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32819780, end_position_on_the_genomic_accession=32850405, orientation='plus', exon_count=8, OMIM=[603108], no_hdr0=''),
    22920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22920, CurrentID=0, Status='live', Symbol='KIFAP3', Aliases=['FLA3', 'KAP-1', 'KAP-3', 'KAP3', 'SMAP', 'Smg-GDS', 'dJ190I16.1'], description='kinesin associated protein 3', other_designations='kinesin-associated protein 3|small G protein GDP dissociation stimulator|smg GDS-associated protein', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169921326, end_position_on_the_genomic_accession=170085203, orientation='minus', exon_count=25, OMIM=[601836], no_hdr0=''),
    22921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22921, CurrentID=0, Status='live', Symbol='MSRB2', Aliases=['CBS-1', 'CBS1', 'CGI-131', 'MSRB', 'PILB'], description='methionine sulfoxide reductase B2', other_designations='methionine-R-sulfoxide reductase B2, mitochondrial|pilin-like transcription factor', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=23095564, end_position_on_the_genomic_accession=23122013, orientation='plus', exon_count=6, OMIM=[613782], no_hdr0=''),
    22924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22924, CurrentID=0, Status='live', Symbol='MAPRE3', Aliases=['EB3', 'EBF3', 'EBF3-S', 'RP3'], description='microtubule associated protein RP/EB family member 3', other_designations='microtubule-associated protein RP/EB family member 3|APC binding protein|EB1 protein family member 3|end-binding protein 3', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26970637, end_position_on_the_genomic_accession=27027219, orientation='plus', exon_count=9, OMIM=[605788], no_hdr0=''),
    22925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22925, CurrentID=0, Status='live', Symbol='PLA2R1', Aliases=['CLEC13C', 'PLA2-R', 'PLA2G1R', 'PLA2IR', 'PLA2R'], description='phospholipase A2 receptor 1', other_designations='secretory phospholipase A2 receptor|180 kDa secretory phospholipase A2 receptor|C-type lectin domain family 13 member C|M-type receptor|phospholipase A2 receptor 1, 180kD|phospholipase A2 receptor 1, 180kDa', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159932002, end_position_on_the_genomic_accession=160062615, orientation='minus', exon_count=35, OMIM=[604939], no_hdr0=''),
    22926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22926, CurrentID=0, Status='live', Symbol='ATF6', Aliases=['ACHM7A', 'ATF6'], description='activating transcription factor 6', other_designations='cyclic AMP-dependent transcription factor ATF-6 alpha|cAMP-dependent transcription factor ATF-6 alpha', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161766320, end_position_on_the_genomic_accession=161964070, orientation='plus', exon_count=17, OMIM=[605537], no_hdr0=''),
    22927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22927, CurrentID=0, Status='live', Symbol='HABP4', Aliases=['IHABP-4', 'IHABP4', 'Ki-1/57', 'SERBP1L'], description='hyaluronan binding protein 4', other_designations='intracellular hyaluronan-binding protein 4|chromodomain helicase DNA binding protein 3 interacting protein|intracellular antigen detected by monoclonal antibody Ki-1|ki-1/57 intracellular antigen', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96450162, end_position_on_the_genomic_accession=96491336, orientation='plus', exon_count=9, OMIM=[617369], no_hdr0=''),
    22928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22928, CurrentID=0, Status='live', Symbol='SEPHS2', Aliases=['SPS2'], description='selenophosphate synthetase 2', other_designations='selenide, water dikinase 2|selenium donor protein 2|selenophosphate synthase 2|selenoprotein SEPHS2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30443631, end_position_on_the_genomic_accession=30445874, orientation='minus', exon_count=1, OMIM=[606218], no_hdr0=''),
    22929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22929, CurrentID=0, Status='live', Symbol='SEPHS1', Aliases=['SELD', 'SPS', 'SPS1'], description='selenophosphate synthetase 1', other_designations='selenide, water dikinase 1|selenium donor protein 1|selenophosphate synthase 1|selenophosphate synthetase 1 +E9|selenophosphate synthetase 1 +E9a|selenophosphate synthetase 1 delta E2|selenophosphate synthetase 1 delta E8|selenophosphate synthetase 1 major', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13317428, end_position_on_the_genomic_accession=13348293, orientation='minus', exon_count=10, OMIM=[600902], no_hdr0=''),
    22930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22930, CurrentID=0, Status='live', Symbol='RAB3GAP1', Aliases=['MARTS2', 'P130', 'RAB3GAP30', 'WARBM1', 'RAB3GAP1'], description='RAB3 GTPase activating protein catalytic subunit 1', other_designations='rab3 GTPase-activating protein catalytic subunit|RAB3 GTPase activating protein subunit 1 (catalytic)|RAB3 GTPase-activating protein 130 kDa subunit|rab3-GAP p130', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135052281, end_position_on_the_genomic_accession=135176667, orientation='plus', exon_count=28, OMIM=[602536], no_hdr0=''),
    22931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22931, CurrentID=0, Status='live', Symbol='RAB18', Aliases=['RAB18LI1', 'WARBM3'], description='RAB18, member RAS oncogene family', other_designations='ras-related protein Rab-18|RAB18 small GTPase', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27504304, end_position_on_the_genomic_accession=27542239, orientation='plus', exon_count=8, OMIM=[602207], no_hdr0=''),
    22932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22932, CurrentID=0, Status='live', Symbol='POMZP3', Aliases=['POM-ZP3'], description='POM121 and ZP3 fusion', other_designations='POM121 and ZP3 fusion protein|POM (POM121 homolog, rat) and ZP3 fusion|POM (POM121 rat homolog) and ZP3 fusion|POM-ZP3 fusion protein|POM121/ZP3 fusion protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76609986, end_position_on_the_genomic_accession=76627279, orientation='minus', exon_count=7, OMIM=[600587], no_hdr0=''),
    22933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22933, CurrentID=0, Status='live', Symbol='SIRT2', Aliases=['SIR2', 'SIR2L', 'SIR2L2'], description='sirtuin 2', other_designations='NAD-dependent protein deacetylase sirtuin-2|NAD-dependent deacetylase sirtuin-2|SIR2-like protein 2|regulatory protein SIR2 homolog 2|silent information regulator 2|sir2-related protein type 2|sirtuin type 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38878555, end_position_on_the_genomic_accession=38899733, orientation='minus', exon_count=17, OMIM=[604480], no_hdr0=''),
    22934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22934, CurrentID=0, Status='live', Symbol='RPIA', Aliases=['RPID', 'RPIA'], description='ribose 5-phosphate isomerase A', other_designations='ribose-5-phosphate isomerase|phosphoriboisomerase|ribose 5-phosphate epimerase', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88691673, end_position_on_the_genomic_accession=88750929, orientation='plus', exon_count=9, OMIM=[180430], no_hdr0=''),
    22936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22936, CurrentID=0, Status='live', Symbol='ELL2', Aliases=['MRCCAT1'], description='elongation factor for RNA polymerase II 2', other_designations='RNA polymerase II elongation factor ELL2|ELL-related RNA polymerase II, elongation factor|elongation factor RNA for polymerase II 2|elongation factor, RNA polymerase II, 2|metastatic renal cell carcinoma-associated transcript 1', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95885098, end_position_on_the_genomic_accession=95961962, orientation='minus', exon_count=15, OMIM=[601874], no_hdr0=''),
    22937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22937, CurrentID=0, Status='live', Symbol='SCAP', Aliases=[], description='SREBF chaperone', other_designations='sterol regulatory element-binding protein cleavage-activating protein|SREBP cleavage-activating protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47413681, end_position_on_the_genomic_accession=47477126, orientation='minus', exon_count=25, OMIM=[601510], no_hdr0=''),
    22938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22938, CurrentID=0, Status='live', Symbol='SNW1', Aliases=['Bx42', 'FUN20', 'NCOA-62', 'PRPF45', 'Prp45', 'SKIIP', 'SKIP', 'SKIP1'], description='SNW domain containing 1', other_designations='SNW domain-containing protein 1|SKI interacting protein|homolog of Drosophila BX42|nuclear protein SkiP|nuclear receptor coactivator NCoA-62|nuclear receptor coactivator, 62-kD|ski-interacting protein', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77717599, end_position_on_the_genomic_accession=77761156, orientation='minus', exon_count=14, OMIM=[603055], no_hdr0=''),
    22941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22941, CurrentID=0, Status='live', Symbol='SHANK2', Aliases=['AUTS17', 'CORTBP1', 'CTTNBP1', 'ProSAP1', 'SHANK', 'SPANK-3'], description='SH3 and multiple ankyrin repeat domains 2', other_designations='SH3 and multiple ankyrin repeat domains protein 2|GKAP/SAPAP interacting protein|cortactin SH3 domain-binding protein|cortactin-binding protein 1|proline-rich synapse associated protein 1', map_location='11q13.3-q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=70467854, end_position_on_the_genomic_accession=71252724, orientation='minus', exon_count=30, OMIM=[603290], no_hdr0=''),
    22943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22943, CurrentID=0, Status='live', Symbol='DKK1', Aliases=['DKK-1', 'SK'], description='dickkopf WNT signaling pathway inhibitor 1', other_designations='dickkopf-related protein 1|dickkopf 1 homolog|dickkopf-1 like|dickkopf-like protein 1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=52314281, end_position_on_the_genomic_accession=52317657, orientation='plus', exon_count=4, OMIM=[605189], no_hdr0=''),
    22944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22944, CurrentID=0, Status='live', Symbol='KIN', Aliases=['BTCD17', 'Rts2', 'KIN'], description='Kin17 DNA and RNA binding protein', other_designations='DNA/RNA-binding protein KIN17|KIN, antigenic determinant of recA protein homolog|binding to curved DNA', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7750962, end_position_on_the_genomic_accession=7787993, orientation='minus', exon_count=14, OMIM=[601720], no_hdr0=''),
    22948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22948, CurrentID=0, Status='live', Symbol='CCT5', Aliases=['CCT-epsilon', 'CCTE', 'HEL-S-69', 'PNAS-102', 'TCP-1-epsilon'], description='chaperonin containing TCP1 subunit 5', other_designations='T-complex protein 1 subunit epsilon|chaperonin containing TCP1, subunit 5 (epsilon)|epididymis secretory protein Li 69', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10249921, end_position_on_the_genomic_accession=10266412, orientation='plus', exon_count=13, OMIM=[610150], no_hdr0=''),
    22949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22949, CurrentID=0, Status='live', Symbol='PTGR1', Aliases=['DIG-1', 'LTB4DH', 'PGR1', 'ZADH3'], description='prostaglandin reductase 1', other_designations='prostaglandin reductase 1|15-oxoprostaglandin 13-reductase|D3T-inducible gene 1 protein|NAD(P)H-dependent alkenal/one oxidoreductase|NADP-dependent leukotriene B4 12-hydroxydehydrogenase|PRG-1|dithiolethione-inducible gene 1 protein|leukotriene B4 12-hydroxydehydrogenase|zinc binding alcohol dehydrogenase domain containing 3', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111549722, end_position_on_the_genomic_accession=111599855, orientation='minus', exon_count=14, OMIM=[601274], no_hdr0=''),
    22950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22950, CurrentID=0, Status='live', Symbol='SLC4A1AP', Aliases=['HLC3'], description='solute carrier family 4 member 1 adaptor protein', other_designations='kanadaptin|HLC-3|human lung cancer oncogene 3 protein|kidney anion exchanger adapter protein|kidney anion exchanger adaptor protein|lung cancer oncogene 3|solute carrier family 4 (anion exchanger), member 1, adapter protein|solute carrier family 4 (anion exchanger), member 1, adaptor protein|solute carrier family 4 anion exchanger member 1 adapter protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27663471, end_position_on_the_genomic_accession=27694980, orientation='plus', exon_count=14, OMIM=[602655], no_hdr0=''),
    22953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22953, CurrentID=0, Status='live', Symbol='P2RX2', Aliases=['DFNA41', 'P2X2'], description='purinergic receptor P2X 2', other_designations='P2X purinoceptor 2|ATP receptor|P2X Receptor, subunit 2|purinergic receptor P2X, ligand gated ion channel, 2', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132618776, end_position_on_the_genomic_accession=132623736, orientation='plus', exon_count=10, OMIM=[600844], no_hdr0=''),
    22954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22954, CurrentID=0, Status='live', Symbol='TRIM32', Aliases=['BBS11', 'HT2A', 'LGMD2H', 'LGMDR8', 'TATIP'], description='tripartite motif containing 32', other_designations='E3 ubiquitin-protein ligase TRIM32|72 kDa Tat-interacting protein|RING-type E3 ubiquitin transferase TRIM32|TAT-interactive protein, 72-KD|tripartite motif-containing protein 32|zinc-finger protein HT2A', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=116687305, end_position_on_the_genomic_accession=116701299, orientation='plus', exon_count=4, OMIM=[602290], no_hdr0=''),
    22955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22955, CurrentID=0, Status='live', Symbol='SCMH1', Aliases=['Scml3'], description='Scm polycomb group protein homolog 1', other_designations='polycomb protein SCMH1|sex comb on midleg homolog 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=41027202, end_position_on_the_genomic_accession=41242306, orientation='minus', exon_count=22, OMIM=[616396], no_hdr0=''),
    22974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22974, CurrentID=0, Status='live', Symbol='TPX2', Aliases=['C20orf1', 'C20orf2', 'DIL-2', 'DIL2', 'FLS353', 'GD:C20orf1', 'HCA519', 'HCTP4', 'REPP86', 'p100'], description='TPX2 microtubule nucleation factor', other_designations='targeting protein for Xklp2|TPX2, microtubule-associated protein homolog|TPX2, microtubule-associated, homolog|differentially expressed in cancerous and non-cancerous lung cells 2|differentially expressed in lung cells|hepatocellular carcinoma-associated antigen 519|hepatocellular carcinoma-associated antigen 90|preferentially expressed in colorectal cancer|protein fls353|restricted expression proliferation associated protein 100', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31739248, end_position_on_the_genomic_accession=31801802, orientation='plus', exon_count=18, OMIM=[605917], no_hdr0=''),
    22976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22976, CurrentID=0, Status='live', Symbol='PAXIP1', Aliases=['CAGF28', 'CAGF29', 'PACIP1L', 'PTIP', 'TNRC2', 'PAXIP1'], description='PAX interacting protein 1', other_designations='PAX-interacting protein 1|PAX interacting (with transcription-activation domain) protein 1|PAX transcription activation domain interacting protein 1 like|protein encoded by CAG trinucleotide repeats', map_location='7q36.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=154943690, end_position_on_the_genomic_accession=155003419, orientation='minus', exon_count=24, OMIM=[608254], no_hdr0=''),
    22977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22977, CurrentID=0, Status='live', Symbol='AKR7A3', Aliases=['AFAR2'], description='aldo-keto reductase family 7 member A3', other_designations='aflatoxin B1 aldehyde reductase member 3|AFB1 aldehyde reductase 2|AFB1-AR 2|aflatoxin B1 aldehyde reductase 2|aflatoxin aldehyde reductase|epididymis secretory sperm binding protein', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19274229, end_position_on_the_genomic_accession=19289362, orientation='minus', exon_count=9, OMIM=[608477], no_hdr0=''),
    22978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22978, CurrentID=0, Status='live', Symbol='NT5C2', Aliases=['GMP', 'NT5B', 'PNT5', 'SPG45', 'SPG65', 'cN-II'], description="5'-nucleotidase, cytosolic II", other_designations="cytosolic purine 5'-nucleotidase|5'-nucleotidase (purine), cytosolic type B|IMP-specific 5'-NT|epididymis secretory sperm binding protein|spastic paraplegia 45 (autosomal recessive)", map_location='10q24.32-q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103088017, end_position_on_the_genomic_accession=103193301, orientation='minus', exon_count=27, OMIM=[600417], no_hdr0=''),
    22979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22979, CurrentID=0, Status='live', Symbol='EFR3B', Aliases=['KIAA0953'], description='EFR3 homolog B', other_designations='protein EFR3 homolog B', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25042076, end_position_on_the_genomic_accession=25159137, orientation='plus', exon_count=24, OMIM=[616797], no_hdr0=''),
    22980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22980, CurrentID=0, Status='live', Symbol='TCF25', Aliases=['FKSG26', 'Hulp1', 'NULP1', 'PRO2620', 'hKIAA1049'], description='transcription factor 25', other_designations='transcription factor 25|TCF-25|nuclear localized protein 1|transcription factor 25 (basic helix-loop-helix)', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89873592, end_position_on_the_genomic_accession=89911384, orientation='plus', exon_count=21, OMIM=[612326], no_hdr0=''),
    22981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22981, CurrentID=0, Status='live', Symbol='NINL', Aliases=['NLP'], description='ninein like', other_designations='ninein-like protein', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25452697, end_position_on_the_genomic_accession=25585531, orientation='minus', exon_count=33, OMIM=[609580], no_hdr0=''),
    22982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22982, CurrentID=0, Status='live', Symbol='DIP2C', Aliases=['KIAA0934'], description='disco interacting protein 2 homolog C', other_designations='disco-interacting protein 2 homolog C|DIP2 disco-interacting protein 2 homolog C|DIP2 homolog C', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=274201, end_position_on_the_genomic_accession=689710, orientation='minus', exon_count=43, OMIM=[611380], no_hdr0=''),
    22983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22983, CurrentID=0, Status='live', Symbol='MAST1', Aliases=['MCCCHCM', 'SAST'], description='microtubule associated serine/threonine kinase 1', other_designations='microtubule-associated serine/threonine-protein kinase 1|syntrophin associated serine/threonine kinase|syntrophin-associated serine/threonine-protein kinase', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12838515, end_position_on_the_genomic_accession=12874952, orientation='plus', exon_count=26, OMIM=[612256], no_hdr0=''),
    22984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22984, CurrentID=0, Status='live', Symbol='PDCD11', Aliases=['ALG-4', 'ALG4', 'NFBP', 'RRP5'], description='programmed cell death 11', other_designations='protein RRP5 homolog|NF-kappa-B-binding protein|apoptosis-linked gene 4|programmed cell death protein 11', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103396615, end_position_on_the_genomic_accession=103446295, orientation='plus', exon_count=38, OMIM=[612333], no_hdr0=''),
    22985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22985, CurrentID=0, Status='live', Symbol='ACIN1', Aliases=['ACINUS', 'ACN', 'fSAP152'], description='apoptotic chromatin condensation inducer 1', other_designations='apoptotic chromatin condensation inducer in the nucleus|functional spliceosome-associated protein 152', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23058564, end_position_on_the_genomic_accession=23095614, orientation='minus', exon_count=22, OMIM=[604562], no_hdr0=''),
    22986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22986, CurrentID=0, Status='live', Symbol='SORCS3', Aliases=['SORCS'], description='sortilin related VPS10 domain containing receptor 3', other_designations='VPS10 domain-containing receptor SorCS3|VPS10 domain receptor protein SORCS 3 (SORCS3)', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104641290, end_position_on_the_genomic_accession=105265242, orientation='plus', exon_count=28, OMIM=[606285], no_hdr0=''),
    22987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22987, CurrentID=0, Status='live', Symbol='SV2C', Aliases=[], description='synaptic vesicle glycoprotein 2C', other_designations='synaptic vesicle glycoprotein 2C|synaptic vesicle protein 2C', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75847463, end_position_on_the_genomic_accession=76353939, orientation='plus', exon_count=18, OMIM=[610291], no_hdr0=''),
    22989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22989, CurrentID=0, Status='live', Symbol='MYH15', Aliases=[], description='myosin heavy chain 15', other_designations='myosin-15|myosin, heavy polypeptide 15', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108380368, end_position_on_the_genomic_accession=108549462, orientation='minus', exon_count=44, OMIM=[609929], no_hdr0=''),
    22990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22990, CurrentID=0, Status='live', Symbol='PCNX1', Aliases=['PCNX', 'PCNXL1', 'pecanex'], description='pecanex 1', other_designations='pecanex-like protein 1|pecanex homolog 1', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70907443, end_position_on_the_genomic_accession=71115382, orientation='plus', exon_count=38, OMIM=[617655], no_hdr0=''),
    22992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22992, CurrentID=0, Status='live', Symbol='KDM2A', Aliases=['CXXC8', 'FBL11', 'FBL7', 'FBXL11', 'JHDM1A', 'LILINA'], description='lysine demethylase 2A', other_designations='lysine-specific demethylase 2A|CXXC-type zinc finger protein 8|F-box and leucine-rich repeat protein 11|F-box/LRR-repeat protein 11|[Histone-H3]-lysine-36 demethylase 1A|jmjC domain-containing histone demethylation protein 1A|jumonji C domain-containing histone demethylase 1A|lysine (K)-specific demethylase 2A', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67119263, end_position_on_the_genomic_accession=67258082, orientation='plus', exon_count=25, OMIM=[605657], no_hdr0=''),
    22993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22993, CurrentID=0, Status='live', Symbol='HMGXB3', Aliases=['HMGX3', 'SMF'], description='HMG-box containing 3', other_designations='HMG domain-containing protein 3|HMG box domain containing 3', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150000611, end_position_on_the_genomic_accession=150053128, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    22994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22994, CurrentID=0, Status='live', Symbol='CEP131', Aliases=['AZ1', 'AZI1', 'ZA1'], description='centrosomal protein 131', other_designations='centrosomal protein of 131 kDa|5-azacytidine induced 1|5-azacytidine-induced protein 1|centrosomal protein 131 kDa|centrosomal protein 131kDa|pre-acrosome localization protein 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81189595, end_position_on_the_genomic_accession=81222989, orientation='minus', exon_count=27, OMIM=[613479], no_hdr0=''),
    22995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22995, CurrentID=0, Status='live', Symbol='CEP152', Aliases=['MCPH4', 'MCPH9', 'SCKL5'], description='centrosomal protein 152', other_designations='centrosomal protein of 152 kDa|asterless|centrosomal protein 152kDa|microcephaly, primary autosomal recessive 4', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48662534, end_position_on_the_genomic_accession=48811904, orientation='minus', exon_count=37, OMIM=[613529], no_hdr0=''),
    22996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22996, CurrentID=0, Status='live', Symbol='TTC39A', Aliases=['C1orf34', 'DEME-6'], description='tetratricopeptide repeat domain 39A', other_designations='tetratricopeptide repeat protein 39A|TPR repeat protein 39A|differentially expressed in MCF7 with estradiol protein 6|testicular tissue protein Li 213', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51287258, end_position_on_the_genomic_accession=51345116, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    22997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22997, CurrentID=0, Status='live', Symbol='IGSF9B', Aliases=['LINC00947', 'MIR4697HG'], description='immunoglobulin superfamily member 9B', other_designations='protein turtle homolog B|MIR4697 host gene (non-protein coding)|long intergenic non-protein coding RNA 947', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=133896438, end_position_on_the_genomic_accession=133956968, orientation='minus', exon_count=20, OMIM=[613773], no_hdr0=''),
    22998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22998, CurrentID=0, Status='live', Symbol='LIMCH1', Aliases=['LIMCH1A', 'LMO7B'], description='LIM and calponin homology domains 1', other_designations='LIM and calponin homology domains-containing protein 1', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41359607, end_position_on_the_genomic_accession=41700044, orientation='plus', exon_count=38, OMIM=[617750], no_hdr0=''),
    22999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=22999, CurrentID=0, Status='live', Symbol='RIMS1', Aliases=['CORD7', 'RAB3IP2', 'RIM', 'RIM1'], description='regulating synaptic membrane exocytosis 1', other_designations='regulating synaptic membrane exocytosis protein 1|RAB3-interacting protein 2|rab-3-interacting protein 2|rab3-interacting molecule 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=71886550, end_position_on_the_genomic_accession=72403145, orientation='plus', exon_count=43, OMIM=[606629], no_hdr0=''),
    23001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23001, CurrentID=0, Status='live', Symbol='WDFY3', Aliases=['ALFY', 'BCHS', 'MCPH18', 'ZFYVE25'], description='WD repeat and FYVE domain containing 3', other_designations='WD repeat and FYVE domain-containing protein 3|autophagy-linked FYVE protein', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=84669597, end_position_on_the_genomic_accession=84966690, orientation='minus', exon_count=74, OMIM=[617485], no_hdr0=''),
    23002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23002, CurrentID=0, Status='live', Symbol='DAAM1', Aliases=[], description='dishevelled associated activator of morphogenesis 1', other_designations='disheveled-associated activator of morphogenesis 1', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59188657, end_position_on_the_genomic_accession=59371405, orientation='plus', exon_count=26, OMIM=[606626], no_hdr0=''),
    23005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23005, CurrentID=0, Status='live', Symbol='MAPKBP1', Aliases=['JNKBP-1', 'JNKBP1', 'NPHP20'], description='mitogen-activated protein kinase binding protein 1', other_designations='mitogen-activated protein kinase-binding protein 1|JNK-binding protein 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41774484, end_position_on_the_genomic_accession=41827855, orientation='plus', exon_count=32, OMIM=[616786], no_hdr0=''),
    23007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23007, CurrentID=0, Status='live', Symbol='PLCH1', Aliases=['PLC eta 1', 'PLC-L3', 'PLCL3'], description='phospholipase C eta 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase eta-1|PLC-eta-1|phosphoinositide phospholipase C-eta-1|phospholipase C-eta1a|phospholipase C-eta1b|phospholipase C-like 3|phospholipase C-like protein 3', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155458603, end_position_on_the_genomic_accession=155745724, orientation='minus', exon_count=33, OMIM=[612835], no_hdr0=''),
    23008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23008, CurrentID=0, Status='live', Symbol='KLHDC10', Aliases=['slim'], description='kelch domain containing 10', other_designations='kelch domain-containing protein 10|PNAS-119|scruin like at the midline homolog', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130070532, end_position_on_the_genomic_accession=130135705, orientation='plus', exon_count=10, OMIM=[615152], no_hdr0=''),
    23011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23011, CurrentID=0, Status='live', Symbol='RAB21', Aliases=[], description='RAB21, member RAS oncogene family', other_designations='ras-related protein Rab-21|GTP-binding protein RAB21', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71754863, end_position_on_the_genomic_accession=71800286, orientation='plus', exon_count=7, OMIM=[612398], no_hdr0=''),
    23012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23012, CurrentID=0, Status='live', Symbol='STK38L', Aliases=['NDR2'], description='serine/threonine kinase 38 like', other_designations='serine/threonine-protein kinase 38-like|NDR2 protein kinase|nuclear Dbf2-related 2|nuclear Dbf2-related kinase 2', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27244233, end_position_on_the_genomic_accession=27325959, orientation='plus', exon_count=20, OMIM=[615836], no_hdr0=''),
    23013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23013, CurrentID=0, Status='live', Symbol='SPEN', Aliases=['HIAA0929', 'MINT', 'RATARS', 'RBM15C', 'SHARP'], description='spen family transcriptional repressor', other_designations='msx2-interacting protein|Msx2 interacting nuclear target (MINT) homolog|SMART/HDAC1-associated repressor protein|nuclear receptor transcription cofactor|spen homolog, transcriptional regulator', map_location='1p36.21-p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15847707, end_position_on_the_genomic_accession=15940456, orientation='plus', exon_count=15, OMIM=[613484], no_hdr0=''),
    23014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23014, CurrentID=0, Status='live', Symbol='FBXO21', Aliases=['FBX21'], description='F-box protein 21', other_designations='F-box only protein 21', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=117141991, end_position_on_the_genomic_accession=117190471, orientation='minus', exon_count=13, OMIM=[609095], no_hdr0=''),
    23015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23015, CurrentID=0, Status='live', Symbol='GOLGA8A', Aliases=['CFAP286', 'FAP286', 'GM88', 'GOLGA8B'], description='golgin A8 family member A', other_designations='golgin subfamily A member 8A|88 kDa Golgi matrix protein|88-kDa golgi protein|GM88 autoantigen|Golgin subfamily A member 8B|golgi autoantigen, golgin subfamily a, 8A|golgin-67', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34379068, end_position_on_the_genomic_accession=34437808, orientation='minus', exon_count=24, OMIM=[616180], no_hdr0=''),
    23016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23016, CurrentID=0, Status='live', Symbol='EXOSC7', Aliases=['EAP1', 'RRP42', 'Rrp42p', 'hRrp42p', 'p8'], description='exosome component 7', other_designations='exosome complex component RRP42|exosome complex exonuclease RRP42|ribosomal RNA-processing protein 42', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44975291, end_position_on_the_genomic_accession=45012668, orientation='plus', exon_count=11, OMIM=[606488], no_hdr0=''),
    23017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23017, CurrentID=0, Status='live', Symbol='FAIM2', Aliases=['LFG', 'LFG2', 'NGP35', 'NMP35', 'TMBIM2'], description='Fas apoptotic inhibitory molecule 2', other_designations='protein lifeguard 2|neural membrane protein 35|transmembrane BAX inhibitor motif-containing protein 2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49866896, end_position_on_the_genomic_accession=49903900, orientation='minus', exon_count=13, OMIM=[604306], no_hdr0=''),
    23019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23019, CurrentID=0, Status='live', Symbol='CNOT1', Aliases=['AD-005', 'CDC39', 'HPE12', 'NOT1', 'NOT1H', 'VIBOS'], description='CCR4-NOT transcription complex subunit 1', other_designations='CCR4-NOT transcription complex subunit 1|CCR4-associated factor 1|NOT1 (negative regulator of transcription 1, yeast) homolog|adrenal gland protein AD-005|negative regulator of transcription subunit 1 homolog', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58519951, end_position_on_the_genomic_accession=58629826, orientation='minus', exon_count=50, OMIM=[604917], no_hdr0=''),
    23020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23020, CurrentID=0, Status='live', Symbol='SNRNP200', Aliases=['ASCC3L1', 'BRR2', 'HELIC2', 'RP33', 'U5-200KD'], description='small nuclear ribonucleoprotein U5 subunit 200', other_designations='U5 small nuclear ribonucleoprotein 200 kDa helicase|BRR2 homolog|U5 snRNP-specific 200 kDa protein|activating signal cointegrator 1 complex subunit 3-like 1|bad response to refrigeration 2 homolog|small nuclear ribonucleoprotein 200kDa (U5)|small nuclear ribonucleoprotein, U5 200kDa subunit', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96274338, end_position_on_the_genomic_accession=96305546, orientation='minus', exon_count=45, OMIM=[601664], no_hdr0=''),
    23022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23022, CurrentID=0, Status='live', Symbol='PALLD', Aliases=['CGI-151', 'CGI151', 'MYN', 'PNCA1', 'SIH002'], description='palladin, cytoskeletal associated protein', other_designations='palladin|myoneurin|sarcoma antigen NY-SAR-77', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=168497039, end_position_on_the_genomic_accession=168928441, orientation='plus', exon_count=29, OMIM=[608092], no_hdr0=''),
    23023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23023, CurrentID=0, Status='live', Symbol='TMCC1', Aliases=[], description='transmembrane and coiled-coil domain family 1', other_designations='transmembrane and coiled-coil domains protein 1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129647792, end_position_on_the_genomic_accession=129893711, orientation='minus', exon_count=17, OMIM=[616242], no_hdr0=''),
    23024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23024, CurrentID=0, Status='live', Symbol='PDZRN3', Aliases=['LNX3', 'SEMACAP3', 'SEMCAP3'], description='PDZ domain containing ring finger 3', other_designations='E3 ubiquitin-protein ligase PDZRN3|RING-type E3 ubiquitin transferase PDZRN3|ligand of Numb protein X 3|likely ortholog of mouse semaF cytoplasmic domain associated protein 3|semaphorin cytoplasmic domain-associated protein 3', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=73382430, end_position_on_the_genomic_accession=73624997, orientation='minus', exon_count=14, OMIM=[609729], no_hdr0=''),
    23025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23025, CurrentID=0, Status='live', Symbol='UNC13A', Aliases=['Munc13-1'], description='unc-13 homolog A', other_designations='protein unc-13 homolog A', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17601328, end_position_on_the_genomic_accession=17688354, orientation='minus', exon_count=44, OMIM=[609894], no_hdr0=''),
    23026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23026, CurrentID=0, Status='live', Symbol='MYO16', Aliases=['MYAP3', 'MYR8', 'Myo16b', 'NYAP3', 'PPP1R107'], description='myosin XVI', other_designations='unconventional myosin-XVI|MYO16 variant protein|myosin heavy chain Myr 8|neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adapter 3|neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adaptor 3|protein phosphatase 1, regulatory subunit 107|unconventional myosin-16', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=108495729, end_position_on_the_genomic_accession=109208005, orientation='plus', exon_count=37, OMIM=[615479], no_hdr0=''),
    23028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23028, CurrentID=0, Status='live', Symbol='KDM1A', Aliases=['AOF2', 'BHC110', 'CPRF', 'KDM1', 'LSD1'], description='lysine demethylase 1A', other_designations='lysine-specific histone demethylase 1A|BRAF35-HDAC complex protein BHC110|FAD-binding protein BRAF35-HDAC complex, 110 kDa subunit|[histone H3]-dimethyl-L-lysine(4) FAD-dependent demethylase 1A|amine oxidase (flavin containing) domain 2|flavin-containing amine oxidase domain-containing protein 2|lysine (K)-specific demethylase 1A|lysine-specific histone demethylase 1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23019443, end_position_on_the_genomic_accession=23083691, orientation='plus', exon_count=21, OMIM=[609132], no_hdr0=''),
    23029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23029, CurrentID=0, Status='live', Symbol='RBM34', Aliases=[], description='RNA binding motif protein 34', other_designations='RNA-binding protein 34|epididymis secretory sperm binding protein', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235131183, end_position_on_the_genomic_accession=235161280, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    23030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23030, CurrentID=0, Status='live', Symbol='KDM4B', Aliases=['JMJD2B', 'MRD65', 'TDRD14B'], description='lysine demethylase 4B', other_designations='lysine-specific demethylase 4B|[histone H3]-trimethyl-L-lysine(9) demethylase 4B|jmjC domain-containing histone demethylation protein 3B|jumonji domain containing 2B|jumonji domain-containing protein 2B|lysine (K)-specific demethylase 4B|tudor domain containing 14B', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4969087, end_position_on_the_genomic_accession=5153603, orientation='plus', exon_count=31, OMIM=[609765], no_hdr0=''),
    23031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23031, CurrentID=0, Status='live', Symbol='MAST3', Aliases=[], description='microtubule associated serine/threonine kinase 3', other_designations='microtubule-associated serine/threonine-protein kinase 3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18097778, end_position_on_the_genomic_accession=18151692, orientation='plus', exon_count=34, OMIM=[612258], no_hdr0=''),
    23032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23032, CurrentID=0, Status='live', Symbol='USP33', Aliases=['VDU1'], description='ubiquitin specific peptidase 33', other_designations='ubiquitin carboxyl-terminal hydrolase 33|VHL-interacting deubiquitinating enzyme 1|deubiquitinating enzyme 33|pVHL-interacting deubiquitinating enzyme 1|ubiquitin thioesterase 33|ubiquitin thiolesterase 33|ubiquitin-specific-processing protease 33', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77695987, end_position_on_the_genomic_accession=77759852, orientation='minus', exon_count=27, OMIM=[615146], no_hdr0=''),
    23033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23033, CurrentID=0, Status='live', Symbol='DOP1A', Aliases=['DOP1', 'DOPEY1', 'KIAA1117', 'dJ202D23.2'], description='DOP1 leucine zipper like protein A', other_designations='protein dopey-1|dopey family member 1|homolog of yeast DOP1', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83067671, end_position_on_the_genomic_accession=83171351, orientation='plus', exon_count=46, OMIM=[616823], no_hdr0=''),
    23034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23034, CurrentID=0, Status='live', Symbol='SAMD4A', Aliases=['SAMD4', 'SMAUG', 'SMAUG1', 'SMG', 'SMGA'], description='sterile alpha motif domain containing 4A', other_designations='protein Smaug homolog 1|SAM domain-containing protein 4A', map_location='14q22.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=54567097, end_position_on_the_genomic_accession=54793315, orientation='plus', exon_count=16, OMIM=[610747], no_hdr0=''),
    23035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23035, CurrentID=0, Status='live', Symbol='PHLPP2', Aliases=['PHLPPL', 'PPM3B'], description='PH domain and leucine rich repeat protein phosphatase 2', other_designations='PH domain leucine-rich repeat-containing protein phosphatase 2|protein phosphatase, Mg2+/Mn2+ dependent 3B', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71644924, end_position_on_the_genomic_accession=71724701, orientation='minus', exon_count=20, OMIM=[611066], no_hdr0=''),
    23036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23036, CurrentID=0, Status='live', Symbol='ZNF292', Aliases=['MRD63', 'MRD64', 'Nbla00365', 'ZFP292', 'ZN-16', 'Zn-15', 'bA393I2.3'], description='zinc finger protein 292', other_designations='zinc finger protein 292|16 zinc-finger domain protein|putative protein product of Nbla00365', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87155565, end_position_on_the_genomic_accession=87265943, orientation='plus', exon_count=14, OMIM=[616213], no_hdr0=''),
    23037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23037, CurrentID=0, Status='live', Symbol='PDZD2', Aliases=['AIPC', 'PAPIN', 'PDZK3', 'PIN1'], description='PDZ domain containing 2', other_designations='PDZ domain-containing protein 2|PDZ domain-containing protein 3|activated in prostate cancer protein|plakophilin-related armadillo repeat protein-interactive PDZ protein', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=31639131, end_position_on_the_genomic_accession=32110932, orientation='plus', exon_count=30, OMIM=[610697], no_hdr0=''),
    23038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23038, CurrentID=0, Status='live', Symbol='WDTC1', Aliases=['ADP', 'DCAF9'], description='WD and tetratricopeptide repeats 1', other_designations='WD and tetratricopeptide repeats protein 1|DDB1 and CUL4 associated factor 9|adipose homolog', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27234613, end_position_on_the_genomic_accession=27308636, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    23039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23039, CurrentID=0, Status='live', Symbol='XPO7', Aliases=['EXP7', 'RANBP16'], description='exportin 7', other_designations='exportin-7|RAN binding protein 16', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=21919662, end_position_on_the_genomic_accession=22006585, orientation='plus', exon_count=29, OMIM=[606140], no_hdr0=''),
    23040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23040, CurrentID=0, Status='live', Symbol='MYT1L', Aliases=['MRD39', 'NZF1', 'ZC2H2C2', 'ZC2HC4B', 'myT1-L'], description='myelin transcription factor 1 like', other_designations='myelin transcription factor 1-like protein|neural zinc finger transcription factor 1', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=1789113, end_position_on_the_genomic_accession=2331388, orientation='minus', exon_count=34, OMIM=[613084], no_hdr0=''),
    23041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23041, CurrentID=0, Status='live', Symbol='MON2', Aliases=[], description='MON2 homolog, regulator of endosome-to-Golgi trafficking', other_designations='protein MON2 homolog|MON2 regulator of endosome-to-Golgi trafficking', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=62466817, end_position_on_the_genomic_accession=62600476, orientation='plus', exon_count=40, OMIM=[616822], no_hdr0=''),
    23042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23042, CurrentID=0, Status='live', Symbol='PDXDC1', Aliases=['LP8165'], description='pyridoxal dependent decarboxylase domain containing 1', other_designations='pyridoxal-dependent decarboxylase domain-containing protein 1', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14974591, end_position_on_the_genomic_accession=15153343, orientation='plus', exon_count=31, OMIM=[614244], no_hdr0=''),
    23043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23043, CurrentID=0, Status='live', Symbol='TNIK', Aliases=['MRT54'], description='TRAF2 and NCK interacting kinase', other_designations='TRAF2 and NCK-interacting protein kinase', map_location='3q26.2-q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=171058414, end_position_on_the_genomic_accession=171460408, orientation='minus', exon_count=34, OMIM=[610005], no_hdr0=''),
    23046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23046, CurrentID=0, Status='live', Symbol='KIF21B', Aliases=[], description='kinesin family member 21B', other_designations='kinesin-like protein KIF21B', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200969390, end_position_on_the_genomic_accession=201023714, orientation='minus', exon_count=37, OMIM=[608322], no_hdr0=''),
    23047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23047, CurrentID=0, Status='live', Symbol='PDS5B', Aliases=['APRIN', 'AS3', 'CG008'], description='PDS5 cohesin associated factor B', other_designations='sister chromatid cohesion protein PDS5 homolog B|androgen induced inhibitor of proliferation|androgen-induced proliferation inhibitor|androgen-induced prostate proliferative shutoff-associated protein AS3|androgen-induced shutoff 3', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32586432, end_position_on_the_genomic_accession=32778019, orientation='plus', exon_count=38, OMIM=[605333], no_hdr0=''),
    23048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23048, CurrentID=0, Status='live', Symbol='FNBP1', Aliases=['FBP17'], description='formin binding protein 1', other_designations='formin-binding protein 1|formin-binding protein 17', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129887187, end_position_on_the_genomic_accession=130053846, orientation='minus', exon_count=19, OMIM=[606191], no_hdr0=''),
    23049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23049, CurrentID=0, Status='live', Symbol='SMG1', Aliases=['61E3.4', 'ATX', 'LIP'], description='SMG1 nonsense mediated mRNA decay associated PI3K related kinase', other_designations='serine/threonine-protein kinase SMG1|PI-3-kinase-related kinase SMG-1|SMG1 phosphatidylinositol 3-kinase-related kinase|lambda-interacting protein|lambda/iota protein kinase C-interacting protein|smg-1 homolog, phosphatidylinositol 3-kinase-related kinase', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18804858, end_position_on_the_genomic_accession=18926428, orientation='minus', exon_count=65, OMIM=[607032], no_hdr0=''),
    23051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23051, CurrentID=0, Status='live', Symbol='ZHX3', Aliases=['TIX1'], description='zinc fingers and homeoboxes 3', other_designations='zinc fingers and homeoboxes protein 3|triple homeobox 1|triple homeobox protein 1|zinc finger and homeodomain protein 3', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41178450, end_position_on_the_genomic_accession=41317731, orientation='minus', exon_count=15, OMIM=[609598], no_hdr0=''),
    23052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23052, CurrentID=0, Status='live', Symbol='ENDOD1', Aliases=[], description='endonuclease domain containing 1', other_designations='endonuclease domain-containing 1 protein', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95089846, end_position_on_the_genomic_accession=95132645, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    23053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23053, CurrentID=0, Status='live', Symbol='ZSWIM8', Aliases=['KIAA0913'], description='zinc finger SWIM-type containing 8', other_designations='zinc finger SWIM domain-containing protein 8', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73785577, end_position_on_the_genomic_accession=73801793, orientation='plus', exon_count=27, OMIM=[619213], no_hdr0=''),
    23054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23054, CurrentID=0, Status='live', Symbol='NCOA6', Aliases=['AIB3', 'ASC2', 'NRC', 'PRIP', 'RAP250', 'TRBP'], description='nuclear receptor coactivator 6', other_designations='nuclear receptor coactivator 6|NRC RAP250|PPAR-interacting protein|activating signal cointegrator-2|amplified in breast cancer protein 3|amplified in breast cancer-3 protein|cancer-amplified transcriptional coactivator ASC-2|nuclear receptor coactivator RAP250|nuclear receptor-activating protein, 250 kDa|peroxisome proliferator-activated receptor interacting protein|thyroid hormone receptor binding protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34714774, end_position_on_the_genomic_accession=34825651, orientation='minus', exon_count=20, OMIM=[605299], no_hdr0=''),
    23057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23057, CurrentID=0, Status='live', Symbol='NMNAT2', Aliases=['C1orf15', 'PNAT2'], description='nicotinamide nucleotide adenylyltransferase 2', other_designations='nicotinamide/nicotinic acid mononucleotide adenylyltransferase 2|NMN adenylyltransferase 2|NMN/NaMN adenylyltransferase 2|NaMN adenylyltransferase 2|nicotinamide mononucleotide adenylyltransferase 2|nicotinate-nucleotide adenylyltransferase 2|pyridine nucleotide adenylyltransferase 2', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183248237, end_position_on_the_genomic_accession=183418380, orientation='minus', exon_count=13, OMIM=[608701], no_hdr0=''),
    23059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23059, CurrentID=0, Status='live', Symbol='CLUAP1', Aliases=['CFAP22', 'FAP22', 'IFT38'], description='clusterin associated protein 1', other_designations='clusterin-associated protein 1|cilia and flagella associated protein 22|flagellar associated protein 22, qilin-like protein, homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3500978, end_position_on_the_genomic_accession=3539048, orientation='plus', exon_count=14, OMIM=[616787], no_hdr0=''),
    23060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23060, CurrentID=0, Status='live', Symbol='ZNF609', Aliases=[], description='zinc finger protein 609', other_designations='zinc finger protein 609', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64460350, end_position_on_the_genomic_accession=64686068, orientation='plus', exon_count=11, OMIM=[617474], no_hdr0=''),
    23061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23061, CurrentID=0, Status='live', Symbol='TBC1D9B', Aliases=['GRAMD9B'], description='TBC1 domain family member 9B', other_designations='TBC1 domain family member 9B|TBC1 domain family, member 9B (with GRAM domain)', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179862071, end_position_on_the_genomic_accession=179907897, orientation='minus', exon_count=22, OMIM=[618039], no_hdr0=''),
    23062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23062, CurrentID=0, Status='live', Symbol='GGA2', Aliases=['VEAR'], description='golgi associated, gamma adaptin ear containing, ARF binding protein 2', other_designations='ADP-ribosylation factor-binding protein GGA2|VHS domain and ear domain of gamma-adaptin|VHS domain and ear domain-containing protein|gamma-adaptin-related protein 2|golgi-localized, gamma ear-containing, ARF-binding protein 2', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23463542, end_position_on_the_genomic_accession=23510494, orientation='minus', exon_count=18, OMIM=[606005], no_hdr0=''),
    23063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23063, CurrentID=0, Status='live', Symbol='WAPL', Aliases=['FOE', 'KIAA0261', 'WAPAL'], description='WAPL cohesin release factor', other_designations='wings apart-like protein homolog|friend of EBNA2 (Epstein-Barr virus nuclear protein 2)|friend of EBNA2 protein', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86435256, end_position_on_the_genomic_accession=86521816, orientation='minus', exon_count=20, OMIM=[610754], no_hdr0=''),
    23064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23064, CurrentID=0, Status='live', Symbol='SETX', Aliases=['ALS4', 'AOA2', 'SCAN2', 'SCAR1', 'Sen1', 'bA479K20.2'], description='senataxin', other_designations='probable helicase senataxin|SEN1 homolog|amyotrophic lateral sclerosis 4 protein', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132261356, end_position_on_the_genomic_accession=132356726, orientation='minus', exon_count=33, OMIM=[608465], no_hdr0=''),
    23065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23065, CurrentID=0, Status='live', Symbol='EMC1', Aliases=['CAVIPMR', 'KIAA0090'], description='ER membrane protein complex subunit 1', other_designations='ER membrane protein complex subunit 1', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19215660, end_position_on_the_genomic_accession=19251524, orientation='minus', exon_count=24, OMIM=[616846], no_hdr0=''),
    23066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23066, CurrentID=0, Status='live', Symbol='CAND2', Aliases=['TIP120B', 'Tp120b'], description='cullin associated and neddylation dissociated 2 (putative)', other_designations='cullin-associated NEDD8-dissociated protein 2|TBP interacting protein|TBP-interacting protein 120B|TBP-interacting protein of 120 kDa B|cullin-associated and neddylation-dissociated protein 2|epididymis secretory sperm binding protein|epididymis tissue protein Li 169|p120 CAND2', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12796654, end_position_on_the_genomic_accession=12834818, orientation='plus', exon_count=17, OMIM=[610403], no_hdr0=''),
    23067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23067, CurrentID=0, Status='live', Symbol='SETD1B', Aliases=['IDDSELD', 'KMT2G', 'Set1B'], description='SET domain containing 1B, histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase SETD1B|SET domain-containing protein 1B|lysine N-methyltransferase 2G', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121803665, end_position_on_the_genomic_accession=121832656, orientation='plus', exon_count=19, OMIM=[611055], no_hdr0=''),
    23070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23070, CurrentID=0, Status='live', Symbol='CMTR1', Aliases=['FTSJD2', 'KIAA0082', 'MTr1', 'hMTr1'], description='cap methyltransferase 1', other_designations="cap-specific mRNA (nucleoside-2'-O-)-methyltransferase 1|FtsJ methyltransferase domain containing 2|ISG95|S-adenosyl-L-methionine-dependent methyltransferase FTSJD2|cap1 2'O-ribose methyltransferase 1|ftsJ methyltransferase domain-containing protein 2|interferon-stimulated gene 95 kDa protein", map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37433214, end_position_on_the_genomic_accession=37482844, orientation='plus', exon_count=25, OMIM=[616189], no_hdr0=''),
    23071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23071, CurrentID=0, Status='live', Symbol='ERP44', Aliases=['PDIA10', 'TXNDC4'], description='endoplasmic reticulum protein 44', other_designations='endoplasmic reticulum resident protein 44|ER protein 44|endoplasmic reticulum resident protein 44 kDa|epididymis secretory sperm binding protein|protein disulfide isomerase family A, member 10|thioredoxin domain containing 4 (endoplasmic reticulum)|thioredoxin domain-containing protein 4', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99979185, end_position_on_the_genomic_accession=100099000, orientation='minus', exon_count=12, OMIM=[609170], no_hdr0=''),
    23072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23072, CurrentID=0, Status='live', Symbol='HECW1', Aliases=['NEDL1'], description='HECT, C2 and WW domain containing E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase HECW1|HECT type E3 ubiquitin ligase|HECT-type E3 ubiquitin transferase HECW1|NEDD4-like ubiquitin-protein ligase 1', map_location='7p14.1-p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43112580, end_position_on_the_genomic_accession=43566001, orientation='plus', exon_count=36, OMIM=[610384], no_hdr0=''),
    23074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23074, CurrentID=0, Status='live', Symbol='UHRF1BP1L', Aliases=['SHIP164'], description='UHRF1 binding protein 1 like', other_designations='UHRF1-binding protein 1-like|UHRF1 (ICBP90) binding protein 1-like|syntaxin 6Habc-interacting protein of 164 kDa|syntaxin-6 Habc-interacting protein of 164 kDa', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100026251, end_position_on_the_genomic_accession=100142874, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    23075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23075, CurrentID=0, Status='live', Symbol='SWAP70', Aliases=['HSPC321', 'SWAP-70'], description='switching B cell complex subunit SWAP70', other_designations='switch-associated protein 70|SWAP switching B-cell complex 70kDa subunit|SWAP switching B-cell complex subunit 70', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9664077, end_position_on_the_genomic_accession=9752993, orientation='plus', exon_count=13, OMIM=[604762], no_hdr0=''),
    23076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23076, CurrentID=0, Status='live', Symbol='RRP1B', Aliases=['KIAA0179', 'NNP1L', 'Nnp1', 'PPP1R136', 'RRP1'], description='ribosomal RNA processing 1B', other_designations='ribosomal RNA processing protein 1 homolog B|RRP1-like protein B|protein phosphatase 1, regulatory subunit 136|ribosomal RNA processing 1 homolog B', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43659560, end_position_on_the_genomic_accession=43696079, orientation='plus', exon_count=16, OMIM=[610654], no_hdr0=''),
    23077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23077, CurrentID=0, Status='live', Symbol='MYCBP2', Aliases=['Myc-bp2', 'PAM', 'PHR1', 'Phr'], description='MYC binding protein 2', other_designations='E3 ubiquitin-protein ligase MYCBP2|Highwire|MYC binding protein 2, E3 ubiquitin protein ligase|PAM/Highwire/RPM-1 protein 1|RING-type E3 ubiquitin transferase MYCBP2|myc-binding protein 2|protein associated with Myc', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=77044657, end_position_on_the_genomic_accession=77327098, orientation='minus', exon_count=89, OMIM=[610392], no_hdr0=''),
    23078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23078, CurrentID=0, Status='live', Symbol='VWA8', Aliases=['KIAA0564', 'P7BP2'], description='von Willebrand factor A domain containing 8', other_designations='von Willebrand factor A domain-containing protein 8|PEX7-binding protein 2|Pex7p-binding protein 2', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41566835, end_position_on_the_genomic_accession=41961109, orientation='minus', exon_count=45, OMIM=[617509], no_hdr0=''),
    23080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23080, CurrentID=0, Status='live', Symbol='AVL9', Aliases=['KIAA0241'], description='AVL9 cell migration associated', other_designations='late secretory pathway protein AVL9 homolog|AVL9 homolog (S. cerevisiase)', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=32495489, end_position_on_the_genomic_accession=32588726, orientation='plus', exon_count=19, OMIM=[612927], no_hdr0=''),
    23081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23081, CurrentID=0, Status='live', Symbol='KDM4C', Aliases=['GASC1', 'JHDM3C', 'JMJD2C', 'TDRD14C'], description='lysine demethylase 4C', other_designations='lysine-specific demethylase 4C|JmjC domain-containing histone demethylation protein 3C|[histone H3]-trimethyl-L-lysine(9) demethylase 4C|gene amplified in squamous cell carcinoma 1 protein|jumonji domain-containing protein 2C|lysine (K)-specific demethylase 4C|tudor domain containing 14C', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6720863, end_position_on_the_genomic_accession=7175648, orientation='plus', exon_count=30, OMIM=[605469], no_hdr0=''),
    23082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23082, CurrentID=0, Status='live', Symbol='PPRC1', Aliases=['PRC'], description='PPARG related coactivator 1', other_designations='peroxisome proliferator-activated receptor gamma coactivator-related protein 1|PGC-1-related coactivator|peroxisome proliferator-activated receptor gamma, coactivator-related 1', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102120634, end_position_on_the_genomic_accession=102150333, orientation='plus', exon_count=19, OMIM=[617462], no_hdr0=''),
    23085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23085, CurrentID=0, Status='live', Symbol='ERC1', Aliases=['Cast2', 'ELKS', 'ERC-1', 'RAB6IP2'], description='ELKS/RAB6-interacting/CAST family member 1', other_designations='ELKS/Rab6-interacting/CAST family member 1|RAB6 interacting protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=990030, end_position_on_the_genomic_accession=1495933, orientation='plus', exon_count=30, OMIM=[607127], no_hdr0=''),
    23086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23086, CurrentID=0, Status='live', Symbol='EXPH5', Aliases=['SLAC2-B', 'SLAC2B'], description='exophilin 5', other_designations='exophilin-5|slp homolog lacking C2 domains b|synaptotagmin-like homologue lacking C2 domains b|synaptotagmin-like protein homolog lacking C2 domains b', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108505431, end_position_on_the_genomic_accession=108607514, orientation='minus', exon_count=13, OMIM=[612878], no_hdr0=''),
    23087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23087, CurrentID=0, Status='live', Symbol='TRIM35', Aliases=['HLS5', 'MAIR'], description='tripartite motif containing 35', other_designations='E3 ubiquitin-protein ligase TRIM35|hemopoietic lineage switch protein 5|tripartite motif-containing protein 35', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27284886, end_position_on_the_genomic_accession=27311272, orientation='minus', exon_count=7, OMIM=[617007], no_hdr0=''),
    23089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23089, CurrentID=0, Status='live', Symbol='PEG10', Aliases=['EDR', 'HB-1', 'MEF3L', 'Mar2', 'Mart2', 'RGAG3', 'RTL2', 'SIRH1'], description='paternally expressed 10', other_designations='retrotransposon-derived protein PEG10|MEF3 like 1|Sushi-Ichi retrotransposon homolog 1|embryonal carcinoma differentiation regulated|mammalian retrotransposon-derived 2|mammalian retrotransposon-derived protein 2|myelin expression factor 3-like protein 1|paternally expressed gene 10 protein|retrotransposon Gag like 2|retrotransposon gag domain-containing protein 3|retrotransposon-derived gag-like polyprotein|ty3/Gypsy-like protein', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=94656325, end_position_on_the_genomic_accession=94669695, orientation='plus', exon_count=2, OMIM=[609810], no_hdr0=''),
    23090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23090, CurrentID=0, Status='live', Symbol='ZNF423', Aliases=['Ebfaz', 'JBTS19', 'NPHP14', 'OAZ', 'Roaz', 'ZFP423', 'Zfp104', 'hOAZ'], description='zinc finger protein 423', other_designations='zinc finger protein 423|OLF-1/EBF associated zinc finger|Smad- and Olf-interacting zinc finger protein|early B-cell factor associated zinc finger protein|olf1/EBF-associated zinc finger protein', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=49487524, end_position_on_the_genomic_accession=49857919, orientation='minus', exon_count=17, OMIM=[604557], no_hdr0=''),
    23091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23091, CurrentID=0, Status='live', Symbol='ZC3H13', Aliases=['KIAA0853', 'Xio'], description='zinc finger CCCH-type containing 13', other_designations='zinc finger CCCH domain-containing protein 13', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45954465, end_position_on_the_genomic_accession=46052794, orientation='minus', exon_count=22, OMIM=[616453], no_hdr0=''),
    23092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23092, CurrentID=0, Status='live', Symbol='ARHGAP26', Aliases=['GRAF', 'GRAF1', 'OPHN1L', 'OPHN1L1'], description='Rho GTPase activating protein 26', other_designations='rho GTPase-activating protein 26|GTPase regulator associated with focal adhesion kinase pp125(FAK)|oligophrenin-1-like protein', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=142770370, end_position_on_the_genomic_accession=143229011, orientation='plus', exon_count=36, OMIM=[605370], no_hdr0=''),
    23093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23093, CurrentID=0, Status='live', Symbol='TTLL5', Aliases=['CORD19', 'KIAA0998', 'STAMP'], description='tubulin tyrosine ligase like 5', other_designations='tubulin polyglutamylase TTLL5|SRC1 and TIF2 associated binding protein|SRC1 and TIF2-associated modulatory protein|tubulin tyrosine ligase-like family, member 5', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75661246, end_position_on_the_genomic_accession=75955079, orientation='plus', exon_count=32, OMIM=[612268], no_hdr0=''),
    23094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23094, CurrentID=0, Status='live', Symbol='SIPA1L3', Aliases=['CTRCT45', 'SPAL3', 'SPAR3'], description='signal induced proliferation associated 1 like 3', other_designations='signal-induced proliferation-associated 1-like protein 3|SIPA1-like protein 3|SPA-1-like protein 3|spine-associated RapGAP 3', map_location='19q13.13-q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37906822, end_position_on_the_genomic_accession=38208369, orientation='plus', exon_count=24, OMIM=[616655], no_hdr0=''),
    23095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23095, CurrentID=0, Status='live', Symbol='KIF1B', Aliases=['CMT2', 'CMT2A', 'CMT2A1', 'HMSNII', 'KLP', 'NBLST1'], description='kinesin family member 1B', other_designations='kinesin-like protein KIF1B|kinesin superfamily protein KIF1B', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10210570, end_position_on_the_genomic_accession=10381603, orientation='plus', exon_count=52, OMIM=[605995], no_hdr0=''),
    23096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23096, CurrentID=0, Status='live', Symbol='IQSEC2', Aliases=['BRAG1', 'IQ-ArfGEF', 'MRX1', 'MRX18', 'MRX78'], description='IQ motif and Sec7 domain ArfGEF 2', other_designations='IQ motif and SEC7 domain-containing protein 2|IQ motif and Sec7 domain 2|brefeldin A resistant Arf-guanine nucleotide exchange factor 1|brefeldin A resistant Arf-guanine nucleotide exchange factor 1b|brefeldin A resistant Arf-guanine nucleotide exchange factor 1c|mental retardation, X-linked 18', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53225784, end_position_on_the_genomic_accession=53321356, orientation='minus', exon_count=23, OMIM=[300522], no_hdr0=''),
    23097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23097, CurrentID=0, Status='live', Symbol='CDK19', Aliases=['CDC2L6', 'CDK11', 'DEE87', 'EIEE87', 'bA346C16.3'], description='cyclin dependent kinase 19', other_designations='cyclin-dependent kinase 19|CDC2-related protein kinase 6|CDK8-like cyclin-dependent kinase|cell division cycle 2-like 6 (CDK8-like)|cell division cycle 2-like protein kinase 6|cell division protein kinase 19|cyclin dependent kinase 19 variant 2|cyclin-dependent kinase (CDC2-like) 11|cyclin-dependent kinase 11|death-preventing kinase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110609978, end_position_on_the_genomic_accession=110816531, orientation='minus', exon_count=22, OMIM=[614720], no_hdr0=''),
    23098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23098, CurrentID=0, Status='live', Symbol='SARM1', Aliases=['HsTIR', 'MyD88-5', 'SAMD2', 'SARM', 'hSARM1'], description='sterile alpha and TIR motif containing 1', other_designations='NAD(+) hydrolase SARM1|NADP(+) hydrolase SARM1|NADase SARM1|SAM domain-containing protein 2|sterile alpha and Armadillo repeat protein|sterile alpha and HEAT/Armadillo motif protein, ortholog of Drosophila|sterile alpha and TIR motif-containing protein 1|sterile alpha motif domain-containing protein 2|tir-1 homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28371694, end_position_on_the_genomic_accession=28404049, orientation='plus', exon_count=9, OMIM=[607732], no_hdr0=''),
    23099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23099, CurrentID=0, Status='live', Symbol='ZBTB43', Aliases=['ZBTB22B', 'ZNF-X', 'ZNF297B'], description='zinc finger and BTB domain containing 43', other_designations='zinc finger and BTB domain-containing protein 43|zinc finger and BTB domain-containing protein 22B|zinc finger protein 297B', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=126804072, end_position_on_the_genomic_accession=126838210, orientation='plus', exon_count=6, OMIM=[618676], no_hdr0=''),
    23101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23101, CurrentID=0, Status='live', Symbol='MCF2L2', Aliases=['ARHGEF22'], description='MCF.2 cell line derived transforming sequence-like 2', other_designations='probable guanine nucleotide exchange factor MCF2L2|MCF2-transforming sequence-like protein 2|dbs-related Rho family guanine nucleotide exchange factor', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183176116, end_position_on_the_genomic_accession=183428619, orientation='minus', exon_count=33, OMIM=[], no_hdr0=''),
    23102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23102, CurrentID=0, Status='live', Symbol='TBC1D2B', Aliases=['NEDSGO'], description='TBC1 domain family member 2B', other_designations='TBC1 domain family member 2B', map_location='15q24.3-q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=77994985, end_position_on_the_genomic_accession=78077711, orientation='minus', exon_count=18, OMIM=[619152], no_hdr0=''),
    23105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23105, CurrentID=0, Status='live', Symbol='FSTL4', Aliases=[], description='follistatin like 4', other_designations='follistatin-related protein 4|follistatin-like protein 4', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=133194827, end_position_on_the_genomic_accession=133842066, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    23107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23107, CurrentID=0, Status='live', Symbol='MRPS27', Aliases=['MRP-S27', 'S27mt'], description='mitochondrial ribosomal protein S27', other_designations='28S ribosomal protein S27, mitochondrial|mitochondrial 28S ribosomal protein S27|mitochondrial small ribosomal subunit protein mS27', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72219403, end_position_on_the_genomic_accession=72320240, orientation='minus', exon_count=12, OMIM=[611989], no_hdr0=''),
    23108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23108, CurrentID=0, Status='live', Symbol='RAP1GAP2', Aliases=['GARNL4', 'RAP1GA3'], description='RAP1 GTPase activating protein 2', other_designations='rap1 GTPase-activating protein 2|GTPase activating RANGAP domain-like 4|GTPase activating Rap/RanGAP domain-like 4|GTPase-activating Rap/Ran-GAP domain-like protein 4', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2755686, end_position_on_the_genomic_accession=3037741, orientation='plus', exon_count=34, OMIM=[618714], no_hdr0=''),
    23109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23109, CurrentID=0, Status='live', Symbol='DDN', Aliases=[], description='dendrin', other_designations='dendrin', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48995149, end_position_on_the_genomic_accession=49001773, orientation='minus', exon_count=3, OMIM=[610588], no_hdr0=''),
    23111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23111, CurrentID=0, Status='live', Symbol='SPART', Aliases=['SPG20', 'TAHCCP1'], description='spartin', other_designations='spartin|spastic paraplegia 20 (Troyer syndrome)|trans-activated by hepatitis C virus core protein 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36301638, end_position_on_the_genomic_accession=36370180, orientation='minus', exon_count=14, OMIM=[607111], no_hdr0=''),
    23112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23112, CurrentID=0, Status='live', Symbol='TNRC6B', Aliases=['GDSBA'], description='trinucleotide repeat containing adaptor 6B', other_designations='trinucleotide repeat-containing gene 6B protein|trinucleotide repeat containing 6B', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40044834, end_position_on_the_genomic_accession=40335808, orientation='plus', exon_count=27, OMIM=[610740], no_hdr0=''),
    23113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23113, CurrentID=0, Status='live', Symbol='CUL9', Aliases=['H7AP1', 'PARC'], description='cullin 9', other_designations='cullin-9|CUL-9|UbcH7-associated protein 1|p53-associated parkin-like cytoplasmic protein|parkin-like cytoplasmic p53 binding protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43182170, end_position_on_the_genomic_accession=43224587, orientation='plus', exon_count=43, OMIM=[607489], no_hdr0=''),
    23114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23114, CurrentID=0, Status='live', Symbol='NFASC', Aliases=['NEDCPMD', 'NF', 'NRCAML'], description='neurofascin', other_designations='neurofascin|neurofascin homolog', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204828652, end_position_on_the_genomic_accession=205022822, orientation='plus', exon_count=36, OMIM=[609145], no_hdr0=''),
    23116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23116, CurrentID=0, Status='live', Symbol='TOGARAM1', Aliases=['FAM179B', 'JBTS37', 'KIAA0423'], description='TOG array regulator of axonemal microtubules 1', other_designations='TOG array regulator of axonemal microtubules protein 1|crescerin|crescerin-1|family with sequence similarity 179 member B|protein FAM179B', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=44962190, end_position_on_the_genomic_accession=45074431, orientation='plus', exon_count=22, OMIM=[617618], no_hdr0=''),
    23117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23117, CurrentID=0, Status='live', Symbol='NPIPB3', Aliases=['KIAA0220L', 'NPIP', 'NPIPB', 'NPIPB5', 'NPIPL3'], description='nuclear pore complex interacting protein family member B3', other_designations='nuclear pore complex-interacting protein family member B3|KIAA0220-like protein|nuclear pore complex-interacting protein B type|nuclear pore complex-interacting protein-like 3|protein pps22-1', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21402129, end_position_on_the_genomic_accession=21425378, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    23118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23118, CurrentID=0, Status='live', Symbol='TAB2', Aliases=['CHTD2', 'MAP3K7IP2', 'TAB-2'], description='TGF-beta activated kinase 1 (MAP3K7) binding protein 2', other_designations='TGF-beta-activated kinase 1 and MAP3K7-binding protein 2|TAK1-binding protein 2|mitogen-activated protein kinase kinase kinase 7-interacting protein 2', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149217926, end_position_on_the_genomic_accession=149411611, orientation='plus', exon_count=15, OMIM=[605101], no_hdr0=''),
    23119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23119, CurrentID=0, Status='live', Symbol='HIC2', Aliases=['HRG22', 'ZBTB30', 'ZNF907'], description='HIC ZBTB transcriptional repressor 2', other_designations='hypermethylated in cancer 2 protein|HIC1-related gene on chromosome 22 protein|hic-2|hic-3|zinc finger and BTB domain-containing protein 30', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21417371, end_position_on_the_genomic_accession=21451463, orientation='plus', exon_count=5, OMIM=[607712], no_hdr0=''),
    23120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23120, CurrentID=0, Status='live', Symbol='ATP10B', Aliases=['ATPVB'], description='ATPase phospholipid transporting 10B (putative)', other_designations='phospholipid-transporting ATPase VB|ATPase, class V, type 10B|P4-ATPase flippase complex alpha subunit ATP10B|probable phospholipid-transporting ATPase VB', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160563120, end_position_on_the_genomic_accession=160929411, orientation='minus', exon_count=28, OMIM=[], no_hdr0=''),
    23122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23122, CurrentID=0, Status='live', Symbol='CLASP2', Aliases=[], description='cytoplasmic linker associated protein 2', other_designations='CLIP-associating protein 2|CLIP-associating protein CLASP2|multiple asters (Mast)-like homolog 2|protein Orbit homolog 2', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33496245, end_position_on_the_genomic_accession=33718356, orientation='minus', exon_count=45, OMIM=[605853], no_hdr0=''),
    23125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23125, CurrentID=0, Status='live', Symbol='CAMTA2', Aliases=[], description='calmodulin binding transcription activator 2', other_designations='calmodulin-binding transcription activator 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4967993, end_position_on_the_genomic_accession=4988281, orientation='minus', exon_count=24, OMIM=[611508], no_hdr0=''),
    23126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23126, CurrentID=0, Status='live', Symbol='POGZ', Aliases=['MRD37', 'WHSUS', 'ZNF280E', 'ZNF635', 'ZNF635m'], description='pogo transposable element derived with ZNF domain', other_designations='pogo transposable element with ZNF domain|putative protein product of Nbla00003|zinc finger protein 280E|zinc finger protein 635', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151402724, end_position_on_the_genomic_accession=151459494, orientation='minus', exon_count=23, OMIM=[614787], no_hdr0=''),
    23127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23127, CurrentID=0, Status='live', Symbol='COLGALT2', Aliases=['C1orf17', 'ColGalT 2', 'GLT25D2'], description='collagen beta(1-O)galactosyltransferase 2', other_designations='procollagen galactosyltransferase 2|glycosyltransferase 25 domain containing 2|glycosyltransferase 25 family member 2|hydroxylysine galactosyltransferase 2', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183929662, end_position_on_the_genomic_accession=184037728, orientation='minus', exon_count=13, OMIM=[617533], no_hdr0=''),
    23129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23129, CurrentID=0, Status='live', Symbol='PLXND1', Aliases=['PLEXD1'], description='plexin D1', other_designations='plexin-D1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129555214, end_position_on_the_genomic_accession=129606676, orientation='minus', exon_count=37, OMIM=[604282], no_hdr0=''),
    23130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23130, CurrentID=0, Status='live', Symbol='ATG2A', Aliases=[], description='autophagy related 2A', other_designations='autophagy-related protein 2 homolog A|ATG2 autophagy related 2 homolog A', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64894546, end_position_on_the_genomic_accession=64917241, orientation='minus', exon_count=41, OMIM=[616225], no_hdr0=''),
    23131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23131, CurrentID=0, Status='live', Symbol='GPATCH8', Aliases=['GPATC8', 'KIAA0553'], description='G-patch domain containing 8', other_designations='G patch domain-containing protein 8', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44395277, end_position_on_the_genomic_accession=44503589, orientation='minus', exon_count=13, OMIM=[614396], no_hdr0=''),
    23132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23132, CurrentID=0, Status='live', Symbol='RAD54L2', Aliases=['ARIP4', 'HSPC325', 'SRISNF2L'], description='RAD54 like 2', other_designations='helicase ARIP4|AR interacting protein 4|RAD54-like protein 2|androgen receptor-interacting protein 4', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51538719, end_position_on_the_genomic_accession=51668660, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    23133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23133, CurrentID=0, Status='live', Symbol='PHF8', Aliases=['JHDM1F', 'KDM7B', 'MRXSSD', 'ZNF422'], description='PHD finger protein 8', other_designations='histone lysine demethylase PHF8|[histone H3]-dimethyl-L-lysine(36) demethylase PHF8|[histone H3]-dimethyl-L-lysine(9) demethylase PHF8|jumonji C domain-containing histone demethylase 1F', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53936680, end_position_on_the_genomic_accession=54048935, orientation='minus', exon_count=28, OMIM=[300560], no_hdr0=''),
    23135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23135, CurrentID=0, Status='live', Symbol='KDM6B', Aliases=['JMJD3', 'NEDCFSA'], description='lysine demethylase 6B', other_designations='lysine-specific demethylase 6B|[histone H3]-trimethyl-L-lysine(27) demethylase 6B|jmjC domain-containing protein 3|jumonji domain containing 3, histone lysine demethylase|jumonji domain-containing protein 3|lysine (K)-specific demethylase 6B', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7834210, end_position_on_the_genomic_accession=7854796, orientation='plus', exon_count=28, OMIM=[611577], no_hdr0=''),
    23136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23136, CurrentID=0, Status='live', Symbol='EPB41L3', Aliases=['4.1B', 'DAL-1', 'DAL1'], description='erythrocyte membrane protein band 4.1 like 3', other_designations='band 4.1-like protein 3|differentially expressed in adenocarcinoma of the lung protein 1', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5392386, end_position_on_the_genomic_accession=5630663, orientation='minus', exon_count=30, OMIM=[605331], no_hdr0=''),
    23137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23137, CurrentID=0, Status='live', Symbol='SMC5', Aliases=['SMC5L1'], description='structural maintenance of chromosomes 5', other_designations='structural maintenance of chromosomes protein 5|SMC protein 5|SMC-5|SMC5 structural maintenance of chromosomes 5-like 1|hSMC5', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=70258962, end_position_on_the_genomic_accession=70354873, orientation='plus', exon_count=27, OMIM=[609386], no_hdr0=''),
    23138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23138, CurrentID=0, Status='live', Symbol='N4BP3', Aliases=['LZTS4'], description='NEDD4 binding protein 3', other_designations='NEDD4-binding protein 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178113506, end_position_on_the_genomic_accession=178127034, orientation='plus', exon_count=6, OMIM=[619140], no_hdr0=''),
    23139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23139, CurrentID=0, Status='live', Symbol='MAST2', Aliases=['MAST205', 'MTSSK'], description='microtubule associated serine/threonine kinase 2', other_designations='microtubule-associated serine/threonine-protein kinase 2|microtubule associated testis specific serine/threonine protein kinase', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45786992, end_position_on_the_genomic_accession=46036124, orientation='plus', exon_count=39, OMIM=[612257], no_hdr0=''),
    23140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23140, CurrentID=0, Status='live', Symbol='ZZEF1', Aliases=['ZZZ4'], description='zinc finger ZZ-type and EF-hand domain containing 1', other_designations='zinc finger ZZ-type and EF-hand domain-containing protein 1|zinc finger, ZZ-type with EF hand domain 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4004445, end_position_on_the_genomic_accession=4143030, orientation='minus', exon_count=55, OMIM=[], no_hdr0=''),
    23141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23141, CurrentID=0, Status='live', Symbol='ANKLE2', Aliases=['KIAA0692', 'LEMD7', 'Lem4', 'MCPH16'], description='ankyrin repeat and LEM domain containing 2', other_designations='ankyrin repeat and LEM domain-containing protein 2|LEM domain containing 7|LEM domain-containing protein 4', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132725503, end_position_on_the_genomic_accession=132761832, orientation='minus', exon_count=17, OMIM=[616062], no_hdr0=''),
    23142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23142, CurrentID=0, Status='live', Symbol='DCUN1D4', Aliases=['DCNL4'], description='defective in cullin neddylation 1 domain containing 4', other_designations='DCN1-like protein 4|DCN1, defective in cullin neddylation 1, domain containing 4|DCUN1 domain-containing protein 4|defective in cullin neddylation protein 1-like protein 4', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=51843132, end_position_on_the_genomic_accession=51916837, orientation='plus', exon_count=20, OMIM=[612977], no_hdr0=''),
    23143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23143, CurrentID=0, Status='live', Symbol='LRCH1', Aliases=['CHDC1', 'NP81'], description='leucine rich repeats and calponin homology domain containing 1', other_designations='leucine-rich repeat and calponin homology domain-containing protein 1|leucine-rich repeats and calponin homology (CH) domain containing 1|neuronal protein 81', map_location='13q14.13-q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46553170, end_position_on_the_genomic_accession=46753041, orientation='plus', exon_count=21, OMIM=[610368], no_hdr0=''),
    23144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23144, CurrentID=0, Status='live', Symbol='ZC3H3', Aliases=['SMICL', 'ZC3HDC3'], description='zinc finger CCCH-type containing 3', other_designations='zinc finger CCCH domain-containing protein 3|smad-interacting CPSF-like factor|zinc finger CCCH-type domain containing 3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143437655, end_position_on_the_genomic_accession=143549729, orientation='minus', exon_count=16, OMIM=[618640], no_hdr0=''),
    23148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23148, CurrentID=0, Status='live', Symbol='NACAD', Aliases=[], description='NAC alpha domain containing', other_designations='NAC-alpha domain-containing protein 1', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=45080432, end_position_on_the_genomic_accession=45089452, orientation='minus', exon_count=7, OMIM=[619419], no_hdr0=''),
    23149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23149, CurrentID=0, Status='live', Symbol='FCHO1', Aliases=['IMD76'], description='FCH and mu domain containing endocytic adaptor 1', other_designations='F-BAR domain only protein 1|FCH domain only 1|FCH domain only protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17747744, end_position_on_the_genomic_accession=17788562, orientation='plus', exon_count=31, OMIM=[613437], no_hdr0=''),
    23150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23150, CurrentID=0, Status='live', Symbol='FRMD4B', Aliases=['6030440G05Rik', 'GRSP1'], description='FERM domain containing 4B', other_designations='FERM domain-containing protein 4B|GRP1-binding protein GRSP1', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69168782, end_position_on_the_genomic_accession=69541340, orientation='minus', exon_count=32, OMIM=[617467], no_hdr0=''),
    23151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23151, CurrentID=0, Status='live', Symbol='GRAMD4', Aliases=['DIP'], description='GRAM domain containing 4', other_designations='GRAM domain-containing protein 4|death-inducing-protein', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46576017, end_position_on_the_genomic_accession=46682756, orientation='plus', exon_count=25, OMIM=[613691], no_hdr0=''),
    23152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23152, CurrentID=0, Status='live', Symbol='CIC', Aliases=['MRD45'], description='capicua transcriptional repressor', other_designations='protein capicua homolog', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42268530, end_position_on_the_genomic_accession=42295796, orientation='plus', exon_count=23, OMIM=[612082], no_hdr0=''),
    23154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23154, CurrentID=0, Status='live', Symbol='NCDN', Aliases=['NEDIES'], description='neurochondrin', other_designations='neurochondrin|norbin', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35557799, end_position_on_the_genomic_accession=35566779, orientation='plus', exon_count=8, OMIM=[608458], no_hdr0=''),
    23155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23155, CurrentID=0, Status='live', Symbol='CLCC1', Aliases=['MCLC', 'RP32'], description='chloride channel CLIC like 1', other_designations='chloride channel CLIC-like protein 1|Mid-1-related chloride channel protein 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108929505, end_position_on_the_genomic_accession=108963484, orientation='minus', exon_count=15, OMIM=[617539], no_hdr0=''),
    23157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23157, CurrentID=0, Status='live', Symbol='SEPTIN6', Aliases=['SEP2', 'SEPT2', 'SEPT6'], description='septin 6', other_designations='septin-6|septin 2', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119615724, end_position_on_the_genomic_accession=119693196, orientation='minus', exon_count=12, OMIM=[300683], no_hdr0=''),
    23158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23158, CurrentID=0, Status='live', Symbol='TBC1D9', Aliases=['GRAMD9', 'MDR1'], description='TBC1 domain family member 9', other_designations='TBC1 domain family member 9|TBC1 domain family member 9A|TBC1 domain family, member 9 (with GRAM domain)', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140620782, end_position_on_the_genomic_accession=140756385, orientation='minus', exon_count=21, OMIM=[618035], no_hdr0=''),
    23160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23160, CurrentID=0, Status='live', Symbol='WDR43', Aliases=['NET12', 'UTP5'], description='WD repeat domain 43', other_designations='WD repeat-containing protein 43|U3 small nucleolar RNA-associated protein 5 homolog|UTP5, small subunit (SSU) processome component, homolog', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28894667, end_position_on_the_genomic_accession=28948219, orientation='plus', exon_count=18, OMIM=[616195], no_hdr0=''),
    23161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23161, CurrentID=0, Status='live', Symbol='SNX13', Aliases=['RGS-PX1'], description='sorting nexin 13', other_designations='sorting nexin-13|rgs domain- and phox domain-containing protein', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=17790761, end_position_on_the_genomic_accession=17940507, orientation='minus', exon_count=33, OMIM=[606589], no_hdr0=''),
    23162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23162, CurrentID=0, Status='live', Symbol='MAPK8IP3', Aliases=['JIP-3', 'JIP3', 'JSAP1', 'NEDBA', 'SYD2', 'syd'], description='mitogen-activated protein kinase 8 interacting protein 3', other_designations='C-Jun-amino-terminal kinase-interacting protein 3|C-jun-amino-terminal kinase interacting protein 3|JNK MAP kinase scaffold protein 3|JNK-interacting protein 3|JNK/SAPK-associated protein-1|JNK/stress-activated protein kinase-associated protein 1|homolog of Drosophila Sunday driver 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1706183, end_position_on_the_genomic_accession=1770351, orientation='plus', exon_count=33, OMIM=[605431], no_hdr0=''),
    23163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23163, CurrentID=0, Status='live', Symbol='GGA3', Aliases=[], description='golgi associated, gamma adaptin ear containing, ARF binding protein 3', other_designations='ADP-ribosylation factor-binding protein GGA3|Golgi-localized, gamma ear-containing, ARF-binding protein 3', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75225464, end_position_on_the_genomic_accession=75262363, orientation='minus', exon_count=20, OMIM=[606006], no_hdr0=''),
    23164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23164, CurrentID=0, Status='live', Symbol='MPRIP', Aliases=['M-RIP', 'MRIP', 'RHOIP3', 'RIP3', 'p116Rip'], description='myosin phosphatase Rho interacting protein', other_designations='myosin phosphatase Rho-interacting protein|Rho interacting protein 3', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17042455, end_position_on_the_genomic_accession=17192648, orientation='plus', exon_count=25, OMIM=[612935], no_hdr0=''),
    23165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23165, CurrentID=0, Status='live', Symbol='NUP205', Aliases=['C7orf14', 'NPHS13'], description='nucleoporin 205', other_designations='nuclear pore complex protein Nup205|205 kDa nucleoporin|nucleoporin Nup205', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135557917, end_position_on_the_genomic_accession=135648753, orientation='plus', exon_count=43, OMIM=[614352], no_hdr0=''),
    23166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23166, CurrentID=0, Status='live', Symbol='STAB1', Aliases=['CLEVER-1', 'FEEL-1', 'FELE-1', 'FEX1', 'SCARH2', 'STAB-1'], description='stabilin 1', other_designations='stabilin-1|MS-1 antigen|common lymphatic endothelial and vascular endothelial receptor-1|fasciclin egf-like, laminin-type egf-like, and link domain-containing scavenger receptor-1|fasciclin, EGF-like, laminin-type EGF-like and link domain-containing scavenger receptor 1', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52495338, end_position_on_the_genomic_accession=52524496, orientation='plus', exon_count=69, OMIM=[608560], no_hdr0=''),
    23167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23167, CurrentID=0, Status='live', Symbol='EFR3A', Aliases=[], description='EFR3 homolog A', other_designations='protein EFR3 homolog A', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=131904093, end_position_on_the_genomic_accession=132013642, orientation='plus', exon_count=26, OMIM=[611798], no_hdr0=''),
    23168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23168, CurrentID=0, Status='live', Symbol='RTF1', Aliases=['GTL7', 'KIAA0252'], description='RTF1 homolog, Paf1/RNA polymerase II complex component', other_designations='RNA polymerase-associated protein RTF1 homolog|Rtf1, Paf1/RNA polymerase II complex component, homolog|ortholog of mouse gene trap locus 7', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41417095, end_position_on_the_genomic_accession=41483563, orientation='plus', exon_count=18, OMIM=[611633], no_hdr0=''),
    23169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23169, CurrentID=0, Status='live', Symbol='SLC35D1', Aliases=['SHNKND', 'UGTREL7'], description='solute carrier family 35 member D1', other_designations='UDP-glucuronic acid/UDP-N-acetylgalactosamine transporter|UDP-GlcA/UDP-GalNAc transporter|UDP-galactose transporter-related 7|UDP-galactose transporter-related protein 7|solute carrier family 35 (UDP-GlcA/UDP-GalNAc transporter), member D1|solute carrier family 35 (UDP-glucuronic acid/UDP-N-acetylgalactosamine dual transporter), member D1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66999350, end_position_on_the_genomic_accession=67054423, orientation='minus', exon_count=15, OMIM=[610804], no_hdr0=''),
    23170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23170, CurrentID=0, Status='live', Symbol='TTLL12', Aliases=['dJ526I14.2'], description='tubulin tyrosine ligase like 12', other_designations='tubulin--tyrosine ligase-like protein 12|inactive tubulin--tyrosine ligase-like protein 12|tubulin tyrosine ligase-like family, member 12', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43166622, end_position_on_the_genomic_accession=43187134, orientation='minus', exon_count=14, OMIM=[619410], no_hdr0=''),
    23171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23171, CurrentID=0, Status='live', Symbol='GPD1L', Aliases=['GPD1-L'], description='glycerol-3-phosphate dehydrogenase 1 like', other_designations='glycerol-3-phosphate dehydrogenase 1-like protein', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32106620, end_position_on_the_genomic_accession=32168715, orientation='plus', exon_count=8, OMIM=[611778], no_hdr0=''),
    23172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23172, CurrentID=0, Status='live', Symbol='ABRAXAS2', Aliases=['ABRO1', 'FAM175B', 'KIAA0157'], description='abraxas 2, BRISC complex subunit', other_designations='BRISC complex subunit Abraxas 2|BRISC complex subunit Abro1|abraxas brother 1|abraxas brother protein 1|family with sequence similarity 175 member B', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124801803, end_position_on_the_genomic_accession=124836670, orientation='plus', exon_count=9, OMIM=[611144], no_hdr0=''),
    23173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23173, CurrentID=0, Status='live', Symbol='METAP1', Aliases=['MAP1A', 'MetAP1A'], description='methionyl aminopeptidase 1', other_designations='methionine aminopeptidase 1|MAP 1|metAP 1|peptidase M 1', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=98995693, end_position_on_the_genomic_accession=99063109, orientation='plus', exon_count=19, OMIM=[610151], no_hdr0=''),
    23174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23174, CurrentID=0, Status='live', Symbol='ZCCHC14', Aliases=['BDG-29', 'BDG29'], description='zinc finger CCHC-type containing 14', other_designations='zinc finger CCHC domain-containing protein 14|zinc finger, CCHC domain containing 14', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87406248, end_position_on_the_genomic_accession=87493024, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    23175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23175, CurrentID=0, Status='live', Symbol='LPIN1', Aliases=['PAP1'], description='lipin 1', other_designations='phosphatidate phosphatase LPIN1', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11677544, end_position_on_the_genomic_accession=11827409, orientation='plus', exon_count=33, OMIM=[605518], no_hdr0=''),
    23176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23176, CurrentID=0, Status='live', Symbol='SEPTIN8', Aliases=['SEP2', 'SEPT8'], description='septin 8', other_designations='septin-8', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132750819, end_position_on_the_genomic_accession=132778216, orientation='minus', exon_count=15, OMIM=[608418], no_hdr0=''),
    23177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23177, CurrentID=0, Status='live', Symbol='CEP68', Aliases=['KIAA0582'], description='centrosomal protein 68', other_designations='centrosomal protein of 68 kDa|centrosomal protein 68kDa', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=65056402, end_position_on_the_genomic_accession=65087004, orientation='plus', exon_count=9, OMIM=[616889], no_hdr0=''),
    23178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23178, CurrentID=0, Status='live', Symbol='PASK', Aliases=['PASKIN', 'STK37'], description='PAS domain containing serine/threonine kinase', other_designations='PAS domain-containing serine/threonine-protein kinase|per-arnt-sim (PAS) domain kinase', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241106099, end_position_on_the_genomic_accession=241150264, orientation='minus', exon_count=24, OMIM=[607505], no_hdr0=''),
    23179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23179, CurrentID=0, Status='live', Symbol='RGL1', Aliases=['RGL'], description='ral guanine nucleotide dissociation stimulator like 1', other_designations='ral guanine nucleotide dissociation stimulator-like 1|ralGDS-like 1', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183636094, end_position_on_the_genomic_accession=183928532, orientation='plus', exon_count=21, OMIM=[605667], no_hdr0=''),
    23180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23180, CurrentID=0, Status='live', Symbol='RFTN1', Aliases=['MIG2', 'PIB10', 'PIG9', 'RAFTLIN'], description='raftlin, lipid raft linker 1', other_designations='raftlin|cell migration-inducing gene 2 protein|proliferation-inducing protein 10|proliferation-inducing protein 9|raft-linking protein', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16315845, end_position_on_the_genomic_accession=16513699, orientation='minus', exon_count=15, OMIM=[618210], no_hdr0=''),
    23181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23181, CurrentID=0, Status='live', Symbol='DIP2A', Aliases=['C21orf106', 'DIP2'], description='disco interacting protein 2 homolog A', other_designations='disco-interacting protein 2 homolog A|DIP2 disco-interacting protein 2 homolog A|DIP2 homolog A|disco-interacting protein 2A', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46458891, end_position_on_the_genomic_accession=46571226, orientation='plus', exon_count=42, OMIM=[607711], no_hdr0=''),
    23184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23184, CurrentID=0, Status='live', Symbol='MESD', Aliases=['BOCAC2', 'OI20', 'MESD'], description='mesoderm development LRP chaperone', other_designations='LRP chaperone MESD|LDLR chaperone MESD|mesoderm development LRP chaperone MESD|mesoderm development candidate 2|mesoderm development protein|renal carcinoma antigen NY-REN-61', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80946289, end_position_on_the_genomic_accession=80989819, orientation='minus', exon_count=5, OMIM=[607783], no_hdr0=''),
    23185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23185, CurrentID=0, Status='live', Symbol='LARP4B', Aliases=['KIAA0217', 'LARP5'], description='La ribonucleoprotein 4B', other_designations='la-related protein 4B|La ribonucleoprotein domain family member 4B|La ribonucleoprotein domain family, member 5|la-related protein 5', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=806914, end_position_on_the_genomic_accession=931900, orientation='minus', exon_count=23, OMIM=[616513], no_hdr0=''),
    23186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23186, CurrentID=0, Status='live', Symbol='RCOR1', Aliases=['COREST', 'RCOR'], description='REST corepressor 1', other_designations='REST corepressor 1', map_location='14q32.31-q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102592593, end_position_on_the_genomic_accession=102730572, orientation='plus', exon_count=12, OMIM=[607675], no_hdr0=''),
    23187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23187, CurrentID=0, Status='live', Symbol='PHLDB1', Aliases=['LL5A'], description='pleckstrin homology like domain family B member 1', other_designations='pleckstrin homology-like domain family B member 1|LL5alpha|pleckstrin homology-like domain family B member 1 variant 3|pleckstrin homology-like domain family B member 1 variant 4|protein LL5-alpha', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118606296, end_position_on_the_genomic_accession=118658028, orientation='plus', exon_count=34, OMIM=[612834], no_hdr0=''),
    23189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23189, CurrentID=0, Status='live', Symbol='KANK1', Aliases=['ANKRD15', 'CPSQ2', 'KANK'], description='KN motif and ankyrin repeat domains 1', other_designations='KN motif and ankyrin repeat domain-containing protein 1|ankyrin repeat domain-containing protein 15|kidney ankyrin repeat-containing protein', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=470295, end_position_on_the_genomic_accession=746104, orientation='plus', exon_count=28, OMIM=[607704], no_hdr0=''),
    23190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23190, CurrentID=0, Status='live', Symbol='UBXN4', Aliases=['UBXD2', 'UBXDC1', 'erasin'], description='UBX domain protein 4', other_designations='UBX domain-containing protein 4|UBX domain containing 2|UBX domain-containing 1|UBX domain-containing protein 2', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135741855, end_position_on_the_genomic_accession=135785056, orientation='plus', exon_count=13, OMIM=[611216], no_hdr0=''),
    23191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23191, CurrentID=0, Status='live', Symbol='CYFIP1', Aliases=['P140SRA-1', 'SHYC', 'SRA-1', 'SRA1'], description='cytoplasmic FMR1 interacting protein 1', other_designations='cytoplasmic FMR1-interacting protein 1|cytoplasmic FMRP interacting protein 1|selective hybridizing clone|specifically Rac1-associated protein 1', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22867052, end_position_on_the_genomic_accession=22980898, orientation='minus', exon_count=34, OMIM=[606322], no_hdr0=''),
    23192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23192, CurrentID=0, Status='live', Symbol='ATG4B', Aliases=['APG4B', 'AUTL1'], description='autophagy related 4B cysteine peptidase', other_designations='cysteine protease ATG4B|APG4 autophagy 4 homolog B|ATG4 autophagy related 4 homolog B|AUT-like 1 cysteine endopeptidase|autophagin-1|autophagy-related cysteine endopeptidase 1|autophagy-related protein 4 homolog B|hAPG4B', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241637659, end_position_on_the_genomic_accession=241673857, orientation='plus', exon_count=16, OMIM=[611338], no_hdr0=''),
    23193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23193, CurrentID=0, Status='live', Symbol='GANAB', Aliases=['G2AN', 'GIIA', 'GLUII', 'PKD3'], description='glucosidase II alpha subunit', other_designations='neutral alpha-glucosidase AB|alpha-glucosidase 2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62624829, end_position_on_the_genomic_accession=62646613, orientation='minus', exon_count=26, OMIM=[104160], no_hdr0=''),
    23194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23194, CurrentID=0, Status='live', Symbol='FBXL7', Aliases=['FBL6', 'FBL7'], description='F-box and leucine rich repeat protein 7', other_designations='F-box/LRR-repeat protein 7|F-box protein Fbl7', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=15500180, end_position_on_the_genomic_accession=15939796, orientation='plus', exon_count=7, OMIM=[605656], no_hdr0=''),
    23195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23195, CurrentID=0, Status='live', Symbol='MDN1', Aliases=['Rea1'], description='midasin AAA ATPase 1', other_designations='midasin|MDN1, midasin homolog|MIDAS-containing protein|dynein-related AAA-ATPase MDN1', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89642498, end_position_on_the_genomic_accession=89828021, orientation='minus', exon_count=105, OMIM=[618200], no_hdr0=''),
    23196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23196, CurrentID=0, Status='live', Symbol='FAM120A', Aliases=['C9orf10', 'HBVPTPAP', 'OSSA'], description='family with sequence similarity 120A', other_designations='constitutive coactivator of PPAR-gamma-like protein 1|oxidative stess-associated Src activator|oxidative stress-associated Src activator', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93451685, end_position_on_the_genomic_accession=93566112, orientation='plus', exon_count=20, OMIM=[612265], no_hdr0=''),
    23197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23197, CurrentID=0, Status='live', Symbol='FAF2', Aliases=['ETEA', 'UBXD8', 'UBXN3B'], description='Fas associated factor family member 2', other_designations='FAS-associated factor 2|UBX domain containing 8|UBX domain protein 3B|UBX domain-containing protein 3B|UBX domain-containing protein 8|expressed in T-cells and eosinophils in atopic dermatitis', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176448328, end_position_on_the_genomic_accession=176510074, orientation='plus', exon_count=11, OMIM=[616935], no_hdr0=''),
    23198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23198, CurrentID=0, Status='live', Symbol='PSME4', Aliases=['PA200'], description='proteasome activator subunit 4', other_designations='proteasome activator complex subunit 4|proteasome (prosome, macropain) activator subunit 4|proteasome activator 200 kDa|proteasome activator PA200', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53864069, end_position_on_the_genomic_accession=53970993, orientation='minus', exon_count=47, OMIM=[607705], no_hdr0=''),
    23199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23199, CurrentID=0, Status='live', Symbol='GSE1', Aliases=['CRHSP24', 'KIAA0182'], description='Gse1 coiled-coil protein', other_designations='genetic suppressor element 1|CTC-786C10.1|Gse1 coiled-coil protein homolog', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85169512, end_position_on_the_genomic_accession=85676200, orientation='plus', exon_count=28, OMIM=[616886], no_hdr0=''),
    23200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23200, CurrentID=0, Status='live', Symbol='ATP11B', Aliases=['ATPIF', 'ATPIR'], description='ATPase phospholipid transporting 11B (putative)', other_designations='phospholipid-transporting ATPase IF|ATPase IR|ATPase, class VI, type 11B|P4-ATPase flippase complex alpha subunit ATP11B|probable phospholipid-transporting ATPase IF|truncated ATPase 11B protein', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=182793504, end_position_on_the_genomic_accession=182923010, orientation='plus', exon_count=34, OMIM=[605869], no_hdr0=''),
    23201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23201, CurrentID=0, Status='live', Symbol='FAM168A', Aliases=['KIAA0280', 'TCRP1'], description='family with sequence similarity 168 member A', other_designations='protein FAM168A|tongue cancer chemotherapy resistance-associated protein 1', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73400487, end_position_on_the_genomic_accession=73598112, orientation='minus', exon_count=9, OMIM=[616316], no_hdr0=''),
    23203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23203, CurrentID=0, Status='live', Symbol='PMPCA', Aliases=['Alpha-MPP', 'CLA1', 'CPD3', 'INPP5E', 'MAS2', 'P-55', 'SCAR2'], description='peptidase, mitochondrial processing subunit alpha', other_designations='mitochondrial-processing peptidase subunit alpha|Cerebellar ataxia-1|cerebellar ataxia 1 (autosomal recessive)|inactive zinc metalloprotease alpha|inositol polyphosphate-5-phosphatase, 72 kD|mitochondrial matrix processing protease, alpha subunit|peptidase, mitochondrial processing alpha subunit', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136410658, end_position_on_the_genomic_accession=136423761, orientation='plus', exon_count=13, OMIM=[613036], no_hdr0=''),
    23204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23204, CurrentID=0, Status='live', Symbol='ARL6IP1', Aliases=['AIP1', 'ARL6IP', 'ARMER', 'SPG61'], description='ADP ribosylation factor like GTPase 6 interacting protein 1', other_designations='ADP-ribosylation factor-like protein 6-interacting protein 1|ADP-ribosylation factor GTPase 6 interacting protein 1|ADP-ribosylation factor-like 6 interacting protein 1|ARL-6-interacting protein 1|aip-1|apoptotic regulator in the membrane of the endoplasmic reticulum', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18791667, end_position_on_the_genomic_accession=18801549, orientation='minus', exon_count=7, OMIM=[607669], no_hdr0=''),
    23205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23205, CurrentID=0, Status='live', Symbol='ACSBG1', Aliases=['BG', 'BG1', 'BGM', 'GR-LACS', 'LPD'], description='acyl-CoA synthetase bubblegum family member 1', other_designations='long-chain-fatty-acid--CoA ligase ACSBG1|bubblegum|lipidosin|very long-chain acyl-CoA synthetase', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78167468, end_position_on_the_genomic_accession=78234625, orientation='minus', exon_count=19, OMIM=[614362], no_hdr0=''),
    23207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23207, CurrentID=0, Status='live', Symbol='PLEKHM2', Aliases=['SKIP'], description='pleckstrin homology and RUN domain containing M2', other_designations='pleckstrin homology domain-containing family M member 2|PH domain-containing family M member 2|SifA (Salmonella-induced filaments A) and kinesin-interacting protein|novel RUN and PH domain-containing protein|pleckstrin homology domain containing, family M (with RUN domain) member 2', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15681506, end_position_on_the_genomic_accession=15734769, orientation='plus', exon_count=22, OMIM=[609613], no_hdr0=''),
    23208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23208, CurrentID=0, Status='live', Symbol='SYT11', Aliases=['SYT12', 'sytXI'], description='synaptotagmin 11', other_designations='synaptotagmin-11|synaptotagmin 12|synaptotagmin XI', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155859502, end_position_on_the_genomic_accession=155885199, orientation='plus', exon_count=4, OMIM=[608741], no_hdr0=''),
    23209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23209, CurrentID=0, Status='live', Symbol='MLC1', Aliases=['LVM', 'MLC', 'VL'], description='modulator of VRAC current 1', other_designations='membrane protein MLC1|megalencephalic leukoencephalopathy with subcortical cysts 1', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50059391, end_position_on_the_genomic_accession=50085875, orientation='minus', exon_count=15, OMIM=[605908], no_hdr0=''),
    23210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23210, CurrentID=0, Status='live', Symbol='JMJD6', Aliases=['PSR', 'PTDSR', 'PTDSR1'], description='jumonji domain containing 6, arginine demethylase and lysine hydroxylase', other_designations='bifunctional arginine demethylase and lysyl-hydroxylase JMJD6|arginine demethylase and lysine hydroxylase|histone arginine demethylase JMJD6|jmjC domain-containing protein 6|jumonji domain-containing protein 6|lysyl-hydroxylase JMJD6|peptide-lysine 5-dioxygenase JMJD6|phosphatidylserine receptor', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76712830, end_position_on_the_genomic_accession=76726783, orientation='minus', exon_count=8, OMIM=[604914], no_hdr0=''),
    23211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23211, CurrentID=0, Status='live', Symbol='ZC3H4', Aliases=['C19orf7'], description='zinc finger CCCH-type containing 4', other_designations='zinc finger CCCH domain-containing protein 4', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47064187, end_position_on_the_genomic_accession=47114437, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    23212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23212, CurrentID=0, Status='live', Symbol='RRS1', Aliases=[], description='ribosome biogenesis regulator 1 homolog', other_designations='ribosome biogenesis regulatory protein homolog|RRS1 ribosome biogenesis regulator homolog|homolog of yeast ribosome biogenesis regulator|homolog of yeast ribosome biogenesis regulatory protein RRS1|ribosome biogenesis regulator homolog|ribosome biogenesis regulatory protein RRS1 homolog', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66429014, end_position_on_the_genomic_accession=66430733, orientation='plus', exon_count=1, OMIM=[618311], no_hdr0=''),
    23213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23213, CurrentID=0, Status='live', Symbol='SULF1', Aliases=['SULF-1'], description='sulfatase 1', other_designations='extracellular sulfatase Sulf-1|sulfatase FP', map_location='8q13.2-q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=69466624, end_position_on_the_genomic_accession=69660912, orientation='plus', exon_count=26, OMIM=[610012], no_hdr0=''),
    23214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23214, CurrentID=0, Status='live', Symbol='XPO6', Aliases=['EXP6', 'RANBP20'], description='exportin 6', other_designations='exportin-6|ran-binding protein 20', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28097976, end_position_on_the_genomic_accession=28212031, orientation='minus', exon_count=31, OMIM=[608411], no_hdr0=''),
    23215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23215, CurrentID=0, Status='live', Symbol='PRRC2C', Aliases=['BAT2-iso', 'BAT2D1', 'BAT2L2', 'XTP2'], description='proline rich coiled-coil 2C', other_designations='protein PRRC2C|BAT2 domain containing 1|BAT2 domain-containing protein 1|HBV X-transactivated gene 2 protein|HBV XAg-transactivated protein 2|HBxAg transactivated protein 2|HLA-B-associated transcript 2-like 2|proline-rich and coiled-coil-containing protein 2C|protein BAT2-like 2', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171485496, end_position_on_the_genomic_accession=171593511, orientation='plus', exon_count=36, OMIM=[617373], no_hdr0=''),
    23216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23216, CurrentID=0, Status='live', Symbol='TBC1D1', Aliases=['TBC', 'TBC1'], description='TBC1 domain family member 1', other_designations='TBC1 domain family member 1|TBC1 (tre-2/USP6, BUB2, cdc16) domain family, member 1', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37891084, end_position_on_the_genomic_accession=38139173, orientation='plus', exon_count=31, OMIM=[609850], no_hdr0=''),
    23217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23217, CurrentID=0, Status='live', Symbol='ZFR2', Aliases=['KIAA1086'], description='zinc finger RNA binding protein 2', other_designations='zinc finger RNA-binding protein 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3804024, end_position_on_the_genomic_accession=3869038, orientation='minus', exon_count=21, OMIM=[619284], no_hdr0=''),
    23218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23218, CurrentID=0, Status='live', Symbol='NBEAL2', Aliases=['BDPLT4', 'GPS'], description='neurobeachin like 2', other_designations='neurobeachin-like protein 2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46979666, end_position_on_the_genomic_accession=47009704, orientation='plus', exon_count=56, OMIM=[614169], no_hdr0=''),
    23219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23219, CurrentID=0, Status='live', Symbol='FBXO28', Aliases=['CENP-30', 'Fbx28'], description='F-box protein 28', other_designations='F-box only protein 28|centromere protein 30', map_location='1q42.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224114111, end_position_on_the_genomic_accession=224162047, orientation='plus', exon_count=5, OMIM=[609100], no_hdr0=''),
    23220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23220, CurrentID=0, Status='live', Symbol='DTX4', Aliases=['RNF155'], description='deltex E3 ubiquitin ligase 4', other_designations='E3 ubiquitin-protein ligase DTX4|RING finger protein 155|RING-type E3 ubiquitin transferase DTX4|deltex 4 homolog|deltex 4, E3 ubiquitin ligase|deltex homolog 4|deltex4|protein deltex-4', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59171430, end_position_on_the_genomic_accession=59208588, orientation='plus', exon_count=10, OMIM=[616110], no_hdr0=''),
    23221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23221, CurrentID=0, Status='live', Symbol='RHOBTB2', Aliases=['DBC2', 'DEE64', 'EIEE64', 'p83'], description='Rho related BTB domain containing 2', other_designations='rho-related BTB domain-containing protein 2|deleted in breast cancer 2 gene protein', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22987251, end_position_on_the_genomic_accession=23020199, orientation='plus', exon_count=15, OMIM=[607352], no_hdr0=''),
    23223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23223, CurrentID=0, Status='live', Symbol='RRP12', Aliases=['KIAA0690'], description='ribosomal RNA processing 12 homolog', other_designations='RRP12-like protein', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97356357, end_position_on_the_genomic_accession=97401370, orientation='minus', exon_count=34, OMIM=[617723], no_hdr0=''),
    23224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23224, CurrentID=0, Status='live', Symbol='SYNE2', Aliases=['EDMD5', 'KASH2', 'NUA', 'NUANCE', 'Nesp2', 'Nesprin-2', 'SYNE-2', 'TROPH'], description='spectrin repeat containing nuclear envelope protein 2', other_designations='nesprin-2|KASH domain-containing protein 2|nesprin 2|nuclear envelope spectrin repeat protein 2|nucleus and actin connecting element protein|polytrophin|spectrin repeat containing, nuclear envelope 2|synaptic nuclear envelope protein 2|synaptic nuclei expressed gene 2', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63761904, end_position_on_the_genomic_accession=64226449, orientation='plus', exon_count=123, OMIM=[608442], no_hdr0=''),
    23225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23225, CurrentID=0, Status='live', Symbol='NUP210', Aliases=['GP210', 'POM210'], description='nucleoporin 210', other_designations='nuclear pore membrane glycoprotein 210|nuclear envelope pore membrane protein POM 210|nuclear pore protein gp210|nucleoporin 210kDa|nucleoporin Nup210|pore membrane protein of 210 kDa', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=13316235, end_position_on_the_genomic_accession=13420322, orientation='minus', exon_count=42, OMIM=[607703], no_hdr0=''),
    23228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23228, CurrentID=0, Status='live', Symbol='PLCL2', Aliases=['PLCE2'], description='phospholipase C like 2', other_designations='inactive phospholipase C-like protein 2|PLC-L(2)|PLC-L2|PLC-epsilon-2|phospholipase C-L2|phospholipase C-epsilon-2', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16802691, end_position_on_the_genomic_accession=17090606, orientation='plus', exon_count=12, OMIM=[614276], no_hdr0=''),
    23229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23229, CurrentID=0, Status='live', Symbol='ARHGEF9', Aliases=['COLLYBISTIN', 'DEE8', 'EIEE8', 'HPEM-2', 'PEM-2', 'PEM2'], description='Cdc42 guanine nucleotide exchange factor 9', other_designations='rho guanine nucleotide exchange factor 9|Cdc42 guanine nucleotide exchange factor (GEF) 9|PEM-2 homolog|hPEM-2 collybistin|rac/Cdc42 guanine nucleotide exchange factor 9', map_location='Xq11.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=63634967, end_position_on_the_genomic_accession=63785546, orientation='minus', exon_count=21, OMIM=[300429], no_hdr0=''),
    23230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23230, CurrentID=0, Status='live', Symbol='VPS13A', Aliases=['CHAC', 'CHOREIN'], description='vacuolar protein sorting 13 homolog A', other_designations='vacuolar protein sorting-associated protein 13A|chorea-acanthocytosis protein|vacuolar protein sorting 13A', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=77177534, end_position_on_the_genomic_accession=77421537, orientation='plus', exon_count=74, OMIM=[605978], no_hdr0=''),
    23231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23231, CurrentID=0, Status='live', Symbol='SEL1L3', Aliases=['Sel-1L3'], description='SEL1L family member 3', other_designations='protein sel-1 homolog 3|sel-1 suppressor of lin-12-like 3|suppressor of lin-12-like protein 3', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25715910, end_position_on_the_genomic_accession=25863566, orientation='minus', exon_count=29, OMIM=[], no_hdr0=''),
    23232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23232, CurrentID=0, Status='live', Symbol='TBC1D12', Aliases=[], description='TBC1 domain family member 12', other_designations='TBC1 domain family member 12', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94402429, end_position_on_the_genomic_accession=94536332, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    23233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23233, CurrentID=0, Status='live', Symbol='EXOC6B', Aliases=['SEC15B', 'SEC15L2', 'SEMDJL3'], description='exocyst complex component 6B', other_designations='exocyst complex component 6B|SEC15 homolog B|SEC15-like protein 2|exocyst complex component Sec15B', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=72175984, end_position_on_the_genomic_accession=72826033, orientation='minus', exon_count=28, OMIM=[607880], no_hdr0=''),
    23234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23234, CurrentID=0, Status='live', Symbol='DNAJC9', Aliases=['HDJC9', 'JDD1', 'SB73'], description='DnaJ heat shock protein family (Hsp40) member C9', other_designations='dnaJ homolog subfamily C member 9|DnaJ (Hsp40) homolog, subfamily C, member 9|DnaJ protein SB73', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73241954, end_position_on_the_genomic_accession=73247255, orientation='minus', exon_count=5, OMIM=[611206], no_hdr0=''),
    23235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23235, CurrentID=0, Status='live', Symbol='SIK2', Aliases=['LOH11CR1I', 'QIK', 'SIK-2', 'SNF1LK2'], description='salt inducible kinase 2', other_designations='serine/threonine-protein kinase SIK2|SNF1-like kinase 2|qin-induced kinase|salt-inducible protein kinase 2|salt-inducible serine/threonine kinase 2|serine/threonine-protein kinase SNF1-like kinase 2', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111602449, end_position_on_the_genomic_accession=111730855, orientation='plus', exon_count=17, OMIM=[608973], no_hdr0=''),
    23236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23236, CurrentID=0, Status='live', Symbol='PLCB1', Aliases=['DEE12', 'EIEE12', 'PI-PLC', 'PLC-154', 'PLC-I', 'PLC-beta-1', 'PLC154A', 'PLCB1B', 'PLCB1'], description='phospholipase C beta 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase beta-1|1-phosphatidyl-D-myo-inositol-4,5-bisphosphate|inositoltrisphosphohydrolase|monophosphatidylinositol phosphodiesterase|phosphoinositidase C|phosphoinositide phospholipase C|phospholipase C, beta 1 (phosphoinositide-specific)|phospholipase C-I|triphosphoinositide phosphodiesterase', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=8132266, end_position_on_the_genomic_accession=8884900, orientation='plus', exon_count=33, OMIM=[607120], no_hdr0=''),
    23237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23237, CurrentID=0, Status='live', Symbol='ARC', Aliases=['Arg3.1', 'hArc'], description='activity regulated cytoskeleton associated protein', other_designations='activity-regulated cytoskeleton-associated protein|ARC/ARG3.1|activity-regulated gene 3.1 protein homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142611049, end_position_on_the_genomic_accession=142614479, orientation='minus', exon_count=3, OMIM=[612461], no_hdr0=''),
    23239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23239, CurrentID=0, Status='live', Symbol='PHLPP1', Aliases=['PHLPP', 'PLEKHE1', 'PPM3A', 'SCOP'], description='PH domain and leucine rich repeat protein phosphatase 1', other_designations='PH domain leucine-rich repeat-containing protein phosphatase 1|PH domain-containing family E member 1|SCN circadian oscillatory protein|pleckstrin homology domain containing, family E (with leucine rich repeats) member 1|protein phosphatase, Mg2+/Mn2+ dependent 3A|suprachiasmatic nucleus circadian oscillatory protein', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=62715445, end_position_on_the_genomic_accession=62980433, orientation='plus', exon_count=19, OMIM=[609396], no_hdr0=''),
    23240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23240, CurrentID=0, Status='live', Symbol='TMEM131L', Aliases=['KIAA0922'], description='transmembrane 131 like', other_designations='transmembrane protein 131-like', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153466346, end_position_on_the_genomic_accession=153637608, orientation='plus', exon_count=37, OMIM=[616243], no_hdr0=''),
    23241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23241, CurrentID=0, Status='live', Symbol='PACS2', Aliases=['DEE66', 'EIEE66', 'PACS-2', 'PACS1L'], description='phosphofurin acidic cluster sorting protein 2', other_designations='phosphofurin acidic cluster sorting protein 2|PACS1-like protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105300718, end_position_on_the_genomic_accession=105398147, orientation='plus', exon_count=26, OMIM=[610423], no_hdr0=''),
    23242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23242, CurrentID=0, Status='live', Symbol='COBL', Aliases=[], description='cordon-bleu WH2 repeat protein', other_designations='protein cordon-bleu', map_location='7p12.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=51016212, end_position_on_the_genomic_accession=51316809, orientation='minus', exon_count=18, OMIM=[610317], no_hdr0=''),
    23243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23243, CurrentID=0, Status='live', Symbol='ANKRD28', Aliases=['CFAP79', 'FAP79', 'PITK', 'PPP1R65'], description='ankyrin repeat domain 28', other_designations='serine/threonine-protein phosphatase 6 regulatory ankyrin repeat subunit A|PP6-ARS-A|ankyrin repeat domain-containing protein 28|phosphatase interactor targeting K protein|phosphatase interactor targeting protein hnRNP K|protein phosphatase 1, regulatory subunit 65|protein phosphatase 6 ankyrin repeat subunit A|serine/threonine-protein phosphatase 6 regulatory subunit ARS-A', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15667236, end_position_on_the_genomic_accession=15859814, orientation='minus', exon_count=36, OMIM=[611122], no_hdr0=''),
    23244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23244, CurrentID=0, Status='live', Symbol='PDS5A', Aliases=['PIG54', 'SCC-112', 'SCC112'], description='PDS5 cohesin associated factor A', other_designations='sister chromatid cohesion protein PDS5 homolog A|PDS5, regulator of cohesion maintenance, homolog A|cell proliferation-inducing gene 54 protein|sister chromatid cohesion protein 112', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39822863, end_position_on_the_genomic_accession=39977911, orientation='minus', exon_count=36, OMIM=[613200], no_hdr0=''),
    23245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23245, CurrentID=0, Status='live', Symbol='ASTN2', Aliases=['bA67K19.1'], description='astrotactin 2', other_designations='astrotactin-2', map_location='9q33.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=116423112, end_position_on_the_genomic_accession=117415057, orientation='minus', exon_count=25, OMIM=[612856], no_hdr0=''),
    23246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23246, CurrentID=0, Status='live', Symbol='BOP1', Aliases=[], description='BOP1 ribosomal biogenesis factor', other_designations='ribosome biogenesis protein BOP1|block of proliferation 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144262045, end_position_on_the_genomic_accession=144291438, orientation='minus', exon_count=16, OMIM=[610596], no_hdr0=''),
    23247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23247, CurrentID=0, Status='live', Symbol='KATNIP', Aliases=['JBTS26', 'KIAA0556'], description='katanin interacting protein', other_designations='katanin-interacting protein', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27550128, end_position_on_the_genomic_accession=27780371, orientation='plus', exon_count=31, OMIM=[616650], no_hdr0=''),
    23248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23248, CurrentID=0, Status='live', Symbol='RPRD2', Aliases=['HSPC099', 'KIAA0460'], description='regulation of nuclear pre-mRNA domain containing 2', other_designations='regulation of nuclear pre-mRNA domain-containing protein 2', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150364147, end_position_on_the_genomic_accession=150476566, orientation='plus', exon_count=13, OMIM=[614695], no_hdr0=''),
    23250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23250, CurrentID=0, Status='live', Symbol='ATP11A', Aliases=['ATPIH', 'ATPIS'], description='ATPase phospholipid transporting 11A', other_designations='phospholipid-transporting ATPase IH|ATPase, class VI, type 11A|P4-ATPase flippase complex alpha subunit ATP11A|phospholipid-translocating ATPase|potential phospholipid-transporting ATPase IH|probable phospholipid-transporting ATPase IH', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112690034, end_position_on_the_genomic_accession=112887168, orientation='plus', exon_count=33, OMIM=[605868], no_hdr0=''),
    23251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23251, CurrentID=0, Status='live', Symbol='MINAR1', Aliases=['KIAA1024', 'UBTOR'], description='membrane integral NOTCH2 associated receptor 1', other_designations='major intrinsically disordered Notch2-binding receptor 1|major intrinsically disordered Notch2-associated receptor 1|ubiquitination and mTOR signaling protein', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79411557, end_position_on_the_genomic_accession=79472304, orientation='plus', exon_count=11, OMIM=[618054], no_hdr0=''),
    23252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23252, CurrentID=0, Status='live', Symbol='OTUD3', Aliases=['DUBA4'], description='OTU deubiquitinase 3', other_designations='OTU domain-containing protein 3|OTU domain containing 3', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19881708, end_position_on_the_genomic_accession=19912945, orientation='plus', exon_count=8, OMIM=[611758], no_hdr0=''),
    23253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23253, CurrentID=0, Status='live', Symbol='ANKRD12', Aliases=['ANCO-2', 'ANCO1', 'GAC-1', 'Nbla00144'], description='ankyrin repeat domain 12', other_designations='ankyrin repeat domain-containing protein 12|ankyrin repeat-containing cofactor 2', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9136767, end_position_on_the_genomic_accession=9285985, orientation='plus', exon_count=17, OMIM=[610616], no_hdr0=''),
    23254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23254, CurrentID=0, Status='live', Symbol='KAZN', Aliases=['C1orf196', 'KAZ'], description='kazrin, periplakin interacting protein', other_designations='kazrin', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13893386, end_position_on_the_genomic_accession=15118043, orientation='plus', exon_count=22, OMIM=[618301], no_hdr0=''),
    23255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23255, CurrentID=0, Status='live', Symbol='MTCL1', Aliases=['CCDC165', 'KIAA0802', 'SOGA2'], description='microtubule crosslinking factor 1', other_designations='microtubule cross-linking factor 1|PAR-1-interacting protein|SOGA family member 2|coiled-coil domain containing 165|coiled-coil domain-containing protein 165', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=8705556, end_position_on_the_genomic_accession=8832778, orientation='plus', exon_count=27, OMIM=[615766], no_hdr0=''),
    23256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23256, CurrentID=0, Status='live', Symbol='SCFD1', Aliases=['C14orf163', 'RA410', 'SLY1', 'SLY1P', 'STXBP1L2'], description='sec1 family domain containing 1', other_designations='sec1 family domain-containing protein 1|syntaxin-binding protein 1-like 2|vesicle transport-related protein', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=30622254, end_position_on_the_genomic_accession=30735850, orientation='plus', exon_count=29, OMIM=[618207], no_hdr0=''),
    23258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23258, CurrentID=0, Status='live', Symbol='DENND5A', Aliases=['DEE49', 'EIEE49', 'RAB6IP1'], description='DENN domain containing 5A', other_designations='DENN domain-containing protein 5A|DENN/MADD domain containing 5A|RAB6 interacting protein 1|rab6-interacting protein 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9138825, end_position_on_the_genomic_accession=9265350, orientation='minus', exon_count=24, OMIM=[617278], no_hdr0=''),
    23259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23259, CurrentID=0, Status='live', Symbol='DDHD2', Aliases=['SAMWD1', 'SPG54', 'iPLA(1)gamma', 'iPLA1gamma'], description='DDHD domain containing 2', other_designations='phospholipase DDHD2|PA-PLA1 like|SAM, WWE and DDHD domain-containing protein 1|intracellular phospholipase A1gamma|sec23p-interacting protein p125-like phosphatidic acid-preferring phospholipase A1', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38231585, end_position_on_the_genomic_accession=38273922, orientation='plus', exon_count=22, OMIM=[615003], no_hdr0=''),
    23261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23261, CurrentID=0, Status='live', Symbol='CAMTA1', Aliases=['CANPMR'], description='calmodulin binding transcription activator 1', other_designations='calmodulin-binding transcription activator 1', map_location='1p36.31-p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6785452, end_position_on_the_genomic_accession=7769706, orientation='plus', exon_count=40, OMIM=[611501], no_hdr0=''),
    23262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23262, CurrentID=0, Status='live', Symbol='PPIP5K2', Aliases=['CFAP160', 'DFNB100', 'HISPPD1', 'IP7K2', 'VIP2'], description='diphosphoinositol pentakisphosphate kinase 2', other_designations='inositol hexakisphosphate and diphosphoinositol-pentakisphosphate kinase 2|VIP1 homolog 2|deafness, autosomal recessive 100|histidine acid phosphatase domain-containing protein 1|inositol heptaphosphate kinase 2|insP6 and PP-IP5 kinase 2', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=103120273, end_position_on_the_genomic_accession=103212799, orientation='plus', exon_count=34, OMIM=[611648], no_hdr0=''),
    23263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23263, CurrentID=0, Status='live', Symbol='MCF2L', Aliases=['ARHGEF14', 'DBS', 'OST'], description='MCF.2 cell line derived transforming sequence like', other_designations="guanine nucleotide exchange factor DBS|DBL's big sister|MCF2 transforming sequence-like protein", map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112894378, end_position_on_the_genomic_accession=113099742, orientation='plus', exon_count=42, OMIM=[609499], no_hdr0=''),
    23264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23264, CurrentID=0, Status='live', Symbol='ZC3H7B', Aliases=['ROXAN1', 'RoXaN'], description='zinc finger CCCH-type containing 7B', other_designations="zinc finger CCCH domain-containing protein 7B|Rotavirus 'X' associated non-structural protein|rotavirus 'X'-associated non-structural protein|rotavirus X protein associated with NSP3|ubiquitous tetratricopeptide containing protein RoXaN", map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41301525, end_position_on_the_genomic_accession=41360147, orientation='plus', exon_count=23, OMIM=[618206], no_hdr0=''),
    23265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23265, CurrentID=0, Status='live', Symbol='EXOC7', Aliases=['2-5-3p', 'BLOM4', 'EX070', 'EXO70', 'EXOC1', 'Exo70p', 'NEDSEBA', 'YJL085W'], description='exocyst complex component 7', other_designations='exocyst complex component 7|exocyst complex component Exo70', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76081016, end_position_on_the_genomic_accession=76103787, orientation='minus', exon_count=22, OMIM=[608163], no_hdr0=''),
    23266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23266, CurrentID=0, Status='live', Symbol='ADGRL2', Aliases=['CIRL2', 'CL2', 'LEC1', 'LPHH1', 'LPHN2'], description='adhesion G protein-coupled receptor L2', other_designations='adhesion G protein-coupled receptor L2|calcium-independent alpha-latrotoxin receptor 2|latrophilin homolog 1|latrophilin-2|lectomedin-1', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=81306104, end_position_on_the_genomic_accession=81993932, orientation='plus', exon_count=39, OMIM=[607018], no_hdr0=''),
    23268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23268, CurrentID=0, Status='live', Symbol='DNMBP', Aliases=['ARHGEF36', 'CTRCT48', 'TUBA'], description='dynamin binding protein', other_designations='dynamin-binding protein|scaffold protein TUBA', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99875571, end_position_on_the_genomic_accession=100009948, orientation='minus', exon_count=20, OMIM=[611282], no_hdr0=''),
    23269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23269, CurrentID=0, Status='live', Symbol='MGA', Aliases=['MAD5', 'MXD5'], description='MAX dimerization protein MGA', other_designations='MAX gene-associated protein|MAX dimerization protein 5|MGA, MAX dimerization protein', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41621225, end_position_on_the_genomic_accession=41769940, orientation='plus', exon_count=27, OMIM=[616061], no_hdr0=''),
    23270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23270, CurrentID=0, Status='live', Symbol='TSPYL4', Aliases=['dJ486I3.2'], description='TSPY like 4', other_designations='testis-specific Y-encoded-like protein 4|TSPY-like protein 4', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116249964, end_position_on_the_genomic_accession=116254075, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    23271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23271, CurrentID=0, Status='live', Symbol='CAMSAP2', Aliases=['CAMSAP1L1'], description='calmodulin regulated spectrin associated protein family member 2', other_designations='calmodulin-regulated spectrin-associated protein 2|calmodulin-regulated spectrin-associated protein 1-like protein 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200738893, end_position_on_the_genomic_accession=200860707, orientation='plus', exon_count=18, OMIM=[613775], no_hdr0=''),
    23272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23272, CurrentID=0, Status='live', Symbol='TASOR', Aliases=['C3orf63', 'FAM208A', 'RAP1401', 'se89-1', 'TASOR'], description='transcription activation suppressor', other_designations='protein TASOR|CTCL tumor antigen se89-1|family with sequence similarity 208 member A|protein FAM208A|retinoblastoma-associated protein 140|retinoblastoma-associated protein RAP140|transgene activation suppressor protein', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=56620132, end_position_on_the_genomic_accession=56683265, orientation='minus', exon_count=24, OMIM=[616493], no_hdr0=''),
    23274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23274, CurrentID=0, Status='live', Symbol='CLEC16A', Aliases=['Gop-1', 'KIAA0350'], description='C-type lectin domain containing 16A', other_designations='protein CLEC16A|C-type lectin domain family 16 member A', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10944539, end_position_on_the_genomic_accession=11193272, orientation='plus', exon_count=35, OMIM=[611303], no_hdr0=''),
    23275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23275, CurrentID=0, Status='live', Symbol='POFUT2', Aliases=['C21orf80', 'FUT13'], description='protein O-fucosyltransferase 2', other_designations='GDP-fucose protein O-fucosyltransferase 2|O-FucT-2|peptide-O-fucosyltransferase 2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45263928, end_position_on_the_genomic_accession=45287914, orientation='minus', exon_count=17, OMIM=[610249], no_hdr0=''),
    23276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23276, CurrentID=0, Status='live', Symbol='KLHL18', Aliases=[], description='kelch like family member 18', other_designations='kelch-like protein 18', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47282940, end_position_on_the_genomic_accession=47346816, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    23277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23277, CurrentID=0, Status='live', Symbol='CLUH', Aliases=['CLU1'], description='clustered mitochondria homolog', other_designations='clustered mitochondria protein homolog|clustered mitochondria (cluA/CLU1) homolog', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2689387, end_position_on_the_genomic_accession=2712020, orientation='minus', exon_count=29, OMIM=[616184], no_hdr0=''),
    23279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23279, CurrentID=0, Status='live', Symbol='NUP160', Aliases=['NPHS19'], description='nucleoporin 160', other_designations='nuclear pore complex protein Nup160|160 kDa nucleoporin|nucleoporin 160kD|nucleoporin 160kDa|nucleoporin Nup160', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47778083, end_position_on_the_genomic_accession=47848544, orientation='minus', exon_count=36, OMIM=[607614], no_hdr0=''),
    23281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23281, CurrentID=0, Status='live', Symbol='MTUS2', Aliases=['CAZIP', 'ICIS', 'KIAA0774', 'TIP150'], description='microtubule associated scaffold protein 2', other_designations='microtubule-associated tumor suppressor candidate 2|+TIP of 150 kDa|cardiac zipper protein|microtubule associated tumor suppressor candidate 2|microtubule plus-end tracking protein TIP150|tracking protein of 150 kDa', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28819963, end_position_on_the_genomic_accession=29505947, orientation='plus', exon_count=21, OMIM=[619358], no_hdr0=''),
    23283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23283, CurrentID=0, Status='live', Symbol='CSTF2T', Aliases=['CstF-64T'], description='cleavage stimulation factor subunit 2 tau variant', other_designations="cleavage stimulation factor subunit 2 tau variant|CF-1 64 kDa subunit tau|CSTF 64 kDa subunit tau|cleavage stimulation factor 64 kDa subunit tau|cleavage stimulation factor subunit 2, tau|cleavage stimulation factor, 3' pre-RNA, subunit 2, 64kDa, tau|cleavage stimulation factor, 3' pre-RNA, subunit 2, tau|tauCstF-64", map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=51695486, end_position_on_the_genomic_accession=51699595, orientation='minus', exon_count=1, OMIM=[611968], no_hdr0=''),
    23284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23284, CurrentID=0, Status='live', Symbol='ADGRL3', Aliases=['CIRL3', 'CL3', 'LEC3', 'LPHN3'], description='adhesion G protein-coupled receptor L3', other_designations='adhesion G protein-coupled receptor L3|calcium-independent alpha-latrotoxin receptor 3|latrophilin homolog 3 (cow)|latrophilin-3|lectomedin 3', map_location='4q13.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=61200326, end_position_on_the_genomic_accession=62078335, orientation='plus', exon_count=32, OMIM=[616417], no_hdr0=''),
    23286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23286, CurrentID=0, Status='live', Symbol='WWC1', Aliases=['HBEBP3', 'HBEBP36', 'KIBRA', 'MEMRYQTL', 'PPP1R168'], description='WW and C2 domain containing 1', other_designations='protein KIBRA|HBeAg-binding protein 3|WW, C2 and coiled-coil domain containing 1|kidney and brain protein|protein WWC1|protein phosphatase 1, regulatory subunit 168', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=168291645, end_position_on_the_genomic_accession=168472303, orientation='plus', exon_count=26, OMIM=[610533], no_hdr0=''),
    23287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23287, CurrentID=0, Status='live', Symbol='AGTPBP1', Aliases=['CCP1', 'CONDCA', 'NNA1'], description='ATP/GTP binding carboxypeptidase 1', other_designations='cytosolic carboxypeptidase 1|ATP/GTP binding protein 1|carboxypeptidase-tubulin|nervous system nuclear protein induced by axotomy protein 1 homolog|soluble carboxypeptidase|tubulinyl-Tyr carboxypeptidase|tyrosine carboxypeptidase', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=85546539, end_position_on_the_genomic_accession=85742029, orientation='minus', exon_count=30, OMIM=[606830], no_hdr0=''),
    23288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23288, CurrentID=0, Status='live', Symbol='IQCE', Aliases=['1700028P05Rik', 'PAPA7'], description='IQ motif containing E', other_designations='IQ domain-containing protein E', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2558978, end_position_on_the_genomic_accession=2614729, orientation='plus', exon_count=24, OMIM=[617631], no_hdr0=''),
    23291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23291, CurrentID=0, Status='live', Symbol='FBXW11', Aliases=['BTRC2', 'BTRCP2', 'FBW1B', 'FBXW1B', 'Fbw11', 'Hos', 'NEDJED'], description='F-box and WD repeat domain containing 11', other_designations='F-box/WD repeat-containing protein 11|F-box and WD repeats protein beta-TrCP2|F-box and WD-40 domain protein 11|F-box and WD-40 domain protein 1B|F-box protein Fbw1b|F-box/WD repeat-containing protein 1B|beta-transducin repeat-containing protein 2|homologous to Slimb protein', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=171861549, end_position_on_the_genomic_accession=172006638, orientation='minus', exon_count=18, OMIM=[605651], no_hdr0=''),
    23293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23293, CurrentID=0, Status='live', Symbol='SMG6', Aliases=['C17orf31', 'EST1A', 'SMG-6', 'hSMG5/7a'], description='SMG6 nonsense mediated mRNA decay factor', other_designations='telomerase-binding protein EST1A|EST1 telomerase component homolog A|ever shorter telomeres 1A|smg-6 homolog, nonsense mediated mRNA decay factor|telomerase subunit EST1A', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2059839, end_position_on_the_genomic_accession=2303836, orientation='minus', exon_count=30, OMIM=[610963], no_hdr0=''),
    23294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23294, CurrentID=0, Status='live', Symbol='ANKS1A', Aliases=['ANKS1'], description='ankyrin repeat and sterile alpha motif domain containing 1A', other_designations='ankyrin repeat and SAM domain-containing protein 1A|Odin|ankyrin repeat and SAM domain containing 1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34889255, end_position_on_the_genomic_accession=35097992, orientation='plus', exon_count=29, OMIM=[608994], no_hdr0=''),
    23295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23295, CurrentID=0, Status='live', Symbol='MGRN1', Aliases=['RNF156'], description='mahogunin ring finger 1', other_designations='E3 ubiquitin-protein ligase MGRN1|RING finger protein 156|RING-type E3 ubiquitin transferase MGRN1|mahogunin RING finger protein 1|mahogunin ring finger 1, E3 ubiquitin protein ligase|probable E3 ubiquitin-protein ligase MGRN1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4624826, end_position_on_the_genomic_accession=4690972, orientation='plus', exon_count=17, OMIM=[607559], no_hdr0=''),
    23299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23299, CurrentID=0, Status='live', Symbol='BICD2', Aliases=['SMALED2', 'SMALED2A', 'SMALED2B', 'bA526D8.1'], description='BICD cargo adaptor 2', other_designations='protein bicaudal D homolog 2|bic-D 2|bicaudal D homolog 2|coiled-coil protein BICD2|cytoskeleton-like bicaudal D protein homolog 2|homolog of Drosophila bicaudal D', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92711363, end_position_on_the_genomic_accession=92764841, orientation='minus', exon_count=8, OMIM=[609797], no_hdr0=''),
    23300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23300, CurrentID=0, Status='live', Symbol='ATMIN', Aliases=['ASCIZ', 'ZNF822'], description='ATM interactor', other_designations='ATM interactor|ATM INteracting protein|ATM/ATR-Substrate Chk2-Interacting Zn++-finger protein|ATM/ATR-substrate CHEK2-interacting zinc finger protein|ATM/ATR-substrate CHK2-interacting zinc finger protein|zinc finger protein 822', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81035842, end_position_on_the_genomic_accession=81047350, orientation='plus', exon_count=5, OMIM=[614693], no_hdr0=''),
    23301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23301, CurrentID=0, Status='live', Symbol='EHBP1', Aliases=['HPC12', 'NACSIN'], description='EH domain binding protein 1', other_designations='EH domain-binding protein 1|NPF calponin-like protein|testis tissue sperm-binding protein Li 50e', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=62673878, end_position_on_the_genomic_accession=63046487, orientation='plus', exon_count=30, OMIM=[609922], no_hdr0=''),
    23302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23302, CurrentID=0, Status='live', Symbol='WSCD1', Aliases=[], description='WSC domain containing 1', other_designations='WSC domain-containing protein 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6069116, end_position_on_the_genomic_accession=6124427, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    23303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23303, CurrentID=0, Status='live', Symbol='KIF13B', Aliases=['GAKIN'], description='kinesin family member 13B', other_designations='kinesin-like protein KIF13B|guanylate kinase associated kinesin|kinesin 13B|kinesin-like protein GAKIN', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=29067278, end_position_on_the_genomic_accession=29263385, orientation='minus', exon_count=42, OMIM=[607350], no_hdr0=''),
    23304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23304, CurrentID=0, Status='live', Symbol='UBR2', Aliases=['C6orf133', 'bA49A4.1', 'dJ242G1.1', 'dJ392M17.3'], description='ubiquitin protein ligase E3 component n-recognin 2', other_designations='E3 ubiquitin-protein ligase UBR2|RING-type E3 ubiquitin transferase UBR2|ubiquitin-protein ligase E3-alpha-2|ubiquitin-protein ligase E3-alpha-II', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42563954, end_position_on_the_genomic_accession=42693505, orientation='plus', exon_count=52, OMIM=[609134], no_hdr0=''),
    23305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23305, CurrentID=0, Status='live', Symbol='ACSL6', Aliases=['ACS2', 'FACL6', 'LACS 6', 'LACS2', 'LACS5'], description='acyl-CoA synthetase long chain family member 6', other_designations='long-chain-fatty-acid--CoA ligase 6|arachidonate--CoA ligase|fatty-acid-Coenzyme A ligase, long-chain 6|long fatty acyl-CoA synthetase 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131949973, end_position_on_the_genomic_accession=132012068, orientation='minus', exon_count=24, OMIM=[604443], no_hdr0=''),
    23306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23306, CurrentID=0, Status='live', Symbol='NEMP1', Aliases=['TMEM194', 'TMEM194A'], description='nuclear envelope integral membrane protein 1', other_designations='nuclear envelope integral membrane protein 1|transmembrane protein 194|transmembrane protein 194A', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57055643, end_position_on_the_genomic_accession=57088703, orientation='minus', exon_count=12, OMIM=[616496], no_hdr0=''),
    23307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23307, CurrentID=0, Status='live', Symbol='FKBP15', Aliases=['FKBP133', 'KIAA0674', 'PPP1R76'], description='FKBP prolyl isomerase family member 15', other_designations='FK506-binding protein 15|133 kDa FK506-binding protein|133 kDa FKBP|FK506 binding protein 15, 133kDa|FK506-binding protein 133kDa|FKBP prolyl isomerase 15|FKBP-133|FKBP-15|WAFL|WASP and FKBP-like protein|protein phosphatase 1, regulatory subunit 76', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113161006, end_position_on_the_genomic_accession=113221325, orientation='minus', exon_count=28, OMIM=[617398], no_hdr0=''),
    23308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23308, CurrentID=0, Status='live', Symbol='ICOSLG', Aliases=['B7-H2', 'B7H2', 'B7RP-1', 'B7RP1', 'B7h', 'CD275', 'GL50', 'ICOS-L', 'ICOSL', 'LICOS'], description='inducible T cell costimulator ligand', other_designations='ICOS ligand|B7 homolog 2|B7 homologue 2|B7-like protein Gl50|B7-related protein 1|transmembrane protein B7-H2 ICOS ligand', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44216979, end_position_on_the_genomic_accession=44240943, orientation='minus', exon_count=9, OMIM=[605717], no_hdr0=''),
    23309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23309, CurrentID=0, Status='live', Symbol='SIN3B', Aliases=[], description='SIN3 transcription regulator family member B', other_designations='paired amphipathic helix protein Sin3b|SIN3 homolog B, transcriptional regulator|SIN3 transcription regulator homolog B|histone deacetylase complex subunit Sin3b|transcriptional corepressor Sin3b', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16829398, end_position_on_the_genomic_accession=16880355, orientation='plus', exon_count=21, OMIM=[607777], no_hdr0=''),
    23310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23310, CurrentID=0, Status='live', Symbol='NCAPD3', Aliases=['CAP-D3', 'CAPD3', 'MCPH22', 'hCAP-D3', 'hHCP-6', 'hcp-6'], description='non-SMC condensin II complex subunit D3', other_designations='condensin-2 complex subunit D3', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134150113, end_position_on_the_genomic_accession=134225461, orientation='minus', exon_count=37, OMIM=[609276], no_hdr0=''),
    23312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23312, CurrentID=0, Status='live', Symbol='DMXL2', Aliases=['DEE81', 'DFNA71', 'EIEE81', 'PEPNS', 'RC3'], description='Dmx like 2', other_designations='dmX-like protein 2|rabconnectin-3', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51447788, end_position_on_the_genomic_accession=51622833, orientation='minus', exon_count=47, OMIM=[612186], no_hdr0=''),
    23313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23313, CurrentID=0, Status='live', Symbol='KIAA0930', Aliases=['C22orf9', 'LSC3'], description='KIAA0930', other_designations='uncharacterized protein KIAA0930', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45192244, end_position_on_the_genomic_accession=45240894, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    23314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23314, CurrentID=0, Status='live', Symbol='SATB2', Aliases=['GLSS'], description='SATB homeobox 2', other_designations='DNA-binding protein SATB2|SATB family member 2|special AT-rich sequence-binding protein 2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=199269500, end_position_on_the_genomic_accession=199471266, orientation='minus', exon_count=18, OMIM=[608148], no_hdr0=''),
    23315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23315, CurrentID=0, Status='live', Symbol='SLC9A8', Aliases=['NHE-8', 'NHE8'], description='solute carrier family 9 member A8', other_designations='sodium/hydrogen exchanger 8|Na(+)/H(+) exchanger 8|solute carrier family 9 (sodium/hydrogen exchanger), member 8|solute carrier family 9, subfamily A (NHE8, cation proton antiporter 8), member 8', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49812828, end_position_on_the_genomic_accession=49892242, orientation='plus', exon_count=21, OMIM=[612730], no_hdr0=''),
    23316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23316, CurrentID=0, Status='live', Symbol='CUX2', Aliases=['CDP2', 'CUTL2', 'DEE67', 'EIEE67'], description='cut like homeobox 2', other_designations='homeobox protein cut-like 2|homeobox protein cux-2', map_location='12q24.11-q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111034165, end_position_on_the_genomic_accession=111350556, orientation='plus', exon_count=26, OMIM=[610648], no_hdr0=''),
    23317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23317, CurrentID=0, Status='live', Symbol='DNAJC13', Aliases=['PARK21', 'RME8'], description='DnaJ heat shock protein family (Hsp40) member C13', other_designations='dnaJ homolog subfamily C member 13|DnaJ (Hsp40) homolog, subfamily C, member 13|DnaJ domain-containing protein RME-8|required for receptor-mediated endocytosis 8', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132417502, end_position_on_the_genomic_accession=132539032, orientation='plus', exon_count=57, OMIM=[614334], no_hdr0=''),
    23318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23318, CurrentID=0, Status='live', Symbol='TUT4', Aliases=['PAPD3', 'TENT3A', 'ZCCHC11'], description='terminal uridylyl transferase 4', other_designations='terminal uridylyltransferase 4|PAP associated domain containing 3|TUTase 4|zinc finger CCHC domain-containing protein 11|zinc finger CCHC-type containing 11|zinc finger, CCHC domain containing 11', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52423275, end_position_on_the_genomic_accession=52553463, orientation='minus', exon_count=35, OMIM=[613692], no_hdr0=''),
    23321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23321, CurrentID=0, Status='live', Symbol='TRIM2', Aliases=['CMT2R', 'RNF86'], description='tripartite motif containing 2', other_designations='tripartite motif-containing protein 2|E3 ubiquitin-protein ligase TRIM2|RING finger protein 86|RING-type E3 ubiquitin transferase TRIM2|tripartite motif protein TRIM2', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153152163, end_position_on_the_genomic_accession=153339317, orientation='plus', exon_count=20, OMIM=[614141], no_hdr0=''),
    23322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23322, CurrentID=0, Status='live', Symbol='RPGRIP1L', Aliases=['COACH3', 'CORS3', 'FTM', 'JBTS7', 'MKS5', 'NPHP8', 'PPP1R134'], description='RPGRIP1 like', other_designations='protein fantom|RPGR-interacting protein 1-like protein|fantom homolog|nephrocystin-8|protein phosphatase 1, regulatory subunit 134', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53598153, end_position_on_the_genomic_accession=53703859, orientation='minus', exon_count=37, OMIM=[610937], no_hdr0=''),
    23324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23324, CurrentID=0, Status='live', Symbol='MAN2B2', Aliases=[], description='mannosidase alpha class 2B member 2', other_designations='epididymis-specific alpha-mannosidase|alpha-1,6-mannosidase|core-specific lysosomal alpha-1,6-Mannosidase|epididymis secretory sperm binding protein', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6575189, end_position_on_the_genomic_accession=6623362, orientation='plus', exon_count=20, OMIM=[618899], no_hdr0=''),
    23325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23325, CurrentID=0, Status='live', Symbol='WASHC4', Aliases=['KIAA1033', 'MRT43', 'SWIP'], description='WASH complex subunit 4', other_designations='WASH complex subunit 4|WASH complex subunit 7|WASH complex subunit SWIP|strumpellin and WASH-interacting protein', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=105107726, end_position_on_the_genomic_accession=105169134, orientation='plus', exon_count=36, OMIM=[615748], no_hdr0=''),
    23326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23326, CurrentID=0, Status='live', Symbol='USP22', Aliases=['USP3L'], description='ubiquitin specific peptidase 22', other_designations='ubiquitin carboxyl-terminal hydrolase 22|deubiquitinating enzyme 22|ubiquitin specific protease 22|ubiquitin thioesterase 22|ubiquitin thiolesterase 22|ubiquitin-specific processing protease 22', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=20999596, end_position_on_the_genomic_accession=21043409, orientation='minus', exon_count=14, OMIM=[612116], no_hdr0=''),
    23327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23327, CurrentID=0, Status='live', Symbol='NEDD4L', Aliases=['NEDD4-2', 'NEDD4.2', 'PVNH7', 'RSP5', 'hNEDD4-2'], description='NEDD4 like E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase NEDD4-like|HECT-type E3 ubiquitin transferase NED4L|neural precursor cell expressed, developmentally down-regulated 4-like, E3 ubiquitin protein ligase|ubiquitin-protein ligase Rsp5', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=58044226, end_position_on_the_genomic_accession=58401540, orientation='plus', exon_count=41, OMIM=[606384], no_hdr0=''),
    23328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23328, CurrentID=0, Status='live', Symbol='SASH1', Aliases=['CAPOK', 'DUH1', 'SH3D6A', 'dJ323M4.1'], description='SAM and SH3 domain containing 1', other_designations='SAM and SH3 domain-containing protein 1|proline-glutamate repeat-containing protein', map_location='6q24.3-q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=148193440, end_position_on_the_genomic_accession=148552049, orientation='plus', exon_count=26, OMIM=[607955], no_hdr0=''),
    23329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23329, CurrentID=0, Status='live', Symbol='TBC1D30', Aliases=[], description='TBC1 domain family member 30', other_designations='TBC1 domain family member 30', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64759484, end_position_on_the_genomic_accession=64881033, orientation='plus', exon_count=18, OMIM=[615077], no_hdr0=''),
    23331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23331, CurrentID=0, Status='live', Symbol='TTC28', Aliases=['TPRBK'], description='tetratricopeptide repeat domain 28', other_designations='tetratricopeptide repeat protein 28|TPR repeat protein 28|TPR repeat-containing big gene cloned at Keio|TPR-containing big gene cloned at Keio', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=27978014, end_position_on_the_genomic_accession=28679865, orientation='minus', exon_count=29, OMIM=[615098], no_hdr0=''),
    23332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23332, CurrentID=0, Status='live', Symbol='CLASP1', Aliases=['MAST1'], description='cytoplasmic linker associated protein 1', other_designations='CLIP-associating protein 1|multiple asters 1|multiple asters homolog 1|protein Orbit homolog 1', map_location='2q14.2-q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=121337776, end_position_on_the_genomic_accession=121649462, orientation='minus', exon_count=50, OMIM=[605852], no_hdr0=''),
    23333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23333, CurrentID=0, Status='live', Symbol='DPY19L1', Aliases=[], description='dpy-19 like C-mannosyltransferase 1', other_designations='probable C-mannosyltransferase DPY19L1|DPY-19-like protein 1|protein dpy-19 homolog 1', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=34928881, end_position_on_the_genomic_accession=35038041, orientation='minus', exon_count=23, OMIM=[613892], no_hdr0=''),
    23334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23334, CurrentID=0, Status='live', Symbol='SZT2', Aliases=['C1orf84', 'DEE18', 'EIEE18', 'KIAA0467', 'KICS1A', 'SZT2B', 'SZT2'], description='SZT2 subunit of KICSTOR complex', other_designations='KICSTOR complex protein SZT2|SZT2 subunit KICSTOR complex|SZT2, KICSTOR complex subunit|seizure threshold 2 protein homolog', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43389884, end_position_on_the_genomic_accession=43454247, orientation='plus', exon_count=76, OMIM=[615463], no_hdr0=''),
    23335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23335, CurrentID=0, Status='live', Symbol='WDR7', Aliases=['TRAG'], description='WD repeat domain 7', other_designations='WD repeat-containing protein 7|TGF-beta resistance associated|TGF-beta resistance-associated protein TRAG|rabconnectin-3 beta', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=56651359, end_position_on_the_genomic_accession=57029798, orientation='plus', exon_count=32, OMIM=[613473], no_hdr0=''),
    23336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23336, CurrentID=0, Status='live', Symbol='SYNM', Aliases=['DMN', 'SYN'], description='synemin', other_designations='synemin|desmuslin|synemin alpha|synemin beta|synemin, intermediate filament protein', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99105069, end_position_on_the_genomic_accession=99136586, orientation='plus', exon_count=6, OMIM=[606087], no_hdr0=''),
    23338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23338, CurrentID=0, Status='live', Symbol='JADE2', Aliases=['JADE-2', 'PHF15'], description='jade family PHD finger 2', other_designations='E3 ubiquitin-protein ligase Jade-2|PHD finger protein 15|jade family PHD finger protein 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134524153, end_position_on_the_genomic_accession=134583228, orientation='plus', exon_count=16, OMIM=[610515], no_hdr0=''),
    23339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23339, CurrentID=0, Status='live', Symbol='VPS39', Aliases=['TLP', 'VAM6', 'hVam6p'], description='VPS39 subunit of HOPS complex', other_designations='vam6/Vps39-like protein|TRAP1-like protein|VPS39, HOPS complex subunit|vacuolar protein sorting 39 homolog', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42158701, end_position_on_the_genomic_accession=42208331, orientation='minus', exon_count=28, OMIM=[612188], no_hdr0=''),
    23341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23341, CurrentID=0, Status='live', Symbol='DNAJC16', Aliases=['ERdj8'], description='DnaJ heat shock protein family (Hsp40) member C16', other_designations='dnaJ homolog subfamily C member 16|DnaJ (Hsp40) homolog, subfamily C, member 16|novel DnaJ domain-containing protein', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15526694, end_position_on_the_genomic_accession=15571987, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    23344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23344, CurrentID=0, Status='live', Symbol='ESYT1', Aliases=['FAM62A', 'MBC2'], description='extended synaptotagmin 1', other_designations='extended synaptotagmin-1|extended synaptotagmin like protein 1|extended synaptotagmin protein 1|family with sequence similarity 62 (C2 domain containing), member A|membrane-bound C2 domain-containing protein', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56128267, end_position_on_the_genomic_accession=56144674, orientation='plus', exon_count=31, OMIM=[616670], no_hdr0=''),
    23345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23345, CurrentID=0, Status='live', Symbol='SYNE1', Aliases=['8B', 'AMC3', 'AMCM', 'ARCA1', 'C6orf98', 'CPG2', 'EDMD4', 'KASH1', 'MYNE1', 'Nesp1', 'SCAR8', 'dJ45H2.2'], description='spectrin repeat containing nuclear envelope protein 1', other_designations='nesprin-1|CPG2 full length|KASH domain-containing protein 1|enaptin|myocyte nuclear envelope protein 1|nesprin 1|spectrin repeat containing, nuclear envelope 1|synaptic nuclear envelope protein 1|synaptic nuclei expressed gene 1', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=152121687, end_position_on_the_genomic_accession=152637395, orientation='minus', exon_count=154, OMIM=[608441], no_hdr0=''),
    23347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23347, CurrentID=0, Status='live', Symbol='SMCHD1', Aliases=['BAMS', 'FSHD2'], description='structural maintenance of chromosomes flexible hinge domain containing 1', other_designations='structural maintenance of chromosomes flexible hinge domain-containing protein 1|SMC hinge domain-containing protein 1', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=2655726, end_position_on_the_genomic_accession=2805017, orientation='plus', exon_count=51, OMIM=[614982], no_hdr0=''),
    23348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23348, CurrentID=0, Status='live', Symbol='DOCK9', Aliases=['ZIZ1', 'ZIZIMIN1'], description='dedicator of cytokinesis 9', other_designations='dedicator of cytokinesis protein 9|cdc42 guanine nucleotide exchange factor zizimin-1', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=98793429, end_position_on_the_genomic_accession=99086694, orientation='minus', exon_count=61, OMIM=[607325], no_hdr0=''),
    23349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23349, CurrentID=0, Status='live', Symbol='PHF24', Aliases=[], description='PHD finger protein 24', other_designations='PHD finger protein 24', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34810040, end_position_on_the_genomic_accession=34982544, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    23350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23350, CurrentID=0, Status='live', Symbol='U2SURP', Aliases=['SR140', 'fSAPa'], description='U2 snRNP associated SURP domain containing', other_designations='U2 snRNP-associated SURP motif-containing protein|140 kDa Ser/Arg-rich domain protein|Ser/Arg-rich domain protein, 140 kDa|U2-associated SR140 protein|U2-associated protein SR140|functional spliceosome-associated protein a', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=143001570, end_position_on_the_genomic_accession=143060725, orientation='plus', exon_count=29, OMIM=[617849], no_hdr0=''),
    23351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23351, CurrentID=0, Status='live', Symbol='KHNYN', Aliases=['KIAA0323'], description='KH and NYN domain containing', other_designations='protein KHNYN', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24423186, end_position_on_the_genomic_accession=24441843, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    23352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23352, CurrentID=0, Status='live', Symbol='UBR4', Aliases=['RBAF600', 'ZUBR1', 'p600'], description='ubiquitin protein ligase E3 component n-recognin 4', other_designations='E3 ubiquitin-protein ligase UBR4|N-recognin-4|RING-type E3 ubiquitin transferase UBR4|retinoblastoma-associated factor 600-like protein|retinoblastoma-associated factor of 600 kDa|zinc finger UBR1-type protein 1', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19074508, end_position_on_the_genomic_accession=19214332, orientation='minus', exon_count=108, OMIM=[609890], no_hdr0=''),
    23353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23353, CurrentID=0, Status='live', Symbol='SUN1', Aliases=['UNC84A'], description='Sad1 and UNC84 domain containing 1', other_designations='SUN domain-containing protein 1|Sad1 unc-84 domain protein 1|protein unc-84 homolog A|sad1/unc-84 protein-like 1|unc-84 homolog A', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=815557, end_position_on_the_genomic_accession=874934, orientation='plus', exon_count=30, OMIM=[607723], no_hdr0=''),
    23354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23354, CurrentID=0, Status='live', Symbol='HAUS5', Aliases=['KIAA0841', 'dgt5'], description='HAUS augmin like complex subunit 5', other_designations='HAUS augmin-like complex subunit 5', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35612735, end_position_on_the_genomic_accession=35625355, orientation='plus', exon_count=20, OMIM=[613432], no_hdr0=''),
    23355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23355, CurrentID=0, Status='live', Symbol='VPS8', Aliases=['KIAA0804'], description='VPS8 subunit of CORVET complex', other_designations='vacuolar protein sorting-associated protein 8 homolog|VPS8, CORVET complex subunit|vacuolar protein sorting 8 homolog', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184812143, end_position_on_the_genomic_accession=185052614, orientation='plus', exon_count=56, OMIM=[618366], no_hdr0=''),
    23357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23357, CurrentID=0, Status='live', Symbol='ANGEL1', Aliases=['Ccr4e', 'KIAA0759'], description='angel homolog 1', other_designations='protein angel homolog 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=76786009, end_position_on_the_genomic_accession=76812882, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    23358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23358, CurrentID=0, Status='live', Symbol='USP24', Aliases=[], description='ubiquitin specific peptidase 24', other_designations='ubiquitin carboxyl-terminal hydrolase 24|deubiquitinating enzyme 24|ubiquitin specific protease 24|ubiquitin thioesterase 24|ubiquitin thiolesterase 24|ubiquitin-specific processing protease 24', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=55066359, end_position_on_the_genomic_accession=55215374, orientation='minus', exon_count=73, OMIM=[610569], no_hdr0=''),
    23359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23359, CurrentID=0, Status='live', Symbol='FAM189A1', Aliases=['TMEM228'], description='family with sequence similarity 189 member A1', other_designations='protein FAM189A1|transmembrane protein 228', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=29117712, end_position_on_the_genomic_accession=29675409, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    23360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23360, CurrentID=0, Status='live', Symbol='FNBP4', Aliases=['FBP30'], description='formin binding protein 4', other_designations='formin-binding protein 4|formin-binding protein 30', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47716494, end_position_on_the_genomic_accession=47767460, orientation='minus', exon_count=20, OMIM=[615265], no_hdr0=''),
    23361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23361, CurrentID=0, Status='live', Symbol='ZNF629', Aliases=['ZNF', 'ZNF65'], description='zinc finger protein 629', other_designations='zinc finger protein 629|DNA-binding protein|zinc finger protein 65', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30778456, end_position_on_the_genomic_accession=30787205, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    23362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23362, CurrentID=0, Status='live', Symbol='PSD3', Aliases=['EFA6D', 'EFA6R', 'HCA67'], description='pleckstrin and Sec7 domain containing 3', other_designations='PH and SEC7 domain-containing protein 3|ADP-ribosylation factor guanine nucleotide factor 6|epididymis tissue protein Li 20mP|exchange factor for ADP-ribosylation factor guanine nucleotide factor 6 D|exchange factor for ARF6 D|hepatocellular carcinoma-associated antigen 67|pleckstrin homology and SEC7 domain-containing protein 3', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=18527303, end_position_on_the_genomic_accession=19086909, orientation='minus', exon_count=29, OMIM=[614440], no_hdr0=''),
    23363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23363, CurrentID=0, Status='live', Symbol='OBSL1', Aliases=[], description='obscurin like cytoskeletal adaptor 1', other_designations='obscurin-like protein 1|obscurin like 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219549408, end_position_on_the_genomic_accession=219571573, orientation='minus', exon_count=23, OMIM=[610991], no_hdr0=''),
    23365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23365, CurrentID=0, Status='live', Symbol='ARHGEF12', Aliases=['LARG', 'PRO2792'], description='Rho guanine nucleotide exchange factor 12', other_designations='rho guanine nucleotide exchange factor 12|Rho guanine nucleotide exchange factor (GEF) 12|leukemia-associated RhoGEF|leukemia-associated rho guanine nucleotide exchange factor', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120336276, end_position_on_the_genomic_accession=120489937, orientation='plus', exon_count=43, OMIM=[604763], no_hdr0=''),
    23366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23366, CurrentID=0, Status='live', Symbol='KIAA0895', Aliases=[], description='KIAA0895', other_designations='uncharacterized protein KIAA0895', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=36324152, end_position_on_the_genomic_accession=36390357, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    23367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23367, CurrentID=0, Status='live', Symbol='LARP1', Aliases=['LARP', 'Lar1', 'Lhp1'], description='La ribonucleoprotein 1, translational regulator', other_designations='la-related protein 1|La ribonucleoprotein domain family member 1', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154682979, end_position_on_the_genomic_accession=154817605, orientation='plus', exon_count=27, OMIM=[612059], no_hdr0=''),
    23368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23368, CurrentID=0, Status='live', Symbol='PPP1R13B', Aliases=['ASPP1', 'p53BP2-like', 'p85'], description='protein phosphatase 1 regulatory subunit 13B', other_designations='apoptosis-stimulating of p53 protein 1|apoptosis-stimulating protein of p53, 1|protein phosphatase 1, regulatory (inhibitor) subunit 13B', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103733195, end_position_on_the_genomic_accession=103849327, orientation='minus', exon_count=21, OMIM=[606455], no_hdr0=''),
    23369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23369, CurrentID=0, Status='live', Symbol='PUM2', Aliases=['PUMH2', 'PUML2'], description='pumilio RNA binding family member 2', other_designations='pumilio homolog 2|pumilio-2', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20248691, end_position_on_the_genomic_accession=20352253, orientation='minus', exon_count=28, OMIM=[607205], no_hdr0=''),
    23370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23370, CurrentID=0, Status='live', Symbol='ARHGEF18', Aliases=['P114-RhoGEF', 'RP78', 'SA-RhoGEF', 'p114RhoGEF'], description='Rho/Rac guanine nucleotide exchange factor 18', other_designations='rho guanine nucleotide exchange factor 18|114 kDa Rho-specific guanine nucleotide exchange factor|Rho-specific guanine nucleotide exchange factor p114|Rho/Rac guanine nucleotide exchange factor (GEF) 18|septin-associated RhoGEF', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7348901, end_position_on_the_genomic_accession=7476990, orientation='plus', exon_count=35, OMIM=[616432], no_hdr0=''),
    23371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23371, CurrentID=0, Status='live', Symbol='TNS2', Aliases=['C1-TEN', 'C1TEN', 'TENC1'], description='tensin 2', other_designations='tensin-2|C1 domain-containing phosphatase and tensin homolog|tensin like C1 domain containing phosphatase (tensin 2)|tensin-like C1 domain-containing phosphatase', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53046980, end_position_on_the_genomic_accession=53064379, orientation='plus', exon_count=32, OMIM=[607717], no_hdr0=''),
    23373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23373, CurrentID=0, Status='live', Symbol='CRTC1', Aliases=['MAML2', 'MECT1', 'Mam-2', 'TORC-1', 'TORC1', 'WAMTP1'], description='CREB regulated transcription coactivator 1', other_designations='CREB-regulated transcription coactivator 1|Mastermind-like protein 2|mucoepidermoid carcinoma translocated protein 1|transducer of regulated cAMP response element-binding protein (CREB) 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18683621, end_position_on_the_genomic_accession=18782333, orientation='plus', exon_count=18, OMIM=[607536], no_hdr0=''),
    23376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23376, CurrentID=0, Status='live', Symbol='UFL1', Aliases=['KIAA0776', 'Maxer', 'NLBP', 'RCAD'], description='UFM1 specific ligase 1', other_designations='E3 UFM1-protein ligase 1|E3 UFM1-protein transferase 1|LZAP-binding protein|Regulator of CDK5RAP3 and DDRGK1|multiple alpha-helix protein located at ER|novel LZAP-binding protein|regulator of C53/LZAP and DDRGK1', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96521806, end_position_on_the_genomic_accession=96555276, orientation='plus', exon_count=19, OMIM=[613372], no_hdr0=''),
    23378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23378, CurrentID=0, Status='live', Symbol='RRP8', Aliases=['KIAA0409', 'NML'], description='ribosomal RNA processing 8', other_designations='ribosomal RNA-processing protein 8|RRP8 methyltransferase homolog|cerebral protein 1|nucleomethylin|ribosomal RNA processing 8, methyltransferase, homolog', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6514830, end_position_on_the_genomic_accession=6603678, orientation='minus', exon_count=10, OMIM=[615818], no_hdr0=''),
    23379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23379, CurrentID=0, Status='live', Symbol='ICE1', Aliases=['KIAA0947'], description='interactor of little elongation complex ELL subunit 1', other_designations='little elongation complex subunit 1|interactor of little elongator complex ELL subunit 1', map_location='5p15.32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=5422673, end_position_on_the_genomic_accession=5490220, orientation='plus', exon_count=22, OMIM=[617958], no_hdr0=''),
    23380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23380, CurrentID=0, Status='live', Symbol='SRGAP2', Aliases=['ARHGAP34', 'FNBP2A', 'SRGAP3', 'SRGAP2'], description='SLIT-ROBO Rho GTPase activating protein 2', other_designations='SLIT-ROBO Rho GTPase-activating protein 2|SLIT-ROBO GAP2|formin-binding protein 2|rho GTPase-activating protein 34', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206203541, end_position_on_the_genomic_accession=206464436, orientation='plus', exon_count=29, OMIM=[606524], no_hdr0=''),
    23381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23381, CurrentID=0, Status='live', Symbol='SMG5', Aliases=['EST1B', 'LPTS-RP1', 'LPTSRP1', 'SMG-5'], description='SMG5 nonsense mediated mRNA decay factor', other_designations='protein SMG5|EST1 telomerase component homolog B|EST1-like protein B|Est1p-like protein B|LPTS interacting protein|ever shorter telomeres 1B|smg-5 homolog, nonsense mediated mRNA decay factor', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156249224, end_position_on_the_genomic_accession=156291516, orientation='minus', exon_count=25, OMIM=[610962], no_hdr0=''),
    23382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23382, CurrentID=0, Status='live', Symbol='AHCYL2', Aliases=['ADOHCYASE3', 'IRBIT2'], description='adenosylhomocysteinase like 2', other_designations='adenosylhomocysteinase 3|IP(3)Rs binding protein released with IP(3) 2|S-adenosyl-L-homocysteine hydrolase 3|S-adenosylhomocysteine hydrolase-like 2|long-IRBIT|putative adenosylhomocysteinase 3', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129225030, end_position_on_the_genomic_accession=129430211, orientation='plus', exon_count=26, OMIM=[616520], no_hdr0=''),
    23383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23383, CurrentID=0, Status='live', Symbol='MAU2', Aliases=['KIAA0892L', 'SCC4', 'mau-2', 'MAU2'], description='MAU2 sister chromatid cohesion factor', other_designations='MAU2 chromatid cohesion factor homolog|cohesin loading complex subunit SCC4 homolog|protein MAU-2|sister chromatid cohesion 4', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19320607, end_position_on_the_genomic_accession=19358754, orientation='plus', exon_count=20, OMIM=[614560], no_hdr0=''),
    23384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23384, CurrentID=0, Status='live', Symbol='SPECC1L', Aliases=['CYTSA', 'GBBB2', 'OBLFC1', 'TBHS'], description='sperm antigen with calponin homology and coiled-coil domains 1 like', other_designations='cytospin-A|SPECC1-like protein|cytokinesis and spindle organization A|renal carcinoma antigen NY-REN-22', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24270831, end_position_on_the_genomic_accession=24417738, orientation='plus', exon_count=19, OMIM=[614140], no_hdr0=''),
    23385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23385, CurrentID=0, Status='live', Symbol='NCSTN', Aliases=['ATAG1874'], description='nicastrin', other_designations='nicastrin|anterior pharynx-defective 2', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160343328, end_position_on_the_genomic_accession=160358949, orientation='plus', exon_count=19, OMIM=[605254], no_hdr0=''),
    23386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23386, CurrentID=0, Status='live', Symbol='NUDCD3', Aliases=['NudCL'], description='NudC domain containing 3', other_designations='nudC domain-containing protein 3|NudC-like protein', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44379119, end_position_on_the_genomic_accession=44490875, orientation='minus', exon_count=9, OMIM=[610296], no_hdr0=''),
    23387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23387, CurrentID=0, Status='live', Symbol='SIK3', Aliases=['L19', 'QSK', 'SEMDK', 'SIK-3'], description='SIK family kinase 3', other_designations='serine/threonine-protein kinase SIK3|salt-inducible kinase 3|serine/threonine-protein kinase QSK', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116843402, end_position_on_the_genomic_accession=117098453, orientation='minus', exon_count=31, OMIM=[614776], no_hdr0=''),
    23389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23389, CurrentID=0, Status='live', Symbol='MED13L', Aliases=['MRFACD', 'PROSIT240', 'THRAP2', 'TRAP240L'], description='mediator complex subunit 13L', other_designations='mediator of RNA polymerase II transcription subunit 13-like|mediator complex subunit 13 like|thyroid hormone receptor-associated protein 2|thyroid hormone receptor-associated protein complex 240 kDa component-like', map_location='12q24.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=115958576, end_position_on_the_genomic_accession=116277693, orientation='minus', exon_count=32, OMIM=[608771], no_hdr0=''),
    23390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23390, CurrentID=0, Status='live', Symbol='ZDHHC17', Aliases=['DHHC-17', 'DHHC17', 'HIP14', 'HIP3', 'HSPC294', 'HYPH'], description='zinc finger DHHC-type palmitoyltransferase 17', other_designations='palmitoyltransferase ZDHHC17|DHHC domain-containing cysteine-rich protein 17|acyltransferase ZDHHC17|acyltransferase ZDHHC7|huntingtin interacting protein 14|huntingtin interacting protein 3|huntingtin yeast partner H|huntingtin-interacting protein H|putative MAPK-activating protein PM11|putative NF-kappa-B-activating protein 205|zinc finger DHHC domain-containing protein 17|zinc finger DHHC-type containing 17', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76764115, end_position_on_the_genomic_accession=76853701, orientation='plus', exon_count=17, OMIM=[607799], no_hdr0=''),
    23392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23392, CurrentID=0, Status='live', Symbol='ECPAS', Aliases=['ECM29', 'KIAA0368'], description='Ecm29 proteasome adaptor and scaffold', other_designations='proteasome adapter and scaffold protein ECM29|ECM29 homolog, proteasome accessory protein|ecm29 proteasome adapter and scaffold|homolog of yeast Ecm29|proteasome-associated protein ECM29 homolog', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111360685, end_position_on_the_genomic_accession=111484383, orientation='minus', exon_count=53, OMIM=[616694], no_hdr0=''),
    23394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23394, CurrentID=0, Status='live', Symbol='ADNP', Aliases=['ADNP1', 'HVDAS', 'MRD28'], description='activity dependent neuroprotector homeobox', other_designations='activity-dependent neuroprotector homeobox protein|ADNP homeobox 1|activity-dependent neuroprotective protein|activity-dependent neuroprotector', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50888918, end_position_on_the_genomic_accession=50931437, orientation='minus', exon_count=9, OMIM=[611386], no_hdr0=''),
    23395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23395, CurrentID=0, Status='live', Symbol='LARS2', Aliases=['HLASA', 'LEURS', 'PRLTS4', 'mtLeuRS'], description='leucyl-tRNA synthetase 2, mitochondrial', other_designations='probable leucine--tRNA ligase, mitochondrial|leucine tRNA ligase 2, mitochondrial|leucine tRNA ligase 2, mitocondrial|leucine translase|probable leucyl-tRNA synthetase, mitochondrial', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45388564, end_position_on_the_genomic_accession=45549407, orientation='plus', exon_count=23, OMIM=[604544], no_hdr0=''),
    23396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23396, CurrentID=0, Status='live', Symbol='PIP5K1C', Aliases=['LCCS3', 'PIP5K-GAMMA', 'PIP5K1-gamma', 'PIP5Kgamma'], description='phosphatidylinositol-4-phosphate 5-kinase type 1 gamma', other_designations='phosphatidylinositol 4-phosphate 5-kinase type-1 gamma|PIP5K1gamma|diphosphoinositide kinase|phosphatidylinositol-4-phosphate 5-kinase, type I, gamma|ptdIns(4)P-5-kinase 1 gamma|type I PIP kinase|type I phosphatidylinositol 4-phosphate 5-kinase gamma', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3630181, end_position_on_the_genomic_accession=3700486, orientation='minus', exon_count=24, OMIM=[606102], no_hdr0=''),
    23397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23397, CurrentID=0, Status='live', Symbol='NCAPH', Aliases=['BRRN1', 'CAP-H', 'CAPH', 'MCPH23'], description='non-SMC condensin I complex subunit H', other_designations='condensin complex subunit 2|barren homolog 1|chromosome-associated protein H', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96335766, end_position_on_the_genomic_accession=96377091, orientation='plus', exon_count=18, OMIM=[602332], no_hdr0=''),
    23398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23398, CurrentID=0, Status='live', Symbol='PPWD1', Aliases=[], description='peptidylprolyl isomerase domain and WD repeat containing 1', other_designations='peptidylprolyl isomerase domain and WD repeat-containing protein 1|epididymis secretory sperm binding protein|spliceosome-associated cyclophilin', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65563295, end_position_on_the_genomic_accession=65587549, orientation='plus', exon_count=13, OMIM=[618274], no_hdr0=''),
    23399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23399, CurrentID=0, Status='live', Symbol='CTDNEP1', Aliases=['DULLARD', 'HSA011916', 'NET56'], description='CTD nuclear envelope phosphatase 1', other_designations='CTD nuclear envelope phosphatase 1|C-terminal domain nuclear envelope phosphatase 1|dullard homolog|serine/threonine-protein phosphatase dullard', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7243591, end_position_on_the_genomic_accession=7251978, orientation='minus', exon_count=9, OMIM=[610684], no_hdr0=''),
    23400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23400, CurrentID=0, Status='live', Symbol='ATP13A2', Aliases=['CLN12', 'HSA9947', 'KRPPD', 'PARK9', 'SPG78'], description='ATPase cation transporting 13A2', other_designations='polyamine-transporting ATPase 13A2|ATPase 13A2|ATPase type 13A2|cation-transporting ATPase 13A2|probable cation-transporting ATPase 13A2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16985958, end_position_on_the_genomic_accession=17011972, orientation='minus', exon_count=29, OMIM=[610513], no_hdr0=''),
    23401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23401, CurrentID=0, Status='live', Symbol='FRAT2', Aliases=['FRAT-2'], description='FRAT regulator of WNT signaling pathway 2', other_designations='GSK-3-binding protein FRAT2|FRAT2, WNT signaling pathway regulator|frequently rearranged in advanced T-cell lymphomas 2', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97332497, end_position_on_the_genomic_accession=97334729, orientation='minus', exon_count=1, OMIM=[605006], no_hdr0=''),
    23403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23403, CurrentID=0, Status='live', Symbol='FBXO46', Aliases=['20D7-FC4', 'FBXO34L', 'Fbx46'], description='F-box protein 46', other_designations='F-box only protein 46', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45710629, end_position_on_the_genomic_accession=45733177, orientation='minus', exon_count=5, OMIM=[609117], no_hdr0=''),
    23404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23404, CurrentID=0, Status='live', Symbol='EXOSC2', Aliases=['RRP4', 'Rrp4p', 'SHRF', 'hRrp4p', 'p7'], description='exosome component 2', other_designations="exosome complex component RRP4|exosome complex exonuclease RRP4|homolog of yeast RRP4 (ribosomal RNA processing 4), 3' 5' exoribonuclease (RRP4)|homolog of yeast RRP4 (ribosomal RNA processing 4), 3'-5'-exoribonuclease|ribosomal RNA-processing protein 4", map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130693760, end_position_on_the_genomic_accession=130704894, orientation='plus', exon_count=9, OMIM=[602238], no_hdr0=''),
    23405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23405, CurrentID=0, Status='live', Symbol='DICER1', Aliases=['DCR1', 'Dicer', 'Dicer1e', 'GLOW', 'HERNA', 'K12H4.8-LIKE', 'MNG1', 'RMSE2'], description='dicer 1, ribonuclease III', other_designations='endoribonuclease Dicer|Dicer1, Dcr-1 homolog|dicer 1, double-stranded RNA-specific endoribonuclease|dicer 1, ribonuclease type III|helicase MOI|helicase with RNAse motif', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95086228, end_position_on_the_genomic_accession=95158263, orientation='minus', exon_count=35, OMIM=[606241], no_hdr0=''),
    23406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23406, CurrentID=0, Status='live', Symbol='COTL1', Aliases=['CLP'], description='coactosin like F-actin binding protein 1', other_designations='coactosin-like protein|coactosin-like 1|epididymis secretory sperm binding protein', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84565596, end_position_on_the_genomic_accession=84618078, orientation='minus', exon_count=4, OMIM=[606748], no_hdr0=''),
    23408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23408, CurrentID=0, Status='live', Symbol='SIRT5', Aliases=['SIR2L5'], description='sirtuin 5', other_designations='NAD-dependent protein deacylase sirtuin-5, mitochondrial|NAD-dependent deacetylase sirtuin-5|NAD-dependent lysine demalonylase and desuccinylase sirtuin-5, mitochondrial|silent mating type information regulation 2, S.cerevisiae, homolog 5|sir2-like 5|sirtuin type 5', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13574217, end_position_on_the_genomic_accession=13615158, orientation='plus', exon_count=17, OMIM=[604483], no_hdr0=''),
    23409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23409, CurrentID=0, Status='live', Symbol='SIRT4', Aliases=['SIR2L4'], description='sirtuin 4', other_designations='NAD-dependent protein lipoamidase sirtuin-4, mitochondrial|NAD-dependent ADP-ribosyltransferase sirtuin-4|NAD-dependent protein deacetylase sirtuin-4|SIR2-like protein 4|regulatory protein SIR2 homolog 4|sir2-like 4|sirtuin type 4', map_location='12q24.23-q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120291780, end_position_on_the_genomic_accession=120313249, orientation='plus', exon_count=5, OMIM=[604482], no_hdr0=''),
    23410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23410, CurrentID=0, Status='live', Symbol='SIRT3', Aliases=['SIR2L3'], description='sirtuin 3', other_designations='NAD-dependent protein deacetylase sirtuin-3, mitochondrial|NAD-dependent deacetylase sirtuin-3, mitochondrial|SIR2-like protein 3|mitochondrial nicotinamide adenine dinucleotide-dependent deacetylase|regulatory protein SIR2 homolog 3|silent mating type information regulation 2, S.cerevisiae, homolog 3|sir2-like 3|sirtuin type 3', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=215030, end_position_on_the_genomic_accession=236931, orientation='minus', exon_count=10, OMIM=[604481], no_hdr0=''),
    23411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23411, CurrentID=0, Status='live', Symbol='SIRT1', Aliases=['SIR2', 'SIR2L1', 'SIR2alpha'], description='sirtuin 1', other_designations='NAD-dependent protein deacetylase sirtuin-1|NAD-dependent protein deacylase sirtuin-1|SIR2-like protein 1|regulatory protein SIR2 homolog 1|sirtuin type 1', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=67884656, end_position_on_the_genomic_accession=67918390, orientation='plus', exon_count=11, OMIM=[604479], no_hdr0=''),
    23412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23412, CurrentID=0, Status='live', Symbol='COMMD3', Aliases=['BUP', 'C10orf8'], description='COMM domain containing 3', other_designations='COMM domain-containing protein 3|protein Bup', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22316388, end_position_on_the_genomic_accession=22320306, orientation='plus', exon_count=8, OMIM=[616700], no_hdr0=''),
    23413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23413, CurrentID=0, Status='live', Symbol='NCS1', Aliases=['FLUP', 'FREQ'], description='neuronal calcium sensor 1', other_designations='neuronal calcium sensor 1|frequenin homolog|frequenin-like protein|frequenin-like ubiquitous protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130172404, end_position_on_the_genomic_accession=130237303, orientation='plus', exon_count=9, OMIM=[603315], no_hdr0=''),
    23414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23414, CurrentID=0, Status='live', Symbol='ZFPM2', Aliases=['DIH3', 'FOG2', 'SRXY9', 'ZC2HC11B', 'ZNF89B', 'hFOG-2'], description='zinc finger protein, FOG family member 2', other_designations='zinc finger protein ZFPM2|FOG-2|Friend of GATA2|friend of GATA 2|friend of GATA protein 2|transcription factor GATA4, modulator of|zinc finger protein 89B|zinc finger protein, multitype 2', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=105318438, end_position_on_the_genomic_accession=105804539, orientation='plus', exon_count=10, OMIM=[603693], no_hdr0=''),
    23415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23415, CurrentID=0, Status='live', Symbol='KCNH4', Aliases=['BEC2', 'ELK1', 'Kv12.3'], description='potassium voltage-gated channel subfamily H member 4', other_designations='potassium voltage-gated channel subfamily H member 4|ELK channel 1|brain-specific eag-like channel 2|ether-a-go-go K(+) channel family member|ether-a-go-go-like potassium channel 1|potassium channel, voltage gated eag related subfamily H, member 4|potassium voltage-gated channel, subfamily H (eag-related), member 4|voltage-gated potassium channel subunit Kv12.3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42156891, end_position_on_the_genomic_accession=42181275, orientation='minus', exon_count=18, OMIM=[604528], no_hdr0=''),
    23416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23416, CurrentID=0, Status='live', Symbol='KCNH3', Aliases=['BEC1', 'ELK2', 'Kv12.2'], description='potassium voltage-gated channel subfamily H member 3', other_designations='potassium voltage-gated channel subfamily H member 3|ELK channel 2|brain-specific eag-like channel 1|ether-a-go-go K(+) channel family member|ether-a-go-go-like potassium channel 2|potassium channel, voltage gated eag related subfamily H, member 3|potassium voltage-gated channel, subfamily H (eag-related), member 3|voltage-gated potassium channel subunit Kv12.2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49538541, end_position_on_the_genomic_accession=49558337, orientation='plus', exon_count=16, OMIM=[604527], no_hdr0=''),
    23417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23417, CurrentID=0, Status='live', Symbol='MLYCD', Aliases=['MCD'], description='malonyl-CoA decarboxylase', other_designations='malonyl-CoA decarboxylase, mitochondrial|malonyl coenzyme A decarboxylase', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=83899115, end_position_on_the_genomic_accession=83927031, orientation='plus', exon_count=5, OMIM=[606761], no_hdr0=''),
    23418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23418, CurrentID=0, Status='live', Symbol='CRB1', Aliases=['CRB1-A-B', 'CRB1-C', 'LCA8', 'RP12', 'CRB1'], description='crumbs cell polarity complex component 1', other_designations='protein crumbs homolog 1|crumbs 1, cell polarity complex component|crumbs family member 1, photoreceptor morphogenesis associated', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197201504, end_position_on_the_genomic_accession=197478455, orientation='plus', exon_count=17, OMIM=[604210], no_hdr0=''),
    23420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23420, CurrentID=0, Status='live', Symbol='NOMO1', Aliases=['Nomo', 'PM5'], description='NODAL modulator 1', other_designations='nodal modulator 1|nodal modulator 3|pM5 protein 3|pM5 protein, telomeric copy', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14833721, end_position_on_the_genomic_accession=14896157, orientation='plus', exon_count=31, OMIM=[609157], no_hdr0=''),
    23421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23421, CurrentID=0, Status='live', Symbol='ITGB3BP', Aliases=['CENP-R', 'CENPR', 'HSU37139', 'NRIF3', 'TAP20'], description='integrin subunit beta 3 binding protein', other_designations='centromere protein R|beta 3 endonexin|beta3-endonexin|integrin beta 3 binding protein (beta3-endonexin)|integrin beta-3-binding protein|nuclear receptor-interacting factor 3', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63440770, end_position_on_the_genomic_accession=63529395, orientation='minus', exon_count=16, OMIM=[605494], no_hdr0=''),
    23423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23423, CurrentID=0, Status='live', Symbol='TMED3', Aliases=['C15orf22', 'P24B', 'p24g4', 'p24gamma4', 'p26'], description='transmembrane p24 trafficking protein 3', other_designations='transmembrane emp24 domain-containing protein 3|integral type I protein|membrane protein p24B|p24 family protein gamma-4|testis tissue sperm-binding protein Li 48e|transmembrane emp24 protein transport domain containing 3', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79311112, end_position_on_the_genomic_accession=79413886, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    23424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23424, CurrentID=0, Status='live', Symbol='TDRD7', Aliases=['CATC4', 'PCTAIRE2BP', 'TRAP'], description='tudor domain containing 7', other_designations='tudor domain-containing protein 7|PCTAIRE2-binding protein|epididymis secretory sperm binding protein|tudor repeat associator with PCTAIRE 2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97412096, end_position_on_the_genomic_accession=97496125, orientation='plus', exon_count=17, OMIM=[611258], no_hdr0=''),
    23426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23426, CurrentID=0, Status='live', Symbol='GRIP1', Aliases=['FRASRS3', 'GRIP'], description='glutamate receptor interacting protein 1', other_designations='glutamate receptor-interacting protein 1', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66347431, end_position_on_the_genomic_accession=67069338, orientation='minus', exon_count=28, OMIM=[604597], no_hdr0=''),
    23428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23428, CurrentID=0, Status='live', Symbol='SLC7A8', Aliases=['LAT2', 'LPI-PC1'], description='solute carrier family 7 member 8', other_designations='large neutral amino acids transporter small subunit 2|L-type amino acid transporter 2|integral membrane protein E16H|solute carrier family 7 (amino acid transporter light chain, L system), member 8|solute carrier family 7 (amino acid transporter, L-type), member 8|solute carrier family 7 (cationic amino acid transporter, y+ system), member 8', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23125295, end_position_on_the_genomic_accession=23183660, orientation='minus', exon_count=13, OMIM=[604235], no_hdr0=''),
    23429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23429, CurrentID=0, Status='live', Symbol='RYBP', Aliases=['AAP1', 'APAP-1', 'DEDAF', 'YEAF1'], description='RING1 and YY1 binding protein', other_designations='RING1 and YY1-binding protein|DED-associated factor|YY1 and E4TF1 associated factor 1|apoptin-associating protein 1|death effector domain-associated factor|ring1 interactor RYBP', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=72374593, end_position_on_the_genomic_accession=72446623, orientation='minus', exon_count=4, OMIM=[607535], no_hdr0=''),
    23430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23430, CurrentID=0, Status='live', Symbol='TPSD1', Aliases=['MCP7-LIKE', 'MCP7L1', 'MMCP-7L'], description='tryptase delta 1', other_designations='tryptase delta|delta-tryptase|hmMCP-3-like tryptase III|mMCP-7-like delta II tryptase|mMCP-7-like-1|mMCP-7-like-2|mast cell tryptase|tryptase-3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1256069, end_position_on_the_genomic_accession=1259008, orientation='plus', exon_count=5, OMIM=[609272], no_hdr0=''),
    23431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23431, CurrentID=0, Status='live', Symbol='AP4E1', Aliases=['CPSQ4', 'SPG51', 'STUT1'], description='adaptor related protein complex 4 subunit epsilon 1', other_designations='AP-4 complex subunit epsilon-1|AP-4 adaptor complex subunit epsilon|adaptor related protein complex 4 epsilon 1 subunit|adaptor-related protein complex AP-4 epsilon|epsilon-adaptin', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50908569, end_position_on_the_genomic_accession=51005900, orientation='plus', exon_count=23, OMIM=[607244], no_hdr0=''),
    23432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23432, CurrentID=0, Status='live', Symbol='GPR161', Aliases=['RE2'], description='G protein-coupled receptor 161', other_designations='G-protein coupled receptor 161|G-protein coupled receptor RE2', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168079542, end_position_on_the_genomic_accession=168137667, orientation='minus', exon_count=12, OMIM=[612250], no_hdr0=''),
    23433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23433, CurrentID=0, Status='live', Symbol='RHOQ', Aliases=['ARHQ', 'HEL-S-42', 'RASL7A', 'TC10', 'TC10A'], description='ras homolog family member Q', other_designations='rho-related GTP-binding protein RhoQ|RAS-like, family 7, member A|epididymis secretory protein Li 42|ras homolog gene family, member Q|ras-like protein TC10|ras-like protein family member 7A', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46542409, end_position_on_the_genomic_accession=46584688, orientation='plus', exon_count=7, OMIM=[605857], no_hdr0=''),
    23435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23435, CurrentID=0, Status='live', Symbol='TARDBP', Aliases=['ALS10', 'TDP-43'], description='TAR DNA binding protein', other_designations='TAR DNA-binding protein 43|TAR DNA-binding protein-43', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11012654, end_position_on_the_genomic_accession=11030528, orientation='plus', exon_count=7, OMIM=[605078], no_hdr0=''),
    23436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23436, CurrentID=0, Status='live', Symbol='CELA3B', Aliases=['CBPP', 'ELA3B'], description='chymotrypsin like elastase 3B', other_designations='chymotrypsin-like elastase family member 3B|cholesterol-binding pancreatic protease|chymotrypsin like elastase family member 3B|elastase 3B, pancreatic|elastase IIIB|elastase-3B|fecal elastase 1|pancreatic elastase 1|pancreatic endopeptidase E|protease E|proteinase E', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21977022, end_position_on_the_genomic_accession=21989354, orientation='plus', exon_count=8, OMIM=[618694], no_hdr0=''),
    23438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23438, CurrentID=0, Status='live', Symbol='HARS2', Aliases=['HARSL', 'HARSR', 'HO3', 'HisRS', 'PRLTS2'], description='histidyl-tRNA synthetase 2, mitochondrial', other_designations='histidine--tRNA ligase, mitochondrial|HARS-related|histidine tRNA ligase 2, mitochondrial (putative)|histidine translase|histidine-tRNA ligase homolog|histidyl-tRNA synthetase 2, mitochondrial (putative)|histidyl-tRNA synthetase 2, mitochondrial, hisRS|probable histidine--tRNA ligase, mitochondrial|probable histidyl-tRNA synthetase, mitochondrial', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140691455, end_position_on_the_genomic_accession=140699305, orientation='plus', exon_count=14, OMIM=[600783], no_hdr0=''),
    23439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23439, CurrentID=0, Status='live', Symbol='ATP1B4', Aliases=[], description='ATPase Na+/K+ transporting family member beta 4', other_designations='protein ATP1B4|ATPase, Na+/K+ transporting, beta 4 polypeptide|BetaM|Na,K-ATPase beta m-subunit|X,K-ATPase beta-m subunit|x/potassium-transporting ATPase subunit beta-m', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120362085, end_position_on_the_genomic_accession=120383237, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    23440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23440, CurrentID=0, Status='live', Symbol='OTP', Aliases=[], description='orthopedia homeobox', other_designations='homeobox protein orthopedia|orthopedia homolog', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77628712, end_position_on_the_genomic_accession=77638713, orientation='minus', exon_count=3, OMIM=[604529], no_hdr0=''),
    23443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23443, CurrentID=0, Status='live', Symbol='SLC35A3', Aliases=['AMRS'], description='solute carrier family 35 member A3', other_designations='UDP-N-acetylglucosamine transporter|golgi UDP-GlcNAc transporter|solute carrier family 35 (UDP-N-acetylglucosamine (UDP-GlcNAc) transporter), member 3|solute carrier family 35 (UDP-N-acetylglucosamine (UDP-GlcNAc) transporter), member A3', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=99968401, end_position_on_the_genomic_accession=100035634, orientation='plus', exon_count=10, OMIM=[605632], no_hdr0=''),
    23446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23446, CurrentID=0, Status='live', Symbol='SLC44A1', Aliases=['CD92', 'CDW92', 'CHTL1', 'CONATOC', 'CTL1'], description='solute carrier family 44 member 1', other_designations='choline transporter-like protein 1|CDW92 antigen|solute carrier family 44 (choline transporter), member 1', map_location='9q31.1-q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=105244608, end_position_on_the_genomic_accession=105439775, orientation='plus', exon_count=19, OMIM=[606105], no_hdr0=''),
    23450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23450, CurrentID=0, Status='live', Symbol='SF3B3', Aliases=['RSE1', 'SAP130', 'SF3b130', 'STAF130'], description='splicing factor 3b subunit 3', other_designations='splicing factor 3B subunit 3|SAP 130|pre-mRNA splicing factor SF3b, 130 kDa subunit|spliceosome-associated protein 130', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70523816, end_position_on_the_genomic_accession=70577668, orientation='plus', exon_count=26, OMIM=[605592], no_hdr0=''),
    23451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23451, CurrentID=0, Status='live', Symbol='SF3B1', Aliases=['Hsh155', 'MDS', 'PRP10', 'PRPF10', 'SAP155', 'SF3b155'], description='splicing factor 3b subunit 1', other_designations='splicing factor 3B subunit 1|pre-mRNA processing 10|pre-mRNA splicing factor SF3b, 155 kDa subunit|spliceosome-associated protein 155|splicing factor 3b, subunit 1, 155kDa', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197389784, end_position_on_the_genomic_accession=197435093, orientation='minus', exon_count=27, OMIM=[605590], no_hdr0=''),
    23452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23452, CurrentID=0, Status='live', Symbol='ANGPTL2', Aliases=['ARP2', 'HARP'], description='angiopoietin like 2', other_designations='angiopoietin-related protein 2|angiopoietin-like protein 2', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127087348, end_position_on_the_genomic_accession=127122684, orientation='minus', exon_count=6, OMIM=[605001], no_hdr0=''),
    23456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23456, CurrentID=0, Status='live', Symbol='ABCB10', Aliases=['EST20237', 'M-ABC2', 'MTABC2'], description='ATP binding cassette subfamily B member 10', other_designations='ATP-binding cassette sub-family B member 10, mitochondrial|ABC transporter 10 protein|ABC-me protein|ABC-mitochondrial erythroid protein|ATP-binding cassette transporter 10|ATP-binding cassette, sub-family B (MDR/TAP), member 10|mitochondrial ATP-binding cassette 2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229516582, end_position_on_the_genomic_accession=229558988, orientation='minus', exon_count=15, OMIM=[605454], no_hdr0=''),
    23457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23457, CurrentID=0, Status='live', Symbol='ABCB9', Aliases=['EST122234', 'TAPL'], description='ATP binding cassette subfamily B member 9', other_designations='ABC-type oligopeptide transporter ABCB9|ATP-binding cassette sub-family B member 9|ABC transporter 9 protein|ATP-binding cassette, sub-family B (MDR/TAP), member 9|TAP-like protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122917324, end_position_on_the_genomic_accession=122975160, orientation='minus', exon_count=19, OMIM=[605453], no_hdr0=''),
    23460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23460, CurrentID=0, Status='live', Symbol='ABCA6', Aliases=['EST155051'], description='ATP binding cassette subfamily A member 6', other_designations='ATP-binding cassette sub-family A member 6|ABC transporter ABCA6|ATP-binding cassette A6|ATP-binding cassette, sub-family A (ABC1), member 6', map_location='17q24.2-q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=69062044, end_position_on_the_genomic_accession=69141927, orientation='minus', exon_count=43, OMIM=[612504], no_hdr0=''),
    23461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23461, CurrentID=0, Status='live', Symbol='ABCA5', Aliases=['ABC13', 'EST90625', 'HTC3'], description='ATP binding cassette subfamily A member 5', other_designations='cholesterol transporter ABCA5|ATP-binding cassette A5|ATP-binding cassette, sub-family A (ABC1), member 5', map_location='17q24.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=69244311, end_position_on_the_genomic_accession=69327133, orientation='minus', exon_count=39, OMIM=[612503], no_hdr0=''),
    23462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23462, CurrentID=0, Status='live', Symbol='HEY1', Aliases=['BHLHb31', 'CHF2', 'HERP2', 'HESR1', 'HRT-1', 'NERP2', 'OAF1', 'hHRT1'], description='hes related family bHLH transcription factor with YRPW motif 1', other_designations='hairy/enhancer-of-split related with YRPW motif protein 1|HES-related repressor protein 1|HES-related repressor protein 2|basic helix-loop-helix protein OAF1|cardiovascular helix-loop-helix factor 2|class B basic helix-loop-helix protein 31|hairy and enhancer of split-related protein 1|hairy-related transcription factor 1|hairy/enhancer-of-split related with YRPW motif 1', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=79764010, end_position_on_the_genomic_accession=79767767, orientation='minus', exon_count=6, OMIM=[602953], no_hdr0=''),
    23463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23463, CurrentID=0, Status='live', Symbol='ICMT', Aliases=['HSTE14', 'MST098', 'MSTP098', 'PCCMT', 'PCMT', 'PPMT'], description='isoprenylcysteine carboxyl methyltransferase', other_designations='protein-S-isoprenylcysteine O-methyltransferase|prenylated protein carboxyl methyltransferase|prenylcysteine carboxyl methyltransferase', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6221193, end_position_on_the_genomic_accession=6235964, orientation='minus', exon_count=6, OMIM=[605851], no_hdr0=''),
    23464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23464, CurrentID=0, Status='live', Symbol='GCAT', Aliases=['KBL'], description='glycine C-acetyltransferase', other_designations='2-amino-3-ketobutyrate coenzyme A ligase, mitochondrial|2-amino-3-ketobutyrate-CoA ligase|AKB ligase|aminoacetone synthase|glycine acetyltransferase', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37807894, end_position_on_the_genomic_accession=37817183, orientation='plus', exon_count=10, OMIM=[607422], no_hdr0=''),
    23466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23466, CurrentID=0, Status='live', Symbol='CBX6', Aliases=[], description='chromobox 6', other_designations='chromobox protein homolog 6|chromobox homolog 6', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38861422, end_position_on_the_genomic_accession=38872216, orientation='minus', exon_count=5, OMIM=[617438], no_hdr0=''),
    23467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23467, CurrentID=0, Status='live', Symbol='NPTXR', Aliases=['NPR'], description='neuronal pentraxin receptor', other_designations='neuronal pentraxin receptor', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38818452, end_position_on_the_genomic_accession=38844028, orientation='minus', exon_count=5, OMIM=[609474], no_hdr0=''),
    23468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23468, CurrentID=0, Status='live', Symbol='CBX5', Aliases=['HEL25', 'HP1', 'HP1A'], description='chromobox 5', other_designations='chromobox protein homolog 5|HP1 alpha homolog|HP1-ALPHA|HP1Hs alpha|antigen p25|chromobox homolog 5 (HP1 alpha homolog, Drosophila)|epididymis luminal protein 25|heterochromatin protein 1 homolog alpha|heterochromatin protein 1-alpha', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54230942, end_position_on_the_genomic_accession=54280122, orientation='minus', exon_count=6, OMIM=[604478], no_hdr0=''),
    23469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23469, CurrentID=0, Status='live', Symbol='PHF3', Aliases=[], description='PHD finger protein 3', other_designations='PHD finger protein 3', map_location='6q12', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=63635802, end_position_on_the_genomic_accession=63726011, orientation='plus', exon_count=18, OMIM=[607789], no_hdr0=''),
    23471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23471, CurrentID=0, Status='live', Symbol='TRAM1', Aliases=['PNAS8', 'TRAM', 'TRAMP'], description='translocation associated membrane protein 1', other_designations='translocating chain-associated membrane protein 1|translocating chain-associating membrane protein|translocation-associating membrane protein 1', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=70573218, end_position_on_the_genomic_accession=70608453, orientation='minus', exon_count=12, OMIM=[605190], no_hdr0=''),
    23473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23473, CurrentID=0, Status='live', Symbol='CAPN7', Aliases=['CALPAIN7', 'PALBH'], description='calpain 7', other_designations='calpain-7|calpain like protease|homolog of Aspergillus Nidulans PALB|palB homolog', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15206246, end_position_on_the_genomic_accession=15252916, orientation='plus', exon_count=24, OMIM=[606400], no_hdr0=''),
    23474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23474, CurrentID=0, Status='live', Symbol='ETHE1', Aliases=['HSCO', 'YF13H12'], description='ETHE1 persulfide dioxygenase', other_designations='persulfide dioxygenase ETHE1, mitochondrial|ethylmalonic encephalopathy 1|hepatoma subtracted clone one protein|protein ETHE1, mitochondrial|sulfur dioxygenase ETHE1', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43506719, end_position_on_the_genomic_accession=43527201, orientation='minus', exon_count=7, OMIM=[608451], no_hdr0=''),
    23475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23475, CurrentID=0, Status='live', Symbol='QPRT', Aliases=['HEL-S-90nase', 'QPRT'], description='quinolinate phosphoribosyltransferase', other_designations='nicotinate-nucleotide pyrophosphorylase [carboxylating]|epididymis secretory sperm binding protein Li 90n|nicotinate-nucleotide pyrophosphorylase (carboxylating)', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29670588, end_position_on_the_genomic_accession=29698699, orientation='plus', exon_count=5, OMIM=[606248], no_hdr0=''),
    23476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23476, CurrentID=0, Status='live', Symbol='BRD4', Aliases=['CAP', 'HUNK1', 'HUNKI', 'MCAP'], description='bromodomain containing 4', other_designations='bromodomain-containing protein 4|chromosome-associated protein|mitotic chromosome-associated protein', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15235519, end_position_on_the_genomic_accession=15332539, orientation='minus', exon_count=23, OMIM=[608749], no_hdr0=''),
    23478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23478, CurrentID=0, Status='live', Symbol='SEC11A', Aliases=['1810012E07Rik', 'SEC11L1', 'SPC18', 'SPCS4A', 'sid2895'], description='SEC11 homolog A, signal peptidase complex subunit', other_designations='signal peptidase complex catalytic subunit SEC11A|SEC11-like protein 1|SPase 18 kDa subunit|endopeptidase SP18|microsomal signal peptidase 18 kDa subunit|signal peptidase complex (18kD)|signal peptidase complex 18', map_location='15q25.2-q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84669544, end_position_on_the_genomic_accession=84716139, orientation='minus', exon_count=9, OMIM=[618258], no_hdr0=''),
    23479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23479, CurrentID=0, Status='live', Symbol='ISCU', Aliases=['2310020H20Rik', 'HML', 'ISU2', 'NIFU', 'NIFUN', 'hnifU'], description='iron-sulfur cluster assembly enzyme', other_designations='iron-sulfur cluster assembly enzyme ISCU, mitochondrial|IscU iron-sulfur cluster scaffold homolog|nifU-like N-terminal domain-containing protein', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108561463, end_position_on_the_genomic_accession=108569384, orientation='plus', exon_count=8, OMIM=[611911], no_hdr0=''),
    23480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23480, CurrentID=0, Status='live', Symbol='SEC61G', Aliases=['SSS1'], description='SEC61 translocon subunit gamma', other_designations='protein transport protein Sec61 subunit gamma|SEC61 translocon gamma subunit|Sec61 gamma subunit|protein transport protein SEC61 gamma subunit', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=54752253, end_position_on_the_genomic_accession=54759211, orientation='minus', exon_count=4, OMIM=[609215], no_hdr0=''),
    23481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23481, CurrentID=0, Status='live', Symbol='PES1', Aliases=['NOP7', 'PES'], description='pescadillo ribosomal biogenesis factor 1', other_designations='pescadillo homolog|pescadillo homolog 1, containing BRCT domain', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30576625, end_position_on_the_genomic_accession=30607013, orientation='minus', exon_count=19, OMIM=[605819], no_hdr0=''),
    23483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23483, CurrentID=0, Status='live', Symbol='TGDS', Aliases=['CATMANS', 'SDR2E1', 'TDPGD'], description='TDP-glucose 4,6-dehydratase', other_designations='dTDP-D-glucose 4,6-dehydratase|growth-inhibiting protein 21|short chain dehydrogenase/reductase family 2E, member 1', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=94574054, end_position_on_the_genomic_accession=94596274, orientation='minus', exon_count=13, OMIM=[616146], no_hdr0=''),
    23484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23484, CurrentID=0, Status='live', Symbol='LEPROTL1', Aliases=['HSPC112', 'Vps55', 'my047'], description='leptin receptor overlapping transcript like 1', other_designations='leptin receptor overlapping transcript-like 1|endospanin-2', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30095408, end_position_on_the_genomic_accession=30138348, orientation='plus', exon_count=5, OMIM=[607338], no_hdr0=''),
    23491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23491, CurrentID=0, Status='live', Symbol='CES3', Aliases=['ES31'], description='carboxylesterase 3', other_designations='carboxylesterase 3|carboxylesterase 3 (brain)|esterase 31|liver carboxylesterase 31 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66961266, end_position_on_the_genomic_accession=66975149, orientation='plus', exon_count=14, OMIM=[605279], no_hdr0=''),
    23492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23492, CurrentID=0, Status='live', Symbol='CBX7', Aliases=[], description='chromobox 7', other_designations='chromobox protein homolog 7', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39130772, end_position_on_the_genomic_accession=39152680, orientation='minus', exon_count=6, OMIM=[608457], no_hdr0=''),
    23493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23493, CurrentID=0, Status='live', Symbol='HEY2', Aliases=['CHF1', 'GRIDLOCK', 'GRL', 'HERP1', 'HESR2', 'HRT2', 'bHLHb32'], description='hes related family bHLH transcription factor with YRPW motif 2', other_designations='hairy/enhancer-of-split related with YRPW motif protein 2|HES-related repressor protein 1|HES-related repressor protein 2|HESR-2|HRT-2|cardiovascular basic helix-loop-helix factor 1|cardiovascular helix-loop-helix factor 1|class B basic helix-loop-helix protein 32|hCHF1|hHRT2|hairy and enhancer of split-related protein 2|hairy-related transcription factor 2|hairy/enhancer-of-split related with YRPW motif 2|protein gridlock homolog', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125747639, end_position_on_the_genomic_accession=125762243, orientation='plus', exon_count=7, OMIM=[604674], no_hdr0=''),
    23495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23495, CurrentID=0, Status='live', Symbol='TNFRSF13B', Aliases=['CD267', 'CVID', 'CVID2', 'IGAD2', 'RYZN', 'TACI', 'TNFRSF14B'], description='TNF receptor superfamily member 13B', other_designations='tumor necrosis factor receptor superfamily member 13B|transmembrane activator and CAML interactor|tumor necrosis factor receptor 13B', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16939081, end_position_on_the_genomic_accession=16972118, orientation='minus', exon_count=5, OMIM=[604907], no_hdr0=''),
    23498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23498, CurrentID=0, Status='live', Symbol='HAAO', Aliases=['3-HAO', 'HAO', 'VCRL1', 'h3HAO'], description='3-hydroxyanthranilate 3,4-dioxygenase', other_designations='3-hydroxyanthranilate 3,4-dioxygenase|3-hydroxyanthranilate oxygenase|3-hydroxyanthranilic acid dioxygenase|HAD', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42767087, end_position_on_the_genomic_accession=42801002, orientation='minus', exon_count=11, OMIM=[604521], no_hdr0=''),
    23499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23499, CurrentID=0, Status='live', Symbol='MACF1', Aliases=['ABP620', 'ACF7', 'LIS9', 'Lnc-PMIF', 'MACF', 'OFC4'], description='microtubule actin crosslinking factor 1', other_designations='microtubule-actin cross-linking factor 1|620 kDa actin binding protein|actin cross-linking family protein 7|postulated migration inhibitory factor|trabeculin-alpha', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39084167, end_position_on_the_genomic_accession=39487138, orientation='plus', exon_count=103, OMIM=[608271], no_hdr0=''),
    23500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23500, CurrentID=0, Status='live', Symbol='DAAM2', Aliases=['NPHS24', 'dJ90A20A.1'], description='dishevelled associated activator of morphogenesis 2', other_designations='disheveled-associated activator of morphogenesis 2', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39792366, end_position_on_the_genomic_accession=39904870, orientation='plus', exon_count=31, OMIM=[606627], no_hdr0=''),
    23503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23503, CurrentID=0, Status='live', Symbol='ZFYVE26', Aliases=['FYVE-CENT', 'SPG15'], description='zinc finger FYVE-type containing 26', other_designations='zinc finger FYVE domain-containing protein 26|FYVE domain-containing centrosomal protein|spastizin|zinc finger, FYVE domain containing 26', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67728892, end_position_on_the_genomic_accession=67817293, orientation='minus', exon_count=45, OMIM=[612012], no_hdr0=''),
    23504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23504, CurrentID=0, Status='live', Symbol='RIMBP2', Aliases=['PPP1R133', 'RBP2', 'RIM-BP2'], description='RIMS binding protein 2', other_designations='RIMS-binding protein 2|RIM binding protein 2|protein phosphatase 1, regulatory subunit 133', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130396133, end_position_on_the_genomic_accession=130716299, orientation='minus', exon_count=30, OMIM=[611602], no_hdr0=''),
    23505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23505, CurrentID=0, Status='live', Symbol='TMEM131', Aliases=['CC28', 'PRO1048', 'RW1', 'YR-23'], description='transmembrane protein 131', other_designations='transmembrane protein 131|2610524E03Rik', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97756336, end_position_on_the_genomic_accession=97996182, orientation='minus', exon_count=42, OMIM=[615659], no_hdr0=''),
    23506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23506, CurrentID=0, Status='live', Symbol='BICRAL', Aliases=['GLTSCR1L', 'KIAA0240'], description='BICRA like chromatin remodeling complex associated protein', other_designations='BRD4-interacting chromatin-remodeling complex-associated protein-like|BRD4 interacting chromatin remodeling complex associated protein like|BRD4 interacting chromatin remodelling complex associated protein like|GLTSCR1 like|glioma tumor suppressor candidate region gene 1 protein-like', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42746987, end_position_on_the_genomic_accession=42868558, orientation='plus', exon_count=17, OMIM=[618502], no_hdr0=''),
    23507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23507, CurrentID=0, Status='live', Symbol='LRRC8B', Aliases=['TA-LRRP', 'TALRRP'], description='leucine rich repeat containing 8 VRAC subunit B', other_designations='volume-regulated anion channel subunit LRRC8B|T-cell activation leucine repeat-rich protein|epididymis secretory sperm binding protein|leucine rich repeat containing 8 family member B|leucine-rich repeat-containing protein 8B', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89522626, end_position_on_the_genomic_accession=89597861, orientation='plus', exon_count=12, OMIM=[612888], no_hdr0=''),
    23508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23508, CurrentID=0, Status='live', Symbol='TTC9', Aliases=['TTC9A'], description='tetratricopeptide repeat domain 9', other_designations='tetratricopeptide repeat protein 9A|TPR repeat protein 9A', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70641916, end_position_on_the_genomic_accession=70675366, orientation='plus', exon_count=3, OMIM=[610488], no_hdr0=''),
    23509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23509, CurrentID=0, Status='live', Symbol='POFUT1', Aliases=['DDD2', 'FUT12', 'O-FUT', 'O-Fuc-T', 'O-FucT-1', 'OFUCT1'], description='protein O-fucosyltransferase 1', other_designations='GDP-fucose protein O-fucosyltransferase 1|o-fucosyltransferase protein|peptide-O-fucosyltransferase 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32207880, end_position_on_the_genomic_accession=32238658, orientation='plus', exon_count=9, OMIM=[607491], no_hdr0=''),
    23510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23510, CurrentID=0, Status='live', Symbol='KCTD2', Aliases=[], description='potassium channel tetramerization domain containing 2', other_designations='BTB/POZ domain-containing protein KCTD2|potassium channel tetramerisation domain containing 2|potassium channel tetramerization domain-containing protein 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75032571, end_position_on_the_genomic_accession=75065886, orientation='plus', exon_count=10, OMIM=[613422], no_hdr0=''),
    23511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23511, CurrentID=0, Status='live', Symbol='NUP188', Aliases=['KIAA0169', 'SANDSTEF', 'hNup188'], description='nucleoporin 188', other_designations='nucleoporin NUP188|nucleoporin 188kDa|nucleoporin NUP188 homolog', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128947699, end_position_on_the_genomic_accession=129007096, orientation='plus', exon_count=44, OMIM=[615587], no_hdr0=''),
    23512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23512, CurrentID=0, Status='live', Symbol='SUZ12', Aliases=['CHET9', 'IMMAS', 'JJAZ1'], description='SUZ12 polycomb repressive complex 2 subunit', other_designations='polycomb protein SUZ12|chET 9 protein|chromatin precipitated E2F target 9 protein|joined to JAZF1 protein|suppressor of zeste 12 protein homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31937007, end_position_on_the_genomic_accession=32001040, orientation='plus', exon_count=16, OMIM=[606245], no_hdr0=''),
    23513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23513, CurrentID=0, Status='live', Symbol='SCRIB', Aliases=['CRIB1', 'SCRB11', 'Vartul', 'SCRIB'], description='scribble planar cell polarity protein', other_designations='protein scribble homolog|scribbled homolog|scribbled planar cell polarity protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143790925, end_position_on_the_genomic_accession=143815773, orientation='minus', exon_count=37, OMIM=[607733], no_hdr0=''),
    23514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23514, CurrentID=0, Status='live', Symbol='SPIDR', Aliases=['KIAA0146'], description='scaffold protein involved in DNA repair', other_designations='DNA repair-scaffolding protein|scaffolding protein involved in DNA repair', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47260878, end_position_on_the_genomic_accession=47736306, orientation='plus', exon_count=31, OMIM=[615384], no_hdr0=''),
    23515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23515, CurrentID=0, Status='live', Symbol='MORC3', Aliases=['NXP2', 'ZCW5', 'ZCWCC3'], description='MORC family CW-type zinc finger 3', other_designations='MORC family CW-type zinc finger protein 3|nuclear matrix protein 2|nuclear matrix protein NXP2|zinc finger CW-type coiled-coil domain protein 3|zinc finger, CW type with coiled-coil domain 3', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36320197, end_position_on_the_genomic_accession=36376637, orientation='plus', exon_count=20, OMIM=[610078], no_hdr0=''),
    23516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23516, CurrentID=0, Status='live', Symbol='SLC39A14', Aliases=['HCIN', 'HMNDYT2', 'LZT-Hs4', 'NET34', 'ZIP14', 'cig19'], description='solute carrier family 39 member 14', other_designations='metal cation symporter ZIP14|LIV-1 subfamily of ZIP zinc transporter 4|Zinc transporter ZIP14|Zrt-, Irt-like protein 14|solute carrier family 39 (metal ion transporter), member 14|solute carrier family 39 (zinc transporter), member 14|zrt- and Irt-like protein 14', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22367278, end_position_on_the_genomic_accession=22434129, orientation='plus', exon_count=16, OMIM=[608736], no_hdr0=''),
    23517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23517, CurrentID=0, Status='live', Symbol='MTREX', Aliases=['Dob1', 'KIAA0052', 'Mtr4', 'SKIV2L2', 'fSAP118'], description='Mtr4 exosome RNA helicase', other_designations='exosome RNA helicase MTR4|ATP-dependent RNA helicase DOB1|ATP-dependent RNA helicase SKIV2L2|ATP-dependent helicase SKIV2L2|Ski2 like RNA helicase 2|TRAMP-like complex helicase|functional spliceosome-associated protein 118|superkiller viralicidic activity 2-like 2', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55307989, end_position_on_the_genomic_accession=55425579, orientation='plus', exon_count=27, OMIM=[618122], no_hdr0=''),
    23518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23518, CurrentID=0, Status='live', Symbol='R3HDM1', Aliases=['R3HDM'], description='R3H domain containing 1', other_designations='R3H domain-containing protein 1|R3H domain (binds single-stranded nucleic acids) containing', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135531484, end_position_on_the_genomic_accession=135725269, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    23519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23519, CurrentID=0, Status='live', Symbol='ANP32D', Aliases=['PP32R2'], description='acidic nuclear phosphoprotein 32 family member D', other_designations='acidic leucine-rich nuclear phosphoprotein 32 family member D|acidic (leucine-rich) nuclear phosphoprotein 32 family, member D|acidic nuclear phosphoprotein 32D|phosphoprotein 32-related protein 2|pp32 related 2|tumorigenic protein pp32r2', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48472559, end_position_on_the_genomic_accession=48473622, orientation='plus', exon_count=1, OMIM=[606878], no_hdr0=''),
    23521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23521, CurrentID=0, Status='live', Symbol='RPL13A', Aliases=['L13A', 'TSTA1'], description='ribosomal protein L13a', other_designations='60S ribosomal protein L13a|23 kDa highly basic protein|epididymis secretory sperm binding protein|large ribosomal subunit protein uL13|tissue specific transplantation antigen 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49487608, end_position_on_the_genomic_accession=49492308, orientation='plus', exon_count=8, OMIM=[619225], no_hdr0=''),
    23522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23522, CurrentID=0, Status='live', Symbol='KAT6B', Aliases=['GTPTS', 'MORF', 'MOZ2', 'MYST4', 'ZC2HC6B', 'qkf', 'querkopf'], description='lysine acetyltransferase 6B', other_designations='histone acetyltransferase KAT6B|K(lysine) acetyltransferase 6B|MOZ, YBF2/SAS3, SAS2 and TIP60 protein 4|MOZ-related factor|MYST histone acetyltransferase (monocytic leukemia) 4|MYST-4|histone acetyltransferase MORF|histone acetyltransferase MOZ2|histone acetyltransferase MYST4|monocytic leukemia zinc finger protein-related factor', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=74824927, end_position_on_the_genomic_accession=75032624, orientation='plus', exon_count=20, OMIM=[605880], no_hdr0=''),
    23523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23523, CurrentID=0, Status='live', Symbol='CABIN1', Aliases=['CAIN', 'KB-318B8.7', 'PPP3IN'], description='calcineurin binding protein 1', other_designations='calcineurin-binding protein cabin-1|calcineurin binding protein cabin 1|calcineurin inhibitor', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24011192, end_position_on_the_genomic_accession=24178628, orientation='plus', exon_count=43, OMIM=[604251], no_hdr0=''),
    23524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23524, CurrentID=0, Status='live', Symbol='SRRM2', Aliases=['300-KD', 'CWF21', 'Cwc21', 'HSPC075', 'SRL300', 'SRm300'], description='serine/arginine repetitive matrix 2', other_designations='serine/arginine repetitive matrix protein 2|300 kDa nuclear matrix antigen|RNA binding protein|SR-related nuclear matrix protein of 300 kDa|ser/Arg-related nuclear matrix protein of 300 kDa|serine/arginine-rich splicing factor-related nuclear matrix protein of 300 kDa|splicing coactivator subunit SRm300|tax-responsive enhancer element-binding protein 803|taxREB803|testicular secretory protein Li 53', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2750903, end_position_on_the_genomic_accession=2771412, orientation='plus', exon_count=16, OMIM=[606032], no_hdr0=''),
    23526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23526, CurrentID=0, Status='live', Symbol='ARHGAP45', Aliases=['HA-1', 'HLA-HA1', 'HMHA1'], description='Rho GTPase activating protein 45', other_designations='rho GTPase-activating protein 45|histocompatibility (minor) HA-1|minor histocompatibility antigen HA-1|minor histocompatibility protein HA-1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1065959, end_position_on_the_genomic_accession=1086628, orientation='plus', exon_count=26, OMIM=[601155], no_hdr0=''),
    23527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23527, CurrentID=0, Status='live', Symbol='ACAP2', Aliases=['CENTB2', 'CNT-B2'], description='ArfGAP with coiled-coil, ankyrin repeat and PH domains 2', other_designations='arf-GAP with coiled-coil, ANK repeat and PH domain-containing protein 2|Arf GAP with coiled coil, ANK repeat and PH domains 2|centaurin-beta-2', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195274742, end_position_on_the_genomic_accession=195443176, orientation='minus', exon_count=29, OMIM=[607766], no_hdr0=''),
    23528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23528, CurrentID=0, Status='live', Symbol='ZNF281', Aliases=['GZP1', 'ZBP-99', 'ZBP99', 'ZNP-99'], description='zinc finger protein 281', other_designations='zinc finger protein 281|GC-box-binding zinc finger protein 1|ZNP-99 transcription factor|transcription factor ZBP-99|zinc finger DNA-binding protein 99', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200404951, end_position_on_the_genomic_accession=200410036, orientation='minus', exon_count=3, OMIM=[618703], no_hdr0=''),
    23529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23529, CurrentID=0, Status='live', Symbol='CLCF1', Aliases=['BSF-3', 'BSF3', 'CISS2', 'CLC', 'NNT-1', 'NNT1', 'NR6'], description='cardiotrophin like cytokine factor 1', other_designations='cardiotrophin-like cytokine factor 1|B-cell stimulatory factor 3|B-cell-stimulating factor 3|CRLF1 associated cytokine-like factor 1|neurotrophin-1/B-cell stimulating factor-3|novel neurotrophin-1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67364168, end_position_on_the_genomic_accession=67374177, orientation='minus', exon_count=4, OMIM=[607672], no_hdr0=''),
    23530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23530, CurrentID=0, Status='live', Symbol='NNT', Aliases=['GCCD4'], description='nicotinamide nucleotide transhydrogenase', other_designations='NAD(P) transhydrogenase, mitochondrial|pyridine nucleotide transhydrogenase', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43601092, end_position_on_the_genomic_accession=43707396, orientation='plus', exon_count=26, OMIM=[607878], no_hdr0=''),
    23531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23531, CurrentID=0, Status='live', Symbol='MMD', Aliases=['MMA1', 'PAQR11', 'MMD'], description='monocyte to macrophage differentiation associated', other_designations='monocyte to macrophage differentiation factor|macrophage maturation-associated|monocyte to macrophage differentiation protein|progestin and adipoQ receptor family member 11|progestin and adipoQ receptor family member XI', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=55392617, end_position_on_the_genomic_accession=55421886, orientation='minus', exon_count=9, OMIM=[604467], no_hdr0=''),
    23532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23532, CurrentID=0, Status='live', Symbol='PRAME', Aliases=['CT130', 'MAPE', 'OIP-4', 'OIP4'], description='PRAME nuclear receptor transcriptional regulator', other_designations='melanoma antigen preferentially expressed in tumors|Opa-interacting protein OIP4|cancer/testis antigen 130|opa-interacting protein 4|preferentially expressed antigen in melanoma|preferentially expressed antigen of melanoma', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22547701, end_position_on_the_genomic_accession=22559294, orientation='minus', exon_count=8, OMIM=[606021], no_hdr0=''),
    23533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23533, CurrentID=0, Status='live', Symbol='PIK3R5', Aliases=['F730038I15Rik', 'FOAP-2', 'P101-PI3K', 'p101'], description='phosphoinositide-3-kinase regulatory subunit 5', other_designations='phosphoinositide 3-kinase regulatory subunit 5|PI3-kinase p101 subunit|phosphatidylinositol 4,5-bisphosphate 3-kinase regulatory subunit|protein FOAP-2|ptdIns-3-kinase p101', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8878916, end_position_on_the_genomic_accession=8965707, orientation='minus', exon_count=22, OMIM=[611317], no_hdr0=''),
    23534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23534, CurrentID=0, Status='live', Symbol='TNPO3', Aliases=['IPO12', 'LGMD1F', 'LGMDD2', 'MTR10A', 'TRN-SR', 'TRN-SR2', 'TRNSR'], description='transportin 3', other_designations='transportin-3|imp12|importin 12|limb girdle muscular dystrophy 1F (autosomal dominant)|transportin-SR', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128954185, end_position_on_the_genomic_accession=129055111, orientation='minus', exon_count=31, OMIM=[610032], no_hdr0=''),
    23536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23536, CurrentID=0, Status='live', Symbol='ADAT1', Aliases=['HADAT1'], description='adenosine deaminase tRNA specific 1', other_designations='tRNA-specific adenosine deaminase 1|adenosine deaminase acting on tRNA|tRNA-specific adenosine-37 deaminase', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75596868, end_position_on_the_genomic_accession=75623281, orientation='minus', exon_count=12, OMIM=[604230], no_hdr0=''),
    23538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23538, CurrentID=0, Status='live', Symbol='OR52A1', Aliases=['HPFH1OR'], description='olfactory receptor family 52 subfamily A member 1', other_designations="olfactory receptor 52A1|odorant receptor HOR3'beta4|olfactory receptor OR11-319", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5146824, end_position_on_the_genomic_accession=5154757, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    23539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23539, CurrentID=0, Status='live', Symbol='SLC16A8', Aliases=['MCT3', 'REMP'], description='solute carrier family 16 member 8', other_designations='monocarboxylate transporter 3|MCT 3|solute carrier 16 (monocarboxylic acid transporters), member 8|solute carrier family 16 (monocarboxylate transporter), member 8|solute carrier family 16, member 8 (monocarboxylic acid transporter 3)', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38078137, end_position_on_the_genomic_accession=38084184, orientation='minus', exon_count=6, OMIM=[610409], no_hdr0=''),
    23541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23541, CurrentID=0, Status='live', Symbol='SEC14L2', Aliases=['C22orf6', 'SPF', 'TAP', 'TAP1'], description='SEC14 like lipid binding 2', other_designations='SEC14-like protein 2|alpha-tocopherol-associated protein|squalene transfer protein|supernatant protein factor|tocopherol-associated protein 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30397018, end_position_on_the_genomic_accession=30425303, orientation='plus', exon_count=12, OMIM=[607558], no_hdr0=''),
    23542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23542, CurrentID=0, Status='live', Symbol='MAPK8IP2', Aliases=['IB-2', 'IB2', 'JIP2', 'PRKM8IPL'], description='mitogen-activated protein kinase 8 interacting protein 2', other_designations='C-Jun-amino-terminal kinase-interacting protein 2|JNK MAP kinase scaffold protein 2|JNK MAP kinase scaffold protein JIP2|JNK-interacting protein 2|homologous to mouse JIP-1|islet-brain 2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50600793, end_position_on_the_genomic_accession=50613978, orientation='plus', exon_count=12, OMIM=[607755], no_hdr0=''),
    23543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23543, CurrentID=0, Status='live', Symbol='RBFOX2', Aliases=['FOX2', 'Fox-2', 'HNRBP2', 'HRNBP2', 'RBM9', 'RTA', 'dJ106I20.3', 'fxh'], description='RNA binding fox-1 homolog 2', other_designations='RNA binding protein fox-1 homolog 2|RNA binding protein, fox-1 homolog 2|RNA-binding motif protein 9|fox-1 homolog B|fox-1 homologue|hexaribonucleotide-binding protein 2|repressor of tamoxifen transcriptional activity', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35738736, end_position_on_the_genomic_accession=36028892, orientation='minus', exon_count=24, OMIM=[612149], no_hdr0=''),
    23544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23544, CurrentID=0, Status='live', Symbol='SEZ6L', Aliases=[], description='seizure related 6 homolog like', other_designations='seizure 6-like protein|seizure related gene 6-like', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26169462, end_position_on_the_genomic_accession=26383596, orientation='plus', exon_count=17, OMIM=[607021], no_hdr0=''),
    23545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23545, CurrentID=0, Status='live', Symbol='ATP6V0A2', Aliases=['A2', 'ARCL', 'ARCL2A', 'ATP6A2', 'ATP6N1D', 'J6B7', 'RTF', 'STV1', 'TJ6', 'TJ6M', 'TJ6S', 'VPH1', 'WSS', 'a2V'], description='ATPase H+ transporting V0 subunit a2', other_designations='V-type proton ATPase 116 kDa subunit a2|A2V-ATPase|ATPase, H+ transporting, lysosomal V0 subunit a2|V-ATPase 116 kDa subunit a2|V-ATPase subunit a2|lysosomal H(+)-transporting ATPase V0 subunit a2|regeneration and tolerance factor|v-type proton ATPase 116 kDa subunit a|vacuolar proton translocating ATPase 116 kDa subunit a', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123712353, end_position_on_the_genomic_accession=123761755, orientation='plus', exon_count=21, OMIM=[611716], no_hdr0=''),
    23546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23546, CurrentID=0, Status='live', Symbol='SYNGR4', Aliases=[], description='synaptogyrin 4', other_designations='synaptogyrin-4|testis tissue sperm-binding protein Li 72n', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48364267, end_position_on_the_genomic_accession=48376377, orientation='plus', exon_count=8, OMIM=[608373], no_hdr0=''),
    23547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23547, CurrentID=0, Status='live', Symbol='LILRA4', Aliases=['CD85g', 'ILT7'], description='leukocyte immunoglobulin like receptor A4', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 4|CD85 antigen-like family member G|immunoglobulin-like transcript 7|leucocyte Ig-like receptor A4|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 4|leukocyte immunoglobulin-like receptor, subfamily A (without TM domain), member 4', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54333185, end_position_on_the_genomic_accession=54339162, orientation='minus', exon_count=8, OMIM=[607517], no_hdr0=''),
    23548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23548, CurrentID=0, Status='live', Symbol='TTC33', Aliases=['OSRF'], description='tetratricopeptide repeat domain 33', other_designations='tetratricopeptide repeat protein 33|TPR repeat protein 33|osmosis responsive factor', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40711576, end_position_on_the_genomic_accession=40755961, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    23549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23549, CurrentID=0, Status='live', Symbol='DNPEP', Aliases=['ASPEP', 'DAP'], description='aspartyl aminopeptidase', other_designations='aspartyl aminopeptidase', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219372043, end_position_on_the_genomic_accession=219400007, orientation='minus', exon_count=19, OMIM=[611367], no_hdr0=''),
    23550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23550, CurrentID=0, Status='live', Symbol='PSD4', Aliases=['EFA6B', 'TIC'], description='pleckstrin and Sec7 domain containing 4', other_designations='PH and SEC7 domain-containing protein 4|ADP-ribosylation factor guanine nucleotide-exchange factor 6|SEC7 homolog|exchange factor for ADP-ribosylation factor guanine nucleotide factor 6 B|exchange factor for ADP-ribosylation factor guanine nucleotide factor 6B|exchange factor for ARF6 B|pleckstrin homology and SEC7 domain-containing protein 4|telomeric of interleukin-1 cluster protein', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113157399, end_position_on_the_genomic_accession=113209391, orientation='plus', exon_count=18, OMIM=[614442], no_hdr0=''),
    23551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23551, CurrentID=0, Status='live', Symbol='RASD2', Aliases=['Rhes', 'TEM2'], description='RASD family member 2', other_designations='GTP-binding protein Rhes|Ras homolog enriched in striatum|tumor endothelial marker 2', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35532806, end_position_on_the_genomic_accession=35554003, orientation='plus', exon_count=7, OMIM=[612842], no_hdr0=''),
    23552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23552, CurrentID=0, Status='live', Symbol='CDK20', Aliases=['CCRK', 'CDCH', 'P42', 'PNQALRE'], description='cyclin dependent kinase 20', other_designations='cyclin-dependent kinase 20|CAK-kinase p42|CDK-activating kinase p42|cell cycle-related kinase|cell division protein kinase 20|cyclin-dependent protein kinase H|cyclin-kinase-activating kinase p42', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=87966441, end_position_on_the_genomic_accession=87974708, orientation='minus', exon_count=9, OMIM=[610076], no_hdr0=''),
    23553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23553, CurrentID=0, Status='live', Symbol='HYAL4', Aliases=['CSHY', 'HYAL-4'], description='hyaluronidase 4', other_designations='hyaluronidase-4|HYAL-4 variant 1|chondroitin sulfate endo-beta-N-acetylgalactosaminidase|chondroitin sulfate hydrolase|hyaluronoglucosaminidase 4', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123763708, end_position_on_the_genomic_accession=123877481, orientation='plus', exon_count=10, OMIM=[604510], no_hdr0=''),
    23554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23554, CurrentID=0, Status='live', Symbol='TSPAN12', Aliases=['EVR5', 'NET-2', 'NET2', 'TM4SF12'], description='tetraspanin 12', other_designations='tetraspanin-12|tetraspan NET-2|transmembrane 4 superfamily member 12|tspan-12', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=120787320, end_position_on_the_genomic_accession=120858337, orientation='minus', exon_count=11, OMIM=[613138], no_hdr0=''),
    23555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23555, CurrentID=0, Status='live', Symbol='TSPAN15', Aliases=['2700063A19Rik', 'NET-7', 'NET7', 'TM4SF15'], description='tetraspanin 15', other_designations='tetraspanin-15|tetraspan NET-7|transmembrane 4 superfamily member 15|transmembrane 4 superfamily member tetraspan NET-7|tspan-15', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69451464, end_position_on_the_genomic_accession=69549508, orientation='plus', exon_count=14, OMIM=[613140], no_hdr0=''),
    23556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23556, CurrentID=0, Status='live', Symbol='PIGN', Aliases=['MCAHS', 'MCAHS1', 'MCD4', 'MDC4', 'PIG-N'], description='phosphatidylinositol glycan anchor biosynthesis class N', other_designations='GPI ethanolamine phosphate transferase 1|MCD4 homolog|phosphatidylinositol-glycan biosynthesis class N protein', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=62041164, end_position_on_the_genomic_accession=62187118, orientation='minus', exon_count=33, OMIM=[606097], no_hdr0=''),
    23557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23557, CurrentID=0, Status='live', Symbol='SNAPIN', Aliases=['BLOC1S7', 'BLOS7', 'BORCS3', 'SNAPAP'], description='SNAP associated protein', other_designations='SNARE-associated protein Snapin|BLOC-1 related complex subunit 3|BLOC-1 subunit 7|SNAP-25-binding protein|SNARE associated protein snapin|biogenesis of lysosomal organelles complex-1, subunit 7|biogenesis of lysosome-related organelles complex 1 subunit 7|synaptosomal-associated protein 25-binding protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153658654, end_position_on_the_genomic_accession=153661852, orientation='plus', exon_count=4, OMIM=[607007], no_hdr0=''),
    23558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23558, CurrentID=0, Status='live', Symbol='WBP2', Aliases=['DFNB107', 'GRAMD6', 'WBP-2'], description='WW domain binding protein 2', other_designations='WW domain-binding protein 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75845699, end_position_on_the_genomic_accession=75856436, orientation='minus', exon_count=9, OMIM=[606962], no_hdr0=''),
    23559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23559, CurrentID=0, Status='live', Symbol='WBP1', Aliases=['WBP-1'], description='WW domain binding protein 1', other_designations='WW domain-binding protein 1|epididymis secretory sperm binding protein', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74458438, end_position_on_the_genomic_accession=74460881, orientation='plus', exon_count=4, OMIM=[606961], no_hdr0=''),
    23560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23560, CurrentID=0, Status='live', Symbol='GTPBP4', Aliases=['CRFG', 'NGB', 'NOG1'], description='GTP binding protein 4', other_designations='GTP-binding protein 4|nucleolar GTP-binding protein 1|G protein-binding protein CRFG|GTP-binding protein NGB|chronic renal failure gene protein', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=988434, end_position_on_the_genomic_accession=1019932, orientation='plus', exon_count=17, OMIM=[619169], no_hdr0=''),
    23562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23562, CurrentID=0, Status='live', Symbol='CLDN14', Aliases=['DFNB29'], description='claudin 14', other_designations='claudin-14', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36460621, end_position_on_the_genomic_accession=36576569, orientation='minus', exon_count=7, OMIM=[605608], no_hdr0=''),
    23563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23563, CurrentID=0, Status='live', Symbol='CHST5', Aliases=['I-GlcNAc-6-ST', 'I-GlcNAc6ST', 'glcNAc6ST-3', 'gn6st-3', 'hIGn6ST'], description='carbohydrate sulfotransferase 5', other_designations='carbohydrate sulfotransferase 5|GST4-alpha|N-acetylglucosamine 6-O-sulfotransferase 3|carbohydrate (N-acetylglucosamine 6-O) sulfotransferase 5|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 4-alpha|intestinal GlcNAc-6-sulfotransferase', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75528530, end_position_on_the_genomic_accession=75536108, orientation='minus', exon_count=4, OMIM=[604817], no_hdr0=''),
    23564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23564, CurrentID=0, Status='live', Symbol='DDAH2', Aliases=['DDAH', 'DDAHII', 'G6a', 'HEL-S-277', 'NG30'], description='dimethylarginine dimethylaminohydrolase 2', other_designations='N(G),N(G)-dimethylarginine dimethylaminohydrolase 2|S-phase protein|dimethylargininase-2|dimethylarginine dimethylaminohydrolase II|epididymis secretory protein Li 277|testis tissue sperm-binding protein Li 54e', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31727040, end_position_on_the_genomic_accession=31730263, orientation='minus', exon_count=9, OMIM=[604744], no_hdr0=''),
    23566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23566, CurrentID=0, Status='live', Symbol='LPAR3', Aliases=['EDG7', 'Edg-7', 'GPCR', 'HOFNH30', 'LP-A3', 'LPA3', 'RP4-678I3'], description='lysophosphatidic acid receptor 3', other_designations='lysophosphatidic acid receptor 3|LPA receptor 3|LPA receptor EDG7|LPA-3|calcium-mobilizing lysophosphatidic acid receptor LP-A3|endothelial cell differentiation gene 7|endothelial differentiation, lysophosphatidic acid G-protein-coupled receptor, 7|lysophosphatidic acid receptor Edg-7', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84811601, end_position_on_the_genomic_accession=84893206, orientation='minus', exon_count=5, OMIM=[605106], no_hdr0=''),
    23567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23567, CurrentID=0, Status='live', Symbol='ZNF346', Aliases=['JAZ', 'Zfp346'], description='zinc finger protein 346', other_designations='zinc finger protein 346|double-stranded RNA-binding zinc finger protein JAZ|just another zinc finger protein', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177022687, end_position_on_the_genomic_accession=177081189, orientation='plus', exon_count=13, OMIM=[605308], no_hdr0=''),
    23568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23568, CurrentID=0, Status='live', Symbol='ARL2BP', Aliases=['BART', 'BART1', 'RP66'], description='ADP ribosylation factor like GTPase 2 binding protein', other_designations='ADP-ribosylation factor-like protein 2-binding protein|ADP-ribosylation factor like 2 binding protein|ARF-like 2-binding protein|ARL2-binding protein|Arf-like 2 binding protein BART1|binder of ARF2 protein 1|binder of Arl Two|binder of Arl2|retinitis pigmentosa 66 (autosomal recessive)', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57245259, end_position_on_the_genomic_accession=57253635, orientation='plus', exon_count=6, OMIM=[615407], no_hdr0=''),
    23569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23569, CurrentID=0, Status='live', Symbol='PADI4', Aliases=['PAD', 'PAD4', 'PADI5', 'PDI4', 'PDI5'], description='peptidyl arginine deiminase 4', other_designations='protein-arginine deiminase type-4|HL-60 PAD|PADI-H protein|peptidyl arginine deiminase, type IV|peptidyl arginine deiminase, type V|protein-arginine deiminase type IV', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17308195, end_position_on_the_genomic_accession=17364004, orientation='plus', exon_count=18, OMIM=[605347], no_hdr0=''),
    23576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23576, CurrentID=0, Status='live', Symbol='DDAH1', Aliases=['DDAH', 'DDAH-1', 'DDAHI', 'HEL-S-16'], description='dimethylarginine dimethylaminohydrolase 1', other_designations='N(G),N(G)-dimethylarginine dimethylaminohydrolase 1|NG, NG-dimethylarginine dimethylaminohydrolase|dimethylargininase-1|epididymis secretory protein Li 16', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85318485, end_position_on_the_genomic_accession=85578274, orientation='minus', exon_count=13, OMIM=[604743], no_hdr0=''),
    23580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23580, CurrentID=0, Status='live', Symbol='CDC42EP4', Aliases=['BORG4', 'CEP4', 'KAIA1777'], description='CDC42 effector protein 4', other_designations='cdc42 effector protein 4|CDC42 effector protein (Rho GTPase binding) 4|binder of Rho GTPases 4', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73283624, end_position_on_the_genomic_accession=73312001, orientation='minus', exon_count=3, OMIM=[605468], no_hdr0=''),
    23581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23581, CurrentID=0, Status='live', Symbol='CASP14', Aliases=['ARCI12'], description='caspase 14', other_designations='caspase-14|CASP-14|apoptosis-related cysteine protease|caspase 14, apoptosis-related cysteine peptidase|caspase 14, apoptosis-related cysteine protease', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15049480, end_position_on_the_genomic_accession=15058293, orientation='plus', exon_count=7, OMIM=[605848], no_hdr0=''),
    23582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23582, CurrentID=0, Status='live', Symbol='CCNDBP1', Aliases=['DIP1', 'GCIP', 'HHM'], description='cyclin D1 binding protein 1', other_designations='cyclin-D1-binding protein 1|D-type cyclin-interacting protein 1|cyclin D-type binding-protein 1|grap2 and cyclin-D-interacting protein|human homolog of Maid', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43185118, end_position_on_the_genomic_accession=43197177, orientation='plus', exon_count=12, OMIM=[607089], no_hdr0=''),
    23583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23583, CurrentID=0, Status='live', Symbol='SMUG1', Aliases=['FDG', 'HMUDG', 'UNG3'], description='single-strand-selective monofunctional uracil-DNA glycosylase 1', other_designations='single-strand selective monofunctional uracil DNA glycosylase', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54121274, end_position_on_the_genomic_accession=54188985, orientation='minus', exon_count=9, OMIM=[607753], no_hdr0=''),
    23584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23584, CurrentID=0, Status='live', Symbol='VSIG2', Aliases=['2210413P10Rik', 'CTH', 'CTXL'], description='V-set and immunoglobulin domain containing 2', other_designations='V-set and immunoglobulin domain-containing protein 2|CT-like protein|cortical thymocyte receptor (X. laevis CTX) like|cortical thymocyte-like protein', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124747474, end_position_on_the_genomic_accession=124752255, orientation='minus', exon_count=7, OMIM=[606011], no_hdr0=''),
    23585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23585, CurrentID=0, Status='live', Symbol='TMEM50A', Aliases=['IFNRC', 'SMP1'], description='transmembrane protein 50A', other_designations='transmembrane protein 50A|cervical cancer oncogene 9|small membrane protein 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25338334, end_position_on_the_genomic_accession=25362361, orientation='plus', exon_count=7, OMIM=[605348], no_hdr0=''),
    23586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23586, CurrentID=0, Status='live', Symbol='DDX58', Aliases=['RIG-I', 'RIG1', 'RIGI', 'RLR-1', 'SGMRT2'], description='DExD/H-box helicase 58', other_designations='antiviral innate immune response receptor RIG-I|DEAD (Asp-Glu-Ala-Asp) box polypeptide 58|DEAD box protein 58|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide|RNA helicase RIG-I|probable ATP-dependent RNA helicase DDX58|retinoic acid-inducible gene 1 protein|retinoic acid-inducible gene I protein', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32455302, end_position_on_the_genomic_accession=32526196, orientation='minus', exon_count=18, OMIM=[609631], no_hdr0=''),
    23587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23587, CurrentID=0, Status='live', Symbol='ELP5', Aliases=['C17orf81', 'DERP6', 'HSPC002', 'MST071', 'MSTP071'], description='elongator acetyltransferase complex subunit 5', other_designations='elongator complex protein 5|S-phase 2 protein|dermal papilla derived protein 6', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7251724, end_position_on_the_genomic_accession=7259940, orientation='plus', exon_count=10, OMIM=[615019], no_hdr0=''),
    23588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23588, CurrentID=0, Status='live', Symbol='KLHDC2', Aliases=['HCLP-1', 'HCLP1', 'LCP'], description='kelch domain containing 2', other_designations='kelch domain-containing protein 2|hepatocellular carcinoma-associated antigen 33|host cell factor homolog LCP|host cell factor-like protein 1', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49767608, end_position_on_the_genomic_accession=49786385, orientation='plus', exon_count=14, OMIM=[611280], no_hdr0=''),
    23589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23589, CurrentID=0, Status='live', Symbol='CARHSP1', Aliases=['CRHSP-24', 'CRHSP24', 'CSDC1'], description='calcium regulated heat stable protein 1', other_designations='calcium-regulated heat-stable protein 1|calcium regulated heat stable protein 1, 24kDa|calcium-regulated heat-stable protein (24kD)|calcium-regulated heat-stable protein of 24 kDa', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8852942, end_position_on_the_genomic_accession=8869006, orientation='minus', exon_count=12, OMIM=[616885], no_hdr0=''),
    23590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23590, CurrentID=0, Status='live', Symbol='PDSS1', Aliases=['COQ1', 'COQ10D2', 'COQ1A', 'DPS', 'SPS', 'TPRT', 'TPT', 'TPT 1', 'hDPS1'], description='decaprenyl diphosphate synthase subunit 1', other_designations='all trans-polyprenyl-diphosphate synthase PDSS1|all-trans-decaprenyl-diphosphate synthase subunit 1|coenzyme Q1 homolog|decaprenyl pyrophosphate synthase subunit 1|polyprenyl pyrophosphate synthetase|prenyl (decaprenyl) diphosphate synthase, subunit 1|solanesyl-diphosphate synthase subunit 1|subunit 1 of decaprenyl diphosphate synthase|trans-prenyltransferase (TPT)|trans-prenyltransferase 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=26697424, end_position_on_the_genomic_accession=26747246, orientation='plus', exon_count=14, OMIM=[607429], no_hdr0=''),
    23592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23592, CurrentID=0, Status='live', Symbol='LEMD3', Aliases=['MAN1'], description='LEM domain containing 3', other_designations='inner nuclear membrane protein Man1|LEM domain-containing protein 3|LEMD3/MKX fusion|MAN antigen 1|integral inner nuclear membrane protein', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=65169583, end_position_on_the_genomic_accession=65248355, orientation='plus', exon_count=13, OMIM=[607844], no_hdr0=''),
    23593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23593, CurrentID=0, Status='live', Symbol='HEBP2', Aliases=['C6ORF34B', 'C6orf34', 'PP23', 'SOUL'], description='heme binding protein 2', other_designations='heme-binding protein 2|placental protein 23', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138403531, end_position_on_the_genomic_accession=138422197, orientation='plus', exon_count=5, OMIM=[605825], no_hdr0=''),
    23594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23594, CurrentID=0, Status='live', Symbol='ORC6', Aliases=['ORC6L'], description='origin recognition complex subunit 6', other_designations='origin recognition complex subunit 6', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46689656, end_position_on_the_genomic_accession=46698394, orientation='plus', exon_count=8, OMIM=[607213], no_hdr0=''),
    23595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23595, CurrentID=0, Status='live', Symbol='ORC3', Aliases=['LAT', 'LATHEOL', 'ORC3'], description='origin recognition complex subunit 3', other_designations='origin recognition complex subunit 3|homolog of latheo, Drosophila|origin recognition complex subunit Latheo|origin recognition complex, subunit 3 honolog', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87590128, end_position_on_the_genomic_accession=87677824, orientation='plus', exon_count=24, OMIM=[604972], no_hdr0=''),
    23596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23596, CurrentID=0, Status='live', Symbol='OPN3', Aliases=['ECPN', 'PPP1R116'], description='opsin 3', other_designations='opsin-3|encephalopsin|opsin 3 (encephalopsin, panopsin)|protein phosphatase 1, regulatory subunit 116', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241593124, end_position_on_the_genomic_accession=241640369, orientation='minus', exon_count=5, OMIM=[606695], no_hdr0=''),
    23597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23597, CurrentID=0, Status='live', Symbol='ACOT9', Aliases=['ACATE2', 'CGI-16', 'MT-ACT48', 'MTACT48'], description='acyl-CoA thioesterase 9', other_designations='acyl-coenzyme A thioesterase 9, mitochondrial|acyl-CoA thioester hydrolase 9|acyl-Coenzyme A thioesterase 2, mitochondrial|mitochondrial Acyl-CoA Thioesterase', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23701055, end_position_on_the_genomic_accession=23743276, orientation='minus', exon_count=16, OMIM=[300862], no_hdr0=''),
    23598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23598, CurrentID=0, Status='live', Symbol='PATZ1', Aliases=['MAZR', 'PATZ', 'RIAZ', 'ZBTB19', 'ZNF278', 'ZSG', 'dJ400N23'], description='POZ/BTB and AT hook containing zinc finger 1', other_designations='POZ-, AT hook-, and zinc finger-containing protein 1|BTB-POZ domain zinc finger transcription factor|MAZ-related factor|POZ-AT hook-zinc finger protein|protein kinase A RI subunit alpha-associated protein|zinc finger and BTB domain-containing protein 19|zinc finger protein 278|zinc finger sarcoma gene protein', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31325804, end_position_on_the_genomic_accession=31346346, orientation='minus', exon_count=6, OMIM=[605165], no_hdr0=''),
    23600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23600, CurrentID=0, Status='live', Symbol='AMACR', Aliases=['AMACRD', 'CBAS4', 'P504S', 'RACE', 'RM'], description='alpha-methylacyl-CoA racemase', other_designations='alpha-methylacyl-CoA racemase|2-methylacyl-CoA racemase', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=33986165, end_position_on_the_genomic_accession=34008050, orientation='minus', exon_count=5, OMIM=[604489], no_hdr0=''),
    23601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23601, CurrentID=0, Status='live', Symbol='CLEC5A', Aliases=['CLECSF5', 'MDL-1', 'MDL1'], description='C-type lectin domain containing 5A', other_designations='C-type lectin domain family 5 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 5|C-type lectin superfamily member 5|myeloid DAP12-associating lectin-1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141927356, end_position_on_the_genomic_accession=141947009, orientation='minus', exon_count=7, OMIM=[604987], no_hdr0=''),
    23603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23603, CurrentID=0, Status='live', Symbol='CORO1C', Aliases=['HCRNN4'], description='coronin 1C', other_designations='coronin-1C|coronin, actin binding protein, 1C|coronin-3', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108645109, end_position_on_the_genomic_accession=108759955, orientation='minus', exon_count=19, OMIM=[605269], no_hdr0=''),
    23604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23604, CurrentID=0, Status='live', Symbol='DAPK2', Aliases=['DRP-1', 'DRP1'], description='death associated protein kinase 2', other_designations='death-associated protein kinase 2|DAP kinase 2', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63907036, end_position_on_the_genomic_accession=64046485, orientation='minus', exon_count=16, OMIM=[616567], no_hdr0=''),
    23607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23607, CurrentID=0, Status='live', Symbol='CD2AP', Aliases=['CMS'], description='CD2 associated protein', other_designations='CD2-associated protein|Cas ligand with multiple Src homology 3 (SH3) domains|adapter protein CMS|cas ligand with multiple SH3 domains', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47477746, end_position_on_the_genomic_accession=47627263, orientation='plus', exon_count=20, OMIM=[604241], no_hdr0=''),
    23608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23608, CurrentID=0, Status='live', Symbol='MKRN1', Aliases=['RNF61'], description='makorin ring finger protein 1', other_designations='E3 ubiquitin-protein ligase makorin-1|RING finger protein 61|RING-type E3 ubiquitin transferase makorin-1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140453033, end_position_on_the_genomic_accession=140479569, orientation='minus', exon_count=11, OMIM=[607754], no_hdr0=''),
    23609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23609, CurrentID=0, Status='live', Symbol='MKRN2', Aliases=['HSPC070', 'RNF62'], description='makorin ring finger protein 2', other_designations='probable E3 ubiquitin-protein ligase makorin-2|RING finger protein 62|RING-type E3 ubiquitin transferase makorin-2|makorin RING zinc-finger protein 2', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12557087, end_position_on_the_genomic_accession=12583713, orientation='plus', exon_count=8, OMIM=[608426], no_hdr0=''),
    23612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23612, CurrentID=0, Status='live', Symbol='PHLDA3', Aliases=['TIH1'], description='pleckstrin homology like domain family A member 3', other_designations='pleckstrin homology-like domain family A member 3|TDAG51/Ipl homolog 1|pleckstrin homology-like domain, family A, member 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201464278, end_position_on_the_genomic_accession=201469188, orientation='minus', exon_count=3, OMIM=[607054], no_hdr0=''),
    23613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23613, CurrentID=0, Status='live', Symbol='ZMYND8', Aliases=['PRKCBP1', 'PRO2893', 'RACK7'], description='zinc finger MYND-type containing 8', other_designations='protein kinase C-binding protein 1|CTCL tumor antigen se14-3|cutaneous T-cell lymphoma-associated antigen se14-3|predicted protein of HQ2893|zinc finger MYND domain-containing protein 8', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=47209214, end_position_on_the_genomic_accession=47356699, orientation='minus', exon_count=29, OMIM=[615713], no_hdr0=''),
    23616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23616, CurrentID=0, Status='live', Symbol='SH3BP1', Aliases=['ARHGAP43'], description='SH3 domain binding protein 1', other_designations='SH3 domain-binding protein 1|3BP-1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37639669, end_position_on_the_genomic_accession=37656117, orientation='plus', exon_count=18, OMIM=[617368], no_hdr0=''),
    23617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23617, CurrentID=0, Status='live', Symbol='TSSK2', Aliases=['DGS-G', 'SPOGA2', 'STK22B', 'TSK2'], description='testis specific serine kinase 2', other_designations='testis-specific serine/threonine-protein kinase 2|TSK-2|TSSK-2|diGeorge syndrome protein G|serine/threonine kinase 22B (spermiogenesis associated)|serine/threonine-protein kinase 22B|spermiogenesis associated 2|testicular secretory protein Li 61|testis specific serine threonine kinase 2|testis-specific kinase 2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19131308, end_position_on_the_genomic_accession=19132622, orientation='plus', exon_count=1, OMIM=[610710], no_hdr0=''),
    23619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23619, CurrentID=0, Status='live', Symbol='ZIM2', Aliases=['ZNF656'], description='zinc finger imprinted 2', other_designations='zinc finger imprinted 2|zinc finger protein 656', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56774547, end_position_on_the_genomic_accession=56840726, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    23620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23620, CurrentID=0, Status='live', Symbol='NTSR2', Aliases=['NTR2'], description='neurotensin receptor 2', other_designations='neurotensin receptor type 2|NT-R-2|levocabastine-sensitive neurotensin receptor|neurotensin receptor, type 2', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11658119, end_position_on_the_genomic_accession=11670206, orientation='minus', exon_count=4, OMIM=[605538], no_hdr0=''),
    23621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23621, CurrentID=0, Status='live', Symbol='BACE1', Aliases=['ASP2', 'BACE', 'HSPC104'], description='beta-secretase 1', other_designations='beta-secretase 1|APP beta-secretase|asp 2|aspartyl protease 2|beta-secretase 1 precursor variant 1|beta-site APP cleaving enzyme 1|beta-site APP-cleaving enzyme|beta-site amyloid beta A4 precursor protein-cleaving enzyme|memapsin-2|membrane-associated aspartic protease 2|transmembrane aspartic proteinase Asp2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117285698, end_position_on_the_genomic_accession=117316256, orientation='minus', exon_count=10, OMIM=[604252], no_hdr0=''),
    23623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23623, CurrentID=0, Status='live', Symbol='RUSC1', Aliases=['NESCA'], description='RUN and SH3 domain containing 1', other_designations='RUN and SH3 domain-containing protein 1|new molecule containing SH3 at the carboxy-terminus', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155320894, end_position_on_the_genomic_accession=155331118, orientation='plus', exon_count=12, OMIM=[617318], no_hdr0=''),
    23624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23624, CurrentID=0, Status='live', Symbol='CBLC', Aliases=['CBL-3', 'CBL-SL', 'RNF57'], description='Cbl proto-oncogene C', other_designations='E3 ubiquitin-protein ligase CBL-C|Cas-Br-M (murine) ecotropic retroviral transforming sequence c|Cas-Br-M (murine) ectropic retroviral transforming sequence c|Cbl proto-oncogene C, E3 ubiquitin protein ligase|Cbl proto-oncogene, E3 ubiquitin protein ligase C|RING finger protein 57|RING-type E3 ubiquitin transferase CBL-C|SH3-binding protein CBL-3|SH3-binding protein CBL-C|signal transduction protein CBL-C', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44777855, end_position_on_the_genomic_accession=44800652, orientation='plus', exon_count=13, OMIM=[608453], no_hdr0=''),
    23625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23625, CurrentID=0, Status='live', Symbol='FAM89B', Aliases=['LRAP25', 'MTVR', 'MTVR1'], description='family with sequence similarity 89 member B', other_designations='leucine repeat adapter protein 25|leucine repeat adaptor protein 25|mammary tumor virus receptor homolog 1|protein FAM89B', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65572538, end_position_on_the_genomic_accession=65574190, orientation='plus', exon_count=2, OMIM=[616128], no_hdr0=''),
    23626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23626, CurrentID=0, Status='live', Symbol='SPO11', Aliases=['CT35', 'SPATA43', 'TOPOVIA', 'TOPVIA'], description='SPO11 initiator of meiotic double stranded breaks', other_designations='meiotic recombination protein SPO11|SPO11 meiotic protein covalently bound to DSB homolog|cancer/testis antigen 35|spermatogenesis associated 43', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57329757, end_position_on_the_genomic_accession=57343993, orientation='plus', exon_count=15, OMIM=[605114], no_hdr0=''),
    23627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23627, CurrentID=0, Status='live', Symbol='PRND', Aliases=['DOPPEL', 'DPL', 'PrPLP', 'dJ1068H6.4'], description='prion like protein doppel', other_designations='prion-like protein doppel|downstream prion protein-like|prion gene complex, downstream|prion protein 2 (dublet)', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4721909, end_position_on_the_genomic_accession=4728460, orientation='plus', exon_count=2, OMIM=[604263], no_hdr0=''),
    23630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23630, CurrentID=0, Status='live', Symbol='KCNE5', Aliases=['KCNE1L'], description='potassium voltage-gated channel subfamily E regulatory subunit 5', other_designations='potassium voltage-gated channel subfamily E regulatory beta subunit 5|AMME syndrome candidate gene 2 protein|AMMECR2 protein|KCNE1-like|cardiac voltage-gated potassium channel accessory subunit 5|potassium channel subunit beta MiRP4|potassium voltage-gated channel subfamily E member 1-like protein|potassium voltage-gated channel, Isk-related family, member 1-like', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=109623700, end_position_on_the_genomic_accession=109625172, orientation='minus', exon_count=1, OMIM=[300328], no_hdr0=''),
    23632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23632, CurrentID=0, Status='live', Symbol='CA14', Aliases=['CAXiV'], description='carbonic anhydrase 14', other_designations='carbonic anhydrase 14|CA-XIV|carbonate dehydratase XIV|carbonic anhydrase XIV|carbonic dehydratase', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150257258, end_position_on_the_genomic_accession=150265862, orientation='plus', exon_count=11, OMIM=[604832], no_hdr0=''),
    23633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23633, CurrentID=0, Status='live', Symbol='KPNA6', Aliases=['IPOA7'], description='karyopherin subunit alpha 6', other_designations='importin subunit alpha-7|importin alpha 7 subunit|importin-alpha-S2|karyopherin alpha 6 (importin alpha 7)', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32108043, end_position_on_the_genomic_accession=32176563, orientation='plus', exon_count=18, OMIM=[610563], no_hdr0=''),
    23635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23635, CurrentID=0, Status='live', Symbol='SSBP2', Aliases=['HSPC116', 'SOSS-B2'], description='single stranded DNA binding protein 2', other_designations='single-stranded DNA-binding protein 2|sequence-specific single-stranded-DNA-binding protein 2', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=81412804, end_position_on_the_genomic_accession=81751097, orientation='minus', exon_count=22, OMIM=[607389], no_hdr0=''),
    23636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23636, CurrentID=0, Status='live', Symbol='NUP62', Aliases=['IBSN', 'SNDI', 'p62'], description='nucleoporin 62', other_designations='nuclear pore glycoprotein p62|62 kDa nucleoporin|nucleoporin 62kD|nucleoporin 62kDa|nucleoporin Nup62', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49906825, end_position_on_the_genomic_accession=49929504, orientation='minus', exon_count=3, OMIM=[605815], no_hdr0=''),
    23637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23637, CurrentID=0, Status='live', Symbol='RABGAP1', Aliases=['GAPCENA', 'TBC1D11'], description='RAB GTPase activating protein 1', other_designations='rab GTPase-activating protein 1|GAP and centrosome-associated protein|Rab6 GTPase activating protein, GAPCenA|TBC1 domain family, member 11|rab6 GTPase activating protein (GAP and centrosome-associated)|rab6 GTPase-activating protein GAPCenA', map_location='9q33.2-q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122931640, end_position_on_the_genomic_accession=123104869, orientation='plus', exon_count=32, OMIM=[615882], no_hdr0=''),
    23639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23639, CurrentID=0, Status='live', Symbol='DNAAF11', Aliases=['CILD19', 'LRRC6', 'LRTP', 'TSLRP', 'tilB'], description='dynein axonemal assembly factor 11', other_designations='dynein axonemal assembly factor 11|protein tilB homolog|leucine rich repeat containing 6|protein TILB homolog|seahorse|testis-specific leucine-rich repeat protein', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132570416, end_position_on_the_genomic_accession=132685039, orientation='minus', exon_count=17, OMIM=[614930], no_hdr0=''),
    23640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23640, CurrentID=0, Status='live', Symbol='HSPBP1', Aliases=['FES1'], description='HSPA (Hsp70) binding protein 1', other_designations='hsp70-binding protein 1|HSPA (heat shock 70kDa) binding protein, cytoplasmic cochaperone 1|heat shock protein-binding protein 1|hsp70 interacting protein', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55262223, end_position_on_the_genomic_accession=55280423, orientation='minus', exon_count=9, OMIM=[612939], no_hdr0=''),
    23641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23641, CurrentID=0, Status='live', Symbol='LDOC1', Aliases=['BCUR1', 'Mar7', 'Mart7', 'RTL7', 'SIRH7'], description='LDOC1 regulator of NFKB signaling', other_designations='protein LDOC1|Sushi-Ichi retrotransposon homolog 7|breast cancer, up-regulated 1|leucine zipper down-regulated in cancer 1|leucine zipper downregulated in cancer|leucine zipper protein down-regulated in cancer cells|mammalian retrotransposon-derived 7|retrotransposon Gag like 7', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141173235, end_position_on_the_genomic_accession=141177129, orientation='minus', exon_count=1, OMIM=[300402], no_hdr0=''),
    23643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23643, CurrentID=0, Status='live', Symbol='LY96', Aliases=['ESOP-1', 'MD-2', 'MD2', 'ly-96'], description='lymphocyte antigen 96', other_designations='lymphocyte antigen 96|myeloid differentiation protein-2|protein MD-2', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73991275, end_position_on_the_genomic_accession=74099807, orientation='plus', exon_count=7, OMIM=[605243], no_hdr0=''),
    23644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23644, CurrentID=0, Status='live', Symbol='EDC4', Aliases=['GE1', 'Ge-1', 'HEDL5', 'HEDLS', 'RCD-8', 'RCD8'], description='enhancer of mRNA decapping 4', other_designations='enhancer of mRNA-decapping protein 4|autoantigen Ge-1|autoantigen RCD-8|human enhancer of decapping large subunit', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67873052, end_position_on_the_genomic_accession=67884499, orientation='plus', exon_count=29, OMIM=[606030], no_hdr0=''),
    23645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23645, CurrentID=0, Status='live', Symbol='PPP1R15A', Aliases=['GADD34'], description='protein phosphatase 1 regulatory subunit 15A', other_designations='protein phosphatase 1 regulatory subunit 15A|growth arrest and DNA damage-inducible protein GADD34|growth arrest and DNA-damage-inducible 34|myeloid differentiation primary response protein MyD116 homolog|protein phosphatase 1, regulatory (inhibitor) subunit 15A', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48872421, end_position_on_the_genomic_accession=48876058, orientation='plus', exon_count=3, OMIM=[611048], no_hdr0=''),
    23646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23646, CurrentID=0, Status='live', Symbol='PLD3', Aliases=['AD19', 'HU-K4', 'HUK4', 'SCA46'], description='phospholipase D family member 3', other_designations="5'-3' exonuclease PLD3|choline phosphatase 3|hindIII K4L homolog|phosphatidylcholine-hydrolyzing phospholipase D3", map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40348395, end_position_on_the_genomic_accession=40378485, orientation='plus', exon_count=15, OMIM=[615698], no_hdr0=''),
    23647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23647, CurrentID=0, Status='live', Symbol='ARFIP2', Aliases=['POR1'], description='ADP ribosylation factor interacting protein 2', other_designations='arfaptin-2|partner of RAC1 (arfaptin 2)', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6476519, end_position_on_the_genomic_accession=6481331, orientation='minus', exon_count=9, OMIM=[601638], no_hdr0=''),
    23648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23648, CurrentID=0, Status='live', Symbol='SSBP3', Aliases=['CSDP', 'SSDP', 'SSDP1'], description='single stranded DNA binding protein 3', other_designations='single-stranded DNA-binding protein 3|sequence-specific single-stranded-DNA-binding protein', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54225432, end_position_on_the_genomic_accession=54413490, orientation='minus', exon_count=22, OMIM=[607390], no_hdr0=''),
    23649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23649, CurrentID=0, Status='live', Symbol='POLA2', Aliases=[], description='DNA polymerase alpha 2, accessory subunit', other_designations='DNA polymerase alpha subunit B|DNA polymerase alpha 70 kDa subunit|polymerase (DNA directed), alpha 2 (70kD subunit)|polymerase (DNA directed), alpha 2, accessory subunit|polymerase (DNA) alpha 2, accessory subunit|polymerase (DNA-directed), alpha (70kD)', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65261917, end_position_on_the_genomic_accession=65306269, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    23650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23650, CurrentID=0, Status='live', Symbol='TRIM29', Aliases=['ATDC'], description='tripartite motif containing 29', other_designations='tripartite motif-containing protein 29|ataxia-telangiectasia group D-associated protein|tripartite motif protein TRIM29', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120111286, end_position_on_the_genomic_accession=120138113, orientation='minus', exon_count=11, OMIM=[610658], no_hdr0=''),
    23654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23654, CurrentID=0, Status='live', Symbol='PLXNB2', Aliases=['MM1', 'Nbla00445', 'PLEXB2', 'dJ402G11.3'], description='plexin B2', other_designations='plexin-B2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50274979, end_position_on_the_genomic_accession=50307646, orientation='minus', exon_count=44, OMIM=[604293], no_hdr0=''),
    23657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23657, CurrentID=0, Status='live', Symbol='SLC7A11', Aliases=['CCBR1', 'xCT'], description='solute carrier family 7 member 11', other_designations='cystine/glutamate transporter|amino acid transport system xc-|calcium channel blocker resistance protein CCBR1|solute carrier family 7 (anionic amino acid transporter light chain, xc- system), member 11|solute carrier family 7, (cationic amino acid transporter, y+ system) member 11', map_location='4q28.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=138164097, end_position_on_the_genomic_accession=138242349, orientation='minus', exon_count=14, OMIM=[607933], no_hdr0=''),
    23658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23658, CurrentID=0, Status='live', Symbol='LSM5', Aliases=['YER146W'], description='LSM5 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm5|LSM5 U6 small nuclear RNA and mRNA degradation associated|LSM5 homolog, U6 small nuclear RNA associated', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=32485338, end_position_on_the_genomic_accession=32495283, orientation='minus', exon_count=6, OMIM=[607285], no_hdr0=''),
    23659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23659, CurrentID=0, Status='live', Symbol='PLA2G15', Aliases=['ACS', 'GXVPLA2', 'LLPL', 'LPLA2', 'LYPLA3'], description='phospholipase A2 group XV', other_designations='phospholipase A2 group XV|1-O-acylceramide synthase|LCAT-like lysophospholipase|group XV phospholipase A2|lysophospholipase 3 (lysosomal phospholipase A2)|lysosomal phospholipase A and acyltransferase|lysosomal phospholipase A2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68245371, end_position_on_the_genomic_accession=68261062, orientation='plus', exon_count=7, OMIM=[609362], no_hdr0=''),
    23660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23660, CurrentID=0, Status='live', Symbol='ZKSCAN5', Aliases=['ZFP-95', 'ZFP95', 'ZNF914', 'ZSCAN37'], description='zinc finger with KRAB and SCAN domains 5', other_designations='zinc finger protein with KRAB and SCAN domains 5|zinc finger protein 95 homolog|zinc finger protein homologous to Zfp95 in mouse', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99504650, end_position_on_the_genomic_accession=99534700, orientation='plus', exon_count=9, OMIM=[611272], no_hdr0=''),
    23670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23670, CurrentID=0, Status='live', Symbol='CEMIP2', Aliases=['TMEM2'], description='cell migration inducing hyaluronidase 2', other_designations='cell surface hyaluronidase|transmembrane protein 2', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=71683366, end_position_on_the_genomic_accession=71769532, orientation='minus', exon_count=25, OMIM=[605835], no_hdr0=''),
    23671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23671, CurrentID=0, Status='live', Symbol='TMEFF2', Aliases=['CT120.2', 'HPP1', 'TENB2', 'TPEF', 'TR', 'TR-2'], description='transmembrane protein with EGF like and two follistatin like domains 2', other_designations='tomoregulin-2|cancer/testis antigen family 120, member 2|hyperplastic polyposis protein 1|transmembrane protein TENB2|transmembrane protein with EGF-like and two follistatin-like domains', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=191948300, end_position_on_the_genomic_accession=192194933, orientation='minus', exon_count=11, OMIM=[605734], no_hdr0=''),
    23673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23673, CurrentID=0, Status='live', Symbol='STX12', Aliases=['STX13', 'STX14'], description='syntaxin 12', other_designations='syntaxin-12', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27773219, end_position_on_the_genomic_accession=27824443, orientation='plus', exon_count=9, OMIM=[606892], no_hdr0=''),
    23676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23676, CurrentID=0, Status='live', Symbol='SMPX', Aliases=['Chisel', 'Csl', 'DFN6', 'DFNX4'], description='small muscle protein X-linked', other_designations='small muscular protein|deafness, X-linked 6, sensorineural|stretch-responsive skeletal muscle protein', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21705978, end_position_on_the_genomic_accession=21758116, orientation='minus', exon_count=6, OMIM=[300066, 300226], no_hdr0=''),
    23677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23677, CurrentID=0, Status='live', Symbol='SH3BP4', Aliases=['BOG25', 'TTP'], description='SH3 domain binding protein 4', other_designations='SH3 domain-binding protein 4|EH-binding protein 10|transferrin receptor-trafficking protein', map_location='2q37.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=234952017, end_position_on_the_genomic_accession=235055714, orientation='plus', exon_count=11, OMIM=[605611], no_hdr0=''),
    23678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23678, CurrentID=0, Status='live', Symbol='SGK3', Aliases=['CISK', 'SGK2', 'SGKL'], description='serum/glucocorticoid regulated kinase family member 3', other_designations='serine/threonine-protein kinase Sgk3|cytokine-independent survival kinase', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66712781, end_position_on_the_genomic_accession=66862022, orientation='plus', exon_count=18, OMIM=[607591], no_hdr0=''),
    23682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23682, CurrentID=0, Status='live', Symbol='RAB38', Aliases=['NY-MEL-1', 'rrGTPbp'], description='RAB38, member RAS oncogene family', other_designations='ras-related protein Rab-38|Rab-related GTP-binding protein|melanoma antigen NY-MEL-1', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=87809490, end_position_on_the_genomic_accession=88175504, orientation='minus', exon_count=6, OMIM=[606281], no_hdr0=''),
    23683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23683, CurrentID=0, Status='live', Symbol='PRKD3', Aliases=['EPK2', 'PKC-NU', 'PKD3', 'PRKCN', 'nPKC-NU'], description='protein kinase D3', other_designations='serine/threonine-protein kinase D3|protein kinase C nu type|protein kinase EPK2', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37250502, end_position_on_the_genomic_accession=37324833, orientation='minus', exon_count=21, OMIM=[607077], no_hdr0=''),
    23704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23704, CurrentID=0, Status='live', Symbol='KCNE4', Aliases=['MIRP3'], description='potassium voltage-gated channel subfamily E regulatory subunit 4', other_designations='potassium voltage-gated channel subfamily E member 4|MINK-related peptide 3|cardiac voltage-gated potassium channel accessory subunit 4|minimum potassium ion channel-related peptide 3|potassium channel subunit beta MiRP3|potassium channel, voltage gated subfamily E regulatory beta subunit 4|potassium voltage-gated channel, Isk-related family, member 4', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223052190, end_position_on_the_genomic_accession=223055637, orientation='plus', exon_count=2, OMIM=[607775], no_hdr0=''),
    23705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23705, CurrentID=0, Status='live', Symbol='CADM1', Aliases=['BL2', 'IGSF4', 'IGSF4A', 'NECL2', 'Necl-2', 'RA175', 'ST17', 'SYNCAM', 'TSLC1', 'sTSLC-1', 'sgIGSF', 'synCAM1'], description='cell adhesion molecule 1', other_designations='cell adhesion molecule 1|TSLC-1|TSLC1/Nectin-like 2/IGSF4|immunoglobulin superfamily member 4|immunoglobulin superfamily, member 4D variant 1|immunoglobulin superfamily, member 4D variant 2|nectin-like 2|nectin-like protein 2|spermatogenic immunoglobulin superfamily|synaptic cell adhesion molecule|truncated CADM1 protein|tumor suppressor in lung cancer 1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=115169236, end_position_on_the_genomic_accession=115504428, orientation='minus', exon_count=13, OMIM=[605686], no_hdr0=''),
    23708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23708, CurrentID=0, Status='live', Symbol='GSPT2', Aliases=['ERF3B', 'GST2'], description='G1 to S phase transition 2', other_designations='eukaryotic peptide chain release factor GTP-binding subunit ERF3B|eukaryotic peptide chain release factor subunit 3b', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51743442, end_position_on_the_genomic_accession=51746232, orientation='plus', exon_count=1, OMIM=[300418], no_hdr0=''),
    23710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23710, CurrentID=0, Status='live', Symbol='GABARAPL1', Aliases=['APG8-LIKE', 'APG8L', 'ATG8', 'ATG8B', 'ATG8L', 'GEC1'], description='GABA type A receptor associated protein like 1', other_designations='gamma-aminobutyric acid receptor-associated protein-like 1|GABA(A) receptor-associated protein-like 1|early estrogen-regulated protein|glandular epithelial cell protein 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10212877, end_position_on_the_genomic_accession=10223128, orientation='plus', exon_count=4, OMIM=[607420], no_hdr0=''),
    23729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23729, CurrentID=0, Status='live', Symbol='SHPK', Aliases=['CARKL', 'SHK'], description='sedoheptulokinase', other_designations='sedoheptulokinase|carbohydrate kinase-like protein', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3608240, end_position_on_the_genomic_accession=3636250, orientation='minus', exon_count=7, OMIM=[605060], no_hdr0=''),
    23731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23731, CurrentID=0, Status='live', Symbol='TMEM245', Aliases=['C9orf5', 'CG-2', 'CG2'], description='transmembrane protein 245', other_designations='transmembrane protein 245|protein CG-2|transmembrane protein C9orf5', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=109015135, end_position_on_the_genomic_accession=109119963, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    23732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23732, CurrentID=0, Status='live', Symbol='FRRS1L', Aliases=['C9orf4', 'CG-6', 'CG6', 'DEE37', 'EIEE37'], description='ferric chelate reductase 1 like', other_designations='DOMON domain-containing protein FRRS1L|brain protein CG-6', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=109130293, end_position_on_the_genomic_accession=109167249, orientation='minus', exon_count=7, OMIM=[604574], no_hdr0=''),
    23741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23741, CurrentID=0, Status='live', Symbol='EID1', Aliases=['C15orf3', 'CRI1', 'EID-1', 'IRO45620', 'PNAS-22', 'PTD014', 'RBP21'], description='EP300 interacting inhibitor of differentiation 1', other_designations='EP300-interacting inhibitor of differentiation 1|21 kDa pRb-associated protein|CREBBP/EP300 inhibitor 1|CREBBP/EP300 inhibitory protein 1|E1A-like inhibitor of differentiation 1|NB4 apoptosis related protein|Rb- and p300-binding protein EID-1|retinoblastoma protein-associated protein', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48878134, end_position_on_the_genomic_accession=48880173, orientation='plus', exon_count=1, OMIM=[605894], no_hdr0=''),
    23742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23742, CurrentID=0, Status='live', Symbol='NPAP1', Aliases=['C15orf2'], description='nuclear pore associated protein 1', other_designations='nuclear pore-associated protein 1|protein C15orf2', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=24675775, end_position_on_the_genomic_accession=24683393, orientation='plus', exon_count=1, OMIM=[610922], no_hdr0=''),
    23743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23743, CurrentID=0, Status='live', Symbol='BHMT2', Aliases=[], description='betaine--homocysteine S-methyltransferase 2', other_designations='S-methylmethionine--homocysteine S-methyltransferase BHMT2|SMM-hcy methyltransferase|betaine-homocysteine methyltransferase 2', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79069767, end_position_on_the_genomic_accession=79090069, orientation='plus', exon_count=8, OMIM=[605932], no_hdr0=''),
    23746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23746, CurrentID=0, Status='live', Symbol='AIPL1', Aliases=['AIPL2', 'LCA4'], description='aryl hydrocarbon receptor interacting protein like 1', other_designations='aryl-hydrocarbon-interacting protein-like 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6423738, end_position_on_the_genomic_accession=6435121, orientation='minus', exon_count=6, OMIM=[604392], no_hdr0=''),
    23753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23753, CurrentID=0, Status='live', Symbol='SDF2L1', Aliases=[], description='stromal cell derived factor 2 like 1', other_designations='stromal cell-derived factor 2-like protein 1|PWP1-interacting protein 8|SDF2-like 1|SDF2-like protein 1|dihydropyrimidinase-like 2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21642302, end_position_on_the_genomic_accession=21644299, orientation='plus', exon_count=3, OMIM=[607551], no_hdr0=''),
    23759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23759, CurrentID=0, Status='live', Symbol='PPIL2', Aliases=['CYC4', 'CYP60', 'Cyp-60', 'UBOX7', 'hCyP-60'], description='peptidylprolyl isomerase like 2', other_designations='RING-type E3 ubiquitin-protein ligase PPIL2|PPIase|RING-type E3 ubiquitin transferase isomerase-like 2|U-box domain containing 7|cyclophilin, 60kDa|cyclophilin-60|cyclophilin-like protein CyP-60|peptidyl-prolyl cis-trans isomerase-like 2|peptidylprolyl cis-trans isomerase|peptidylprolyl isomerase (cyclophilin)-like 2|probable inactive peptidyl-prolyl cis-trans isomerase-like 2|rotamase PPIL2', map_location='22q11.21-q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21666010, end_position_on_the_genomic_accession=21700015, orientation='plus', exon_count=24, OMIM=[607588], no_hdr0=''),
    23760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23760, CurrentID=0, Status='live', Symbol='PITPNB', Aliases=['PI-TP-beta', 'PtdInsTP', 'VIB1B'], description='phosphatidylinositol transfer protein beta', other_designations='phosphatidylinositol transfer protein beta isoform|PtdIns transfer protein beta|phosphotidylinositol transfer protein, beta', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=27851669, end_position_on_the_genomic_accession=27919263, orientation='minus', exon_count=13, OMIM=[606876], no_hdr0=''),
    23761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23761, CurrentID=0, Status='live', Symbol='PISD', Aliases=['DJ858B16', 'LIBF', 'PSD', 'PSDC', 'PSSC', 'dJ858B16.2'], description='phosphatidylserine decarboxylase', other_designations='phosphatidylserine decarboxylase proenzyme, mitochondrial', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31618491, end_position_on_the_genomic_accession=31662564, orientation='minus', exon_count=14, OMIM=[612770], no_hdr0=''),
    23762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23762, CurrentID=0, Status='live', Symbol='OSBP2', Aliases=['HLM', 'ORP-4', 'ORP4', 'OSBPL1', 'OSBPL4'], description='oxysterol binding protein 2', other_designations='oxysterol-binding protein 2|OSBP-related protein 4|oxysterol binding protein-like 1|oxysterol-binding protein-related protein 4', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30693782, end_position_on_the_genomic_accession=30907813, orientation='plus', exon_count=19, OMIM=[606729], no_hdr0=''),
    23764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23764, CurrentID=0, Status='live', Symbol='MAFF', Aliases=['U-MAF', 'hMafF'], description='MAF bZIP transcription factor F', other_designations='transcription factor MafF|v-maf avian musculoaponeurotic fibrosarcoma oncogene family protein F|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog F', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38201994, end_position_on_the_genomic_accession=38216511, orientation='plus', exon_count=4, OMIM=[604877], no_hdr0=''),
    23765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23765, CurrentID=0, Status='live', Symbol='IL17RA', Aliases=['CANDF5', 'CD217', 'CDw217', 'IL-17RA', 'IL17R', 'IMD51', 'hIL-17R'], description='interleukin 17 receptor A', other_designations='interleukin-17 receptor A|IL-17 receptor A', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17085000, end_position_on_the_genomic_accession=17115693, orientation='plus', exon_count=13, OMIM=[605461], no_hdr0=''),
    23767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23767, CurrentID=0, Status='live', Symbol='FLRT3', Aliases=['HH21'], description='fibronectin leucine rich transmembrane protein 3', other_designations='leucine-rich repeat transmembrane protein FLRT3|fibronectin-like domain-containing leucine-rich transmembrane protein 3', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=14322985, end_position_on_the_genomic_accession=14337847, orientation='minus', exon_count=4, OMIM=[604808], no_hdr0=''),
    23768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23768, CurrentID=0, Status='live', Symbol='FLRT2', Aliases=[], description='fibronectin leucine rich transmembrane protein 2', other_designations='leucine-rich repeat transmembrane protein FLRT2|fibronectin-like domain-containing leucine-rich transmembrane protein 2', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=85527372, end_position_on_the_genomic_accession=85654428, orientation='plus', exon_count=12, OMIM=[604807], no_hdr0=''),
    23769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23769, CurrentID=0, Status='live', Symbol='FLRT1', Aliases=['SPG68'], description='fibronectin leucine rich transmembrane protein 1', other_designations='leucine-rich repeat transmembrane protein FLRT1|fibronectin-like domain-containing leucine-rich transmembrane protein 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64035931, end_position_on_the_genomic_accession=64127289, orientation='plus', exon_count=5, OMIM=[604806], no_hdr0=''),
    23770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23770, CurrentID=0, Status='live', Symbol='FKBP8', Aliases=['FKBP38', 'FKBPr38'], description='FKBP prolyl isomerase 8', other_designations='peptidyl-prolyl cis-trans isomerase FKBP8|38 kDa FK506-binding protein|38 kDa FKBP|FK506 binding protein 8, 38kDa|FK506-binding protein 8|FKBP-38|FKBP-8|PPIase FKBP8|hFKBP38|rotamase', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18531763, end_position_on_the_genomic_accession=18543573, orientation='minus', exon_count=9, OMIM=[604840], no_hdr0=''),
    23774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23774, CurrentID=0, Status='live', Symbol='BRD1', Aliases=['BRL', 'BRPF1', 'BRPF2'], description='bromodomain containing 1', other_designations='bromodomain-containing protein 1|BR140-like protein|bromodomain and PHD finger-containing protein 2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49773278, end_position_on_the_genomic_accession=49827873, orientation='minus', exon_count=19, OMIM=[604589], no_hdr0=''),
    23779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23779, CurrentID=0, Status='live', Symbol='ARHGAP8', Aliases=['BPGAP1', 'PP610'], description='Rho GTPase activating protein 8', other_designations='rho GTPase-activating protein 8|BCH domain-containing Cdc42GAP-like protein|BNIP-2 and Cdc42GAP homology domain-containing, proline-rich and Cdc42GAP-like protein subtype-1|rho-type GTPase-activating protein 8', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44752575, end_position_on_the_genomic_accession=44862784, orientation='plus', exon_count=13, OMIM=[609405], no_hdr0=''),
    23780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23780, CurrentID=0, Status='live', Symbol='APOL2', Aliases=['APOL-II', 'APOL3'], description='apolipoprotein L2', other_designations='apolipoprotein L2|apolipoprotein L, 2|apolipoprotein L-II', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36226209, end_position_on_the_genomic_accession=36239954, orientation='minus', exon_count=10, OMIM=[607252], no_hdr0=''),
    23784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23784, CurrentID=0, Status='live', Symbol='POTEH', Aliases=['A26C3', 'ACTBL1', 'CT104.7', 'POTE22'], description='POTE ankyrin domain family member H', other_designations='POTE ankyrin domain family member H|ANKRD26-like family C member 3|actin, beta-like 1|cancer/testis antigen family 104, member 7|prostate, ovary, testis-expressed protein on chromosome 22|protein expressed in prostate, ovary, testis, and placenta 22|protein expressed in prostate, ovary, testis, and placenta POTE14 like', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=15690026, end_position_on_the_genomic_accession=15721631, orientation='plus', exon_count=11, OMIM=[608913], no_hdr0=''),
    23786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23786, CurrentID=0, Status='live', Symbol='BCL2L13', Aliases=['BCL-RAMBO', 'Bcl2-L-13', 'MIL1'], description='BCL2 like 13', other_designations='bcl-2-like protein 13|BCL2-like 13 (apoptosis facilitator)', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17628855, end_position_on_the_genomic_accession=17730855, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    23787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23787, CurrentID=0, Status='live', Symbol='MTCH1', Aliases=['CGI-64', 'PIG60', 'PSAP', 'SLC25A49'], description='mitochondrial carrier 1', other_designations='mitochondrial carrier homolog 1|cell proliferation-inducing protein 60|presenilin-associated protein|solute carrier family 25, member 49', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36968135, end_position_on_the_genomic_accession=36987171, orientation='minus', exon_count=12, OMIM=[610449], no_hdr0=''),
    23788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=23788, CurrentID=0, Status='live', Symbol='MTCH2', Aliases=['HSPC032', 'MIMP', 'SLC25A50'], description='mitochondrial carrier 2', other_designations='mitochondrial carrier homolog 2|2310034D24Rik|met-induced mitochondrial protein|solute carrier family 25, member 50', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47604309, end_position_on_the_genomic_accession=47642597, orientation='minus', exon_count=14, OMIM=[613221], no_hdr0=''),
    24137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24137, CurrentID=0, Status='live', Symbol='KIF4A', Aliases=['KIF4', 'KIF4G1', 'MRX100'], description='kinesin family member 4A', other_designations='chromosome-associated kinesin KIF4A|chromokinesin-A', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70290104, end_position_on_the_genomic_accession=70420886, orientation='plus', exon_count=31, OMIM=[300521], no_hdr0=''),
    24138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24138, CurrentID=0, Status='live', Symbol='IFIT5', Aliases=['ISG58', 'P58', 'RI58'], description='interferon induced protein with tetratricopeptide repeats 5', other_designations='interferon-induced protein with tetratricopeptide repeats 5|IFIT-5|interferon-induced 58 kDa protein|retinoic acid- and interferon-inducible 58 kDa protein|retinoic acid- and interferon-inducible protein (58kD)', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89414568, end_position_on_the_genomic_accession=89420997, orientation='plus', exon_count=2, OMIM=[616135], no_hdr0=''),
    24139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24139, CurrentID=0, Status='live', Symbol='EML2', Aliases=['ELP70', 'EMAP-2', 'EMAP2'], description='EMAP like 2', other_designations='echinoderm microtubule-associated protein-like 2|echinoderm MT-associated protein (EMAP)-like protein 70|echinoderm microtubule associated protein like 2|microtubule-associated protein like echinoderm EMAP', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45609396, end_position_on_the_genomic_accession=45645629, orientation='minus', exon_count=27, OMIM=[617494], no_hdr0=''),
    24140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24140, CurrentID=0, Status='live', Symbol='FTSJ1', Aliases=['CDLIV', 'JM23', 'MRX44', 'MRX9', 'SPB1', 'TRMT7'], description="FtsJ RNA 2'-O-methyltransferase 1", other_designations="putative tRNA (cytidine(32)/guanosine(34)-2'-O)-methyltransferase|2'-O-ribose RNA methyltransferase TRM7 homolog|FtsJ RNA methyltransferase homolog 1|FtsJ-like protein 1|cell division protein|putative ribosomal RNA methyltransferase 1|rRNA (uridine-2'-O-)-methyltransferase|tRNA methyltransferase 7 homolog", map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48476021, end_position_on_the_genomic_accession=48486364, orientation='plus', exon_count=15, OMIM=[300499], no_hdr0=''),
    24141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24141, CurrentID=0, Status='live', Symbol='LAMP5', Aliases=['BAD-LAMP', 'BADLAMP', 'C20orf103', 'LAMP-5', 'UNC-46'], description='lysosomal associated membrane protein family member 5', other_designations='lysosome-associated membrane glycoprotein 5|LAMP family protein C20orf103|brain and dendritic cell-associated LAMP|brain-associated LAMP-like protein|lysosome-associated membrane protein 5', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=9514590, end_position_on_the_genomic_accession=9530524, orientation='plus', exon_count=6, OMIM=[614641], no_hdr0=''),
    24142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24142, CurrentID=0, Status='live', Symbol='NAA80', Aliases=['FUS-2', 'FUS2', 'HsNAAA80', 'NAT6'], description='N-alpha-acetyltransferase 80, NatH catalytic subunit', other_designations='N-alpha-acetyltransferase 80|N-acetyltransferase 6 (GCN5-related)|protein fusion-2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50296402, end_position_on_the_genomic_accession=50299405, orientation='minus', exon_count=3, OMIM=[607073], no_hdr0=''),
    24144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24144, CurrentID=0, Status='live', Symbol='TFIP11', Aliases=['NTR1', 'STIP', 'STIP-1', 'Spp382', 'TIP39', 'bK445C9.6'], description='tuftelin interacting protein 11', other_designations='tuftelin-interacting protein 11|septin and tuftelin-interacting protein 1|sip1/tuftelin interacting protein', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26491240, end_position_on_the_genomic_accession=26513591, orientation='minus', exon_count=16, OMIM=[612747], no_hdr0=''),
    24145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24145, CurrentID=0, Status='live', Symbol='PANX1', Aliases=['MRS1', 'OOMD7', 'PX1', 'UNQ2529'], description='pannexin 1', other_designations='pannexin-1|innexin', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94128841, end_position_on_the_genomic_accession=94185596, orientation='plus', exon_count=7, OMIM=[608420], no_hdr0=''),
    24146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24146, CurrentID=0, Status='live', Symbol='CLDN15', Aliases=[], description='claudin 15', other_designations='claudin-15', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101232094, end_position_on_the_genomic_accession=101238820, orientation='minus', exon_count=6, OMIM=[615778], no_hdr0=''),
    24147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24147, CurrentID=0, Status='live', Symbol='FJX1', Aliases=[], description='four-jointed box kinase 1', other_designations='four-jointed box protein 1|four jointed box 1|four-jointed protein homolog|putative secreted ligand homologous to fjx1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35618460, end_position_on_the_genomic_accession=35620865, orientation='plus', exon_count=1, OMIM=[612206], no_hdr0=''),
    24148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24148, CurrentID=0, Status='live', Symbol='PRPF6', Aliases=['ANT-1', 'ANT1', 'C20orf14', 'Prp6', 'RP60', 'SNRNP102', 'TOM', 'U5-102K', 'hPrp6'], description='pre-mRNA processing factor 6', other_designations='pre-mRNA-processing factor 6|PRP6 homolog|PRP6 pre-mRNA processing factor 6 homolog|U5 snRNP-associated 102 kDa protein|U5-102 kDa protein|androgen receptor N-terminal domain transactivating protein-1|p102 U5 small nuclear ribonucleoprotein particle-binding protein|putative mitochondrial outer membrane protein import receptor', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63981132, end_position_on_the_genomic_accession=64033100, orientation='plus', exon_count=21, OMIM=[613979], no_hdr0=''),
    24149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24149, CurrentID=0, Status='live', Symbol='ZNF318', Aliases=['HRIHFB2436', 'TZF', 'ZFP318'], description='zinc finger protein 318', other_designations='zinc finger protein 318|endocrine regulator|endocrine regulatory protein|testicular zinc finger', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43336070, end_position_on_the_genomic_accession=43369647, orientation='minus', exon_count=10, OMIM=[617512], no_hdr0=''),
    24150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=24150, CurrentID=0, Status='live', Symbol='TP53TG3', Aliases=['P53TG3A', 'TP53TG3E', 'TP53TG3F', 'TP53TG3'], description='TP53 target 3', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein|p53 target gene 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=32673519, end_position_on_the_genomic_accession=32676129, orientation='minus', exon_count=4, OMIM=[617482], no_hdr0=''),
    25758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25758, CurrentID=0, Status='live', Symbol='KIAA1549L', Aliases=['C11orf41', 'C11orf69', 'G2'], description='KIAA1549 like', other_designations='UPF0606 protein KIAA1549L|UPF0606 protein C11orf41|uncharacterized protein C11orf69', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33376108, end_position_on_the_genomic_accession=33674102, orientation='plus', exon_count=22, OMIM=[612297], no_hdr0=''),
    25759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25759, CurrentID=0, Status='live', Symbol='SHC2', Aliases=['SCK', 'SHCB', 'SLI'], description='SHC adaptor protein 2', other_designations='SHC-transforming protein 2|SH2 domain protein C2|SHC (Src homology 2 domain containing) transforming protein 2|SHC-transforming protein B|neuronal Shc adaptor homolog|protein Sck|src homology 2 domain-containing-transforming protein C2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=416589, end_position_on_the_genomic_accession=461033, orientation='minus', exon_count=16, OMIM=[605217], no_hdr0=''),
    25763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25763, CurrentID=0, Status='live', Symbol='H2AP', Aliases=['CXorf27', 'HIP17', 'HYPM'], description='H2A.P histone', other_designations='huntingtin-interacting protein M|histone H2A.P|huntingtin interacting protein M|huntingtin yeast partner M', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37990779, end_position_on_the_genomic_accession=37991314, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    25764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25764, CurrentID=0, Status='live', Symbol='HYPK', Aliases=['C15orf63', 'HSPC136'], description='huntingtin interacting protein K', other_designations='huntingtin-interacting protein K|huntingtin yeast partner K', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43800421, end_position_on_the_genomic_accession=43804427, orientation='plus', exon_count=4, OMIM=[612784], no_hdr0=''),
    25766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25766, CurrentID=0, Status='live', Symbol='PRPF40B', Aliases=['HYPC'], description='pre-mRNA processing factor 40 homolog B', other_designations='pre-mRNA-processing factor 40 homolog B|Huntingtin interacting protein C|PRP40 pre-mRNA processing factor 40 homolog B|huntingtin yeast partner C', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49622717, end_position_on_the_genomic_accession=49645129, orientation='plus', exon_count=29, OMIM=[], no_hdr0=''),
    25769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25769, CurrentID=0, Status='live', Symbol='SLC24A2', Aliases=['NCKX2'], description='solute carrier family 24 member 2', other_designations='sodium/potassium/calcium exchanger 2|Na(+)/K(+)/Ca(2+)-exchange protein 2|retinal cone Na-Ca+K exchanger|solute carrier family 24 (sodium/potassium/calcium exchanger), member 2', map_location='9p22.1-p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19507452, end_position_on_the_genomic_accession=20307888, orientation='minus', exon_count=16, OMIM=[609838], no_hdr0=''),
    25770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25770, CurrentID=0, Status='live', Symbol='C22orf31', Aliases=['HS747E2A', 'bK747E2.1'], description='chromosome 22 open reading frame 31', other_designations='uncharacterized protein C22orf31', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29058672, end_position_on_the_genomic_accession=29073943, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    25771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25771, CurrentID=0, Status='live', Symbol='TBC1D22A', Aliases=['C22orf4', 'HSC79E021'], description='TBC1 domain family member 22A', other_designations='TBC1 domain family member 22A|putative GTPase activator', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46762631, end_position_on_the_genomic_accession=47224975, orientation='plus', exon_count=31, OMIM=[616879], no_hdr0=''),
    25774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25774, CurrentID=0, Status='live', Symbol='GSTT4', Aliases=['GSTTP1', 'HS322B1A'], description='glutathione S-transferase theta 4', other_designations='glutathione S-transferase theta-4|GST class-theta-4|glutathione S-transferase theta pseudogene 1', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23988481, end_position_on_the_genomic_accession=24005474, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    25776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25776, CurrentID=0, Status='live', Symbol='CBY1', Aliases=['C22orf2', 'CBY', 'Chibby1', 'HS508I15A', 'PGEA1', 'PIGEA-14', 'PIGEA14', 'arb1'], description='chibby family member 1, beta catenin antagonist', other_designations='protein chibby homolog 1|ARPP-binding protein|PKD2 interactor, Golgi and endoplasmic reticulum-associated 1|chibby CTNNB1-mediated transcription inhibitor|chibby homolog 1|coiled-coil protein PIGEA-14|cytosolic leucine-rich protein|polycystin-2 interactor, Golgi- and endoplasmic reticulum-associated protein, 14 kDa', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38656638, end_position_on_the_genomic_accession=38673850, orientation='plus', exon_count=6, OMIM=[607757], no_hdr0=''),
    25777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25777, CurrentID=0, Status='live', Symbol='SUN2', Aliases=['UNC84B', 'rab5IP'], description='Sad1 and UNC84 domain containing 2', other_designations='SUN domain-containing protein 2|Sad1 unc-84 domain protein 2|nuclear envelope protein|protein unc-84 homolog B|rab5-interacting protein|sad1/unc-84 protein-like 2|unc-84 homolog B', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38734727, end_position_on_the_genomic_accession=38756014, orientation='minus', exon_count=22, OMIM=[613569], no_hdr0=''),
    25778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25778, CurrentID=0, Status='live', Symbol='DSTYK', Aliases=['CAKUT1', 'DustyPK', 'HDCMD38P', 'RIP5', 'RIPK5', 'SPG23'], description='dual serine/threonine and tyrosine protein kinase', other_designations='dual serine/threonine and tyrosine protein kinase|RIP-homologous kinase|dusty PK|dusty protein kinase|receptor-interacting serine/threonine-protein kinase 5|sgK496|spastic paraplegia 23 (autosomal recessive)|sugen kinase 496', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205142497, end_position_on_the_genomic_accession=205211702, orientation='minus', exon_count=14, OMIM=[612666], no_hdr0=''),
    25780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25780, CurrentID=0, Status='live', Symbol='RASGRP3', Aliases=['GRP3'], description='RAS guanyl releasing protein 3', other_designations='ras guanyl-releasing protein 3|CalDAG-GEFIII|RAS guanyl releasing protein 3 (calcium and DAG-regulated)|calcium and DAG-regulated guanine nucleotide exchange factor III|calcium- and diacylglycerol-regulated guanine nucleotide exchange factor III|guanine nucleotide exchange factor for Rap1', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=33436348, end_position_on_the_genomic_accession=33564731, orientation='plus', exon_count=25, OMIM=[609531], no_hdr0=''),
    25782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25782, CurrentID=0, Status='live', Symbol='RAB3GAP2', Aliases=['MARTS1', 'RAB3-GAP150', 'RAB3GAP150', 'SPG69', 'WARBM2', 'p150'], description='RAB3 GTPase activating non-catalytic protein subunit 2', other_designations='rab3 GTPase-activating protein non-catalytic subunit|RAB3 GTPase activating protein subunit 2 (non-catalytic)|RGAP-iso|rab3 GTPase-activating protein 150 kDa subunit|rab3-GAP p150|rab3-GAP regulatory subunit', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220148293, end_position_on_the_genomic_accession=220272453, orientation='minus', exon_count=35, OMIM=[609275], no_hdr0=''),
    25788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25788, CurrentID=0, Status='live', Symbol='RAD54B', Aliases=['RDH54'], description='RAD54 homolog B', other_designations='DNA repair and recombination protein RAD54B', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94371960, end_position_on_the_genomic_accession=94475115, orientation='minus', exon_count=17, OMIM=[604289], no_hdr0=''),
    25789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25789, CurrentID=0, Status='live', Symbol='TMEM59L', Aliases=['BSMAP', 'C19orf4'], description='transmembrane protein 59 like', other_designations='transmembrane protein 59-like|brain-specific membrane-anchored protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18612870, end_position_on_the_genomic_accession=18621040, orientation='plus', exon_count=7, OMIM=[617096], no_hdr0=''),
    25790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25790, CurrentID=0, Status='live', Symbol='CFAP45', Aliases=['CCDC19', 'NESG1'], description='cilia and flagella associated protein 45', other_designations='cilia- and flagella-associated protein 45|coiled-coil domain containing 19|coiled-coil domain-containing protein 19, mitochondrial|nasopharyngeal epithelium specific protein 1 (NESG1)|nasopharyngeal epithelium-specific protein 1|protein CFAP45, mitochondrial', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159872364, end_position_on_the_genomic_accession=159900165, orientation='minus', exon_count=12, OMIM=[605152], no_hdr0=''),
    25791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25791, CurrentID=0, Status='live', Symbol='NGEF', Aliases=['ARHGEF27', 'EPHEXIN'], description='neuronal guanine nucleotide exchange factor', other_designations='ephexin-1|eph-interacting exchange protein|ephexin1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232878686, end_position_on_the_genomic_accession=233013256, orientation='minus', exon_count=18, OMIM=[605991], no_hdr0=''),
    25792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25792, CurrentID=0, Status='live', Symbol='CIZ1', Aliases=['LSFR1', 'NP94', 'ZNF356'], description='CDKN1A interacting zinc finger protein 1', other_designations='cip1-interacting zinc finger protein|nuclear protein NP94|zinc finger protein 356', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128166065, end_position_on_the_genomic_accession=128204222, orientation='minus', exon_count=23, OMIM=[611420], no_hdr0=''),
    25793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25793, CurrentID=0, Status='live', Symbol='FBXO7', Aliases=['FBX', 'FBX07', 'FBX7', 'PARK15', 'PKPS'], description='F-box protein 7', other_designations='F-box only protein 7', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32474682, end_position_on_the_genomic_accession=32498829, orientation='plus', exon_count=10, OMIM=[605648], no_hdr0=''),
    25794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25794, CurrentID=0, Status='live', Symbol='FSCN2', Aliases=['RFSN', 'RP30'], description='fascin actin-bundling protein 2, retinal', other_designations='fascin-2|fascin homolog 2, actin-bundling protein, retinal', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81513019, end_position_on_the_genomic_accession=81537130, orientation='plus', exon_count=9, OMIM=[607643], no_hdr0=''),
    25796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25796, CurrentID=0, Status='live', Symbol='PGLS', Aliases=['6PGL', 'HEL-S-304'], description='6-phosphogluconolactonase', other_designations='6-phosphogluconolactonase|epididymis secretory protein Li 304|epididymis secretory sperm binding protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17511649, end_position_on_the_genomic_accession=17521291, orientation='plus', exon_count=6, OMIM=[604951], no_hdr0=''),
    25797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25797, CurrentID=0, Status='live', Symbol='QPCT', Aliases=['GCT', 'QC', 'sQC'], description='glutaminyl-peptide cyclotransferase', other_designations='glutaminyl-peptide cyclotransferase|EC|glutaminyl cyclase|glutaminyl-tRNA cyclotransferase|glutamyl cyclase', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37344630, end_position_on_the_genomic_accession=37373322, orientation='plus', exon_count=7, OMIM=[607065], no_hdr0=''),
    25798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25798, CurrentID=0, Status='live', Symbol='BRI3', Aliases=['I3'], description='brain protein I3', other_designations='brain protein I3|pRGR2', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98281673, end_position_on_the_genomic_accession=98322398, orientation='plus', exon_count=8, OMIM=[615628], no_hdr0=''),
    25799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25799, CurrentID=0, Status='live', Symbol='ZNF324', Aliases=['ZF5128A', 'ZNF324'], description='zinc finger protein 324', other_designations='zinc finger protein 324A|zinc finger protein ZF5128', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58467080, end_position_on_the_genomic_accession=58475436, orientation='plus', exon_count=5, OMIM=[617477], no_hdr0=''),
    25800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25800, CurrentID=0, Status='live', Symbol='SLC39A6', Aliases=['LIV-1', 'ZIP6'], description='solute carrier family 39 member 6', other_designations='zinc transporter ZIP6|LIV-1 protein, estrogen regulated|ZIP-6|estrogen-regulated protein LIV-1|solute carrier family 39 (metal ion transporter), member 6|solute carrier family 39 (zinc transporter), member 6|zrt- and Irt-like protein 6', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36108531, end_position_on_the_genomic_accession=36129868, orientation='minus', exon_count=11, OMIM=[608731], no_hdr0=''),
    25801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25801, CurrentID=0, Status='live', Symbol='GCA', Aliases=['GCL'], description='grancalcin', other_designations='grancalcin|grancalcin, EF-hand calcium-binding protein|grancalcin, penta-EF-hand protein', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=162318763, end_position_on_the_genomic_accession=162377225, orientation='plus', exon_count=13, OMIM=[607030], no_hdr0=''),
    25802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25802, CurrentID=0, Status='live', Symbol='LMOD1', Aliases=['1D', '64kD', 'D1', 'MMIHS3', 'SM-LMOD', 'SMLMOD'], description='leiomodin 1', other_designations='leiomodin-1|64 kDa autoantigen 1D|64 kDa autoantigen 1D3|64 kDa autoantigen D1|leimodin 1 (smooth muscle)|leiomodin 1 (smooth muscle)|leiomodin, muscle form|smooth muscle leiomodin|thyroid and eye muscle autoantigen D1 (64kD)|thyroid-associated ophthalmopathy autoantigen', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201896456, end_position_on_the_genomic_accession=201946548, orientation='minus', exon_count=3, OMIM=[602715], no_hdr0=''),
    25803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25803, CurrentID=0, Status='live', Symbol='SPDEF', Aliases=['PDEF', 'bA375E1.3'], description='SAM pointed domain containing ETS transcription factor', other_designations='SAM pointed domain-containing Ets transcription factor|prostate epithelium-specific Ets transcription factor|prostate-derived Ets factor|prostate-specific Ets', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34537800, end_position_on_the_genomic_accession=34556329, orientation='minus', exon_count=8, OMIM=[608144], no_hdr0=''),
    25804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25804, CurrentID=0, Status='live', Symbol='LSM4', Aliases=['GRP', 'YER112W'], description='LSM4 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm4|LSM4 U6 small nuclear RNA and mRNA degradation associated|LSM4 homolog, U6 small nuclear RNA associated|glycine-rich protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18306236, end_position_on_the_genomic_accession=18323076, orientation='minus', exon_count=5, OMIM=[607284], no_hdr0=''),
    25805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25805, CurrentID=0, Status='live', Symbol='BAMBI', Aliases=['NMA'], description='BMP and activin membrane bound inhibitor', other_designations='BMP and activin membrane-bound inhibitor homolog|non-metastatic gene A protein|putative transmembrane protein NMA', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=28677521, end_position_on_the_genomic_accession=28682932, orientation='plus', exon_count=3, OMIM=[604444], no_hdr0=''),
    25806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25806, CurrentID=0, Status='live', Symbol='VAX2', Aliases=['DRES93'], description='ventral anterior homeobox 2', other_designations='ventral anterior homeobox 2', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70900551, end_position_on_the_genomic_accession=70933917, orientation='plus', exon_count=5, OMIM=[604295], no_hdr0=''),
    25807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25807, CurrentID=0, Status='live', Symbol='RHBDD3', Aliases=['C22orf3', 'HS984G1A', 'PTAG'], description='rhomboid domain containing 3', other_designations='rhomboid domain-containing protein 3|hypothetical protein HS984G1A|pituitary tumor apoptosis', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29259852, end_position_on_the_genomic_accession=29268213, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    25809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25809, CurrentID=0, Status='live', Symbol='TTLL1', Aliases=['C22orf7', 'HS323M22B'], description='tubulin tyrosine ligase like 1', other_designations='probable tubulin polyglutamylase TTLL1|PGs3|catalytic subunit of neural tubulin polyglutamylase|tubulin polyglutamylase complex subunit 3|tubulin tyrosine ligase-like family, member 1|tubulin--tyrosine ligase-like protein 1|tubulin-tyrosine ligase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43039516, end_position_on_the_genomic_accession=43089418, orientation='minus', exon_count=14, OMIM=[608955], no_hdr0=''),
    25813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25813, CurrentID=0, Status='live', Symbol='SAMM50', Aliases=['CGI-51', 'OMP85', 'SAM50', 'TOB55', 'TRG-3', 'YNL026W'], description='SAMM50 sorting and assembly machinery component', other_designations='sorting and assembly machinery component 50 homolog|sorting and assembly machinery 50kDa|transformation-related gene 3 protein', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43955442, end_position_on_the_genomic_accession=43996529, orientation='plus', exon_count=15, OMIM=[612058], no_hdr0=''),
    25814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25814, CurrentID=0, Status='live', Symbol='ATXN10', Aliases=['E46L', 'HUMEEP', 'SCA10'], description='ataxin 10', other_designations='ataxin-10|brain protein E46 homolog|spinocerebellar ataxia type 10 protein', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45671834, end_position_on_the_genomic_accession=45845307, orientation='plus', exon_count=12, OMIM=[611150], no_hdr0=''),
    25816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25816, CurrentID=0, Status='live', Symbol='TNFAIP8', Aliases=['GG2-1', 'MDC-3.13', 'NDED', 'SCC-S2', 'SCCS2'], description='TNF alpha induced protein 8', other_designations='tumor necrosis factor alpha-induced protein 8|NF-kappa-B-inducible DED-containing protein|TNF-induced protein GG2-1|head and neck tumor and metastasis-related protein|tumor necrosis factor, alpha induced protein 8', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=119268759, end_position_on_the_genomic_accession=119399688, orientation='plus', exon_count=7, OMIM=[612111], no_hdr0=''),
    25817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25817, CurrentID=0, Status='live', Symbol='TAFA5', Aliases=['FAM19A5', 'QLLK5208', 'TAFA-5', 'UNQ5208'], description='TAFA chemokine like family member 5', other_designations='chemokine-like protein TAFA-5|TAFA protein 5|family with sequence similarity 19 (chemokine (C-C motif)-like), member A5|family with sequence similarity 19 member A5, C-C motif chemokine like|protein FAM19A5', map_location='22q13.32', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=48489553, end_position_on_the_genomic_accession=48751932, orientation='plus', exon_count=5, OMIM=[617499], no_hdr0=''),
    25818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25818, CurrentID=0, Status='live', Symbol='KLK5', Aliases=['KLK-L2', 'KLKL2', 'SCTE'], description='kallikrein related peptidase 5', other_designations='kallikrein-5|kallikrein-like protein 2|stratum corneum tryptic enzyme', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50943299, end_position_on_the_genomic_accession=50953038, orientation='minus', exon_count=7, OMIM=[605643], no_hdr0=''),
    25819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25819, CurrentID=0, Status='live', Symbol='NOCT', Aliases=['CCR4L', 'CCRN4L', 'Ccr4c', 'NOC'], description='nocturnin', other_designations='nocturnin|CCR4 carbon catabolite repression 4-like|CCR4 protein homolog|CCR4-like (carbon catabolite repression 4, S.cerevisiae)|carbon catabolite repression 4-like protein|circadian deadenylase NOC', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139015781, end_position_on_the_genomic_accession=139045939, orientation='plus', exon_count=3, OMIM=[608468], no_hdr0=''),
    25820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25820, CurrentID=0, Status='live', Symbol='ARIH1', Aliases=['ARI', 'HARI', 'HHARI', 'UBCH7BP'], description='ariadne RBR E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase ARIH1|ARI-1|H7-AP2|MOP-6|ariadne homolog, ubiquitin-conjugating enzyme E2 binding protein, 1|ariadne, Drosophila, homolog of|monocyte protein 6|protein ariadne-1 homolog|ubcH7-binding protein|ubcM4-interacting protein|ubiquitin-conjugating enzyme E2-binding protein 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72474330, end_position_on_the_genomic_accession=72602987, orientation='plus', exon_count=14, OMIM=[605624], no_hdr0=''),
    25821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25821, CurrentID=0, Status='live', Symbol='MTO1', Aliases=['CGI-02', 'COXPD10'], description='mitochondrial tRNA translation optimization 1', other_designations='protein MTO1 homolog, mitochondrial|homolog of yeast Mto1|mitochondrial MTO1-3|mitochondrial translation optimization 1 homolog', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73461737, end_position_on_the_genomic_accession=73509236, orientation='plus', exon_count=14, OMIM=[614667], no_hdr0=''),
    25822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25822, CurrentID=0, Status='live', Symbol='DNAJB5', Aliases=['Hsc40'], description='DnaJ heat shock protein family (Hsp40) member B5', other_designations='dnaJ homolog subfamily B member 5|DnaJ (Hsp40) homolog, subfamily B, member 5|heat shock cognate 40|heat shock protein Hsp40-2|heat shock protein Hsp40-3|heat shock protein cognate 40', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34989745, end_position_on_the_genomic_accession=34998900, orientation='plus', exon_count=7, OMIM=[611328], no_hdr0=''),
    25823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25823, CurrentID=0, Status='live', Symbol='TPSG1', Aliases=['PRSS31', 'TMT', 'trpA'], description='tryptase gamma 1', other_designations='tryptase gamma|serine protease 31|transmembrane tryptase|tryptase gamma I|tryptase gamma II', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1221651, end_position_on_the_genomic_accession=1226454, orientation='minus', exon_count=7, OMIM=[609341], no_hdr0=''),
    25824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25824, CurrentID=0, Status='live', Symbol='PRDX5', Aliases=['ACR1', 'AOEB166', 'B166', 'HEL-S-55', 'PLP', 'PMP20', 'PRDX6', 'PRXV', 'SBBI10', 'prx-V'], description='peroxiredoxin 5', other_designations='peroxiredoxin-5, mitochondrial|Alu co-repressor 1|TPx type VI|antioxidant enzyme B166|epididymis secretory protein Li 55|liver tissue 2D-page spot 71B|peroxiredoxin V|peroxisomal antioxidant enzyme|thioredoxin peroxidase PMP20|thioredoxin reductase|thioredoxin-dependent peroxiredoxin 5', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64318121, end_position_on_the_genomic_accession=64321811, orientation='plus', exon_count=6, OMIM=[606583], no_hdr0=''),
    25825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25825, CurrentID=0, Status='live', Symbol='BACE2', Aliases=['AEPLC', 'ALP56', 'ASP1', 'ASP21', 'BAE2', 'CDA13', 'CEAP1', 'DRAP'], description='beta-secretase 2', other_designations='beta-secretase 2|56 kDa aspartic-like protease|Down syndrome region aspartic protease|SLCO3A1/BACE2 fusion|aspartyl protease 1|beta-site APP-cleaving enzyme 2|beta-site amyloid beta A4 precursor protein-cleaving enzyme 2|memapsin-1|membrane-associated aspartic protease 1|theta-secretase|transmembrane aspartic proteinase Asp1', map_location='21q22.2-q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41168160, end_position_on_the_genomic_accession=41282530, orientation='plus', exon_count=10, OMIM=[605668], no_hdr0=''),
    25827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25827, CurrentID=0, Status='live', Symbol='FBXL2', Aliases=['FBL2', 'FBL3'], description='F-box and leucine rich repeat protein 2', other_designations='F-box/LRR-repeat protein 2|F-box protein FBL2/FBL3|F-box protein containing leucine-rich repeats', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33277025, end_position_on_the_genomic_accession=33422698, orientation='plus', exon_count=22, OMIM=[605652], no_hdr0=''),
    25828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25828, CurrentID=0, Status='live', Symbol='TXN2', Aliases=['COXPD29', 'MT-TRX', 'MTRX', 'TRX2', 'TXN'], description='thioredoxin 2', other_designations='thioredoxin, mitochondrial|mitochondrial thioredoxin', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36467036, end_position_on_the_genomic_accession=36481672, orientation='minus', exon_count=5, OMIM=[609063], no_hdr0=''),
    25829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25829, CurrentID=0, Status='live', Symbol='TMEM184B', Aliases=['C22orf5', 'FM08', 'HS5O6A', 'HSPC256'], description='transmembrane protein 184B', other_designations='transmembrane protein 184B|putative MAPK-activating protein FM08', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38219291, end_position_on_the_genomic_accession=38273013, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    25830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25830, CurrentID=0, Status='live', Symbol='SULT4A1', Aliases=['BR-STL-1', 'BRSTL1', 'DJ388M5.3', 'NST', 'SULTX3', 'hBR-STL-1'], description='sulfotransferase family 4A member 1', other_designations='sulfotransferase 4A1|ST4A1|brain sulfotransferase-like protein|hBR-STL|nervous system cytosolic sulfotransferase|nervous system sulfotransferase|sulfotransferase-related protein', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43824509, end_position_on_the_genomic_accession=43862513, orientation='minus', exon_count=11, OMIM=[608359], no_hdr0=''),
    25831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25831, CurrentID=0, Status='live', Symbol='HECTD1', Aliases=['EULIR'], description='HECT domain E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase HECTD1|E3 ligase for inhibin receptor|HECT domain containing E3 ubiquitin protein ligase 1|HECT domain-containing protein 1|HECT-type E3 ubiquitin transferase HECTD1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31100117, end_position_on_the_genomic_accession=31207793, orientation='minus', exon_count=45, OMIM=[618649], no_hdr0=''),
    25832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25832, CurrentID=0, Status='live', Symbol='NBPF14', Aliases=['DJ328E19.C1.1', 'NBPF'], description='NBPF member 14', other_designations='neuroblastoma breakpoint family member 14|AE5', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148531385, end_position_on_the_genomic_accession=148595717, orientation='minus', exon_count=66, OMIM=[614003], no_hdr0=''),
    25833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25833, CurrentID=0, Status='live', Symbol='POU2F3', Aliases=['Epoc-1', 'OCT-11', 'OCT11', 'OTF-11', 'PLA-1', 'PLA1', 'Skn-1a'], description='POU class 2 homeobox 3', other_designations='POU domain, class 2, transcription factor 3|POU domain transcription factor OCT11a|octamer-binding protein 11|octamer-binding transcription factor 11|transcription factor PLA-1|transcription factor Skn-1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120236638, end_position_on_the_genomic_accession=120319945, orientation='plus', exon_count=17, OMIM=[607394], no_hdr0=''),
    25834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25834, CurrentID=0, Status='live', Symbol='MGAT4C', Aliases=['GNTIVH', 'HGNT-IV-H'], description='MGAT4 family member C', other_designations='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase C|N-acetylglucosaminyltransferase IV homolog|N-acetylglucosaminyltransferase IVc|N-glycosyl-oligosaccharide-glycoprotein N-acetylglucosaminyltransferase IVc|UDP-N-acetylglucosamine: alpha-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IVc|UDP-N-acetylglucosamine:a-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IV|UDP-N-acetylglucosamine:a-1,3-D-mannoside beta-1,4-N-acetylglucosaminyltransferase IV-homolog|glcNAc-T IVc|gnT-IVc|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase, isozyme C (putative)', map_location='12q21.31-q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85955667, end_position_on_the_genomic_accession=86839000, orientation='minus', exon_count=19, OMIM=[607385], no_hdr0=''),
    25836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25836, CurrentID=0, Status='live', Symbol='NIPBL', Aliases=['CDLS', 'CDLS1', 'IDN3', 'IDN3-B', 'Scc2'], description='NIPBL cohesin loading factor', other_designations='nipped-B-like protein|Nipped-B homolog|SCC2 homolog|delangin|sister chromatid cohesion 2 homolog', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36876769, end_position_on_the_genomic_accession=37066413, orientation='plus', exon_count=49, OMIM=[608667], no_hdr0=''),
    25837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25837, CurrentID=0, Status='live', Symbol='RAB26', Aliases=['V46133'], description='RAB26, member RAS oncogene family', other_designations='ras-related protein Rab-26|Ras-related oncogene protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2148144, end_position_on_the_genomic_accession=2154165, orientation='plus', exon_count=11, OMIM=[605455], no_hdr0=''),
    25839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25839, CurrentID=0, Status='live', Symbol='COG4', Aliases=['CDG2J', 'COD1', 'SWILS'], description='component of oligomeric golgi complex 4', other_designations='conserved oligomeric Golgi complex subunit 4|COG complex subunit 4|complexed with Dor1p|conserved oligomeric Golgi complex protein 4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70480567, end_position_on_the_genomic_accession=70523554, orientation='minus', exon_count=20, OMIM=[606976], no_hdr0=''),
    25840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25840, CurrentID=0, Status='live', Symbol='METTL7A', Aliases=['AAM-B', 'AAMB'], description='methyltransferase like 7A', other_designations='methyltransferase-like protein 7A|protein AAM-B', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50925015, end_position_on_the_genomic_accession=50932508, orientation='plus', exon_count=2, OMIM=[618338], no_hdr0=''),
    25841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25841, CurrentID=0, Status='live', Symbol='ABTB2', Aliases=['ABTB2A', 'BTBD22'], description='ankyrin repeat and BTB domain containing 2', other_designations='ankyrin repeat and BTB/POZ domain-containing protein 2|ankyrin repeat and BTB (POZ) domain containing 2', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34150987, end_position_on_the_genomic_accession=34358010, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    25842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25842, CurrentID=0, Status='live', Symbol='ASF1A', Aliases=['CGI-98', 'CIA', 'HSPC146'], description='anti-silencing function 1A histone chaperone', other_designations='histone chaperone ASF1A|ASF1 anti-silencing function 1 homolog A|CCG1-interacting factor A|anti-silencing function protein 1 homolog A|hAsf1|hAsf1a|hCIA', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=118894152, end_position_on_the_genomic_accession=118909171, orientation='plus', exon_count=4, OMIM=[609189], no_hdr0=''),
    25843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25843, CurrentID=0, Status='live', Symbol='MOB4', Aliases=['2C4D', 'CGI-95', 'MOB1', 'MOB3', 'MOBKL3', 'PHOCN', 'PREI3'], description='MOB family member 4, phocein', other_designations='MOB-like protein phocein|MOB1, Mps One Binder kinase activator-like 3|Mps One Binder kinase activator-like 3|class II mMOB1|mob1 homolog 3|phocein, Mob-like protein|preimplantation protein 3', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197515554, end_position_on_the_genomic_accession=197553699, orientation='plus', exon_count=10, OMIM=[609361], no_hdr0=''),
    25844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25844, CurrentID=0, Status='live', Symbol='YIPF3', Aliases=['C6orf109', 'FinGER3', 'KLIP1', 'dJ337H4.3'], description='Yip1 domain family member 3', other_designations='protein YIPF3|killer lineage protein 1|natural killer cell-specific antigen KLIP1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43511832, end_position_on_the_genomic_accession=43516926, orientation='minus', exon_count=9, OMIM=[609775], no_hdr0=''),
    25847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25847, CurrentID=0, Status='live', Symbol='ANAPC13', Aliases=['APC13', 'SWM1'], description='anaphase promoting complex subunit 13', other_designations='anaphase-promoting complex subunit 13|cyclosome subunit 13', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134477704, end_position_on_the_genomic_accession=134486023, orientation='minus', exon_count=3, OMIM=[614484], no_hdr0=''),
    25849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25849, CurrentID=0, Status='live', Symbol='PARM1', Aliases=['Cipar1', 'DKFZP564O0823', 'PARM-1', 'WSC4'], description='prostate androgen-regulated mucin-like protein 1', other_designations='prostate androgen-regulated mucin-like protein 1|WSC4, cell wall integrity and stress response component 4 homolog|castration-induced prostatic apoptosis-related protein 1|prostatic androgen-regulated mucin-like protein 1|prostatic androgen-repressed message 1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74933116, end_position_on_the_genomic_accession=75050113, orientation='plus', exon_count=5, OMIM=[617688], no_hdr0=''),
    25850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25850, CurrentID=0, Status='live', Symbol='ZNF345', Aliases=['HZF10'], description='zinc finger protein 345', other_designations='zinc finger protein 345|zinc finger protein HZF10', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36850350, end_position_on_the_genomic_accession=36893218, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    25851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25851, CurrentID=0, Status='live', Symbol='TECPR1', Aliases=[], description='tectonin beta-propeller repeat containing 1', other_designations='tectonin beta-propeller repeat-containing protein 1', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98214624, end_position_on_the_genomic_accession=98252235, orientation='minus', exon_count=28, OMIM=[614781], no_hdr0=''),
    25852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25852, CurrentID=0, Status='live', Symbol='ARMC8', Aliases=['GID5', 'HSPC056', 'S863-2', 'VID28'], description='armadillo repeat containing 8', other_designations='armadillo repeat-containing protein 8|GID complex subunit 5, VID28 homolog', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138187248, end_position_on_the_genomic_accession=138298389, orientation='plus', exon_count=25, OMIM=[618521], no_hdr0=''),
    25853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25853, CurrentID=0, Status='live', Symbol='DCAF12', Aliases=['CT102', 'KIAA1892', 'TCC52', 'WDR40A'], description='DDB1 and CUL4 associated factor 12', other_designations='DDB1- and CUL4-associated factor 12|WD repeat domain 40A|WD repeat-containing protein 40A|cancer/testis antigen 102|centrosome-related protein TCC52|testis cancer centrosome-related protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34086387, end_position_on_the_genomic_accession=34126698, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    25854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25854, CurrentID=0, Status='live', Symbol='FAM149A', Aliases=['MST119', 'MSTP119'], description='family with sequence similarity 149 member A', other_designations='protein FAM149A', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186104704, end_position_on_the_genomic_accession=186175337, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    25855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25855, CurrentID=0, Status='live', Symbol='BRMS1', Aliases=[], description='BRMS1 transcriptional repressor and anoikis regulator', other_designations='breast cancer metastasis-suppressor 1|breast cancer metastasis suppressor 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66337333, end_position_on_the_genomic_accession=66345125, orientation='minus', exon_count=9, OMIM=[606259], no_hdr0=''),
    25858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25858, CurrentID=0, Status='live', Symbol='CATSPERZ', Aliases=['C11orf20', 'TEX40'], description='catsper channel auxiliary subunit zeta', other_designations='cation channel sperm-associated protein subunit zeta|catSper-zeta|catSperzeta|testis expressed 40|testis-expressed protein 40|testis-expressed sequence 40 protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64300358, end_position_on_the_genomic_accession=64304770, orientation='plus', exon_count=5, OMIM=[617511], no_hdr0=''),
    25861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25861, CurrentID=0, Status='live', Symbol='WHRN', Aliases=['CIP98', 'DFNB31', 'PDZD7B', 'USH2D', 'WI'], description='whirlin', other_designations='whirlin|CASK-interacting protein CIP98|autosomal recessive deafness type 31 protein', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114402078, end_position_on_the_genomic_accession=114505500, orientation='minus', exon_count=21, OMIM=[607928], no_hdr0=''),
    25862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25862, CurrentID=0, Status='live', Symbol='USP49', Aliases=[], description='ubiquitin specific peptidase 49', other_designations='ubiquitin carboxyl-terminal hydrolase 49|deubiquitinating enzyme 49|ubiquitin specific protease 49|ubiquitin thioesterase 49|ubiquitin thiolesterase 49|ubiquitin-specific-processing protease 49', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41789896, end_position_on_the_genomic_accession=41895375, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    25864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25864, CurrentID=0, Status='live', Symbol='ABHD14A', Aliases=['DORZ1'], description='abhydrolase domain containing 14A', other_designations='protein ABHD14A|abhydrolase domain-containing protein 14A|alpha/beta hydrolase domain-containing protein 14A', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51975064, end_position_on_the_genomic_accession=51981196, orientation='plus', exon_count=5, OMIM=[618771], no_hdr0=''),
    25865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25865, CurrentID=0, Status='live', Symbol='PRKD2', Aliases=['HSPC187', 'PKD2', 'nPKC-D2'], description='protein kinase D2', other_designations='serine/threonine-protein kinase D2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46674316, end_position_on_the_genomic_accession=46717114, orientation='minus', exon_count=19, OMIM=[607074], no_hdr0=''),
    25870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25870, CurrentID=0, Status='live', Symbol='SUMF2', Aliases=['pFGE'], description='sulfatase modifying factor 2', other_designations='inactive C-alpha-formylglycine-generating enzyme 2|C-alpha-formyglycine-generating enzyme 2|C-alpha-formylglycine-generating enzyme 2|epididymis secretory sperm binding protein|paralog of formylglycine-generating enzyme|paralog of the formylglycine-generating enzyme', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56064007, end_position_on_the_genomic_accession=56080670, orientation='plus', exon_count=11, OMIM=[607940], no_hdr0=''),
    25871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25871, CurrentID=0, Status='live', Symbol='NEPRO', Aliases=['ANXD3', 'C3orf17', 'NET17'], description='nucleolus and neural progenitor protein', other_designations='nucleolus and neural progenitor protein|protein nepro homolog', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113002444, end_position_on_the_genomic_accession=113019721, orientation='minus', exon_count=9, OMIM=[617089], no_hdr0=''),
    25873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25873, CurrentID=0, Status='live', Symbol='RPL36', Aliases=['L36'], description='ribosomal protein L36', other_designations='60S ribosomal protein L36|large ribosomal subunit protein eL36', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5690295, end_position_on_the_genomic_accession=5691875, orientation='plus', exon_count=3, OMIM=[617893], no_hdr0=''),
    25874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25874, CurrentID=0, Status='live', Symbol='MPC2', Aliases=['BRP44', 'SLC54A2'], description='mitochondrial pyruvate carrier 2', other_designations='mitochondrial pyruvate carrier 2|brain protein 44', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167916675, end_position_on_the_genomic_accession=167937072, orientation='minus', exon_count=7, OMIM=[614737], no_hdr0=''),
    25875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25875, CurrentID=0, Status='live', Symbol='LETMD1', Aliases=['1110019O13Rik', 'HCCR', 'HCCR-1', 'HCCR-2', 'HCCR1', 'HCCR2', 'HCRR-2', 'SLC55A3'], description='LETM1 domain containing 1', other_designations='LETM1 domain-containing protein 1|cervical cancer 1 proto-oncogene protein p40|cervical cancer proto-oncogene 2 protein|epididymis secretory sperm binding protein|human cervical cancer oncogene|regulator of TP53', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51048220, end_position_on_the_genomic_accession=51068958, orientation='plus', exon_count=11, OMIM=[619070], no_hdr0=''),
    25876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25876, CurrentID=0, Status='live', Symbol='SPEF1', Aliases=['C20orf28', 'CLAMPA', 'SPEF1'], description='sperm flagellar 1', other_designations='sperm flagellar protein 1|calponin-homology and microtubule-associated protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3777504, end_position_on_the_genomic_accession=3781448, orientation='minus', exon_count=7, OMIM=[610674], no_hdr0=''),
    25878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25878, CurrentID=0, Status='live', Symbol='MXRA5', Aliases=[], description='matrix remodeling associated 5', other_designations='matrix-remodeling-associated protein 5|adhesion protein with leucine-rich repeats and Immunoglobulin domains related to perlecan|adlican|matrix-remodelling associated 5', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=3308565, end_position_on_the_genomic_accession=3346652, orientation='minus', exon_count=7, OMIM=[300938], no_hdr0=''),
    25879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25879, CurrentID=0, Status='live', Symbol='DCAF13', Aliases=['GM83', 'HSPC064', 'Sof1', 'WDSOF1'], description='DDB1 and CUL4 associated factor 13', other_designations='DDB1- and CUL4-associated factor 13|WD repeat and SOF domain-containing protein 1|WD repeats and SOF1 domain containing', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103415386, end_position_on_the_genomic_accession=103443453, orientation='plus', exon_count=11, OMIM=[616196], no_hdr0=''),
    25880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25880, CurrentID=0, Status='live', Symbol='TMEM186', Aliases=['C16orf51'], description='transmembrane protein 186', other_designations='transmembrane protein 186', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8795180, end_position_on_the_genomic_accession=8797639, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    25884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25884, CurrentID=0, Status='live', Symbol='CHRDL2', Aliases=['BNF1', 'CHL2'], description='chordin like 2', other_designations='chordin-like protein 2|breast tumor novel factor 1|chordin-related protein 2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74696429, end_position_on_the_genomic_accession=74731426, orientation='minus', exon_count=12, OMIM=[613127], no_hdr0=''),
    25885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25885, CurrentID=0, Status='live', Symbol='POLR1A', Aliases=['A190', 'AFDCIN', 'RPA1', 'RPA190', 'RPA194', 'RPO1-4', 'RPO14'], description='RNA polymerase I subunit A', other_designations='DNA-directed RNA polymerase I subunit RPA1|DNA-directed RNA polymerase I largest subunit|DNA-directed RNA polymerase I subunit A|DNA-directed RNA polymerase I subunit A1|RNA polymerase I 194 kDa subunit|polymerase (RNA) I polypeptide A, 194kDa|polymerase (RNA) I subunit A', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86020216, end_position_on_the_genomic_accession=86105886, orientation='minus', exon_count=34, OMIM=[616404], no_hdr0=''),
    25886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25886, CurrentID=0, Status='live', Symbol='POC1A', Aliases=['PIX2', 'SOFT', 'WDR51A'], description='POC1 centriolar protein A', other_designations='POC1 centriolar protein homolog A|WD repeat domain 51A|WD repeat-containing protein 51A|proteome of centriole protein 1A', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52075226, end_position_on_the_genomic_accession=52154423, orientation='minus', exon_count=13, OMIM=[614783], no_hdr0=''),
    25888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25888, CurrentID=0, Status='live', Symbol='ZNF473', Aliases=['ZFP100', 'ZN473'], description='zinc finger protein 473', other_designations='zinc finger protein 473|zinc finger protein 100 homolog', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50026005, end_position_on_the_genomic_accession=50048776, orientation='plus', exon_count=5, OMIM=[617908], no_hdr0=''),
    25890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25890, CurrentID=0, Status='live', Symbol='ABI3BP', Aliases=['NESHBP', 'TARSH'], description='ABI family member 3 binding protein', other_designations='target of Nesh-SH3|ABI family, member 3 (NESH) binding protein|ABI gene family member 3-binding protein|ABI gene family, member 3 (NESH) binding protein|nesh-binding protein', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100749156, end_position_on_the_genomic_accession=100993508, orientation='minus', exon_count=68, OMIM=[606279], no_hdr0=''),
    25891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25891, CurrentID=0, Status='live', Symbol='PAMR1', Aliases=['DKFZP586H2123', 'FP938', 'RAMP'], description='peptidase domain containing associated with muscle regeneration 1', other_designations='inactive serine protease PAMR1|peptidase domain-containing protein associated with muscle regeneration 1|regeneration associated muscle protease|regeneration-associated muscle protease homolog', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35431827, end_position_on_the_genomic_accession=35530300, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    25893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25893, CurrentID=0, Status='live', Symbol='TRIM58', Aliases=['BIA2'], description='tripartite motif containing 58', other_designations='E3 ubiquitin-protein ligase TRIM58|RING-type E3 ubiquitin transferase TRIM58|tripartite motif-containing protein 58', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247857187, end_position_on_the_genomic_accession=247880138, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    25894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25894, CurrentID=0, Status='live', Symbol='PLEKHG4', Aliases=['ARHGEF44', 'PRTPHN1', 'SCA4'], description='pleckstrin homology and RhoGEF domain containing G4', other_designations='puratrophin-1|PH domain-containing family G member 4|Purkinje cell atrophy associated protein 1|pleckstrin homology domain containing, family G (with RhoGef domain) member 4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67277820, end_position_on_the_genomic_accession=67289485, orientation='plus', exon_count=27, OMIM=[609526], no_hdr0=''),
    25895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25895, CurrentID=0, Status='live', Symbol='EEF1AKMT3', Aliases=['FAM119B', 'METTL21B'], description='EEF1A lysine methyltransferase 3', other_designations='EEF1A lysine methyltransferase 3|family with sequence similarity 119, member B|hepatocellular carcinoma-associated antigen 557a|hepatocellularcarcinoma-associated antigen HCA557a|methyltransferase like 21B|methyltransferase-like protein 21B|protein-lysine methyltransferase METTL21B', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57772614, end_position_on_the_genomic_accession=57782541, orientation='plus', exon_count=4, OMIM=[615258], no_hdr0=''),
    25896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25896, CurrentID=0, Status='live', Symbol='INTS7', Aliases=['C1orf73', 'INT7'], description='integrator complex subunit 7', other_designations='integrator complex subunit 7', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211940328, end_position_on_the_genomic_accession=212035557, orientation='minus', exon_count=23, OMIM=[611350], no_hdr0=''),
    25897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25897, CurrentID=0, Status='live', Symbol='RNF19A', Aliases=['RNF19'], description='ring finger protein 19A, RBR E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase RNF19A|double ring-finger protein|protein p38 interacting with transcription factor Sp1|ring finger protein 19A, E3 ubiquitin protein ligase|ring-IBR-ring domain containing protein Dorfin', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100257062, end_position_on_the_genomic_accession=100336204, orientation='minus', exon_count=15, OMIM=[607119], no_hdr0=''),
    25898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25898, CurrentID=0, Status='live', Symbol='RCHY1', Aliases=['ARNIP', 'CHIMP', 'PIRH2', 'PRO1996', 'RNF199', 'ZCHY', 'ZNF363'], description='ring finger and CHY zinc finger domain containing 1', other_designations='RING finger and CHY zinc finger domain-containing protein 1|CH-rich interacting match with PLAG1|E3 ubiquitin-protein ligase Pirh2|RING finger protein 199|RING-type E3 ubiquitin transferase RCHY1|androgen-receptor N-terminal-interacting protein|p53-induced protein with a RING-H2 domain|ring finger and CHY zinc finger domain containing 1, E3 ubiquitin protein ligase|zinc finger protein 363|zinc finger, CHY-type', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75479033, end_position_on_the_genomic_accession=75514715, orientation='minus', exon_count=10, OMIM=[607680], no_hdr0=''),
    25900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25900, CurrentID=0, Status='live', Symbol='IFFO1', Aliases=['HOM-TES-103', 'IFFO'], description='intermediate filament family orphan 1', other_designations='non-homologous end joining factor IFFO1|NHEJ factor IFFO1|intermediate filament-like MGC:2625', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6538961, end_position_on_the_genomic_accession=6556097, orientation='minus', exon_count=12, OMIM=[610495], no_hdr0=''),
    25901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25901, CurrentID=0, Status='live', Symbol='CCDC28A', Aliases=['C6orf80', 'CCRL1AP'], description='coiled-coil domain containing 28A', other_designations='coiled-coil domain-containing protein 28A|chemokine C-C motif receptor-like 1 adjacent', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138773769, end_position_on_the_genomic_accession=138793319, orientation='plus', exon_count=7, OMIM=[615353], no_hdr0=''),
    25902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25902, CurrentID=0, Status='live', Symbol='MTHFD1L', Aliases=['FTHFSDC1', 'MTC1THFS', 'dJ292B18.2'], description='methylenetetrahydrofolate dehydrogenase (NADP+ dependent) 1 like', other_designations='monofunctional C1-tetrahydrofolate synthase, mitochondrial|10-formyl-THF synthetase|formyltetrahydrofolate synthetase domain containing 1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150865684, end_position_on_the_genomic_accession=151101887, orientation='plus', exon_count=42, OMIM=[611427], no_hdr0=''),
    25903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25903, CurrentID=0, Status='live', Symbol='OLFML2B', Aliases=[], description='olfactomedin like 2B', other_designations='olfactomedin-like protein 2B|photomedin-2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161983192, end_position_on_the_genomic_accession=162023869, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    25904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25904, CurrentID=0, Status='live', Symbol='CNOT10', Aliases=[], description='CCR4-NOT transcription complex subunit 10', other_designations='CCR4-NOT transcription complex subunit 10', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32685188, end_position_on_the_genomic_accession=32773875, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    25906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25906, CurrentID=0, Status='live', Symbol='ANAPC15', Aliases=['APC15', 'C11orf51', 'HSPC020'], description='anaphase promoting complex subunit 15', other_designations='anaphase-promoting complex subunit 15', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72106372, end_position_on_the_genomic_accession=72112780, orientation='minus', exon_count=11, OMIM=[614717], no_hdr0=''),
    25907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25907, CurrentID=0, Status='live', Symbol='TMEM158', Aliases=['BBP', 'RIS1', 'p40BBP'], description='transmembrane protein 158', other_designations='transmembrane protein 158|40 kDa BINP-binding protein|BINP receptor|Ras induced senescence 1|brain injury-derived neurotrophic peptide (BINP) binding protein|brain specific binding protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45224466, end_position_on_the_genomic_accession=45226287, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    25909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25909, CurrentID=0, Status='live', Symbol='AHCTF1', Aliases=['ELYS', 'MST108', 'MSTP108', 'TMBS62'], description='AT-hook containing transcription factor 1', other_designations='protein ELYS|ELYS transcription factor-like protein TMBS62|embryonic large molecule derived from yolk sac|putative AT-hook-containing transcription factor 1', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=246839098, end_position_on_the_genomic_accession=246931948, orientation='minus', exon_count=39, OMIM=[610853], no_hdr0=''),
    25911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25911, CurrentID=0, Status='live', Symbol='DPCD', Aliases=[], description='deleted in primary ciliary dyskinesia homolog (mouse)', other_designations='protein DPCD|RP11-529I10.4|deleted in a mouse model of primary ciliary dyskinesia', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101588321, end_position_on_the_genomic_accession=101609662, orientation='plus', exon_count=8, OMIM=[616467], no_hdr0=''),
    25912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25912, CurrentID=0, Status='live', Symbol='C1orf43', Aliases=['HSPC012', 'NICE-3', 'NICE3', 'NS5ATP4', 'S863-3'], description='chromosome 1 open reading frame 43', other_designations='protein C1orf43|HCV NS5A-transactivated protein 4|hepatitis C virus NS5A-transactivated protein 4|uncharacterized protein C1orf43', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154206720, end_position_on_the_genomic_accession=154220590, orientation='minus', exon_count=7, OMIM=[617428], no_hdr0=''),
    25913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25913, CurrentID=0, Status='live', Symbol='POT1', Aliases=['CMM10', 'GLM9', 'HPOT1'], description='protection of telomeres 1', other_designations='protection of telomeres protein 1|POT1-like telomere end-binding protein|protection of telomeres 1 homolog', map_location='7q31.33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=124822386, end_position_on_the_genomic_accession=124929825, orientation='minus', exon_count=21, OMIM=[606478], no_hdr0=''),
    25914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25914, CurrentID=0, Status='live', Symbol='RTTN', Aliases=['MSSP'], description='rotatin', other_designations='rotatin', map_location='18q22.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=70003031, end_position_on_the_genomic_accession=70205726, orientation='minus', exon_count=55, OMIM=[610436], no_hdr0=''),
    25915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25915, CurrentID=0, Status='live', Symbol='NDUFAF3', Aliases=['2P1', 'C3orf60', 'E3-3', 'MC1DN18'], description='NADH:ubiquinone oxidoreductase complex assembly factor 3', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex assembly factor 3|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, assembly factor 3|NADH dehydrogenase (ubiquinone) complex I, assembly factor 3|nuclear protein E3-3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49020452, end_position_on_the_genomic_accession=49023495, orientation='plus', exon_count=8, OMIM=[612911], no_hdr0=''),
    25917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25917, CurrentID=0, Status='live', Symbol='THUMPD3', Aliases=[], description='THUMP domain containing 3', other_designations='THUMP domain-containing protein 3', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9362862, end_position_on_the_genomic_accession=9386791, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    25920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25920, CurrentID=0, Status='live', Symbol='NELFB', Aliases=['COBRA1', 'NELF-B'], description='negative elongation factor complex member B', other_designations='negative elongation factor B|cofactor of BRCA1|negative elongation factor protein B', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137255327, end_position_on_the_genomic_accession=137273542, orientation='plus', exon_count=13, OMIM=[611180], no_hdr0=''),
    25921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25921, CurrentID=0, Status='live', Symbol='ZDHHC5', Aliases=['DHHC5', 'ZNF375'], description='zinc finger DHHC-type palmitoyltransferase 5', other_designations='palmitoyltransferase ZDHHC5|DHHC-5|membrane-associated DHHC5 zinc finger protein|probable palmitoyltransferase ZDHHC5|zinc finger DHHC domain-containing protein 5|zinc finger DHHC-type containing 5|zinc finger protein 375|zinc finger, DHHC domain containing 5', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57668040, end_position_on_the_genomic_accession=57701187, orientation='plus', exon_count=15, OMIM=[614586], no_hdr0=''),
    25923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25923, CurrentID=0, Status='live', Symbol='ATL3', Aliases=['HSN1F'], description='atlastin GTPase 3', other_designations='atlastin-3', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63624082, end_position_on_the_genomic_accession=63671974, orientation='minus', exon_count=15, OMIM=[609369], no_hdr0=''),
    25924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25924, CurrentID=0, Status='live', Symbol='MYRIP', Aliases=['SLAC2-C', 'SLAC2C'], description='myosin VIIA and Rab interacting protein', other_designations='rab effector MyRIP|Slp homologue lacking C2 domains|exophilin-8|myosin-VIIa- and Rab-interacting protein|slp homolog lacking C2 domains c|synaptotagmin-like protein homologue lacking C2 domains-c|synaptotagmin-like protein lacking C2 domains C', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39808914, end_position_on_the_genomic_accession=40260321, orientation='plus', exon_count=20, OMIM=[611790], no_hdr0=''),
    25925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25925, CurrentID=0, Status='live', Symbol='ZNF521', Aliases=['EHZF', 'Evi3'], description='zinc finger protein 521', other_designations='zinc finger protein 521|LYST-interacting protein 3|early hematopoietic zinc finger protein', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=25061924, end_position_on_the_genomic_accession=25352194, orientation='minus', exon_count=12, OMIM=[610974], no_hdr0=''),
    25926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25926, CurrentID=0, Status='live', Symbol='NOL11', Aliases=[], description='nucleolar protein 11', other_designations='nucleolar protein 11', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67717936, end_position_on_the_genomic_accession=67744531, orientation='plus', exon_count=18, OMIM=[615366], no_hdr0=''),
    25927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25927, CurrentID=0, Status='live', Symbol='CNRIP1', Aliases=['C2orf32', 'CRIP-1', 'CRIP1'], description='cannabinoid receptor interacting protein 1', other_designations='CB1 cannabinoid receptor-interacting protein 1|cannabinoid receptor CB1-interacting protein 1', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68284171, end_position_on_the_genomic_accession=68319949, orientation='minus', exon_count=5, OMIM=[618538], no_hdr0=''),
    25928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25928, CurrentID=0, Status='live', Symbol='SOSTDC1', Aliases=['CDA019', 'DAND7', 'ECTODIN', 'USAG1'], description='sclerostin domain containing 1', other_designations='sclerostin domain-containing protein 1|cystine-knot containing secreted protein|ectodermal BMP inhibitor|uterine sensitization-associated protein-1|wise', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16461481, end_position_on_the_genomic_accession=16465738, orientation='minus', exon_count=2, OMIM=[609675], no_hdr0=''),
    25929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25929, CurrentID=0, Status='live', Symbol='GEMIN5', Aliases=['GEMIN-5', 'NEDCAM'], description='gem nuclear organelle associated protein 5', other_designations='gem-associated protein 5', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154887411, end_position_on_the_genomic_accession=154938211, orientation='minus', exon_count=28, OMIM=[607005], no_hdr0=''),
    25930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25930, CurrentID=0, Status='live', Symbol='PTPN23', Aliases=['HD-PTP', 'HDPTP', 'NEDBASS', 'PTP-TD14'], description='protein tyrosine phosphatase non-receptor type 23', other_designations='tyrosine-protein phosphatase non-receptor type 23|his domain-containing protein tyrosine phosphatase|protein tyrosine phosphatase TD14', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47381001, end_position_on_the_genomic_accession=47413435, orientation='plus', exon_count=25, OMIM=[606584], no_hdr0=''),
    25932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25932, CurrentID=0, Status='live', Symbol='CLIC4', Aliases=['CLIC4L', 'H1', 'MTCLIC', 'huH1', 'p64H1'], description='chloride intracellular channel 4', other_designations='chloride intracellular channel protein 4|chloride intracellular channel 4 like|epididymis secretory sperm binding protein|intracellular chloride ion channel protein p64H1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24745447, end_position_on_the_genomic_accession=24844321, orientation='plus', exon_count=6, OMIM=[606536], no_hdr0=''),
    25934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25934, CurrentID=0, Status='live', Symbol='NIPSNAP3A', Aliases=['HSPC299', 'NIPSNAP4', 'TASSC'], description='nipsnap homolog 3A', other_designations='protein NipSnap homolog 3A|protein NipSnap homolog 4|target for Salmonella secreted protein C', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104747683, end_position_on_the_genomic_accession=104760120, orientation='plus', exon_count=6, OMIM=[608871], no_hdr0=''),
    25936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25936, CurrentID=0, Status='live', Symbol='NSL1', Aliases=['C1orf48', 'DC8', 'MIS14'], description='NSL1 component of MIS12 kinetochore complex', other_designations='kinetochore-associated protein NSL1 homolog|NSL1, MIND kinetochore complex component, homolog|NSL1, MIS12 kinetochore complex component', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212726153, end_position_on_the_genomic_accession=212798900, orientation='minus', exon_count=10, OMIM=[609174], no_hdr0=''),
    25937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25937, CurrentID=0, Status='live', Symbol='WWTR1', Aliases=['TAZ'], description='WW domain containing transcription regulator 1', other_designations='WW domain-containing transcription regulator protein 1|transcriptional co-activator with PDZ-binding motif', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149517235, end_position_on_the_genomic_accession=149724788, orientation='minus', exon_count=13, OMIM=[607392], no_hdr0=''),
    25938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25938, CurrentID=0, Status='live', Symbol='HEATR5A', Aliases=['C14orf125', 'p200b'], description='HEAT repeat containing 5A', other_designations='HEAT repeat-containing protein 5A', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31291788, end_position_on_the_genomic_accession=31420550, orientation='minus', exon_count=36, OMIM=[], no_hdr0=''),
    25939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25939, CurrentID=0, Status='live', Symbol='SAMHD1', Aliases=['CHBL2', 'DCIP', 'HDDC1', 'MOP-5', 'SBBI88', 'hSAMHD1'], description='SAM and HD domain containing deoxynucleoside triphosphate triphosphohydrolase 1', other_designations='deoxynucleoside triphosphate triphosphohydrolase SAMHD1|SAM domain and HD domain 1|SAM domain and HD domain-containing protein 1|dNTPase|dendritic cell-derived IFNG-induced protein|monocyte protein 5', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36889773, end_position_on_the_genomic_accession=36951708, orientation='minus', exon_count=16, OMIM=[606754], no_hdr0=''),
    25940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25940, CurrentID=0, Status='live', Symbol='FAM98A', Aliases=[], description='family with sequence similarity 98 member A', other_designations='protein FAM98A', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=33583660, end_position_on_the_genomic_accession=33599299, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    25941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25941, CurrentID=0, Status='live', Symbol='TPGS2', Aliases=['C18orf10', 'HMFN0601', 'L17', 'PGs2'], description='tubulin polyglutamylase complex subunit 2', other_designations='tubulin polyglutamylase complex subunit 2', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36777647, end_position_on_the_genomic_accession=36829003, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    25942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25942, CurrentID=0, Status='live', Symbol='SIN3A', Aliases=['WITKOS'], description='SIN3 transcription regulator family member A', other_designations='paired amphipathic helix protein Sin3a|SIN3 homolog A, transcription regulator|histone deacetylase complex subunit Sin3a|transcriptional co-repressor Sin3A|transcriptional corepressor Sin3a|transcriptional regulator, SIN3A', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75369379, end_position_on_the_genomic_accession=75455819, orientation='minus', exon_count=26, OMIM=[607776], no_hdr0=''),
    25943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25943, CurrentID=0, Status='live', Symbol='DNAAF9', Aliases=['C20orf194'], description='dynein axonemal assembly factor 9', other_designations='dynein axonemal assembly factor 9|uncharacterized protein C20orf194|shulin', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3249302, end_position_on_the_genomic_accession=3407669, orientation='minus', exon_count=39, OMIM=[614146], no_hdr0=''),
    25945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25945, CurrentID=0, Status='live', Symbol='NECTIN3', Aliases=['CD113', 'CDW113', 'NECTIN-3', 'PPR3', 'PRR3', 'PVRL3', 'PVRR3'], description='nectin cell adhesion molecule 3', other_designations='nectin-3|nectin 3|poliovirus receptor-related 3|poliovirus receptor-related protein 3', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111071764, end_position_on_the_genomic_accession=111201444, orientation='plus', exon_count=14, OMIM=[607147], no_hdr0=''),
    25946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25946, CurrentID=0, Status='live', Symbol='ZNF385A', Aliases=['HZF', 'RZF', 'ZFP385', 'ZNF385'], description='zinc finger protein 385A', other_designations='zinc finger protein 385A|hematopoietic zinc finger protein|retinal zinc finger protein|zinc finger protein 385', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54369134, end_position_on_the_genomic_accession=54391610, orientation='minus', exon_count=11, OMIM=[609124], no_hdr0=''),
    25948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25948, CurrentID=0, Status='live', Symbol='KBTBD2', Aliases=['BKLHD1'], description='kelch repeat and BTB domain containing 2', other_designations='kelch repeat and BTB domain-containing protein 2|BTB and kelch domain containing 1|BTB and kelch domain-containing protein 1|kelch repeat and BTB (POZ) domain containing 2', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=32868172, end_position_on_the_genomic_accession=32892144, orientation='minus', exon_count=6, OMIM=[619393], no_hdr0=''),
    25949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25949, CurrentID=0, Status='live', Symbol='SYF2', Aliases=['CBPIN', 'NTC31', 'P29', 'fSAP29'], description='SYF2 pre-mRNA splicing factor', other_designations='pre-mRNA-splicing factor SYF2|CCNDBP1 interactor|GCIP-interacting protein p29|SYF2 homolog, RNA splicing factor|functional spliceosome-associated protein 29', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25222276, end_position_on_the_genomic_accession=25232502, orientation='minus', exon_count=7, OMIM=[607090], no_hdr0=''),
    25950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25950, CurrentID=0, Status='live', Symbol='RWDD3', Aliases=['RSUME'], description='RWD domain containing 3', other_designations='RWD domain-containing protein 3|RWD domain-containing sumoylation enhancer|RWD-containing sumoylation enhancer', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=95234155, end_position_on_the_genomic_accession=95247225, orientation='plus', exon_count=5, OMIM=[615875], no_hdr0=''),
    25953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25953, CurrentID=0, Status='live', Symbol='PNKD', Aliases=['BRP17', 'DYT8', 'FKSG19', 'FPD1', 'KIPP1184', 'MR-1', 'MR-1S', 'MR1', 'PDC', 'PKND11', 'R1', 'TAHCCP2', 'PNKD'], description='PNKD metallo-beta-lactamase domain containing', other_designations='probable hydrolase PNKD|PNKD, MBL domain containing|brain protein 17|myofibrillogenesis regulator 1|trans-activated by hepatitis C virus core protein 2', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218270485, end_position_on_the_genomic_accession=218346793, orientation='plus', exon_count=12, OMIM=[609023], no_hdr0=''),
    25956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25956, CurrentID=0, Status='live', Symbol='SEC31B', Aliases=['SEC31B-1', 'SEC31L2'], description='SEC31 homolog B, COPII coat complex component', other_designations='protein transport protein Sec31B|SEC31 homolog B, COPII coating complex component|SEC31-like 2|SEC31-like protein 2|SEC31-related protein B|secretory pathway component Sec31B-1', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100486647, end_position_on_the_genomic_accession=100519861, orientation='minus', exon_count=26, OMIM=[610258], no_hdr0=''),
    25957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25957, CurrentID=0, Status='live', Symbol='PNISR', Aliases=['C6orf111', 'HSPC306', 'SFRS18', 'SRrp130', 'bA98I9.2'], description='PNN interacting serine and arginine rich protein', other_designations='arginine/serine-rich protein PNISR|PNN-interacting serine/arginine-rich protein|SR-related protein|SR-rich protein|serine-arginine-rich-splicing regulatory protein 130|splicing factor, arginine/serine-rich 130|splicing factor, arginine/serine-rich 18', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99398050, end_position_on_the_genomic_accession=99426306, orientation='minus', exon_count=13, OMIM=[616653], no_hdr0=''),
    25959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25959, CurrentID=0, Status='live', Symbol='KANK2', Aliases=['ANKRD25', 'MXRA3', 'NPHS16', 'PPKWH', 'SIP'], description='KN motif and ankyrin repeat domains 2', other_designations='KN motif and ankyrin repeat domain-containing protein 2|SRC-interacting protein|SRC1-interacting protein|ankyrin repeat domain-containing protein 25|kidney ankyrin repeat-containing protein 2|matrix-remodeling-associated protein 3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11164270, end_position_on_the_genomic_accession=11197865, orientation='minus', exon_count=15, OMIM=[614610], no_hdr0=''),
    25960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25960, CurrentID=0, Status='live', Symbol='ADGRA2', Aliases=['GPR124', 'TEM5'], description='adhesion G protein-coupled receptor A2', other_designations='adhesion G protein-coupled receptor A2|G-protein coupled receptor 124|tumor endothelial marker 5', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37796883, end_position_on_the_genomic_accession=37844896, orientation='plus', exon_count=19, OMIM=[606823], no_hdr0=''),
    25961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25961, CurrentID=0, Status='live', Symbol='NUDT13', Aliases=[], description='nudix hydrolase 13', other_designations='NAD(P)H pyrophosphatase NUDT13, mitochondrial|nucleoside diphosphate-linked moiety X motif 13|nudix (nucleoside diphosphate linked moiety X)-type motif 13|nudix motif 13', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73110455, end_position_on_the_genomic_accession=73131827, orientation='plus', exon_count=11, OMIM=[609233], no_hdr0=''),
    25962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25962, CurrentID=0, Status='live', Symbol='VIRMA', Aliases=['KIAA1429', 'MSTP054', 'fSAP121'], description='vir like m6A methyltransferase associated', other_designations='protein virilizer homolog|functional spliceosome-associated protein 121|virilizer homolog', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94487689, end_position_on_the_genomic_accession=94553469, orientation='minus', exon_count=25, OMIM=[616447], no_hdr0=''),
    25963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25963, CurrentID=0, Status='live', Symbol='TMEM87A', Aliases=[], description='transmembrane protein 87A', other_designations='transmembrane protein 87A', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42210447, end_position_on_the_genomic_accession=42273584, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    25966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25966, CurrentID=0, Status='live', Symbol='C2CD2', Aliases=['C21orf25', 'C21orf258', 'TMEM24L'], description='C2 calcium dependent domain containing 2', other_designations='C2 domain-containing protein 2|TMEM24 related geme|transmembrane protein 24-like', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41885110, end_position_on_the_genomic_accession=41954018, orientation='minus', exon_count=17, OMIM=[617581], no_hdr0=''),
    25970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25970, CurrentID=0, Status='live', Symbol='SH2B1', Aliases=['PSM', 'SH2B'], description='SH2B adaptor protein 1', other_designations='SH2B adapter protein 1|SH2 domain-containing protein 1B|SH2 domain-containing putative adapter SH2-B|SH2-B signaling protein|pro-rich, PH and SH2 domain-containing signaling mediator', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28846606, end_position_on_the_genomic_accession=28874205, orientation='plus', exon_count=13, OMIM=[608937], no_hdr0=''),
    25972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25972, CurrentID=0, Status='live', Symbol='UNC50', Aliases=['GMH1', 'HSD23', 'PDLs22', 'UNCL', 'URP'], description='unc-50 inner nuclear membrane RNA binding protein', other_designations='protein unc-50 homolog|geal-6 membrane-associated high-copy suppressor 1|periodontal ligament-specific protein 22|protein GMH1 homolog|unc-50 related|unc-50-like protein|uncoordinated-like protein', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98608589, end_position_on_the_genomic_accession=98618515, orientation='plus', exon_count=6, OMIM=[617826], no_hdr0=''),
    25973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25973, CurrentID=0, Status='live', Symbol='PARS2', Aliases=['DEE75', 'EIEE75', 'MT-PRORS', 'proRS'], description='prolyl-tRNA synthetase 2, mitochondrial', other_designations='probable proline--tRNA ligase, mitochondrial|proline tRNA ligase 2, mitochondrial (putative)|prolyl-tRNA synthetase 2, mitochondrial (putative)', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54756898, end_position_on_the_genomic_accession=54764523, orientation='minus', exon_count=2, OMIM=[612036], no_hdr0=''),
    25974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25974, CurrentID=0, Status='live', Symbol='MMACHC', Aliases=['cblC'], description='metabolism of cobalamin associated C', other_designations='cyanocobalamin reductase / alkylcobalamin dealkylase|alkylcobalamin:glutathione S-alkyltransferase|cyanocobalamin reductase (cyanide-eliminating)|methylmalonic aciduria (cobalamin deficiency) cblC type, with homocystinuria|methylmalonic aciduria and homocystinuria type C protein', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45500229, end_position_on_the_genomic_accession=45513382, orientation='plus', exon_count=4, OMIM=[609831], no_hdr0=''),
    25975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25975, CurrentID=0, Status='live', Symbol='EGFL6', Aliases=['MAEG', 'W80'], description='EGF like domain multiple 6', other_designations='epidermal growth factor-like protein 6|EGF repeat-containing protein 6|EGF-like protein 6|MAM and EGF domain containing|MAM and EGF domains-containing gene protein', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13569601, end_position_on_the_genomic_accession=13633575, orientation='plus', exon_count=12, OMIM=[300239], no_hdr0=''),
    25976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25976, CurrentID=0, Status='live', Symbol='TIPARP', Aliases=['ARTD14', 'PARP7', 'pART14'], description='TCDD inducible poly(ADP-ribose) polymerase', other_designations='protein mono-ADP-ribosyltransferase TIPARP|ADP-ribosyltransferase diphtheria toxin-like 14|poly [ADP-ribose] polymerase 7', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=156674590, end_position_on_the_genomic_accession=156706770, orientation='plus', exon_count=8, OMIM=[612480], no_hdr0=''),
    25977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25977, CurrentID=0, Status='live', Symbol='NECAP1', Aliases=['DEE21', 'EIEE21'], description='NECAP endocytosis associated 1', other_designations='adaptin ear-binding coat-associated protein 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8082274, end_position_on_the_genomic_accession=8097881, orientation='plus', exon_count=8, OMIM=[611623], no_hdr0=''),
    25978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25978, CurrentID=0, Status='live', Symbol='CHMP2B', Aliases=['ALS17', 'CHMP2.5', 'DMT1', 'FTDALS7', 'VPS2-2', 'VPS2B'], description='charged multivesicular body protein 2B', other_designations='charged multivesicular body protein 2b|VPS2 homolog B|chromatin modifying protein 2B|vacuolar protein-sorting-associated protein 2-2', map_location='3p11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=87227309, end_position_on_the_genomic_accession=87255556, orientation='plus', exon_count=7, OMIM=[609512], no_hdr0=''),
    25979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25979, CurrentID=0, Status='live', Symbol='DHRS7B', Aliases=['CGI-93', 'SDR32C1'], description='dehydrogenase/reductase 7B', other_designations='dehydrogenase/reductase SDR family member 7B|dehydrogenase/reductase (SDR family) member 7B|short-chain dehydrogenase/reductase family 32C member 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21123368, end_position_on_the_genomic_accession=21191445, orientation='plus', exon_count=10, OMIM=[616160], no_hdr0=''),
    25980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25980, CurrentID=0, Status='live', Symbol='AAR2', Aliases=['C20orf4', 'CGI-23'], description='AAR2 splicing factor', other_designations='protein AAR2 homolog|AAR2 splicing factor homolog', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36236136, end_position_on_the_genomic_accession=36256934, orientation='plus', exon_count=5, OMIM=[617365], no_hdr0=''),
    25981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25981, CurrentID=0, Status='live', Symbol='DNAH1', Aliases=['CILD37', 'DNAHC1', 'HDHC7', 'HL-11', 'HL11', 'HSRF-1', 'SPGF18', 'XLHSRF-1'], description='dynein axonemal heavy chain 1', other_designations='dynein axonemal heavy chain 1|dynein heavy chain 1, axonemal|axonemal beta dynein heavy chain 1|ciliary dynein heavy chain 1|dynein, axonemal, heavy polypeptide 1|heat shock regulated protein 1|testicular tissue protein Li 60', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52313010, end_position_on_the_genomic_accession=52400497, orientation='plus', exon_count=80, OMIM=[603332], no_hdr0=''),
    25983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25983, CurrentID=0, Status='live', Symbol='NGDN', Aliases=['C14orf120', 'CANu1', 'LCP5', 'NGD', 'lpd-2'], description='neuroguidin', other_designations='neuroguidin|EIF4E-binding protein|centromere accumulated nuclear protein 1|eukaryotic initiation factor 4E and CPEB binding protein|neuroguidin, EIF4E binding protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23469703, end_position_on_the_genomic_accession=23478826, orientation='plus', exon_count=10, OMIM=[610777], no_hdr0=''),
    25984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25984, CurrentID=0, Status='live', Symbol='KRT23', Aliases=['CK23', 'HAIK1', 'K23'], description='keratin 23', other_designations='keratin, type I cytoskeletal 23|CK-23|cytokeratin 23|histone deacetylase inducible keratin 23|hyperacetylation-inducible type I keratin|keratin 23 (histone deacetylase inducible)|keratin 23, type I|type I intermediate filament cytokeratin', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40922696, end_position_on_the_genomic_accession=40937646, orientation='minus', exon_count=10, OMIM=[606194], no_hdr0=''),
    25987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25987, CurrentID=0, Status='live', Symbol='TSKU', Aliases=['E2IG4', 'LRRC54', 'TSK'], description='tsukushi, small leucine rich proteoglycan', other_designations='tsukushi|E2-induced gene 4 protein|leucine rich repeat containing 54|leucine-rich repeat-containing protein 54|tsukushi homolog|tsukushi small leucine rich proteoglycan homolog|tsukushin', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76782280, end_position_on_the_genomic_accession=76798144, orientation='plus', exon_count=5, OMIM=[608015], no_hdr0=''),
    25988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25988, CurrentID=0, Status='live', Symbol='HINFP', Aliases=['HiNF-P', 'MIZF', 'ZNF743'], description='histone H4 transcription factor', other_designations='histone H4 transcription factor|MBD2 (methyl-CpG-binding protein)-interacting zinc finger protein|MBD2-interacting zinc finger 1|MBD2-interacting zinc finger protein|histone H4 gene-specific protein HiNF-P|histone nuclear factor P|methyl-CpG-binding protein 2-interacting zinc finger protein', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119121577, end_position_on_the_genomic_accession=119136059, orientation='plus', exon_count=15, OMIM=[607099], no_hdr0=''),
    25989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25989, CurrentID=0, Status='live', Symbol='ULK3', Aliases=[], description='unc-51 like kinase 3', other_designations='serine/threonine-protein kinase ULK3', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74836118, end_position_on_the_genomic_accession=74843166, orientation='minus', exon_count=17, OMIM=[613472], no_hdr0=''),
    25992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25992, CurrentID=0, Status='live', Symbol='SNED1', Aliases=['IRE-BP1', 'SST3', 'Snep'], description='sushi, nidogen and EGF like domains 1', other_designations='sushi, nidogen and EGF-like domain-containing protein 1|insulin responsive sequence DNA binding protein-1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240997410, end_position_on_the_genomic_accession=241095568, orientation='plus', exon_count=38, OMIM=[616634], no_hdr0=''),
    25994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25994, CurrentID=0, Status='live', Symbol='HIGD1A', Aliases=['HIG1', 'RCF1a'], description='HIG1 hypoxia inducible domain family member 1A', other_designations='HIG1 domain family member 1A, mitochondrial|HIG1 domain family, member 1A|RCF1 homolog A|hypoxia inducible gene 1|hypoxia-inducible gene 1 protein', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42782908, end_position_on_the_genomic_accession=42804490, orientation='minus', exon_count=4, OMIM=[618623], no_hdr0=''),
    25996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25996, CurrentID=0, Status='live', Symbol='REXO2', Aliases=['CGI-114', 'REX2', 'RFN', 'SFN'], description='RNA exonuclease 2', other_designations='oligoribonuclease, mitochondrial|REX2, RNA exonuclease 2 homolog|RNA exonuclease 2 homolog|small fragment nuclease', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114439467, end_position_on_the_genomic_accession=114450279, orientation='plus', exon_count=7, OMIM=[607149], no_hdr0=''),
    25998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25998, CurrentID=0, Status='live', Symbol='IBTK', Aliases=['BTBD26', 'BTKI'], description='inhibitor of Bruton tyrosine kinase', other_designations="inhibitor of Bruton tyrosine kinase|BTK-binding protein|Bruton agammaglobulinemia tyrosine kinase inhibitor|inhibitor of Bruton's tyrosine kinase-alpha|inhibitor of Bruton's tyrosine kinase-beta|inhibitor of Bruton's tyrosine kinase-gamma", map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=82169987, end_position_on_the_genomic_accession=82247747, orientation='minus', exon_count=30, OMIM=[606457], no_hdr0=''),
    25999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=25999, CurrentID=0, Status='live', Symbol='CLIP3', Aliases=['CLIPR-59', 'CLIPR59', 'RSNL1'], description='CAP-Gly domain containing linker protein 3', other_designations='CAP-Gly domain-containing linker protein 3|CLIP-170-related 59 kDa protein|cytoplasmic linker protein 170-related 59 kDa protein|restin-like 1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36014660, end_position_on_the_genomic_accession=36032873, orientation='minus', exon_count=14, OMIM=[607382], no_hdr0=''),
    26000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26000, CurrentID=0, Status='live', Symbol='TBC1D10B', Aliases=['EPI64B', 'FP2461'], description='TBC1 domain family member 10B', other_designations='TBC1 domain family member 10B|Rab27A-GAPbeta|rab27A-GAP-beta', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30357102, end_position_on_the_genomic_accession=30370494, orientation='minus', exon_count=9, OMIM=[613620], no_hdr0=''),
    26001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26001, CurrentID=0, Status='live', Symbol='RNF167', Aliases=['5730408C10Rik', 'LP2254', 'RING105'], description='ring finger protein 167', other_designations='E3 ubiquitin-protein ligase RNF167|RING-type E3 ubiquitin transferase RNF167', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4940092, end_position_on_the_genomic_accession=4945222, orientation='plus', exon_count=12, OMIM=[610431], no_hdr0=''),
    26002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26002, CurrentID=0, Status='live', Symbol='MOXD1', Aliases=['MOX', 'PRO5780', 'dJ248E1.1'], description='monooxygenase DBH like 1', other_designations='DBH-like monooxygenase protein 1|dopamine-oxygenase|monooxygenase X', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132296055, end_position_on_the_genomic_accession=132401520, orientation='minus', exon_count=12, OMIM=[609000], no_hdr0=''),
    26003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26003, CurrentID=0, Status='live', Symbol='GORASP2', Aliases=['GOLPH6', 'GRASP55', 'GRS2', 'p59'], description='golgi reassembly stacking protein 2', other_designations='Golgi reassembly-stacking protein 2|golgi phosphoprotein 6|golgi reassembly stacking protein 2, 55kDa', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170928477, end_position_on_the_genomic_accession=170967130, orientation='plus', exon_count=11, OMIM=[608693], no_hdr0=''),
    26005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26005, CurrentID=0, Status='live', Symbol='C2CD3', Aliases=['OFD14'], description='C2 domain containing 3 centriole elongation regulator', other_designations='C2 domain-containing protein 3|C2 calcium dependent domain containing 3', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74012718, end_position_on_the_genomic_accession=74171002, orientation='minus', exon_count=34, OMIM=[615944], no_hdr0=''),
    26007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26007, CurrentID=0, Status='live', Symbol='TKFC', Aliases=['DAK', 'NET45D', 'TKFC'], description='triokinase and FMN cyclase', other_designations='triokinase/FMN cyclase|ATP-dependent dihydroxyacetone kinase|DHA kinase|Dha kinase/FMN cyclase|FAD-AMP lyase cyclic FMN forming|FAD-AMP lyase cyclizing|bifunctional ATP-dependent dihydroxyacetone kinase/FAD-AMP lyase (cyclizing)|dihydroxyacetone kinase 2 homolog|glycerone kinase|testis tissue sperm-binding protein Li 84P', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61333228, end_position_on_the_genomic_accession=61353426, orientation='plus', exon_count=22, OMIM=[615844], no_hdr0=''),
    26009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26009, CurrentID=0, Status='live', Symbol='ZZZ3', Aliases=['ATAC1'], description='zinc finger ZZ-type containing 3', other_designations='ZZ-type zinc finger-containing protein 3|ATAC component 1 homolog|zinc finger, ZZ domain containing 3', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77561526, end_position_on_the_genomic_accession=77683440, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    26010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26010, CurrentID=0, Status='live', Symbol='SPATS2L', Aliases=['DNAPTP6', 'SGNP'], description='spermatogenesis associated serine rich 2 like', other_designations='SPATS2-like protein|DNA polymerase-transactivated protein 6|stress granule and nucleolar protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200305879, end_position_on_the_genomic_accession=200482264, orientation='plus', exon_count=21, OMIM=[613817], no_hdr0=''),
    26011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26011, CurrentID=0, Status='live', Symbol='TENM4', Aliases=['Doc4', 'ETM5', 'ODZ4', 'TEN4', 'TNM4', 'Ten-M4', 'ten-4'], description='teneurin transmembrane protein 4', other_designations='teneurin-4|odz, odd Oz/ten-m homolog 4|protein Odd Oz/ten-m homolog 4|tenascin-M4', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78652829, end_position_on_the_genomic_accession=79441030, orientation='minus', exon_count=36, OMIM=[610084], no_hdr0=''),
    26012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26012, CurrentID=0, Status='live', Symbol='NSMF', Aliases=['HH9', 'NELF'], description='NMDA receptor synaptonuclear signaling and neuronal migration factor', other_designations='NMDA receptor synaptonuclear signaling and neuronal migration factor|nasal embryonic LHRH factor|nasal embryonic luteinizing hormone-releasing hormone factor', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137447570, end_position_on_the_genomic_accession=137459334, orientation='minus', exon_count=17, OMIM=[608137], no_hdr0=''),
    26013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26013, CurrentID=0, Status='live', Symbol='L3MBTL1', Aliases=['H-L(3)MBT', 'L3MBTL', 'ZC2HC3', 'dJ138B7.3'], description='L3MBTL histone methyl-lysine binding protein 1', other_designations='lethal(3)malignant brain tumor-like protein 1|L3MBTL1, histone methyl-lysine binding protein|l(3)mbt protein homolog|l(3)mbt-like 1|lethal (3) malignant brain tumor l(3)', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43507697, end_position_on_the_genomic_accession=43550954, orientation='plus', exon_count=24, OMIM=[608802], no_hdr0=''),
    26015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26015, CurrentID=0, Status='live', Symbol='RPAP1', Aliases=[], description='RNA polymerase II associated protein 1', other_designations='RNA polymerase II-associated protein 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41517176, end_position_on_the_genomic_accession=41544257, orientation='minus', exon_count=25, OMIM=[611475], no_hdr0=''),
    26017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26017, CurrentID=0, Status='live', Symbol='FAM32A', Aliases=['OTAG-12', 'OTAG12'], description='family with sequence similarity 32 member A', other_designations='protein FAM32A|ovarian tumor associated gene-12', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16185184, end_position_on_the_genomic_accession=16192046, orientation='plus', exon_count=4, OMIM=[614554], no_hdr0=''),
    26018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26018, CurrentID=0, Status='live', Symbol='LRIG1', Aliases=['LIG-1', 'LIG1'], description='leucine rich repeats and immunoglobulin like domains 1', other_designations='leucine-rich repeats and immunoglobulin-like domains protein 1|leucine-rich repeat protein LRIG1|ortholog of mouse integral membrane glycoprotein LIG-1', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=66378797, end_position_on_the_genomic_accession=66501121, orientation='minus', exon_count=23, OMIM=[608868], no_hdr0=''),
    26019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26019, CurrentID=0, Status='live', Symbol='UPF2', Aliases=['HUPF2', 'RENT2', 'smg-3'], description='UPF2 regulator of nonsense mediated mRNA decay', other_designations='regulator of nonsense transcripts 2|FRS2/UPF2/LEMD3 fusion|LEMD3/UPF2 fusion|UPF2 regulator of nonsense transcripts homolog|nonsense mRNA reducing factor 2|smg-3 homolog, nonsense mediated mRNA decay factor|up-frameshift suppressor 2 homolog|yeast Upf2p homolog', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=11920022, end_position_on_the_genomic_accession=12043170, orientation='minus', exon_count=24, OMIM=[605529], no_hdr0=''),
    26020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26020, CurrentID=0, Status='live', Symbol='LRP10', Aliases=['LRP-10', 'LRP9', 'MST087', 'MSTP087'], description='LDL receptor related protein 10', other_designations='low-density lipoprotein receptor-related protein 10', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22871613, end_position_on_the_genomic_accession=22881713, orientation='plus', exon_count=7, OMIM=[609921], no_hdr0=''),
    26022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26022, CurrentID=0, Status='live', Symbol='TMEM98', Aliases=['TADA1'], description='transmembrane protein 98', other_designations='transmembrane protein 98', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32928153, end_position_on_the_genomic_accession=32944315, orientation='plus', exon_count=9, OMIM=[615949], no_hdr0=''),
    26024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26024, CurrentID=0, Status='live', Symbol='PTCD1', Aliases=[], description='pentatricopeptide repeat domain 1', other_designations='pentatricopeptide repeat-containing protein 1, mitochondrial', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99416739, end_position_on_the_genomic_accession=99438798, orientation='minus', exon_count=8, OMIM=[614774], no_hdr0=''),
    26025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26025, CurrentID=0, Status='live', Symbol='PCDHGA12', Aliases=['CDH21', 'FIB3', 'PCDH-GAMMA-A12'], description='protocadherin gamma subfamily A, 12', other_designations='protocadherin gamma-A12|cadherin 21|fibroblast cadherin FIB3|fibroblast cadherin-3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141430507, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[603059], no_hdr0=''),
    26027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26027, CurrentID=0, Status='live', Symbol='ACOT11', Aliases=['BFIT', 'STARD14', 'THEA', 'THEM1'], description='acyl-CoA thioesterase 11', other_designations='acyl-coenzyme A thioesterase 11|START domain containing 14|StAR-related lipid transfer (START) domain containing 14|acyl-CoA thioester hydrolase 11|adipose-associated thioesterase|brown fat-inducible thioesterase|palmitoyl-coenzyme A thioesterase|thioesterase superfamily member 1|thioesterase, adipose associated', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54548228, end_position_on_the_genomic_accession=54639192, orientation='plus', exon_count=18, OMIM=[606803], no_hdr0=''),
    26030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26030, CurrentID=0, Status='live', Symbol='PLEKHG3', Aliases=['ARHGEF43', 'KIAA0599'], description='pleckstrin homology and RhoGEF domain containing G3', other_designations='pleckstrin homology domain-containing family G member 3|PH domain-containing family G member 3|pleckstrin homology domain containing, family G (with RhoGef domain) member 3|pleckstrin homology domain containing, family G, member 3', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64704128, end_position_on_the_genomic_accession=64750249, orientation='plus', exon_count=25, OMIM=[617940], no_hdr0=''),
    26031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26031, CurrentID=0, Status='live', Symbol='OSBPL3', Aliases=['ORP-3', 'ORP3', 'OSBP3'], description='oxysterol binding protein like 3', other_designations='oxysterol-binding protein-related protein 3|OSBP-related protein 3', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=24796537, end_position_on_the_genomic_accession=24980218, orientation='minus', exon_count=26, OMIM=[606732], no_hdr0=''),
    26032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26032, CurrentID=0, Status='live', Symbol='SUSD5', Aliases=[], description='sushi domain containing 5', other_designations='sushi domain-containing protein 5', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33150041, end_position_on_the_genomic_accession=33218952, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    26033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26033, CurrentID=0, Status='live', Symbol='ATRNL1', Aliases=['ALP', 'bA338L11.1', 'bA454H24.1'], description='attractin like 1', other_designations='attractin-like protein 1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=115093365, end_position_on_the_genomic_accession=115948999, orientation='plus', exon_count=38, OMIM=[612869], no_hdr0=''),
    26034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26034, CurrentID=0, Status='live', Symbol='IPCEF1', Aliases=['PIP3-E'], description='interaction protein for cytohesin exchange factors 1', other_designations='interactor protein for cytohesin exchange factors 1|interaction protein for cytohesin exchange factors 1 Interaction protein for cytohesin exchange factors 1|phosphoinositide-binding protein PIP3-E', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=154154496, end_position_on_the_genomic_accession=154356803, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    26035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26035, CurrentID=0, Status='live', Symbol='GLCE', Aliases=['HSEPI'], description='glucuronic acid epimerase', other_designations='D-glucuronyl C5-epimerase|UDP-glucuronic acid epimerase|glucuronyl C5-epimerase|heparan sulfate C5-epimerase|heparan sulfate epimerase|heparin/heparan sulfate-glucuronic acid C5-epimerase|heparosan-N-sulfate-glucuronate 5-epimerase', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=69160555, end_position_on_the_genomic_accession=69272209, orientation='plus', exon_count=10, OMIM=[612134], no_hdr0=''),
    26036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26036, CurrentID=0, Status='live', Symbol='ZNF451', Aliases=['COASTER', 'dJ417I1.1'], description='zinc finger protein 451', other_designations='E3 SUMO-protein ligase ZNF451|E3 SUMO-protein transferase ZNF451|coactivator for steroid receptors', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=57088970, end_position_on_the_genomic_accession=57170305, orientation='plus', exon_count=19, OMIM=[615708], no_hdr0=''),
    26037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26037, CurrentID=0, Status='live', Symbol='SIPA1L1', Aliases=['E6TP1', 'SPAR1'], description='signal induced proliferation associated 1 like 1', other_designations='signal-induced proliferation-associated 1-like protein 1|SIPA1-like protein 1|high-risk human papilloma viruses E6 oncoproteins targeted protein 1|spine-associated RapGAP 1', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=71320418, end_position_on_the_genomic_accession=71741209, orientation='plus', exon_count=37, OMIM=[617504], no_hdr0=''),
    26038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26038, CurrentID=0, Status='live', Symbol='CHD5', Aliases=['CHD-5'], description='chromodomain helicase DNA binding protein 5', other_designations='chromodomain-helicase-DNA-binding protein 5|ATP-dependent helicase CHD5', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6101787, end_position_on_the_genomic_accession=6180321, orientation='minus', exon_count=42, OMIM=[610771], no_hdr0=''),
    26039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26039, CurrentID=0, Status='live', Symbol='SS18L1', Aliases=['CREST', 'LP2261'], description='SS18L1 subunit of BAF chromatin remodeling complex', other_designations='calcium-responsive transactivator|SS18-like protein 1|SS18L1, nBAF chromatin remodeling complex subunit|SYT homolog 1|synovial sarcoma translocation gene on chromosome 18-like 1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62143765, end_position_on_the_genomic_accession=62182514, orientation='plus', exon_count=15, OMIM=[606472], no_hdr0=''),
    26040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26040, CurrentID=0, Status='live', Symbol='SETBP1', Aliases=['MRD29', 'SEB'], description='SET binding protein 1', other_designations='SET-binding protein', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=44680072, end_position_on_the_genomic_accession=45068510, orientation='plus', exon_count=15, OMIM=[611060], no_hdr0=''),
    26043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26043, CurrentID=0, Status='live', Symbol='UBXN7', Aliases=['UBXD7'], description='UBX domain protein 7', other_designations='UBX domain-containing protein 7|UBX domain containing 7', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196347659, end_position_on_the_genomic_accession=196454323, orientation='minus', exon_count=12, OMIM=[616379], no_hdr0=''),
    26045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26045, CurrentID=0, Status='live', Symbol='LRRTM2', Aliases=[], description='leucine rich repeat transmembrane neuronal 2', other_designations='leucine-rich repeat transmembrane neuronal protein 2|leucine-rich repeat neuronal 2 protein|leucine-rich repeat transmembrane neuronal 2 protein', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138868921, end_position_on_the_genomic_accession=138875335, orientation='minus', exon_count=2, OMIM=[610868], no_hdr0=''),
    26046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26046, CurrentID=0, Status='live', Symbol='LTN1', Aliases=['C21orf10', 'C21orf98', 'RNF160', 'ZNF294'], description='listerin E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase listerin|RING-type E3 ubiquitin transferase listerin|ring finger protein 160|zinc finger protein 294', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=28928144, end_position_on_the_genomic_accession=28992988, orientation='minus', exon_count=31, OMIM=[613083], no_hdr0=''),
    26047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26047, CurrentID=0, Status='live', Symbol='CNTNAP2', Aliases=['AUTS15', 'CASPR2', 'CDFE', 'NRXN4', 'PTHSL1'], description='contactin associated protein 2', other_designations='contactin-associated protein-like 2|cell recognition molecule Caspr2|contactin associated protein like 2|homolog of Drosophila neurexin IV', map_location='7q35-q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=146116207, end_position_on_the_genomic_accession=148420998, orientation='plus', exon_count=25, OMIM=[604569], no_hdr0=''),
    26048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26048, CurrentID=0, Status='live', Symbol='ZNF500', Aliases=['ZKSCAN18', 'ZSCAN50'], description='zinc finger protein 500', other_designations='zinc finger protein 500|zinc finger protein with KRAB and SCAN domains 18', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4745961, end_position_on_the_genomic_accession=4767219, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    26049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26049, CurrentID=0, Status='live', Symbol='FAM169A', Aliases=['SLAP75'], description='family with sequence similarity 169 member A', other_designations='soluble lamin-associated protein of 75 kDa|protein FAM169A|soluble lamina-associated protein of 75 kD', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=74777574, end_position_on_the_genomic_accession=74867994, orientation='minus', exon_count=15, OMIM=[615769], no_hdr0=''),
    26050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26050, CurrentID=0, Status='live', Symbol='SLITRK5', Aliases=['LRRC11', 'bA364G4.2'], description='SLIT and NTRK like family member 5', other_designations='SLIT and NTRK-like protein 5|leucine rich repeat containing 11|leucine-rich repeat-containing protein 11|slit and trk like gene 5', map_location='13q31.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=87671371, end_position_on_the_genomic_accession=87679616, orientation='plus', exon_count=4, OMIM=[609680], no_hdr0=''),
    26051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26051, CurrentID=0, Status='live', Symbol='PPP1R16B', Aliases=['ANKRD4', 'TIMAP'], description='protein phosphatase 1 regulatory subunit 16B', other_designations='protein phosphatase 1 regulatory inhibitor subunit 16B|CAAX box protein TIMAP|TGF-beta-inhibited membrane-associated protein|ankyrin repeat domain protein 4|ankyrin repeat domain-containing protein 4|hTIMAP|protein phosphatase 1, regulatory (inhibitor) subunit 16B', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38805694, end_position_on_the_genomic_accession=38923024, orientation='plus', exon_count=12, OMIM=[613275], no_hdr0=''),
    26052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26052, CurrentID=0, Status='live', Symbol='DNM3', Aliases=['Dyna III'], description='dynamin 3', other_designations='dynamin-3|T-dynamin|dynamin family member|dynamin, testicular', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171841495, end_position_on_the_genomic_accession=172418466, orientation='plus', exon_count=31, OMIM=[611445], no_hdr0=''),
    26053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26053, CurrentID=0, Status='live', Symbol='AUTS2', Aliases=['FBRSL2', 'MRD26'], description='activator of transcription and developmental regulator AUTS2', other_designations='autism susceptibility gene 2 protein|AUTS2, activator of transcription and developmental regulator|autism susceptibility candidate 2|autism-related protein 1', map_location='7q11.22', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=69598475, end_position_on_the_genomic_accession=70793506, orientation='plus', exon_count=23, OMIM=[607270], no_hdr0=''),
    26054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26054, CurrentID=0, Status='live', Symbol='SENP6', Aliases=['SSP1', 'SUSP1'], description='SUMO specific peptidase 6', other_designations='sentrin-specific protease 6|2810017C20Rik|SUMO-1-specific protease 1|SUMO1/sentrin specific peptidase 6|SUMO1/sentrin specific protease 6|sentrin/SUMO-specific protease SENP6', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75601864, end_position_on_the_genomic_accession=75718281, orientation='plus', exon_count=27, OMIM=[605003], no_hdr0=''),
    26056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26056, CurrentID=0, Status='live', Symbol='RAB11FIP5', Aliases=['GAF1', 'RIP11', 'gaf-1', 'pp75', 'rab11-FIP5'], description='RAB11 family interacting protein 5', other_designations='rab11 family-interacting protein 5|RAB11 family interacting protein 5 (class I)|gamma-SNAP-associated factor 1|phosphoprotein pp75|rab11-interacting protein Rip11', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73073382, end_position_on_the_genomic_accession=73112948, orientation='minus', exon_count=6, OMIM=[605536], no_hdr0=''),
    26057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26057, CurrentID=0, Status='live', Symbol='ANKRD17', Aliases=['GTAR', 'MASK2', 'NY-BR-16'], description='ankyrin repeat domain 17', other_designations='ankyrin repeat domain-containing protein 17|gene trap ankyrin repeat protein|serologically defined breast cancer antigen NY-BR-16', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73073376, end_position_on_the_genomic_accession=73259766, orientation='minus', exon_count=37, OMIM=[615929], no_hdr0=''),
    26058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26058, CurrentID=0, Status='live', Symbol='GIGYF2', Aliases=['GYF2', 'PARK11', 'PERQ2', 'PERQ3', 'TNRC15'], description='GRB10 interacting GYF protein 2', other_designations='GRB10-interacting GYF protein 2|PERQ amino acid rich, with GYF domain 3|PERQ amino acid-rich with GYF domain-containing protein 2|Parkinson disease (autosomal recessive, early onset) 11|trinucleotide repeat-containing gene 15 protein', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232697331, end_position_on_the_genomic_accession=232860605, orientation='plus', exon_count=35, OMIM=[612003], no_hdr0=''),
    26059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26059, CurrentID=0, Status='live', Symbol='ERC2', Aliases=['CAST', 'CAST1', 'ELKSL', 'SPBC110', 'Spc110'], description='ELKS/RAB6-interacting/CAST family member 2', other_designations='ERC protein 2|CAZ-associated structural protein|cytomatrix protein p110', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=55508311, end_position_on_the_genomic_accession=56468473, orientation='minus', exon_count=23, OMIM=[617250], no_hdr0=''),
    26060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26060, CurrentID=0, Status='live', Symbol='APPL1', Aliases=['APPL', 'DIP13alpha', 'MODY14'], description='adaptor protein, phosphotyrosine interacting with PH domain and leucine zipper 1', other_designations='DCC-interacting protein 13-alpha|AKT2 interactor|adapter protein containing PH domain, PTB domain and leucine zipper motif 1|adaptor protein containing pH domain, PTB domain and leucine zipper motif 1|adaptor protein, phosphotyrosine interaction, PH domain and leucine zipper containing 1|dip13-alpha|signaling adaptor protein DIP13alpha', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57227729, end_position_on_the_genomic_accession=57273471, orientation='plus', exon_count=23, OMIM=[604299], no_hdr0=''),
    26061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26061, CurrentID=0, Status='live', Symbol='HACL1', Aliases=['2-HPCL', 'HPCL', 'HPCL2', 'PHYH2'], description='2-hydroxyacyl-CoA lyase 1', other_designations='2-hydroxyacyl-CoA lyase 1|1600020H07Rik|2-hydroxyphytanol-CoA lyase|2-hydroxyphytanoyl-CoA lyase|phytanoyl-CoA 2-hydroxylase 2|phytanoyl-CoA hydroxylase 2', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15560699, end_position_on_the_genomic_accession=15601569, orientation='minus', exon_count=17, OMIM=[604300], no_hdr0=''),
    26063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26063, CurrentID=0, Status='live', Symbol='DECR2', Aliases=['PDCR', 'SDR17C1'], description='2,4-dienoyl-CoA reductase 2', other_designations='peroxisomal 2,4-dienoyl-CoA reductase [(3E)-enoyl-CoA-producing]|2,4-dienoyl-CoA reductase 2, peroxisomal|peroxisomal 2,4-dienoyl-CoA reductase|short chain dehydrogenase/reductase family 17C member 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=401885, end_position_on_the_genomic_accession=412482, orientation='plus', exon_count=9, OMIM=[615839], no_hdr0=''),
    26064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26064, CurrentID=0, Status='live', Symbol='RAI14', Aliases=['NORPEG', 'RAI13'], description='retinoic acid induced 14', other_designations='ankycorbin|ankyrin repeat and coiled-coil structure-containing protein|novel retinal pigment epithelial cell protein|retinoic acid-induced protein 14', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34656303, end_position_on_the_genomic_accession=34832612, orientation='plus', exon_count=29, OMIM=[606586], no_hdr0=''),
    26065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26065, CurrentID=0, Status='live', Symbol='LSM14A', Aliases=['C19orf13', 'FAM61A', 'RAP55', 'RAP55A'], description='LSM14A mRNA processing body assembly factor', other_designations='protein LSM14 homolog A|LSM14 homolog A|LSM14A, SCD6 homolog A|RNA-associated protein 55|RNA-associated protein 55A|alphaSNBP|family with sequence similarity 61, member A|hRAP55|hRAP55A|protein SCD6 homolog|putative alpha-synuclein-binding protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34172499, end_position_on_the_genomic_accession=34229288, orientation='plus', exon_count=15, OMIM=[610677], no_hdr0=''),
    26071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26071, CurrentID=0, Status='live', Symbol='RTL8A', Aliases=['CXX1b', 'FAM127B', 'MAR8A', 'SIRH6'], description='retrotransposon Gag like 8A', other_designations='retrotransposon Gag-like protein 8A|Sushi-Ichi retrotransposon homolog 6|family with sequence similarity 127 member B|mammalian retrotransposon derived protein 8A|mammalian retrotransposon-derived 8A|protein FAM127B', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135050932, end_position_on_the_genomic_accession=135052135, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26073, CurrentID=0, Status='live', Symbol='POLDIP2', Aliases=['PDIP38', 'POLD4', 'p38'], description='DNA polymerase delta interacting protein 2', other_designations='polymerase delta-interacting protein 2|38 kDa DNA polymerase delta interaction protein|polymerase (DNA) delta interacting protein 2|polymerase (DNA-directed), delta interacting protein 2|polymerase delta interacting protein 38', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28346633, end_position_on_the_genomic_accession=28357527, orientation='minus', exon_count=11, OMIM=[611519], no_hdr0=''),
    26074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26074, CurrentID=0, Status='live', Symbol='CFAP61', Aliases=['C20orf26', 'CaM-IP3', 'dJ1002M8.3', 'dJ1178H5.4'], description='cilia and flagella associated protein 61', other_designations='cilia- and flagella-associated protein 61', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=20052514, end_position_on_the_genomic_accession=20360714, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    26083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26083, CurrentID=0, Status='live', Symbol='TBC1D29P', Aliases=['TBC1D29'], description='TBC1 domain family member 29, pseudogene', other_designations='putative TBC1 domain family member 29|TBC1 domain family, member 29', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30559640, end_position_on_the_genomic_accession=30565667, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    26084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26084, CurrentID=0, Status='live', Symbol='ARHGEF26', Aliases=['CSGEF', 'HMFN1864', 'SGEF'], description='Rho guanine nucleotide exchange factor 26', other_designations='rho guanine nucleotide exchange factor 26|Rho guanine nucleotide exchange factor (GEF) 26|SH3 domain-containing guanine exchange factor|Src homology 3 domain-containing guanine nucleotide exchange factor|testicular tissue protein Li 171', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=154121003, end_position_on_the_genomic_accession=154257827, orientation='plus', exon_count=17, OMIM=[617552], no_hdr0=''),
    26085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26085, CurrentID=0, Status='live', Symbol='KLK13', Aliases=['KLK-L4', 'KLKL4'], description='kallikrein related peptidase 13', other_designations='kallikrein-13|kallikrein-like gene 4|kallikrein-like protein 4', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51055626, end_position_on_the_genomic_accession=51065106, orientation='minus', exon_count=7, OMIM=[605505], no_hdr0=''),
    26086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26086, CurrentID=0, Status='live', Symbol='GPSM1', Aliases=['AGS3'], description='G protein signaling modulator 1', other_designations='G-protein-signaling modulator 1|G-protein signalling modulator 1 (AGS3-like, C. elegans)|activator of G-protein signaling 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136327539, end_position_on_the_genomic_accession=136359605, orientation='plus', exon_count=18, OMIM=[609491], no_hdr0=''),
    26088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26088, CurrentID=0, Status='live', Symbol='GGA1', Aliases=[], description='golgi associated, gamma adaptin ear containing, ARF binding protein 1', other_designations='ADP-ribosylation factor-binding protein GGA1|ADP-ribosylation factor binding protein 1|gamma-adaptin related protein 1|golgi-localized, gamma ear-containing, ARF-binding protein 1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37608474, end_position_on_the_genomic_accession=37633564, orientation='plus', exon_count=20, OMIM=[606004], no_hdr0=''),
    26090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26090, CurrentID=0, Status='live', Symbol='ABHD12', Aliases=['ABHD12A', 'BEM46L2', 'C20orf22', 'PHARC', 'dJ965G21.2', 'hABHD12'], description='abhydrolase domain containing 12, lysophospholipase', other_designations='lysophosphatidylserine lipase ABHD12|2-arachidonoylglycerol hydrolase ABHD12|abhydrolase domain-containing protein 12|monoacylglycerol lipase ABHD12|oxidized phosphatidylserine lipase ABHD12', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25294743, end_position_on_the_genomic_accession=25390835, orientation='minus', exon_count=16, OMIM=[613599], no_hdr0=''),
    26091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26091, CurrentID=0, Status='live', Symbol='HERC4', Aliases=[], description='HECT and RLD domain containing E3 ubiquitin protein ligase 4', other_designations='probable E3 ubiquitin-protein ligase HERC4|HECT domain and RCC1-like domain-containing protein 4|HECT-type E3 ubiquitin transferase HERC4|hect domain and RLD 4', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=67921905, end_position_on_the_genomic_accession=68075324, orientation='minus', exon_count=32, OMIM=[609248], no_hdr0=''),
    26092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26092, CurrentID=0, Status='live', Symbol='TOR1AIP1', Aliases=['LAP1', 'LAP1B', 'LAP1C', 'LGMD2Y'], description='torsin 1A interacting protein 1', other_designations='torsin-1A-interacting protein 1|lamin-associated protein 1B|lamina-associated polypeptide 1B|torsin A interacting protein 1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179882285, end_position_on_the_genomic_accession=179920076, orientation='plus', exon_count=10, OMIM=[614512], no_hdr0=''),
    26093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26093, CurrentID=0, Status='live', Symbol='CCDC9', Aliases=[], description='coiled-coil domain containing 9', other_designations='coiled-coil domain-containing protein 9', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47256525, end_position_on_the_genomic_accession=47271958, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    26094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26094, CurrentID=0, Status='live', Symbol='DCAF4', Aliases=['WDR21', 'WDR21A'], description='DDB1 and CUL4 associated factor 4', other_designations='DDB1- and CUL4-associated factor 4|WD repeat domain 21A|WD repeat-containing protein 21A', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=72926337, end_position_on_the_genomic_accession=72962098, orientation='plus', exon_count=18, OMIM=[616372], no_hdr0=''),
    26095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26095, CurrentID=0, Status='live', Symbol='PTPN20', Aliases=['CT126A', 'PTPN20B', 'bA142I17.1', 'bA42B19.1', 'PTPN20'], description='protein tyrosine phosphatase non-receptor type 20', other_designations='tyrosine-protein phosphatase non-receptor type 20|protein tyrosine phosphatase, non-receptor type 20A|protein tyrosine phosphatase, non-receptor type 20B', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46911372, end_position_on_the_genomic_accession=47003829, orientation='plus', exon_count=17, OMIM=[610630, 610631], no_hdr0=''),
    26097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26097, CurrentID=0, Status='live', Symbol='CHTOP', Aliases=['C10orf77', 'C1orf77', 'FL-SRAG', 'FOP', 'SRAG', 'SRAG-3', 'SRAG-5', 'pp7704'], description='chromatin target of PRMT1', other_designations='chromatin target of PRMT1 protein|friend of PRMT1 protein|small protein rich in arginine and glycine', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153634066, end_position_on_the_genomic_accession=153646306, orientation='plus', exon_count=6, OMIM=[614206], no_hdr0=''),
    26098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26098, CurrentID=0, Status='live', Symbol='EDRF1', Aliases=['C10orf137'], description='erythroid differentiation regulatory factor 1', other_designations='erythroid differentiation-related factor 1', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125719547, end_position_on_the_genomic_accession=125764143, orientation='plus', exon_count=27, OMIM=[], no_hdr0=''),
    26099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26099, CurrentID=0, Status='live', Symbol='SZRD1', Aliases=['C1orf144'], description='SUZ RNA binding domain containing 1', other_designations='SUZ domain-containing protein 1|UPF0485 protein C1orf144|putative MAPK activating protein PM20,PM21|putative MAPK-activating protein PM18/PM20/PM22', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16367242, end_position_on_the_genomic_accession=16398145, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    26100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26100, CurrentID=0, Status='live', Symbol='WIPI2', Aliases=['ATG18B', 'Atg21', 'CGI-50', 'IDDSSA', 'WIPI-2'], description='WD repeat domain, phosphoinositide interacting 2', other_designations='WD repeat domain phosphoinositide-interacting protein 2|WD40 repeat protein interacting with phosphoinositides 2|WIPI49-like protein 2', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5190233, end_position_on_the_genomic_accession=5233855, orientation='plus', exon_count=13, OMIM=[609225], no_hdr0=''),
    26103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26103, CurrentID=0, Status='live', Symbol='LRIT1', Aliases=['FIGLER9', 'LRRC21', 'PAL'], description='leucine rich repeat, Ig-like and transmembrane domains 1', other_designations='leucine-rich repeat, immunoglobulin-like domain and transmembrane domain-containing protein 1|fibronectin type III, immunoglobulin and leucine rich repeat domains 9|leucine rich repeat containing 21|leucine-rich repeat, immunoglobulin-like and transmembrane domains 1|leucine-rich repeat-containing protein 21|photoreceptor-associated LRR superfamily protein|retina-specific protein PAL', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84231520, end_position_on_the_genomic_accession=84241546, orientation='minus', exon_count=5, OMIM=[616103], no_hdr0=''),
    26108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26108, CurrentID=0, Status='live', Symbol='PYGO1', Aliases=[], description='pygopus family PHD finger 1', other_designations='pygopus homolog 1|pygopus-like protein 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55538884, end_position_on_the_genomic_accession=55588971, orientation='minus', exon_count=4, OMIM=[606902], no_hdr0=''),
    26112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26112, CurrentID=0, Status='live', Symbol='CCDC69', Aliases=[], description='coiled-coil domain containing 69', other_designations='coiled-coil domain-containing protein 69', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151181052, end_position_on_the_genomic_accession=151224092, orientation='minus', exon_count=9, OMIM=[619288], no_hdr0=''),
    26115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26115, CurrentID=0, Status='live', Symbol='TANC2', Aliases=['IDDALDS', 'ROLSA', 'rols'], description='tetratricopeptide repeat, ankyrin repeat and coiled-coil containing 2', other_designations='protein TANC2|putative ankyrin-repeat containing protein|rolling pebbles homolog B|tetratricopeptide repeat, ankyrin repeat and coiled-coil domain-containing protein 2', map_location='17q23.2-q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62966235, end_position_on_the_genomic_accession=63427706, orientation='plus', exon_count=31, OMIM=[615047], no_hdr0=''),
    26118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26118, CurrentID=0, Status='live', Symbol='WSB1', Aliases=['SWIP1', 'WSB-1'], description='WD repeat and SOCS box containing 1', other_designations='WD repeat and SOCS box-containing protein 1|SOCS box-containing WD protein SWiP-1', map_location='17q11.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=27294080, end_position_on_the_genomic_accession=27315926, orientation='plus', exon_count=10, OMIM=[610091], no_hdr0=''),
    26119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26119, CurrentID=0, Status='live', Symbol='LDLRAP1', Aliases=['ARH', 'ARH1', 'ARH2', 'FHCB1', 'FHCB2', 'FHCL4'], description='low density lipoprotein receptor adaptor protein 1', other_designations='low density lipoprotein receptor adapter protein 1|LDL receptor adaptor protein|autosomal recessive hypercholesterolemia protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25543588, end_position_on_the_genomic_accession=25590400, orientation='plus', exon_count=16, OMIM=[605747], no_hdr0=''),
    26121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26121, CurrentID=0, Status='live', Symbol='PRPF31', Aliases=['NY-BR-99', 'PRP31', 'RP11', 'SNRNP61'], description='pre-mRNA processing factor 31', other_designations='U4/U6 small nuclear ribonucleoprotein Prp31|PRP31 pre-mRNA processing factor 31 homolog|U4/U6 snRNP 61 kDa protein|hPrp31|protein 61K|serologically defined breast cancer antigen NY-BR-99', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54115706, end_position_on_the_genomic_accession=54131719, orientation='plus', exon_count=13, OMIM=[606419], no_hdr0=''),
    26122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26122, CurrentID=0, Status='live', Symbol='EPC2', Aliases=['EPC-LIKE'], description='enhancer of polycomb homolog 2', other_designations='enhancer of polycomb homolog 2', map_location='2q23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=148644751, end_position_on_the_genomic_accession=148788491, orientation='plus', exon_count=15, OMIM=[611000], no_hdr0=''),
    26123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26123, CurrentID=0, Status='live', Symbol='TCTN3', Aliases=['C10orf61', 'JBTS18', 'OFD4', 'TECT3'], description='tectonic family member 3', other_designations='tectonic-3', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95663401, end_position_on_the_genomic_accession=95693954, orientation='minus', exon_count=14, OMIM=[613847], no_hdr0=''),
    26127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26127, CurrentID=0, Status='live', Symbol='FGFR1OP2', Aliases=['HSPC123-like', 'WIT3.0'], description='FGFR1 oncogene partner 2', other_designations='FGFR1 oncogene partner 2|fibroblast growth factor receptor 1 oncogene partner 2|wound inducible transcript 3.0', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26938470, end_position_on_the_genomic_accession=26966648, orientation='plus', exon_count=7, OMIM=[608858], no_hdr0=''),
    26128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26128, CurrentID=0, Status='live', Symbol='KIFBP', Aliases=['KBP', 'KIAA1279', 'KIF1BP', 'TTC20'], description='kinesin family binding protein', other_designations='KIF-binding protein|KIF1 binding protein|kinesin binding protein|mutant KIF1 binding protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68988803, end_position_on_the_genomic_accession=69016982, orientation='plus', exon_count=8, OMIM=[609367], no_hdr0=''),
    26130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26130, CurrentID=0, Status='live', Symbol='GAPVD1', Aliases=['GAPEX5', 'GAPex-5', 'RAP6'], description='GTPase activating protein and VPS9 domains 1', other_designations='GTPase-activating protein and VPS9 domain-containing protein 1|Rab5 exchange factor|Rab5-activating protein 6', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125261794, end_position_on_the_genomic_accession=125367207, orientation='plus', exon_count=32, OMIM=[611714], no_hdr0=''),
    26133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26133, CurrentID=0, Status='live', Symbol='TRPC4AP', Aliases=['C20orf188', 'PPP1R158', 'TRRP4AP', 'TRUSS'], description='transient receptor potential cation channel subfamily C member 4 associated protein', other_designations='short transient receptor potential channel 4-associated protein|TNF-receptor ubiquitous scaffolding/signaling protein|TRP4-associated protein|protein phosphatase 1, regulatory subunit 158|trpc4-associated protein|tumor necrosis factor receptor-associated ubiquitous scaffolding and signaling protein', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35002404, end_position_on_the_genomic_accession=35092835, orientation='minus', exon_count=22, OMIM=[608430], no_hdr0=''),
    26135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26135, CurrentID=0, Status='live', Symbol='SERBP1', Aliases=['CGI-55', 'CHD3IP', 'HABP4L', 'PAI-RBP1', 'PAIRBP1'], description='SERPINE1 mRNA binding protein 1', other_designations='plasminogen activator inhibitor 1 RNA-binding protein|PAI-1 mRNA binding protein|PAI1 RNA-binding protein 1|chromodomain helicase DNA binding protein 3 interacting protein', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67407810, end_position_on_the_genomic_accession=67430402, orientation='minus', exon_count=8, OMIM=[607378], no_hdr0=''),
    26136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26136, CurrentID=0, Status='live', Symbol='TES', Aliases=['TESSS-2', 'TES'], description='testin LIM domain protein', other_designations='testin|testis derived transcript (3 LIM domains)', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=116210539, end_position_on_the_genomic_accession=116258786, orientation='plus', exon_count=8, OMIM=[606085], no_hdr0=''),
    26137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26137, CurrentID=0, Status='live', Symbol='ZBTB20', Aliases=['DPZF', 'HOF', 'ODA-8S', 'PRIMS', 'ZNF288'], description='zinc finger and BTB domain containing 20', other_designations='zinc finger and BTB domain-containing protein 20|BTB/POZ zinc finger protein DPZF|dendritic cell-derived BTB/POZ zinc finger|zinc finger protein 288', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=114314500, end_position_on_the_genomic_accession=115147288, orientation='minus', exon_count=27, OMIM=[606025], no_hdr0=''),
    26140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26140, CurrentID=0, Status='live', Symbol='TTLL3', Aliases=['HOTTL'], description='tubulin tyrosine ligase like 3', other_designations='tubulin monoglycylase TTLL3|tubulin tyrosine ligase-like family, member 3|tubulin--tyrosine ligase-like protein 3', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9809727, end_position_on_the_genomic_accession=9836365, orientation='plus', exon_count=15, OMIM=[619195], no_hdr0=''),
    26145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26145, CurrentID=0, Status='live', Symbol='IRF2BP1', Aliases=[], description='interferon regulatory factor 2 binding protein 1', other_designations='interferon regulatory factor 2-binding protein 1|IRF-2-binding protein 1|probable E3 ubiquitin-protein ligase IRF2BP1|probable RING-type E3 ubiquitin transferase IRF2BP1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45883608, end_position_on_the_genomic_accession=45886141, orientation='minus', exon_count=1, OMIM=[615331], no_hdr0=''),
    26146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26146, CurrentID=0, Status='live', Symbol='TRAF3IP1', Aliases=['FAP116', 'IFT54', 'MIP-T3', 'MIPT3', 'SLSN9'], description='TRAF3 interacting protein 1', other_designations='TRAF3-interacting protein 1|TNF receptor-associated factor 3 interacting protein 1|interleukin 13 receptor alpha 1-binding protein-1|intraflagellar transport protein 54 homolog|microtubule interacting protein that associates with TRAF3|microtubule-interacting protein associated with TRAF3', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238320489, end_position_on_the_genomic_accession=238400900, orientation='plus', exon_count=20, OMIM=[607380], no_hdr0=''),
    26147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26147, CurrentID=0, Status='live', Symbol='PHF19', Aliases=['MTF2L1', 'PCL3', 'TDRD19B'], description='PHD finger protein 19', other_designations='PHD finger protein 19|polycomb like 3|polycomb-like protein 3|tudor domain containing 19B', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120855651, end_position_on_the_genomic_accession=120902160, orientation='minus', exon_count=21, OMIM=[609740], no_hdr0=''),
    26149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26149, CurrentID=0, Status='live', Symbol='ZNF658', Aliases=[], description='zinc finger protein 658', other_designations='zinc finger protein 658', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=66900725, end_position_on_the_genomic_accession=66932141, orientation='plus', exon_count=9, OMIM=[616290], no_hdr0=''),
    26150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26150, CurrentID=0, Status='live', Symbol='RIBC2', Aliases=['C22orf11', 'TRIB'], description='RIB43A domain with coiled-coils 2', other_designations='RIB43A-like with coiled-coils protein 2', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45413693, end_position_on_the_genomic_accession=45432509, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    26151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26151, CurrentID=0, Status='live', Symbol='NAT9', Aliases=['EBSP', 'hNATL'], description='N-acetyltransferase 9 (putative)', other_designations='N-acetyltransferase 9|N-acetyltransferase 9 (GCN5-related, putative)|embryo brain specific protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74770529, end_position_on_the_genomic_accession=74776395, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    26152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26152, CurrentID=0, Status='live', Symbol='ZNF337', Aliases=[], description='zinc finger protein 337', other_designations='zinc finger protein 337', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25673195, end_position_on_the_genomic_accession=25696879, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    26153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26153, CurrentID=0, Status='live', Symbol='KIF26A', Aliases=[], description='kinesin family member 26A', other_designations='kinesin-like protein KIF26A|KIF26A variant protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104138587, end_position_on_the_genomic_accession=104180898, orientation='plus', exon_count=15, OMIM=[613231], no_hdr0=''),
    26154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26154, CurrentID=0, Status='live', Symbol='ABCA12', Aliases=['ARCI4A', 'ARCI4B', 'ICR2B', 'LI2'], description='ATP binding cassette subfamily A member 12', other_designations='glucosylceramide transporter ABCA12|ATP-binding cassette sub-family A member 12|ATP-binding cassette transporter 12|ATP-binding cassette, sub-family A (ABC1), member 12', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=214931542, end_position_on_the_genomic_accession=215138626, orientation='minus', exon_count=55, OMIM=[607800], no_hdr0=''),
    26155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26155, CurrentID=0, Status='live', Symbol='NOC2L', Aliases=['NET15', 'NET7', 'NIR', 'PPP1R112'], description='NOC2 like nucleolar associated transcriptional repressor', other_designations='nucleolar complex protein 2 homolog|NOC2-like protein|NOC2L nucleolar associated transcriptional repressor|novel INHAT (inhibitor of histone acetyltransferase) repressor|novel INHAT repressor|nucleolar complex associated 2 homolog|protein NOC2 homolog|protein phosphatase 1, regulatory subunit 12', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=944203, end_position_on_the_genomic_accession=959256, orientation='minus', exon_count=19, OMIM=[610770], no_hdr0=''),
    26156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26156, CurrentID=0, Status='live', Symbol='RSL1D1', Aliases=['CSIG', 'L12', 'PBK1', 'UTP30'], description='ribosomal L1 domain containing 1', other_designations='ribosomal L1 domain-containing protein 1|CATX-11|cellular senescence-inhibited gene protein', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11833850, end_position_on_the_genomic_accession=11851542, orientation='minus', exon_count=9, OMIM=[615874], no_hdr0=''),
    26157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26157, CurrentID=0, Status='live', Symbol='GIMAP2', Aliases=['HIMAP2', 'IAN12', 'IMAP2'], description='GTPase, IMAP family member 2', other_designations='GTPase IMAP family member 2|immune-associated nucleotide-binding protein 12|immunity associated protein 2', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150685706, end_position_on_the_genomic_accession=150693641, orientation='plus', exon_count=3, OMIM=[608085], no_hdr0=''),
    26160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26160, CurrentID=0, Status='live', Symbol='IFT172', Aliases=['BBS20', 'NPHP17', 'RP71', 'SLB', 'SRTD10', 'osm-1', 'wim'], description='intraflagellar transport 172', other_designations='intraflagellar transport protein 172 homolog|intraflagellar transport 172 homolog|selective LIM binding factor homolog|wimple homolog', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27444373, end_position_on_the_genomic_accession=27489819, orientation='minus', exon_count=52, OMIM=[607386], no_hdr0=''),
    26164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26164, CurrentID=0, Status='live', Symbol='MTG2', Aliases=['GTPBP5', 'ObgH1', 'dJ1005F21.2'], description='mitochondrial ribosome associated GTPase 2', other_designations='mitochondrial ribosome-associated GTPase 2|GTP binding protein 5 (putative)|GTP-binding protein 5|protein obg homolog 1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62183028, end_position_on_the_genomic_accession=62203568, orientation='plus', exon_count=12, OMIM=[610919], no_hdr0=''),
    26165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26165, CurrentID=0, Status='live', Symbol='SPATA31A7', Aliases=['AEP1', 'C9orf36', 'C9orf36A', 'FAM75A4', 'FAM75A7', 'SPATA31A4'], description='SPATA31 subfamily A member 7', other_designations='spermatogenesis-associated protein 31A7|SPATA31 subfamily A, member 4|family with sequence similarity 75, member A4|family with sequence similarity 75, member A7|protein FAM75A4|protein FAM75A7|spermatogenesis-associated protein 31A4', map_location='9q12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=61190036, end_position_on_the_genomic_accession=61196280, orientation='plus', exon_count=4, OMIM=[616584], no_hdr0=''),
    26166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26166, CurrentID=0, Status='live', Symbol='RGS22', Aliases=['CT145', 'PRTD-NY2'], description='regulator of G protein signaling 22', other_designations='regulator of G-protein signaling 22', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=99960936, end_position_on_the_genomic_accession=100106946, orientation='minus', exon_count=32, OMIM=[615650], no_hdr0=''),
    26167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26167, CurrentID=0, Status='live', Symbol='PCDHB5', Aliases=['PCDH-BETA5'], description='protocadherin beta 5', other_designations='protocadherin beta-5|PCDH-beta-5', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141135206, end_position_on_the_genomic_accession=141138615, orientation='plus', exon_count=1, OMIM=[606331], no_hdr0=''),
    26168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26168, CurrentID=0, Status='live', Symbol='SENP3', Aliases=['SMT3IP1', 'SSP3', 'Ulp1'], description='SUMO specific peptidase 3', other_designations='sentrin-specific protease 3|SUMO-1-specific protease 3|SUMO1/sentrin/SMT3 specific peptidase 3|sentrin/SUMO-specific protease 3', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7561919, end_position_on_the_genomic_accession=7571969, orientation='plus', exon_count=11, OMIM=[612844], no_hdr0=''),
    26173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26173, CurrentID=0, Status='live', Symbol='INTS1', Aliases=['INT1', 'NDCAGF', 'NET28'], description='integrator complex subunit 1', other_designations='integrator complex subunit 1', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1470277, end_position_on_the_genomic_accession=1504389, orientation='minus', exon_count=48, OMIM=[611345], no_hdr0=''),
    26175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26175, CurrentID=0, Status='live', Symbol='TMEM251', Aliases=['C14orf109', 'DMAN'], description='transmembrane protein 251', other_designations='transmembrane protein 251|UPF0694 transmembrane protein C14orf109', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93184974, end_position_on_the_genomic_accession=93188463, orientation='plus', exon_count=3, OMIM=[619332], no_hdr0=''),
    26188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26188, CurrentID=0, Status='live', Symbol='OR1C1', Aliases=['HSTPCR27', 'OR1-42', 'OR1.5.10', 'ORL211', 'TPCR27'], description='olfactory receptor family 1 subfamily C member 1', other_designations='olfactory receptor 1C1|olfactory receptor OR1-42|olfactory receptor TPCR27', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247754846, end_position_on_the_genomic_accession=247760556, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26189, CurrentID=0, Status='live', Symbol='OR1A2', Aliases=['OR17-6'], description='olfactory receptor family 1 subfamily A member 2', other_designations='olfactory receptor 1A2|olfactory receptor 17-6|olfactory receptor OR17-10', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3197519, end_position_on_the_genomic_accession=3198448, orientation='plus', exon_count=1, OMIM=[618047], no_hdr0=''),
    26190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26190, CurrentID=0, Status='live', Symbol='FBXW2', Aliases=['FBW2', 'Fwd2', 'Md6'], description='F-box and WD repeat domain containing 2', other_designations='F-box/WD repeat-containing protein 2|F-box and WD-40 domain protein 2|F-box and WD-40 domain-containing protein 2', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120756974, end_position_on_the_genomic_accession=120793440, orientation='minus', exon_count=9, OMIM=[609071], no_hdr0=''),
    26191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26191, CurrentID=0, Status='live', Symbol='PTPN22', Aliases=['LYP', 'LYP1', 'LYP2', 'PEP.5', 'PTPN22.6', 'PTPN8', 'PTPN22'], description='protein tyrosine phosphatase non-receptor type 22', other_designations='tyrosine-protein phosphatase non-receptor type 22|PEST-domain phosphatase|hematopoietic cell protein-tyrosine phosphatase 70Z-PEP|lymphoid-specific protein tyrosine phosphatase|protein tyrosine phosphatase, non-receptor type 22 (lymphoid)|protein tyrosine phosphatase, non-receptor type 8', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113813811, end_position_on_the_genomic_accession=113871761, orientation='minus', exon_count=24, OMIM=[600716], no_hdr0=''),
    26205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26205, CurrentID=0, Status='live', Symbol='GMEB2', Aliases=['GMEB-2', 'P79PIF', 'PIF79'], description='glucocorticoid modulatory element binding protein 2', other_designations='glucocorticoid modulatory element-binding protein 2|DNA-binding protein p79PIF|PIF p79|parvovirus initiation factor, p79', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63587602, end_position_on_the_genomic_accession=63627101, orientation='minus', exon_count=11, OMIM=[607451], no_hdr0=''),
    26206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26206, CurrentID=0, Status='live', Symbol='SPAG8', Aliases=['BS-84', 'CILD28', 'CT142', 'HSD-1', 'SMP1', 'SPAG3', 'hSMP-1'], description='sperm associated antigen 8', other_designations='sperm-associated antigen 8|sperm membrane protein 1|sperm membrane protein BS-84|testicular tissue protein Li 177', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35807785, end_position_on_the_genomic_accession=35812272, orientation='minus', exon_count=9, OMIM=[605731], no_hdr0=''),
    26207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26207, CurrentID=0, Status='live', Symbol='PITPNC1', Aliases=['M-RDGB-beta', 'MRDGBbeta', 'RDGB-BETA', 'RDGBB', 'RDGBB1'], description='phosphatidylinositol transfer protein cytoplasmic 1', other_designations='cytoplasmic phosphatidylinositol transfer protein 1|M-rdgB beta|mammalian rdgB homolog beta|retinal degeneration B beta 1|retinal degeneration B homolog beta', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67377281, end_position_on_the_genomic_accession=67697256, orientation='plus', exon_count=13, OMIM=[605134], no_hdr0=''),
    26211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26211, CurrentID=0, Status='live', Symbol='OR2F1', Aliases=['7M1-2', 'OLF3', 'OR14-60', 'OR2F3', 'OR2F3P', 'OR2F4', 'OR2F5', 'OR7-139', 'OR7-140'], description='olfactory receptor family 2 subfamily F member 1', other_designations='olfactory receptor 2F1|olfactory receptor 2F3|olfactory receptor 2F4|olfactory receptor 2F5|olfactory receptor OR7-7|olfactory receptor, family 2, subfamily F, member 3|olfactory receptor, family 2, subfamily F, member 4|olfactory receptor, family 2, subfamily F, member 5|olfactory receptor-like protein OLF3', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143907152, end_position_on_the_genomic_accession=143964360, orientation='plus', exon_count=5, OMIM=[608497], no_hdr0=''),
    26212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26212, CurrentID=0, Status='live', Symbol='OR2B6', Aliases=['OR2B1', 'OR2B1P', 'OR2B5P', 'OR5-40', 'OR5-41', 'OR6-31', 'dJ408B20.2', 'OR2B6'], description='olfactory receptor family 2 subfamily B member 6', other_designations='olfactory receptor 2B6|hs6M1-32|olfactory receptor 2B1|olfactory receptor 2B5|olfactory receptor 5-40|olfactory receptor 6-31|olfactory receptor OR6-4|olfactory receptor, family 2, subfamily B, member 1 pseudogene|olfactory receptor, family 2, subfamily B, member 5|olfactory receptor, family 2, subfamily B, member 6 pseudogene', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27957241, end_position_on_the_genomic_accession=27958182, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26219, CurrentID=0, Status='live', Symbol='OR1J4', Aliases=['HSHTPCRX01', 'HTPCRX01', 'OR9-21'], description='olfactory receptor family 1 subfamily J member 4', other_designations='olfactory receptor 1J4|olfactory receptor OR9-21', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122519141, end_position_on_the_genomic_accession=122520082, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26224, CurrentID=0, Status='live', Symbol='FBXL3', Aliases=['FBL3', 'FBL3AA', 'IDDSFAS', 'FBXL3'], description='F-box and leucine rich repeat protein 3', other_designations='F-box/LRR-repeat protein 3|F-box and leucine-rich repeat protein 3A|F-box protein Fbl3a|F-box/LRR-repeat protein 3A', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=76992597, end_position_on_the_genomic_accession=77027164, orientation='minus', exon_count=6, OMIM=[605653], no_hdr0=''),
    26225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26225, CurrentID=0, Status='live', Symbol='ARL5A', Aliases=['ARFLP5', 'ARL5'], description='ADP ribosylation factor like GTPase 5A', other_designations='ADP-ribosylation factor-like protein 5A|ADP-ribosylation factor-like 5|ADP-ribosylation factor-like 5A|ADP-ribosylation factor-like protein 5', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151798797, end_position_on_the_genomic_accession=151828421, orientation='minus', exon_count=6, OMIM=[608960], no_hdr0=''),
    26227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26227, CurrentID=0, Status='live', Symbol='PHGDH', Aliases=['3-PGDH', '3PGDH', 'HEL-S-113', 'NLS', 'NLS1', 'PDG', 'PGAD', 'PGD', 'PGDHD', 'SERA', 'PHGDH'], description='phosphoglycerate dehydrogenase', other_designations='D-3-phosphoglycerate dehydrogenase|2-oxoglutarate reductase|3-phosphoglycerate dehydrogenase|epididymis secretory protein Li 113|malate dehydrogenase', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119711934, end_position_on_the_genomic_accession=119744218, orientation='plus', exon_count=16, OMIM=[606879], no_hdr0=''),
    26228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26228, CurrentID=0, Status='live', Symbol='STAP1', Aliases=['BRDG1', 'STAP-1'], description='signal transducing adaptor family member 1', other_designations='signal-transducing adaptor protein 1|BCR downstream-signaling protein 1|docking protein BRDG1|stem cell adaptor protein 1', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67558727, end_position_on_the_genomic_accession=67607337, orientation='plus', exon_count=10, OMIM=[604298], no_hdr0=''),
    26229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26229, CurrentID=0, Status='live', Symbol='B3GAT3', Aliases=['GLCATI', 'JDSCD', 'glcUAT-I'], description='beta-1,3-glucuronyltransferase 3', other_designations='galactosylgalactosylxylosylprotein 3-beta-glucuronosyltransferase 3|Sqv-8-like protein|UDP-GlcUA:Gal beta-1,3-Gal-R glucuronyltransferase|beta-1,3-glucuronyltransferase 3 (glucuronosyltransferase I)', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62615296, end_position_on_the_genomic_accession=62621986, orientation='minus', exon_count=6, OMIM=[606374], no_hdr0=''),
    26230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26230, CurrentID=0, Status='live', Symbol='TIAM2', Aliases=['STEF', 'TIAM-2'], description='TIAM Rac1 associated GEF 2', other_designations='rho guanine nucleotide exchange factor TIAM2|SIF and TIAM1-like exchange factor|T cell lymphoma invasion and metastasis 2|T-lymphoma invasion and metastasis-inducing protein 2', map_location='6q25.2-q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=154995315, end_position_on_the_genomic_accession=155257723, orientation='plus', exon_count=30, OMIM=[604709], no_hdr0=''),
    26232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26232, CurrentID=0, Status='live', Symbol='FBXO2', Aliases=['FBG1', 'FBX2', 'Fbs1', 'NFB42', 'OCP1'], description='F-box protein 2', other_designations='F-box only protein 2|F-box gene 1|organ of Corti protein 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11648387, end_position_on_the_genomic_accession=11654429, orientation='minus', exon_count=6, OMIM=[607112], no_hdr0=''),
    26233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26233, CurrentID=0, Status='live', Symbol='FBXL6', Aliases=['FBL6', 'FBL6A', 'PP14630'], description='F-box and leucine rich repeat protein 6', other_designations='F-box/LRR-repeat protein 6|F-box protein Fbl6', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144355431, end_position_on_the_genomic_accession=144358472, orientation='minus', exon_count=9, OMIM=[609076], no_hdr0=''),
    26234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26234, CurrentID=0, Status='live', Symbol='FBXL5', Aliases=['FBL4', 'FBL5', 'FLR1'], description='F-box and leucine rich repeat protein 5', other_designations='F-box/LRR-repeat protein 5|F-box protein FBL4/FBL5|p45SKP2-like protein', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15604381, end_position_on_the_genomic_accession=15681544, orientation='minus', exon_count=16, OMIM=[605655], no_hdr0=''),
    26235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26235, CurrentID=0, Status='live', Symbol='FBXL4', Aliases=['FBL4', 'FBL5', 'MTDPS13'], description='F-box and leucine rich repeat protein 4', other_designations='F-box/LRR-repeat protein 4', map_location='6q16.1-q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=98868535, end_position_on_the_genomic_accession=98948006, orientation='minus', exon_count=12, OMIM=[605654], no_hdr0=''),
    26239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26239, CurrentID=0, Status='live', Symbol='LCE2B', Aliases=['LEP10', 'SPRL1B', 'XP5'], description='late cornified envelope 2B', other_designations='late cornified envelope protein 2B|late envelope protein 10|skin-specific protein Xp5|small proline rich-like (epidermal differentiation complex) 1B|small proline-rich-like epidermal differentiation complex protein 1B', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152686123, end_position_on_the_genomic_accession=152687397, orientation='plus', exon_count=2, OMIM=[612610], no_hdr0=''),
    26240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26240, CurrentID=0, Status='live', Symbol='FAM50B', Aliases=['D6S2654E', 'X5L'], description='family with sequence similarity 50 member B', other_designations='protein FAM50B|XAP5 like|XAP5-like protein', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3831901, end_position_on_the_genomic_accession=3851320, orientation='plus', exon_count=4, OMIM=[614686], no_hdr0=''),
    26245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26245, CurrentID=0, Status='live', Symbol='OR2M4', Aliases=['HSHTPCRX18', 'HTPCRX18', 'OR1-55', 'OST710', 'TPCR100'], description='olfactory receptor family 2 subfamily M member 4', other_designations='olfactory receptor 2M4|novel 7 transmembrane receptor (rhodopsin family) protein|olfactory receptor OR1-55|olfactory receptor TPCR100', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248231417, end_position_on_the_genomic_accession=248244679, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26246, CurrentID=0, Status='live', Symbol='OR2L2', Aliases=['HSHTPCRH07', 'HTPCRH07', 'OR1-48', 'OR2L12', 'OR2L4P'], description='olfactory receptor family 2 subfamily L member 2', other_designations='olfactory receptor 2L2|olfactory receptor 2L12|olfactory receptor 2L4|olfactory receptor OR1-48 pseudogene|olfactory receptor, family 2, subfamily L, member 12|olfactory receptor, family 2, subfamily L, member 4 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248030070, end_position_on_the_genomic_accession=248042305, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    26248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26248, CurrentID=0, Status='live', Symbol='OR2K2', Aliases=['HSHTPCRH06', 'HTPCRH06', 'OR2AN1P', 'OR2AR1P'], description='olfactory receptor family 2 subfamily K member 2', other_designations='olfactory receptor 2K2|olfactory receptor OR9-17|olfactory receptor, family 2, subfamily AN, member 1 pseudogene|olfactory receptor, family 2, subfamily AR, member 1 pseudogene', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111327229, end_position_on_the_genomic_accession=111330224, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26249, CurrentID=0, Status='live', Symbol='KLHL3', Aliases=['PHA2D'], description='kelch like family member 3', other_designations='kelch-like protein 3', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=137617500, end_position_on_the_genomic_accession=137736089, orientation='minus', exon_count=17, OMIM=[605775], no_hdr0=''),
    26251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26251, CurrentID=0, Status='live', Symbol='KCNG2', Aliases=['KCNF2', 'KV6.2'], description='potassium voltage-gated channel modifier subfamily G member 2', other_designations='potassium voltage-gated channel subfamily G member 2|cardiac potassium channel subunit|potassium channel, voltage gated modifier subfamily G, member 2|potassium voltage-gated channel, subfamily G, member 2|voltage-gated potassium channel subunit Kv6.2', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79797938, end_position_on_the_genomic_accession=79903512, orientation='plus', exon_count=5, OMIM=[605696], no_hdr0=''),
    26253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26253, CurrentID=0, Status='live', Symbol='CLEC4E', Aliases=['CLECSF9', 'MINCLE'], description='C-type lectin domain family 4 member E', other_designations='C-type lectin domain family 4 member E|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 9|C-type lectin superfamily member 9|macrophage-inducible C-type lectin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8533305, end_position_on_the_genomic_accession=8541327, orientation='minus', exon_count=6, OMIM=[609962], no_hdr0=''),
    26254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26254, CurrentID=0, Status='live', Symbol='OPTC', Aliases=['OPT'], description='opticin', other_designations='opticin|oculoglycan', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203494153, end_position_on_the_genomic_accession=203508949, orientation='plus', exon_count=8, OMIM=[605127], no_hdr0=''),
    26256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26256, CurrentID=0, Status='live', Symbol='CABYR', Aliases=['CABYRac', 'CABYRc/d', 'CABYRe', 'CBP86', 'CT88', 'FSP-2', 'FSP2', 'CABYR'], description='calcium binding tyrosine phosphorylation regulated', other_designations='calcium-binding tyrosine phosphorylation-regulated protein|calcium binding tyrosine-(Y)-phosphorylation regulated (fibrousheathin 2)|calcium-binding protein 86|cancer/testis antigen 88|fibrousheathin II|fibrousheathin-2|testis tissue sperm-binding protein Li 84P|testis-specific calcium-binding protein CBP86', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=24138956, end_position_on_the_genomic_accession=24161600, orientation='plus', exon_count=9, OMIM=[612135], no_hdr0=''),
    26257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26257, CurrentID=0, Status='live', Symbol='NKX2-8', Aliases=['NKX2.8', 'NKX2H', 'Nkx2-9'], description='NK2 homeobox 8', other_designations='homeobox protein Nkx-2.8|NK-2 homolog 8|NK-2 homolog H|NK2 transcription factor related, locus 8|homeobox protein NK-2 homolog H', map_location='14q13.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=36580004, end_position_on_the_genomic_accession=36582614, orientation='minus', exon_count=2, OMIM=[603245], no_hdr0=''),
    26258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26258, CurrentID=0, Status='live', Symbol='BLOC1S6', Aliases=['BLOS6', 'HPS9', 'PA', 'PALLID', 'PLDN'], description='biogenesis of lysosomal organelles complex 1 subunit 6', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 6|BLOC-1 subunit 6|BLOC-1 subunit pallidin|biogenesis of lysosomal organelles complex-1, subunit 5, pallidin|biogenesis of lysosomal organelles complex-1, subunit 6, pallidin|pallid protein homolog|syntaxin 13 binding protein 1|syntaxin 13-interacting protein pallid', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45587123, end_position_on_the_genomic_accession=45609716, orientation='plus', exon_count=7, OMIM=[604310], no_hdr0=''),
    26259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26259, CurrentID=0, Status='live', Symbol='FBXW8', Aliases=['FBW6', 'FBW8', 'FBX29', 'FBXO29', 'FBXW6'], description='F-box and WD repeat domain containing 8', other_designations='F-box/WD repeat-containing protein 8|F-box and WD-40 domain protein 8|F-box and WD-40 domain-containing protein 8|F-box only protein 29', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=116910949, end_position_on_the_genomic_accession=117032498, orientation='plus', exon_count=16, OMIM=[609073], no_hdr0=''),
    26260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26260, CurrentID=0, Status='live', Symbol='FBXO25', Aliases=['FBX25'], description='F-box protein 25', other_designations='F-box only protein 25|F-box protein Fbx25', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=406813, end_position_on_the_genomic_accession=477967, orientation='plus', exon_count=14, OMIM=[609098], no_hdr0=''),
    26261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26261, CurrentID=0, Status='live', Symbol='FBXO24', Aliases=['FBX24'], description='F-box protein 24', other_designations='F-box only protein 24|F-box protein Fbx24', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100582490, end_position_on_the_genomic_accession=100601117, orientation='plus', exon_count=16, OMIM=[609097], no_hdr0=''),
    26262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26262, CurrentID=0, Status='live', Symbol='TSPAN17', Aliases=['FBX23', 'FBXO23', 'TM4SF17'], description='tetraspanin 17', other_designations='tetraspanin-17|F-box only protein 23, transmembrane 4 superfamily member 17|tetraspan protein SB134', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176647484, end_position_on_the_genomic_accession=176659051, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    26263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26263, CurrentID=0, Status='live', Symbol='FBXO22', Aliases=['FBX22', 'FISTC1'], description='F-box protein 22', other_designations='F-box only protein 22|F-box protein FBX22p44|FIST domain containing 1', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75903878, end_position_on_the_genomic_accession=75942511, orientation='plus', exon_count=8, OMIM=[609096], no_hdr0=''),
    26266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26266, CurrentID=0, Status='live', Symbol='SLC13A4', Aliases=['NAS2', 'SUT-1', 'SUT1'], description='solute carrier family 13 member 4', other_designations='solute carrier family 13 member 4|Na(+)/sulfate cotransporter SUT-1|solute carrier family 13 (sodium/sulfate symporter), member 4|solute carrier family 13 (sodium/sulfate symporters), member 4|solute carrier family 13 (sodium/sulphate symporters), member 4|sulphate transporter 1', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135681231, end_position_on_the_genomic_accession=135728186, orientation='minus', exon_count=17, OMIM=[604309], no_hdr0=''),
    26267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26267, CurrentID=0, Status='live', Symbol='FBXO10', Aliases=['FBX10', 'PRMT11'], description='F-box protein 10', other_designations='F-box only protein 10|F-box protein Fbx10', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37510892, end_position_on_the_genomic_accession=37576380, orientation='minus', exon_count=14, OMIM=[609092], no_hdr0=''),
    26268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26268, CurrentID=0, Status='live', Symbol='FBXO9', Aliases=['FBX9', 'NY-REN-57', 'VCIA1', 'dJ341E18.2'], description='F-box protein 9', other_designations='F-box only protein 9|F-box protein Fbx9|cross-immune reaction antigen 1|renal carcinoma antigen NY-REN-57', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53057807, end_position_on_the_genomic_accession=53100873, orientation='plus', exon_count=17, OMIM=[609091], no_hdr0=''),
    26269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26269, CurrentID=0, Status='live', Symbol='FBXO8', Aliases=['DC10', 'FBS', 'FBX8'], description='F-box protein 8', other_designations='F-box only protein 8|F-box protein Fbx8|F-box/SEC7 protein FBS', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=174236658, end_position_on_the_genomic_accession=174283667, orientation='minus', exon_count=7, OMIM=[605649], no_hdr0=''),
    26270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26270, CurrentID=0, Status='live', Symbol='FBXO6', Aliases=['FBG2', 'FBS2', 'FBX6', 'Fbx6b'], description='F-box protein 6', other_designations='F-box only protein 6|F-box protein FBG2|F-box protein Fbx6|F-box protein that recognizes sugar chains 2|F-box/G-domain protein 2', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11664200, end_position_on_the_genomic_accession=11674354, orientation='plus', exon_count=11, OMIM=[605647], no_hdr0=''),
    26271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26271, CurrentID=0, Status='live', Symbol='FBXO5', Aliases=['EMI1', 'FBX5', 'Fbxo31'], description='F-box protein 5', other_designations='F-box only protein 5|F-box protein Fbx5|early mitotic inhibitor 1', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=152970535, end_position_on_the_genomic_accession=152983579, orientation='minus', exon_count=6, OMIM=[606013], no_hdr0=''),
    26272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26272, CurrentID=0, Status='live', Symbol='FBXO4', Aliases=['FBX4'], description='F-box protein 4', other_designations='F-box only protein 4|F-box protein Fbx4', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=41918061, end_position_on_the_genomic_accession=42040230, orientation='plus', exon_count=9, OMIM=[609090], no_hdr0=''),
    26273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26273, CurrentID=0, Status='live', Symbol='FBXO3', Aliases=['FBA', 'FBX3'], description='F-box protein 3', other_designations='F-box only protein 3|F-box protein FBX3', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33740944, end_position_on_the_genomic_accession=33774520, orientation='minus', exon_count=11, OMIM=[609089], no_hdr0=''),
    26275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26275, CurrentID=0, Status='live', Symbol='HIBCH', Aliases=['HIBYLCOAH'], description='3-hydroxyisobutyryl-CoA hydrolase', other_designations='3-hydroxyisobutyryl-CoA hydrolase, mitochondrial|3-hydroxyisobutyryl-Coenzyme A hydrolase|HIB-CoA hydrolase|HIBYL-CoA-H|testicular tissue protein Li 86', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190203920, end_position_on_the_genomic_accession=190319826, orientation='minus', exon_count=16, OMIM=[610690], no_hdr0=''),
    26276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26276, CurrentID=0, Status='live', Symbol='VPS33B', Aliases=[], description='VPS33B late endosome and lysosome associated', other_designations='vacuolar protein sorting-associated protein 33B|vacuolar protein sorting 33 homolog B|vacuolar protein sorting 33-like protein B', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90998416, end_position_on_the_genomic_accession=91022839, orientation='minus', exon_count=24, OMIM=[608552], no_hdr0=''),
    26277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26277, CurrentID=0, Status='live', Symbol='TINF2', Aliases=['DKCA3', 'TIN2'], description='TERF1 interacting nuclear factor 2', other_designations='TERF1-interacting nuclear factor 2|TERF1 (TRF1)-interacting nuclear factor 2|TRF1-interacting nuclear protein 2', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24239640, end_position_on_the_genomic_accession=24242674, orientation='minus', exon_count=6, OMIM=[604319], no_hdr0=''),
    26278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26278, CurrentID=0, Status='live', Symbol='SACS', Aliases=['ARSACS', 'DNAJC29', 'PPP1R138', 'SPAX6'], description='sacsin molecular chaperone', other_designations='sacsin|dnaJ homolog subfamily C member 29|protein phosphatase 1, regulatory subunit 138|spastic ataxia of Charlevoix-Saguenay (sacsin)', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23328827, end_position_on_the_genomic_accession=23433728, orientation='minus', exon_count=13, OMIM=[604490], no_hdr0=''),
    26279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26279, CurrentID=0, Status='live', Symbol='PLA2G2D', Aliases=['PLA2IID', 'SPLASH', 'sPLA2-IID', 'sPLA2S'], description='phospholipase A2 group IID', other_designations='group IID secretory phospholipase A2|GIID sPLA2|phosphatidylcholine 2-acylhydrolase 2D|secretory phospholipase A2s|secretory-type PLA, stroma-associated homolog', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20111939, end_position_on_the_genomic_accession=20119536, orientation='minus', exon_count=4, OMIM=[605630], no_hdr0=''),
    26280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26280, CurrentID=0, Status='live', Symbol='IL1RAPL2', Aliases=['IL-1R9', 'IL1R9', 'IL1RAPL-2', 'TIGIRR-1'], description='interleukin 1 receptor accessory protein like 2', other_designations='X-linked interleukin-1 receptor accessory protein-like 2|IL-1 receptor accessory protein-like 2|IL-1R-9|IL1RAPL-2-related protein|interleukin 1 receptor 9|three immunoglobulin domain-containing IL-1 receptor-related 1', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104566199, end_position_on_the_genomic_accession=105769729, orientation='plus', exon_count=12, OMIM=[300277], no_hdr0=''),
    26281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26281, CurrentID=0, Status='live', Symbol='FGF20', Aliases=['FGF-20', 'RHDA2'], description='fibroblast growth factor 20', other_designations='fibroblast growth factor 20', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=16992181, end_position_on_the_genomic_accession=17002345, orientation='minus', exon_count=3, OMIM=[605558], no_hdr0=''),
    26284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26284, CurrentID=0, Status='live', Symbol='ERAL1', Aliases=['CEGA', 'ERA', 'ERA-WA', 'ERAL1B', 'H-ERA', 'HERA-A', 'HERA-B', 'PRLTS6', 'ERAL1'], description='Era like 12S mitochondrial rRNA chaperone 1', other_designations='GTPase Era, mitochondrial|ERA-like protein 1|Era G-protein-like 1|GTP-binding protein era homolog|GTPase, human homolog of E. coli essential cell cycle protein Era|conserved ERA-like GTPase|era (E. coli G-protein homolog)-like 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28855016, end_position_on_the_genomic_accession=28861061, orientation='plus', exon_count=10, OMIM=[607435], no_hdr0=''),
    26285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26285, CurrentID=0, Status='live', Symbol='CLDN17', Aliases=[], description='claudin 17', other_designations='claudin-17|human CLDN17 gene for claudin-17', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30165565, end_position_on_the_genomic_accession=30166805, orientation='minus', exon_count=1, OMIM=[617005], no_hdr0=''),
    26286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26286, CurrentID=0, Status='live', Symbol='ARFGAP3', Aliases=['ARFGAP1'], description='ADP ribosylation factor GTPase activating protein 3', other_designations='ADP-ribosylation factor GTPase-activating protein 3|ADP-ribosylation factor GTPase activating protein 1|ARF GAP 3', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42796502, end_position_on_the_genomic_accession=42857294, orientation='minus', exon_count=16, OMIM=[612439], no_hdr0=''),
    26287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26287, CurrentID=0, Status='live', Symbol='ANKRD2', Aliases=['ARPP'], description='ankyrin repeat domain 2', other_designations='ankyrin repeat domain-containing protein 2|ankyrin repeat domain 2 (stretch responsive muscle)|skeletal muscle ankyrin repeat protein', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97572441, end_position_on_the_genomic_accession=97583884, orientation='plus', exon_count=9, OMIM=[610734], no_hdr0=''),
    26289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26289, CurrentID=0, Status='live', Symbol='AK5', Aliases=['AK6'], description='adenylate kinase 5', other_designations='adenylate kinase isoenzyme 5|AK 5|ATP-AMP transphosphorylase 5|adenylate kinase 6', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77281908, end_position_on_the_genomic_accession=77559966, orientation='plus', exon_count=16, OMIM=[608009], no_hdr0=''),
    26290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26290, CurrentID=0, Status='live', Symbol='GALNT8', Aliases=['GALNAC-T8'], description='polypeptide N-acetylgalactosaminyltransferase 8', other_designations='probable polypeptide N-acetylgalactosaminyltransferase 8|GalNAc transferase 8|UDP-GalNAc: polypeptide N-acetylgalactosaminyltransferase 8|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 8 (GalNAc-T8)|polypeptide GalNAc transferase 8|pp-GaNTase 8|protein-UDP acetylgalactosaminyltransferase 8', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4720400, end_position_on_the_genomic_accession=4772726, orientation='plus', exon_count=11, OMIM=[606250], no_hdr0=''),
    26291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26291, CurrentID=0, Status='live', Symbol='FGF21', Aliases=[], description='fibroblast growth factor 21', other_designations='fibroblast growth factor 21', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48755524, end_position_on_the_genomic_accession=48758330, orientation='plus', exon_count=4, OMIM=[609436], no_hdr0=''),
    26292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26292, CurrentID=0, Status='live', Symbol='MYCBP', Aliases=['AMY-1'], description='MYC binding protein', other_designations='C-Myc-binding protein|associate of myc-1|c-myc binding protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38862490, end_position_on_the_genomic_accession=38873378, orientation='minus', exon_count=5, OMIM=[606535], no_hdr0=''),
    26297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26297, CurrentID=0, Status='live', Symbol='SERGEF', Aliases=['DELGEF', 'Gnefr'], description='secretion regulating guanine nucleotide exchange factor', other_designations='secretion-regulating guanine nucleotide exchange factor|deafness locus associated putative guanine nucleotide exchange factor|guanine nucleotide exchange factor-related protein', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17788048, end_position_on_the_genomic_accession=18013047, orientation='minus', exon_count=12, OMIM=[606051], no_hdr0=''),
    26298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26298, CurrentID=0, Status='live', Symbol='EHF', Aliases=['ESE3', 'ESE3B', 'ESEJ'], description='ETS homologous factor', other_designations='ETS homologous factor|ESE3 transcription factor|ETS domain-containing transcription factor|epithelium-specific Ets transcription factor 3|hEHF', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34621093, end_position_on_the_genomic_accession=34663288, orientation='plus', exon_count=17, OMIM=[605439], no_hdr0=''),
    26301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26301, CurrentID=0, Status='live', Symbol='GBGT1', Aliases=['A3GALNT', 'FS', 'UNQ2513'], description='globoside alpha-1,3-N-acetylgalactosaminyltransferase 1 (FORS blood group)', other_designations='globoside alpha-1,3-N-acetylgalactosaminyltransferase 1|Forssman blood group|Forssman glycolipid synthetase (FS)|forssman glycolipid synthase-like protein', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133152948, end_position_on_the_genomic_accession=133163914, orientation='minus', exon_count=7, OMIM=[606074], no_hdr0=''),
    26330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26330, CurrentID=0, Status='live', Symbol='GAPDHS', Aliases=['GAPD2', 'GAPDH-2', 'GAPDS', 'HEL-S-278', 'HSD-35'], description='glyceraldehyde-3-phosphate dehydrogenase, spermatogenic', other_designations='glyceraldehyde-3-phosphate dehydrogenase, testis-specific|epididymis secretory protein Li 278|spermatogenic cell-specific glyceraldehyde 3-phosphate dehydrogenase 2|spermatogenic glyceraldehyde-3-phosphate dehydrogenase', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35533456, end_position_on_the_genomic_accession=35545319, orientation='plus', exon_count=11, OMIM=[609169], no_hdr0=''),
    26333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26333, CurrentID=0, Status='live', Symbol='OR7A17', Aliases=['BC85395_4', 'HTPCRX19'], description='olfactory receptor family 7 subfamily A member 17', other_designations='olfactory receptor 7A17|olfactory receptor OR19-20', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14878203, end_position_on_the_genomic_accession=14886132, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    26338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26338, CurrentID=0, Status='live', Symbol='OR5L2', Aliases=['HSHTPCRX16', 'HTPCRX16', 'OR11-153'], description='olfactory receptor family 5 subfamily L member 2', other_designations='olfactory receptor 5L2|olfactory receptor OR11-153|olfactory receptor, family 5, subfamily L, member 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55827219, end_position_on_the_genomic_accession=55828154, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26339, CurrentID=0, Status='live', Symbol='OR5K1', Aliases=['HSHTPCRX10', 'HTPCRX10', 'OR3-8'], description='olfactory receptor family 5 subfamily K member 1', other_designations='olfactory receptor 5K1|olfactory receptor OR3-8', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98463201, end_position_on_the_genomic_accession=98472924, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26341, CurrentID=0, Status='live', Symbol='OR5H1', Aliases=['HSHTPCRX14', 'HTPCRX14'], description='olfactory receptor family 5 subfamily H member 1', other_designations='olfactory receptor 5H1', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98130721, end_position_on_the_genomic_accession=98138548, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26353, CurrentID=0, Status='live', Symbol='HSPB8', Aliases=['CMT2L', 'DHMN2', 'E2IG1', 'H11', 'HMN2', 'HMN2A', 'HSP22'], description='heat shock protein family B (small) member 8', other_designations='heat shock protein beta-8|E2-induced gene 1 protein|alpha-crystallin C chain|heat shock 22kDa protein 8|heat shock 27kDa protein 8|protein kinase H11|small stress protein-like protein HSP22', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119178931, end_position_on_the_genomic_accession=119194746, orientation='plus', exon_count=3, OMIM=[608014], no_hdr0=''),
    26354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26354, CurrentID=0, Status='live', Symbol='GNL3', Aliases=['C77032', 'E2IG3', 'NNP47', 'NS'], description='G protein nucleolar 3', other_designations='guanine nucleotide-binding protein-like 3|E2-induced gene 3 protein|estradiol-induced nucleotide binding protein|guanine nucleotide binding protein-like 3 (nucleolar)|novel nucleolar protein 47|nucleolar GTP-binding protein 3|nucleostemin', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52685920, end_position_on_the_genomic_accession=52694497, orientation='plus', exon_count=15, OMIM=[608011], no_hdr0=''),
    26355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26355, CurrentID=0, Status='live', Symbol='FAM162A', Aliases=['C3orf28', 'E2IG5', 'HGTD-P'], description='family with sequence similarity 162 member A', other_designations='protein FAM162A|E2-induced gene 5 protein|HIF-1 alpha-responsive proapoptotic molecule|growth and transformation-dependent protein', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122384182, end_position_on_the_genomic_accession=122412334, orientation='plus', exon_count=5, OMIM=[608017], no_hdr0=''),
    26468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26468, CurrentID=0, Status='live', Symbol='LHX6', Aliases=['LHX6.1'], description='LIM homeobox 6', other_designations='LIM/homeobox protein Lhx6|LIM homeodomain protein 6.1|LIM/homeobox protein Lhx6.1', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122185626, end_position_on_the_genomic_accession=122228957, orientation='minus', exon_count=14, OMIM=[608215], no_hdr0=''),
    26469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26469, CurrentID=0, Status='live', Symbol='PTPN18', Aliases=['BDP1', 'PTP-HSCF'], description='protein tyrosine phosphatase non-receptor type 18', other_designations='tyrosine-protein phosphatase non-receptor type 18|brain-derived phosphatase|protein tyrosine phosphatase, non-receptor type 18 (brain-derived)', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130356012, end_position_on_the_genomic_accession=130375405, orientation='plus', exon_count=16, OMIM=[606587], no_hdr0=''),
    26470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26470, CurrentID=0, Status='live', Symbol='SEZ6L2', Aliases=['BSRPA', 'PSK-1'], description='seizure related 6 homolog like 2', other_designations='seizure 6-like protein 2|seizure related 6-like protein 2|type I transmembrane receptor (seizure-related protein)', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29871159, end_position_on_the_genomic_accession=29899550, orientation='minus', exon_count=18, OMIM=[616667], no_hdr0=''),
    26471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26471, CurrentID=0, Status='live', Symbol='NUPR1', Aliases=['COM1', 'P8'], description='nuclear protein 1, transcriptional regulator', other_designations='nuclear protein 1|candidate of metastasis 1|nuclear protein, transcriptional regulator, 1|nuclear transcriptional regulator protein 1|protein p8', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28532708, end_position_on_the_genomic_accession=28538974, orientation='minus', exon_count=3, OMIM=[614812], no_hdr0=''),
    26472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26472, CurrentID=0, Status='live', Symbol='PPP1R14B', Aliases=['PHI-1', 'PLCB3N', 'PNG', 'SOM172'], description='protein phosphatase 1 regulatory inhibitor subunit 14B', other_designations='protein phosphatase 1 regulatory subunit 14B|phospholipase C beta-3 neighboring gene protein|phospholipase C-beta-3 neighbouring gene protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64244479, end_position_on_the_genomic_accession=64246943, orientation='minus', exon_count=4, OMIM=[601140], no_hdr0=''),
    26476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26476, CurrentID=0, Status='live', Symbol='OR10J1', Aliases=['HGMP07J', 'HSHGMP07J'], description='olfactory receptor family 10 subfamily J member 1', other_designations='olfactory receptor 10J1|olfactory receptor OR1-26|olfactory receptor-like protein HGMP07J', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159397465, end_position_on_the_genomic_accession=159440967, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    26493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26493, CurrentID=0, Status='live', Symbol='OR8B8', Aliases=['TPCR85'], description='olfactory receptor family 8 subfamily B member 8', other_designations='olfactory receptor 8B8|olfactory receptor OR11-316|olfactory receptor TPCR85|olfactory-like receptor JCG8', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124437445, end_position_on_the_genomic_accession=124445696, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    26494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26494, CurrentID=0, Status='live', Symbol='OR8G1', Aliases=['HSTPCR25P', 'TPCR25', 'OR8G1'], description='olfactory receptor family 8 subfamily G member 1', other_designations='olfactory receptor 8G1|olfactory receptor OR11-281|olfactory receptor TPCR25|olfactory receptor, family 8, subfamily G, member 1 pseudogene', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124241095, end_position_on_the_genomic_accession=124254364, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    26496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26496, CurrentID=0, Status='live', Symbol='OR10A3', Aliases=['HSHTPCRX12', 'HTPCRX12'], description='olfactory receptor family 10 subfamily A member 3', other_designations='olfactory receptor 10A3|olfactory receptor OR11-97', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7937171, end_position_on_the_genomic_accession=7941708, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26497, CurrentID=0, Status='live', Symbol='OR10D3', Aliases=['HTPCRX09P', 'OR10D3'], description='olfactory receptor family 10 subfamily D member 3', other_designations='putative olfactory receptor 10D3|olfactory receptor OR11-293|olfactory receptor family 10 subfamily D member 3 (putative)|olfactory receptor, family 10, subfamily D, member 3 (non-functional)|olfactory receptor, family 10, subfamily D, member 3 pseudogene|seven transmembrane helix receptor', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124183345, end_position_on_the_genomic_accession=124188780, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26499, CurrentID=0, Status='live', Symbol='PLEK2', Aliases=[], description='pleckstrin 2', other_designations='pleckstrin-2|pleckstrin 2 homolog', map_location='14q23.3-q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67386984, end_position_on_the_genomic_accession=67412165, orientation='minus', exon_count=9, OMIM=[608007], no_hdr0=''),
    26502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26502, CurrentID=0, Status='live', Symbol='NARF', Aliases=['IOP2'], description='nuclear prelamin A recognition factor', other_designations='nuclear prelamin A recognition factor|iron-only hydrogenase-like protein 2|prenyl-dependent prelamin A binding protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82458198, end_position_on_the_genomic_accession=82490537, orientation='plus', exon_count=16, OMIM=[605349], no_hdr0=''),
    26503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26503, CurrentID=0, Status='live', Symbol='SLC17A5', Aliases=['AST', 'ISSD', 'NSD', 'SD', 'SIALIN', 'SIASD', 'SLD'], description='solute carrier family 17 member 5', other_designations='sialin|H(+)/nitrate cotransporter|H(+)/sialic acid cotransporter|membrane glycoprotein HP59|sialic acid storage disease|sodium/sialic acid cotransporter|solute carrier family 17 (acidic sugar transporter), member 5|solute carrier family 17 (anion/sugar transporter), member 5|vesicular H(+)/Aspartate-glutamate cotransporter', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73593379, end_position_on_the_genomic_accession=73653992, orientation='minus', exon_count=13, OMIM=[604322], no_hdr0=''),
    26504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26504, CurrentID=0, Status='live', Symbol='CNNM4', Aliases=['ACDP4'], description='cyclin and CBS domain divalent metal cation transport mediator 4', other_designations='metal transporter CNNM4|ancient conserved domain protein 4|ancient conserved domain-containing protein 4|cyclin-M4', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96760902, end_position_on_the_genomic_accession=96811888, orientation='plus', exon_count=11, OMIM=[607805], no_hdr0=''),
    26505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26505, CurrentID=0, Status='live', Symbol='CNNM3', Aliases=['ACDP3'], description='cyclin and CBS domain divalent metal cation transport mediator 3', other_designations='metal transporter CNNM3|ancient conserved domain protein 3|ancient conserved domain-containing protein 3|cyclin-M3', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96814946, end_position_on_the_genomic_accession=96837109, orientation='plus', exon_count=10, OMIM=[607804], no_hdr0=''),
    26507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26507, CurrentID=0, Status='live', Symbol='CNNM1', Aliases=['ACDP1', 'CLP-1'], description='cyclin and CBS domain divalent metal cation transport mediator 1', other_designations='metal transporter CNNM1|ancient conserved domain-containing protein 1|cyclin-M1', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99329101, end_position_on_the_genomic_accession=99394330, orientation='plus', exon_count=12, OMIM=[607802], no_hdr0=''),
    26508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26508, CurrentID=0, Status='live', Symbol='HEYL', Aliases=['HESR3', 'HEY3', 'HRT3', 'bHLHb33'], description='hes related family bHLH transcription factor with YRPW motif like', other_designations='hairy/enhancer-of-split related with YRPW motif-like protein|HEY-like protein|HRT-3|class B basic helix-loop-helix protein 33|hHRT3|hHeyL|hairy-related transcription factor 3|hairy/enhancer-of-split related with YRPW motif 3', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39623435, end_position_on_the_genomic_accession=39639643, orientation='minus', exon_count=6, OMIM=[609034], no_hdr0=''),
    26509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26509, CurrentID=0, Status='live', Symbol='MYOF', Aliases=['FER1L3', 'HAE7'], description='myoferlin', other_designations='myoferlin|fer-1-like 3, myoferlin|fer-1-like family member 3|fer-1-like protein 3', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93306429, end_position_on_the_genomic_accession=93482505, orientation='minus', exon_count=59, OMIM=[604603], no_hdr0=''),
    26511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26511, CurrentID=0, Status='live', Symbol='CHIC2', Aliases=['BTL'], description='cysteine rich hydrophobic domain 2', other_designations='cysteine-rich hydrophobic domain-containing protein 2|BRX-like translocated in leukemia|cystein-rich hydrophobic domain 2|cysteine-rich hydrophobic domain 2 protein', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=53996335, end_position_on_the_genomic_accession=54064690, orientation='minus', exon_count=7, OMIM=[604332], no_hdr0=''),
    26512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26512, CurrentID=0, Status='live', Symbol='INTS6', Aliases=['DBI-1', 'DDX26', 'DDX26A', 'DICE1', 'HDB', 'INT6', 'Notchl2'], description='integrator complex subunit 6', other_designations='integrator complex subunit 6|DEAD box protein|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 26|RNA helicase HDB|protein deleted in cancer 1', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51353171, end_position_on_the_genomic_accession=51453333, orientation='minus', exon_count=22, OMIM=[604331], no_hdr0=''),
    26515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26515, CurrentID=0, Status='live', Symbol='TIMM10B', Aliases=['FXC1', 'TIM10B', 'Tim9b'], description='translocase of inner mitochondrial membrane 10B', other_designations='mitochondrial import inner membrane translocase subunit Tim10 B|fracture callus 1 homolog|fracture callus protein 1|mitochondrial import inner membrane translocase subunit Tim9 B|translocase of inner mitochondrial membrane 10 homolog B', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6481501, end_position_on_the_genomic_accession=6484681, orientation='plus', exon_count=3, OMIM=[607388], no_hdr0=''),
    26517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26517, CurrentID=0, Status='live', Symbol='TIMM13', Aliases=['TIM13', 'TIM13BA', 'TIMM13B', 'ppv1', 'TIMM13'], description='translocase of inner mitochondrial membrane 13', other_designations='mitochondrial import inner membrane translocase subunit Tim13|mitochondrial import inner membrane translocase subunit Tim13B|translocase of inner mitochondrial membrane 13 homolog', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2425625, end_position_on_the_genomic_accession=2427586, orientation='minus', exon_count=3, OMIM=[607383], no_hdr0=''),
    26519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26519, CurrentID=0, Status='live', Symbol='TIMM10', Aliases=['TIM10', 'TIM10AA', 'TIMM10'], description='translocase of inner mitochondrial membrane 10', other_designations='mitochondrial import inner membrane translocase subunit Tim10|translocase of inner mitochondrial membrane 10 homolog', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57528464, end_position_on_the_genomic_accession=57542505, orientation='minus', exon_count=4, OMIM=[602251], no_hdr0=''),
    26520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26520, CurrentID=0, Status='live', Symbol='TIMM9', Aliases=['TIM9', 'TIM9A'], description='translocase of inner mitochondrial membrane 9', other_designations='mitochondrial import inner membrane translocase subunit Tim9|translocase of inner mitochondrial membrane 9 homolog', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58408494, end_position_on_the_genomic_accession=58427531, orientation='minus', exon_count=6, OMIM=[607384], no_hdr0=''),
    26521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26521, CurrentID=0, Status='live', Symbol='TIMM8B', Aliases=['DDP2', 'TIM8B'], description='translocase of inner mitochondrial membrane 8 homolog B', other_designations='mitochondrial import inner membrane translocase subunit Tim8 B|DDP-like protein|deafness dystonia protein 2', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112084800, end_position_on_the_genomic_accession=112086756, orientation='minus', exon_count=3, OMIM=[606659], no_hdr0=''),
    26523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26523, CurrentID=0, Status='live', Symbol='AGO1', Aliases=['EIF2C', 'EIF2C1', 'GERP95', 'Q99', 'hAgo1'], description='argonaute RISC component 1', other_designations='protein argonaute-1|Golgi Endoplasmic Reticulum protein 95 kDa|argonaute 1, RISC catalytic component|argonaute RISC catalytic component 1|argonaute1|eIF-2C 1|eIF2C 1|eukaryotic translation initiation factor 2C, 1|putative RNA-binding protein Q99', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35869761, end_position_on_the_genomic_accession=35930532, orientation='plus', exon_count=20, OMIM=[606228], no_hdr0=''),
    26524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26524, CurrentID=0, Status='live', Symbol='LATS2', Aliases=['KPM'], description='large tumor suppressor kinase 2', other_designations='serine/threonine-protein kinase LATS2|LATS (large tumor suppressor, Drosophila) homolog 2|LATS, large tumor suppressor, homolog 2|kinase phosphorylated during mitosis protein|large tumor suppressor homolog 2|serine/threonine kinase KPM|serine/threonine-protein kinase kpm|warts-like kinase', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20973036, end_position_on_the_genomic_accession=21061586, orientation='minus', exon_count=11, OMIM=[604861], no_hdr0=''),
    26525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26525, CurrentID=0, Status='live', Symbol='IL36RN', Aliases=['FIL1', 'FIL1(DELTA)', 'FIL1D', 'IL-36Ra', 'IL1F5', 'IL1HY1', 'IL1L1', 'IL1RP3', 'IL36RA', 'PSORP', 'PSORS14'], description='interleukin 36 receptor antagonist', other_designations='interleukin-36 receptor antagonist protein|IL-1 related protein 3|IL-1F5 (IL-1HY1, FIL1-delta, IL-1RP3, IL-1L1, IL-1-delta)|IL-1ra homolog 1|IL1F5 (Canonical product IL-1F5a)|interleukin 1 family, member 5 (delta)|interleukin-1 HY1|interleukin-1 receptor antagonist homolog 1|interleukin-1-like protein 1', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113058638, end_position_on_the_genomic_accession=113064744, orientation='plus', exon_count=6, OMIM=[605507], no_hdr0=''),
    26526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26526, CurrentID=0, Status='live', Symbol='TSPAN16', Aliases=['TM-8', 'TM4-B', 'TM4SF16'], description='tetraspanin 16', other_designations='tetraspanin-16|tetraspanin TM4-B|transmembrane 4 superfamily member 16|tspan-16', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11296144, end_position_on_the_genomic_accession=11326996, orientation='plus', exon_count=9, OMIM=[617580], no_hdr0=''),
    26528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26528, CurrentID=0, Status='live', Symbol='DAZAP1', Aliases=[], description='DAZ associated protein 1', other_designations='DAZ-associated protein 1|deleted in azoospermia-associated protein 1|testicular tissue protein Li 50', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1407586, end_position_on_the_genomic_accession=1435684, orientation='plus', exon_count=16, OMIM=[607430], no_hdr0=''),
    26529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26529, CurrentID=0, Status='live', Symbol='OR12D2', Aliases=['DJ994E9.8', 'HS6M1-20'], description='olfactory receptor family 12 subfamily D member 2', other_designations='olfactory receptor 12D2|olfactory receptor OR6-28', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29395631, end_position_on_the_genomic_accession=29398008, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26530, CurrentID=0, Status='live', Symbol='OR12D1', Aliases=['OR12D1P', 'hs6M1-19'], description='olfactory receptor family 12 subfamily D member 1 (gene/pseudogene)', other_designations='olfactory receptor 12D1|olfactory receptor 12D1 pseudogene|olfactory receptor, family 12, subfamily D, member 1 pseudogene', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29417065, end_position_on_the_genomic_accession=29418396, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26531, CurrentID=0, Status='live', Symbol='OR11A1', Aliases=['6M1-18', 'OR11A2', 'dJ994E9.6', 'hs6M1-18'], description='olfactory receptor family 11 subfamily A member 1', other_designations='olfactory receptor 11A1|olfactory receptor 11A2|olfactory receptor OR6-30|olfactory receptor, family 11, subfamily A, member 2', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29425504, end_position_on_the_genomic_accession=29457071, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    26532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26532, CurrentID=0, Status='live', Symbol='OR10H3', Aliases=[], description='olfactory receptor family 10 subfamily H member 3', other_designations='olfactory receptor 10H3|olfactory receptor OR19-24', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15737985, end_position_on_the_genomic_accession=15742343, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26533, CurrentID=0, Status='live', Symbol='OR10G3', Aliases=['OR14-40'], description='olfactory receptor family 10 subfamily G member 3', other_designations='olfactory receptor 10G3|olfactory receptor OR14-40', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21568520, end_position_on_the_genomic_accession=21580076, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26534, CurrentID=0, Status='live', Symbol='OR10G2', Aliases=['OR14-41'], description='olfactory receptor family 10 subfamily G member 2', other_designations='olfactory receptor 10G2|olfactory receptor OR14-41 pseudogene', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21633836, end_position_on_the_genomic_accession=21634940, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    26538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26538, CurrentID=0, Status='live', Symbol='OR10H2', Aliases=[], description='olfactory receptor family 10 subfamily H member 2', other_designations='olfactory receptor 10H2|olfactory receptor OR19-23', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15728024, end_position_on_the_genomic_accession=15729052, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26539, CurrentID=0, Status='live', Symbol='OR10H1', Aliases=[], description='olfactory receptor family 10 subfamily H member 1', other_designations='olfactory receptor 10H1|olfactory receptor OR19-27', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15804549, end_position_on_the_genomic_accession=15815664, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    26548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26548, CurrentID=0, Status='live', Symbol='ITGB1BP2', Aliases=['CHORDC3', 'ITGB1BP', 'MELUSIN', 'MSTP015'], description='integrin subunit beta 1 binding protein 2', other_designations='integrin beta-1-binding protein 2|integrin beta 1 binding protein (melusin) 2', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71301750, end_position_on_the_genomic_accession=71305371, orientation='plus', exon_count=11, OMIM=[300332], no_hdr0=''),
    26574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26574, CurrentID=0, Status='live', Symbol='AATF', Aliases=['BFR2', 'CHE-1', 'CHE1', 'DED'], description='apoptosis antagonizing transcription factor', other_designations='protein AATF|rb-binding protein Che-1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36948954, end_position_on_the_genomic_accession=37056871, orientation='plus', exon_count=12, OMIM=[608463], no_hdr0=''),
    26575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26575, CurrentID=0, Status='live', Symbol='RGS17', Aliases=['RGS-17', 'RGSZ2', 'hRGS17'], description='regulator of G protein signaling 17', other_designations='regulator of G-protein signaling 17', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=153004459, end_position_on_the_genomic_accession=153131284, orientation='minus', exon_count=5, OMIM=[607191], no_hdr0=''),
    26576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26576, CurrentID=0, Status='live', Symbol='SRPK3', Aliases=['MSSK-1', 'MSSK1', 'STK23'], description='SRSF protein kinase 3', other_designations='SRSF protein kinase 3|SFRS protein kinase 3|SR-protein-specific kinase 3|muscle-specific serine kinase 1|serine arginine rich protein-specific kinase 3|serine/threonine kinase 23|serine/threonine-protein kinase 23|serine/threonine-protein kinase SRPK3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153781041, end_position_on_the_genomic_accession=153785730, orientation='plus', exon_count=15, OMIM=[301002], no_hdr0=''),
    26577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26577, CurrentID=0, Status='live', Symbol='PCOLCE2', Aliases=['PCPE2'], description='procollagen C-endopeptidase enhancer 2', other_designations='procollagen C-endopeptidase enhancer 2|procollagen C-proteinase enhancer 2|procollagen COOH-terminal proteinase enhancer 2', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142817874, end_position_on_the_genomic_accession=142889083, orientation='minus', exon_count=9, OMIM=[607064], no_hdr0=''),
    26578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26578, CurrentID=0, Status='live', Symbol='OSTF1', Aliases=['OSF', 'SH3P2', 'bA235O14.1'], description='osteoclast stimulating factor 1', other_designations='osteoclast-stimulating factor 1', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=75088480, end_position_on_the_genomic_accession=75147265, orientation='plus', exon_count=11, OMIM=[610180], no_hdr0=''),
    26579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26579, CurrentID=0, Status='live', Symbol='MYEOV', Aliases=['OCIM'], description='myeloma overexpressed', other_designations='myeloma-overexpressed gene protein|myeloma overexpressed (in a subset of t(11;14) positive multiple myelomas)|myeloma overexpressed gene (in a subset of t(11;14) positive multiple myelomas)|oncogene in multiple myeloma', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69294155, end_position_on_the_genomic_accession=69297287, orientation='plus', exon_count=3, OMIM=[605625], no_hdr0=''),
    26580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26580, CurrentID=0, Status='live', Symbol='BSCL2', Aliases=['GNG3LG', 'HMN5', 'HMN5C', 'PELD', 'SPG17'], description='BSCL2 lipid droplet biogenesis associated, seipin', other_designations='seipin|BSCL2, seipin lipid droplet biogenesis associated|Berardinelli-Seip congenital lipodystrophy 2 (seipin)|Bernardinelli-Seip congenital lipodystrophy type 2 protein', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62690262, end_position_on_the_genomic_accession=62709537, orientation='minus', exon_count=13, OMIM=[606158], no_hdr0=''),
    26581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26581, CurrentID=0, Status='live', Symbol='DUX5', Aliases=['DUX1'], description='double homeobox 5', other_designations='double homeobox protein 5|double homeobox protein 1', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[611444], no_hdr0=''),
    26582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26582, CurrentID=0, Status='live', Symbol='DUX3', Aliases=[], description='double homeobox 3', other_designations='putative double homeobox protein 3', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[611443], no_hdr0=''),
    26584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26584, CurrentID=0, Status='live', Symbol='DUX1', Aliases=[], description='double homeobox 1', other_designations='double homeobox protein 1', map_location='', chromosome='10', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[611441], no_hdr0=''),
    26585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26585, CurrentID=0, Status='live', Symbol='GREM1', Aliases=['C15DUPq', 'CKTSF1B1', 'CRAC1', 'CRCS4', 'DAND2', 'DRM', 'DUP15q', 'GREMLIN', 'HMPS', 'HMPS1', 'IHG-2', 'MPSH', 'PIG2'], description='gremlin 1, DAN family BMP antagonist', other_designations='gremlin-1|DAN domain family member 2|cell proliferation-inducing gene 2 protein|colorectal adenoma and carcinoma 1|cysteine knot superfamily 1, BMP antagonist 1|down-regulated in Mos-transformed cells protein|gremlin 1, cysteine knot superfamily, homolog|gremlin 1-like protein|hereditary mixed polyposis syndrome|increased in high glucose-2', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32718004, end_position_on_the_genomic_accession=32745106, orientation='plus', exon_count=3, OMIM=[603054], no_hdr0=''),
    26586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26586, CurrentID=0, Status='live', Symbol='CKAP2', Aliases=['LB1', 'TMAP', 'se20-10'], description='cytoskeleton associated protein 2', other_designations='cytoskeleton-associated protein 2|CTCL tumor antigen se20-10|tumor- and microtubule-associated protein|tumor-associated microtubule-associated protein', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52455429, end_position_on_the_genomic_accession=52476627, orientation='plus', exon_count=10, OMIM=[611569], no_hdr0=''),
    26589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26589, CurrentID=0, Status='live', Symbol='MRPL46', Aliases=['C15orf4', 'LIECG2', 'P2ECSL'], description='mitochondrial ribosomal protein L46', other_designations='39S ribosomal protein L46, mitochondrial|L46mt|MRP-L46|mitochondrial large ribosomal subunit protein mL46', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88459478, end_position_on_the_genomic_accession=88467388, orientation='minus', exon_count=4, OMIM=[611851], no_hdr0=''),
    26595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26595, CurrentID=0, Status='live', Symbol='OR8B2', Aliases=['OR11-309', 'OR11-310'], description='olfactory receptor family 8 subfamily B member 2', other_designations='olfactory receptor 8B2|olfactory receptor OR11-309|olfactory receptor OR11-310', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124382394, end_position_on_the_genomic_accession=124397320, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    26608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26608, CurrentID=0, Status='live', Symbol='TBL2', Aliases=['WBSCR13', 'WS-betaTRP'], description='transducin beta like 2', other_designations='transducin beta-like protein 2|WS beta-transducin repeats protein|Williams-Beuren syndrome chromosome region 13|epididymis secretory sperm binding protein|transducin -like 2', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73567537, end_position_on_the_genomic_accession=73578605, orientation='minus', exon_count=9, OMIM=[605842], no_hdr0=''),
    26609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26609, CurrentID=0, Status='live', Symbol='VCX', Aliases=['VCX-10r-B1', 'VCX1', 'VCX10R', 'VCXB1', 'VCX'], description='variable charge X-linked', other_designations='variable charge X-linked protein 1|variable charge protein on X with ten repeats|variable charge, X chromosome|variably charged protein X-B1', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=7842262, end_position_on_the_genomic_accession=7844143, orientation='plus', exon_count=3, OMIM=[300229], no_hdr0=''),
    26610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26610, CurrentID=0, Status='live', Symbol='ELP4', Aliases=['AN', 'AN2', 'C11orf19', 'PAX6NEB', 'PAXNEB', 'dJ68P15A.1', 'hELP4'], description='elongator acetyltransferase complex subunit 4', other_designations='elongator complex protein 4|PAX6 neighbor gene protein|elongation protein 4 homolog', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=31509767, end_position_on_the_genomic_accession=31790324, orientation='plus', exon_count=12, OMIM=[606985], no_hdr0=''),
    26648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26648, CurrentID=0, Status='live', Symbol='OR7E24', Aliases=['HSHT2', 'OR19-8P', 'OR7E24Q', 'OR7E24'], description='olfactory receptor family 7 subfamily E member 24', other_designations='olfactory receptor 7E24|olfactory receptor OR19-14', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9247344, end_position_on_the_genomic_accession=9252625, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26658, CurrentID=0, Status='live', Symbol='OR7C2', Aliases=['CIT-HSP-87M17', 'OR19-18', 'OR7C3'], description='olfactory receptor family 7 subfamily C member 2', other_designations='olfactory receptor 7C2|olfactory receptor 19-18|olfactory receptor 7C3|olfactory receptor OR19-22|olfactory receptor, family 7, subfamily C, member 3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14941489, end_position_on_the_genomic_accession=14942448, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26659, CurrentID=0, Status='live', Symbol='OR7A5', Aliases=['HTPCR2'], description='olfactory receptor family 7 subfamily A member 5', other_designations='olfactory receptor 7A5|olfactory receptor OR19-17|olfactory receptor TPCR92|olfactory receptor, family 7, subfamily A, member 5 pseudogene', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14826241, end_position_on_the_genomic_accession=14835185, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    26664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26664, CurrentID=0, Status='live', Symbol='OR7C1', Aliases=['CIT-HSP-146E8', 'HSTPCR86P', 'OR19-5', 'OR7C4', 'TPCR86'], description='olfactory receptor family 7 subfamily C member 1', other_designations='olfactory receptor 7C1|olfactory receptor 7C4|olfactory receptor OR19-16|olfactory receptor TPCR86|olfactory receptor, family 7, subfamily C, member 4', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14798515, end_position_on_the_genomic_accession=14835185, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    26683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26683, CurrentID=0, Status='live', Symbol='OR4F3', Aliases=[], description='olfactory receptor family 4 subfamily F member 3', other_designations='olfactory receptor 4F3/4F16/4F29|olfactory receptor OR1-1|olfactory receptor OR7-21', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181342142, end_position_on_the_genomic_accession=181370030, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26686, CurrentID=0, Status='live', Symbol='OR4E2', Aliases=['OR14-42'], description='olfactory receptor family 4 subfamily E member 2', other_designations='olfactory receptor 4E2|olfactory receptor OR14-42', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21653835, end_position_on_the_genomic_accession=21667642, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    26687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26687, CurrentID=0, Status='live', Symbol='OR4E1', Aliases=['OR4E1P'], description='olfactory receptor family 4 subfamily E member 1', other_designations='olfactory receptor 4E1|olfactory receptor OR14-43|olfactory receptor, family 4, subfamily E, member 1 pseudogene', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21667886, end_position_on_the_genomic_accession=21673818, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26689, CurrentID=0, Status='live', Symbol='OR4D1', Aliases=['OR17-23', 'OR4D3', 'OR4D4P', 'TPCR16'], description='olfactory receptor family 4 subfamily D member 1', other_designations='olfactory receptor 4D1|olfactory receptor 4D3|olfactory receptor OR17-23 pseudogene|olfactory receptor TPCR16|olfactory receptor, family 4, subfamily D, member 3|olfactory receptor, family 4, subfamily D, member 4 pseudogene|seven transmembrane helix receptor', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58148384, end_position_on_the_genomic_accession=58159585, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    26692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26692, CurrentID=0, Status='live', Symbol='OR2W1', Aliases=['hs6M1-15'], description='olfactory receptor family 2 subfamily W member 1', other_designations='olfactory receptor 2W1|olfactory receptor OR6-13', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29044213, end_position_on_the_genomic_accession=29045175, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    26693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26693, CurrentID=0, Status='live', Symbol='OR2V1', Aliases=['OR2V1P', 'OST265'], description='olfactory receptor family 2 subfamily V member 1', other_designations='olfactory receptor 2V1|olfactory receptor, family 2, subfamily V, member 1 pseudogene', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181123122, end_position_on_the_genomic_accession=181131169, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    26696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26696, CurrentID=0, Status='live', Symbol='OR2T1', Aliases=['OR1-25'], description='olfactory receptor family 2 subfamily T member 1', other_designations='olfactory receptor 2T1|olfactory receptor 1-25|olfactory receptor OR1-61', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248403048, end_position_on_the_genomic_accession=248408020, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26707, CurrentID=0, Status='live', Symbol='OR2J2', Aliases=['OR6-19', 'OR6-8', 'OR6.3.8', 'ORL684', 'dJ80I19.4', 'hs6M1-6'], description='olfactory receptor family 2 subfamily J member 2', other_designations='olfactory receptor 2J2|olfactory receptor 6-8|olfactory receptor OR6-19', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29170907, end_position_on_the_genomic_accession=29175811, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    26716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26716, CurrentID=0, Status='live', Symbol='OR2H1', Aliases=['6M1-16', 'HS6M1-16', 'OLFR42A-9004-14', 'OLFR42A-9004.14/9026.2', 'OR2H6', 'OR2H8', 'OR6-2', 'dJ994E9.4'], description='olfactory receptor family 2 subfamily H member 1', other_designations='olfactory receptor 2H1|olfactory receptor 2H6|olfactory receptor 2H8|olfactory receptor 6-2|olfactory receptor OR6-32|olfactory receptor, family 2, subfamily H, member 6|olfactory receptor, family 2, subfamily H, member 8', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29457133, end_position_on_the_genomic_accession=29464328, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    26735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26735, CurrentID=0, Status='live', Symbol='OR1L3', Aliases=['OR9-28', 'OR9-D'], description='olfactory receptor family 1 subfamily L member 3', other_designations='olfactory receptor 1L3|olfactory receptor 9-D|olfactory receptor OR9-28', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122675130, end_position_on_the_genomic_accession=122676104, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26737, CurrentID=0, Status='live', Symbol='OR1L1', Aliases=['HG23', 'OR1L2', 'OR9-27', 'OR9-C'], description='olfactory receptor family 1 subfamily L member 1', other_designations='olfactory receptor 1L1|olfactory receptor 1L2|olfactory receptor 9-C|olfactory receptor OR9-27|olfactory receptor, family 1, subfamily L, member 2', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122661716, end_position_on_the_genomic_accession=122662648, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    26740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26740, CurrentID=0, Status='live', Symbol='OR1J2', Aliases=['HG152', 'HSA5', 'OR1J3', 'OR1J5', 'OR9-19', 'OST044'], description='olfactory receptor family 1 subfamily J member 2', other_designations='olfactory receptor 1J2|HTPCRX15|olfactory receptor 1J3|olfactory receptor 1J5|olfactory receptor OR9-19|olfactory receptor, family 1, subfamily J, member 3|olfactory receptor, family 1, subfamily J, member 5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122448953, end_position_on_the_genomic_accession=122580427, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    26747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26747, CurrentID=0, Status='live', Symbol='NUFIP1', Aliases=['NUFIP', 'Rsa1', 'bA540M5.1'], description='nuclear FMR1 interacting protein 1', other_designations='nuclear fragile X mental retardation-interacting protein 1|NUFIP1, FMR1 interacting protein 1|nuclear FMRP-interacting protein 1|nuclear fragile X mental retardation protein interacting protein 1', map_location='13q14.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=44939249, end_position_on_the_genomic_accession=44989483, orientation='minus', exon_count=11, OMIM=[604354], no_hdr0=''),
    26748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26748, CurrentID=0, Status='live', Symbol='GAGE12I', Aliases=['AL4', 'CT4.7', 'GAGE-7B', 'GAGE7B'], description='G antigen 12I', other_designations='G antigen 12I|G antigen 12G|G antigen 7B|cancer/testis antigen 4.7|g antigen 12F/G/I', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300637], no_hdr0=''),
    26749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26749, CurrentID=0, Status='live', Symbol='GAGE2E', Aliases=['GAGE-2E', 'GAGE8'], description='G antigen 2E', other_designations='G antigen 2E', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300736], no_hdr0=''),
    26750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26750, CurrentID=0, Status='live', Symbol='RPS6KC1', Aliases=['RPK118', 'RSKL1', 'S6K-delta-1', 'S6PKh1', 'humS6PKh1'], description='ribosomal protein S6 kinase C1', other_designations='ribosomal protein S6 kinase delta-1|52 kDa ribosomal protein S6 kinase|SPHK1-binding protein|ribosomal S6 kinase-like protein with two PSK domains 118 kDa protein|ribosomal protein S6 kinase, 52kDa, polypeptide 1', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=213051241, end_position_on_the_genomic_accession=213378753, orientation='plus', exon_count=22, OMIM=[617517], no_hdr0=''),
    26751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26751, CurrentID=0, Status='live', Symbol='SH3YL1', Aliases=['RAY'], description='SH3 and SYLF domain containing 1', other_designations='SH3 domain-containing YSC84-like protein 1|SH3 domain containing, Ysc84-like 1', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218136, end_position_on_the_genomic_accession=264824, orientation='minus', exon_count=19, OMIM=[617314], no_hdr0=''),
    26762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26762, CurrentID=0, Status='live', Symbol='HAVCR1', Aliases=['CD365', 'HAVCR', 'HAVCR-1', 'KIM-1', 'KIM1', 'TIM', 'TIM-1', 'TIM1', 'TIMD-1', 'TIMD1'], description='hepatitis A virus cellular receptor 1', other_designations='hepatitis A virus cellular receptor 1|T cell immunoglobin domain and mucin domain protein 1|T-cell immunoglobulin mucin family member 1|T-cell immunoglobulin mucin receptor 1|T-cell membrane protein 1|kidney injury molecule 1', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157028383, end_position_on_the_genomic_accession=157069633, orientation='minus', exon_count=11, OMIM=[606518], no_hdr0=''),
    26872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26872, CurrentID=0, Status='live', Symbol='STEAP1', Aliases=['PRSS24', 'STEAP'], description='STEAP family member 1', other_designations='metalloreductase STEAP1|STEAP1 metalloreductase|six transmembrane epithelial antigen of the prostate 1|six-transmembrane epithelial antigen of prostate 1', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90154469, end_position_on_the_genomic_accession=90164827, orientation='plus', exon_count=5, OMIM=[604415], no_hdr0=''),
    26873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26873, CurrentID=0, Status='live', Symbol='OPLAH', Aliases=['5-Opase', 'OPLAD', 'OPLAH'], description='5-oxoprolinase, ATP-hydrolysing', other_designations='5-oxoprolinase|5-oxo-L-prolinase|pyroglutamase', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144051266, end_position_on_the_genomic_accession=144064026, orientation='minus', exon_count=28, OMIM=[614243], no_hdr0=''),
    26952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26952, CurrentID=0, Status='live', Symbol='SMR3A', Aliases=['P-B1', 'PBI', 'PRL5', 'PROL5'], description='submaxillary gland androgen regulated protein 3A', other_designations='submaxillary gland androgen-regulated protein 3A|proline rich 5 (salivary)|proline- rich protein 5|proline-rich protein PBI|protein homologous to salivary proline-rich protein P-B|submaxillary gland androgen regulated protein 3 homolog A', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70360760, end_position_on_the_genomic_accession=70367158, orientation='plus', exon_count=3, OMIM=[618340], no_hdr0=''),
    26953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26953, CurrentID=0, Status='live', Symbol='RANBP6', Aliases=[], description='RAN binding protein 6', other_designations='ran-binding protein 6|Ran-GTP binding protein', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6011025, end_position_on_the_genomic_accession=6015660, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    26958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26958, CurrentID=0, Status='live', Symbol='COPG2', Aliases=['2-COP', 'gamma-2-COP'], description='COPI coat complex subunit gamma 2', other_designations='coatomer subunit gamma-2|coat protein, nonclathrin, gamma-2-cop|coatomer protein complex subunit gamma 2|gamma-2-coat protein|testicular secretory protein Li 12', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130506238, end_position_on_the_genomic_accession=130668748, orientation='minus', exon_count=24, OMIM=[604355], no_hdr0=''),
    26959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26959, CurrentID=0, Status='live', Symbol='HBP1', Aliases=[], description='HMG-box transcription factor 1', other_designations='HMG box-containing protein 1|high mobility group box transcription factor 1', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107168987, end_position_on_the_genomic_accession=107202523, orientation='plus', exon_count=14, OMIM=[616714], no_hdr0=''),
    26960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26960, CurrentID=0, Status='live', Symbol='NBEA', Aliases=['BCL8B', 'LYST2', 'NEDEGE'], description='neurobeachin', other_designations='neurobeachin|lysosomal-trafficking regulator 2', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=34942270, end_position_on_the_genomic_accession=35672736, orientation='plus', exon_count=63, OMIM=[604889], no_hdr0=''),
    26973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26973, CurrentID=0, Status='live', Symbol='CHORDC1', Aliases=['CHP1'], description='cysteine and histidine rich domain containing 1', other_designations='cysteine and histidine-rich domain-containing protein 1|CHORD-containing protein 1|CHP-1|chord domain-containing protein 1|cysteine and histidine-rich domain (CHORD) containing 1|cysteine and histidine-rich domain (CHORD)-containing, zinc-binding protein 1|morgana|protein morgana', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=90200429, end_position_on_the_genomic_accession=90223082, orientation='minus', exon_count=14, OMIM=[604353], no_hdr0=''),
    26974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26974, CurrentID=0, Status='live', Symbol='ZNF285', Aliases=['ZNF285A'], description='zinc finger protein 285', other_designations='zinc finger protein 285|zinc finger protein 285A', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44382298, end_position_on_the_genomic_accession=44401608, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    26984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26984, CurrentID=0, Status='live', Symbol='SEC22A', Aliases=['SEC22L2'], description='SEC22 homolog A, vesicle trafficking protein', other_designations='vesicle-trafficking protein SEC22a|SEC22 vesicle trafficking protein homolog A|SEC22 vesicle trafficking protein-like 2', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123201943, end_position_on_the_genomic_accession=123274136, orientation='plus', exon_count=9, OMIM=[612442], no_hdr0=''),
    26985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26985, CurrentID=0, Status='live', Symbol='AP3M1', Aliases=[], description='adaptor related protein complex 3 subunit mu 1', other_designations='AP-3 complex subunit mu-1|AP-3 adapter complex mu3A subunit|adapter-related protein complex 3 mu-1 subunit|adaptor related protein complex 3 mu 1 subunit|clathrin adaptor complex AP3, mu-3A subunit|mu-adaptin 3A|mu3A-adaptin', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=74120012, end_position_on_the_genomic_accession=74151067, orientation='minus', exon_count=11, OMIM=[610366], no_hdr0=''),
    26986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26986, CurrentID=0, Status='live', Symbol='PABPC1', Aliases=['PAB1', 'PABP', 'PABP1', 'PABPC2', 'PABPL1'], description='poly(A) binding protein cytoplasmic 1', other_designations='polyadenylate-binding protein 1|poly(A) binding protein, cytoplasmic 2', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100702916, end_position_on_the_genomic_accession=100722088, orientation='minus', exon_count=15, OMIM=[604679], no_hdr0=''),
    26993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26993, CurrentID=0, Status='live', Symbol='AKAP8L', Aliases=['HA95', 'HAP95', 'NAKAP', 'NAKAP95'], description='A-kinase anchoring protein 8 like', other_designations='A-kinase anchor protein 8-like|A kinase (PRKA) anchor protein 8-like|AKAP8-like protein|helicase A-binding protein 95 kDa|homologous to AKAP95 protein|neighbor of A-kinase anchoring protein 95|neighbor of AKAP95|testis tissue sperm-binding protein Li 90mP', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15380050, end_position_on_the_genomic_accession=15418988, orientation='minus', exon_count=16, OMIM=[609475], no_hdr0=''),
    26994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26994, CurrentID=0, Status='live', Symbol='RNF11', Aliases=['CGI-123', 'SID1669'], description='ring finger protein 11', other_designations='RING finger protein 11', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51236273, end_position_on_the_genomic_accession=51273447, orientation='plus', exon_count=3, OMIM=[612598], no_hdr0=''),
    26995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26995, CurrentID=0, Status='live', Symbol='TRUB2', Aliases=['CLONE24922'], description='TruB pseudouridine synthase family member 2', other_designations='mitochondrial mRNA pseudouridine synthase TRUB2|TruB pseudouridine (psi) synthase family member 2|TruB pseudouridine (psi) synthase homolog 2|probable tRNA pseudouridine synthase 2', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128305159, end_position_on_the_genomic_accession=128322447, orientation='minus', exon_count=10, OMIM=[610727], no_hdr0=''),
    26996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26996, CurrentID=0, Status='live', Symbol='GPR160', Aliases=['GPCR1', 'GPCR150'], description='G protein-coupled receptor 160', other_designations='probable G-protein coupled receptor 160|G-protein coupled receptor GPCR1|hGPCR1|putative G protein-coupled receptor', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170037995, end_position_on_the_genomic_accession=170085417, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    26998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26998, CurrentID=0, Status='live', Symbol='FETUB', Aliases=['16G2', 'Gugu', 'IRL685'], description='fetuin B', other_designations='fetuin-B|fetuin-like protein IRL685', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186635969, end_position_on_the_genomic_accession=186653141, orientation='plus', exon_count=8, OMIM=[605954], no_hdr0=''),
    26999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=26999, CurrentID=0, Status='live', Symbol='CYFIP2', Aliases=['DEE65', 'EIEE65', 'PIR121'], description='cytoplasmic FMR1 interacting protein 2', other_designations='cytoplasmic FMR1-interacting protein 2|p53-inducible protein 121', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157266091, end_position_on_the_genomic_accession=157395594, orientation='plus', exon_count=37, OMIM=[606323], no_hdr0=''),
    27000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27000, CurrentID=0, Status='live', Symbol='DNAJC2', Aliases=['MPHOSPH11', 'MPP11', 'ZRF1', 'ZUO1'], description='DnaJ heat shock protein family (Hsp40) member C2', other_designations='dnaJ homolog subfamily C member 2|DnaJ (Hsp40) homolog, subfamily C, member 2|M-phase phosphoprotein 11|zuotin-related factor 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103312289, end_position_on_the_genomic_accession=103344790, orientation='minus', exon_count=19, OMIM=[605502], no_hdr0=''),
    27005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27005, CurrentID=0, Status='live', Symbol='USP21', Aliases=['USP16', 'USP23'], description='ubiquitin specific peptidase 21', other_designations='ubiquitin carboxyl-terminal hydrolase 21|NEDD8-specific protease|deubiquitinating enzyme 21|ubiquitin specific protease 21|ubiquitin thioesterase 21|ubiquitin thiolesterase 21|ubiquitin-specific processing protease 21|ubiquitin-specific protease 16', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161159487, end_position_on_the_genomic_accession=161165752, orientation='plus', exon_count=13, OMIM=[604729], no_hdr0=''),
    27006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27006, CurrentID=0, Status='live', Symbol='FGF22', Aliases=[], description='fibroblast growth factor 22', other_designations='fibroblast growth factor 22|FGF-22', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=639879, end_position_on_the_genomic_accession=644373, orientation='plus', exon_count=3, OMIM=[605831], no_hdr0=''),
    27010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27010, CurrentID=0, Status='live', Symbol='TPK1', Aliases=['HTPK1', 'PP20', 'THMD5'], description='thiamin pyrophosphokinase 1', other_designations='thiamin pyrophosphokinase 1|placental protein 20|thiamine diphosphokinase|thiamine kinase', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144451941, end_position_on_the_genomic_accession=144836424, orientation='minus', exon_count=27, OMIM=[606370], no_hdr0=''),
    27012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27012, CurrentID=0, Status='live', Symbol='KCNV1', Aliases=['HNKA', 'KCNB3', 'KV2.3', 'KV8.1'], description='potassium voltage-gated channel modifier subfamily V member 1', other_designations='potassium voltage-gated channel subfamily V member 1|neuronal potassium channel alpha subunit HNKA|potassium channel Kv8.1|potassium channel, subfamily V, member 1|potassium channel, voltage gated modifier subfamily V, member 1|voltage-gated potassium channel subunit Kv8.1', map_location='8q23.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109963636, end_position_on_the_genomic_accession=109975771, orientation='minus', exon_count=4, OMIM=[608164], no_hdr0=''),
    27013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27013, CurrentID=0, Status='live', Symbol='CNPPD1', Aliases=['C2orf24', 'CGI-57'], description='cyclin Pas1/PHO80 domain containing 1', other_designations='protein CNPPD1|cyclin Pas1/PHO80 domain-containing protein 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219171897, end_position_on_the_genomic_accession=219179272, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    27018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27018, CurrentID=0, Status='live', Symbol='BEX3', Aliases=['Bex', 'DXS6984E', 'HGR74', 'NADE', 'NGFRAP1'], description='brain expressed X-linked 3', other_designations='protein BEX3|brain-expressed X-linked protein 3|nerve growth factor receptor (TNFRSF16) associated protein 1|ovarian granulosa cell 13.0 kDa protein HGR74|p75NTR-associated cell death executor', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103376323, end_position_on_the_genomic_accession=103378164, orientation='plus', exon_count=3, OMIM=[300361], no_hdr0=''),
    27019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27019, CurrentID=0, Status='live', Symbol='DNAI1', Aliases=['CILD1', 'DIC1', 'ICS1', 'PCD'], description='dynein axonemal intermediate chain 1', other_designations='dynein axonemal intermediate chain 1|dynein, axonemal, intermediate polypeptide 1|immotile cilia syndrome 1|testis tissue sperm-binding protein Li 87P', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34458805, end_position_on_the_genomic_accession=34520984, orientation='plus', exon_count=20, OMIM=[604366], no_hdr0=''),
    27020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27020, CurrentID=0, Status='live', Symbol='NPTN', Aliases=['GP55', 'GP65', 'SDFR1', 'SDR1', 'np55', 'np65'], description='neuroplastin', other_designations='neuroplastin|SDR-1|stromal cell derived factor receptor 1|stromal cell-derived receptor 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73560014, end_position_on_the_genomic_accession=73633389, orientation='minus', exon_count=13, OMIM=[612820], no_hdr0=''),
    27022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27022, CurrentID=0, Status='live', Symbol='FOXD3', Aliases=['AIS1', 'Genesis', 'HFH2', 'VAMAS2'], description='forkhead box D3', other_designations='forkhead box protein D3|HNF3/FH transcription factor genesis', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63322567, end_position_on_the_genomic_accession=63325128, orientation='plus', exon_count=1, OMIM=[611539], no_hdr0=''),
    27023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27023, CurrentID=0, Status='live', Symbol='FOXB1', Aliases=['FKH5', 'HFKH-5'], description='forkhead box B1', other_designations='forkhead box protein B1|transcription factor FKH-5', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=60004311, end_position_on_the_genomic_accession=60007444, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    27030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27030, CurrentID=0, Status='live', Symbol='MLH3', Aliases=['HNPCC7'], description='mutL homolog 3', other_designations='DNA mismatch repair protein Mlh3', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75013764, end_position_on_the_genomic_accession=75051479, orientation='minus', exon_count=14, OMIM=[604395], no_hdr0=''),
    27031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27031, CurrentID=0, Status='live', Symbol='NPHP3', Aliases=['CFAP31', 'MKS7', 'NPH3', 'RHPD', 'RHPD1', 'SLSN3'], description='nephrocystin 3', other_designations='nephrocystin-3|Meckel syndrome, type 7|cilia and flagella associated protein 31|nephronophthisis 3 (adolescent)', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132680609, end_position_on_the_genomic_accession=132722409, orientation='minus', exon_count=27, OMIM=[608002], no_hdr0=''),
    27032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27032, CurrentID=0, Status='live', Symbol='ATP2C1', Aliases=['ATP2C1A', 'BCPM', 'HHD', 'PMR1', 'SPCA1', 'hSPCA1'], description='ATPase secretory pathway Ca2+ transporting 1', other_designations='calcium-transporting ATPase type 2C member 1|ATP-dependent Ca(2+) pump PMR1|ATPase 2C1|ATPase, Ca(2+)-sequestering|ATPase, Ca++ transporting, type 2C, member 1|Ca(2+)/Mn(2+)-ATPase 2C1|HUSSY-28|secretory pathway Ca(2+)-transporting ATPase type 1|secretory pathway Ca2+/Mn2+ ATPase 1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130850595, end_position_on_the_genomic_accession=131016712, orientation='plus', exon_count=31, OMIM=[604384], no_hdr0=''),
    27033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27033, CurrentID=0, Status='live', Symbol='ZBTB32', Aliases=['FAXF', 'FAZF', 'Rog', 'TZFP', 'ZNF538'], description='zinc finger and BTB domain containing 32', other_designations='zinc finger and BTB domain-containing protein 32|FANCC-interacting protein|fanconi anemia zinc finger protein|repressor of GATA|testis zinc finger protein|zinc finger protein 538', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35704481, end_position_on_the_genomic_accession=35717048, orientation='plus', exon_count=7, OMIM=[605859], no_hdr0=''),
    27034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27034, CurrentID=0, Status='live', Symbol='ACAD8', Aliases=['ACAD-8', 'ARC42', 'IBDH'], description='acyl-CoA dehydrogenase family member 8', other_designations='isobutyryl-CoA dehydrogenase, mitochondrial|activator-recruited cofactor 42 kDa component|acyl-Coenzyme A dehydrogenase family, member 8', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134253538, end_position_on_the_genomic_accession=134265858, orientation='plus', exon_count=14, OMIM=[604773], no_hdr0=''),
    27035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27035, CurrentID=0, Status='live', Symbol='NOX1', Aliases=['GP91-2', 'MOX1', 'NOH-1', 'NOH1'], description='NADPH oxidase 1', other_designations='NADPH oxidase 1|NADH/NADPH mitogenic oxidase subunit P65-MOX|NADPH oxidase homolog-1|mitogenic oxidase (pyridine nucleotide-dependent superoxide-generating)|mitogenic oxidase 1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100843324, end_position_on_the_genomic_accession=100874359, orientation='minus', exon_count=14, OMIM=[300225], no_hdr0=''),
    27036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27036, CurrentID=0, Status='live', Symbol='SIGLEC7', Aliases=['AIRM-1', 'AIRM1', 'CD328', 'CDw328', 'D-siglec', 'QA79', 'SIGLEC-7', 'SIGLEC19P', 'SIGLECP2', 'p75', 'p75/AIRM1'], description='sialic acid binding Ig like lectin 7', other_designations='sialic acid-binding Ig-like lectin 7|QA79 membrane protein|adhesion inhibitory receptor molecule 1, siglec-7|sialic acid binding immunoglobulin-like lectin 7', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51142260, end_position_on_the_genomic_accession=51153526, orientation='plus', exon_count=7, OMIM=[604410], no_hdr0=''),
    27037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27037, CurrentID=0, Status='live', Symbol='TRMT2A', Aliases=['HTF9C'], description='tRNA methyltransferase 2 homolog A', other_designations='tRNA (uracil-5-)-methyltransferase homolog A|TRM2 tRNA methyltransferase 2 homolog A|hpaII tiny fragments locus 9c protein', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20111872, end_position_on_the_genomic_accession=20117254, orientation='minus', exon_count=14, OMIM=[611151], no_hdr0=''),
    27039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27039, CurrentID=0, Status='live', Symbol='PKD2L2', Aliases=['TRPP5'], description='polycystin 2 like 2, transient receptor potential cation channel', other_designations='polycystic kidney disease 2-like 2 protein|polycystin-2L2|polycystin-L2|transient receptor potential cation channel subfamily P member 5', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=137889411, end_position_on_the_genomic_accession=137942747, orientation='plus', exon_count=16, OMIM=[604669], no_hdr0=''),
    27040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27040, CurrentID=0, Status='live', Symbol='LAT', Aliases=['IMD521', 'pp36', 'LAT'], description='linker for activation of T cells', other_designations='linker for activation of T-cells family member 1|36 kDa phospho-tyrosine adapter protein|36 kDa phospho-tyrosine adaptor protein|linker for activation of T cells, transmembrane adaptor|p36-38', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28984803, end_position_on_the_genomic_accession=28990784, orientation='plus', exon_count=12, OMIM=[602354], no_hdr0=''),
    27042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27042, CurrentID=0, Status='live', Symbol='UTP25', Aliases=['C1orf107', 'DEF', 'DIEXF', 'DJ434O14.5'], description='UTP25 small subunit processor component', other_designations='U3 small nucleolar RNA-associated protein 25 homolog|digestive organ expansion factor homolog|digestive-organ expansion factor homolog', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209827972, end_position_on_the_genomic_accession=209857565, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    27043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27043, CurrentID=0, Status='live', Symbol='PELP1', Aliases=['MNAR', 'P160'], description='proline, glutamate and leucine rich protein 1', other_designations='proline-, glutamic acid- and leucine-rich protein 1|modulator of non-genomic activity of estrogen receptor|proline and glutamic acid rich nuclear protein|transcription factor HMX3', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4669774, end_position_on_the_genomic_accession=4704137, orientation='minus', exon_count=19, OMIM=[609455], no_hdr0=''),
    27044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27044, CurrentID=0, Status='live', Symbol='SND1', Aliases=['TDRD11', 'Tudor-SN', 'p100'], description='staphylococcal nuclease and tudor domain containing 1', other_designations='staphylococcal nuclease domain-containing protein 1|EBNA2 coactivator p100|testis tissue sperm-binding protein Li 82P|tudor domain-containing protein 11', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127652145, end_position_on_the_genomic_accession=128092593, orientation='plus', exon_count=25, OMIM=[602181], no_hdr0=''),
    27063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27063, CurrentID=0, Status='live', Symbol='ANKRD1', Aliases=['ALRP', 'C-193', 'CARP', 'CVARP', 'MCARP', 'bA320F15.2'], description='ankyrin repeat domain 1', other_designations='ankyrin repeat domain-containing protein 1|ankyrin repeat domain 1 (cardiac muscle)|cardiac ankyrin repeat protein|cytokine-inducible gene C-193 protein|cytokine-inducible nuclear protein|epididymis secretory sperm binding protein|liver ankyrin repeat domain 1', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=90912096, end_position_on_the_genomic_accession=90921087, orientation='minus', exon_count=9, OMIM=[609599], no_hdr0=''),
    27065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27065, CurrentID=0, Status='live', Symbol='NSG1', Aliases=['D4S234', 'D4S234E', 'NEEP21', 'P21'], description='neuronal vesicle trafficking associated 1', other_designations='neuronal vesicle trafficking-associated protein 1|brain neuron cytoplasmic protein 1|carboxyterminally EE-tagged neuron-enriched endosomal 21 kDa protein|neuron specific gene family member 1|neuron-enriched endosomal protein of 21 kDa|neuron-specific protein family member 1', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4386532, end_position_on_the_genomic_accession=4419058, orientation='plus', exon_count=8, OMIM=[607645], no_hdr0=''),
    27067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27067, CurrentID=0, Status='live', Symbol='STAU2', Aliases=['39K2', '39K3'], description='staufen double-stranded RNA binding protein 2', other_designations='double-stranded RNA-binding protein Staufen homolog 2|staufen homolog 2|staufen, RNA binding protein, homolog 2', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73420369, end_position_on_the_genomic_accession=73747480, orientation='minus', exon_count=17, OMIM=[605920], no_hdr0=''),
    27068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27068, CurrentID=0, Status='live', Symbol='PPA2', Aliases=['HSPC124', 'SCFAI', 'SCFI', 'SID6-306'], description='inorganic pyrophosphatase 2', other_designations='inorganic pyrophosphatase 2, mitochondrial|PPase 2|pyrophosphatase (inorganic) 2|pyrophosphatase SID6-306|pyrophosphate phospho-hydrolase 2', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105369077, end_position_on_the_genomic_accession=105474070, orientation='minus', exon_count=12, OMIM=[609988], no_hdr0=''),
    27069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27069, CurrentID=0, Status='live', Symbol='GHITM', Aliases=['DERP2', 'HSPC282', 'MICS1', 'My021', 'PTD010', 'TMBIM5'], description='growth hormone inducible transmembrane protein', other_designations='growth hormone-inducible transmembrane protein|dermal papilla-derived protein 2|mitochondrial morphology and cristae structure 1|transmembrane BAX inhibitor motif containing 5|transmembrane BAX inhibitor motif-containing protein 5', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84139509, end_position_on_the_genomic_accession=84153568, orientation='plus', exon_count=9, OMIM=[619205], no_hdr0=''),
    27071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27071, CurrentID=0, Status='live', Symbol='DAPP1', Aliases=['BAM32'], description='dual adaptor of phosphotyrosine and 3-phosphoinositides 1', other_designations='dual adapter for phosphotyrosine and 3-phosphotyrosine and 3-phosphoinositide|B-cell adapter molecule of 32 kDa|b lymphocyte adapter protein Bam32|hDAPP1', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99816827, end_position_on_the_genomic_accession=99872290, orientation='plus', exon_count=13, OMIM=[605768], no_hdr0=''),
    27072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27072, CurrentID=0, Status='live', Symbol='VPS41', Aliases=['HVPS41', 'HVSP41', 'SCAR29', 'hVps41p'], description='VPS41 subunit of HOPS complex', other_designations='vacuolar protein sorting-associated protein 41 homolog|S53|VPS41, HOPS complex subunit|vacuolar assembly protein 41|vacuolar protein sorting 41 homolog', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38722974, end_position_on_the_genomic_accession=38909200, orientation='minus', exon_count=31, OMIM=[605485], no_hdr0=''),
    27074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27074, CurrentID=0, Status='live', Symbol='LAMP3', Aliases=['CD208', 'DC LAMP', 'DC-LAMP', 'DCLAMP', 'LAMP', 'LAMP-3', 'TSC403'], description='lysosomal associated membrane protein 3', other_designations='lysosome-associated membrane glycoprotein 3|DC-lysosome-associated membrane glycoprotein', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183122215, end_position_on_the_genomic_accession=183162761, orientation='minus', exon_count=11, OMIM=[605883], no_hdr0=''),
    27075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27075, CurrentID=0, Status='live', Symbol='TSPAN13', Aliases=['NET-6', 'NET6', 'TM4SF13'], description='tetraspanin 13', other_designations='tetraspanin-13|tetraspan NET-6|transmembrane 4 superfamily member 13|transmembrane 4 superfamily member tetraspan NET-6|tspan-13', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16753755, end_position_on_the_genomic_accession=16784536, orientation='plus', exon_count=6, OMIM=[613139], no_hdr0=''),
    27076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27076, CurrentID=0, Status='live', Symbol='LYPD3', Aliases=['C4.4A'], description='LY6/PLAUR domain containing 3', other_designations='ly6/PLAUR domain-containing protein 3|2310061G07Rik|GPI-anchored metastasis-associated protein C4.4A homolog|GPI-anchored metastasis-associated protein homolog|MIG-C4|matrigel-induced gene C4 protein', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43460787, end_position_on_the_genomic_accession=43465608, orientation='minus', exon_count=5, OMIM=[609484], no_hdr0=''),
    27077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27077, CurrentID=0, Status='live', Symbol='B9D1', Aliases=['B9', 'EPPB9', 'JBTS27', 'MKS9', 'MKSR-1', 'MKSR1'], description='B9 domain containing 1', other_designations='B9 domain-containing protein 1|B9 protein domain 1|MKS1-related protein 1|endothelial precursor protein B9', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19334695, end_position_on_the_genomic_accession=19377913, orientation='minus', exon_count=11, OMIM=[614144], no_hdr0=''),
    27079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27079, CurrentID=0, Status='live', Symbol='RPUSD2', Aliases=['C15orf19', 'C18B11', 'PUS9'], description='RNA pseudouridine synthase domain containing 2', other_designations='RNA pseudouridylate synthase domain-containing protein 2|C18B11 homolog (44.9kD)|RNA pseudouridylate synthase domain containing 2', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40569299, end_position_on_the_genomic_accession=40574949, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    27085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27085, CurrentID=0, Status='live', Symbol='MTBP', Aliases=['MDM2BP'], description='MDM2 binding protein', other_designations='mdm2-binding protein|MDM2 (mouse double minute 2)-binding protein, 104kD|Mdm2, transformed 3T3 cell double minute 2, p53 binding protein binding protein, 104kDa', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=120445401, end_position_on_the_genomic_accession=120523636, orientation='plus', exon_count=25, OMIM=[605927], no_hdr0=''),
    27086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27086, CurrentID=0, Status='live', Symbol='FOXP1', Aliases=['12CC4', 'HSPC215', 'MFH', 'QRF1', 'hFKH1B'], description='forkhead box P1', other_designations='forkhead box protein P1|fork head-related protein like B|glutamine-rich factor 1|mac-1-regulated forkhead', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=70954708, end_position_on_the_genomic_accession=71583978, orientation='minus', exon_count=30, OMIM=[605515], no_hdr0=''),
    27087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27087, CurrentID=0, Status='live', Symbol='B3GAT1', Aliases=['CD57', 'GLCATP', 'GLCUATP', 'HNK1', 'LEU7', 'NK-1', 'NK1'], description='beta-1,3-glucuronyltransferase 1', other_designations='galactosylgalactosylxylosylprotein 3-beta-glucuronosyltransferase 1|LEU7 antigen|UDP-GlcUA:glycoprotein beta-1,3-glucuronyltransferase|glucuronosyltransferase P', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134378504, end_position_on_the_genomic_accession=134412242, orientation='minus', exon_count=11, OMIM=[151290], no_hdr0=''),
    27089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27089, CurrentID=0, Status='live', Symbol='UQCRQ', Aliases=['MC3DN4', 'QCR8', 'QP-C', 'QPC', 'UQCR7'], description='ubiquinol-cytochrome c reductase complex III subunit VII', other_designations='cytochrome b-c1 complex subunit 8|complex III subunit 8|complex III subunit VIII|low molecular mass ubiquinone-binding protein (9.5kD)|ubiquinol-cytochrome c reductase complex 9.5 kDa protein|ubiquinol-cytochrome c reductase complex ubiquinone-binding protein QP-C|ubiquinol-cytochrome c reductase, complex III subunit VII, 9.5kDa', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132866642, end_position_on_the_genomic_accession=132868847, orientation='plus', exon_count=3, OMIM=[612080], no_hdr0=''),
    27090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27090, CurrentID=0, Status='live', Symbol='ST6GALNAC4', Aliases=['IV', 'SIAT3-C', 'SIAT3C', 'SIAT7-D', 'SIAT7D', 'ST6GALNACIV', 'ST6GalNAc'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 4', other_designations='alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3-N-acetyl-galactosaminide alpha-2,6-sialyltransferase|NeuAc-alpha-2,3-Gal-beta-1,3-GalNAc-alpha-2, 6-sialyltransferase alpha2,6-sialyltransferase|NeuAc-alpha-2,3-Gal-beta-1,3-GalNAc-alpha-2,6-sialyltransferase IV|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 4|ST6 GalNAc alpha-2,6-sialyltransferase 4|ST6 neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminidealpha-2,6-sialyltransferase 4|ST6GalNAc IV|sialyltransferase 3C|sialyltransferase 7D ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase)', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127907886, end_position_on_the_genomic_accession=127917052, orientation='minus', exon_count=8, OMIM=[606378], no_hdr0=''),
    27091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27091, CurrentID=0, Status='live', Symbol='CACNG5', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 5', other_designations='voltage-dependent calcium channel gamma-5 subunit|TARP gamma-5|calcium channel, voltage-dependent, gamma subunit 5|neuronal voltage-gated calcium channel gamma-5 subunit|transmembrane AMPAR regulatory protein gamma-5', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=66835117, end_position_on_the_genomic_accession=66894751, orientation='plus', exon_count=6, OMIM=[606405], no_hdr0=''),
    27092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27092, CurrentID=0, Status='live', Symbol='CACNG4', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 4', other_designations='voltage-dependent calcium channel gamma-4 subunit|TARP gamma-4|calcium channel, voltage-dependent, gamma subunit 4|neuronal voltage-gated calcium channel gamma-4 subunit|transmembrane AMPAR regulatory protein gamma-4', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=66964707, end_position_on_the_genomic_accession=67033398, orientation='plus', exon_count=4, OMIM=[606404], no_hdr0=''),
    27094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27094, CurrentID=0, Status='live', Symbol='KCNMB3', Aliases=['BKBETA3', 'HBETA3', 'K(VCA)BETA-3', 'KCNMB2', 'KCNMBL', 'SLO-BETA-3', 'SLOBETA3'], description='potassium calcium-activated channel subfamily M regulatory beta subunit 3', other_designations='calcium-activated potassium channel subunit beta-3|BK channel beta subunit 3|BK channel subunit beta-3|MaxiK channel beta-subunit 3|big potassium channel beta subunit 3|calcium-activated potassium channel regulatory subunit|calcium-activated potassium channel, subfamily M subunit beta-3|charybdotoxin receptor subunit beta-3|large conductance, voltage and Ca2+ activated potassium channel Maxi K beta 3 subunit|maxi K channel subunit beta-3|potassium channel subfamily M regulatory beta subunit 3|potassium large conductance calcium-activated channel, subfamily M beta member 3', map_location='3q26.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179239703, end_position_on_the_genomic_accession=179267050, orientation='minus', exon_count=7, OMIM=[605222], no_hdr0=''),
    27095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27095, CurrentID=0, Status='live', Symbol='TRAPPC3', Aliases=['BET3'], description='trafficking protein particle complex subunit 3', other_designations='trafficking protein particle complex subunit 3|trafficking protein particle complex 3', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36136572, end_position_on_the_genomic_accession=36156053, orientation='minus', exon_count=6, OMIM=[610955], no_hdr0=''),
    27097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27097, CurrentID=0, Status='live', Symbol='TAF5L', Aliases=['PAF65B'], description='TATA-box binding protein associated factor 5 like', other_designations='TAF5-like RNA polymerase II p300/CBP-associated factor-associated factor 65 kDa subunit 5L|PAF65-beta|PCAF-associated factor 65 beta|TAF5-like RNA polymerase II, p300/CBP-associated factor (PCAF)-associated factor, 65kDa', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229593111, end_position_on_the_genomic_accession=229626122, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    27098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27098, CurrentID=0, Status='live', Symbol='CLUL1', Aliases=['RA337M'], description='clusterin like 1', other_designations='clusterin-like protein 1|clusterin-like 1 (retinal)|retinal clusterin-like protein|retinal-specific clusterin-like protein', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=596988, end_position_on_the_genomic_accession=650298, orientation='plus', exon_count=17, OMIM=[616990], no_hdr0=''),
    27101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27101, CurrentID=0, Status='live', Symbol='CACYBP', Aliases=['GIG5', 'PNAS-107', 'S100A6BP', 'SIP'], description='calcyclin binding protein', other_designations='calcyclin-binding protein|S100A6-binding protein|Siah-interacting protein (SIP)|growth-inhibiting gene 5 protein|hCacyBP', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=174999435, end_position_on_the_genomic_accession=175012027, orientation='plus', exon_count=8, OMIM=[606186], no_hdr0=''),
    27102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27102, CurrentID=0, Status='live', Symbol='EIF2AK1', Aliases=['HCR', 'HRI', 'LEMSPAD', 'hHRI'], description='eukaryotic translation initiation factor 2 alpha kinase 1', other_designations='eukaryotic translation initiation factor 2-alpha kinase 1|heme regulated initiation factor 2 alpha kinase|heme sensitive initiation factor 2a kinase|heme-controlled repressor|heme-regulated eukaryotic initiation factor eIF-2-alpha kinase|heme-regulated inhibitor|heme-regulated repressor|hemin-sensitive initiation factor 2-alpha kinase', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6022247, end_position_on_the_genomic_accession=6059175, orientation='minus', exon_count=15, OMIM=[613635], no_hdr0=''),
    27106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27106, CurrentID=0, Status='live', Symbol='ARRDC2', Aliases=['CLONE24945', 'PP2703'], description='arrestin domain containing 2', other_designations='arrestin domain-containing protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18001124, end_position_on_the_genomic_accession=18014102, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    27107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27107, CurrentID=0, Status='live', Symbol='ZBTB11', Aliases=['MRT69', 'ZNF-U69274', 'ZNF913'], description='zinc finger and BTB domain containing 11', other_designations='zinc finger and BTB domain-containing protein 11', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101648889, end_position_on_the_genomic_accession=101677132, orientation='minus', exon_count=13, OMIM=[618181], no_hdr0=''),
    27109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27109, CurrentID=0, Status='live', Symbol='DMAC2L', Aliases=['ATP5S', 'ATPW', 'FB', 'HSU79253'], description='distal membrane arm assembly component 2 like', other_designations='ATP synthase subunit s, mitochondrial|ATP synthase coupling factor B, mitochondrial|ATP synthase coupling factor B-like 1|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit s (factor B)|ATP synthase, H+ transporting, mitochondrial Fo complex subunit s (factor B)|ATP synthase-coupling factor B|distal membrane arm assembly complex 2 like|distal membrane arm assembly complex 2-like protein|mitochondrial ATP synthase regulatory component factor B', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50311516, end_position_on_the_genomic_accession=50327957, orientation='plus', exon_count=12, OMIM=[618579], no_hdr0=''),
    27111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27111, CurrentID=0, Status='live', Symbol='SDCBP2', Aliases=['SITAC', 'SITAC18', 'ST-2', 'ST2'], description='syndecan binding protein 2', other_designations='syntenin-2|syndecan binding protein (syntenin) 2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1309909, end_position_on_the_genomic_accession=1329139, orientation='minus', exon_count=10, OMIM=[617358], no_hdr0=''),
    27112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27112, CurrentID=0, Status='live', Symbol='NALF2', Aliases=['CXorf63', 'FAM155B', 'TED', 'TMEM28', 'bB57D9.1'], description='NALCN channel auxiliary factor 2', other_designations='transmembrane protein FAM155B|bB57D9.1 (TED protein)|family with sequence similarity 155 member B|transmembrane protein 28', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=69504326, end_position_on_the_genomic_accession=69532508, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    27113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27113, CurrentID=0, Status='live', Symbol='BBC3', Aliases=['JFY-1', 'JFY1', 'PUMA'], description='BCL2 binding component 3', other_designations='bcl-2-binding component 3|p53 up-regulated modulator of apoptosis|p53-upregulated modulator of apoptosis', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47220822, end_position_on_the_genomic_accession=47232998, orientation='minus', exon_count=7, OMIM=[605854], no_hdr0=''),
    27115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27115, CurrentID=0, Status='live', Symbol='PDE7B', Aliases=['bA472E5.1'], description='phosphodiesterase 7B', other_designations="cAMP-specific 3',5'-cyclic phosphodiesterase 7B|high-affinity cAMP-specific 3',5'-cyclic phosphodiesterase|rolipram-insensitive phosphodiesterase type 7", map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=135851701, end_position_on_the_genomic_accession=136195574, orientation='plus', exon_count=13, OMIM=[604645], no_hdr0=''),
    27120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27120, CurrentID=0, Status='live', Symbol='DKKL1', Aliases=['CT34', 'SGY', 'SGY-1', 'SGY1'], description='dickkopf like acrosomal protein 1', other_designations='dickkopf-like protein 1|cancer/testis antigen 34|dickkopf-like 1|protein soggy-1|soggy|soggy-1|testicular secretory protein Li 15', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49360520, end_position_on_the_genomic_accession=49375132, orientation='plus', exon_count=10, OMIM=[605418], no_hdr0=''),
    27121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27121, CurrentID=0, Status='live', Symbol='DKK4', Aliases=['DKK-4'], description='dickkopf WNT signaling pathway inhibitor 4', other_designations='dickkopf-related protein 4|dickkopf-4|hDkk-4', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42373194, end_position_on_the_genomic_accession=42391322, orientation='minus', exon_count=6, OMIM=[605417], no_hdr0=''),
    27122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27122, CurrentID=0, Status='live', Symbol='DKK3', Aliases=['REIC', 'RIG'], description='dickkopf WNT signaling pathway inhibitor 3', other_designations='dickkopf-related protein 3|RIG-like 5-6|RIG-like 7-1|dickkopf 3 homolog|dickkopf homolog 3|dickkopf-3|dkk-3|hDkk-3|regulated in glioma', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=11963036, end_position_on_the_genomic_accession=12009827, orientation='minus', exon_count=12, OMIM=[605416], no_hdr0=''),
    27123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27123, CurrentID=0, Status='live', Symbol='DKK2', Aliases=['DKK-2'], description='dickkopf WNT signaling pathway inhibitor 2', other_designations='dickkopf-related protein 2|dickkopf 2 homolog|dickkopf homolog 2|dickkopf-2|hDkk-2', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=106921802, end_position_on_the_genomic_accession=107036313, orientation='minus', exon_count=4, OMIM=[605415], no_hdr0=''),
    27124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27124, CurrentID=0, Status='live', Symbol='INPP5J', Aliases=['INPP5', 'PIB5PA', 'PIPP'], description='inositol polyphosphate-5-phosphatase J', other_designations='phosphatidylinositol 4,5-bisphosphate 5-phosphatase A', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31107736, end_position_on_the_genomic_accession=31134697, orientation='plus', exon_count=18, OMIM=[606481], no_hdr0=''),
    27125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27125, CurrentID=0, Status='live', Symbol='AFF4', Aliases=['AF5Q31', 'CHOPS', 'MCEF'], description='AF4/FMR2 family member 4', other_designations='AF4/FMR2 family member 4|ALL1-fused gene from chromosome 5q31 protein|major CDK9 elongation factor-associated protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132875381, end_position_on_the_genomic_accession=132963655, orientation='minus', exon_count=23, OMIM=[604417], no_hdr0=''),
    27127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27127, CurrentID=0, Status='live', Symbol='SMC1B', Aliases=['SMC1BETA', 'SMC1L2'], description='structural maintenance of chromosomes 1B', other_designations='structural maintenance of chromosomes protein 1B|SMC protein 1B|SMC1 (structural maintenance of chromosomes 1, yeast)-like 1|SMC1 structural maintenance of chromosomes 1-like 2|mitosis-specific chromosome segregation protein like protein beta', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45344063, end_position_on_the_genomic_accession=45413671, orientation='minus', exon_count=26, OMIM=[608685], no_hdr0=''),
    27128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27128, CurrentID=0, Status='live', Symbol='CYTH4', Aliases=['CYT4', 'DJ63G5.1', 'PSCD4', 'cytohesin-4'], description='cytohesin 4', other_designations='cytohesin-4|PH, SEC7 and coiled-coil domain-containing protein 4|pleckstrin homology, Sec7 and coiled/coil domains 4', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37282508, end_position_on_the_genomic_accession=37315341, orientation='plus', exon_count=13, OMIM=[606514], no_hdr0=''),
    27129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27129, CurrentID=0, Status='live', Symbol='HSPB7', Aliases=['cvHSP'], description='heat shock protein family B (small) member 7', other_designations='heat shock protein beta-7|cardiovascular heat shock protein|heat shock 27kD protein family, member 7 (cardiovascular)|heat shock 27kDa protein family, member 7 (cardiovascular)', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16014029, end_position_on_the_genomic_accession=16019594, orientation='minus', exon_count=4, OMIM=[610692], no_hdr0=''),
    27130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27130, CurrentID=0, Status='live', Symbol='INVS', Aliases=['INV', 'NPH2', 'NPHP2'], description='inversin', other_designations='inversin|inversion of embryo turning homolog|inversion of embryonic turning|nephrocystin-2', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100099243, end_position_on_the_genomic_accession=100302175, orientation='plus', exon_count=18, OMIM=[243305], no_hdr0=''),
    27131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27131, CurrentID=0, Status='live', Symbol='SNX5', Aliases=[], description='sorting nexin 5', other_designations='sorting nexin-5', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17941600, end_position_on_the_genomic_accession=17968794, orientation='minus', exon_count=14, OMIM=[605937], no_hdr0=''),
    27132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27132, CurrentID=0, Status='live', Symbol='CPNE7', Aliases=[], description='copine 7', other_designations='copine-7|copine VII', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89575758, end_position_on_the_genomic_accession=89597246, orientation='plus', exon_count=19, OMIM=[605689], no_hdr0=''),
    27133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27133, CurrentID=0, Status='live', Symbol='KCNH5', Aliases=['EAG2', 'H-EAG2', 'Kv10.2', 'hEAG2'], description='potassium voltage-gated channel subfamily H member 5', other_designations='potassium voltage-gated channel subfamily H member 5|ether-a-go-go 2|ether-a-go-go-related potassium channel 2|potassium channel, voltage gated eag related subfamily H, member 5|potassium voltage-gated channel, subfamily H (eag-related), member 5|voltage-gated potassium channel subunit Kv10.2', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=62699464, end_position_on_the_genomic_accession=63045458, orientation='minus', exon_count=11, OMIM=[605716], no_hdr0=''),
    27134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27134, CurrentID=0, Status='live', Symbol='TJP3', Aliases=['ZO-3', 'ZO3'], description='tight junction protein 3', other_designations='tight junction protein ZO-3|tight junction protein 3 (zona occludens 3)|zona occludens protein 3|zonula occludens protein 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3708384, end_position_on_the_genomic_accession=3750813, orientation='plus', exon_count=22, OMIM=[612689], no_hdr0=''),
    27136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27136, CurrentID=0, Status='live', Symbol='MORC1', Aliases=['CT33', 'MORC', 'ZCW6'], description='MORC family CW-type zinc finger 1', other_designations='MORC family CW-type zinc finger protein 1|cancer/testis antigen 33|microrchidia, mouse, homolog of', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108958248, end_position_on_the_genomic_accession=109118134, orientation='minus', exon_count=32, OMIM=[603205], no_hdr0=''),
    27141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27141, CurrentID=0, Status='live', Symbol='CIDEB', Aliases=[], description='cell death inducing DFFA like effector b', other_designations='cell death activator CIDE-B', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24305187, end_position_on_the_genomic_accession=24311435, orientation='minus', exon_count=8, OMIM=[604441], no_hdr0=''),
    27143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27143, CurrentID=0, Status='live', Symbol='PALD1', Aliases=['KIAA1274', 'PALD'], description='phosphatase domain containing paladin 1', other_designations='paladin|palladin', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70458542, end_position_on_the_genomic_accession=70568450, orientation='plus', exon_count=24, OMIM=[614656], no_hdr0=''),
    27145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27145, CurrentID=0, Status='live', Symbol='FILIP1', Aliases=['FILIP'], description='filamin A interacting protein 1', other_designations='filamin-A-interacting protein 1', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75291858, end_position_on_the_genomic_accession=75493800, orientation='minus', exon_count=10, OMIM=[607307], no_hdr0=''),
    27146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27146, CurrentID=0, Status='live', Symbol='FAM184B', Aliases=[], description='family with sequence similarity 184 member B', other_designations='protein FAM184B', map_location='4p15.32-p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17629306, end_position_on_the_genomic_accession=17781621, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    27147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27147, CurrentID=0, Status='live', Symbol='DENND2A', Aliases=['FAM31D', 'KIAA1277'], description='DENN domain containing 2A', other_designations='DENN domain-containing protein 2A|DENN/MADD domain containing 2A', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140518418, end_position_on_the_genomic_accession=140641460, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    27148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27148, CurrentID=0, Status='live', Symbol='STK36', Aliases=['FU'], description='serine/threonine kinase 36', other_designations='serine/threonine-protein kinase 36|fused homolog|testicular tissue protein Li 188', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218672049, end_position_on_the_genomic_accession=218702717, orientation='plus', exon_count=30, OMIM=[607652], no_hdr0=''),
    27151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27151, CurrentID=0, Status='live', Symbol='CPAMD8', Aliases=['ASGD8', 'K-CAP', 'VIP'], description='C3 and PZP like alpha-2-macroglobulin domain containing 8', other_designations='C3 and PZP-like alpha-2-macroglobulin domain-containing protein 8|alpha-2 macroglobulin family protein VIP', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16892951, end_position_on_the_genomic_accession=17026818, orientation='minus', exon_count=43, OMIM=[608841], no_hdr0=''),
    27152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27152, CurrentID=0, Status='live', Symbol='INTU', Aliases=['CPLANE4', 'INT', 'OFD17', 'PDZD6', 'PDZK6', 'SRTD20'], description='inturned planar cell polarity protein', other_designations='protein inturned|PDZ domain containing 6|PDZ domain-containing protein 6|ciliogenesis and planar polarity effector 4|inturned planar cell polarity effector homolog', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127623271, end_position_on_the_genomic_accession=127726737, orientation='plus', exon_count=21, OMIM=[610621], no_hdr0=''),
    27153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27153, CurrentID=0, Status='live', Symbol='ZNF777', Aliases=[], description='zinc finger protein 777', other_designations='zinc finger protein 777', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149431363, end_position_on_the_genomic_accession=149461062, orientation='minus', exon_count=8, OMIM=[619298], no_hdr0=''),
    27154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27154, CurrentID=0, Status='live', Symbol='BRPF3', Aliases=[], description='bromodomain and PHD finger containing 3', other_designations='bromodomain and PHD finger-containing protein 3', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36196744, end_position_on_the_genomic_accession=36232790, orientation='plus', exon_count=16, OMIM=[616856], no_hdr0=''),
    27156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27156, CurrentID=0, Status='live', Symbol='RSPH14', Aliases=['RTDR1'], description='radial spoke head 14 homolog', other_designations='radial spoke head 14 homolog|rhabdoid tumor deletion region gene 1|rhabdoid tumor deletion region protein 1', map_location='22q11.22-q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23059408, end_position_on_the_genomic_accession=23180048, orientation='minus', exon_count=13, OMIM=[605663], no_hdr0=''),
    27158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27158, CurrentID=0, Status='live', Symbol='NDOR1', Aliases=['CIAE1', 'NR1', 'bA350O14.9'], description='NADPH dependent diflavin oxidoreductase 1', other_designations='NADPH-dependent diflavin oxidoreductase 1|NADPH-dependent FMN and FAD-containing oxidoreductase', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137205667, end_position_on_the_genomic_accession=137219361, orientation='plus', exon_count=14, OMIM=[606073], no_hdr0=''),
    27159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27159, CurrentID=0, Status='live', Symbol='CHIA', Aliases=['AMCASE', 'CHIT2', 'TSA1902'], description='chitinase acidic', other_designations='acidic mammalian chitinase|lung-specific protein TSA1902', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111290851, end_position_on_the_genomic_accession=111320566, orientation='plus', exon_count=13, OMIM=[606080], no_hdr0=''),
    27161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27161, CurrentID=0, Status='live', Symbol='AGO2', Aliases=['CASC7', 'EIF2C2', 'LESKRES', 'LINC00980', 'PPD', 'Q10'], description='argonaute RISC catalytic component 2', other_designations='protein argonaute-2|PAZ Piwi domain protein|argonaute 2, RISC catalytic component|cancer susceptibility candidate 7 (non-protein coding)|eukaryotic translation initiation factor 2C, 2|long intergenic non-protein coding RNA 980|protein slicer', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=140520156, end_position_on_the_genomic_accession=140642406, orientation='minus', exon_count=22, OMIM=[606229], no_hdr0=''),
    27163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27163, CurrentID=0, Status='live', Symbol='NAAA', Aliases=['ASAHL', 'PLT'], description='N-acylethanolamine acid amidase', other_designations='N-acylethanolamine-hydrolyzing acid amidase|ASAH-like protein|acid ceramidase-like protein|acylsphingosine deacylase NAAA', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75910655, end_position_on_the_genomic_accession=75941013, orientation='minus', exon_count=14, OMIM=[607469], no_hdr0=''),
    27164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27164, CurrentID=0, Status='live', Symbol='SALL3', Aliases=['ZNF796'], description='spalt like transcription factor 3', other_designations='sal-like protein 3|C2H2 zinc finger protein SALL3|epididymis secretory sperm binding protein|hSALL3|spalt-like zinc finger protein|zinc finger protein 796', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=78979818, end_position_on_the_genomic_accession=78998969, orientation='plus', exon_count=3, OMIM=[605079], no_hdr0=''),
    27165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27165, CurrentID=0, Status='live', Symbol='GLS2', Aliases=['GA', 'GLS', 'LGA', 'hLGA'], description='glutaminase 2', other_designations='glutaminase liver isoform, mitochondrial|L-glutamine amidohydrolase|breast cell glutaminase|glutaminase 2 (liver, mitochondrial)|glutaminase I|phosphate-activated glutaminase|phosphate-dependent glutaminase', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56470952, end_position_on_the_genomic_accession=56488161, orientation='minus', exon_count=19, OMIM=[606365], no_hdr0=''),
    27166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27166, CurrentID=0, Status='live', Symbol='PRELID1', Aliases=['CGI-106', 'PRELI', 'PX19', 'SBBI12'], description='PRELI domain containing 1', other_designations='PRELI domain-containing protein 1, mitochondrial|25 kDa protein of relevant evolutionary and lymphoid interest|px19-like protein', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177303799, end_position_on_the_genomic_accession=177306949, orientation='plus', exon_count=5, OMIM=[605733], no_hdr0=''),
    27173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27173, CurrentID=0, Status='live', Symbol='SLC39A1', Aliases=['ZIP1', 'ZIRTL'], description='solute carrier family 39 member 1', other_designations='zinc transporter ZIP1|solute carrier family 39 (zinc transporter), member 1|solute carrier family 39 (zinc transporter), member 3|zrt- and Irt-like protein 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153959110, end_position_on_the_genomic_accession=153968184, orientation='minus', exon_count=7, OMIM=[604740], no_hdr0=''),
    27175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27175, CurrentID=0, Status='live', Symbol='TUBG2', Aliases=[], description='tubulin gamma 2', other_designations='tubulin gamma-2 chain|gamma-2-tubulin|tubulin gamma 2 chain', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42659284, end_position_on_the_genomic_accession=42667006, orientation='plus', exon_count=12, OMIM=[605785], no_hdr0=''),
    27177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27177, CurrentID=0, Status='live', Symbol='IL36B', Aliases=['FIL1', 'FIL1-(ETA)', 'FIL1H', 'FILI-(ETA)', 'IL-1F8', 'IL-1H2', 'IL1-ETA', 'IL1F8', 'IL1H2'], description='interleukin 36 beta', other_designations='interleukin-36 beta|FIL1 eta|IL-1 eta|IL-1F8 (FIL1-eta)|IL1F8 (Canonical product IL-1F8a)|Interleukin-1 Superfamily e|family of interleukin 1-eta|interleukin 1 family, member 8 (eta)|interleukin-1 eta|interleukin-1 family member 8|interleukin-1 homolog 2', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113022089, end_position_on_the_genomic_accession=113052867, orientation='minus', exon_count=8, OMIM=[605508], no_hdr0=''),
    27178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27178, CurrentID=0, Status='live', Symbol='IL37', Aliases=['FIL1', 'FIL1(ZETA)', 'FIL1Z', 'IL-1F7', 'IL-1H', 'IL-1H4', 'IL-1RP1', 'IL-23', 'IL-37', 'IL1F7', 'IL1H4', 'IL1RP1'], description='interleukin 37', other_designations='interleukin-37|FIL1 zeta|IL-1 zeta|IL-1F7b (IL-1H4, IL-1H, IL-1RP1)|IL-1X protein|IL1F7 (canonical product IL-1F7b)|interleukin 1 family member 7|interleukin 1, zeta|interleukin-1 homolog 4|interleukin-1 superfamily z|interleukin-1-related protein|interleukin-23', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112911165, end_position_on_the_genomic_accession=112918882, orientation='plus', exon_count=7, OMIM=[605510], no_hdr0=''),
    27179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27179, CurrentID=0, Status='live', Symbol='IL36A', Aliases=['FIL1', 'FIL1(EPSILON)', 'FIL1E', 'IL-1F6', 'IL1(EPSILON)', 'IL1F6'], description='interleukin 36 alpha', other_designations='interleukin-36 alpha|FIL1 epsilon|IL-1 epsilon|IL-1F6 (FIL-1-epsilon)|interleukin 1 family, member 6 (epsilon)|interleukin-1 epsilon|interleukin-1 family member 6', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113005459, end_position_on_the_genomic_accession=113011071, orientation='plus', exon_count=6, OMIM=[605509], no_hdr0=''),
    27180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27180, CurrentID=0, Status='live', Symbol='SIGLEC9', Aliases=['CD329', 'CDw329', 'FOAP-9', 'OBBP-LIKE', 'siglec-9'], description='sialic acid binding Ig like lectin 9', other_designations='sialic acid-binding Ig-like lectin 9|protein FOAP-9', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51124880, end_position_on_the_genomic_accession=51140480, orientation='plus', exon_count=12, OMIM=[605640], no_hdr0=''),
    27181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27181, CurrentID=0, Status='live', Symbol='SIGLEC8', Aliases=['SAF2', 'SIGLEC-8L', 'SIGLEC8'], description='sialic acid binding Ig like lectin 8', other_designations='sialic acid-binding Ig-like lectin 8|CDw329|SAF-2|sialoadhesin family member 2', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51450997, end_position_on_the_genomic_accession=51458454, orientation='minus', exon_count=7, OMIM=[605639], no_hdr0=''),
    27183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27183, CurrentID=0, Status='live', Symbol='VPS4A', Aliases=['CIMDAG', 'SKD1', 'SKD1A', 'SKD2', 'VPS4', 'VPS4-1'], description='vacuolar protein sorting 4 homolog A', other_designations='vacuolar protein sorting-associated protein 4A|SKD1-homolog|hVPS4|vacuolar protein sorting factor 4A|vacuolar sorting protein 4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69311350, end_position_on_the_genomic_accession=69326939, orientation='plus', exon_count=11, OMIM=[609982], no_hdr0=''),
    27185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27185, CurrentID=0, Status='live', Symbol='DISC1', Aliases=['C1orf136', 'SCZD9'], description='DISC1 scaffold protein', other_designations='disrupted in schizophrenia 1 protein', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231626790, end_position_on_the_genomic_accession=232041272, orientation='plus', exon_count=19, OMIM=[605210], no_hdr0=''),
    27189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27189, CurrentID=0, Status='live', Symbol='IL17C', Aliases=['CX2', 'IL-17C'], description='interleukin 17C', other_designations='interleukin-17C|cytokine CX2', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88638572, end_position_on_the_genomic_accession=88640468, orientation='plus', exon_count=3, OMIM=[604628], no_hdr0=''),
    27190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27190, CurrentID=0, Status='live', Symbol='IL17B', Aliases=['IL-17B', 'IL-20', 'NIRF', 'ZCYTO7'], description='interleukin 17B', other_designations='interleukin-17B|cytokine-like protein ZCYTO7|interleukin 20|interleukin-17 beta|neuronal interleukin-17 related factor', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149374267, end_position_on_the_genomic_accession=149404202, orientation='minus', exon_count=7, OMIM=[604627], no_hdr0=''),
    27197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27197, CurrentID=0, Status='live', Symbol='GPR82', Aliases=[], description='G protein-coupled receptor 82', other_designations='probable G-protein coupled receptor 82', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41724181, end_position_on_the_genomic_accession=41730130, orientation='plus', exon_count=3, OMIM=[300748], no_hdr0=''),
    27198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27198, CurrentID=0, Status='live', Symbol='HCAR1', Aliases=['FKSG80', 'GPR104', 'GPR81', 'HCA1', 'LACR1', 'TA-GPCR', 'TAGPCR'], description='hydroxycarboxylic acid receptor 1', other_designations='hydroxycarboxylic acid receptor 1|G protein-coupled receptor 104|G-protein coupled receptor 81|T-cell activation G protein-coupled receptor|hydroxy-carboxylic acid receptor 1|lactate receptor 1', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122726076, end_position_on_the_genomic_accession=122730844, orientation='minus', exon_count=1, OMIM=[606923], no_hdr0=''),
    27199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27199, CurrentID=0, Status='live', Symbol='OXGR1', Aliases=['GPR80', 'GPR99', 'P2RY15', 'P2Y15', 'aKGR'], description='oxoglutarate receptor 1', other_designations='2-oxoglutarate receptor 1|G protein-coupled receptor 80|G-protein coupled receptor 99|P2Y purinoceptor 15|P2Y-like GPCR|P2Y-like nucleotide receptor|alpha-ketoglutarate receptor 1|oxoglutarate (alpha-ketoglutarate) receptor 1|seven transmembrane helix receptor', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=96985713, end_position_on_the_genomic_accession=96994730, orientation='minus', exon_count=5, OMIM=[606922], no_hdr0=''),
    27201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27201, CurrentID=0, Status='live', Symbol='GPR78', Aliases=[], description='G protein-coupled receptor 78', other_designations='G-protein coupled receptor 78', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8580392, end_position_on_the_genomic_accession=8590023, orientation='plus', exon_count=3, OMIM=[606921], no_hdr0=''),
    27202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27202, CurrentID=0, Status='live', Symbol='C5AR2', Aliases=['C5L2', 'GPF77', 'GPR77'], description='complement C5a receptor 2', other_designations='C5a anaphylatoxin chemotactic receptor 2|C5a anaphylatoxin chemotactic receptor C5L2|G protein-coupled receptor 77|G protein-coupled receptor C5L2|complement component 5a receptor 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47331614, end_position_on_the_genomic_accession=47347329, orientation='plus', exon_count=5, OMIM=[609949], no_hdr0=''),
    27229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27229, CurrentID=0, Status='live', Symbol='TUBGCP4', Aliases=['76P', 'GCP-4', 'GCP4', 'Grip76', 'MCCRP3'], description='tubulin gamma complex associated protein 4', other_designations='gamma-tubulin complex component 4|gamma tubulin ring complex protein (76p gene)|gamma-ring complex protein 76 kDa', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43371073, end_position_on_the_genomic_accession=43409771, orientation='plus', exon_count=19, OMIM=[609610], no_hdr0=''),
    27230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27230, CurrentID=0, Status='live', Symbol='SERP1', Aliases=['RAMP4'], description='stress associated endoplasmic reticulum protein 1', other_designations='stress-associated endoplasmic reticulum protein 1|ribosome associated membrane protein 4|ribosome-attached membrane protein 4', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150541998, end_position_on_the_genomic_accession=150546496, orientation='minus', exon_count=3, OMIM=[617674], no_hdr0=''),
    27231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27231, CurrentID=0, Status='live', Symbol='NMRK2', Aliases=['ITGB1BP3', 'MIBP', 'NRK2'], description='nicotinamide riboside kinase 2', other_designations='nicotinamide riboside kinase 2|NRK 2|RNK 2|integrin beta-1-binding protein 3|muscle-specific beta 1 integrin binding protein|nicotinic acid riboside kinase 2|nmR-K 2|ribosylnicotinamide kinase 2|ribosylnicotinic acid kinase 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3933069, end_position_on_the_genomic_accession=3942416, orientation='plus', exon_count=8, OMIM=[608705], no_hdr0=''),
    27232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27232, CurrentID=0, Status='live', Symbol='GNMT', Aliases=['HEL-S-182mP'], description='glycine N-methyltransferase', other_designations='glycine N-methyltransferase|epididymis secretory sperm binding protein Li 182mP', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42960754, end_position_on_the_genomic_accession=42963880, orientation='plus', exon_count=6, OMIM=[606628], no_hdr0=''),
    27233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27233, CurrentID=0, Status='live', Symbol='SULT1C4', Aliases=['SULT1C', 'SULT1C2'], description='sulfotransferase family 1C member 4', other_designations='sulfotransferase 1C4|ST1C4|SULT1C#2|sulfotransferase 1C2|sulfotransferase family, cytosolic, 1C, member 2|sulfotransferase family, cytosolic, 1C, member 4|sulfotransferase family, cytosolic, 1C, member C2', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108377954, end_position_on_the_genomic_accession=108388989, orientation='plus', exon_count=7, OMIM=[608357], no_hdr0=''),
    27235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27235, CurrentID=0, Status='live', Symbol='COQ2', Aliases=['CL640', 'COQ10D1', 'MSA1', 'PHB:PPT'], description='coenzyme Q2, polyprenyltransferase', other_designations='4-hydroxybenzoate polyprenyltransferase, mitochondrial|4-HB polyprenyltransferase|4-hydroxybenzoate decaprenyltransferase|PHB:polyprenyltransferase|coenzyme Q2 4-hydroxybenzoate polyprenyltransferase|coenzyme Q2 homolog, prenyltransferase|para-hydroxybenzoate-polyprenyltransferase, mitochondrial', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83263824, end_position_on_the_genomic_accession=83285134, orientation='minus', exon_count=7, OMIM=[609825], no_hdr0=''),
    27236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27236, CurrentID=0, Status='live', Symbol='ARFIP1', Aliases=['HSU52521'], description='ADP ribosylation factor interacting protein 1', other_designations='arfaptin-1', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=152779954, end_position_on_the_genomic_accession=152912357, orientation='plus', exon_count=13, OMIM=[605928], no_hdr0=''),
    27237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27237, CurrentID=0, Status='live', Symbol='ARHGEF16', Aliases=['GEF16', 'NBR'], description='Rho guanine nucleotide exchange factor 16', other_designations='rho guanine nucleotide exchange factor 16|Rho guanine exchange factor (GEF) 16|Rho guanine nucleotide exchange factor (GEF) 16|ephexin-4|ephexin4', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3454589, end_position_on_the_genomic_accession=3481115, orientation='plus', exon_count=18, OMIM=[618871], no_hdr0=''),
    27238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27238, CurrentID=0, Status='live', Symbol='GPKOW', Aliases=['GPATC5', 'GPATCH5', 'Mos2', 'Spp2', 'T54'], description='G-patch domain and KOW motifs', other_designations='G-patch domain and KOW motifs-containing protein|G patch domain and KOW motifs-containing protein|protein MOS2 homolog', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49113396, end_position_on_the_genomic_accession=49124547, orientation='minus', exon_count=12, OMIM=[301003], no_hdr0=''),
    27239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27239, CurrentID=0, Status='live', Symbol='GPR162', Aliases=['A-2', 'GRCA'], description='G protein-coupled receptor 162', other_designations='probable G-protein coupled receptor 162|gene rich cluster, A|gene-rich cluster gene A protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6821821, end_position_on_the_genomic_accession=6827421, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    27240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27240, CurrentID=0, Status='live', Symbol='SIT1', Aliases=['SIT', 'SIT-R'], description='signaling threshold regulating transmembrane adaptor 1', other_designations='signaling threshold-regulating transmembrane adapter 1|SHP-2 interacting transmembrane adaptor protein|SHP2 interacting transmembrane adaptor|SHP2-interacting transmembrane adapter protein|SHP2-interacting transmembrane adaptor protein|gp30/40|suppression inducing transmembrane adaptor 1|suppression-inducing transmembrane adapter 1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35649295, end_position_on_the_genomic_accession=35650931, orientation='minus', exon_count=5, OMIM=[604964], no_hdr0=''),
    27241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27241, CurrentID=0, Status='live', Symbol='BBS9', Aliases=['B1', 'C18', 'D1', 'PTHB1'], description='Bardet-Biedl syndrome 9', other_designations='protein PTHB1|PTH-responsive osteosarcoma B1 protein|bardet-Biedl syndrome 9 protein|parathyroid hormone-responsive B1 gene protein', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=33129244, end_position_on_the_genomic_accession=33637238, orientation='plus', exon_count=30, OMIM=[607968], no_hdr0=''),
    27242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27242, CurrentID=0, Status='live', Symbol='TNFRSF21', Aliases=['BM-018', 'CD358', 'DR6'], description='TNF receptor superfamily member 21', other_designations='tumor necrosis factor receptor superfamily member 21|TNFR-related death receptor 6|death receptor 6', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47231532, end_position_on_the_genomic_accession=47309905, orientation='minus', exon_count=6, OMIM=[605732], no_hdr0=''),
    27243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27243, CurrentID=0, Status='live', Symbol='CHMP2A', Aliases=['BC-2', 'BC2', 'CHMP2', 'VPS2', 'VPS2A'], description='charged multivesicular body protein 2A', other_designations='charged multivesicular body protein 2a|VPS2 homolog A|chromatin modifying protein 2A|putative breast adenocarcinoma marker (32kD)|putative breast adenocarcinoma marker BC-2|vacuolar protein sorting-associated protein 2-1|vps2-1', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58551566, end_position_on_the_genomic_accession=58555624, orientation='minus', exon_count=6, OMIM=[610893], no_hdr0=''),
    27244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27244, CurrentID=0, Status='live', Symbol='SESN1', Aliases=['PA26', 'SEST1'], description='sestrin 1', other_designations='sestrin-1|p53 activated gene 26|p53 regulated PA26 nuclear protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108984309, end_position_on_the_genomic_accession=109094846, orientation='minus', exon_count=12, OMIM=[606103], no_hdr0=''),
    27245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27245, CurrentID=0, Status='live', Symbol='AHDC1', Aliases=['MRD25', 'XIGIS'], description='AT-hook DNA binding motif containing 1', other_designations='AT-hook DNA-binding motif-containing protein 1', map_location='1p36.11-p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27534245, end_position_on_the_genomic_accession=27604178, orientation='minus', exon_count=13, OMIM=[615790], no_hdr0=''),
    27246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27246, CurrentID=0, Status='live', Symbol='RNF115', Aliases=['BCA2', 'ZNF364'], description='ring finger protein 115', other_designations='E3 ubiquitin-protein ligase RNF115|RING-type E3 ubiquitin transferase RNF115|rabring 7|zinc finger protein 364', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145738868, end_position_on_the_genomic_accession=145824095, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    27247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27247, CurrentID=0, Status='live', Symbol='NFU1', Aliases=['CGI-33', 'HIRIP', 'HIRIP5', 'MMDS1', 'NIFUC', 'Nfu', 'NifU'], description='NFU1 iron-sulfur cluster scaffold', other_designations='NFU1 iron-sulfur cluster scaffold homolog, mitochondrial|HIRA-interacting protein 5|NifU-like C-terminal domain containing|iron-sulfur cluster scaffold protein', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69395750, end_position_on_the_genomic_accession=69439567, orientation='minus', exon_count=10, OMIM=[608100], no_hdr0=''),
    27248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27248, CurrentID=0, Status='live', Symbol='ERLEC1', Aliases=['C2orf30', 'CIM', 'CL24936', 'CL25084', 'HEL117', 'XTP3-B', 'XTP3TPB'], description='endoplasmic reticulum lectin 1', other_designations='endoplasmic reticulum lectin 1|ER lectin|XTP3-transactivated gene B protein|XTP3-transactivated protein B|cancer invasion and metastasis-related|epididymis luminal protein 117|erlectin 1', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53787017, end_position_on_the_genomic_accession=53834524, orientation='plus', exon_count=16, OMIM=[611229], no_hdr0=''),
    27249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27249, CurrentID=0, Status='live', Symbol='MMADHC', Aliases=['C2orf25', 'CL25022', 'cblD'], description='metabolism of cobalamin associated D', other_designations='cobalamin trafficking protein CblD|methylmalonic aciduria (cobalamin deficiency) cblD type, with homocystinuria|methylmalonic aciduria and homocystinuria type D protein, mitochondrial|protein C2orf25, mitochondrial', map_location='2q23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=149569637, end_position_on_the_genomic_accession=149587775, orientation='minus', exon_count=8, OMIM=[611935], no_hdr0=''),
    27250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27250, CurrentID=0, Status='live', Symbol='PDCD4', Aliases=['H731'], description='programmed cell death 4', other_designations='programmed cell death protein 4|neoplastic transformation inhibitor protein|nuclear antigen H731|programmed cell death 4 (neoplastic transformation inhibitor)|protein 197/15a', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110871928, end_position_on_the_genomic_accession=110900006, orientation='plus', exon_count=13, OMIM=[608610], no_hdr0=''),
    27252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27252, CurrentID=0, Status='live', Symbol='KLHL20', Aliases=['KHLHX', 'KLEIP', 'KLHLX'], description='kelch like family member 20', other_designations='kelch-like protein 20|Kelch motif containing protein|kelch-like ECT2-interacting protein|kelch-like protein X', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173714912, end_position_on_the_genomic_accession=173786826, orientation='plus', exon_count=13, OMIM=[617679], no_hdr0=''),
    27253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27253, CurrentID=0, Status='live', Symbol='PCDH17', Aliases=['PCDH68', 'PCH68'], description='protocadherin 17', other_designations='protocadherin-17|protocadherin 68', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57630104, end_position_on_the_genomic_accession=57729311, orientation='plus', exon_count=6, OMIM=[611760], no_hdr0=''),
    27254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27254, CurrentID=0, Status='live', Symbol='CSDC2', Aliases=['PIPPIN', 'dJ347H13.2'], description='cold shock domain containing C2', other_designations='cold shock domain-containing protein C2|RNA-binding protein pippin|cold shock domain containing C2, RNA binding', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41561010, end_position_on_the_genomic_accession=41576666, orientation='plus', exon_count=4, OMIM=[617689], no_hdr0=''),
    27255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27255, CurrentID=0, Status='live', Symbol='CNTN6', Aliases=['NB3'], description='contactin 6', other_designations='contactin-6|neural adhesion molecule|neural recognition molecule NB-3', map_location='3p26.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=978021, end_position_on_the_genomic_accession=1404217, orientation='plus', exon_count=32, OMIM=[607220], no_hdr0=''),
    27257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27257, CurrentID=0, Status='live', Symbol='LSM1', Aliases=['CASM', 'YJL124C'], description='LSM1 homolog, mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm1|LSM1 homolog, U6 small nuclear RNA associated|LSM1 mRNA degradation associated|LSM1, U6 small nuclear RNA associated|LSM1-like protein U6 small nuclear RNA associated|cancer-associated Sm protein|cancer-associated Sm-like protein|small nuclear ribonuclear CaSm', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38163321, end_position_on_the_genomic_accession=38176730, orientation='minus', exon_count=5, OMIM=[607281], no_hdr0=''),
    27258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27258, CurrentID=0, Status='live', Symbol='LSM3', Aliases=['SMX4', 'USS2', 'YLR438C'], description='LSM3 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm3|LSM3 U6 small nuclear RNA and mRNA degradation associated|LSM3 homolog, U6 small nuclear RNA associated', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14178817, end_position_on_the_genomic_accession=14201122, orientation='plus', exon_count=4, OMIM=[607283], no_hdr0=''),
    27283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27283, CurrentID=0, Status='live', Symbol='TINAG', Aliases=['TIN-AG'], description='tubulointerstitial nephritis antigen', other_designations='tubulointerstitial nephritis antigen', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=54307792, end_position_on_the_genomic_accession=54390151, orientation='plus', exon_count=12, OMIM=[606749], no_hdr0=''),
    27284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27284, CurrentID=0, Status='live', Symbol='SULT1B1', Aliases=['ST1B1', 'ST1B2', 'SULT1B2'], description='sulfotransferase family 1B member 1', other_designations='sulfotransferase family cytosolic 1B member 1|sulfotransferase 1B1|sulfotransferase 1B2|sulfotransferase family, cytosolic, 1B, member 1|thyroid hormone sulfotransferase', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69721167, end_position_on_the_genomic_accession=69760644, orientation='minus', exon_count=10, OMIM=[608436], no_hdr0=''),
    27285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27285, CurrentID=0, Status='live', Symbol='TEKT2', Aliases=['TEKTB1', 'TEKTIN-T', 'h-tektin-t'], description='tektin 2', other_designations='tektin-2|tektin 2 (testicular)|tektin-B1|testicular tektin B1-like protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36084094, end_position_on_the_genomic_accession=36088275, orientation='plus', exon_count=11, OMIM=[608953], no_hdr0=''),
    27286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27286, CurrentID=0, Status='live', Symbol='SRPX2', Aliases=['BPP', 'CBPS', 'PMGX', 'RESDX', 'SRPUL'], description='sushi repeat containing protein X-linked 2', other_designations='sushi repeat-containing protein SRPX2|sushi-repeat protein up-regulated in leukemia|sushi-repeat protein upregulated in leukemia', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100644199, end_position_on_the_genomic_accession=100675788, orientation='plus', exon_count=11, OMIM=[300642], no_hdr0=''),
    27287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27287, CurrentID=0, Status='live', Symbol='VENTX', Aliases=['HPX42B', 'NA88A2', 'VENTX'], description='VENT homeobox', other_designations='homeobox protein VENTX|VENT homeobox homolog|VENT-like homeobox 2|VENT-like homeobox protein 2|hemopoietic progenitor homeobox protein VENTX2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133237855, end_position_on_the_genomic_accession=133241928, orientation='plus', exon_count=3, OMIM=[607158], no_hdr0=''),
    27288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27288, CurrentID=0, Status='live', Symbol='RBMXL2', Aliases=['HNRNPG-T', 'HNRNPGT', 'HNRPGT'], description='RBMX like 2', other_designations='RNA-binding motif protein, X-linked-like-2|RNA binding motif protein, X-linked like 2|heterogeneous nuclear ribonucleoprotein G T|hnRNP G-T|testes-specific heterogenous nuclear ribonucleoprotein G-T|testis-specific heterogeneous nuclear ribonucleoprotein G-T', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7088998, end_position_on_the_genomic_accession=7091148, orientation='plus', exon_count=1, OMIM=[605444], no_hdr0=''),
    27289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27289, CurrentID=0, Status='live', Symbol='RND1', Aliases=['ARHS', 'RHO6', 'RHOS'], description='Rho family GTPase 1', other_designations='rho-related GTP-binding protein Rho6|ras homolog gene family, member S', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48857145, end_position_on_the_genomic_accession=48865870, orientation='minus', exon_count=5, OMIM=[609038], no_hdr0=''),
    27290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27290, CurrentID=0, Status='live', Symbol='SPINK4', Aliases=['HEL136', 'PEC-60', 'PEC60'], description='serine peptidase inhibitor Kazal type 4', other_designations='serine protease inhibitor Kazal-type 4|epididymis luminal protein 136|gastrointestinal peptide|peptide PEC-60 homolog', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33240167, end_position_on_the_genomic_accession=33248567, orientation='plus', exon_count=4, OMIM=[613929], no_hdr0=''),
    27291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27291, CurrentID=0, Status='live', Symbol='R3HCC1L', Aliases=['C10orf28', 'GIDRP86', 'GIDRP88', 'PSORT'], description='R3H domain and coiled-coil containing 1 like', other_designations='coiled-coil domain-containing protein R3HCC1L|R3H and coiled-coil domain-containing protein 1-like|growth inhibition and differentiation related protein 86|growth inhibition and differentiation-related protein 88|putative mitochondrial space protein 32.1', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=98134630, end_position_on_the_genomic_accession=98244897, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    27292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27292, CurrentID=0, Status='live', Symbol='DIMT1', Aliases=['DIM1L', 'HSA9761', 'HUSSY5', 'DIMT1'], description='DIM1 rRNA methyltransferase and ribosome maturation factor', other_designations="probable dimethyladenosine transferase|18S rRNA (adenine(1779)-N(6)/adenine(1780)-N(6))-dimethyltransferase|18S rRNA dimethylase|DIM1 dimethyladenosine transferase 1 homolog|DIM1 dimethyladenosine transferase 1-like|DIMT1 rRNA methyltransferase and ribosome maturation factor|S-adenosylmethionine-6-N',N'-adenosyl(rRNA) dimethyltransferase|dimethyladenosine transferase|probable 18S rRNA (adenine(1779)-N(6)/adenine(1780)-N(6))-dimethyltransferase|probable 18S rRNA dimethylase|probable S-adenosylmethionine-6-N',N'-adenosyl(rRNA) dimethyltransferase", map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=62387254, end_position_on_the_genomic_accession=62403905, orientation='minus', exon_count=13, OMIM=[612499], no_hdr0=''),
    27293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27293, CurrentID=0, Status='live', Symbol='SMPDL3B', Aliases=['ASML3B'], description='sphingomyelin phosphodiesterase acid like 3B', other_designations='acid sphingomyelinase-like phosphodiesterase 3b|ASM-like phosphodiesterase 3b', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27934955, end_position_on_the_genomic_accession=27959152, orientation='plus', exon_count=10, OMIM=[617737], no_hdr0=''),
    27294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27294, CurrentID=0, Status='live', Symbol='DHDH', Aliases=['2DD', 'HUM2DD'], description='dihydrodiol dehydrogenase', other_designations='trans-1,2-dihydrobenzene-1,2-diol dehydrogenase|3-deoxyglucosone reductase|D-xylose 1-dehydrogenase|D-xylose-NADP dehydrogenase|dihydrodiol dehydrogenase (dimeric)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48932790, end_position_on_the_genomic_accession=48944969, orientation='plus', exon_count=8, OMIM=[606377], no_hdr0=''),
    27295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27295, CurrentID=0, Status='live', Symbol='PDLIM3', Aliases=['ALP'], description='PDZ and LIM domain 3', other_designations='PDZ and LIM domain protein 3|alpha-actinin-2-associated LIM protein|enigma homolog', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185500660, end_position_on_the_genomic_accession=185535507, orientation='minus', exon_count=9, OMIM=[605889], no_hdr0=''),
    27296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27296, CurrentID=0, Status='live', Symbol='TP53TG5', Aliases=['C20orf10', 'CLG01'], description='TP53 target 5', other_designations='TP53-target gene 5 protein|TP53-inducible gene 5 protein', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45372557, end_position_on_the_genomic_accession=45378550, orientation='minus', exon_count=5, OMIM=[617316], no_hdr0=''),
    27297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27297, CurrentID=0, Status='live', Symbol='CRCP', Aliases=['C17', 'CGRP-RCP', 'CGRPRCP', 'POLR3I', 'POLR3J', 'RCP', 'RCP9', 'RPC9'], description='CGRP receptor component', other_designations='DNA-directed RNA polymerase III subunit RPC9|CGRP-receptor component protein|RNA polymerase III subunit C9|calcitonin gene-related peptide-receptor component protein', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66114818, end_position_on_the_genomic_accession=66154568, orientation='plus', exon_count=7, OMIM=[606121], no_hdr0=''),
    27299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27299, CurrentID=0, Status='live', Symbol='ADAMDEC1', Aliases=['M12.219'], description='ADAM like decysin 1', other_designations='ADAM DEC1|ADAM-like protein decysin-1|a disintegrin and metalloproteinase domain-like protein decysin-1|decysin|disintegrin protease', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=24384285, end_position_on_the_genomic_accession=24406013, orientation='plus', exon_count=15, OMIM=[606393], no_hdr0=''),
    27300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27300, CurrentID=0, Status='live', Symbol='ZNF544', Aliases=[], description='zinc finger protein 544', other_designations='zinc finger protein 544', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58228594, end_position_on_the_genomic_accession=58277497, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    27301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27301, CurrentID=0, Status='live', Symbol='APEX2', Aliases=['APE2', 'APEXL2', 'XTH2', 'ZGRF2'], description='apurinic/apyrimidinic endodeoxyribonuclease 2', other_designations='DNA-(apurinic or apyrimidinic site) endonuclease 2|AP endonuclease 2|AP endonuclease XTH2|APEX nuclease (apurinic/apyrimidinic endonuclease) 2|DNA-(apurinic or apyrimidinic site) lyase 2|apurinic/apyrimidinic endonuclease-like 2|zinc finger, GRF-type containing 2', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55000363, end_position_on_the_genomic_accession=55009057, orientation='plus', exon_count=6, OMIM=[300773], no_hdr0=''),
    27302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27302, CurrentID=0, Status='live', Symbol='BMP10', Aliases=[], description='bone morphogenetic protein 10', other_designations='bone morphogenetic protein 10', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68860909, end_position_on_the_genomic_accession=68871397, orientation='minus', exon_count=2, OMIM=[608748], no_hdr0=''),
    27303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27303, CurrentID=0, Status='live', Symbol='RBMS3', Aliases=[], description='RNA binding motif single stranded interacting protein 3', other_designations='RNA-binding motif, single-stranded-interacting protein 3|RNA binding motif, single stranded interacting protein|RNA-binding protein', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=29280860, end_position_on_the_genomic_accession=30010395, orientation='plus', exon_count=19, OMIM=[605786], no_hdr0=''),
    27304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27304, CurrentID=0, Status='live', Symbol='MOCS3', Aliases=['UBA4'], description='molybdenum cofactor synthesis 3', other_designations='adenylyltransferase and sulfurtransferase MOCS3|MPT synthase sulfurylase|UBA4, ubiquitin-activating enzyme E1 homolog|molybdenum cofactor synthesis protein 3|molybdopterin synthase sulfurylase|ubiquitin-like modifier activating enzyme 4', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50958818, end_position_on_the_genomic_accession=50963929, orientation='plus', exon_count=1, OMIM=[609277], no_hdr0=''),
    27306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27306, CurrentID=0, Status='live', Symbol='HPGDS', Aliases=['GSTS', 'GSTS1', 'GSTS1-1', 'PGD2', 'PGDS'], description='hematopoietic prostaglandin D synthase', other_designations='hematopoietic prostaglandin D synthase|GST class-sigma|epididymis secretory sperm binding protein|glutathione S-transferase sigma|glutathione-dependent PGD synthase|glutathione-dependent PGD synthetase|glutathione-requiring prostaglandin D synthase|hematopoietic prostaglandin D2 synthase|prostaglandin-H2 D-isomerase', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=94298535, end_position_on_the_genomic_accession=94342876, orientation='minus', exon_count=6, OMIM=[602598], no_hdr0=''),
    27309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27309, CurrentID=0, Status='live', Symbol='ZNF330', Aliases=['HSA6591', 'NOA36'], description='zinc finger protein 330', other_designations='zinc finger protein 330|nucleolar autoantigen 36|nucleolar cysteine-rich protein|zinc finger autoantigen 330', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=141220294, end_position_on_the_genomic_accession=141234697, orientation='plus', exon_count=11, OMIM=[609550], no_hdr0=''),
    27314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27314, CurrentID=0, Status='live', Symbol='RAB30', Aliases=[], description='RAB30, member RAS oncogene family', other_designations='ras-related protein Rab-30', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=82973133, end_position_on_the_genomic_accession=83071897, orientation='minus', exon_count=7, OMIM=[605693], no_hdr0=''),
    27315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27315, CurrentID=0, Status='live', Symbol='PGAP2', Aliases=['CWH43-N', 'FRAG1', 'HPMRS3', 'MRT17', 'MRT21'], description='post-GPI attachment to proteins 2', other_designations='post-GPI attachment to proteins factor 2|FGF receptor activating protein 1|cell wall biogenesis 43 N-terminal homolog|mental retardation, non-syndromic, autosomal recessive, 17|mental retardation, non-syndromic, autosomal recessive, 21', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3797724, end_position_on_the_genomic_accession=3826371, orientation='plus', exon_count=15, OMIM=[615187], no_hdr0=''),
    27316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27316, CurrentID=0, Status='live', Symbol='RBMX', Aliases=['HNRNPG', 'HNRPG', 'MRXS11P1', 'RBMXRT', 'RNMX', 'hnRNP-G', 'RBMX'], description='RNA binding motif protein X-linked', other_designations='RNA-binding motif protein, X chromosome|glycoprotein p43|heterogeneous nuclear ribonucleoprotein G|hnRNP G', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136869192, end_position_on_the_genomic_accession=136880725, orientation='minus', exon_count=11, OMIM=[300199], no_hdr0=''),
    27319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27319, CurrentID=0, Status='live', Symbol='BHLHE22', Aliases=['BHLHB5', 'Beta3', 'Beta3a', 'CAGL85', 'TNRC20'], description='basic helix-loop-helix family member e22', other_designations='class E basic helix-loop-helix protein 22|basic helix-loop-helix domain containing, class B, 5|class B basic helix-loop-helix protein 5|trinucleotide repeat containing 20', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=64580365, end_position_on_the_genomic_accession=64583627, orientation='plus', exon_count=1, OMIM=[613483], no_hdr0=''),
    27324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27324, CurrentID=0, Status='live', Symbol='TOX3', Aliases=['CAGF9', 'TNRC9'], description='TOX high mobility group box family member 3', other_designations='TOX high mobility group box family member 3|CAG trinucleotide repeat-containing gene F9 protein|trinucleotide repeat-containing gene 9 protein', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=52436415, end_position_on_the_genomic_accession=52547802, orientation='minus', exon_count=10, OMIM=[611416], no_hdr0=''),
    27327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27327, CurrentID=0, Status='live', Symbol='TNRC6A', Aliases=['CAGH26', 'FAME6', 'GW1', 'GW182', 'TNRC6'], description='trinucleotide repeat containing adaptor 6A', other_designations='trinucleotide repeat-containing gene 6A protein|CAG repeat protein 26|CTD-2540M10.1|EDIE|EMSY interactor protein|GW182 autoantigen|glycine-tryptophan protein of 182 kDa|trinucleotide repeat containing 6A', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=24610205, end_position_on_the_genomic_accession=24826223, orientation='plus', exon_count=28, OMIM=[610739], no_hdr0=''),
    27328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27328, CurrentID=0, Status='live', Symbol='PCDH11X', Aliases=['PCDH-X', 'PCDH-Y', 'PCDH11', 'PCDH11Y', 'PCDH22', 'PCDHX', 'PPP1R119'], description='protocadherin 11 X-linked', other_designations='protocadherin-11 X-linked|Protocadherin on the Y chromosome|Protocadherin prostate cancer|Protocadherin-11 Y-linked|Protocadherin-22|Protocadherin-PC|protein phosphatase 1, regulatory subunit 119|protocadherin 11X|protocadherin on the X chromosome|protocadherin-S', map_location='Xq21.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=91779310, end_position_on_the_genomic_accession=92623230, orientation='plus', exon_count=15, OMIM=[300246], no_hdr0=''),
    27329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27329, CurrentID=0, Status='live', Symbol='ANGPTL3', Aliases=['ANG-5', 'ANGPT5', 'ANL3', 'FHBL2'], description='angiopoietin like 3', other_designations='angiopoietin-related protein 3|angiopoietin 5', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62597520, end_position_on_the_genomic_accession=62606313, orientation='plus', exon_count=7, OMIM=[604774], no_hdr0=''),
    27330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27330, CurrentID=0, Status='live', Symbol='RPS6KA6', Aliases=['PP90RSK4', 'RSK-4', 'RSK4', 'S6K-alpha-6', 'p90RSK6'], description='ribosomal protein S6 kinase A6', other_designations='ribosomal protein S6 kinase alpha-6|90 kDa ribosomal protein S6 kinase 6|S6K-alpha 6|p90-RSK 6|ribosomal S6 kinase 4|ribosomal protein S6 kinase, 90kDa, polypeptide 6', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=84058346, end_position_on_the_genomic_accession=84188199, orientation='minus', exon_count=27, OMIM=[300303], no_hdr0=''),
    27332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27332, CurrentID=0, Status='live', Symbol='ZNF638', Aliases=['NP220', 'ZFML', 'Zfp638'], description='zinc finger protein 638', other_designations='zinc finger protein 638|CTCL tumor antigen se33-1|CTCL-associated antigen se33-1|NP220 nuclear protein|cutaneous T-cell lymphoma-associated antigen se33-1|nuclear protein 220|zinc finger matrin-like protein', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71331782, end_position_on_the_genomic_accession=71435061, orientation='plus', exon_count=28, OMIM=[614349], no_hdr0=''),
    27333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27333, CurrentID=0, Status='live', Symbol='GOLIM4', Aliases=['GIMPC', 'GOLPH4', 'GPP130', 'P138'], description='golgi integral membrane protein 4', other_designations='Golgi integral membrane protein 4|130 kDa golgi-localized phosphoprotein|cis Golgi-localized calcium-binding protein|golgi integral membrane protein, cis|golgi phosphoprotein 4|golgi phosphoprotein of 130 kDa|golgi-localized phosphoprotein of 130 kDa|type II Golgi membrane protein', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=168008672, end_position_on_the_genomic_accession=168095924, orientation='minus', exon_count=17, OMIM=[606805], no_hdr0=''),
    27334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27334, CurrentID=0, Status='live', Symbol='P2RY10', Aliases=['LYPSR2', 'P2Y10'], description='P2Y receptor family member 10', other_designations='putative P2Y purinoceptor 10|G-protein coupled purinergic receptor P2Y10|P2Y-like receptor|purinergic receptor P2Y, G-protein coupled, 10|purinergic receptor P2Y10', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78945391, end_position_on_the_genomic_accession=78963727, orientation='plus', exon_count=5, OMIM=[300529], no_hdr0=''),
    27335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27335, CurrentID=0, Status='live', Symbol='EIF3K', Aliases=['ARG134', 'EIF3-p28', 'EIF3S12', 'HSPC029', 'M9', 'MSTP001', 'PLAC-24', 'PLAC24', 'PRO1474', 'PTD001'], description='eukaryotic translation initiation factor 3 subunit K', other_designations='eukaryotic translation initiation factor 3 subunit K|eIF-3 p28|eukaryotic translation initiation factor 3, subunit 12|muscle specific|muscle-specific gene M9 protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38619188, end_position_on_the_genomic_accession=38636954, orientation='plus', exon_count=8, OMIM=[609596], no_hdr0=''),
    27336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27336, CurrentID=0, Status='live', Symbol='HTATSF1', Aliases=['TAT-SF1', 'TATSF1', 'dJ196E23.2'], description='HIV-1 Tat specific factor 1', other_designations='HIV Tat-specific factor 1|HIV TAT specific factor 1|cofactor required for Tat activation of HIV-1 transcription', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136497227, end_position_on_the_genomic_accession=136512346, orientation='plus', exon_count=10, OMIM=[300346], no_hdr0=''),
    27338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27338, CurrentID=0, Status='live', Symbol='UBE2S', Aliases=['E2-EPF', 'E2EPF', 'EPF5'], description='ubiquitin conjugating enzyme E2 S', other_designations='ubiquitin-conjugating enzyme E2 S|E2 ubiquitin-conjugating enzyme S|E2-EPF5|ubiquitin carrier protein S|ubiquitin conjugating enzyme E2S|ubiquitin-conjugating enzyme E2-24 kDa|ubiquitin-conjugating enzyme E2-EPF5|ubiquitin-protein ligase S', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55399745, end_position_on_the_genomic_accession=55408439, orientation='minus', exon_count=5, OMIM=[610309], no_hdr0=''),
    27339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27339, CurrentID=0, Status='live', Symbol='PRPF19', Aliases=['NMP200', 'PRP19', 'PSO4', 'SNEV', 'UBOX4', 'hPSO4'], description='pre-mRNA processing factor 19', other_designations='pre-mRNA-processing factor 19|PRP19/PSO4 homolog|PRP19/PSO4 pre-mRNA processing factor 19 homolog|RING-type E3 ubiquitin transferase PRP19|nuclear matrix protein 200|nuclear matrix protein NMP200 related to splicing factor PRP19|psoralen 4|senescence evasion factor', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60890547, end_position_on_the_genomic_accession=60906585, orientation='minus', exon_count=16, OMIM=[608330], no_hdr0=''),
    27340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27340, CurrentID=0, Status='live', Symbol='UTP20', Aliases=['1A6/DRIM', 'DRIM'], description='UTP20 small subunit processome component', other_designations='small subunit processome component 20 homolog|NNP73|UTP20 small subunit (SSU) processome component|UTP20, small subunit (SSU) processome component, homolog|down regulated in metastasis|down-regulated in metastasis protein|novel nucleolar protein 73', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101280105, end_position_on_the_genomic_accession=101386618, orientation='plus', exon_count=62, OMIM=[612822], no_hdr0=''),
    27341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27341, CurrentID=0, Status='live', Symbol='RRP7A', Aliases=['BK126B4.3', 'CGI-96', 'Rrp7'], description='ribosomal RNA processing 7 homolog A', other_designations='ribosomal RNA-processing protein 7 homolog A|CTA-126B4.5|gastric cancer antigen Zg14', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42508344, end_position_on_the_genomic_accession=42519796, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    27342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27342, CurrentID=0, Status='live', Symbol='RABGEF1', Aliases=['RABEX5', 'RAP1', 'rabex-5'], description='RAB guanine nucleotide exchange factor 1', other_designations='rab5 GDP/GTP exchange factor|RAB guanine nucleotide exchange factor (GEF) 1|rabaptin-5-associated exchange factor for Rab5', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66654567, end_position_on_the_genomic_accession=66811464, orientation='plus', exon_count=24, OMIM=[609700], no_hdr0=''),
    27343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27343, CurrentID=0, Status='live', Symbol='POLL', Aliases=['BETAN', 'POLKAPPA'], description='DNA polymerase lambda', other_designations='DNA polymerase lambda|DNA polymerase beta-2|DNA polymerase beta-N|DNA polymerase kappa|polymerase (DNA directed), lambda|polymerase (DNA) lambda', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101578882, end_position_on_the_genomic_accession=101588319, orientation='minus', exon_count=10, OMIM=[606343], no_hdr0=''),
    27344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27344, CurrentID=0, Status='live', Symbol='PCSK1N', Aliases=['BigLEN', 'PEN', 'PROSAAS', 'SAAS', 'SCG8', 'SgVIII'], description='proprotein convertase subtilisin/kexin type 1 inhibitor', other_designations='proSAAS|granin-like neuroendocrine peptide|pro-SAAS|proprotein convertase 1 inhibitor', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48831096, end_position_on_the_genomic_accession=48835610, orientation='minus', exon_count=3, OMIM=[300399], no_hdr0=''),
    27345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27345, CurrentID=0, Status='live', Symbol='KCNMB4', Aliases=[], description='potassium calcium-activated channel subfamily M regulatory beta subunit 4', other_designations='calcium-activated potassium channel subunit beta-4|BK channel beta subunit 4|BK channel subunit beta-4|BKbeta4|MaxiK channel beta-subunit 4|big potassium channel beta subunit 4|calcium-activated potassium channel, subfamily M subunit beta-4|charybdotoxin receptor subunit beta-4|hbeta4|k(VCA)beta-4|large conductance calcium-dependent potassium ion channel beta 4 subunit|maxi K channel subunit beta-4|potassium channel subfamily M regulatory beta subunit 4|potassium large conductance calcium-activated channel, subfamily M, beta member 4|slo-beta-4', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=70366220, end_position_on_the_genomic_accession=70434292, orientation='plus', exon_count=5, OMIM=[605223], no_hdr0=''),
    27346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27346, CurrentID=0, Status='live', Symbol='TMEM97', Aliases=['MAC30', 'sigma2R'], description='transmembrane protein 97', other_designations='sigma intracellular receptor 2|meningioma-associated protein 30|sigma-2 receptor|sigma2 receptor', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28319041, end_position_on_the_genomic_accession=28328685, orientation='plus', exon_count=3, OMIM=[612912], no_hdr0=''),
    27347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27347, CurrentID=0, Status='live', Symbol='STK39', Aliases=['DCHT', 'PASK', 'SPAK'], description='serine/threonine kinase 39', other_designations='STE20/SPS1-related proline-alanine-rich protein kinase|STE20/SPS1 homolog|Ste20-like protein kinase|proline-alanine-rich STE20-related kinase|serine threonine kinase 39 (STE20/SPS1 homolog, yeast)|serine/threonine-protein kinase 39|small intestine SPAK-like kinase|ste-20-related kinase', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=167954020, end_position_on_the_genomic_accession=168247595, orientation='minus', exon_count=23, OMIM=[607648], no_hdr0=''),
    27348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27348, CurrentID=0, Status='live', Symbol='TOR1B', Aliases=['DQ1'], description='torsin family 1 member B', other_designations='torsin-1B|torsin ATPase-1B|torsin B', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129803143, end_position_on_the_genomic_accession=129811424, orientation='plus', exon_count=5, OMIM=[608050], no_hdr0=''),
    27349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27349, CurrentID=0, Status='live', Symbol='MCAT', Aliases=['FASN2C', 'MCT', 'MCT1', 'MT', 'NET62', 'fabD'], description='malonyl-CoA-acyl carrier protein transacylase', other_designations='malonyl-CoA-acyl carrier protein transacylase, mitochondrial|[Acyl-carrier-protein] malonyltransferase|[acyl-carrier-protein] S-malonyltransferase|malonyl CoA:ACP acyltransferase (mitochondrial)|mitochondrial malonyl CoA:ACP acyltransferase|mitochondrial malonyltransferase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43132206, end_position_on_the_genomic_accession=43143398, orientation='minus', exon_count=4, OMIM=[614479], no_hdr0=''),
    27350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27350, CurrentID=0, Status='live', Symbol='APOBEC3C', Aliases=['A3C', 'APOBEC1L', 'ARDC2', 'ARDC4', 'ARP5', 'PBI', 'bK150C2.3'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3C', other_designations='DNA dC->dU-editing enzyme APOBEC-3C|apolipoprotein B editing enzyme catalytic polypeptide-like 3C|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3C|phorbolin I|probable DNA dC->dU-editing enzyme APOBEC-3C', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39014236, end_position_on_the_genomic_accession=39020352, orientation='plus', exon_count=3, OMIM=[607750], no_hdr0=''),
    27351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27351, CurrentID=0, Status='live', Symbol='DESI1', Aliases=['D15Wsu75e', 'DESI2', 'DJ347H13.4', 'DeSI-1', 'FAM152B', 'POST', 'PPPDE2'], description='desumoylating isopeptidase 1', other_designations='desumoylating isopeptidase 1|PPPDE peptidase domain containing 2|PPPDE peptidase domain-containing protein 2|desumoylating isopeptidase 2|family with sequence similarity 152, member B|polyubiquitinated substrate transporter', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41598028, end_position_on_the_genomic_accession=41621077, orientation='minus', exon_count=7, OMIM=[614637], no_hdr0=''),
    27352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27352, CurrentID=0, Status='live', Symbol='SGSM3', Aliases=['CIP85', 'MAP', 'RABGAP5', 'RUSC3', 'RUTBC3', 'RabGAP-5', 'rabGAPLP'], description='small G protein signaling modulator 3', other_designations='small G protein signaling modulator 3|RUN and SH3 containing 3|RUN and TBC1 domain containing 3|RUN and TBC1 domain-containing protein 3|merlin binding protein|merlin-associated protein|rab-GTPase-activating protein-like protein|small G protein signaling modulator 3 protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40370584, end_position_on_the_genomic_accession=40410289, orientation='plus', exon_count=23, OMIM=[610440], no_hdr0=''),
    27429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27429, CurrentID=0, Status='live', Symbol='HTRA2', Aliases=['MGCA8', 'OMI', 'PARK13', 'PRSS25'], description='HtrA serine peptidase 2', other_designations='serine protease HTRA2, mitochondrial|HtrA-like serine protease|Omi stress-regulated endoprotease|epididymis secretory sperm binding protein|high temperature requirement protein A2|protease, serine, 25|serine protease 25|serine proteinase OMI', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74529405, end_position_on_the_genomic_accession=74533556, orientation='plus', exon_count=8, OMIM=[606441], no_hdr0=''),
    27430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27430, CurrentID=0, Status='live', Symbol='MAT2B', Aliases=['MAT-II', 'MATIIbeta', 'Nbla02999', 'SDR23E1', 'TGR'], description='methionine adenosyltransferase 2B', other_designations='methionine adenosyltransferase 2 subunit beta|MAT II beta|beta regulatory subunit of methionine adenosyltransferase|dTDP-4-keto-6-deoxy-D-glucose 4-reductase|methionine adenosyltransferase II, beta|putative dTDP-4-keto-6-deoxy-D-glucose 4-reductase|putative protein product of Nbla02999|short chain dehydrogenase/reductase family 23E, member 1|testicular tissue protein Li 118', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=163503064, end_position_on_the_genomic_accession=163519354, orientation='plus', exon_count=8, OMIM=[605527], no_hdr0=''),
    27433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27433, CurrentID=0, Status='live', Symbol='TOR2A', Aliases=['TORP1'], description='torsin family 2 member A', other_designations='prosalusin|salusin-beta|torsin-2A|torsin-related protein 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127731524, end_position_on_the_genomic_accession=127735328, orientation='minus', exon_count=5, OMIM=[608052], no_hdr0=''),
    27434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27434, CurrentID=0, Status='live', Symbol='POLM', Aliases=['Pol Mu', 'Tdt-N'], description='DNA polymerase mu', other_designations='DNA-directed DNA/RNA polymerase mu|Pol iota|polymerase (DNA) mu|polymerase (DNA-directed), mu|terminal transferase', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44072062, end_position_on_the_genomic_accession=44082530, orientation='minus', exon_count=11, OMIM=[606344], no_hdr0=''),
    27436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27436, CurrentID=0, Status='live', Symbol='EML4', Aliases=['C2orf2', 'ELP120', 'EMAP-4', 'EMAPL4', 'ROPP120'], description='EMAP like 4', other_designations='echinoderm microtubule-associated protein-like 4|echinoderm microtubule associated protein like 4|restrictedly overexpressed proliferation-associated protein|ropp 120', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42169353, end_position_on_the_genomic_accession=42332548, orientation='plus', exon_count=26, OMIM=[607442], no_hdr0=''),
    27439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27439, CurrentID=0, Status='live', Symbol='TMEM121B', Aliases=['CECR6'], description='transmembrane protein 121B', other_designations='transmembrane protein 121B|cat eye syndrome chromosome region, candidate 6|cat eye syndrome critical region protein 6', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17116297, end_position_on_the_genomic_accession=17121360, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    27440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27440, CurrentID=0, Status='live', Symbol='HDHD5', Aliases=['CECR5'], description='haloacid dehalogenase like hydrolase domain containing 5', other_designations='haloacid dehalogenase-like hydrolase domain-containing 5|cat eye syndrome chromosome region, candidate 5|cat eye syndrome critical region protein 5', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17137520, end_position_on_the_genomic_accession=17165287, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    27443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27443, CurrentID=0, Status='live', Symbol='CECR2', Aliases=[], description='CECR2 histone acetyl-lysine reader', other_designations='cat eye syndrome critical region protein 2|cat eye syndrome chromosome region, candidate 2', map_location='22q11.1-q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17359949, end_position_on_the_genomic_accession=17558151, orientation='plus', exon_count=21, OMIM=[607576], no_hdr0=''),
    27445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=27445, CurrentID=0, Status='live', Symbol='PCLO', Aliases=['ACZ', 'PCH3'], description='piccolo presynaptic cytomatrix protein', other_designations='protein piccolo|aczonin', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=82754012, end_position_on_the_genomic_accession=83164161, orientation='minus', exon_count=25, OMIM=[604918], no_hdr0=''),
    28227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28227, CurrentID=0, Status='live', Symbol='PPP2R3B', Aliases=['NYREN8', 'PPP2R3L', 'PPP2R3LY', 'PR48', 'PR70'], description="protein phosphatase 2 regulatory subunit B''beta", other_designations="serine/threonine-protein phosphatase 2A regulatory subunit B'' subunit beta|NY-REN-8 antigen|protein phosphatase 2 (formerly 2A), regulatory subunit B'', beta|protein phosphatase 2, regulatory subunit B'', beta|serine/threonine protein phosphatase 2A, 48kDa regulatory subunit B", map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=333933, end_position_on_the_genomic_accession=387327, orientation='minus', exon_count=16, OMIM=[300339], no_hdr0=''),
    28231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28231, CurrentID=0, Status='live', Symbol='SLCO4A1', Aliases=['OATP-E', 'OATP1', 'OATP4A1', 'OATPE', 'OATPRP1', 'POAT', 'SLC21A12'], description='solute carrier organic anion transporter family member 4A1', other_designations='solute carrier organic anion transporter family member 4A1|OATP-RP1|colon organic anion transporter|organic anion transporter polypeptide-related protein 1|organic anion transporting polypeptide E|sodium-independent organic anion transporter E|solute carrier family 21 (organic anion transporter), member 12|solute carrier family 21 member 12', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62642058, end_position_on_the_genomic_accession=62690722, orientation='plus', exon_count=17, OMIM=[612436], no_hdr0=''),
    28232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28232, CurrentID=0, Status='live', Symbol='SLCO3A1', Aliases=['OATP-D', 'OATP-RP3', 'OATP3A1', 'OATPD', 'OATPRP3', 'SLC21A11'], description='solute carrier organic anion transporter family member 3A1', other_designations='solute carrier organic anion transporter family member 3A1|PGE1 transporter|organic anion transporter polypeptide-related protein 3|organic anion-transporting polypeptide D|sodium-independent organic anion transporter D|solute carrier family 21 (organic anion transporter), member 11|solute carrier family 21 member 11', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=91853708, end_position_on_the_genomic_accession=92172435, orientation='plus', exon_count=16, OMIM=[612435], no_hdr0=''),
    28234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28234, CurrentID=0, Status='live', Symbol='SLCO1B3', Aliases=['HBLRR', 'LST-2', 'LST-3TM13', 'LST3', 'OATP-8', 'OATP1B3', 'OATP8', 'SLC21A8'], description='solute carrier organic anion transporter family member 1B3', other_designations='solute carrier organic anion transporter family member 1B3|liver-specific organic anion transporter 2|liver-specific organic anion transporter 3TM13|organic anion transporter 8|organic anion transporter LST-3c|organic anion-transporting polypeptide 8|solute carrier family 21 (organic anion transporter), member 8', map_location='12p12.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=20810705, end_position_on_the_genomic_accession=20916911, orientation='plus', exon_count=17, OMIM=[605495], no_hdr0=''),
    28316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28316, CurrentID=0, Status='live', Symbol='CDH20', Aliases=['CDH7L3', 'Cdh7'], description='cadherin 20', other_designations='cadherin-20|cadherin 20, type 2', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=61333430, end_position_on_the_genomic_accession=61555779, orientation='plus', exon_count=15, OMIM=[605807], no_hdr0=''),
    28511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28511, CurrentID=0, Status='live', Symbol='NKIRAS2', Aliases=['KBRAS2', 'kappaB-Ras2'], description='NFKB inhibitor interacting Ras like 2', other_designations='NF-kappa-B inhibitor-interacting Ras-like protein 2|I-kappa-B-interacting Ras-like protein 2|NFKB inhibitor interacting Ras-like protein 2|kappa B-Ras protein 2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42017576, end_position_on_the_genomic_accession=42025641, orientation='plus', exon_count=5, OMIM=[604497], no_hdr0=''),
    28512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28512, CurrentID=0, Status='live', Symbol='NKIRAS1', Aliases=['KBRAS1', 'kappaB-Ras1'], description='NFKB inhibitor interacting Ras like 1', other_designations='NF-kappa-B inhibitor-interacting Ras-like protein 1|I-kappa-B-interacting Ras-like protein 1|NFKB inhibitor interacting Ras-like protein 1|kappa B-Ras protein 1|kappa B-ras 1', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=23889949, end_position_on_the_genomic_accession=23946562, orientation='minus', exon_count=13, OMIM=[604496], no_hdr0=''),
    28513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28513, CurrentID=0, Status='live', Symbol='CDH19', Aliases=['CDH7', 'CDH7L2'], description='cadherin 19', other_designations='cadherin-19|cadherin 19, type 2', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=66501083, end_position_on_the_genomic_accession=66604241, orientation='minus', exon_count=14, OMIM=[603016], no_hdr0=''),
    28514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28514, CurrentID=0, Status='live', Symbol='DLL1', Aliases=['DELTA1', 'DL1', 'Delta', 'NEDBAS'], description='delta like canonical Notch ligand 1', other_designations='delta-like protein 1|H-Delta-1|drosophila Delta homolog 1|epididymis secretory sperm binding protein', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=170282200, end_position_on_the_genomic_accession=170291078, orientation='minus', exon_count=11, OMIM=[606582], no_hdr0=''),
    28951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28951, CurrentID=0, Status='live', Symbol='TRIB2', Aliases=['C5FW', 'GS3955', 'TRB2'], description='tribbles pseudokinase 2', other_designations='tribbles homolog 2', map_location='2p24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=12716936, end_position_on_the_genomic_accession=12742734, orientation='plus', exon_count=3, OMIM=[609462], no_hdr0=''),
    28952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28952, CurrentID=0, Status='live', Symbol='CCDC22', Aliases=['CXorf37', 'JM1', 'RTSC2'], description='coiled-coil domain containing 22', other_designations='coiled-coil domain-containing protein 22', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49235470, end_position_on_the_genomic_accession=49250526, orientation='plus', exon_count=17, OMIM=[300859], no_hdr0=''),
    28954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28954, CurrentID=0, Status='live', Symbol='REM1', Aliases=['GD:REM', 'GES'], description='RRAD and GEM like GTPase 1', other_designations='GTP-binding protein REM 1|GTPase-regulating endothelial cell sprouting|RAS (RAD and GEM)-like GTP-binding 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31475273, end_position_on_the_genomic_accession=31484895, orientation='plus', exon_count=5, OMIM=[610388], no_hdr0=''),
    28955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28955, CurrentID=0, Status='live', Symbol='DEXI', Aliases=['MYLE'], description='Dexi homolog', other_designations='dexamethasone-induced protein|dexamethasone-induced transcript', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10928891, end_position_on_the_genomic_accession=10942468, orientation='minus', exon_count=2, OMIM=[617901], no_hdr0=''),
    28956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28956, CurrentID=0, Status='live', Symbol='LAMTOR2', Aliases=['ENDAP', 'HSPC003', 'MAPBPIP', 'MAPKSP1AP', 'ROBLD3', 'Ragulator2', 'p14'], description='late endosomal/lysosomal adaptor, MAPK and MTOR activator 2', other_designations='ragulator complex protein LAMTOR2|MAPBP-interacting protein|MAPKSP1 adaptor protein|endosomal adaptor protein p14|late endosomal/lysosomal Mp1-interacting protein|late endosomal/lysosomal adaptor and MAPK and MTOR activator 2|mitogen-activated protein-binding protein-interacting protein (MAPBPIP)|roadblock domain containing 3|roadblock domain-containing protein 3', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156054782, end_position_on_the_genomic_accession=156058506, orientation='plus', exon_count=4, OMIM=[610389], no_hdr0=''),
    28957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28957, CurrentID=0, Status='live', Symbol='MRPS28', Aliases=['COXPD47', 'HSPC007', 'MRP-S28', 'MRP-S35', 'MRPS35'], description='mitochondrial ribosomal protein S28', other_designations='28S ribosomal protein S28, mitochondrial|28S ribosomal protein S35, mitochondrial|S28mt|S35mt|mitochondrial 28S ribosomal protein S35|mitochondrial small ribosomal subunit protein bS1m', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=79918717, end_position_on_the_genomic_accession=80030259, orientation='minus', exon_count=3, OMIM=[611990], no_hdr0=''),
    28958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28958, CurrentID=0, Status='live', Symbol='COA3', Aliases=['CCDC56', 'COX25', 'HSPC009', 'MC4DN14', 'MITRAC12'], description='cytochrome c oxidase assembly factor 3', other_designations='cytochrome c oxidase assembly factor 3 homolog, mitochondrial|coiled-coil domain-containing protein 56|cytochrome C oxidase assembly factor 3 homolog, mitochondrial|cytochrome c oxidase assembly protein 3 homolog, mitochondrial|mitochondrial translation regulation assembly intermediate of cytochrome c oxidase protein of 12 kDa', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42797625, end_position_on_the_genomic_accession=42798704, orientation='minus', exon_count=2, OMIM=[614775], no_hdr0=''),
    28959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28959, CurrentID=0, Status='live', Symbol='TMEM176B', Aliases=['LR8', 'MS4B2'], description='transmembrane protein 176B', other_designations='transmembrane protein 176B|LR8-like protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150791287, end_position_on_the_genomic_accession=150801360, orientation='minus', exon_count=11, OMIM=[610385], no_hdr0=''),
    28960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28960, CurrentID=0, Status='live', Symbol='DCPS', Aliases=['ARS', 'DCS1', 'HINT-5', 'HINT5', 'HSL1', 'HSPC015'], description='decapping enzyme, scavenger', other_designations="m7GpppX diphosphatase|5'-(N(7)-methyl 5'-triphosphoguanosine)-[mRNA] diphosphatase|decapping scavenger enzyme|epididymis secretory sperm binding protein|heat shock-like protein 1|hint-related 7meGMP-directed hydrolase|histidine triad nucleotide-binding protein 5|histidine triad protein member 5|homolog of C. elegans 7meGMP-directed hydrolase dcs-1|mRNA decapping enzyme|scavenger mRNA-decapping enzyme DcpS", map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126304060, end_position_on_the_genomic_accession=126350005, orientation='plus', exon_count=6, OMIM=[610534], no_hdr0=''),
    28962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28962, CurrentID=0, Status='live', Symbol='OSTM1', Aliases=['GIPN', 'GL', 'HSPC019', 'OPTB5'], description='osteoclastogenesis associated transmembrane protein 1', other_designations='osteopetrosis-associated transmembrane protein 1|CLCN7 accessory beta subunit|GAIP-interacting protein N terminus|chloride channel 7 beta subunit|grey-lethal osteopetrosis|osteopetrosis associated transmembrane protein 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108041409, end_position_on_the_genomic_accession=108074741, orientation='minus', exon_count=7, OMIM=[607649], no_hdr0=''),
    28964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28964, CurrentID=0, Status='live', Symbol='GIT1', Aliases=['p95-APP1'], description='GIT ArfGAP 1', other_designations='ARF GTPase-activating protein GIT1|ARF GAP GIT1|CAT-1|CAT1|G protein-coupled receptor kinase interacting ArfGAP 1|G protein-coupled receptor kinase-interactor 1|GRK-interacting protein 1|cool-associated and tyrosine-phosphorylated protein 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29573475, end_position_on_the_genomic_accession=29589648, orientation='minus', exon_count=21, OMIM=[608434], no_hdr0=''),
    28965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28965, CurrentID=0, Status='live', Symbol='SLC27A6', Aliases=['ACSVL2', 'FACVL2', 'FATP6', 'VLCS-H1'], description='solute carrier family 27 member 6', other_designations='long-chain fatty acid transport protein 6|acyl-CoA synthetase very long chain family, member 2|arachidonate--CoA ligase|fatty-acid-Coenzyme A ligase, very long-chain 2|solute carrier family 27 (fatty acid transporter), member 6|very long-chain acyl-CoA synthetase homolog 1', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=128965488, end_position_on_the_genomic_accession=129033635, orientation='plus', exon_count=10, OMIM=[604196], no_hdr0=''),
    28966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28966, CurrentID=0, Status='live', Symbol='SNX24', Aliases=['PRO1284', 'SBBI31'], description='sorting nexin 24', other_designations='sorting nexin-24|sorting nexing 24', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122845510, end_position_on_the_genomic_accession=123029318, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    28968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28968, CurrentID=0, Status='live', Symbol='SLC6A16', Aliases=['NT5', 'NTT5'], description='solute carrier family 6 member 16', other_designations='orphan sodium- and chloride-dependent neurotransmitter transporter NTT5|CTC-301O7.4|solute carrier family 6 (neurotransmitter transporter), member 16', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49289632, end_position_on_the_genomic_accession=49332320, orientation='minus', exon_count=16, OMIM=[607972], no_hdr0=''),
    28969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28969, CurrentID=0, Status='live', Symbol='BZW2', Aliases=['5MP1', 'HSPC028', 'MST017', 'MSTP017'], description='basic leucine zipper and W2 domains 2', other_designations='basic leucine zipper and W2 domain-containing protein 2', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16646181, end_position_on_the_genomic_accession=16706522, orientation='plus', exon_count=15, OMIM=[619275], no_hdr0=''),
    28970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28970, CurrentID=0, Status='live', Symbol='C11orf54', Aliases=['PTD012', 'PTOD012'], description='chromosome 11 open reading frame 54', other_designations='ester hydrolase C11orf54|epididymis secretory sperm binding protein', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93741672, end_position_on_the_genomic_accession=93764749, orientation='plus', exon_count=13, OMIM=[615810], no_hdr0=''),
    28971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28971, CurrentID=0, Status='live', Symbol='AAMDC', Aliases=['C11orf67', 'CK067', 'PTD015'], description='adipogenesis associated Mth938 domain containing', other_designations='mth938 domain-containing protein|UPF0366 protein C11orf67|adipogenesis associated Mth938 domain-containing protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77821144, end_position_on_the_genomic_accession=77906024, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    28972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28972, CurrentID=0, Status='live', Symbol='SPCS1', Aliases=['HSPC033', 'SPC1', 'SPC12', 'YJR010C-A'], description='signal peptidase complex subunit 1', other_designations='signal peptidase complex subunit 1|SPase 12 kDa subunit|microsomal signal peptidase 12 kDa subunit|signal peptidase 12kDa|signal peptidase complex 12 kDa subunit|signal peptidase complex subunit 1 homolog', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52706106, end_position_on_the_genomic_accession=52711148, orientation='plus', exon_count=4, OMIM=[610358], no_hdr0=''),
    28973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28973, CurrentID=0, Status='live', Symbol='MRPS18B', Aliases=['C6orf14', 'HSPC183', 'HumanS18a', 'MRP-S18-2', 'MRPS18-2', 'PTD017', 'S18amt'], description='mitochondrial ribosomal protein S18B', other_designations='28S ribosomal protein S18b, mitochondrial|28S ribosomal protein S18-2, mitochondrial|MRP-S18-b|S18mt-b|mitochondrial ribosomal protein S18-2|mitochondrial small ribosomal subunit protein bS18b|mitochondrial small ribosomal subunit protein bS18m-B|mitochondrial small ribosomal subunit protein mS40|mrps18-b', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30617320, end_position_on_the_genomic_accession=30626393, orientation='plus', exon_count=7, OMIM=[611982], no_hdr0=''),
    28974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28974, CurrentID=0, Status='live', Symbol='C19orf53', Aliases=['HSPC023', 'LYDG10'], description='chromosome 19 open reading frame 53', other_designations='leydig cell tumor 10 kDa protein homolog', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13774456, end_position_on_the_genomic_accession=13778773, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    28976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28976, CurrentID=0, Status='live', Symbol='ACAD9', Aliases=['MC1DN20', 'NPD002'], description='acyl-CoA dehydrogenase family member 9', other_designations='complex I assembly factor ACAD9, mitochondrial|acyl-Coenzyme A dehydrogenase family, member 9|very-long-chain acyl-CoA dehydrogenase VLCAD', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128879596, end_position_on_the_genomic_accession=128913114, orientation='plus', exon_count=18, OMIM=[611103], no_hdr0=''),
    28977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28977, CurrentID=0, Status='live', Symbol='MRPL42', Aliases=['HSPC204', 'L31MT', 'L42MT', 'MRP-L31', 'MRP-L42', 'MRP-S32', 'MRPL31', 'MRPS32', 'PTD007', 'RPML31', 'S32MT'], description='mitochondrial ribosomal protein L42', other_designations='39S ribosomal protein L42, mitochondrial|28S ribosomal protein S32, mitochondrial|39S ribosomal protein L31, mitochondrial|mitochondrial large ribosomal subunit protein mL42', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=93467514, end_position_on_the_genomic_accession=93516214, orientation='plus', exon_count=7, OMIM=[611847], no_hdr0=''),
    28978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28978, CurrentID=0, Status='live', Symbol='TMEM14A', Aliases=['C6orf73', 'PTD011'], description='transmembrane protein 14A', other_designations='transmembrane protein 14A', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52671099, end_position_on_the_genomic_accession=52686588, orientation='plus', exon_count=5, OMIM=[616870], no_hdr0=''),
    28981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28981, CurrentID=0, Status='live', Symbol='IFT81', Aliases=['CDV-1', 'CDV-1R', 'CDV1', 'CDV1R', 'DV1', 'SRTD19'], description='intraflagellar transport 81', other_designations='intraflagellar transport protein 81 homolog|carnitine deficiency-associated gene expressed in ventricle 1|carnitine deficiency-associated protein expressed in ventricle 1', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110124335, end_position_on_the_genomic_accession=110218793, orientation='plus', exon_count=22, OMIM=[605489], no_hdr0=''),
    28982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28982, CurrentID=0, Status='live', Symbol='FLVCR1', Aliases=['AXPC1', 'FLVCR', 'MFSD7B', 'PCA', 'PCARP', 'SLC49A1'], description='FLVCR heme transporter 1', other_designations='feline leukemia virus subgroup C receptor-related protein 1|feline leukemia virus subgroup C cellular receptor 1', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212858275, end_position_on_the_genomic_accession=212899363, orientation='plus', exon_count=13, OMIM=[609144], no_hdr0=''),
    28983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28983, CurrentID=0, Status='live', Symbol='TMPRSS11E', Aliases=['DESC12', 'TMPRSS11E'], description='transmembrane serine protease 11E', other_designations='transmembrane protease serine 11E|serine protease DESC1|transmembrane protease serine 11E2|transmembrane protease, serine 11E', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68447463, end_position_on_the_genomic_accession=68497604, orientation='plus', exon_count=10, OMIM=[610399], no_hdr0=''),
    28984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28984, CurrentID=0, Status='live', Symbol='RGCC', Aliases=['C13orf15', 'RGC-32', 'RGC32', 'bA157L14.2'], description='regulator of cell cycle', other_designations='regulator of cell cycle RGCC|response gene to complement 32 protein', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41457411, end_position_on_the_genomic_accession=41470876, orientation='plus', exon_count=7, OMIM=[610077], no_hdr0=''),
    28985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28985, CurrentID=0, Status='live', Symbol='MCTS1', Aliases=['MCT-1', 'MCT1'], description='MCTS1 re-initiation and release factor', other_designations='malignant T-cell-amplified sequence 1|malignant T-cell amplified sequence 1|multiple copies T-cell malignancies|multiple copies in T-cell lymphoma-1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120604101, end_position_on_the_genomic_accession=120621159, orientation='plus', exon_count=7, OMIM=[300587], no_hdr0=''),
    28986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28986, CurrentID=0, Status='live', Symbol='MAGEH1', Aliases=['APR-1', 'APR1', 'MAGEH'], description='MAGE family member H1', other_designations='melanoma-associated antigen H1|apoptosis-related protein 1|melanoma antigen family H, 1|melanoma antigen family H1|restin', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55452127, end_position_on_the_genomic_accession=55453566, orientation='plus', exon_count=1, OMIM=[300548], no_hdr0=''),
    28987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28987, CurrentID=0, Status='live', Symbol='NOB1', Aliases=['ART-4', 'MST158', 'MSTP158P', 'PSMD8BP1', 'NOB1'], description='NIN1 (RPN12) binding protein 1 homolog', other_designations='RNA-binding protein NOB1|NIN1/PSMD8 binding protein 1 homolog|PSMD8 binding protein 1|adenocarcinoma antigen recognized by T lymphocytes 4|nin one binding protein|phosphorylation regulatory protein HP-10|protein ART-4', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69741871, end_position_on_the_genomic_accession=69754926, orientation='minus', exon_count=9, OMIM=[613586], no_hdr0=''),
    28988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28988, CurrentID=0, Status='live', Symbol='DBNL', Aliases=['ABP1', 'HIP-55', 'HIP55', 'SH3P7'], description='drebrin like', other_designations='drebrin-like protein|HPK1-interacting protein of 55 kDa|SH3 domain-containing protein 7|actin-binding protein 1|cervical SH3P7|cervical mucin-associated protein|drebrin-F|src homology 3 domain-containing protein HIP-55', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44044702, end_position_on_the_genomic_accession=44069456, orientation='plus', exon_count=13, OMIM=[610106], no_hdr0=''),
    28989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28989, CurrentID=0, Status='live', Symbol='NTMT1', Aliases=['AD-003', 'C9orf32', 'HOMT1A', 'METTL11A', 'NRMT', 'NRMT1', 'NTM1A'], description='N-terminal Xaa-Pro-Lys N-methyltransferase 1', other_designations='N-terminal Xaa-Pro-Lys N-methyltransferase 1|N-terminal RCC1 methyltransferase|X-Pro-Lys N-terminal protein methyltransferase 1A|alpha N-terminal protein methyltransferase 1A|methyltransferase-like protein 11A', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129608872, end_position_on_the_genomic_accession=129636742, orientation='plus', exon_count=7, OMIM=[613560], no_hdr0=''),
    28990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28990, CurrentID=0, Status='live', Symbol='ASTE1', Aliases=['HT001'], description='asteroid homolog 1', other_designations='protein asteroid homolog 1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=131013875, end_position_on_the_genomic_accession=131026825, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    28991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28991, CurrentID=0, Status='live', Symbol='COMMD5', Aliases=['HCARG', 'HT002'], description='COMM domain containing 5', other_designations='COMM domain-containing protein 5|hypertension-related calcium-regulated gene protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144837978, end_position_on_the_genomic_accession=144853556, orientation='minus', exon_count=6, OMIM=[608216], no_hdr0=''),
    28992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28992, CurrentID=0, Status='live', Symbol='MACROD1', Aliases=['LRP16'], description='mono-ADP ribosylhydrolase 1', other_designations='ADP-ribose glycohydrolase MACROD1|MACRO domain containing 1|MACRO domain-containing protein 1|O-acetyl-ADP-ribose deacetylase MACROD1|[Protein ADP-ribosylaspartate] hydrolase MACROD1|[Protein ADP-ribosylglutamate] hydrolase|[Protein ADP-ribosylglutamate] hydrolase MACROD1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63998554, end_position_on_the_genomic_accession=64166652, orientation='minus', exon_count=14, OMIM=[610400], no_hdr0=''),
    28996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28996, CurrentID=0, Status='live', Symbol='HIPK2', Aliases=['PRO0593'], description='homeodomain interacting protein kinase 2', other_designations='homeodomain-interacting protein kinase 2|hHIPk2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139561570, end_position_on_the_genomic_accession=139777998, orientation='minus', exon_count=18, OMIM=[606868], no_hdr0=''),
    28998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28998, CurrentID=0, Status='live', Symbol='MRPL13', Aliases=['L13', 'L13A', 'L13mt', 'RPL13', 'RPML13'], description='mitochondrial ribosomal protein L13', other_designations='39S ribosomal protein L13, mitochondrial|MRP-L13|mitochondrial large ribosomal subunit protein uL13m', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=120395437, end_position_on_the_genomic_accession=120445150, orientation='minus', exon_count=7, OMIM=[610200], no_hdr0=''),
    28999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=28999, CurrentID=0, Status='live', Symbol='KLF15', Aliases=['KKLF'], description='Kruppel like factor 15', other_designations='Krueppel-like factor 15|kidney-enriched Kruppel-like factor|kidney-enriched krueppel-like factor', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126288121, end_position_on_the_genomic_accession=126357408, orientation='minus', exon_count=8, OMIM=[606465], no_hdr0=''),
    29015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29015, CurrentID=0, Status='live', Symbol='SLC43A3', Aliases=['EEG1', 'ENBT1', 'FOAP-13', 'PRO1659', 'SEEEG-1'], description='solute carrier family 43 member 3', other_designations='solute carrier family 43 member 3|likely ortholog of mouse embryonic epithelial gene 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57406954, end_position_on_the_genomic_accession=57427580, orientation='minus', exon_count=15, OMIM=[618034], no_hdr0=''),
    29028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29028, CurrentID=0, Status='live', Symbol='ATAD2', Aliases=['ANCCA', 'CT137', 'PRO2000'], description='ATPase family AAA domain containing 2', other_designations='ATPase family AAA domain-containing protein 2|AAA nuclear coregulator cancer-associated protein', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123319850, end_position_on_the_genomic_accession=123396447, orientation='minus', exon_count=28, OMIM=[611941], no_hdr0=''),
    29035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29035, CurrentID=0, Status='live', Symbol='C16orf72', Aliases=['PRO0149', 'TAPR1'], description='chromosome 16 open reading frame 72', other_designations='UPF0472 protein C16orf72|Telomere Attrition and p53 Response 1', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=9091377, end_position_on_the_genomic_accession=9121635, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    29057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29057, CurrentID=0, Status='live', Symbol='FAM156A', Aliases=['PRO0659', 'TMEM29'], description='family with sequence similarity 156 member A', other_designations='protein FAM156A/FAM156B|protein FAM156A|transmembrane protein 29|transmembrane protein 29/29B', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52947254, end_position_on_the_genomic_accession=52995472, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    29058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29058, CurrentID=0, Status='live', Symbol='TMEM230', Aliases=['C20orf30', 'HSPC274', 'dJ1116H23.2.1'], description='transmembrane protein 230', other_designations='transmembrane protein 230|UPF0414 transmembrane protein C20orf30', map_location='20p13-p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5064877, end_position_on_the_genomic_accession=5113091, orientation='minus', exon_count=11, OMIM=[617019], no_hdr0=''),
    29062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29062, CurrentID=0, Status='live', Symbol='WDR91', Aliases=['HSPC049', 'SORF-1', 'SORF1'], description='WD repeat domain 91', other_designations='WD repeat-containing protein 91', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135183839, end_position_on_the_genomic_accession=135211556, orientation='minus', exon_count=17, OMIM=[616303], no_hdr0=''),
    29063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29063, CurrentID=0, Status='live', Symbol='ZCCHC4', Aliases=['HSPC052', 'ZGRF4'], description='zinc finger CCHC-type containing 4', other_designations='rRNA N6-adenosine-methyltransferase ZCCHC4|DHHC domain-containing zinc finger protein|zinc finger CCHC domain-containing protein 4|zinc finger, CCHC domain containing 4|zinc finger, GRF-type containing 4', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25312774, end_position_on_the_genomic_accession=25373176, orientation='plus', exon_count=15, OMIM=[611792], no_hdr0=''),
    29066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29066, CurrentID=0, Status='live', Symbol='ZC3H7A', Aliases=['HSPC055', 'ZC3H7', 'ZC3HDC7'], description='zinc finger CCCH-type containing 7A', other_designations='zinc finger CCCH domain-containing protein 7A|zinc finger CCCH-type domain containing 7|zinc-finger protein AY163807', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11750588, end_position_on_the_genomic_accession=11797258, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    29068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29068, CurrentID=0, Status='live', Symbol='ZBTB44', Aliases=['BTBD15', 'HSPC063', 'ZNF851'], description='zinc finger and BTB domain containing 44', other_designations='zinc finger and BTB domain-containing protein 44|BTB (POZ) domain containing 15|BTB/POZ domain-containing protein 15|zinc finger protein 851', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130226677, end_position_on_the_genomic_accession=130314917, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    29070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29070, CurrentID=0, Status='live', Symbol='CCDC113', Aliases=['HSPC065'], description='coiled-coil domain containing 113', other_designations='coiled-coil domain-containing protein 113', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58196862, end_position_on_the_genomic_accession=58283836, orientation='plus', exon_count=16, OMIM=[616070], no_hdr0=''),
    29071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29071, CurrentID=0, Status='live', Symbol='C1GALT1C1', Aliases=['C1GALT2', 'C38H2-L1', 'COSMC', 'HSPC067', 'MST143', 'TNPS'], description='C1GALT1 specific chaperone 1', other_designations='C1GALT1-specific chaperone 1|C38H2-like protein 1|beta 1,3-galactosyltransferase 2|core 1 beta1,3-galactosyltransferase 2|core 1 beta3-Gal-T2|core 1 beta3-galactosyltransferase-specific molecular chaperone|truncated C1GALT1-specific chaperone 1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120625674, end_position_on_the_genomic_accession=120630054, orientation='minus', exon_count=3, OMIM=[300611], no_hdr0=''),
    29072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29072, CurrentID=0, Status='live', Symbol='SETD2', Aliases=['HBP231', 'HIF-1', 'HIP-1', 'HSPC069', 'HYPB', 'KMT3A', 'LLS', 'SET2', 'p231HBP'], description='SET domain containing 2, histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase SETD2|huntingtin interacting protein 1|huntingtin yeast partner B|huntingtin-interacting protein B|lysine N-methyltransferase 3A|protein-lysine N-methyltransferase SETD2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47016431, end_position_on_the_genomic_accession=47164113, orientation='minus', exon_count=26, OMIM=[612778], no_hdr0=''),
    29074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29074, CurrentID=0, Status='live', Symbol='MRPL18', Aliases=['HSPC071', 'L18mt', 'MRP-L18'], description='mitochondrial ribosomal protein L18', other_designations='39S ribosomal protein L18, mitochondrial|mitochondrial large ribosomal subunit protein uL18m', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159789812, end_position_on_the_genomic_accession=159798429, orientation='plus', exon_count=6, OMIM=[611831], no_hdr0=''),
    29078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29078, CurrentID=0, Status='live', Symbol='NDUFAF4', Aliases=['C6orf66', 'HRPAP20', 'HSPC125', 'MC1DN15', 'My013', 'bA22L21.1'], description='NADH:ubiquinone oxidoreductase complex assembly factor 4', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex assembly factor 4|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, assembly factor 4|NADH dehydrogenase (ubiquinone) complex I, assembly factor 4|hormone-regulated proliferation-associated protein of 20 kDa|hormone-regulated proliferation-associated protein, 20 kDa', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96889315, end_position_on_the_genomic_accession=96897891, orientation='minus', exon_count=3, OMIM=[611776], no_hdr0=''),
    29079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29079, CurrentID=0, Status='live', Symbol='MED4', Aliases=['ARC36', 'DRIP36', 'HSPC126', 'TRAP36', 'VDRIP'], description='mediator complex subunit 4', other_designations='mediator of RNA polymerase II transcription subunit 4|activator-recruited cofactor 36 kDa component|mediator, 34-kD subunit, homolog|vitamin D receptor-interacting protein, 36-kD|vitamin D3 receptor-interacting protein complex 36 kDa component', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48075724, end_position_on_the_genomic_accession=48095104, orientation='minus', exon_count=8, OMIM=[605718], no_hdr0=''),
    29080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29080, CurrentID=0, Status='live', Symbol='CCDC59', Aliases=['BR22', 'HSPC128', 'TAP26'], description='coiled-coil domain containing 59', other_designations='thyroid transcription factor 1-associated protein 26|TTF-1-associated protein 26|TTF-1-associated protein BR2|coiled-coil domain-containing protein 59', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=82352303, end_position_on_the_genomic_accession=82358805, orientation='minus', exon_count=5, OMIM=[619280], no_hdr0=''),
    29081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29081, CurrentID=0, Status='live', Symbol='METTL5', Aliases=['HSPC133', 'MRT72'], description='methyltransferase 5, N6-adenosine', other_designations='rRNA N6-adenosine-methyltransferase METTL5|methyltransferase like 5|methyltransferase-like protein 5', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169811757, end_position_on_the_genomic_accession=169824905, orientation='minus', exon_count=8, OMIM=[618628], no_hdr0=''),
    29082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29082, CurrentID=0, Status='live', Symbol='CHMP4A', Aliases=['C14orf123', 'CHMP4', 'CHMP4B', 'HSPC134', 'SHAX2', 'SNF7', 'SNF7-1', 'VPS32-1', 'VPS32A'], description='charged multivesicular body protein 4A', other_designations='charged multivesicular body protein 4a|SNF7 homolog associated with Alix-2|Snf7 homologue associated with Alix 2|chromatin modifying protein 4A|vacuolar protein sorting-associated protein 32-1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24209615, end_position_on_the_genomic_accession=24213488, orientation='minus', exon_count=6, OMIM=[610051], no_hdr0=''),
    29083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29083, CurrentID=0, Status='live', Symbol='GTPBP8', Aliases=['HSPC135'], description='GTP binding protein 8 (putative)', other_designations='GTP-binding protein 8', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112990984, end_position_on_the_genomic_accession=113001969, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    29085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29085, CurrentID=0, Status='live', Symbol='PHPT1', Aliases=['CGI-202', 'HEL-S-132P', 'HSPC141', 'PHP', 'PHP14'], description='phosphohistidine phosphatase 1', other_designations='14 kDa phosphohistidine phosphatase|epididymis secretory sperm binding protein Li 132P|protein histidine phosphatase|protein janus-A homolog|sex-regulated protein janus-a', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136849409, end_position_on_the_genomic_accession=136851024, orientation='plus', exon_count=3, OMIM=[610167], no_hdr0=''),
    29086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29086, CurrentID=0, Status='live', Symbol='BABAM1', Aliases=['C19orf62', 'HSPC142', 'MERIT40', 'NBA1'], description='BRISC and BRCA1 A complex member 1', other_designations='BRISC and BRCA1-A complex member 1|BRCA1-A complex subunit MERIT40|mediator of RAP80 interactions and targeting subunit of 40 kDa|mediator of Rap80 interactions and targeting 40 kDa|new component of the BRCA1-A complex|new component of the BRCAA1 A complex', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17267443, end_position_on_the_genomic_accession=17279337, orientation='plus', exon_count=9, OMIM=[612766], no_hdr0=''),
    29087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29087, CurrentID=0, Status='live', Symbol='THYN1', Aliases=['HSPC144', 'MDS012', 'MY105', 'THY28', 'THY28KD'], description='thymocyte nuclear protein 1', other_designations='thymocyte nuclear protein 1|thymocyte protein thy28', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134248282, end_position_on_the_genomic_accession=134253352, orientation='minus', exon_count=8, OMIM=[613739], no_hdr0=''),
    29088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29088, CurrentID=0, Status='live', Symbol='MRPL15', Aliases=['HSPC145', 'L15mt', 'MRP-L15', 'MRP-L7', 'RPML7'], description='mitochondrial ribosomal protein L15', other_designations='39S ribosomal protein L15, mitochondrial|mitochondrial large ribosomal subunit protein uL15m', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=54135224, end_position_on_the_genomic_accession=54148514, orientation='plus', exon_count=6, OMIM=[611828], no_hdr0=''),
    29089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29089, CurrentID=0, Status='live', Symbol='UBE2T', Aliases=['FANCT', 'HSPC150', 'PIG50'], description='ubiquitin conjugating enzyme E2 T', other_designations='ubiquitin-conjugating enzyme E2 T|E2 ubiquitin-conjugating enzyme T|HSPC150 protein similar to ubiquitin-conjugating enzyme|cell proliferation-inducing gene 50 protein|ubiquitin carrier protein T|ubiquitin conjugating enzyme E2T|ubiquitin-conjugating enzyme E2T (putative)|ubiquitin-protein ligase T', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202331657, end_position_on_the_genomic_accession=202341936, orientation='minus', exon_count=7, OMIM=[610538], no_hdr0=''),
    29090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29090, CurrentID=0, Status='live', Symbol='TIMM21', Aliases=['C18orf55', 'HSPC154', 'TIM21'], description='translocase of inner mitochondrial membrane 21', other_designations='mitochondrial import inner membrane translocase subunit Tim21|TIM21-like protein, mitochondrial|translocase of inner mitochondrial membrane 21 homolog', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74148517, end_position_on_the_genomic_accession=74160531, orientation='plus', exon_count=6, OMIM=[615180], no_hdr0=''),
    29091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29091, CurrentID=0, Status='live', Symbol='STXBP6', Aliases=['HSPC156', 'amisyn'], description='syntaxin binding protein 6', other_designations='syntaxin-binding protein 6', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24809454, end_position_on_the_genomic_accession=25050147, orientation='minus', exon_count=18, OMIM=[607958], no_hdr0=''),
    29093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29093, CurrentID=0, Status='live', Symbol='MRPL22', Aliases=['HSPC158', 'L22mt', 'MRP-L22', 'MRP-L25', 'RPML25'], description='mitochondrial ribosomal protein L22', other_designations='39S ribosomal protein L22, mitochondrial|39S ribosomal protein L25, mitochondrial|L25mt|mitochondrial large ribosomal subunit protein uL22m', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154941073, end_position_on_the_genomic_accession=154969411, orientation='plus', exon_count=7, OMIM=[611835], no_hdr0=''),
    29094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29094, CurrentID=0, Status='live', Symbol='LGALSL', Aliases=['GRP', 'HSPC159'], description='galectin like', other_designations='galectin-related protein|galectin-like protein|lectin galactoside-binding-like protein|lectin, galactoside binding like', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=64454162, end_position_on_the_genomic_accession=64461381, orientation='plus', exon_count=5, OMIM=[617902], no_hdr0=''),
    29095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29095, CurrentID=0, Status='live', Symbol='ORMDL2', Aliases=['HSPC160', 'MST095', 'MSTP095', 'adoplin-2'], description='ORMDL sphingolipid biosynthesis regulator 2', other_designations='ORM1-like protein 2|expressed in normal aorta', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55818041, end_position_on_the_genomic_accession=55821879, orientation='plus', exon_count=4, OMIM=[610074], no_hdr0=''),
    29097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29097, CurrentID=0, Status='live', Symbol='CNIH4', Aliases=['CNIH-4', 'CNIH2', 'HSPC163'], description='cornichon family AMPA receptor auxiliary protein 4', other_designations='protein cornichon homolog 4|cornichon homolog 4', map_location='1q42.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224356879, end_position_on_the_genomic_accession=224379452, orientation='plus', exon_count=6, OMIM=[617483], no_hdr0=''),
    29098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29098, CurrentID=0, Status='live', Symbol='RANGRF', Aliases=['HSPC165', 'HSPC236', 'MOG1', 'RANGNRF'], description='RAN guanine nucleotide release factor', other_designations='ran guanine nucleotide release factor|MOG1 homolog|ran-binding protein MOG1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8288670, end_position_on_the_genomic_accession=8290087, orientation='plus', exon_count=3, OMIM=[607954], no_hdr0=''),
    29099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29099, CurrentID=0, Status='live', Symbol='COMMD9', Aliases=['C11orf55', 'HSPC166', 'LINC00610'], description='COMM domain containing 9', other_designations='COMM domain-containing protein 9', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36272292, end_position_on_the_genomic_accession=36289428, orientation='minus', exon_count=7, OMIM=[612299], no_hdr0=''),
    29100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29100, CurrentID=0, Status='live', Symbol='TMEM208', Aliases=['HSPC171', 'hSND2'], description='transmembrane protein 208', other_designations='transmembrane protein 208|SRP-independent targeting 2 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67227130, end_position_on_the_genomic_accession=67229278, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    29101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29101, CurrentID=0, Status='live', Symbol='SSU72', Aliases=['HSPC182', 'PNAS-120'], description='SSU72 homolog, RNA polymerase II CTD phosphatase', other_designations='RNA polymerase II subunit A C-terminal domain phosphatase SSU72|CTD phosphatase SSU72', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1541673, end_position_on_the_genomic_accession=1574863, orientation='minus', exon_count=5, OMIM=[617680], no_hdr0=''),
    29102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29102, CurrentID=0, Status='live', Symbol='DROSHA', Aliases=['ETOHI2', 'HSA242976', 'RANSE3L', 'RN3', 'RNASE3L', 'RNASEN'], description='drosha ribonuclease III', other_designations='ribonuclease 3|RNase III|drosha, double-stranded RNA-specific endoribonuclease|nuclear RNase III Drosha|p241|putative protein p241 which interacts with transcription factor Sp1|putative ribonuclease III|ribonuclease type III, nuclear', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=31400494, end_position_on_the_genomic_accession=31532142, orientation='minus', exon_count=39, OMIM=[608828], no_hdr0=''),
    29103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29103, CurrentID=0, Status='live', Symbol='DNAJC15', Aliases=['DNAJD1', 'HSD18', 'MCJ'], description='DnaJ heat shock protein family (Hsp40) member C15', other_designations='dnaJ homolog subfamily C member 15|DNAJ domain-containing|DnaJ (Hsp40) homolog, subfamily C, member 15|DnaJ (Hsp40) homolog, subfamily D, member 1|cell growth-inhibiting gene 22 protein|methylation-controlled J protein', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=43023586, end_position_on_the_genomic_accession=43114213, orientation='plus', exon_count=6, OMIM=[615339], no_hdr0=''),
    29104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29104, CurrentID=0, Status='live', Symbol='N6AMT1', Aliases=['C21orf127', 'HEMK2', 'KMT9', 'MTQ2', 'N6AMT', 'PRED28', 'PrmC', 'm.HsaHemK2P'], description='N-6 adenine-specific DNA methyltransferase 1', other_designations='methyltransferase N6AMT1|HemK methyltransferase family member 2|N-6 adenine-specific DNA methyltransferase 1 (putative)|N6-DNA-methyltransferase|lysine N-methyltransferase 9|methylarsonite methyltransferase N6AMT1|protein N(5)-glutamine methyltransferase', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=28439661, end_position_on_the_genomic_accession=28885367, orientation='minus', exon_count=13, OMIM=[614553], no_hdr0=''),
    29105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29105, CurrentID=0, Status='live', Symbol='CFAP20', Aliases=['BUG22', 'C16orf80', 'EVORF', 'GTL3', 'fSAP23'], description='cilia and flagella associated protein 20', other_designations='cilia- and flagella-associated protein 20|UPF0468 protein C16orf80|basal body up-regulated protein 22|flagellar associated protein 20 homolog|functional spliceosome-associated protein 23|gene trap locus 3|transcription factor IIB', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58113592, end_position_on_the_genomic_accession=58129381, orientation='minus', exon_count=6, OMIM=[617906], no_hdr0=''),
    29106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29106, CurrentID=0, Status='live', Symbol='SCG3', Aliases=['SGIII'], description='secretogranin III', other_designations='secretogranin-3', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51681503, end_position_on_the_genomic_accession=51721026, orientation='plus', exon_count=12, OMIM=[611796], no_hdr0=''),
    29107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29107, CurrentID=0, Status='live', Symbol='NXT1', Aliases=['MTR2', 'P15'], description='nuclear transport factor 2 like export factor 1', other_designations='NTF2-related export protein 1|NTF2-like export factor 1|NTX2-like export factor1|NUTF-like export factor 1|protein p15', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23350791, end_position_on_the_genomic_accession=23354771, orientation='plus', exon_count=2, OMIM=[605811], no_hdr0=''),
    29108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29108, CurrentID=0, Status='live', Symbol='PYCARD', Aliases=['ASC', 'CARD5', 'TMS', 'TMS-1', 'TMS1'], description='PYD and CARD domain containing', other_designations='apoptosis-associated speck-like protein containing a CARD|caspase recruitment domain-containing protein 5|target of methylation-induced silencing 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31201486, end_position_on_the_genomic_accession=31202760, orientation='minus', exon_count=3, OMIM=[606838], no_hdr0=''),
    29109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29109, CurrentID=0, Status='live', Symbol='FHOD1', Aliases=['FHOS'], description='formin homology 2 domain containing 1', other_designations='FH1/FH2 domain-containing protein 1|formin homolog overexpressed in spleen 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67229389, end_position_on_the_genomic_accession=67247481, orientation='minus', exon_count=26, OMIM=[606881], no_hdr0=''),
    29110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29110, CurrentID=0, Status='live', Symbol='TBK1', Aliases=['FTDALS4', 'IIAE8', 'NAK', 'T2K'], description='TANK binding kinase 1', other_designations='serine/threonine-protein kinase TBK1|NF-kB-activating kinase|NF-kappa-B-activating kinase', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64452105, end_position_on_the_genomic_accession=64502114, orientation='plus', exon_count=24, OMIM=[604834], no_hdr0=''),
    29113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29113, CurrentID=0, Status='live', Symbol='C6orf15', Aliases=['STG'], description='chromosome 6 open reading frame 15', other_designations='uncharacterized protein C6orf15|simian taste bud-specific|taste bud-specific protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31111223, end_position_on_the_genomic_accession=31112575, orientation='minus', exon_count=2, OMIM=[611401], no_hdr0=''),
    29114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29114, CurrentID=0, Status='live', Symbol='TAGLN3', Aliases=['NP22', 'NP24', 'NP25'], description='transgelin 3', other_designations='transgelin-3|neuronal protein 22|neuronal protein NP25', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111998922, end_position_on_the_genomic_accession=112013885, orientation='plus', exon_count=5, OMIM=[607953], no_hdr0=''),
    29115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29115, CurrentID=0, Status='live', Symbol='SAP30BP', Aliases=['HCNGP', 'HTRG', 'HTRP'], description='SAP30 binding protein', other_designations='SAP30-binding protein|HSV-1 binding|transcriptional regulator protein HCNGP', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75667311, end_position_on_the_genomic_accession=75708059, orientation='plus', exon_count=14, OMIM=[610218], no_hdr0=''),
    29116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29116, CurrentID=0, Status='live', Symbol='MYLIP', Aliases=['IDOL', 'MIR'], description='myosin regulatory light chain interacting protein', other_designations='E3 ubiquitin-protein ligase MYLIP|E3 ubiquitin ligase-inducible degrader of the low density lipoprotein receptor|RING-type E3 ubiquitin transferase MYLIP|band 4.1 superfamily member BZF1|cellular modulator of immune recognition (c-MIR)|inducible degrader of the LDL-receptor', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=16129086, end_position_on_the_genomic_accession=16151015, orientation='plus', exon_count=8, OMIM=[610082], no_hdr0=''),
    29117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29117, CurrentID=0, Status='live', Symbol='BRD7', Aliases=['BP75', 'CELTIX1', 'NAG4'], description='bromodomain containing 7', other_designations='bromodomain-containing protein 7|75 kDa bromodomain protein|protein CELTIX-1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50315957, end_position_on_the_genomic_accession=50368988, orientation='minus', exon_count=18, OMIM=[618489], no_hdr0=''),
    29118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29118, CurrentID=0, Status='live', Symbol='DDX25', Aliases=['GRTH'], description='DEAD-box helicase 25', other_designations='ATP-dependent RNA helicase DDX25|DEAD (Asp-Glu-Ala-Asp) box helicase 25|DEAD (Asp-Glu-Ala-Asp) box polypeptide 25|DEAD box protein 25|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 25|epididymis secretory sperm binding protein|gonadotropin-regulated testicular RNA helicase', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125903328, end_position_on_the_genomic_accession=125928843, orientation='plus', exon_count=14, OMIM=[607663], no_hdr0=''),
    29119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29119, CurrentID=0, Status='live', Symbol='CTNNA3', Aliases=['ARVD13', 'VR22'], description='catenin alpha 3', other_designations='catenin alpha-3|alpha-T-catenin|alpha-catenin-like protein|catenin (cadherin-associated protein), alpha 3', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=65912523, end_position_on_the_genomic_accession=67696217, orientation='minus', exon_count=27, OMIM=[607667], no_hdr0=''),
    29121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29121, CurrentID=0, Status='live', Symbol='CLEC2D', Aliases=['CLAX', 'LLT1', 'OCIL'], description='C-type lectin domain family 2 member D', other_designations='C-type lectin domain family 2 member D|C-type lectin related f|C-type lectin superfamily 2, member D|LLT-1|lectin-like NK cell receptor|lectin-like transcript 1|osteoclast inhibitory lectin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9669713, end_position_on_the_genomic_accession=9699553, orientation='plus', exon_count=6, OMIM=[605659], no_hdr0=''),
    29122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29122, CurrentID=0, Status='live', Symbol='PRSS50', Aliases=['CT20', 'TSP50'], description='serine protease 50', other_designations='probable threonine protease PRSS50|cancer/testis antigen 20|protease, serine 50|testes-specific protease 50|testicular tissue protein Li 210|testis-specific protease-like protein 50', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46712117, end_position_on_the_genomic_accession=46717869, orientation='minus', exon_count=6, OMIM=[607950], no_hdr0=''),
    29123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29123, CurrentID=0, Status='live', Symbol='ANKRD11', Aliases=['ANCO-1', 'ANCO1', 'LZ16', 'T13'], description='ankyrin repeat domain 11', other_designations='ankyrin repeat domain-containing protein 11|ankyrin repeat-containing cofactor 1|nasopharyngeal carcinoma susceptibility protein|truncated ankyrin repeat domain 11 aberrant transcript 1|truncated ankyrin repeat domain 11 aberrant transcript 2', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89267619, end_position_on_the_genomic_accession=89490561, orientation='minus', exon_count=21, OMIM=[611192], no_hdr0=''),
    29124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29124, CurrentID=0, Status='live', Symbol='LGALS13', Aliases=['GAL13', 'PLAC8', 'PP13'], description='galectin 13', other_designations='galactoside-binding soluble lectin 13|beta-galactoside-binding lectin|gal-13|lectin, galactoside-binding, soluble, 13|placental protein 13|placental tissue protein 13', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39602411, end_position_on_the_genomic_accession=39607474, orientation='plus', exon_count=4, OMIM=[608717], no_hdr0=''),
    29125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29125, CurrentID=0, Status='live', Symbol='C11orf21', Aliases=[], description='chromosome 11 open reading frame 21', other_designations='uncharacterized protein C11orf21', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2295628, end_position_on_the_genomic_accession=2303140, orientation='minus', exon_count=6, OMIM=[611033], no_hdr0=''),
    29126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29126, CurrentID=0, Status='live', Symbol='CD274', Aliases=['B7-H', 'B7H1', 'PD-L1', 'PDCD1L1', 'PDCD1LG1', 'PDL1', 'hPD-L1'], description='CD274 molecule', other_designations='programmed cell death 1 ligand 1|B7 homolog 1|CD274 antigen|PDCD1 ligand 1', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5450542, end_position_on_the_genomic_accession=5470554, orientation='plus', exon_count=7, OMIM=[605402], no_hdr0=''),
    29127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29127, CurrentID=0, Status='live', Symbol='RACGAP1', Aliases=['CYK4', 'HsCYK-4', 'ID-GAP', 'MgcRacGAP'], description='Rac GTPase activating protein 1', other_designations='rac GTPase-activating protein 1|male germ cell RacGap|protein CYK4 homolog', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49989162, end_position_on_the_genomic_accession=50033206, orientation='minus', exon_count=24, OMIM=[604980], no_hdr0=''),
    29128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29128, CurrentID=0, Status='live', Symbol='UHRF1', Aliases=['ICBP90', 'Np95', 'RNF106', 'TDRD22', 'hNP95', 'hUHRF1', 'huNp95'], description='ubiquitin like with PHD and ring finger domains 1', other_designations='E3 ubiquitin-protein ligase UHRF1|RING finger protein 106|RING-type E3 ubiquitin transferase UHRF1|inverted CCAAT box-binding protein of 90 kDa|nuclear phosphoprotein 95|nuclear protein 95|nuclear zinc finger protein Np95|transcription factor ICBP90|ubiquitin-like PHD and RING finger domain-containing protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4903080, end_position_on_the_genomic_accession=4962154, orientation='plus', exon_count=20, OMIM=[607990], no_hdr0=''),
    29760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29760, CurrentID=0, Status='live', Symbol='BLNK', Aliases=['AGM4', 'BASH-S', 'LY57', 'SLP-65', 'SLP65', 'bca', 'BLNK'], description='B cell linker', other_designations='B-cell linker protein|B cell adaptor containing SH2 domain|B-cell activation|B-cell adapter containing a SH2 domain protein|B-cell adapter containing a Src homology 2 domain protein|Src homology 2 domain-containing leukocyte protein of 65 kDa|Src homology [SH2] domain-containing leukocyte protein of 65 kD|cytoplasmic adapter protein', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96189171, end_position_on_the_genomic_accession=96271569, orientation='minus', exon_count=17, OMIM=[604515], no_hdr0=''),
    29761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29761, CurrentID=0, Status='live', Symbol='USP25', Aliases=['USP21'], description='ubiquitin specific peptidase 25', other_designations='ubiquitin carboxyl-terminal hydrolase 25|USP on chromosome 21|deubiquitinating enzyme 25|ubiquitin thioesterase 25|ubiquitin thiolesterase 25|ubiquitin-specific processing protease 25', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=15729947, end_position_on_the_genomic_accession=15880064, orientation='plus', exon_count=31, OMIM=[604736], no_hdr0=''),
    29763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29763, CurrentID=0, Status='live', Symbol='PACSIN3', Aliases=['SDPIII'], description='protein kinase C and casein kinase substrate in neurons 3', other_designations='protein kinase C and casein kinase substrate in neurons protein 3|SH3 domain-containing protein 6511|syndapin III', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47177521, end_position_on_the_genomic_accession=47186446, orientation='minus', exon_count=12, OMIM=[606513], no_hdr0=''),
    29765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29765, CurrentID=0, Status='live', Symbol='TMOD4', Aliases=['SK-TMOD'], description='tropomodulin 4', other_designations='tropomodulin-4|actin-capping protein|skeletal muscle tropomodulin|skeletal tropomodulin|tropomodulin 4 (muscle)', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151169986, end_position_on_the_genomic_accession=151175981, orientation='minus', exon_count=10, OMIM=[605834], no_hdr0=''),
    29766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29766, CurrentID=0, Status='live', Symbol='TMOD3', Aliases=['UTMOD'], description='tropomodulin 3', other_designations='tropomodulin-3|tropomodulin 3 (ubiquitous)|ubiquitous tropomodulin', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51829653, end_position_on_the_genomic_accession=51915725, orientation='plus', exon_count=12, OMIM=[605112], no_hdr0=''),
    29767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29767, CurrentID=0, Status='live', Symbol='TMOD2', Aliases=['N-TMOD', 'NTMOD'], description='tropomodulin 2', other_designations='tropomodulin-2|neuronal tropomodulin|tropomodulin 2 (neuronal)', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51751561, end_position_on_the_genomic_accession=51816363, orientation='plus', exon_count=10, OMIM=[602928], no_hdr0=''),
    29775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29775, CurrentID=0, Status='live', Symbol='CARD10', Aliases=['BIMP1', 'CARMA3'], description='caspase recruitment domain family member 10', other_designations='caspase recruitment domain-containing protein 10|Bcl10 binding protein and activator of NFKB|CARD-containing MAGUK 3 protein|CARD-containing MAGUK protein 3|carma 3', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37490362, end_position_on_the_genomic_accession=37519415, orientation='minus', exon_count=20, OMIM=[607209], no_hdr0=''),
    29777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29777, CurrentID=0, Status='live', Symbol='ABT1', Aliases=['Esf2', 'hABT1'], description='activator of basal transcription 1', other_designations='activator of basal transcription 1|TATA-binding protein-binding protein|basal transcriptional activator', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26596953, end_position_on_the_genomic_accession=26600739, orientation='plus', exon_count=3, OMIM=[618750], no_hdr0=''),
    29780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29780, CurrentID=0, Status='live', Symbol='PARVB', Aliases=['CGI-56'], description='parvin beta', other_designations='beta-parvin|affixin', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43999164, end_position_on_the_genomic_accession=44172939, orientation='plus', exon_count=19, OMIM=[608121], no_hdr0=''),
    29781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29781, CurrentID=0, Status='live', Symbol='NCAPH2', Aliases=['CAPH2'], description='non-SMC condensin II complex subunit H2', other_designations='condensin-2 complex subunit H2|CAP-H2 subunit of the condensin II complex|CTA-384D8.36|chromosome-associated protein H2|kleisin beta', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50508218, end_position_on_the_genomic_accession=50524780, orientation='plus', exon_count=21, OMIM=[611230], no_hdr0=''),
    29785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29785, CurrentID=0, Status='live', Symbol='CYP2S1', Aliases=['CYPIIS1'], description='cytochrome P450 family 2 subfamily S member 1', other_designations='cytochrome P450 2S1|cytochrome P450, family 2, subfamily S, polypeptide 1|cytochrome P540, subfamily IIS, polypeptide 1|hydroperoxy icosatetraenoate dehydratase|thromboxane-A synthase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41193219, end_position_on_the_genomic_accession=41207539, orientation='plus', exon_count=9, OMIM=[611529], no_hdr0=''),
    29789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29789, CurrentID=0, Status='live', Symbol='OLA1', Aliases=['DOC45', 'GBP45', 'GTBP9', 'GTPBP9', 'PTD004'], description='Obg like ATPase 1', other_designations='obg-like ATPase 1|DNA damage-regulated overexpressed in cancer 45 protein|GTP-binding protein 9 (putative)|GTP-binding protein PTD004|homologous yeast-44.2 protein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174072447, end_position_on_the_genomic_accession=174248532, orientation='minus', exon_count=11, OMIM=[611175], no_hdr0=''),
    29796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29796, CurrentID=0, Status='live', Symbol='UQCR10', Aliases=['HSPC051', 'HSPC119', 'HSPC151', 'QCR9', 'UCCR7.2', 'UCRC'], description='ubiquinol-cytochrome c reductase, complex III subunit X', other_designations='cytochrome b-c1 complex subunit 9|cytochrome C1, nonheme 7kDa protein|cytochrome c1 non-heme 7 kDa protein|ubiquinol-cytochrome c reductase complex (7.2 kD)|ubiquinol-cytochrome c reductase complex 7.2 kDa protein|ubiquinol-cytochrome c reductase, complex III subunit X, 7.2kDa', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29767369, end_position_on_the_genomic_accession=29770413, orientation='plus', exon_count=2, OMIM=[610843], no_hdr0=''),
    29799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29799, CurrentID=0, Status='live', Symbol='YPEL1', Aliases=['FKSG3'], description='yippee like 1', other_designations='protein yippee-like 1|DiGeorge syndrome-related protein', map_location='22q11.21-q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21697536, end_position_on_the_genomic_accession=21735794, orientation='minus', exon_count=5, OMIM=[608082], no_hdr0=''),
    29800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29800, CurrentID=0, Status='live', Symbol='ZDHHC1', Aliases=['C16orf1', 'DHHC-1', 'HSU90653', 'ZNF377'], description='zinc finger DHHC-type containing 1', other_designations='palmitoyltransferase ZDHHC1|DHHC domain-containing cysteine-rich protein 1|probable palmitoyltransferase ZDHHC1|zinc finger DHHC domain-containing protein 1|zinc finger protein 377|zinc finger, DHHC domain containing 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67394152, end_position_on_the_genomic_accession=67416494, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    29801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29801, CurrentID=0, Status='live', Symbol='ZDHHC8', Aliases=['DHHC8', 'ZDHHCL1', 'ZNF378'], description='zinc finger DHHC-type palmitoyltransferase 8', other_designations='palmitoyltransferase ZDHHC8|membrane-associated DHHC8 zinc finger protein|zinc finger DHHC-type containing 8|zinc finger protein 378|zinc finger, DHHC domain like containing 1', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20131804, end_position_on_the_genomic_accession=20148007, orientation='plus', exon_count=11, OMIM=[608784], no_hdr0=''),
    29802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29802, CurrentID=0, Status='live', Symbol='VPREB3', Aliases=['8HS20', 'N27C7-2'], description='V-set pre-B cell surrogate light chain 3', other_designations='pre-B lymphocyte protein 3|pre-B lymphocyte 3|pre-B lymphocyte gene 3', map_location='22q11', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23752743, end_position_on_the_genomic_accession=23754425, orientation='minus', exon_count=2, OMIM=[605017], no_hdr0=''),
    29803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29803, CurrentID=0, Status='live', Symbol='REPIN1', Aliases=['AP4', 'RIP60', 'ZNF464', 'Zfp464'], description='replication initiator 1', other_designations='replication initiator 1|60 kDa origin-specific DNA-binding protein|60 kDa replication initiation region protein|ATT-binding protein|DHFR oribeta-binding protein RIP60|H_DJ0584D14.12|replication initiation region protein (60kD)|zinc finger protein 464 (RIP60)|zinc finger protein AP4', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150368096, end_position_on_the_genomic_accession=150374043, orientation='plus', exon_count=5, OMIM=[619039], no_hdr0=''),
    29841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29841, CurrentID=0, Status='live', Symbol='GRHL1', Aliases=['LBP32', 'MGR', 'NH32', 'TFCP2L2'], description='grainyhead like transcription factor 1', other_designations='grainyhead-like protein 1 homolog|LBP protein 32|grainyhead-like 1|mammalian grainyhead|transcription factor CP2-like 2|transcription factor LBP-32', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9951693, end_position_on_the_genomic_accession=10002279, orientation='plus', exon_count=17, OMIM=[609786], no_hdr0=''),
    29842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29842, CurrentID=0, Status='live', Symbol='TFCP2L1', Aliases=['CRTR1', 'LBP-9', 'LBP9'], description='transcription factor CP2 like 1', other_designations='transcription factor CP2-like protein 1|CP2-related transcriptional repressor 1|CRTR-1|transcription factor LBP-9', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=121216587, end_position_on_the_genomic_accession=121285210, orientation='minus', exon_count=17, OMIM=[609785], no_hdr0=''),
    29843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29843, CurrentID=0, Status='live', Symbol='SENP1', Aliases=['SuPr-2'], description='SUMO specific peptidase 1', other_designations='sentrin-specific protease 1|SUMO1/sentrin specific peptidase 1|SUMO1/sentrin specific protease 1|sentrin/SUMO-specific protease SENP1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48042893, end_position_on_the_genomic_accession=48106308, orientation='minus', exon_count=21, OMIM=[612157], no_hdr0=''),
    29844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29844, CurrentID=0, Status='live', Symbol='TFPT', Aliases=['FB1', 'INO80F', 'amida'], description='TCF3 fusion partner', other_designations='TCF3 fusion partner|INO80 complex subunit F|TCF3 (E2A) fusion partner (in childhood Leukemia)|amida, partner of the E2A', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54107020, end_position_on_the_genomic_accession=54115657, orientation='minus', exon_count=7, OMIM=[609519], no_hdr0=''),
    29850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29850, CurrentID=0, Status='live', Symbol='TRPM5', Aliases=['LTRPC5', 'MTR1'], description='transient receptor potential cation channel subfamily M member 5', other_designations='transient receptor potential cation channel subfamily M member 5|MLSN1 and TRP-related|MLSN1- and TRP-related gene 1 protein|long transient receptor potential channel 5', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2403962, end_position_on_the_genomic_accession=2423424, orientation='minus', exon_count=25, OMIM=[604600], no_hdr0=''),
    29851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29851, CurrentID=0, Status='live', Symbol='ICOS', Aliases=['AILIM', 'CD278', 'CVID1'], description='inducible T cell costimulator', other_designations='inducible T-cell costimulator|activation-inducible lymphocyte immunomediatory molecule|inducible T-cell co-stimulator|inducible costimulator', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203936763, end_position_on_the_genomic_accession=203961577, orientation='plus', exon_count=5, OMIM=[604558], no_hdr0=''),
    29855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29855, CurrentID=0, Status='live', Symbol='UBN1', Aliases=['VT', 'VT4'], description='ubinuclein 1', other_designations='ubinuclein-1|HIRA-binding protein|ubiquitously expressed nuclear protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4846665, end_position_on_the_genomic_accession=4882401, orientation='plus', exon_count=20, OMIM=[609771], no_hdr0=''),
    29880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29880, CurrentID=0, Status='live', Symbol='ALG5', Aliases=['bA421P11.2'], description='ALG5 dolichyl-phosphate beta-glucosyltransferase', other_designations='dolichyl-phosphate beta-glucosyltransferase|Alg5, S. cerevisiae, homolog of|asparagine-linked glycosylation 5 homolog (S. cerevisiae, dolichyl-phosphate beta-glucosyltransferase)|asparagine-linked glycosylation 5 homolog (yeast, dolichyl-phosphate beta-glucosyltransferase)|asparagine-linked glycosylation 5, dolichyl-phosphate beta-glucosyltransferase homolog|asparagine-linked glycosylation protein 5 homolog|dolP-glucosyltransferase|dolichyl phosphate glucosyltransferase', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36949738, end_position_on_the_genomic_accession=36999367, orientation='minus', exon_count=11, OMIM=[604565], no_hdr0=''),
    29881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29881, CurrentID=0, Status='live', Symbol='NPC1L1', Aliases=['LDLCQ7', 'NPC11L1', 'SLC65A2'], description='NPC1 like intracellular cholesterol transporter 1', other_designations='NPC1-like intracellular cholesterol transporter 1|NPC1 (Niemann-Pick disease, type C1, gene)-like 1|NPC1 like 1|niemann-Pick C1-like protein 1', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44512440, end_position_on_the_genomic_accession=44541651, orientation='minus', exon_count=20, OMIM=[608010], no_hdr0=''),
    29882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29882, CurrentID=0, Status='live', Symbol='ANAPC2', Aliases=['APC2'], description='anaphase promoting complex subunit 2', other_designations='anaphase-promoting complex subunit 2|cyclosome subunit 2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137174784, end_position_on_the_genomic_accession=137188585, orientation='minus', exon_count=14, OMIM=[606946], no_hdr0=''),
    29883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29883, CurrentID=0, Status='live', Symbol='CNOT7', Aliases=['CAF-1', 'CAF1', 'Caf1a', 'hCAF-1'], description='CCR4-NOT transcription complex subunit 7', other_designations='CCR4-NOT transcription complex subunit 7|BTG1-binding factor 1|CCR4-associated factor 1|carbon catabolite repressor protein (CCR4)-associative factor 1', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17221981, end_position_on_the_genomic_accession=17246857, orientation='minus', exon_count=12, OMIM=[604913], no_hdr0=''),
    29886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29886, CurrentID=0, Status='live', Symbol='SNX8', Aliases=['Mvp1'], description='sorting nexin 8', other_designations='sorting nexin-8', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2251770, end_position_on_the_genomic_accession=2354477, orientation='minus', exon_count=15, OMIM=[614905], no_hdr0=''),
    29887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29887, CurrentID=0, Status='live', Symbol='SNX10', Aliases=['OPTB8'], description='sorting nexin 10', other_designations='sorting nexin-10', map_location='7p15.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=26291862, end_position_on_the_genomic_accession=26374383, orientation='plus', exon_count=12, OMIM=[614780], no_hdr0=''),
    29888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29888, CurrentID=0, Status='live', Symbol='STRN4', Aliases=['PPP2R6C', 'ZIN', 'zinedin'], description='striatin 4', other_designations="striatin-4|protein phosphatase 2 regulatory subunit B'''gamma|striatin, calmodulin binding protein 4", map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46719509, end_position_on_the_genomic_accession=46746475, orientation='minus', exon_count=23, OMIM=[614767], no_hdr0=''),
    29889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29889, CurrentID=0, Status='live', Symbol='GNL2', Aliases=['HUMAUANTIG', 'NGP1', 'Ngp-1', 'Nog2', 'Nug2'], description='G protein nucleolar 2', other_designations="nucleolar GTP-binding protein 2|autoantigen NGP-1|guanine nucleotide binding protein-like 2 (nucleolar)|novel nucleolar guanosine 5'-triphosphate binding protein autoantigen|nucleolar G-protein gene 1|nucleolar GTPase|nucleostemin-2", map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37566816, end_position_on_the_genomic_accession=37595937, orientation='minus', exon_count=18, OMIM=[609365], no_hdr0=''),
    29890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29890, CurrentID=0, Status='live', Symbol='RBM15B', Aliases=['HUMAGCGB', 'HsOTT3', 'OTT3'], description='RNA binding motif protein 15B', other_designations='putative RNA-binding protein 15B|chromosome 3p21.1 gene sequence|huOTT3|one twenty two protein 3', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51391285, end_position_on_the_genomic_accession=51397908, orientation='plus', exon_count=1, OMIM=[612602], no_hdr0=''),
    29893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29893, CurrentID=0, Status='live', Symbol='PSMC3IP', Aliases=['GT198', 'HOP2', 'HUMGT198A', 'ODG3', 'TBPIP'], description='PSMC3 interacting protein', other_designations='homologous-pairing protein 2 homolog|DBD-interacting|TBP-1-interacting protein|nuclear receptor coactivator GT198|proteasome 26S ATPase subunit 3-interacting protein|tat-binding protein 1-interacting protein', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42572310, end_position_on_the_genomic_accession=42577831, orientation='minus', exon_count=9, OMIM=[608665], no_hdr0=''),
    29894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29894, CurrentID=0, Status='live', Symbol='CPSF1', Aliases=['CPSF160', 'HSU37012', 'MYP27', 'P/cl.18'], description='cleavage and polyadenylation specific factor 1', other_designations='cleavage and polyadenylation specificity factor subunit 1|CPSF 160 kDa subunit|cleavage and polyadenylation specific factor 1, 160kDa|cleavage and polyadenylation specificity factor 160 kDa subunit|polyadenylation specificity factor', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144393231, end_position_on_the_genomic_accession=144409400, orientation='minus', exon_count=39, OMIM=[606027], no_hdr0=''),
    29895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29895, CurrentID=0, Status='live', Symbol='MYLPF', Aliases=['DA1C', 'HUMMLC2B', 'MLC2B', 'MRLC2', 'MYL11'], description='myosin light chain, phosphorylatable, fast skeletal muscle', other_designations='myosin regulatory light chain 2, skeletal muscle isoform|fast skeletal myosin light chain 2|myosin light chain 2|myosin, light chain 11, regulatory', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30370934, end_position_on_the_genomic_accession=30377991, orientation='plus', exon_count=10, OMIM=[617378], no_hdr0=''),
    29896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29896, CurrentID=0, Status='live', Symbol='TRA2A', Aliases=['AWMS1', 'HSU53209'], description='transformer 2 alpha homolog', other_designations='transformer-2 protein homolog alpha|TRA-2 alpha|TRA2-alpha|Tra2alpha|htra-2 alpha|putative MAPK activating protein PM24|transformer-2 alpha|transformer-2 protein homolog A', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23504780, end_position_on_the_genomic_accession=23531981, orientation='minus', exon_count=10, OMIM=[602718], no_hdr0=''),
    29899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29899, CurrentID=0, Status='live', Symbol='GPSM2', Aliases=['CMCS', 'DFNB82', 'LGN', 'PINS'], description='G protein signaling modulator 2', other_designations='G-protein-signaling modulator 2|G-protein signalling modulator 2 (AGS3-like, C. elegans)|mosaic protein LGN', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108875350, end_position_on_the_genomic_accession=108934545, orientation='plus', exon_count=19, OMIM=[609245], no_hdr0=''),
    29901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29901, CurrentID=0, Status='live', Symbol='SAC3D1', Aliases=['HSU79266', 'SHD1'], description='SAC3 domain containing 1', other_designations='SAC3 domain-containing protein 1|SAC3 homology domain-containing protein 1|Sac3 homology domain 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65040933, end_position_on_the_genomic_accession=65044828, orientation='plus', exon_count=4, OMIM=[618796], no_hdr0=''),
    29902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29902, CurrentID=0, Status='live', Symbol='FAM216A', Aliases=['C12orf24', 'HSU79274'], description='family with sequence similarity 216 member A', other_designations='protein FAM216A|protein predicted by clone 23733|uncharacterized protein C12orf24', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110468413, end_position_on_the_genomic_accession=110490385, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    29903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29903, CurrentID=0, Status='live', Symbol='CCDC106', Aliases=['HSU79303', 'ZNF581'], description='coiled-coil domain containing 106', other_designations='coiled-coil domain-containing protein 106|protein predicted by clone 23882', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55647400, end_position_on_the_genomic_accession=55653161, orientation='plus', exon_count=7, OMIM=[613478], no_hdr0=''),
    29904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29904, CurrentID=0, Status='live', Symbol='EEF2K', Aliases=['CaMKIII', 'HSU93850', 'eEF-2K'], description='eukaryotic elongation factor 2 kinase', other_designations='eukaryotic elongation factor 2 kinase|alternative protein EEF2K|calcium/calmodulin-dependent eukaryotic elongation factor-2 kinase|calmodulin-dependent protein kinase III|eEF-2 kinase|elongation factor-2 kinase|eukaroytic elongation factor 2 kinase', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22206278, end_position_on_the_genomic_accession=22288738, orientation='plus', exon_count=20, OMIM=[606968], no_hdr0=''),
    29906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29906, CurrentID=0, Status='live', Symbol='ST8SIA5', Aliases=['SIAT8-E', 'SIAT8E', 'ST8SiaV'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 5', other_designations='alpha-2,8-sialyltransferase 8E|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 5|sialyltransferase 8E (alpha-2, 8-polysialytransferase)|sialyltransferase St8Sia V', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46667821, end_position_on_the_genomic_accession=46757053, orientation='minus', exon_count=9, OMIM=[607162], no_hdr0=''),
    29907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29907, CurrentID=0, Status='live', Symbol='SNX15', Aliases=['HSAF001435'], description='sorting nexin 15', other_designations='sorting nexin-15|clone iota unknown protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65027439, end_position_on_the_genomic_accession=65040572, orientation='plus', exon_count=8, OMIM=[605964], no_hdr0=''),
    29909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29909, CurrentID=0, Status='live', Symbol='GPR171', Aliases=['H963'], description='G protein-coupled receptor 171', other_designations='probable G-protein coupled receptor 171|F730001G15Rik|G-protein coupled receptor H963|platelet activating receptor homolog', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151197754, end_position_on_the_genomic_accession=151203674, orientation='minus', exon_count=4, OMIM=[618925], no_hdr0=''),
    29911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29911, CurrentID=0, Status='live', Symbol='HOOK2', Aliases=['HK2'], description='hook microtubule tethering protein 2', other_designations='protein Hook homolog 2|h-hook2|hHK2|hook homolog 2', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12763003, end_position_on_the_genomic_accession=12775552, orientation='minus', exon_count=23, OMIM=[607824], no_hdr0=''),
    29914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29914, CurrentID=0, Status='live', Symbol='UBIAD1', Aliases=['SCCD', 'TERE1'], description='UbiA prenyltransferase domain containing 1', other_designations='ubiA prenyltransferase domain-containing protein 1|transitional epithelia response protein|transitional epithelial response protein 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11273198, end_position_on_the_genomic_accession=11299574, orientation='plus', exon_count=4, OMIM=[611632], no_hdr0=''),
    29915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29915, CurrentID=0, Status='live', Symbol='HCFC2', Aliases=['HCF-2', 'HCF2'], description='host cell factor C2', other_designations='host cell factor 2|C2 factor', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104064526, end_position_on_the_genomic_accession=104108954, orientation='plus', exon_count=17, OMIM=[607926], no_hdr0=''),
    29916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29916, CurrentID=0, Status='live', Symbol='SNX11', Aliases=[], description='sorting nexin 11', other_designations='sorting nexin-11', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48107533, end_position_on_the_genomic_accession=48123601, orientation='plus', exon_count=9, OMIM=[614906], no_hdr0=''),
    29919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29919, CurrentID=0, Status='live', Symbol='RMC1', Aliases=['C18orf8', 'HsT2591', 'MIC1', 'Mic-1', 'WDR98'], description='regulator of MON1-CCZ1', other_designations='regulator of MON1-CCZ1 complex|WD repeat domain 98|WD repeat-containing protein 98|colon cancer-associated protein Mic1|macrophage inhibitory cytokine 1|uncharacterized protein C18orf8', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23503470, end_position_on_the_genomic_accession=23531822, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    29920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29920, CurrentID=0, Status='live', Symbol='PYCR2', Aliases=['HLD10', 'P5CR2'], description='pyrroline-5-carboxylate reductase 2', other_designations='pyrroline-5-carboxylate reductase 2|P5C reductase 2|pyrroline-5-carboxylate reductase family member 2', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225919878, end_position_on_the_genomic_accession=225924250, orientation='minus', exon_count=7, OMIM=[616406], no_hdr0=''),
    29922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29922, CurrentID=0, Status='live', Symbol='NME7', Aliases=['CFAP67', 'MN23H7', 'NDK 7', 'NDK7', 'nm23-H7'], description='NME/NM23 family member 7', other_designations='nucleoside diphosphate kinase 7|NDP kinase 7|cilia and flagella associated protein 67|non-metastatic cells 7, protein expressed in (nucleoside-diphosphate kinase)', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169132531, end_position_on_the_genomic_accession=169367797, orientation='minus', exon_count=13, OMIM=[613465], no_hdr0=''),
    29923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29923, CurrentID=0, Status='live', Symbol='HILPDA', Aliases=['C7orf68', 'HIG-2', 'HIG2'], description='hypoxia inducible lipid droplet associated', other_designations='hypoxia-inducible lipid droplet-associated protein|hypoxia inducible gene 2|hypoxia-inducible gene 2 protein|hypoxia-inducible protein 2', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128455878, end_position_on_the_genomic_accession=128458418, orientation='plus', exon_count=2, OMIM=[617905], no_hdr0=''),
    29924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29924, CurrentID=0, Status='live', Symbol='EPN1', Aliases=[], description='epsin 1', other_designations='epsin-1|EH domain-binding mitotic phosphoprotein|EPS-15-interacting protein 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55675226, end_position_on_the_genomic_accession=55709533, orientation='plus', exon_count=13, OMIM=[607262], no_hdr0=''),
    29925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29925, CurrentID=0, Status='live', Symbol='GMPPB', Aliases=['LGMDR19', 'MDDGA14', 'MDDGB14', 'MDDGC14'], description='GDP-mannose pyrophosphorylase B', other_designations='mannose-1-phosphate guanyltransferase beta|GTP-mannose-1-phosphate guanylyltransferase beta', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49719916, end_position_on_the_genomic_accession=49723951, orientation='minus', exon_count=9, OMIM=[615320], no_hdr0=''),
    29926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29926, CurrentID=0, Status='live', Symbol='GMPPA', Aliases=['AAMR'], description='GDP-mannose pyrophosphorylase A', other_designations='mannose-1-phosphate guanyltransferase alpha|GMPP-alpha|GTP-mannose-1-phosphate guanylyltransferase alpha|epididymis secretory sperm binding protein|mannose-1-phosphate guanylyltransferase (GDP)', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219498891, end_position_on_the_genomic_accession=219506989, orientation='plus', exon_count=13, OMIM=[615495], no_hdr0=''),
    29927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29927, CurrentID=0, Status='live', Symbol='SEC61A1', Aliases=['ADTKD5', 'HNFJ4', 'HSEC61', 'SEC61', 'SEC61A'], description='SEC61 translocon subunit alpha 1', other_designations='protein transport protein Sec61 subunit alpha isoform 1|SEC61 translocon alpha 1 subunit|Sec61 alpha 1 subunit|Sec61 alpha-1|protein transport protein SEC61 alpha subunit|protein transport protein Sec61 subunit alpha|sec61 homolog', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128052437, end_position_on_the_genomic_accession=128071683, orientation='plus', exon_count=12, OMIM=[609213], no_hdr0=''),
    29928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29928, CurrentID=0, Status='live', Symbol='TIMM22', Aliases=['COXPD43', 'TEX4', 'TIM22'], description='translocase of inner mitochondrial membrane 22', other_designations='mitochondrial import inner membrane translocase subunit Tim22|testis-expressed protein 4|testis-expressed sequence 4|translocase of inner mitochondrial membrane 22 homolog', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=997129, end_position_on_the_genomic_accession=1003671, orientation='plus', exon_count=4, OMIM=[607251], no_hdr0=''),
    29929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29929, CurrentID=0, Status='live', Symbol='ALG6', Aliases=['CDG1C'], description='ALG6 alpha-1,3-glucosyltransferase', other_designations='dolichyl pyrophosphate Man9GlcNAc2 alpha-1,3-glucosyltransferase|Man(9)GlcNAc(2)-PP-Dol alpha-1,3-glucosyltransferase|asparagine-linked glycosylation 6 homolog (S. cerevisiae, alpha-1,3-glucosyltransferase)|asparagine-linked glycosylation 6 homolog (yeast, alpha-1,3-glucosyltransferase)|asparagine-linked glycosylation 6, alpha-1,3-glucosyltransferase homolog|asparagine-linked glycosylation protein 6 homolog|dol-P-Glc:Man(9)GlcNAc(2)-PP-Dol alpha-1,3-glucosyltransferase|dolichyl-P-Glc:Man(9)GlcNAc(2)-PP-dolichol alpha- 1->3-glucosyltransferase|dolichyl-P-Glc:Man9GlcNAc2-PP-dolichyl glucosyltransferase|dolichyl-P-Glc:Man9GlcNAc2-PP-dolichylglucosyltransferase', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63367627, end_position_on_the_genomic_accession=63438553, orientation='plus', exon_count=15, OMIM=[604566], no_hdr0=''),
    29930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29930, CurrentID=0, Status='live', Symbol='PCDHB1', Aliases=['PCDH-BETA1'], description='protocadherin beta 1', other_designations='protocadherin beta-1|PCDH-beta-1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141051374, end_position_on_the_genomic_accession=141059346, orientation='plus', exon_count=1, OMIM=[606327], no_hdr0=''),
    29933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29933, CurrentID=0, Status='live', Symbol='GPR132', Aliases=['G2A'], description='G protein-coupled receptor 132', other_designations='probable G-protein coupled receptor 132|G2 accumulation protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105049395, end_position_on_the_genomic_accession=105065430, orientation='minus', exon_count=5, OMIM=[606167], no_hdr0=''),
    29934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29934, CurrentID=0, Status='live', Symbol='SNX12', Aliases=[], description='sorting nexin 12', other_designations='sorting nexin-12', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71059247, end_position_on_the_genomic_accession=71073426, orientation='minus', exon_count=5, OMIM=[300883], no_hdr0=''),
    29935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29935, CurrentID=0, Status='live', Symbol='RPA4', Aliases=['HSU24186'], description='replication protein A4', other_designations='replication protein A 30 kDa subunit|RF-A protein 4|RP-A p30|replication factor A protein 4|replication protein A complex 34 kd subunit homolog Rpa4|replication protein A4, 30kDa|replication protein A4, 34kDa', map_location='Xq21.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=96883908, end_position_on_the_genomic_accession=96885467, orientation='plus', exon_count=1, OMIM=[300767], no_hdr0=''),
    29937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29937, CurrentID=0, Status='live', Symbol='NENF', Aliases=['CIR2', 'SCIRP10', 'SPUF'], description='neudesin neurotrophic factor', other_designations='neudesin|SCIRP10-related protein|Spinal cord injury related protein 10|cell growth-inhibiting protein 47|cell immortalization-related protein 2|neuron-derived neurotrophic factor|secreted protein of unknown function', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212432920, end_position_on_the_genomic_accession=212446379, orientation='plus', exon_count=4, OMIM=[611874], no_hdr0=''),
    29940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29940, CurrentID=0, Status='live', Symbol='DSE', Aliases=['DS-epi1P', 'DSEPI', 'EDSMC2', 'SART-2', 'SART2', 'DSE'], description='dermatan sulfate epimerase', other_designations='dermatan-sulfate epimerase|DS epimerase|chondroitin-glucuronate 5-epimerase|squamous cell carcinoma antigen recognized by T-cells 2', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116254171, end_position_on_the_genomic_accession=116444861, orientation='plus', exon_count=15, OMIM=[605942], no_hdr0=''),
    29941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29941, CurrentID=0, Status='live', Symbol='PKN3', Aliases=['UTDP4-1'], description='protein kinase N3', other_designations='serine/threonine-protein kinase N3|protein kinase PKN-beta|protein-kinase C-related kinase 3', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128702497, end_position_on_the_genomic_accession=128720918, orientation='plus', exon_count=23, OMIM=[610714], no_hdr0=''),
    29942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29942, CurrentID=0, Status='live', Symbol='PURG', Aliases=['PURG-A-B', 'PURGA', 'PURGB', 'PURG'], description='purine rich element binding protein G', other_designations='purine-rich element-binding protein gamma|Pur-gamma', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30995802, end_position_on_the_genomic_accession=31033356, orientation='minus', exon_count=3, OMIM=[618041], no_hdr0=''),
    29943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29943, CurrentID=0, Status='live', Symbol='PADI1', Aliases=['HPAD10', 'PAD1', 'PDI', 'PDI1'], description='peptidyl arginine deiminase 1', other_designations='protein-arginine deiminase type-1|hPAD-colony 10|peptidyl arginine deiminase, type I|peptidylarginine deiminase I|protein-arginine deiminase type I', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17205125, end_position_on_the_genomic_accession=17246007, orientation='plus', exon_count=20, OMIM=[607934], no_hdr0=''),
    29944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29944, CurrentID=0, Status='live', Symbol='PNMA3', Aliases=['MA3', 'MA5'], description='PNMA family member 3', other_designations='paraneoplastic antigen Ma3|paraneoplastic Ma antigen 3|paraneoplastic cancer-testis-brain antigen', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153056470, end_position_on_the_genomic_accession=153060462, orientation='plus', exon_count=3, OMIM=[300675], no_hdr0=''),
    29945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29945, CurrentID=0, Status='live', Symbol='ANAPC4', Aliases=['APC4'], description='anaphase promoting complex subunit 4', other_designations='anaphase-promoting complex subunit 4|cyclosome subunit 4', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25377263, end_position_on_the_genomic_accession=25418498, orientation='plus', exon_count=29, OMIM=[606947], no_hdr0=''),
    29946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29946, CurrentID=0, Status='live', Symbol='SERTAD3', Aliases=['RBT1'], description='SERTA domain containing 3', other_designations='SERTA domain-containing protein 3|RPA-binding trans-activator|replication protein-binding trans-activator', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40440843, end_position_on_the_genomic_accession=40444335, orientation='minus', exon_count=4, OMIM=[612125], no_hdr0=''),
    29947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29947, CurrentID=0, Status='live', Symbol='DNMT3L', Aliases=[], description='DNA methyltransferase 3 like', other_designations='DNA (cytosine-5)-methyltransferase 3-like|DNA (cytosine-5-)-methyltransferase 3-like|cytosine-5-methyltransferase 3-like protein|human cytosine-5-methyltransferase 3-like protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44246339, end_position_on_the_genomic_accession=44261897, orientation='minus', exon_count=12, OMIM=[606588], no_hdr0=''),
    29948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29948, CurrentID=0, Status='live', Symbol='OSGIN1', Aliases=['BDGI', 'OKL38'], description='oxidative stress induced growth inhibitor 1', other_designations='oxidative stress-induced growth inhibitor 1|BMSC-derived growth inhibitor|bone marrow stromal cell-derived growth inhibitor|ovary, kidney and liver protein 38|pregnancy-induced growth inhibitor OKL38', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=83953240, end_position_on_the_genomic_accession=83966332, orientation='plus', exon_count=6, OMIM=[607975], no_hdr0=''),
    29949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29949, CurrentID=0, Status='live', Symbol='IL19', Aliases=['IL-10C', 'MDA1', 'NG.1', 'ZMDA1'], description='interleukin 19', other_designations='interleukin-19|melanoma differentiation associated protein-like protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206770773, end_position_on_the_genomic_accession=206842981, orientation='plus', exon_count=9, OMIM=[605687], no_hdr0=''),
    29950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29950, CurrentID=0, Status='live', Symbol='SERTAD1', Aliases=['SEI1', 'TRIP-Br1', 'TRIPBR1'], description='SERTA domain containing 1', other_designations='SERTA domain-containing protein 1|CDK4-binding protein p34SEI|CDK4-binding protein p34SEI1|SEI-1|p34(SEI-1)|transcriptional regulator interacting with the PHD-bromodomain 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40421589, end_position_on_the_genomic_accession=40425992, orientation='minus', exon_count=2, OMIM=[617850], no_hdr0=''),
    29951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29951, CurrentID=0, Status='live', Symbol='PDZRN4', Aliases=['LNX4', 'SAMCAP3L'], description='PDZ domain containing ring finger 4', other_designations='PDZ domain-containing RING finger protein 4|IMAGE5767589|SEMACAP3-like protein|ligand of Numb protein X 4', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=41188320, end_position_on_the_genomic_accession=41574745, orientation='plus', exon_count=11, OMIM=[609730], no_hdr0=''),
    29952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29952, CurrentID=0, Status='live', Symbol='DPP7', Aliases=['DPP2', 'DPPII', 'QPP'], description='dipeptidyl peptidase 7', other_designations='dipeptidyl peptidase 2|DPP II|carboxytripeptidase|dipeptidyl aminopeptidase II|dipeptidyl arylamidase II|dipeptidyl-peptidase II|quiescent cell proline dipeptidase', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137110540, end_position_on_the_genomic_accession=137117980, orientation='minus', exon_count=13, OMIM=[610537], no_hdr0=''),
    29953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29953, CurrentID=0, Status='live', Symbol='TRHDE', Aliases=['PAP-II', 'PGPEP2', 'TRH-DE'], description='thyrotropin releasing hormone degrading enzyme', other_designations='thyrotropin-releasing hormone-degrading ectoenzyme|TRH-degrading ectoenzyme|TRH-specific aminopeptidase|pyroglutamyl aminopeptidase II|pyroglutamyl-peptidase II|thyroliberinase', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=72087288, end_position_on_the_genomic_accession=72670758, orientation='plus', exon_count=24, OMIM=[606950], no_hdr0=''),
    29954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29954, CurrentID=0, Status='live', Symbol='POMT2', Aliases=['LGMD2N', 'LGMDR14', 'MDDGA2', 'MDDGB2', 'MDDGC2'], description='protein O-mannosyltransferase 2', other_designations='protein O-mannosyl-transferase 2|dolichyl-phosphate-mannose--protein mannosyltransferase 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77274956, end_position_on_the_genomic_accession=77320885, orientation='minus', exon_count=21, OMIM=[607439], no_hdr0=''),
    29956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29956, CurrentID=0, Status='live', Symbol='CERS2', Aliases=['L3', 'LASS2', 'SP260', 'TMSG1'], description='ceramide synthase 2', other_designations='ceramide synthase 2|LAG1 homolog, ceramide synthase 2|LAG1 longevity assurance 2|longevity assurance (LAG1, S. cerevisiae) homolog 2|sphingosine N-acyltransferase CERS2|tumor metastasis-suppressor gene 1 protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150965184, end_position_on_the_genomic_accession=150974835, orientation='minus', exon_count=13, OMIM=[606920], no_hdr0=''),
    29957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29957, CurrentID=0, Status='live', Symbol='SLC25A24', Aliases=['APC1', 'SCAMC-1', 'SCAMC1'], description='solute carrier family 25 member 24', other_designations='calcium-binding mitochondrial carrier protein SCaMC-1|calcium-binding transporter|mitochondrial ATP-Mg/Pi carrier protein 1|mitochondrial Ca(2+)-dependent solute carrier protein 1|short calcium-binding mitochondrial carrier 1|small calcium-binding mitochondrial carrier protein 1|solute carrier family 25 (mitochondrial carrier; phosphate carrier), member 24', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108134043, end_position_on_the_genomic_accession=108200343, orientation='minus', exon_count=11, OMIM=[608744], no_hdr0=''),
    29958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29958, CurrentID=0, Status='live', Symbol='DMGDH', Aliases=['DMGDHD', 'ME2GLYDH'], description='dimethylglycine dehydrogenase', other_designations='dimethylglycine dehydrogenase, mitochondrial', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=78997564, end_position_on_the_genomic_accession=79069674, orientation='minus', exon_count=18, OMIM=[605849], no_hdr0=''),
    29959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29959, CurrentID=0, Status='live', Symbol='NRBP1', Aliases=['BCON3', 'MADM', 'MUDPNP', 'NRBP'], description='nuclear receptor binding protein 1', other_designations='nuclear receptor-binding protein|multiple domain putative nuclear protein|myeloid leukemia factor 1 adaptor molecule', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27427790, end_position_on_the_genomic_accession=27442259, orientation='plus', exon_count=20, OMIM=[606010], no_hdr0=''),
    29960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29960, CurrentID=0, Status='live', Symbol='MRM2', Aliases=['FJH1', 'FTSJ2', 'HEL97', 'MTDPS17', 'RRMJ2'], description='mitochondrial rRNA methyltransferase 2', other_designations="rRNA methyltransferase 2, mitochondrial|16S rRNA (uridine(1369)-2'-O)-methyltransferase|16S rRNA [Um1369] 2'-O-methyltransferase|FtsJ RNA methyltransferase homolog 2|FtsJ homolog 2|MRM2 RNA methyltransferase homolog|cell division protein FtsJ|epididymis luminal protein 97|protein ftsJ homolog 2|putative ribosomal RNA methyltransferase 2|rRNA (uridine-2'-O-)-methyltransferase", map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2234195, end_position_on_the_genomic_accession=2242205, orientation='minus', exon_count=3, OMIM=[606906], no_hdr0=''),
    29964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29964, CurrentID=0, Status='live', Symbol='PRICKLE4', Aliases=['C6orf49', 'OBTP', 'OEBT', 'TOMM6'], description='prickle planar cell polarity protein 4', other_designations='prickle-like protein 4|over-expressed breast tumor protein|overexpressed breast tumor protein|overexpressed breast tumour protein|prickle homolog 4|translocase of outer mitochondrial membrane 6 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41780782, end_position_on_the_genomic_accession=41787452, orientation='plus', exon_count=8, OMIM=[611389], no_hdr0=''),
    29965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29965, CurrentID=0, Status='live', Symbol='CDIP1', Aliases=['C16orf5', 'CDIP', 'I1', 'LITAFL'], description='cell death inducing p53 target 1', other_designations='cell death-inducing p53-target protein 1|LITAF-like protein|cell death inducing protein|cell death involved p53-target|lipopolysaccharide-induced tumor necrosis factor-alpha-like protein|transmembrane protein I1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4510669, end_position_on_the_genomic_accession=4538773, orientation='minus', exon_count=7, OMIM=[610503], no_hdr0=''),
    29966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29966, CurrentID=0, Status='live', Symbol='STRN3', Aliases=['PPP2R6B', 'S/G2NA', 'SG2NA'], description='striatin 3', other_designations="striatin-3|cell cycle S/G2 nuclear autoantigen|cell cycle autoantigen SG2NA|nuclear autoantigen|protein phosphatase 2 regulatory subunit B'''beta|s/G2 antigen|striatin, calmodulin binding protein 3", map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=30893804, end_position_on_the_genomic_accession=31026401, orientation='minus', exon_count=18, OMIM=[614766], no_hdr0=''),
    29967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29967, CurrentID=0, Status='live', Symbol='LRP12', Aliases=['MIG13A', 'ST7'], description='LDL receptor related protein 12', other_designations='low-density lipoprotein receptor-related protein 12|LDLR-related protein 12|suppressor of tumorigenicity 7 protein', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=104489236, end_position_on_the_genomic_accession=104589258, orientation='minus', exon_count=7, OMIM=[618299], no_hdr0=''),
    29968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29968, CurrentID=0, Status='live', Symbol='PSAT1', Aliases=['EPIP', 'NLS2', 'PSA', 'PSAT', 'PSATD'], description='phosphoserine aminotransferase 1', other_designations='phosphoserine aminotransferase|endometrial progesterone-induced protein|phosphohydroxythreonine aminotransferase|phosphoserine transaminase', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=78297125, end_position_on_the_genomic_accession=78330093, orientation='plus', exon_count=9, OMIM=[610936], no_hdr0=''),
    29969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29969, CurrentID=0, Status='live', Symbol='MDFIC', Aliases=['HIC1', 'MDFIC'], description='MyoD family inhibitor domain containing', other_designations='myoD family inhibitor domain-containing protein|I-mfa domain-containing protein', map_location='7q31.1-q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=114922094, end_position_on_the_genomic_accession=115019917, orientation='plus', exon_count=6, OMIM=[614511], no_hdr0=''),
    29970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29970, CurrentID=0, Status='live', Symbol='SCHIP1', Aliases=['SCHIP-1'], description='schwannomin interacting protein 1', other_designations='schwannomin-interacting protein 1', map_location='3q25.32-q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=159273244, end_position_on_the_genomic_accession=159897359, orientation='plus', exon_count=14, OMIM=[619206], no_hdr0=''),
    29974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29974, CurrentID=0, Status='live', Symbol='A1CF', Aliases=['ACF', 'ACF64', 'ACF65', 'APOBEC1CF', 'ASP'], description='APOBEC1 complementation factor', other_designations='APOBEC1 complementation factor|APOBEC-1 stimulating protein|apo-B RNA editing protein|apobec-1 complementation factor (ACF) (ASP)', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50799409, end_position_on_the_genomic_accession=50885666, orientation='minus', exon_count=15, OMIM=[618199], no_hdr0=''),
    29978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29978, CurrentID=0, Status='live', Symbol='UBQLN2', Aliases=['ALS15', 'CHAP1', 'DSK2', 'HRIHFB2157', 'N4BP4', 'PLIC2'], description='ubiquilin 2', other_designations='ubiquilin-2|Nedd4 binding protein 4|protein linking IAP with cytoskeleton 2|ubiquitin-like product Chap1/Dsk2', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=56563627, end_position_on_the_genomic_accession=56567868, orientation='plus', exon_count=1, OMIM=[300264], no_hdr0=''),
    29979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29979, CurrentID=0, Status='live', Symbol='UBQLN1', Aliases=['DA41', 'DSK2', 'PLIC-1', 'UBQN', 'XDRP1'], description='ubiquilin 1', other_designations='ubiquilin-1|hPLIC-1|protein linking IAP with cytoskeleton 1|testicular tissue protein Li 219', map_location='9q21.2-q21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83659968, end_position_on_the_genomic_accession=83707979, orientation='minus', exon_count=12, OMIM=[605046], no_hdr0=''),
    29980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29980, CurrentID=0, Status='live', Symbol='DONSON', Aliases=['B17', 'C21orf60', 'MIMIS', 'MISSLA'], description='DNA replication fork stabilization factor DONSON', other_designations='protein downstream neighbor of Son|downstream neighbor of SON', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33577551, end_position_on_the_genomic_accession=33588684, orientation='minus', exon_count=10, OMIM=[611428], no_hdr0=''),
    29982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29982, CurrentID=0, Status='live', Symbol='NRBF2', Aliases=['COPR', 'COPR1', 'COPR2', 'NRBF-2'], description='nuclear receptor binding factor 2', other_designations='nuclear receptor-binding factor 2|comodulator of PPAR and RXR 1|comodulator of PPAR and RXR 2', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=63133325, end_position_on_the_genomic_accession=63155029, orientation='plus', exon_count=5, OMIM=[616477], no_hdr0=''),
    29984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29984, CurrentID=0, Status='live', Symbol='RHOD', Aliases=['ARHD', 'RHOHP1', 'RHOM', 'Rho'], description='ras homolog family member D', other_designations='rho-related GTP-binding protein RhoD|Rho-related protein HP1|ras homolog D|ras homolog gene family, member A|ras homolog gene family, member D', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67056847, end_position_on_the_genomic_accession=67072017, orientation='plus', exon_count=5, OMIM=[605781], no_hdr0=''),
    29985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29985, CurrentID=0, Status='live', Symbol='SLC39A3', Aliases=['ZIP-3', 'ZIP3'], description='solute carrier family 39 member 3', other_designations='zinc transporter ZIP3|solute carrier family 39 (zinc transporter), member 3|zrt- and Irt-like protein 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2732524, end_position_on_the_genomic_accession=2740076, orientation='minus', exon_count=3, OMIM=[612168], no_hdr0=''),
    29986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29986, CurrentID=0, Status='live', Symbol='SLC39A2', Aliases=['6A1', 'ETI-1', 'ZIP-2', 'ZIP2'], description='solute carrier family 39 member 2', other_designations='zinc transporter ZIP2|Zrt- and Irt-like protein 2|solute carrier family 39 (zinc transporter), member 2|zinc uptake transporter 2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20999293, end_position_on_the_genomic_accession=21001871, orientation='plus', exon_count=4, OMIM=[612166], no_hdr0=''),
    29988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29988, CurrentID=0, Status='live', Symbol='SLC2A8', Aliases=['GLUT8', 'GLUTX1'], description='solute carrier family 2 member 8', other_designations='solute carrier family 2, facilitated glucose transporter member 8|glucose transporter type 8|glucose transporter type X1|solute carrier family 2 (facilitated glucose transporter), member 8', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127397140, end_position_on_the_genomic_accession=127407898, orientation='plus', exon_count=11, OMIM=[605245], no_hdr0=''),
    29989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29989, CurrentID=0, Status='live', Symbol='OBP2B', Aliases=['LCN14', 'OBPIIb'], description='odorant binding protein 2B', other_designations='odorant-binding protein 2b|odorant-binding protein IIb', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133205279, end_position_on_the_genomic_accession=133223255, orientation='minus', exon_count=11, OMIM=[604606], no_hdr0=''),
    29990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29990, CurrentID=0, Status='live', Symbol='PILRB', Aliases=['FDFACT1', 'FDFACT2'], description='paired immunoglobin like type 2 receptor beta', other_designations='paired immunoglobulin-like type 2 receptor beta|activating receptor PILR-beta|activating receptor PILRbeta|cell surface receptor FDFACT|cell surface receptor FDFACT1|cell surface receptor FDFACT2|paired immunoglobin-like receptor beta|paired immunoglobulin-like receptor beta', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100358117, end_position_on_the_genomic_accession=100367831, orientation='plus', exon_count=5, OMIM=[605342], no_hdr0=''),
    29991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29991, CurrentID=0, Status='live', Symbol='OBP2A', Aliases=['LCN13', 'OBP', 'OBP2C', 'OBPIIa', 'hOBPIIa'], description='odorant binding protein 2A', other_designations='odorant-binding protein 2a|odorant-binding protein IIa|putative odorant-binding protein 2c', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135544812, end_position_on_the_genomic_accession=135549969, orientation='plus', exon_count=8, OMIM=[164320], no_hdr0=''),
    29992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29992, CurrentID=0, Status='live', Symbol='PILRA', Aliases=['FDF03'], description='paired immunoglobin like type 2 receptor alpha', other_designations='paired immunoglobulin-like type 2 receptor alpha|cell surface receptor FDF03|inhibitory receptor PILR-alpha', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100372659, end_position_on_the_genomic_accession=100400098, orientation='plus', exon_count=8, OMIM=[605341], no_hdr0=''),
    29993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29993, CurrentID=0, Status='live', Symbol='PACSIN1', Aliases=['SDPI'], description='protein kinase C and casein kinase substrate in neurons 1', other_designations='protein kinase C and casein kinase substrate in neurons protein 1|syndapin I|syndapin-1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34466076, end_position_on_the_genomic_accession=34536262, orientation='plus', exon_count=12, OMIM=[606512], no_hdr0=''),
    29994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29994, CurrentID=0, Status='live', Symbol='BAZ2B', Aliases=['WALp4'], description='bromodomain adjacent to zinc finger domain 2B', other_designations='bromodomain adjacent to zinc finger domain protein 2B', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159315312, end_position_on_the_genomic_accession=159712442, orientation='minus', exon_count=51, OMIM=[605683], no_hdr0=''),
    29995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29995, CurrentID=0, Status='live', Symbol='LMCD1', Aliases=[], description='LIM and cysteine rich domains 1', other_designations='LIM and cysteine-rich domains protein 1|dyxin', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8501823, end_position_on_the_genomic_accession=8574668, orientation='plus', exon_count=7, OMIM=[604859], no_hdr0=''),
    29997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29997, CurrentID=0, Status='live', Symbol='NOP53', Aliases=['GLTSCR2', 'PICT-1', 'PICT1'], description='NOP53 ribosome biogenesis factor', other_designations='ribosome biogenesis protein NOP53|glioma tumor suppressor candidate region gene 2 protein|p60|protein interacting with carboxyl terminus 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47745546, end_position_on_the_genomic_accession=47757058, orientation='plus', exon_count=13, OMIM=[605691], no_hdr0=''),
    29998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29998, CurrentID=0, Status='live', Symbol='BICRA', Aliases=['CSS12', 'GLTSCR1'], description='BRD4 interacting chromatin remodeling complex associated protein', other_designations='BRD4-interacting chromatin-remodeling complex-associated protein|BRD4 interacting chromatin remodelling complex associated protein|glioma tumor suppressor candidate region gene 1 protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47608196, end_position_on_the_genomic_accession=47703277, orientation='plus', exon_count=17, OMIM=[605690], no_hdr0=''),
    29999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=29999, CurrentID=0, Status='live', Symbol='FSCN3', Aliases=[], description='fascin actin-bundling protein 3', other_designations='fascin-3|fascin actin-bundling protein 3, testicular|fascin homolog 3, actin-bundling protein, testicular|testicular secretory protein Li 18|testis fascin', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127593736, end_position_on_the_genomic_accession=127602144, orientation='plus', exon_count=7, OMIM=[615800], no_hdr0=''),
    30000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30000, CurrentID=0, Status='live', Symbol='TNPO2', Aliases=['IPO3', 'KPNB2B', 'TRN2'], description='transportin 2', other_designations='transportin-2|importin 3|karyopherin beta 2b, transportin|karyopherin beta-2b|transportin 2 (importin 3, karyopherin beta 2b)', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12699201, end_position_on_the_genomic_accession=12723932, orientation='minus', exon_count=28, OMIM=[603002], no_hdr0=''),
    30001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30001, CurrentID=0, Status='live', Symbol='ERO1A', Aliases=['ERO1-L', 'ERO1-L-alpha', 'ERO1-alpha', 'ERO1L', 'ERO1LA', 'Ero1alpha'], description='endoplasmic reticulum oxidoreductase 1 alpha', other_designations='ERO1-like protein alpha|endoplasmic oxidoreductin-1-like protein|endoplasmic reticulum oxidoreductase alpha|oxidoreductin-1-L-alpha', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52639915, end_position_on_the_genomic_accession=52695750, orientation='minus', exon_count=17, OMIM=[615435], no_hdr0=''),
    30008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30008, CurrentID=0, Status='live', Symbol='EFEMP2', Aliases=['ARCL1B', 'FBLN4', 'MBP1', 'UPH1'], description='EGF containing fibulin extracellular matrix protein 2', other_designations='EGF-containing fibulin-like extracellular matrix protein 2|EGF containing fibulin like extracellular matrix protein 2|FIBL-4|fibulin 4|mutant p53 binding protein 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65866441, end_position_on_the_genomic_accession=65872800, orientation='minus', exon_count=12, OMIM=[604633], no_hdr0=''),
    30009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30009, CurrentID=0, Status='live', Symbol='TBX21', Aliases=['T-PET', 'T-bet', 'TBET', 'TBLYM'], description='T-box transcription factor 21', other_designations='T-box transcription factor TBX21|T-box 21|T-box expressed in T cells|T-box protein 21|T-cell-specific T-box transcription factor T-bet|transcription factor TBLYM', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47733236, end_position_on_the_genomic_accession=47746122, orientation='plus', exon_count=6, OMIM=[604895], no_hdr0=''),
    30010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30010, CurrentID=0, Status='live', Symbol='NXPH1', Aliases=['NPH1', 'Nbla00697'], description='neurexophilin 1', other_designations='neurexophilin-1', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=8433609, end_position_on_the_genomic_accession=8752961, orientation='plus', exon_count=3, OMIM=[604639], no_hdr0=''),
    30011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30011, CurrentID=0, Status='live', Symbol='SH3KBP1', Aliases=['AGMX2', 'CD2BP3', 'CIN85', 'GIG10', 'HSB-1', 'HSB1', 'IMD61', 'MIG18'], description='SH3 domain containing kinase binding protein 1', other_designations='SH3 domain-containing kinase-binding protein 1|CD2-binding protein 3|SH3-domain kinase binding protein 1|Src family kinase-binding protein 1|c-Cbl-interacting protein|cbl-interacting protein of 85 kDa|human Src family kinase-binding protein 1|migration-inducing gene 18|src-related kinase binding protein-1', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=19533977, end_position_on_the_genomic_accession=19887600, orientation='minus', exon_count=26, OMIM=[300374], no_hdr0=''),
    30012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30012, CurrentID=0, Status='live', Symbol='TLX3', Aliases=['HOX11L2', 'RNX'], description='T cell leukemia homeobox 3', other_designations='T-cell leukemia homeobox protein 3|homeo box 11-like 2|homeobox protein Hox-11L2', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=171309248, end_position_on_the_genomic_accession=171312139, orientation='plus', exon_count=3, OMIM=[604640], no_hdr0=''),
    30014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30014, CurrentID=0, Status='live', Symbol='SPANXA1', Aliases=['CT11.1', 'CT11.3', 'NAP-X', 'SPAN-X', 'SPAN-Xa', 'SPAN-Xb', 'SPANX', 'SPANX-A'], description='sperm protein associated with the nucleus, X-linked, family member A1', other_designations='sperm protein associated with the nucleus on the X chromosome A|Cancer/testis antigen 11.3|Cancer/testis-associated protein CTp11|Nuclear-associated protein SPAN-Xc|SPANX family member A|SPANX family, member A1|Sperm protein associated with the nucleus on the X chromosome C|cancer/testis antigen 11.1|cancer/testis antigen family 11, member 1|nuclear-associated protein SPAN-Xa|sperm protein associated with the nucleus, X chromosome, family member A1', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141583674, end_position_on_the_genomic_accession=141584738, orientation='minus', exon_count=2, OMIM=[300305], no_hdr0=''),
    30061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30061, CurrentID=0, Status='live', Symbol='SLC40A1', Aliases=['FPN1', 'HFE4', 'IREG1', 'MST079', 'MSTP079', 'MTP1', 'SLC11A3'], description='solute carrier family 40 member 1', other_designations='solute carrier family 40 member 1|iron regulated gene 1|solute carrier family 11 (proton-coupled divalent metal ion transporters), member 3|solute carrier family 40 (iron-regulated transporter), member 1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189560590, end_position_on_the_genomic_accession=189580811, orientation='minus', exon_count=9, OMIM=[604653], no_hdr0=''),
    30062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30062, CurrentID=0, Status='live', Symbol='RAX', Aliases=['MCOP3', 'RX'], description='retina and anterior neural fold homeobox', other_designations='retinal homeobox protein Rx|retina and anterior neural fold homeobox protein', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59267038, end_position_on_the_genomic_accession=59273454, orientation='minus', exon_count=3, OMIM=[601881], no_hdr0=''),
    30811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30811, CurrentID=0, Status='live', Symbol='HUNK', Aliases=[], description='hormonally up-regulated Neu-associated kinase', other_designations='hormonally up-regulated neu tumor-associated kinase|B19|hormonally upregulated Neu-associated kinase|hormonally upregulated neu tumor-associated kinase|serine/threonine protein kinase MAK-V', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=31873020, end_position_on_the_genomic_accession=32004064, orientation='plus', exon_count=11, OMIM=[606532], no_hdr0=''),
    30812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30812, CurrentID=0, Status='live', Symbol='SOX8', Aliases=[], description='SRY-box transcription factor 8', other_designations='transcription factor SOX-8|SRY (sex determining region Y)-box 8|SRY-box 8', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=981770, end_position_on_the_genomic_accession=986979, orientation='plus', exon_count=3, OMIM=[605923], no_hdr0=''),
    30813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30813, CurrentID=0, Status='live', Symbol='VSX1', Aliases=['CAASDS', 'KTCN', 'KTCN1', 'PPCD', 'PPCD1', 'PPD', 'RINX'], description='visual system homeobox 1', other_designations='visual system homeobox 1|homeodomain protein RINX|retinal inner nuclear layer homeobox protein|transcription factor VSX1|visual system homeobox 1 homolog, CHX10-like', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25069940, end_position_on_the_genomic_accession=25082141, orientation='minus', exon_count=8, OMIM=[605020], no_hdr0=''),
    30814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30814, CurrentID=0, Status='live', Symbol='PLA2G2E', Aliases=['GIIE sPLA2', 'sPLA2-IIE'], description='phospholipase A2 group IIE', other_designations='group IIE secretory phospholipase A2|phosphatidylcholine 2-acylhydrolase 2E', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19920009, end_position_on_the_genomic_accession=19923617, orientation='minus', exon_count=4, OMIM=[618320], no_hdr0=''),
    30815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30815, CurrentID=0, Status='live', Symbol='ST6GALNAC6', Aliases=['SIAT7-F', 'SIAT7F', 'ST6GALNACVI'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 6', other_designations='alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase 6|CMP-NeuAC:(beta)-N-acetylgalactosaminide (alpha)2,6-sialyltransferase member VI|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 6|ST6 -N-acetylgalactosaminide alpha-26-sialyltransferase 6|ST6 GalNAc alpha-2,6-sialyltransferase 6|epididymis secretory sperm binding protein|galNAc alpha-2,6-sialyltransferase VI|sialyltransferase 7F|sialytransferase 7 ((alpha-N-acetylneuraminyl 2,3-betagalactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialytransferase) F', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127885321, end_position_on_the_genomic_accession=127906764, orientation='minus', exon_count=10, OMIM=[610135], no_hdr0=''),
    30816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30816, CurrentID=0, Status='live', Symbol='ERVW-1', Aliases=['ENV', 'ENVW', 'ERVWE1', 'HERV-7q', 'HERV-W-ENV', 'HERV7Q', 'HERVW', 'HERVWENV'], description='endogenous retrovirus group W member 1, envelope', other_designations='syncytin-1|HERV-7q envelope protein|HERV-W Env glycoprotein|HERV-W envelope protein|HERV-W_7q21.2 provirus ancestral Env polyprotein|HERV-tryptophan envelope protein|endogenous retroviral family W, env(C7), member 1|endogenous retrovirus group W, member 1|envelope glycoprotein|envelope polyprotein gPr73|enverin|human endogenous retrovirus W envC7-1 envelope protein', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92468380, end_position_on_the_genomic_accession=92477946, orientation='minus', exon_count=2, OMIM=[604659], no_hdr0=''),
    30817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30817, CurrentID=0, Status='live', Symbol='ADGRE2', Aliases=['CD312', 'CD97', 'EMR2', 'VBU'], description='adhesion G protein-coupled receptor E2', other_designations='adhesion G protein-coupled receptor E2|CD97 antigen|EGF-like module-containing mucin-like hormone receptor-like 2|Leukocyte antigen CD97|egf-like module containing, mucin-like, hormone receptor-like 2', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14732392, end_position_on_the_genomic_accession=14778560, orientation='minus', exon_count=24, OMIM=[606100], no_hdr0=''),
    30818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30818, CurrentID=0, Status='live', Symbol='KCNIP3', Aliases=['CSEN', 'DREAM', 'KCHIP3'], description='potassium voltage-gated channel interacting protein 3', other_designations='calsenilin|A-type potassium channel modulatory protein 3|DRE-antagonist modulator|Kv channel interacting protein 3, calsenilin|calsenilin, presenilin-binding protein, EF hand transcription factor|kv channel-interacting protein 3|potassium channel interacting protein 3', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95297325, end_position_on_the_genomic_accession=95386077, orientation='plus', exon_count=11, OMIM=[604662], no_hdr0=''),
    30819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30819, CurrentID=0, Status='live', Symbol='KCNIP2', Aliases=['KCHIP2'], description='potassium voltage-gated channel interacting protein 2', other_designations='Kv channel-interacting protein 2|A-type potassium channel modulatory protein 2|Kv channel interacting protein 2|cardiac voltage-gated potassium channel modulatory subunit|potassium channel-interacting protein 2', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101825971, end_position_on_the_genomic_accession=101843875, orientation='minus', exon_count=12, OMIM=[604661], no_hdr0=''),
    30820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30820, CurrentID=0, Status='live', Symbol='KCNIP1', Aliases=['KCHIP1', 'VABP'], description='potassium voltage-gated channel interacting protein 1', other_designations='Kv channel-interacting protein 1|A-type potassium channel modulatory protein 1|Kv channel interacting protein 1|potassium channel interacting protein 1|vesicle APC-binding protein', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170353055, end_position_on_the_genomic_accession=170736632, orientation='plus', exon_count=14, OMIM=[604660], no_hdr0=''),
    30827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30827, CurrentID=0, Status='live', Symbol='CXXC1', Aliases=['2410002I16Rik', '5830420C16Rik', 'CFP1', 'CGBP', 'HsT2645', 'PCCX1', 'PHF18', 'SPP1', 'ZCGPC1', 'hCGBP'], description='CXXC finger protein 1', other_designations='CXXC-type zinc finger protein 1|CXXC finger 1 (PHD domain)|CpG binding protein|DNA-binding protein with PHD finger and CXXC domain|PHD finger and CXXC domain-containing protein 1|cpG-binding protein|zinc finger, CpG binding-type containing 1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50282343, end_position_on_the_genomic_accession=50288303, orientation='minus', exon_count=16, OMIM=[609150], no_hdr0=''),
    30832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30832, CurrentID=0, Status='live', Symbol='ZNF354C', Aliases=['KID3'], description='zinc finger protein 354C', other_designations='zinc finger protein 354C|KRAB-zinc finger protein synten|kidney, ischemia, and developmentally-regulated protein 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179060373, end_position_on_the_genomic_accession=179083977, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    30833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30833, CurrentID=0, Status='live', Symbol='NT5C', Aliases=['DNT', 'DNT1', 'HEL74', 'P5N2', 'PN-I', 'PN-II', 'UMPH2', 'cdN', 'dNT-1'], description="5', 3'-nucleotidase, cytosolic", other_designations="5'(3')-deoxyribonucleotidase, cytosolic type|5' nucleotidase, deoxy (pyrimidine), cytosolic type C|cytosolic 5',3'-pyrimidine nucleotidase|deoxy-5'-nucleotidase 1|epididymis luminal protein 74|epididymis secretory sperm binding protein|uridine 5'-monophosphate phosphohydrolase 2|uridine 5-prime monophosphate hydrolase 2", map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75130228, end_position_on_the_genomic_accession=75131965, orientation='minus', exon_count=5, OMIM=[191720], no_hdr0=''),
    30834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30834, CurrentID=0, Status='live', Symbol='POLR1H', Aliases=['A12.2', 'HTEX-6', 'HTEX6', 'Rpa12', 'TCTEX6', 'TEX6', 'ZNRD1', 'ZR14', 'hZR14', 'tctex-6'], description='RNA polymerase I subunit H', other_designations='DNA-directed RNA polymerase I subunit RPA12|DNA-directed RNA polymerase I subunit H|RNA polymerase I small specific subunit Rpa12|transcription-associated zinc ribbon protein|zinc ribbon domain containing 1', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30061265, end_position_on_the_genomic_accession=30064907, orientation='plus', exon_count=4, OMIM=[607525], no_hdr0=''),
    30835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30835, CurrentID=0, Status='live', Symbol='CD209', Aliases=['CDSIGN', 'CLEC4L', 'DC-SIGN', 'DC-SIGN1', 'hDC-SIGN'], description='CD209 molecule', other_designations='CD209 antigen|C-type lectin domain family 4 member L|HIV gpl20-binding protein|dendritic cell-specific ICAM-3-grabbing non-integrin 1|dendritic cell-specific intercellular adhesion molecule-3-grabbing non-integrin|dendritic cell-specific intracellular adhesion molecules (ICAM)-3 grabbing non-integrin', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7739993, end_position_on_the_genomic_accession=7747534, orientation='minus', exon_count=6, OMIM=[604672], no_hdr0=''),
    30836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30836, CurrentID=0, Status='live', Symbol='DNTTIP2', Aliases=['ERBP', 'FCF2', 'HSU15552', 'LPTS-RP2', 'TdIF2'], description='deoxynucleotidyltransferase terminal interacting protein 2', other_designations='deoxynucleotidyltransferase terminal-interacting protein 2|LPTS-interacting protein 2|acidic 82 kDa protein mRNA|estrogen receptor binding protein|tdT-interacting factor 2', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93866284, end_position_on_the_genomic_accession=93879206, orientation='minus', exon_count=7, OMIM=[611199], no_hdr0=''),
    30837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30837, CurrentID=0, Status='live', Symbol='SOCS7', Aliases=['NAP4', 'NCKAP4'], description='suppressor of cytokine signaling 7', other_designations='suppressor of cytokine signaling 7|NAP-4|NCK-associated protein 4|Nck, Ash and phospholipase C binding protein|SOCS-7|nck, Ash and phospholipase C gamma-binding protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38351844, end_position_on_the_genomic_accession=38405593, orientation='plus', exon_count=11, OMIM=[608788], no_hdr0=''),
    30844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30844, CurrentID=0, Status='live', Symbol='EHD4', Aliases=['PAST4'], description='EH domain containing 4', other_designations='EH domain-containing protein 4|PAST homolog 4|hepatocellular carcinoma-associated protein 10/11|hepatocellular carcinoma-associated protein HCA11|ortholog of rat pincher', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41895933, end_position_on_the_genomic_accession=41972557, orientation='minus', exon_count=6, OMIM=[605892], no_hdr0=''),
    30845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30845, CurrentID=0, Status='live', Symbol='EHD3', Aliases=['PAST3'], description='EH domain containing 3', other_designations='EH domain-containing protein 3|PAST homolog 3', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=31234152, end_position_on_the_genomic_accession=31269451, orientation='plus', exon_count=7, OMIM=[605891], no_hdr0=''),
    30846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30846, CurrentID=0, Status='live', Symbol='EHD2', Aliases=['PAST2'], description='EH domain containing 2', other_designations='EH domain-containing protein 2|PAST homolog 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47713422, end_position_on_the_genomic_accession=47743134, orientation='plus', exon_count=6, OMIM=[605890], no_hdr0=''),
    30848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30848, CurrentID=0, Status='live', Symbol='CTAG2', Aliases=['CAMEL', 'CT2', 'CT6.2', 'CT6.2a', 'CT6.2b', 'ESO2', 'LAGE-1', 'LAGE2B'], description='cancer/testis antigen 2', other_designations='cancer/testis antigen 2|CTL-recognized antigen on melanoma|LAGE-1a protein|autoimmunogenic cancer/testis antigen NY-ESO-2|cancer/testis antigen 6.2|cancer/testis antigen family 6, member 2a|cancer/testis antigen family 6, member 2b|l antigen family member 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154651977, end_position_on_the_genomic_accession=154653579, orientation='minus', exon_count=3, OMIM=[300396], no_hdr0=''),
    30849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30849, CurrentID=0, Status='live', Symbol='PIK3R4', Aliases=['VPS15', 'p150'], description='phosphoinositide-3-kinase regulatory subunit 4', other_designations='phosphoinositide 3-kinase regulatory subunit 4|PI3-kinase p150 subunit|PI3-kinase regulatory subunit 4|phosphatidylinositol 3-kinase-associated p150|phosphoinositide 3-kinase adaptor protein|phosphoinositide-3-kinase, regulatory subunit 4, p150', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130678934, end_position_on_the_genomic_accession=130746829, orientation='minus', exon_count=20, OMIM=[602610], no_hdr0=''),
    30850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30850, CurrentID=0, Status='live', Symbol='CDR2L', Aliases=['HUMPPA'], description='cerebellar degeneration related protein 2 like', other_designations='cerebellar degeneration-related protein 2-like|paraneoplastic 62 kDa antigen|paraneoplastic antigen', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74987632, end_position_on_the_genomic_accession=75005800, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    30851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30851, CurrentID=0, Status='live', Symbol='TAX1BP3', Aliases=['TIP-1', 'TIP1'], description='Tax1 binding protein 3', other_designations='tax1-binding protein 3|Tax interaction protein 1|Tax1 (human T-cell leukemia virus type I) binding protein 3|glutaminase-interacting protein 3|tax-interacting protein 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3662895, end_position_on_the_genomic_accession=3668578, orientation='minus', exon_count=4, OMIM=[616484], no_hdr0=''),
    30968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=30968, CurrentID=0, Status='live', Symbol='STOML2', Aliases=['HSPC108', 'SLP-2'], description='stomatin like 2', other_designations='stomatin-like protein 2, mitochondrial|EPB72-like 2|EPB72-like protein 2|paraprotein target 7|paratarg-7|stomatin (EPB72)-like 2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35099776, end_position_on_the_genomic_accession=35103195, orientation='minus', exon_count=11, OMIM=[608292], no_hdr0=''),
    43847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=43847, CurrentID=0, Status='live', Symbol='KLK14', Aliases=['KLK-L6'], description='kallikrein related peptidase 14', other_designations='kallikrein-14|kallikrein-like protein 6', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51077494, end_position_on_the_genomic_accession=51084210, orientation='minus', exon_count=8, OMIM=[606135], no_hdr0=''),
    43849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=43849, CurrentID=0, Status='live', Symbol='KLK12', Aliases=['KLK-L5', 'KLKL5'], description='kallikrein related peptidase 12', other_designations='kallikrein-12|kallikrein-like protein 5', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51028954, end_position_on_the_genomic_accession=51035648, orientation='minus', exon_count=6, OMIM=[605539], no_hdr0=''),
    49854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49854, CurrentID=0, Status='live', Symbol='ZBTB21', Aliases=['ZNF295'], description='zinc finger and BTB domain containing 21', other_designations='zinc finger and BTB domain-containing protein 21|zinc finger protein 295', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41986831, end_position_on_the_genomic_accession=42010418, orientation='minus', exon_count=5, OMIM=[616485], no_hdr0=''),
    49855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49855, CurrentID=0, Status='live', Symbol='SCAPER', Aliases=['IDDRP', 'MSTP063', 'ZNF291', 'Zfp291'], description='S-phase cyclin A associated protein in the ER', other_designations='S phase cyclin A-associated protein in the endoplasmic reticulum|zinc finger protein 291', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76347904, end_position_on_the_genomic_accession=76905455, orientation='minus', exon_count=47, OMIM=[611611], no_hdr0=''),
    49856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49856, CurrentID=0, Status='live', Symbol='WRAP73', Aliases=['WDR8'], description='WD repeat containing, antisense to TP73', other_designations='WD repeat-containing protein WRAP73|WD repeat domain 8|epididymis secretory sperm binding protein', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3630767, end_position_on_the_genomic_accession=3650103, orientation='minus', exon_count=13, OMIM=[606040], no_hdr0=''),
    49860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49860, CurrentID=0, Status='live', Symbol='CRNN', Aliases=['C1orf10', 'DRC1', 'PDRC1', 'SEP53'], description='cornulin', other_designations='cornulin|53 kDa putative calcium-binding protein|53 kDa squamous epithelial-induced stress protein|58 kDa heat shock protein|squamous epithelial heat shock protein 53|tumor-related protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152409243, end_position_on_the_genomic_accession=152414263, orientation='minus', exon_count=3, OMIM=[611312], no_hdr0=''),
    49861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=49861, CurrentID=0, Status='live', Symbol='CLDN20', Aliases=[], description='claudin 20', other_designations='claudin-20|testis secretory sperm-binding protein Li 229n', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=155264013, end_position_on_the_genomic_accession=155276548, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    50484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50484, CurrentID=0, Status='live', Symbol='RRM2B', Aliases=['MTDPS8A', 'MTDPS8B', 'P53R2'], description='ribonucleotide reductase regulatory TP53 inducible subunit M2B', other_designations='ribonucleoside-diphosphate reductase subunit M2 B|TP53-inducible ribonucleotide reductase M2 B|p53-inducible ribonucleotide reductase small subunit 2 homolog|p53-inducible ribonucleotide reductase small subunit 2 short form beta|p53-inducible ribonucleotide reductase small subunit 2-like protein|ribonucleotide reductase M2 B (TP53 inducible)', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=102204501, end_position_on_the_genomic_accession=102238961, orientation='minus', exon_count=9, OMIM=[604712], no_hdr0=''),
    50485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50485, CurrentID=0, Status='live', Symbol='SMARCAL1', Aliases=['HARP', 'HHARP'], description='SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily a like 1', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily A-like protein 1|ATP-driven annealing helicase|HepA-related protein|SMARCA-like protein 1|sucrose nonfermenting protein 2-like 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216412484, end_position_on_the_genomic_accession=216483053, orientation='plus', exon_count=19, OMIM=[606622], no_hdr0=''),
    50486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50486, CurrentID=0, Status='live', Symbol='G0S2', Aliases=[], description='G0/G1 switch 2', other_designations='G0/G1 switch protein 2|G0/G1 switch regulatory protein 2|G0/G1switch 2', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209675412, end_position_on_the_genomic_accession=209676390, orientation='plus', exon_count=2, OMIM=[614447], no_hdr0=''),
    50487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50487, CurrentID=0, Status='live', Symbol='PLA2G3', Aliases=['GIII-SPLA2', 'SPLA2III', 'sPLA2-III'], description='phospholipase A2 group III', other_designations='group 3 secretory phospholipase A2|group III secreted phospholipase A2|phosphatidylcholine 2-acylhydrolase 3|phosphatidylcholine 2-acylhydrolase GIII', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31134807, end_position_on_the_genomic_accession=31140508, orientation='minus', exon_count=9, OMIM=[611651], no_hdr0=''),
    50488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50488, CurrentID=0, Status='live', Symbol='MINK1', Aliases=['B55', 'MAP4K6', 'MINK', 'YSK2', 'ZC3'], description='misshapen like kinase 1', other_designations='misshapen-like kinase 1|GCK family kinase MINK|MAPK/ERK kinase kinase kinase 6|MEK kinase kinase 6|MEKKK 6|misshapen/NIK-related kinase|mitogen-activated protein kinase kinase kinase kinase 6', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4833340, end_position_on_the_genomic_accession=4898061, orientation='plus', exon_count=35, OMIM=[609426], no_hdr0=''),
    50489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50489, CurrentID=0, Status='live', Symbol='CD207', Aliases=['CLEC4K'], description='CD207 molecule', other_designations='C-type lectin domain family 4 member K|C-type lectin domain family 4, member K|CD207 antigen, langerin|CD207 molecule, langerin|Langerhans cell specific c-type lectin', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70825248, end_position_on_the_genomic_accession=70860787, orientation='minus', exon_count=10, OMIM=[604862], no_hdr0=''),
    50506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50506, CurrentID=0, Status='live', Symbol='DUOX2', Aliases=['LNOX2', 'NOXEF2', 'P138-TOX', 'TDH6', 'THOX2'], description='dual oxidase 2', other_designations='dual oxidase 2|NADH/NADPH thyroid oxidase p138-tox|NADPH oxidase/peroxidase DUOX2|NADPH thyroid oxidase 2|dual oxidase-like domains 2|flavoprotein NADPH oxidase|large NOX 2|long NOX 2|nicotinamide adenine dinucleotide phosphate oxidase|p138 thyroid oxidase|thyroid oxidase 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45092650, end_position_on_the_genomic_accession=45114172, orientation='minus', exon_count=34, OMIM=[606759], no_hdr0=''),
    50507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50507, CurrentID=0, Status='live', Symbol='NOX4', Aliases=['KOX', 'KOX-1', 'RENOX'], description='NADPH oxidase 4', other_designations='NADPH oxidase 4|kidney oxidase-1|kidney superoxide-producing NADPH oxidase|renal NAD(P)H-oxidase', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89324353, end_position_on_the_genomic_accession=89589557, orientation='minus', exon_count=29, OMIM=[605261], no_hdr0=''),
    50508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50508, CurrentID=0, Status='live', Symbol='NOX3', Aliases=['GP91-3', 'MOX-2'], description='NADPH oxidase 3', other_designations='NADPH oxidase 3|NADPH oxidase catalytic subunit-like 3|gp91phox homolog 3|mitogenic oxidase 2', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=155395368, end_position_on_the_genomic_accession=155455839, orientation='minus', exon_count=14, OMIM=[607105], no_hdr0=''),
    50509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50509, CurrentID=0, Status='live', Symbol='COL5A3', Aliases=[], description='collagen type V alpha 3 chain', other_designations='collagen alpha-3(V) chain|collagen, type V, alpha 3|pro-(alpha)3(V) collagen', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9959561, end_position_on_the_genomic_accession=10010532, orientation='minus', exon_count=67, OMIM=[120216], no_hdr0=''),
    50511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50511, CurrentID=0, Status='live', Symbol='SYCP3', Aliases=['COR1', 'RPRGL4', 'SCP3', 'SPGF4'], description='synaptonemal complex protein 3', other_designations='synaptonemal complex protein 3', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101728648, end_position_on_the_genomic_accession=101739721, orientation='minus', exon_count=8, OMIM=[604759], no_hdr0=''),
    50512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50512, CurrentID=0, Status='live', Symbol='PODXL2', Aliases=['EG', 'PODLX2'], description='podocalyxin like 2', other_designations='podocalyxin-like protein 2|endoglycan', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127629185, end_position_on_the_genomic_accession=127672802, orientation='plus', exon_count=8, OMIM=[616627], no_hdr0=''),
    50515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50515, CurrentID=0, Status='live', Symbol='CHST11', Aliases=['C4ST', 'C4ST-1', 'C4ST1', 'HSA269537', 'OCBMD'], description='carbohydrate sulfotransferase 11', other_designations='carbohydrate sulfotransferase 11|C4S-1|IgH/CHST11 fusion|carbohydrate (chondroitin 4) sulfotransferase 11|chondroitin 4-O-sulfotransferase 1', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104456948, end_position_on_the_genomic_accession=104762014, orientation='plus', exon_count=7, OMIM=[610128], no_hdr0=''),
    50604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50604, CurrentID=0, Status='live', Symbol='IL20', Aliases=['IL-20', 'IL10D', 'ZCYTO10'], description='interleukin 20', other_designations='interleukin-20|cytokine Zcyto10|four alpha helix cytokine', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206863565, end_position_on_the_genomic_accession=206869223, orientation='plus', exon_count=8, OMIM=[605619], no_hdr0=''),
    50613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50613, CurrentID=0, Status='live', Symbol='UBQLN3', Aliases=['TUP-1'], description='ubiquilin 3', other_designations='ubiquilin-3|testicular tissue protein Li 220', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5507300, end_position_on_the_genomic_accession=5509957, orientation='minus', exon_count=3, OMIM=[605473], no_hdr0=''),
    50614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50614, CurrentID=0, Status='live', Symbol='GALNT9', Aliases=['GALNAC-T9', 'GALNACT9'], description='polypeptide N-acetylgalactosaminyltransferase 9', other_designations='polypeptide N-acetylgalactosaminyltransferase 9|GalNAc transferase 9|UDP-GalNAc: polypeptide N-acetylgalactosaminyltransferase 9|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 9 (GalNAc-T9)|polypeptide GalNAc transferase 9|pp-GaNTase 9|protein-UDP acetylgalactosaminyltransferase 9', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132196372, end_position_on_the_genomic_accession=132329589, orientation='minus', exon_count=13, OMIM=[606251], no_hdr0=''),
    50615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50615, CurrentID=0, Status='live', Symbol='IL21R', Aliases=['CD360', 'IMD56', 'NILR'], description='interleukin 21 receptor', other_designations='interleukin-21 receptor|IL-21 receptor|novel interleukin receptor', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27402162, end_position_on_the_genomic_accession=27452043, orientation='plus', exon_count=12, OMIM=[605383], no_hdr0=''),
    50616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50616, CurrentID=0, Status='live', Symbol='IL22', Aliases=['IL-21', 'IL-22', 'IL-D110', 'IL-TIF', 'ILTIF', 'TIFIL-23', 'TIFa', 'zcyto18'], description='interleukin 22', other_designations='interleukin-22|IL-10-related T-cell-derived inducible factor|cytokine Zcyto18', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68248242, end_position_on_the_genomic_accession=68253604, orientation='minus', exon_count=6, OMIM=[605330], no_hdr0=''),
    50617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50617, CurrentID=0, Status='live', Symbol='ATP6V0A4', Aliases=['A4', 'ATP6N1B', 'ATP6N2', 'DRTA3', 'RDRTA2', 'RTA1C', 'RTADR', 'STV1', 'VPH1', 'VPP2'], description='ATPase H+ transporting V0 subunit a4', other_designations='V-type proton ATPase 116 kDa subunit a isoform 4|V-type proton ATPase 116 kDa subunit a|ATPase, H+ transporting, lysosomal (vacuolar proton pump) non-catalytic accessory protein 1B|ATPase, H+ transporting, lysosomal (vacuolar proton pump) non-catalytic accessory protein 2 (38kD)|ATPase, H+ transporting, lysosomal V0 subunit a4|H(+)-transporting two-sector ATPase, noncatalytic accessory protein 1B|V-ATPase 116 kDa|V-ATPase subunit a4|vacuolar proton pump 116 kDa accessory subunit|vacuolar proton pump, subunit 2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138706294, end_position_on_the_genomic_accession=138799839, orientation='minus', exon_count=24, OMIM=[605239], no_hdr0=''),
    50618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50618, CurrentID=0, Status='live', Symbol='ITSN2', Aliases=['PRO2015', 'SH3D1B', 'SH3P18', 'SWA', 'SWAP'], description='intersectin 2', other_designations='intersectin-2|SH3 domain-containing protein 1B|SH3P18-like WASP-associated protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24202864, end_position_on_the_genomic_accession=24360538, orientation='minus', exon_count=45, OMIM=[604464], no_hdr0=''),
    50619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50619, CurrentID=0, Status='live', Symbol='DEF6', Aliases=['IBP', 'SLAT', 'SWAP70L'], description='DEF6 guanine nucleotide exchange factor', other_designations='differentially expressed in FDCP 6 homolog|DEF-6|IRF4-binding protein|SWAP-70-like adaptor protein of T cells', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35297818, end_position_on_the_genomic_accession=35321771, orientation='plus', exon_count=11, OMIM=[610094], no_hdr0=''),
    50624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50624, CurrentID=0, Status='live', Symbol='CUZD1', Aliases=['ERG-1', 'ERG1', 'ITMAP1', 'UO-44'], description='CUB and zona pellucida like domains 1', other_designations='CUB and zona pellucida-like domain-containing protein 1|CUB and ZP domain-containing protein 1|estrogen regulated gene 1|transmembrane protein UO-44', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122832158, end_position_on_the_genomic_accession=122845857, orientation='minus', exon_count=9, OMIM=[616644], no_hdr0=''),
    50626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50626, CurrentID=0, Status='live', Symbol='CYHR1', Aliases=['CHRP'], description='cysteine and histidine rich 1', other_designations='cysteine and histidine-rich protein 1|cysteine and histidine rich protein|cysteine/histidine-rich 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144449582, end_position_on_the_genomic_accession=144465701, orientation='minus', exon_count=7, OMIM=[616635], no_hdr0=''),
    50628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50628, CurrentID=0, Status='live', Symbol='GEMIN4', Aliases=['HC56', 'HCAP1', 'HHRF-1', 'NEDMCR', 'p97'], description='gem nuclear organelle associated protein 4', other_designations='gem-associated protein 4|HCC-associated protein 1|component of gems 4|gemin-4', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=744421, end_position_on_the_genomic_accession=752868, orientation='minus', exon_count=6, OMIM=[606969], no_hdr0=''),
    50632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50632, CurrentID=0, Status='live', Symbol='CALY', Aliases=['DRD1IP', 'NSG3'], description='calcyon neuron specific vesicular protein', other_designations='neuron-specific vesicular protein calcyon|D1 dopamine receptor-interacting protein|calcyon D1 dopamine receptor-interacting protein (CALCYON)|calcyon protein|dopamine receptor D1 interacting protein', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133324072, end_position_on_the_genomic_accession=133336896, orientation='minus', exon_count=9, OMIM=[604647], no_hdr0=''),
    50636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50636, CurrentID=0, Status='live', Symbol='ANO7', Aliases=['D-TMPP', 'DTMPP', 'IPCA-5', 'IPCA5', 'NGEP', 'PCANAP5', 'PCANAP5L', 'TMEM16G'], description='anoctamin 7', other_designations='anoctamin-7|Dresden-transmembrane protein of the prostate|prostate cancer associated protein 5|transmembrane protein 16G', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241188551, end_position_on_the_genomic_accession=241239602, orientation='plus', exon_count=27, OMIM=[605096], no_hdr0=''),
    50640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50640, CurrentID=0, Status='live', Symbol='PNPLA8', Aliases=['IPLA2-2', 'IPLA2G', 'MMLA', 'PNPLA-gamma', 'iPLA2gamma'], description='patatin like phospholipase domain containing 8', other_designations='calcium-independent phospholipase A2-gamma|intracellular membrane-associated calcium-independent phospholipase A2 gamma|membrane-associated calcium-independent phospholipase A2 gamma', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=108470417, end_position_on_the_genomic_accession=108528178, orientation='minus', exon_count=14, OMIM=[612123], no_hdr0=''),
    50649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50649, CurrentID=0, Status='live', Symbol='ARHGEF4', Aliases=['ASEF', 'ASEF1', 'GEF4', 'SMIM39', 'STM6'], description='Rho guanine nucleotide exchange factor 4', other_designations='rho guanine nucleotide exchange factor 4|APC-stimulated guanine nucleotide exchange factor 1|Rho guanine nucleotide exchange factor (GEF) 4', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130836914, end_position_on_the_genomic_accession=131051514, orientation='plus', exon_count=20, OMIM=[605216], no_hdr0=''),
    50650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50650, CurrentID=0, Status='live', Symbol='ARHGEF3', Aliases=['GEF3', 'STA3', 'XPLN'], description='Rho guanine nucleotide exchange factor 3', other_designations='rho guanine nucleotide exchange factor 3|59.8 kDA protein|Rho guanine nucleotide exchange factor (GEF) 3|RhoGEF protein|exchange factor found in platelets and leukemic and neuronal tissues, XPLN', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=56727419, end_position_on_the_genomic_accession=57079308, orientation='minus', exon_count=21, OMIM=[612115], no_hdr0=''),
    50651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50651, CurrentID=0, Status='live', Symbol='SLC45A1', Aliases=['DNB5', 'IDDNPF', 'PAST-A'], description='solute carrier family 45 member 1', other_designations='proton-associated sugar transporter A|H+/sugar symporter|deleted in neuroblastoma 5 protein', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8318114, end_position_on_the_genomic_accession=8344167, orientation='plus', exon_count=9, OMIM=[605763], no_hdr0=''),
    50674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50674, CurrentID=0, Status='live', Symbol='NEUROG3', Aliases=['Atoh5', 'Math4B', 'NGN-3', 'bHLHa7', 'ngn3'], description='neurogenin 3', other_designations='neurogenin-3|class A basic helix-loop-helix protein 7|protein atonal homolog 5', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69571440, end_position_on_the_genomic_accession=69573425, orientation='minus', exon_count=2, OMIM=[604882], no_hdr0=''),
    50700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50700, CurrentID=0, Status='live', Symbol='RDH8', Aliases=['PRRDH', 'SDR28C2'], description='retinol dehydrogenase 8', other_designations='retinol dehydrogenase 8|photoreceptor outer segment all-trans retinol dehydrogenase|retinol dehydrogenase 8 (all-trans)|short chain dehydrogenase/reductase family 28C member 2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10013483, end_position_on_the_genomic_accession=10022279, orientation='plus', exon_count=6, OMIM=[608575], no_hdr0=''),
    50717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50717, CurrentID=0, Status='live', Symbol='DCAF8', Aliases=['GAN2', 'H326', 'WDR42A'], description='DDB1 and CUL4 associated factor 8', other_designations='DDB1- and CUL4-associated factor 8|WD repeat domain 42A|WD repeat-containing protein 42A', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160215720, end_position_on_the_genomic_accession=160262549, orientation='minus', exon_count=14, OMIM=[615820], no_hdr0=''),
    50801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50801, CurrentID=0, Status='live', Symbol='KCNK4', Aliases=['FHEIG', 'K2p4.1', 'TRAAK', 'TRAAK1'], description='potassium two pore domain channel subfamily K member 4', other_designations='potassium channel subfamily K member 4|K2P4.1 potassium channel|TWIK-related arachidonic acid-stimulated potassium channel protein|potassium channel, subfamily K, member 4|potassium channel, two pore domain subfamily K, member 4|two pore K(+) channel KT4.1|two pore K+ channel KT4.1|two pore potassium channel KT4.1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64291302, end_position_on_the_genomic_accession=64300031, orientation='plus', exon_count=9, OMIM=[605720], no_hdr0=''),
    50802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50802, CurrentID=0, Status='live', Symbol='IGK', Aliases=['IGK@'], description='immunoglobulin kappa locus', other_designations='', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88857361, end_position_on_the_genomic_accession=90235368, orientation='plus', exon_count=0, OMIM=[], no_hdr0=''),
    50804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50804, CurrentID=0, Status='live', Symbol='MYEF2', Aliases=['HsT18564', 'MEF-2', 'MST156', 'MSTP156', 'myEF-2'], description='myelin expression factor 2', other_designations='myelin expression factor 2|myelin gene expression factor 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48134632, end_position_on_the_genomic_accession=48178517, orientation='minus', exon_count=19, OMIM=[619395], no_hdr0=''),
    50805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50805, CurrentID=0, Status='live', Symbol='IRX4', Aliases=['IRXA3'], description='iroquois homeobox 4', other_designations='iroquois-class homeodomain protein IRX-4|homeodomain protein IRXA3|iroquois homeobox protein 4', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1877413, end_position_on_the_genomic_accession=1887179, orientation='minus', exon_count=8, OMIM=[606199], no_hdr0=''),
    50807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50807, CurrentID=0, Status='live', Symbol='ASAP1', Aliases=['AMAP1', 'CENTB4', 'DDEF1', 'PAG2', 'PAP', 'ZG14P'], description='ArfGAP with SH3 domain, ankyrin repeat and PH domain 1', other_designations='arf-GAP with SH3 domain, ANK repeat and PH domain-containing protein 1|130 kDa phosphatidylinositol 4,5-biphosphate-dependent ARF1 GTPase-activating protein|130 kDa phosphatidylinositol 4,5-bisphosphate-dependent ARF1 GTPase-activating protein|ADP-ribosylation factor-directed GTPase-activating protein 1|ARF GTPase-activating protein 1|DEF-1|PIP2-dependent ARF1 GAP|centaurin, beta 4|development and differentiation-enhancing factor 1', map_location='8q24.21-q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=130052104, end_position_on_the_genomic_accession=130443848, orientation='minus', exon_count=37, OMIM=[605953], no_hdr0=''),
    50808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50808, CurrentID=0, Status='live', Symbol='AK3', Aliases=['AK3L1', 'AK6', 'AKL3L', 'AKL3L1', 'FIX'], description='adenylate kinase 3', other_designations='GTP:AMP phosphotransferase AK3, mitochondrial|GTP:AMP phosphotransferase, mitochondrial|adenylate kinase 3 alpha-like 1|adenylate kinase 6, adenylate kinase 3 like 1', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4709556, end_position_on_the_genomic_accession=4742043, orientation='minus', exon_count=8, OMIM=[609290], no_hdr0=''),
    50809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50809, CurrentID=0, Status='live', Symbol='HP1BP3', Aliases=['HP1-BP74', 'HP1BP74'], description='heterochromatin protein 1 binding protein 3', other_designations='heterochromatin protein 1-binding protein 3', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20740266, end_position_on_the_genomic_accession=20787307, orientation='minus', exon_count=15, OMIM=[616072], no_hdr0=''),
    50810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50810, CurrentID=0, Status='live', Symbol='HDGFL3', Aliases=['CGI-142', 'HDGF-2', 'HDGF2', 'HDGFRP3', 'HRP-3'], description='HDGF like 3', other_designations='hepatoma-derived growth factor-related protein 3|hepatoma-derived growth factor 2|hepatoma-derived growth factor, related protein 3', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83112738, end_position_on_the_genomic_accession=83207823, orientation='minus', exon_count=7, OMIM=[616643], no_hdr0=''),
    50813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50813, CurrentID=0, Status='live', Symbol='COPS7A', Aliases=['CSN7', 'CSN7A', 'SGN7a'], description='COP9 signalosome subunit 7A', other_designations='COP9 signalosome complex subunit 7a|COP9 complex subunit 7a|COP9 constitutive photomorphogenic homolog subunit 7A|JAB1-containing signalosome subunit 7a|dermal papilla-derived protein 10', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6724046, end_position_on_the_genomic_accession=6731868, orientation='plus', exon_count=9, OMIM=[616009], no_hdr0=''),
    50814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50814, CurrentID=0, Status='live', Symbol='NSDHL', Aliases=['H105E3', 'SDR31E1', 'XAP104'], description='NAD(P) dependent steroid dehydrogenase-like', other_designations='sterol-4-alpha-carboxylate 3-dehydrogenase, decarboxylating|NAD(P) dependent steroid dehydrogenase-like protein transcript|epididymis secretory sperm binding protein|protein H105e3|short chain dehydrogenase/reductase family 31E, member 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152831001, end_position_on_the_genomic_accession=152869729, orientation='plus', exon_count=11, OMIM=[300275], no_hdr0=''),
    50831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50831, CurrentID=0, Status='live', Symbol='TAS2R3', Aliases=['T2R3'], description='taste 2 receptor member 3', other_designations='taste receptor type 2 member 3|candidate taste receptor T2R3|taste receptor, type 2, member 3', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141764097, end_position_on_the_genomic_accession=141765197, orientation='plus', exon_count=1, OMIM=[604868], no_hdr0=''),
    50832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50832, CurrentID=0, Status='live', Symbol='TAS2R4', Aliases=['T2R4'], description='taste 2 receptor member 4', other_designations='taste receptor type 2 member 4|candidate taste receptor T2R4|taste receptor, type 2, member 4', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141776674, end_position_on_the_genomic_accession=141781691, orientation='plus', exon_count=1, OMIM=[604869], no_hdr0=''),
    50833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50833, CurrentID=0, Status='live', Symbol='TAS2R16', Aliases=['BGLPT', 'T2R16'], description='taste 2 receptor member 16', other_designations='taste receptor type 2 member 16|candidate taste receptor T2R16|taste receptor, type 2, member 16', map_location='7q31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122994704, end_position_on_the_genomic_accession=122995700, orientation='minus', exon_count=1, OMIM=[604867], no_hdr0=''),
    50834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50834, CurrentID=0, Status='live', Symbol='TAS2R1', Aliases=['T2R1', 'TRB7'], description='taste 2 receptor member 1', other_designations='taste receptor type 2 member 1|taste receptor, family B, member 7|taste receptor, type 2, member 1', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=9627347, end_position_on_the_genomic_accession=9903876, orientation='minus', exon_count=10, OMIM=[604796], no_hdr0=''),
    50835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50835, CurrentID=0, Status='live', Symbol='TAS2R9', Aliases=['T2R9', 'TRB6'], description='taste 2 receptor member 9', other_designations='taste receptor type 2 member 9|taste receptor, family B, member 6|taste receptor, type 2, member 9', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10809094, end_position_on_the_genomic_accession=10810168, orientation='minus', exon_count=1, OMIM=[604795], no_hdr0=''),
    50836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50836, CurrentID=0, Status='live', Symbol='TAS2R8', Aliases=['T2R8', 'TRB5'], description='taste 2 receptor member 8', other_designations='taste receptor type 2 member 8|taste receptor, family B, member 5|taste receptor, type 2, member 8', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10806051, end_position_on_the_genomic_accession=10807286, orientation='minus', exon_count=1, OMIM=[604794], no_hdr0=''),
    50837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50837, CurrentID=0, Status='live', Symbol='TAS2R7', Aliases=['T2R7', 'TRB4'], description='taste 2 receptor member 7', other_designations='taste receptor type 2 member 7|taste receptor, family B, member 4|taste receptor, type 2, member 7', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10801532, end_position_on_the_genomic_accession=10802627, orientation='minus', exon_count=1, OMIM=[604793], no_hdr0=''),
    50838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50838, CurrentID=0, Status='live', Symbol='TAS2R13', Aliases=['T2R13', 'TRB3'], description='taste 2 receptor member 13', other_designations='taste receptor type 2 member 13|taste receptor, family B, member 3|taste receptor, type 2, member 13', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10907926, end_position_on_the_genomic_accession=10909562, orientation='minus', exon_count=1, OMIM=[604792], no_hdr0=''),
    50839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50839, CurrentID=0, Status='live', Symbol='TAS2R10', Aliases=['T2R10', 'TRB2'], description='taste 2 receptor member 10', other_designations='taste receptor type 2 member 10|taste receptor, family B, member 2|taste receptor, type 2, member 10', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10825346, end_position_on_the_genomic_accession=10826269, orientation='minus', exon_count=1, OMIM=[604791], no_hdr0=''),
    50840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50840, CurrentID=0, Status='live', Symbol='TAS2R14', Aliases=['T2R14', 'TRB1'], description='taste 2 receptor member 14', other_designations='taste receptor type 2 member 14|taste receptor, family B, member 1|taste receptor, type 2, member 14', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10938254, end_position_on_the_genomic_accession=10939207, orientation='minus', exon_count=1, OMIM=[604790], no_hdr0=''),
    50846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50846, CurrentID=0, Status='live', Symbol='DHH', Aliases=['GDMN', 'GDXYM', 'HHG-3', 'SRXY7'], description='desert hedgehog signaling molecule', other_designations='desert hedgehog protein', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49086656, end_position_on_the_genomic_accession=49094801, orientation='minus', exon_count=5, OMIM=[605423], no_hdr0=''),
    50848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50848, CurrentID=0, Status='live', Symbol='F11R', Aliases=['CD321', 'JAM', 'JAM1', 'JAMA', 'JCAM', 'KAT', 'PAM-1'], description='F11 receptor', other_designations='junctional adhesion molecule A|junctional adhesion molecule 1|platelet F11 receptor|platelet adhesion molecule 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160995211, end_position_on_the_genomic_accession=161021152, orientation='minus', exon_count=10, OMIM=[605721], no_hdr0=''),
    50852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50852, CurrentID=0, Status='live', Symbol='TRAT1', Aliases=['HSPC062', 'TCRIM', 'TRIM', 'pp29/30'], description='T cell receptor associated transmembrane adaptor 1', other_designations='T-cell receptor-associated transmembrane adapter 1|T cell receptor interacting molecule', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108822786, end_position_on_the_genomic_accession=108855005, orientation='plus', exon_count=6, OMIM=[604962], no_hdr0=''),
    50853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50853, CurrentID=0, Status='live', Symbol='VILL', Aliases=[], description='villin like', other_designations='villin-like protein', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37987978, end_position_on_the_genomic_accession=38007185, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    50855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50855, CurrentID=0, Status='live', Symbol='PARD6A', Aliases=['PAR-6A', 'PAR6', 'PAR6C', 'PAR6alpha', 'TAX40', 'TIP-40'], description='par-6 family cell polarity regulator alpha', other_designations='partitioning defective 6 homolog alpha|PAR-6 alpha|Tax-interacting protein 40|par-6 partitioning defective 6 homolog alpha|partitioning-defective protein 6|tax interaction protein 40', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67660956, end_position_on_the_genomic_accession=67662774, orientation='plus', exon_count=3, OMIM=[607484], no_hdr0=''),
    50856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50856, CurrentID=0, Status='live', Symbol='CLEC4A', Aliases=['CD367', 'CLECSF6', 'DCIR', 'DDB27', 'HDCGC13P', 'LLIR', 'hDCIR'], description='C-type lectin domain family 4 member A', other_designations='C-type lectin domain family 4 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 6|C-type lectin DDB27|C-type lectin superfamily member 6|dendritic cell immunoreceptor|lectin-like immunoreceptor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8102902, end_position_on_the_genomic_accession=8138607, orientation='plus', exon_count=10, OMIM=[605306], no_hdr0=''),
    50859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50859, CurrentID=0, Status='live', Symbol='SPOCK3', Aliases=['HSAJ1454', 'TES-3', 'TICN3'], description='SPARC (osteonectin), cwcv and kazal like domains proteoglycan 3', other_designations='testican-3|SPARC/osteonectin, cwcv and kazal like domains proteoglycan 3|sparc/osteonectin, cwcv and kazal-like domains proteoglycan (testican) 3', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=166733384, end_position_on_the_genomic_accession=167234869, orientation='minus', exon_count=15, OMIM=[607989], no_hdr0=''),
    50861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50861, CurrentID=0, Status='live', Symbol='STMN3', Aliases=['SCLIP'], description='stathmin 3', other_designations='stathmin-3|SCG10-like protein|stathmin-like 3', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63639712, end_position_on_the_genomic_accession=63653424, orientation='minus', exon_count=6, OMIM=[608362], no_hdr0=''),
    50862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50862, CurrentID=0, Status='live', Symbol='RNF141', Aliases=['RFP141', 'ZFP26', 'ZNF230'], description='ring finger protein 141', other_designations='RING finger protein 141|C3HC4-like zinc finger protein|zinc finger protein 230', map_location='11p15', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10511673, end_position_on_the_genomic_accession=10541187, orientation='minus', exon_count=6, OMIM=[616641], no_hdr0=''),
    50863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50863, CurrentID=0, Status='live', Symbol='NTM', Aliases=['CEPU-1', 'HNT', 'IGLON2', 'NTRI'], description='neurotrimin', other_designations='neurotrimin|IgLON family member 2', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=131370615, end_position_on_the_genomic_accession=132336822, orientation='plus', exon_count=21, OMIM=[607938], no_hdr0=''),
    50865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50865, CurrentID=0, Status='live', Symbol='HEBP1', Aliases=['HBP', 'HEBP'], description='heme binding protein 1', other_designations='heme-binding protein 1|p22HBP', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12974870, end_position_on_the_genomic_accession=13000265, orientation='minus', exon_count=4, OMIM=[605826], no_hdr0=''),
    50937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50937, CurrentID=0, Status='live', Symbol='CDON', Aliases=['CDO1', 'HPE11', 'Ihog', 'ORCAM', 'CDON'], description='cell adhesion associated, oncogene regulated', other_designations='cell adhesion molecule-related/down-regulated by oncogenes|Cdon homolog|surface glycoprotein, Ig superfamily member', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125956813, end_position_on_the_genomic_accession=126063335, orientation='minus', exon_count=24, OMIM=[608707], no_hdr0=''),
    50939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50939, CurrentID=0, Status='live', Symbol='IMPG2', Aliases=['IPM200', 'RP56', 'SPACRCAN', 'VMD5'], description='interphotoreceptor matrix proteoglycan 2', other_designations='interphotoreceptor matrix proteoglycan 2|IPM 200|interphotoreceptor matrix proteoglycan IPM 200|interphotoreceptor matrix proteoglycan of 200 kDa|sialoprotein associated with cones and rods proteoglycan', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101222546, end_position_on_the_genomic_accession=101320575, orientation='minus', exon_count=19, OMIM=[607056], no_hdr0=''),
    50940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50940, CurrentID=0, Status='live', Symbol='PDE11A', Aliases=['PPNAD2'], description='phosphodiesterase 11A', other_designations="dual 3',5'-cyclic-AMP and -GMP phosphodiesterase 11A|cAMP and cGMP cyclic nucleotide phosphodiesterase 11A", map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177623244, end_position_on_the_genomic_accession=178108339, orientation='minus', exon_count=24, OMIM=[604961], no_hdr0=''),
    50943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50943, CurrentID=0, Status='live', Symbol='FOXP3', Aliases=['AIID', 'DIETER', 'IPEX', 'JM2', 'PIDX', 'XPID'], description='forkhead box P3', other_designations='forkhead box protein P3|FOXP3delta7|immune dysregulation, polyendocrinopathy, enteropathy, X-linked|immunodeficiency, polyendocrinopathy, enteropathy, X-linked', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49250436, end_position_on_the_genomic_accession=49264932, orientation='minus', exon_count=12, OMIM=[300292], no_hdr0=''),
    50944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50944, CurrentID=0, Status='live', Symbol='SHANK1', Aliases=['SPANK-1', 'SSTRIP', 'synamon'], description='SH3 and multiple ankyrin repeat domains 1', other_designations='SH3 and multiple ankyrin repeat domains protein 1|SSTR-interacting protein|somatostatin receptor-interacting protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50659255, end_position_on_the_genomic_accession=50719802, orientation='minus', exon_count=25, OMIM=[604999], no_hdr0=''),
    50945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50945, CurrentID=0, Status='live', Symbol='TBX22', Aliases=['ABERS', 'CLPA', 'CPX', 'TBXX', 'dJ795G23.1'], description='T-box transcription factor 22', other_designations='T-box transcription factor TBX22|T-box 22|T-box protein 22', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=80014753, end_position_on_the_genomic_accession=80031774, orientation='plus', exon_count=9, OMIM=[300307], no_hdr0=''),
    50964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50964, CurrentID=0, Status='live', Symbol='SOST', Aliases=['CDD', 'DAND61', 'VBCH', 'SOST'], description='sclerostin', other_designations='sclerostin', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43753738, end_position_on_the_genomic_accession=43758791, orientation='minus', exon_count=2, OMIM=[605740], no_hdr0=''),
    50999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=50999, CurrentID=0, Status='live', Symbol='TMED5', Aliases=['CGI-100', 'p24g2', 'p28'], description='transmembrane p24 trafficking protein 5', other_designations='transmembrane emp24 domain-containing protein 5|p24 family protein gamma-2|p24gamma2|transmembrane emp24 protein transport domain containing 5', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93149742, end_position_on_the_genomic_accession=93180413, orientation='minus', exon_count=6, OMIM=[616876], no_hdr0=''),
    51000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51000, CurrentID=0, Status='live', Symbol='SLC35B3', Aliases=['C6orf196', 'CGI-19', 'PAPST2'], description='solute carrier family 35 member B3', other_designations="adenosine 3'-phospho 5'-phosphosulfate transporter 2|3' phosphoadenosine 5' phosphosulfate transporter 2|PAPS transporter 2|solute carrier family 35 (adenosine 3'-phospho 5'-phosphosulfate transporter), member B3", map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=8411435, end_position_on_the_genomic_accession=8435567, orientation='minus', exon_count=13, OMIM=[610845], no_hdr0=''),
    51001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51001, CurrentID=0, Status='live', Symbol='MTERF3', Aliases=['CGI-12', 'MTERFD1'], description='mitochondrial transcription termination factor 3', other_designations='transcription termination factor 3, mitochondrial|MTERF domain containing 1|mTERF domain-containing protein 1, mitochondrial', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96239398, end_position_on_the_genomic_accession=96261613, orientation='minus', exon_count=10, OMIM=[616930], no_hdr0=''),
    51002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51002, CurrentID=0, Status='live', Symbol='TPRKB', Aliases=['CGI-121', 'CGI121', 'GAMOS5'], description='TP53RK binding protein', other_designations='EKC/KEOPS complex subunit TPRKB|PRPK (p53-related protein kinase)-binding protein', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73729873, end_position_on_the_genomic_accession=73737345, orientation='minus', exon_count=8, OMIM=[608680], no_hdr0=''),
    51003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51003, CurrentID=0, Status='live', Symbol='MED31', Aliases=['3110004H13Rik', 'CGI-125', 'Soh1'], description='mediator complex subunit 31', other_designations='mediator of RNA polymerase II transcription subunit 31|hSOH1|mediator complex subunit SOH1|mediator of RNA polymerase II transcription, subunit 31 homolog', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6643311, end_position_on_the_genomic_accession=6651605, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    51004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51004, CurrentID=0, Status='live', Symbol='COQ6', Aliases=['CGI-10', 'CGI10', 'COQ10D6'], description='coenzyme Q6, monooxygenase', other_designations='ubiquinone biosynthesis monooxygenase COQ6, mitochondrial|coenzyme Q10 monooxygenase 6|coenzyme Q6 homolog, monooxygenase', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73949926, end_position_on_the_genomic_accession=73963670, orientation='plus', exon_count=15, OMIM=[614647], no_hdr0=''),
    51005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51005, CurrentID=0, Status='live', Symbol='AMDHD2', Aliases=['CGI-14'], description='amidohydrolase domain containing 2', other_designations='N-acetylglucosamine-6-phosphate deacetylase|amidohydrolase domain-containing protein 2|glcNAc 6-P deacetylase|putative N-acetylglucosamine-6-phosphate deacetylase', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2520362, end_position_on_the_genomic_accession=2531422, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    51006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51006, CurrentID=0, Status='live', Symbol='SLC35C2', Aliases=['BA394O2.1', 'C20orf5', 'CGI-15', 'OVCOV1'], description='solute carrier family 35 member C2', other_designations='solute carrier family 35 member C2|ovarian cancer-overexpressed gene 1 protein|solute carrier family 35 (GDP-fucose transporter), member C2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46345984, end_position_on_the_genomic_accession=46364427, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    51008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51008, CurrentID=0, Status='live', Symbol='ASCC1', Aliases=['ASC1p50', 'CGI-18', 'SMABF2', 'p50'], description='activating signal cointegrator 1 complex subunit 1', other_designations='activating signal cointegrator 1 complex subunit 1|ASC-1 complex subunit P50|trip4 complex subunit p50', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72096032, end_position_on_the_genomic_accession=72218777, orientation='minus', exon_count=16, OMIM=[614215], no_hdr0=''),
    51009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51009, CurrentID=0, Status='live', Symbol='DERL2', Aliases=['CGI-101', 'DERtrin-2', 'F-LAN-1', 'F-LANa', 'FLANa', 'derlin-2'], description='derlin 2', other_designations='derlin-2|Der1-like domain family, member 2|carcinoma related|degradation in endoplasmic reticulum protein 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5471254, end_position_on_the_genomic_accession=5486225, orientation='minus', exon_count=8, OMIM=[610304], no_hdr0=''),
    51010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51010, CurrentID=0, Status='live', Symbol='EXOSC3', Aliases=['CGI-102', 'PCH1B', 'RRP40', 'Rrp40p', 'bA3J10.7', 'hRrp-40', 'p10'], description='exosome component 3', other_designations='exosome complex component RRP40|exosome complex exonuclease RRP40|ribosomal RNA-processing protein 40', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37779714, end_position_on_the_genomic_accession=37785092, orientation='minus', exon_count=4, OMIM=[606489], no_hdr0=''),
    51011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51011, CurrentID=0, Status='live', Symbol='FAHD2A', Aliases=['CGI-105'], description='fumarylacetoacetate hydrolase domain containing 2A', other_designations='fumarylacetoacetate hydrolase domain-containing protein 2A|fumarylacetoacetate hydrolase domain containing 1', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95402672, end_position_on_the_genomic_accession=95416702, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    51012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51012, CurrentID=0, Status='live', Symbol='PRELID3B', Aliases=['C20orf45', 'SLMO2', 'dJ543J19.5'], description='PRELI domain containing 3B', other_designations='PRELI domain containing protein 3B|protein slowmo homolog 2|slowmo homolog 2', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59033145, end_position_on_the_genomic_accession=59042786, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    51013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51013, CurrentID=0, Status='live', Symbol='EXOSC1', Aliases=['CGI-108', 'CSL4', 'Csl4p', 'PCH1F', 'SKI4', 'Ski4p', 'p13'], description='exosome component 1', other_designations="exosome complex component CSL4|3'-5' exoribonuclease CSL4 homolog|exosomal core protein CSL4|homolog of yeast exosomal core protein CSL4", map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97435909, end_position_on_the_genomic_accession=97446006, orientation='minus', exon_count=9, OMIM=[606493], no_hdr0=''),
    51014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51014, CurrentID=0, Status='live', Symbol='TMED7', Aliases=['CGI-109', 'p24g3', 'p24gamma3', 'p27'], description='transmembrane p24 trafficking protein 7', other_designations='transmembrane emp24 domain-containing protein 7|p24 family protein gamma-3|transmembrane emp24 protein transport domain containing 7', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115613210, end_position_on_the_genomic_accession=115626036, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    51015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51015, CurrentID=0, Status='live', Symbol='ISOC1', Aliases=['CGI-111'], description='isochorismatase domain containing 1', other_designations='isochorismatase domain-containing protein 1', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=129094749, end_position_on_the_genomic_accession=129114028, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    51016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51016, CurrentID=0, Status='live', Symbol='EMC9', Aliases=['C14orf122', 'CGI-112', 'FAM158A'], description='ER membrane protein complex subunit 9', other_designations='ER membrane protein complex subunit 9|UPF0172 protein FAM158A|family with sequence similarity 158, member A', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24138959, end_position_on_the_genomic_accession=24142602, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    51018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51018, CurrentID=0, Status='live', Symbol='RRP15', Aliases=['CGI-115', 'KIAA0507'], description='ribosomal RNA processing 15 homolog', other_designations='RRP15-like protein|ribosomal RNA-processing protein 15', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=218285293, end_position_on_the_genomic_accession=218337983, orientation='plus', exon_count=6, OMIM=[611193], no_hdr0=''),
    51019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51019, CurrentID=0, Status='live', Symbol='WASHC3', Aliases=['CCDC53', 'CGI-116'], description='WASH complex subunit 3', other_designations='WASH complex subunit 3|WASH complex subunit CCDC53|coiled-coil domain containing 53|coiled-coil domain-containing protein 53', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102012840, end_position_on_the_genomic_accession=102062124, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    51020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51020, CurrentID=0, Status='live', Symbol='HDDC2', Aliases=['C6orf74', 'CGI-130', 'NS5ATP2', 'dJ167O5.2'], description='HD domain containing 2', other_designations="5'-deoxynucleotidase HDDC2|HCV NS5A-transactivated protein 2|HD domain-containing protein 2|hepatitis C virus NS5A-transactivated protein 2|testicular tissue protein Li 83", map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125275350, end_position_on_the_genomic_accession=125302066, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    51021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51021, CurrentID=0, Status='live', Symbol='MRPS16', Aliases=['CGI-132', 'COXPD2', 'MRP-S16', 'RPMS16'], description='mitochondrial ribosomal protein S16', other_designations='28S ribosomal protein S16, mitochondrial|S16mt|mitochondrial small ribosomal subunit protein bS16m', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73248849, end_position_on_the_genomic_accession=73252644, orientation='minus', exon_count=3, OMIM=[609204], no_hdr0=''),
    51022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51022, CurrentID=0, Status='live', Symbol='GLRX2', Aliases=['CGI-133', 'GRX2'], description='glutaredoxin 2', other_designations='glutaredoxin 2|bA101E13.1 (GRX2 glutaredoxin (thioltransferase) 2)|glutaredoxin (thioltransferase) 2', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=193096465, end_position_on_the_genomic_accession=193106114, orientation='minus', exon_count=5, OMIM=[606820], no_hdr0=''),
    51023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51023, CurrentID=0, Status='live', Symbol='MRPS18C', Aliases=['CGI-134', 'MRP-S18-1', 'MRP-S18-c', 'MRPS18-1', 'S18mt-c', 'mrps18-c'], description='mitochondrial ribosomal protein S18C', other_designations='28S ribosomal protein S18c, mitochondrial|28S ribosomal protein S18-1, mitochondrial|mitochondrial ribosomal protein S18-1|mitochondrial small ribosomal subunit protein bS18c|mitochondrial small ribosomal subunit protein bS18m|mitochondrial small ribosomal subunit protein bS18m-C', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83456058, end_position_on_the_genomic_accession=83462298, orientation='plus', exon_count=6, OMIM=[611983], no_hdr0=''),
    51024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51024, CurrentID=0, Status='live', Symbol='FIS1', Aliases=['CGI-135', 'TTC11'], description='fission, mitochondrial 1', other_designations='mitochondrial fission 1 protein|FIS1 homolog|H_NH0132A01.6|TPR repeat protein 11|fission 1 (mitochondrial outer membrane) homolog|hFis1|mitochondrial fission molecule|tetratricopeptide repeat domain 11|tetratricopeptide repeat protein 11', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101239472, end_position_on_the_genomic_accession=101245081, orientation='minus', exon_count=5, OMIM=[609003], no_hdr0=''),
    51025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51025, CurrentID=0, Status='live', Symbol='PAM16', Aliases=['CGI-136', 'MAGMAS', 'SMDMDM', 'TIM16', 'TIMM16'], description='presequence translocase associated motor 16', other_designations='mitochondrial import inner membrane translocase subunit TIM16|magmas-like protein|mitochondria associated protein involved in granulocyte macrophage colony stimulating factor signal transduction|mitochondria-associated granulocyte macrophage CSF-signaling molecule|presequence translocase associated motor 16 homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4340251, end_position_on_the_genomic_accession=4351321, orientation='minus', exon_count=5, OMIM=[614336], no_hdr0=''),
    51026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51026, CurrentID=0, Status='live', Symbol='GOLT1B', Aliases=['CGI-141', 'GCT2', 'GOT1', 'GOT1B', 'YMR292W'], description='golgi transport 1B', other_designations='vesicle transport protein GOT1B|germ cell tumor 2|hGOT1a|putative NF-kappa-B-activating protein 470', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21501176, end_position_on_the_genomic_accession=21518408, orientation='plus', exon_count=6, OMIM=[615078], no_hdr0=''),
    51027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51027, CurrentID=0, Status='live', Symbol='BOLA1', Aliases=['CGI-143'], description='bolA family member 1', other_designations='bolA-like protein 1|bolA homolog 1|bolA-like 1', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149899568, end_position_on_the_genomic_accession=149900795, orientation='plus', exon_count=2, OMIM=[613181], no_hdr0=''),
    51028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51028, CurrentID=0, Status='live', Symbol='VPS36', Aliases=['C13orf9', 'CGI-145', 'EAP45'], description='vacuolar protein sorting 36 homolog', other_designations='vacuolar protein-sorting-associated protein 36|ELL-associated protein of 45 kDa|ESCRT-II complex subunit VPS36', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52412606, end_position_on_the_genomic_accession=52450634, orientation='minus', exon_count=15, OMIM=[610903], no_hdr0=''),
    51029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51029, CurrentID=0, Status='live', Symbol='DESI2', Aliases=['C1orf121', 'CGI-146', 'DESI', 'DESI1', 'DeSI-2', 'FAM152A', 'PNAS-4', 'PPPDE1'], description='desumoylating isopeptidase 2', other_designations='deubiquitinase DESI2|PPPDE peptidase domain-containing protein 1|desumoylating isopeptidase 1|family with sequence similarity 152, member A', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244652760, end_position_on_the_genomic_accession=244709033, orientation='plus', exon_count=8, OMIM=[614638], no_hdr0=''),
    51030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51030, CurrentID=0, Status='live', Symbol='TVP23B', Aliases=['CGI-148', 'FAM18B', 'FAM18B1', 'NPD008', 'YDR084C'], description='trans-golgi network vesicle protein 23 homolog B', other_designations='Golgi apparatus membrane protein TVP23 homolog B|family with sequence similarity 18, member B|family with sequence similarity 18, member B1|protein FAM18B1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18781183, end_position_on_the_genomic_accession=18806714, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    51031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51031, CurrentID=0, Status='live', Symbol='GLOD4', Aliases=['C17orf25', 'CGI-150', 'HC71'], description='glyoxalase domain containing 4', other_designations='glyoxalase domain-containing protein 4', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=759321, end_position_on_the_genomic_accession=789830, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    51032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51032, CurrentID=0, Status='live', Symbol='CELA2B', Aliases=['ELA2B'], description='chymotrypsin like elastase 2B', other_designations='chymotrypsin-like elastase family member 2B|RP11-265F14.2|chymotrypsin like elastase family member 2B|elastase 2B|pancreatic elastase IIB (ELA2B)', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15476104, end_position_on_the_genomic_accession=15491395, orientation='plus', exon_count=8, OMIM=[609444], no_hdr0=''),
    51035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51035, CurrentID=0, Status='live', Symbol='UBXN1', Aliases=['2B28', 'SAKS1', 'UBXD10'], description='UBX domain protein 1', other_designations='UBX domain-containing protein 1|SAPK substrate protein 1|UBA/UBX 33.3 kDa protein', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62676500, end_position_on_the_genomic_accession=62679116, orientation='minus', exon_count=9, OMIM=[616378], no_hdr0=''),
    51042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51042, CurrentID=0, Status='live', Symbol='ZNF593', Aliases=['ZT86'], description='zinc finger protein 593', other_designations='zinc finger protein 593|zinc finger protein T86', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26169908, end_position_on_the_genomic_accession=26170873, orientation='plus', exon_count=3, OMIM=[616698], no_hdr0=''),
    51043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51043, CurrentID=0, Status='live', Symbol='ZBTB7B', Aliases=['CKROX', 'THPOK', 'ZBTB15', 'ZFP-67', 'ZFP67', 'ZNF857B', 'c-KROX', 'hcKROX'], description='zinc finger and BTB domain containing 7B', other_designations='zinc finger and BTB domain-containing protein 7B|T-helper-inducing POZ/Krueppel-like factor|krueppel-related zinc finger protein cKrox|zinc finger and BTB domain containing 15|zinc finger protein 67 homolog|zinc finger protein 857B|zinc finger protein Th-POK', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155002628, end_position_on_the_genomic_accession=155018523, orientation='plus', exon_count=8, OMIM=[607646], no_hdr0=''),
    51046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51046, CurrentID=0, Status='live', Symbol='ST8SIA3', Aliases=['SIAT8C', 'ST8SiaIII'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 3', other_designations='sia-alpha-2,3-Gal-beta-1,4-GlcNAc-R:alpha 2,8-sialyltransferase|SIAT8-C|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 3|alpha-2,8-sialyltransferase 8C|alpha-2,8-sialyltransferase III|sialyltransferase 8C (alpha2,3Galbeta1,4GlcNAcalpha 2,8-sialyltransferase)|sialyltransferase St8Sia III|sialytransferase St8Sia III', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57352557, end_position_on_the_genomic_accession=57368931, orientation='plus', exon_count=4, OMIM=[609478], no_hdr0=''),
    51050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51050, CurrentID=0, Status='live', Symbol='PI15', Aliases=['CRISP8', 'P24TI', 'P25TI'], description='peptidase inhibitor 15', other_designations='peptidase inhibitor 15|25 kDa trypsin inhibitor|CRISP-8|PI-15|cysteine-rich secretory protein 8|protease inhibitor 15|sugarCrisp', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=74824534, end_position_on_the_genomic_accession=74855029, orientation='plus', exon_count=6, OMIM=[607076], no_hdr0=''),
    51052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51052, CurrentID=0, Status='live', Symbol='PRLH', Aliases=['PRH', 'PRRP'], description='prolactin releasing hormone', other_designations='prolactin-releasing peptide|preproprolactin-releasing peptide', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237566574, end_position_on_the_genomic_accession=237567175, orientation='plus', exon_count=2, OMIM=[602663], no_hdr0=''),
    51053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51053, CurrentID=0, Status='live', Symbol='GMNN', Aliases=['Gem', 'MGORS6'], description='geminin DNA replication inhibitor', other_designations='geminin', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24774937, end_position_on_the_genomic_accession=24786099, orientation='plus', exon_count=9, OMIM=[602842], no_hdr0=''),
    51056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51056, CurrentID=0, Status='live', Symbol='LAP3', Aliases=['HEL-S-106', 'LAP', 'LAPEP', 'PEPS'], description='leucine aminopeptidase 3', other_designations='cytosol aminopeptidase|cysteinylglycine-S-conjugate dipeptidase|epididymis secretory protein Li 106|leucyl aminopeptidase|peptidase S|proline aminopeptidase|prolyl aminopeptidase', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17577198, end_position_on_the_genomic_accession=17607970, orientation='plus', exon_count=13, OMIM=[170250], no_hdr0=''),
    51057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51057, CurrentID=0, Status='live', Symbol='WDPCP', Aliases=['BBS15', 'C2orf86', 'CHDTHP', 'CPLANE5', 'FRITZ', 'FRTZ'], description='WD repeat containing planar cell polarity effector', other_designations='WD repeat-containing and planar cell polarity effector protein fritz homolog|Bardet-Biedl syndrome 15 protein|WD repeat-containing protein C2orf86|ciliogenesis and planar polarity effector 5', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=63119559, end_position_on_the_genomic_accession=63588733, orientation='minus', exon_count=25, OMIM=[613580], no_hdr0=''),
    51058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51058, CurrentID=0, Status='live', Symbol='ZNF691', Aliases=['Zfp691'], description='zinc finger protein 691', other_designations='zinc finger protein 691', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42846563, end_position_on_the_genomic_accession=42852477, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    51059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51059, CurrentID=0, Status='live', Symbol='FAM135B', Aliases=['C8ORFK32'], description='family with sequence similarity 135 member B', other_designations='protein FAM135B', map_location='8q24.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=138130023, end_position_on_the_genomic_accession=138497730, orientation='minus', exon_count=30, OMIM=[], no_hdr0=''),
    51060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51060, CurrentID=0, Status='live', Symbol='TXNDC12', Aliases=['AG1', 'AGR1', 'ERP16', 'ERP18', 'ERP19', 'PDIA16', 'TLP19', 'hAG-1', 'hTLP19'], description='thioredoxin domain containing 12', other_designations='thioredoxin domain-containing protein 12|ER protein 18|ER protein 19|anterior gradient homolog 1|endoplasmic reticulum protein ERp19|endoplasmic reticulum resident protein 18|endoplasmic reticulum resident protein 19|endoplasmic reticulum thioredoxin superfamily member, 18 kDa|protein disulfide isomerase family A, member 16|thioredoxin domain containing 12 (endoplasmic reticulum)|thioredoxin-like protein p19', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52020131, end_position_on_the_genomic_accession=52056171, orientation='minus', exon_count=8, OMIM=[609448], no_hdr0=''),
    51061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51061, CurrentID=0, Status='live', Symbol='TXNDC11', Aliases=['EFP1'], description='thioredoxin domain containing 11', other_designations='thioredoxin domain-containing protein 11|EF-hand binding protein 1', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11679080, end_position_on_the_genomic_accession=11742857, orientation='minus', exon_count=14, OMIM=[617792], no_hdr0=''),
    51062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51062, CurrentID=0, Status='live', Symbol='ATL1', Aliases=['AD-FSP', 'FSP1', 'GBP3', 'HSN1D', 'SPG3', 'SPG3A', 'atlastin1'], description='atlastin GTPase 1', other_designations='atlastin-1|GBP-3|GTP-binding protein 3|brain-specific GTP-binding protein|guanine nucleotide-binding protein 3|guanylate-binding protein 3|hGBP3|spastic paraplegia 3 protein A', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50533082, end_position_on_the_genomic_accession=50633068, orientation='plus', exon_count=15, OMIM=[606439], no_hdr0=''),
    51063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51063, CurrentID=0, Status='live', Symbol='CALHM2', Aliases=['FAM26B'], description='calcium homeostasis modulator family member 2', other_designations='calcium homeostasis modulator protein 2|calcium homeostasis modulator 2|family with sequence similarity 26, member B', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103446783, end_position_on_the_genomic_accession=103452403, orientation='minus', exon_count=4, OMIM=[612235], no_hdr0=''),
    51065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51065, CurrentID=0, Status='live', Symbol='RPS27L', Aliases=[], description='ribosomal protein S27 like', other_designations='40S ribosomal protein S27-like|small ribosomal subunit protein eS27-like', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63148249, end_position_on_the_genomic_accession=63157477, orientation='minus', exon_count=4, OMIM=[612055], no_hdr0=''),
    51066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51066, CurrentID=0, Status='live', Symbol='SSUH2', Aliases=['C3orf32', 'SSU-2', 'fls485'], description='ssu-2 homolog', other_designations='protein SSUH2 homolog|protein ssu-2 homolog', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8619386, end_position_on_the_genomic_accession=8745035, orientation='minus', exon_count=32, OMIM=[617479], no_hdr0=''),
    51067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51067, CurrentID=0, Status='live', Symbol='YARS2', Aliases=['CGI-04', 'MLASA2', 'MT-TYRRS', 'TYRRS'], description='tyrosyl-tRNA synthetase 2', other_designations='tyrosine--tRNA ligase, mitochondrial|tyrosine tRNA ligase 2, mitochondrial|tyrosyl-tRNA synthetase 2, mitochondrial', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=32725247, end_position_on_the_genomic_accession=32756458, orientation='minus', exon_count=8, OMIM=[610957], no_hdr0=''),
    51068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51068, CurrentID=0, Status='live', Symbol='NMD3', Aliases=['CGI-07'], description='NMD3 ribosome export adaptor', other_designations='60S ribosomal export protein NMD3|NMD3 homolog|hNMD3', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=161221292, end_position_on_the_genomic_accession=161253532, orientation='plus', exon_count=17, OMIM=[611021], no_hdr0=''),
    51069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51069, CurrentID=0, Status='live', Symbol='MRPL2', Aliases=['CGI-22', 'MRP-L14', 'RPML14'], description='mitochondrial ribosomal protein L2', other_designations='39S ribosomal protein L2, mitochondrial|L2mt|MRP-L2|mitochondrial large ribosomal subunit protein uL2m', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43054029, end_position_on_the_genomic_accession=43060180, orientation='minus', exon_count=8, OMIM=[611822], no_hdr0=''),
    51070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51070, CurrentID=0, Status='live', Symbol='NOSIP', Aliases=['CGI-25'], description='nitric oxide synthase interacting protein', other_designations='nitric oxide synthase-interacting protein|E3 ubiquitin-protein ligase NOSIP|RING-type E3 ubiquitin transferase NOSIP|eNOS-interacting protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49555468, end_position_on_the_genomic_accession=49580556, orientation='minus', exon_count=13, OMIM=[616759], no_hdr0=''),
    51071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51071, CurrentID=0, Status='live', Symbol='DERA', Aliases=['CGI-26', 'DEOC'], description='deoxyribose-phosphate aldolase', other_designations='deoxyribose-phosphate aldolase|2-deoxy-D-ribose 5-phosphate aldolase|2-deoxyribose-5-phosphate aldolase homolog|deoxyriboaldolase|deoxyribose-phosphate aldolase (putative)|phosphodeoxyriboaldolase|putative deoxyribose-phosphate aldolase', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=15911332, end_position_on_the_genomic_accession=16037381, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    51072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51072, CurrentID=0, Status='live', Symbol='MEMO1', Aliases=['C2orf4', 'CGI-27', 'MEMO', 'NS5ATP7'], description='mediator of cell motility 1', other_designations='protein MEMO1|C21orf19-like protein|HCV NS5A-transactivated protein 7|hepatitis C virus NS5A-transactivated protein 7|mediator of ErbB2-driven cell motility 1', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=31867188, end_position_on_the_genomic_accession=32011008, orientation='minus', exon_count=15, OMIM=[611786], no_hdr0=''),
    51073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51073, CurrentID=0, Status='live', Symbol='MRPL4', Aliases=['CGI-28', 'L4mt'], description='mitochondrial ribosomal protein L4', other_designations='39S ribosomal protein L4, mitochondrial|MRP-L4|mitochondrial large ribosomal subunit protein uL4m', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10251951, end_position_on_the_genomic_accession=10260055, orientation='plus', exon_count=10, OMIM=[611823], no_hdr0=''),
    51074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51074, CurrentID=0, Status='live', Symbol='APIP', Aliases=['APIP2', 'CGI-29', 'CGI29', 'MMRP19', 'hAPIP'], description='APAF1 interacting protein', other_designations='methylthioribulose-1-phosphate dehydratase|MTRu-1-P dehydratase|probable methylthioribulose-1-phosphate dehydratase', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34882295, end_position_on_the_genomic_accession=34916411, orientation='minus', exon_count=9, OMIM=[612491], no_hdr0=''),
    51075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51075, CurrentID=0, Status='live', Symbol='TMX2', Aliases=['CGI-31', 'NEDMCMS', 'PDIA12', 'PIG26', 'TXNDC14'], description='thioredoxin related transmembrane protein 2', other_designations='thioredoxin-related transmembrane protein 2|cell proliferation-inducing gene 26 protein|growth-inhibiting gene 11|protein disulfide isomerase family A, member 12|thioredoxin domain-containing protein 14', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57712593, end_position_on_the_genomic_accession=57740973, orientation='plus', exon_count=9, OMIM=[616715], no_hdr0=''),
    51076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51076, CurrentID=0, Status='live', Symbol='CUTC', Aliases=['CGI-32'], description='cutC copper transporter', other_designations='copper homeostasis protein cutC homolog|cutC copper transporter homolog', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99732234, end_position_on_the_genomic_accession=99756134, orientation='plus', exon_count=9, OMIM=[610101], no_hdr0=''),
    51077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51077, CurrentID=0, Status='live', Symbol='FCF1', Aliases=['Bka', 'C14orf111', 'CGI-35', 'UTP24'], description='FCF1 rRNA-processing protein', other_designations='rRNA-processing protein FCF1 homolog|FCF1 small subunit', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74713118, end_position_on_the_genomic_accession=74738620, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    51078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51078, CurrentID=0, Status='live', Symbol='THAP4', Aliases=['CGI-36', 'Nb(III)', 'PP238'], description='THAP domain containing 4', other_designations='peroxynitrite isomerase THAP4|THAP domain-containing protein 4|epididymis secretory sperm binding protein|nitrobindin', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241584405, end_position_on_the_genomic_accession=241637543, orientation='minus', exon_count=8, OMIM=[612533], no_hdr0=''),
    51079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51079, CurrentID=0, Status='live', Symbol='NDUFA13', Aliases=['B16.6', 'CDA016', 'CGI-39', 'GRIM-19', 'GRIM19', 'MC1DN28'], description='NADH:ubiquinone oxidoreductase subunit A13', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 13|CI-B16.6|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 13|NADH-ubiquinone oxidoreductase B16.6 subunit|cell death regulatory protein GRIM-19|cell death-regulatory protein GRIM19|complex I B16.6 subunit|complex I-B16.6|gene associated with retinoic and IFN-induced mortality 19 protein|gene associated with retinoic and interferon-induced mortality 19 protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19516225, end_position_on_the_genomic_accession=19528198, orientation='plus', exon_count=5, OMIM=[609435], no_hdr0=''),
    51081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51081, CurrentID=0, Status='live', Symbol='MRPS7', Aliases=['COXPD34', 'MRP-S', 'MRP-S7', 'RP-S7', 'RPMS7', 'S7mt', 'bMRP27a'], description='mitochondrial ribosomal protein S7', other_designations='28S ribosomal protein S7, mitochondrial|30S ribosomal protein S7 homolog|bMRP-27a|mitochondrial small ribosomal subunit protein uS7m', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75261879, end_position_on_the_genomic_accession=75266376, orientation='plus', exon_count=5, OMIM=[611974], no_hdr0=''),
    51082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51082, CurrentID=0, Status='live', Symbol='POLR1D', Aliases=['AC19', 'POLR1C', 'RPA16', 'RPA9', 'RPAC2', 'RPC16', 'RPO1-3', 'TCS2'], description='RNA polymerase I and III subunit D', other_designations='DNA-directed RNA polymerases I and III subunit RPAC2|Protein POLR1D|DNA-directed RNA polymerase I subunit D|RNA polymerase I subunit D|RNA polymerases I and III subunit AC2|polymerase (RNA) I polypeptide D, 16kDa|polymerase (RNA) I subunit D', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27620743, end_position_on_the_genomic_accession=27667415, orientation='plus', exon_count=6, OMIM=[613715], no_hdr0=''),
    51083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51083, CurrentID=0, Status='live', Symbol='GAL', Aliases=['ETL8-GMAP', 'GALN', 'GLNN', 'GMAP', 'GAL'], description='galanin and GMAP prepropeptide', other_designations='galanin peptides|galanin prepropeptide|galanin-message-associated peptide|galanin-related peptide|galanin/GMAP prepropeptide', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68684544, end_position_on_the_genomic_accession=68691175, orientation='plus', exon_count=6, OMIM=[137035], no_hdr0=''),
    51084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51084, CurrentID=0, Status='live', Symbol='CRYL1', Aliases=['GDH', 'HEL30', 'gul3DH', 'lambda-CRY'], description='crystallin lambda 1', other_designations='lambda-crystallin homolog|L-gulonate 3-dehydrogenase|crystallin, lamda 1|epididymis luminal protein 30|testicular tissue protein Li 44', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20403669, end_position_on_the_genomic_accession=20525857, orientation='minus', exon_count=10, OMIM=[609877], no_hdr0=''),
    51085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51085, CurrentID=0, Status='live', Symbol='MLXIPL', Aliases=['CHREBP', 'MIO', 'MLX', 'MONDOB', 'WBSCR14', 'WS-bHLH', 'bHLHd14'], description='MLX interacting protein like', other_designations='carbohydrate-responsive element-binding protein|Mlx interactor|WS basic-helix-loop-helix leucine zipper protein|Williams Beuren syndrome chromosome region 14|Williams-Beuren syndrome chromosome region 14 protein 1|Williams-Beuren syndrome chromosome region 14 protein 2|Williams-Beuren syndrome chromosome region 14 protein 3|carbohydrate response element binding protein|class D basic helix-loop-helix protein 14|williams-Beuren syndrome chromosomal region 14 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73593201, end_position_on_the_genomic_accession=73624522, orientation='minus', exon_count=18, OMIM=[605678], no_hdr0=''),
    51086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51086, CurrentID=0, Status='live', Symbol='TNNI3K', Aliases=['CARK', 'CCDD'], description='TNNI3 interacting kinase', other_designations='serine/threonine-protein kinase TNNI3K|cardiac ankyrin repeat kinase|cardiac troponin I-interacting kinase', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74235387, end_position_on_the_genomic_accession=74544428, orientation='plus', exon_count=25, OMIM=[613932], no_hdr0=''),
    51087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51087, CurrentID=0, Status='live', Symbol='YBX2', Aliases=['CONTRIN', 'CSDA3', 'DBPC', 'MSY2'], description='Y-box binding protein 2', other_designations='Y-box-binding protein 2|DNA-binding protein C|epididymis secretory sperm binding protein|germ cell specific Y-box binding protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7288254, end_position_on_the_genomic_accession=7294639, orientation='minus', exon_count=10, OMIM=[611447], no_hdr0=''),
    51088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51088, CurrentID=0, Status='live', Symbol='KLHL5', Aliases=[], description='kelch like family member 5', other_designations='kelch-like protein 5|lymphocyte activation-associated protein', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39044674, end_position_on_the_genomic_accession=39143101, orientation='plus', exon_count=16, OMIM=[608064], no_hdr0=''),
    51090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51090, CurrentID=0, Status='live', Symbol='PLLP', Aliases=['PMLP', 'TM4SF11'], description='plasmolipin', other_designations='plasmolipin|plasma membrane proteolipid (plasmolipin)|transmembrane 4 superfamily member 11 (plasmolipin)', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57256097, end_position_on_the_genomic_accession=57284672, orientation='minus', exon_count=4, OMIM=[600340], no_hdr0=''),
    51091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51091, CurrentID=0, Status='live', Symbol='SEPSECS', Aliases=['LP', 'PCH2D', 'SLA', 'SLA/LP'], description='Sep (O-phosphoserine) tRNA:Sec (selenocysteine) tRNA synthase', other_designations='O-phosphoseryl-tRNA(Sec) selenium transferase|SLA-p35|SLA/LP autoantigen|UGA suppressor tRNA-associated protein|liver-pancreas antigen|soluble liver antigen|soluble liver antigen/liver pancreas antigen|tRNA(Ser/Sec)-associated antigenic protein', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25120014, end_position_on_the_genomic_accession=25160546, orientation='minus', exon_count=13, OMIM=[613009], no_hdr0=''),
    51092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51092, CurrentID=0, Status='live', Symbol='SIDT2', Aliases=['CGI-40'], description='SID1 transmembrane family member 2', other_designations='SID1 transmembrane family member 2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117178743, end_position_on_the_genomic_accession=117197442, orientation='plus', exon_count=26, OMIM=[617551], no_hdr0=''),
    51093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51093, CurrentID=0, Status='live', Symbol='METTL25B', Aliases=['C1orf66', 'CGI-41', 'RRNAD1'], description='methyltransferase like 25B', other_designations='protein RRNAD1|ribosomal RNA adenine dimethylase domain containing 1|ribosomal RNA adenine dimethylase domain-containing protein 1', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156728469, end_position_on_the_genomic_accession=156736960, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    51094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51094, CurrentID=0, Status='live', Symbol='ADIPOR1', Aliases=['ACDCR1', 'CGI-45', 'CGI45', 'PAQR1', 'TESBP1A'], description='adiponectin receptor 1', other_designations='adiponectin receptor protein 1|progestin and adipoQ receptor family member 1|progestin and adipoQ receptor family member I', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202940825, end_position_on_the_genomic_accession=202958572, orientation='minus', exon_count=11, OMIM=[607945], no_hdr0=''),
    51095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51095, CurrentID=0, Status='live', Symbol='TRNT1', Aliases=['CCA1', 'CGI-47', 'MtCCA', 'RPEM', 'SIFD'], description='tRNA nucleotidyl transferase 1', other_designations='CCA tRNA nucleotidyltransferase 1, mitochondrial|ATP(CTP):tRNA nucleotidyltransferase|CCA-adding enzyme|mitochondrial CCA-adding tRNA-nucleotidyltransferase|mt CCA-adding enzyme|mt tRNA CCA-diphosphorylase|mt tRNA CCA-pyrophosphorylase|mt tRNA adenylyltransferase|tRNA CCA nucleotidyl transferase 1|tRNA nucleotidyl transferase, CCA-adding, 1|tRNA-nucleotidyltransferase 1, mitochondrial', map_location='3p26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=3126937, end_position_on_the_genomic_accession=3153435, orientation='plus', exon_count=11, OMIM=[612907], no_hdr0=''),
    51096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51096, CurrentID=0, Status='live', Symbol='UTP18', Aliases=['CGI-48', 'WDR50'], description='UTP18 small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 18 homolog|UTP18, small subunit (SSU) processome component, homolog|WD repeat domain 50|WD repeat-containing protein 50', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51260546, end_position_on_the_genomic_accession=51297933, orientation='plus', exon_count=16, OMIM=[612816], no_hdr0=''),
    51097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51097, CurrentID=0, Status='live', Symbol='SCCPDH', Aliases=['CGI-49', 'NET11'], description='saccharopine dehydrogenase (putative)', other_designations='saccharopine dehydrogenase-like oxidoreductase|epididymis secretory sperm binding protein|probable saccharopine dehydrogenase', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=246724409, end_position_on_the_genomic_accession=246768137, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    51098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51098, CurrentID=0, Status='live', Symbol='IFT52', Aliases=['C20orf9', 'CGI-53', 'NGD2', 'NGD5'], description='intraflagellar transport 52', other_designations='intraflagellar transport protein 52 homolog|protein NGD5 homolog', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43590937, end_position_on_the_genomic_accession=43647299, orientation='plus', exon_count=15, OMIM=[617094], no_hdr0=''),
    51099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51099, CurrentID=0, Status='live', Symbol='ABHD5', Aliases=['CGI58', 'IECN2', 'NCIE2'], description='abhydrolase domain containing 5, lysophosphatidic acid acyltransferase', other_designations='1-acylglycerol-3-phosphate O-acyltransferase ABHD5|abhydrolase domain-containing protein 5|lipid droplet-binding protein CGI-58|truncated abhydrolase domain-containing protein 5', map_location='3p21.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=43690870, end_position_on_the_genomic_accession=43734371, orientation='plus', exon_count=9, OMIM=[604780], no_hdr0=''),
    51100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51100, CurrentID=0, Status='live', Symbol='SH3GLB1', Aliases=['Bif-1', 'CGI-61', 'PPP1R70', 'dJ612B15.2'], description='SH3 domain containing GRB2 like, endophilin B1', other_designations='endophilin-B1|Bax-interacting factor 1|SH3 domain-containing GRB2-like protein B1|SH3-containing protein SH3GLB1|SH3-domain GRB2 like endophilin B1|protein phosphatase 1, regulatory subunit 70|testicular tissue protein Li 172', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86704570, end_position_on_the_genomic_accession=86748184, orientation='plus', exon_count=12, OMIM=[609287], no_hdr0=''),
    51101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51101, CurrentID=0, Status='live', Symbol='ZC2HC1A', Aliases=['C8orf70', 'CGI-62', 'FAM164A'], description='zinc finger C2HC-type containing 1A', other_designations='zinc finger C2HC domain-containing protein 1A|family with sequence similarity 164, member A|protein FAM164A', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=78666049, end_position_on_the_genomic_accession=78719765, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    51102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51102, CurrentID=0, Status='live', Symbol='MECR', Aliases=['CGI-63', 'DYTOABG', 'ETR1', 'FASN2B', 'NRBF1'], description='mitochondrial trans-2-enoyl-CoA reductase', other_designations='enoyl-[acyl-carrier-protein] reductase, mitochondrial|2-enoyl thioester reductase|homolog of yeast 2-enoyl thioester reductase|mitochondrial 2-enoyl thioester reductase|nuclear receptor binding factor 1|trans-2-enoyl-CoA reductase, mitochondrial', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=29192657, end_position_on_the_genomic_accession=29230948, orientation='minus', exon_count=15, OMIM=[608205], no_hdr0=''),
    51103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51103, CurrentID=0, Status='live', Symbol='NDUFAF1', Aliases=['CGI-65', 'CGI65', 'CIA30', 'MC1DN11'], description='NADH:ubiquinone oxidoreductase complex assembly factor 1', other_designations='complex I intermediate-associated protein 30, mitochondrial|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, assembly factor 1|NADH dehydrogenase (ubiquinone) complex I, assembly factor 1|NADH-ubiquinone oxidoreductase 1 alpha subcomplex, assembly factor 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41387353, end_position_on_the_genomic_accession=41402501, orientation='minus', exon_count=6, OMIM=[606934], no_hdr0=''),
    51104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51104, CurrentID=0, Status='live', Symbol='ABHD17B', Aliases=['C9orf77', 'CGI-67', 'FAM108B1'], description='abhydrolase domain containing 17B, depalmitoylase', other_designations='alpha/beta hydrolase domain-containing protein 17B|abhydrolase domain-containing protein 17B|abhydrolase domain-containing protein FAM108B1|epididymis secretory sperm binding protein|family with sequence similarity 108, member B1|protein ABHD17B', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=71862452, end_position_on_the_genomic_accession=71911536, orientation='minus', exon_count=8, OMIM=[617943], no_hdr0=''),
    51105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51105, CurrentID=0, Status='live', Symbol='PHF20L1', Aliases=['CGI-72', 'TDRD20B', 'URLC1'], description='PHD finger protein 20 like 1', other_designations='PHD finger protein 20-like protein 1|tudor domain containing 20B|tudor domain-containing protein PHF20L1|up-regulated in lung cancer 1', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132775371, end_position_on_the_genomic_accession=132848807, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    51106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51106, CurrentID=0, Status='live', Symbol='TFB1M', Aliases=['CGI-75', 'CGI75', 'mtTFB', 'mtTFB1'], description='transcription factor B1, mitochondrial', other_designations="dimethyladenosine transferase 1, mitochondrial|S-adenosylmethionine-6-N', N'-adenosyl(rRNA) dimethyltransferase 1|h-mtTFB1|hTFB1M|homolog of yeast mitochondrial transcription factor B|mitochondrial 12S rRNA dimethylase 1|mitochondrial dimethyladenosine transferase 1", map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=155229871, end_position_on_the_genomic_accession=155314497, orientation='minus', exon_count=15, OMIM=[607033], no_hdr0=''),
    51107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51107, CurrentID=0, Status='live', Symbol='APH1A', Aliases=['6530402N02Rik', 'APH-1', 'APH-1A', 'CGI-78'], description='aph-1 homolog A, gamma-secretase subunit', other_designations='gamma-secretase subunit APH-1A|APH1A gamma secretase subunit|anterior pharynx defective 1 homolog A|aph-1alpha|presenilin-stabilization factor', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150265404, end_position_on_the_genomic_accession=150282179, orientation='minus', exon_count=8, OMIM=[607629], no_hdr0=''),
    51108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51108, CurrentID=0, Status='live', Symbol='METTL9', Aliases=['CGI-81', 'DREV', 'DREV1', 'PAP1', 'hMETTL9'], description='methyltransferase like 9', other_designations='protein-L-histidine N-pros-methyltransferase|methyltransferase-like protein 9|CTB-31N19.3|DORA reverse strand protein 1|p53 activated protein 1', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21597208, end_position_on_the_genomic_accession=21657471, orientation='plus', exon_count=6, OMIM=[609388], no_hdr0=''),
    51109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51109, CurrentID=0, Status='live', Symbol='RDH11', Aliases=['ARSDR1', 'CGI82', 'HCBP12', 'MDT1', 'PSDR1', 'RALR1', 'RDJCSS', 'SCALD', 'SDR7C1'], description='retinol dehydrogenase 11', other_designations='retinol dehydrogenase 11|HCV core-binding protein HCBP12|androgen-regulated short-chain dehydrogenase/reductase 1|prostate short-chain dehydrogenase reductase 1|retinal reductase 1|retinol dehydrogenase 11 (all-trans/9-cis/11-cis)|short chain dehydrogenase/reductase family 7C, member 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67676800, end_position_on_the_genomic_accession=67695764, orientation='minus', exon_count=7, OMIM=[607849], no_hdr0=''),
    51110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51110, CurrentID=0, Status='live', Symbol='LACTB2', Aliases=['CGI-83'], description='lactamase beta 2', other_designations='endoribonuclease LACTB2|beta-lactamase-like protein 2|testicular secretory protein Li 23', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=70637266, end_position_on_the_genomic_accession=70669185, orientation='minus', exon_count=7, OMIM=[618921], no_hdr0=''),
    51111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51111, CurrentID=0, Status='live', Symbol='KMT5B', Aliases=['CGI-85', 'CGI85', 'MRD51', 'SUV420H1'], description='lysine methyltransferase 5B', other_designations='histone-lysine N-methyltransferase KMT5B|[histone H4]-N-methyl-L-lysine20 N-methyltransferase KMT5B|[histone H4]-lysine20 N-methyltransferase KMT5B|histone-lysine N-methyltransferase SUV420H1|lysine (K)-specific methyltransferase 5B|lysine N-methyltransferase 5B|lysine-specific methyltransferase 5B|su(var)4-20 homolog 1|suppressor of variegation 4-20 homolog 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68154863, end_position_on_the_genomic_accession=68213899, orientation='minus', exon_count=13, OMIM=[610881], no_hdr0=''),
    51112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51112, CurrentID=0, Status='live', Symbol='TRAPPC12', Aliases=['CGI-87', 'PEBAS', 'TTC-15', 'TTC15'], description='trafficking protein particle complex subunit 12', other_designations='trafficking protein particle complex subunit 12|TPR repeat protein 15|tetratricopeptide repeat domain 15|tetratricopeptide repeat protein 15|trafficking of membranes and mitosis|trafficking protein particle complex 12', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3379245, end_position_on_the_genomic_accession=3479571, orientation='plus', exon_count=20, OMIM=[614139], no_hdr0=''),
    51114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51114, CurrentID=0, Status='live', Symbol='ZDHHC9', Aliases=['CGI89', 'CXorf11', 'DHHC9', 'MMSA1', 'MRXSZ', 'ZDHHC10', 'ZNF379', 'ZNF380'], description='zinc finger DHHC-type palmitoyltransferase 9', other_designations='palmitoyltransferase ZDHHC9|Asp-His-His-Cys domain containing protein 9|antigen MMSA-1|zinc finger DHHC-type containing 9|zinc finger protein 379|zinc finger protein 380|zinc finger, DHHC domain containing 10', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129803288, end_position_on_the_genomic_accession=129843886, orientation='minus', exon_count=12, OMIM=[300646], no_hdr0=''),
    51115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51115, CurrentID=0, Status='live', Symbol='RMDN1', Aliases=['CGI-90', 'FAM82B', 'RMD-1', 'RMD1'], description='regulator of microtubule dynamics 1', other_designations='regulator of microtubule dynamics protein 1|family with sequence similarity 82, member B|microtubule-associated protein', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86467055, end_position_on_the_genomic_accession=86514357, orientation='minus', exon_count=15, OMIM=[611871], no_hdr0=''),
    51116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51116, CurrentID=0, Status='live', Symbol='MRPS2', Aliases=['CGI-91', 'COXPD36', 'MRP-S2', 'S2mt'], description='mitochondrial ribosomal protein S2', other_designations='28S ribosomal protein S2, mitochondrial|mitochondrial small ribosomal subunit protein uS2m', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135499965, end_position_on_the_genomic_accession=135504673, orientation='plus', exon_count=7, OMIM=[611971], no_hdr0=''),
    51117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51117, CurrentID=0, Status='live', Symbol='COQ4', Aliases=['CGI-92', 'COQ10D7'], description='coenzyme Q4', other_designations='ubiquinone biosynthesis protein COQ4 homolog, mitochondrial|coenzyme Q biosynthesis protein 4 homolog|coenzyme Q4 homolog', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128322486, end_position_on_the_genomic_accession=128334072, orientation='plus', exon_count=8, OMIM=[612898], no_hdr0=''),
    51118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51118, CurrentID=0, Status='live', Symbol='UTP11', Aliases=['CGI-94', 'CGI94L', 'UTP11'], description='UTP11 small subunit processome component', other_designations='probable U3 small nucleolar RNA-associated protein 11|U3 snoRNA-associated protein 11|UTP11, small subunit processome component homolog|UTP11-like protein|UTP11-like, U3 small nucleolar ribonucleoprotein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38012716, end_position_on_the_genomic_accession=38024820, orientation='plus', exon_count=8, OMIM=[609440], no_hdr0=''),
    51119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51119, CurrentID=0, Status='live', Symbol='SBDS', Aliases=['CGI-97', 'SDO1', 'SDS', 'SWDS'], description='SBDS ribosome maturation factor', other_designations='ribosome maturation protein SBDS|SBDS, ribosome assembly guanine nucleotide exchange factor', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66987680, end_position_on_the_genomic_accession=66995586, orientation='minus', exon_count=5, OMIM=[607444], no_hdr0=''),
    51121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51121, CurrentID=0, Status='live', Symbol='RPL26L1', Aliases=['RPL26P1'], description='ribosomal protein L26 like 1', other_designations='60S ribosomal protein L26-like 1|large ribosomal subunit protein uL24-like 1|ribosomal protein L26 homolog|ribosomal protein L26 pseudogene 1', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172953677, end_position_on_the_genomic_accession=172969771, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    51122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51122, CurrentID=0, Status='live', Symbol='COMMD2', Aliases=['HSPC042'], description='COMM domain containing 2', other_designations='COMM domain-containing protein 2', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149738472, end_position_on_the_genomic_accession=149752489, orientation='minus', exon_count=5, OMIM=[616699], no_hdr0=''),
    51123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51123, CurrentID=0, Status='live', Symbol='ZNF706', Aliases=['HSPC038', 'PNAS-106', 'PNAS-113'], description='zinc finger protein 706', other_designations='zinc finger protein 706', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=101197052, end_position_on_the_genomic_accession=101206470, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    51124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51124, CurrentID=0, Status='live', Symbol='IER3IP1', Aliases=['HSPC039', 'MEDS', 'PRO2309'], description='immediate early response 3 interacting protein 1', other_designations='immediate early response 3-interacting protein 1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47152834, end_position_on_the_genomic_accession=47176364, orientation='minus', exon_count=3, OMIM=[609382], no_hdr0=''),
    51125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51125, CurrentID=0, Status='live', Symbol='GOLGA7', Aliases=['GCP16', 'GOLGA3AP1A', 'HSPC041', 'GOLGA7'], description='golgin A7', other_designations='golgin subfamily A member 7|Golgi complex-associated protein of 16kDa|golgi autoantigen, golgin subfamily a, 7|golgi complex-associated protein of 16 kDa', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41490396, end_position_on_the_genomic_accession=41510980, orientation='plus', exon_count=7, OMIM=[609453], no_hdr0=''),
    51126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51126, CurrentID=0, Status='live', Symbol='NAA20', Aliases=['NAT3', 'NAT3P', 'NAT5', 'NAT5P', 'dJ1002M8.1'], description='N-alpha-acetyltransferase 20, NatB catalytic subunit', other_designations='N-alpha-acetyltransferase 20|N-acetyltransferase 3 homolog|N-acetyltransferase 5 (ARD1 homolog, S. cerevisiae)|N-acetyltransferase 5 (GCN5-related, putative)|N-acetyltransferase 5, ARD1 subunit (arrest-defective 1, S. cerevisiae, homolog)|N-terminal acetyltransferase B complex catalytic subunit NAA20|N-terminal acetyltransferase B complex catalytic subunit NAT5|N-terminal acetyltransferase complex ARD1 subunit|methionine N-acetyltransferase|natB catalytic subunit|natB complex subunit NAT5', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=20017290, end_position_on_the_genomic_accession=20033655, orientation='plus', exon_count=7, OMIM=[610833], no_hdr0=''),
    51127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51127, CurrentID=0, Status='live', Symbol='TRIM17', Aliases=['RBCC', 'RNF16', 'terf'], description='tripartite motif containing 17', other_designations='E3 ubiquitin-protein ligase TRIM17|RING finger protein terf|RING-type E3 ubiquitin transferase TRIM17|ring finger protein 16|testis RING finger protein|tripartite motif-containing protein 17', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228406877, end_position_on_the_genomic_accession=228416882, orientation='minus', exon_count=7, OMIM=[606123], no_hdr0=''),
    51128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51128, CurrentID=0, Status='live', Symbol='SAR1B', Aliases=['ANDD', 'CMRD', 'GTBPB', 'SARA2'], description='secretion associated Ras related GTPase 1B', other_designations='GTP-binding protein SAR1b|2310075M17Rik|GTP-binding protein B|GTP-binding protein Sara|SAR1 homolog B|SAR1a gene homolog 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134601149, end_position_on_the_genomic_accession=134632828, orientation='minus', exon_count=8, OMIM=[607690], no_hdr0=''),
    51129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51129, CurrentID=0, Status='live', Symbol='ANGPTL4', Aliases=['ARP4', 'FIAF', 'HARP', 'HFARP', 'NL2', 'PGAR', 'TGQTL', 'UNQ171', 'pp1158'], description='angiopoietin like 4', other_designations='angiopoietin-related protein 4|PPARG angiopoietin related protein|fasting-induced adipose factor|hepatic angiopoietin-related protein|hepatic fibrinogen/angiopoietin-related protein|peroxisome proliferator-activated receptor (PPAR) gamma induced angiopoietin-related protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8364129, end_position_on_the_genomic_accession=8374373, orientation='plus', exon_count=7, OMIM=[605910], no_hdr0=''),
    51130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51130, CurrentID=0, Status='live', Symbol='ASB3', Aliases=['ASB-3'], description='ankyrin repeat and SOCS box containing 3', other_designations='ankyrin repeat and SOCS box protein 3', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53669980, end_position_on_the_genomic_accession=53786953, orientation='minus', exon_count=10, OMIM=[605760], no_hdr0=''),
    51131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51131, CurrentID=0, Status='live', Symbol='PHF11', Aliases=['APY', 'BCAP', 'IGEL', 'IGER', 'IGHER', 'NY-REN-34', 'NYREN34'], description='PHD finger protein 11', other_designations='PHD finger protein 11|BRCA1 C-terminus-associated protein|IgE responsiveness (atopic)|renal carcinoma antigen NY-REN-34', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49495953, end_position_on_the_genomic_accession=49528992, orientation='plus', exon_count=13, OMIM=[607796], no_hdr0=''),
    51132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51132, CurrentID=0, Status='live', Symbol='RLIM', Aliases=['MRX61', 'NY-REN-43', 'RNF12', 'TOKAS'], description='ring finger protein, LIM domain interacting', other_designations='E3 ubiquitin-protein ligase RLIM|E3 ubiquitin-protein ligase RNF12|LIM domain-interacting RING finger protein|R-LIM|RING finger LIM domain-binding protein|RING-type E3 ubiquitin transferase RLIM|renal carcinoma antigen NY-REN-43|ring finger protein 12|ring zinc finger LIM domain binding protein|ring zinc finger protein NY-REN-43antigen', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=74582976, end_position_on_the_genomic_accession=74614624, orientation='minus', exon_count=5, OMIM=[300379], no_hdr0=''),
    51133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51133, CurrentID=0, Status='live', Symbol='KCTD3', Aliases=['NY-REN-45'], description='potassium channel tetramerization domain containing 3', other_designations='BTB/POZ domain-containing protein KCTD3|NY-REN-45 antigen|potassium channel tetramerisation domain containing 3|renal carcinoma antigen NY-REN-45', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=215567304, end_position_on_the_genomic_accession=215621807, orientation='plus', exon_count=18, OMIM=[613272], no_hdr0=''),
    51134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51134, CurrentID=0, Status='live', Symbol='CEP83', Aliases=['CCDC41', 'NPHP18', 'NY-REN-58'], description='centrosomal protein 83', other_designations='centrosomal protein of 83 kDa|NY-REN-58 antigen|coiled-coil domain-containing protein 41|renal carcinoma antigen NY-REN-58', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=94265652, end_position_on_the_genomic_accession=94460616, orientation='minus', exon_count=31, OMIM=[615847], no_hdr0=''),
    51135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51135, CurrentID=0, Status='live', Symbol='IRAK4', Aliases=['IMD67', 'IPD1', 'IRAK-4', 'NY-REN-64', 'REN64'], description='interleukin 1 receptor associated kinase 4', other_designations='interleukin-1 receptor-associated kinase 4|renal carcinoma antigen NY-REN-64', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=43758909, end_position_on_the_genomic_accession=43789543, orientation='plus', exon_count=19, OMIM=[606883], no_hdr0=''),
    51136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51136, CurrentID=0, Status='live', Symbol='RNFT1', Aliases=['PTD016'], description='ring finger protein, transmembrane 1', other_designations='E3 ubiquitin-protein ligase RNFT1|RING finger and transmembrane domain-containing protein 1', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59952240, end_position_on_the_genomic_accession=59964740, orientation='minus', exon_count=9, OMIM=[615172], no_hdr0=''),
    51138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51138, CurrentID=0, Status='live', Symbol='COPS4', Aliases=['CSN4', 'SGN4'], description='COP9 signalosome subunit 4', other_designations='COP9 signalosome complex subunit 4|COP9 constitutive photomorphogenic homolog subunit 4|COP9 constitutive photomorphogenic-like protein subunit 4|JAB1-containing signalosome subunit 4|signalosome subunit 4|testis tissue sperm-binding protein Li 42a', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83035183, end_position_on_the_genomic_accession=83075818, orientation='plus', exon_count=11, OMIM=[616008], no_hdr0=''),
    51141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51141, CurrentID=0, Status='live', Symbol='INSIG2', Aliases=['INSIG-2'], description='insulin induced gene 2', other_designations='insulin-induced gene 2 protein|INSIG2 membrane protein|insulin induced protein 2', map_location='2q14.1-q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=118088471, end_position_on_the_genomic_accession=118110997, orientation='plus', exon_count=7, OMIM=[608660], no_hdr0=''),
    51142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51142, CurrentID=0, Status='live', Symbol='CHCHD2', Aliases=['C7orf17', 'MIX17B', 'MNRR1', 'NS2TP', 'PARK22'], description='coiled-coil-helix-coiled-coil-helix domain containing 2', other_designations='coiled-coil-helix-coiled-coil-helix domain-containing protein 2|16.7kD protein|HCV NS2 trans-regulated protein|MIX17 homolog B|aging-associated gene 10 protein|coiled-coil-helix-coiled-coil-helix domain-containing protein 2, mitochondrial|mitochondria nuclear retrograde regulator 1|mitochondrial nuclear retrograde regulator 1', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56101573, end_position_on_the_genomic_accession=56106476, orientation='minus', exon_count=4, OMIM=[616244], no_hdr0=''),
    51143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51143, CurrentID=0, Status='live', Symbol='DYNC1LI1', Aliases=['DLC-A', 'DNCLI1', 'LIC1'], description='dynein cytoplasmic 1 light intermediate chain 1', other_designations='cytoplasmic dynein 1 light intermediate chain 1|dynein light chain A|dynein light intermediate chain 1, cytosolic|dynein, cytoplasmic, light intermediate polypeptide 1', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32525974, end_position_on_the_genomic_accession=32570858, orientation='minus', exon_count=13, OMIM=[615890], no_hdr0=''),
    51144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51144, CurrentID=0, Status='live', Symbol='HSD17B12', Aliases=['KAR', 'SDR12C1'], description='hydroxysteroid 17-beta dehydrogenase 12', other_designations='very-long-chain 3-oxoacyl-CoA reductase|17-beta-HSD 12|17-beta-hydroxysteroid dehydrogenase 12|17beta-HSD type 12|3-ketoacyl-CoA reductase|estradiol 17-beta-dehydrogenase 12|short chain dehydrogenase/reductase family 12C member 1|steroid dehydrogenase homolog', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=43576476, end_position_on_the_genomic_accession=43856617, orientation='plus', exon_count=17, OMIM=[609574], no_hdr0=''),
    51146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51146, CurrentID=0, Status='live', Symbol='A4GNT', Aliases=['alpha4GnT'], description='alpha-1,4-N-acetylglucosaminyltransferase', other_designations='alpha-1,4-N-acetylglucosaminyltransferase', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138123713, end_position_on_the_genomic_accession=138133310, orientation='minus', exon_count=4, OMIM=[616709], no_hdr0=''),
    51147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51147, CurrentID=0, Status='live', Symbol='ING4', Aliases=['my036', 'p29ING4'], description='inhibitor of growth family member 4', other_designations='inhibitor of growth protein 4|brain my036 protein|candidate tumor suppressor p33 ING1 homolog', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6650301, end_position_on_the_genomic_accession=6663143, orientation='minus', exon_count=9, OMIM=[608524], no_hdr0=''),
    51148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51148, CurrentID=0, Status='live', Symbol='CERCAM', Aliases=['CEECAM1', 'GLT25D3'], description='cerebral endothelial cell adhesion molecule', other_designations='inactive glycosyltransferase 25 family member 3|cerebral cell adhesion molecule|cerebral endothelial cell adhesion molecule 1|glycosyltransferase 25 domain containing 3|glycosyltransferase 25 family member 3|probable inactive glycosyltransferase 25 family member 3', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128405994, end_position_on_the_genomic_accession=128437351, orientation='plus', exon_count=21, OMIM=[616626], no_hdr0=''),
    51149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51149, CurrentID=0, Status='live', Symbol='MRNIP', Aliases=['C5orf45'], description='MRN complex interacting protein', other_designations='MRN complex-interacting protein|MRN-interacting protein|UPF0544 protein C5orf45', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179837276, end_position_on_the_genomic_accession=179858817, orientation='minus', exon_count=7, OMIM=[617154], no_hdr0=''),
    51150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51150, CurrentID=0, Status='live', Symbol='SDF4', Aliases=['Cab45', 'SDF-4'], description='stromal cell derived factor 4', other_designations='45 kDa calcium-binding protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1216908, end_position_on_the_genomic_accession=1232005, orientation='minus', exon_count=7, OMIM=[614282], no_hdr0=''),
    51151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51151, CurrentID=0, Status='live', Symbol='SLC45A2', Aliases=['1A1', 'AIM1', 'MATP', 'OCA4', 'SHEP5'], description='solute carrier family 45 member 2', other_designations='membrane-associated transporter protein|melanoma antigen AIM1|protein AIM-1|underwhite', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=33944623, end_position_on_the_genomic_accession=33984693, orientation='minus', exon_count=7, OMIM=[606202], no_hdr0=''),
    51154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51154, CurrentID=0, Status='live', Symbol='MRTO4', Aliases=['C1orf33', 'MRT4', 'dJ657E11.4'], description='MRT4 homolog, ribosome maturation factor', other_designations='mRNA turnover protein 4 homolog|60S acidic ribosomal protein PO|MRT4, mRNA turnover 4, homolog|MRTO4 ribosome maturation factor|mRNA turnover 4 homolog|ribosome assembly factor MRTO4', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19251799, end_position_on_the_genomic_accession=19260128, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    51155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51155, CurrentID=0, Status='live', Symbol='JPT1', Aliases=['ARM2', 'HN1', 'HN1A'], description='Jupiter microtubule associated homolog 1', other_designations='jupiter microtubule associated homolog 1|androgen-regulated protein 2|hematological and neurological expressed 1 protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75135243, end_position_on_the_genomic_accession=75154512, orientation='minus', exon_count=7, OMIM=[619242], no_hdr0=''),
    51156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51156, CurrentID=0, Status='live', Symbol='SERPINA10', Aliases=['PZI', 'ZPI'], description='serpin family A member 10', other_designations='protein Z-dependent protease inhibitor|PZ-dependent protease inhibitor|Protein-Z dependent proteinase inhibitor|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 10|serpin A10|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 10', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94280460, end_position_on_the_genomic_accession=94293353, orientation='minus', exon_count=7, OMIM=[605271], no_hdr0=''),
    51157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51157, CurrentID=0, Status='live', Symbol='ZNF580', Aliases=[], description='zinc finger protein 580', other_designations='zinc finger protein 580|LDL-induced EC protein', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55641002, end_position_on_the_genomic_accession=55643470, orientation='plus', exon_count=2, OMIM=[617888], no_hdr0=''),
    51160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51160, CurrentID=0, Status='live', Symbol='VPS28', Aliases=[], description='VPS28 subunit of ESCRT-I', other_designations='vacuolar protein sorting-associated protein 28 homolog|ESCRT-I complex subunit VPS28|VPS28, ESCRT-I subunit|vacuolar protein sorting 28 homolog|vacuolar protein sorting 28-like protein|yeast class E protein Vps28p homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144423617, end_position_on_the_genomic_accession=144428548, orientation='minus', exon_count=10, OMIM=[611952], no_hdr0=''),
    51161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51161, CurrentID=0, Status='live', Symbol='C3orf18', Aliases=['G20'], description='chromosome 3 open reading frame 18', other_designations='uncharacterized protein C3orf18', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50558025, end_position_on_the_genomic_accession=50574835, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    51162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51162, CurrentID=0, Status='live', Symbol='EGFL7', Aliases=['NEU1', 'VE-STATIN', 'ZNEU1'], description='EGF like domain multiple 7', other_designations='epidermal growth factor-like protein 7|EGF-like protein 7|NOTCH4-like protein|multiple EGF-like domains protein 7|multiple epidermal growth factor-like domains protein 7|vascular endothelial statin', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136654753, end_position_on_the_genomic_accession=136672678, orientation='plus', exon_count=14, OMIM=[608582], no_hdr0=''),
    51163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51163, CurrentID=0, Status='live', Symbol='DBR1', Aliases=[], description='debranching RNA lariats 1', other_designations='lariat debranching enzyme|RNA lariat debranching enzyme|debranching enzyme homolog 1', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138160988, end_position_on_the_genomic_accession=138174921, orientation='minus', exon_count=8, OMIM=[607024], no_hdr0=''),
    51164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51164, CurrentID=0, Status='live', Symbol='DCTN4', Aliases=['DYN4', 'P62'], description='dynactin subunit 4', other_designations='dynactin subunit 4|dynactin 4 (p62)|dynactin p62 subunit|dynactin subunit p62', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150708440, end_position_on_the_genomic_accession=150759095, orientation='minus', exon_count=19, OMIM=[614758], no_hdr0=''),
    51166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51166, CurrentID=0, Status='live', Symbol='AADAT', Aliases=['KAT2', 'KATII', 'KYAT2'], description='aminoadipate aminotransferase', other_designations='kynurenine/alpha-aminoadipate aminotransferase, mitochondrial|2-aminoadipate aminotransferase|2-aminoadipate transaminase|KAT/AadAT|L kynurenine/alpha aminoadipate aminotransferase|alpha-aminoadipate aminotransferase|kynurenine aminotransferase II|kynurenine--oxoglutarate aminotransferase II|kynurenine--oxoglutarate transaminase 2|kynurenine--oxoglutarate transaminase II', map_location='4q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=170060222, end_position_on_the_genomic_accession=170091699, orientation='minus', exon_count=17, OMIM=[611754], no_hdr0=''),
    51167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51167, CurrentID=0, Status='live', Symbol='CYB5R4', Aliases=['NCB5OR', 'cb5/cb5R', 'dJ676J13.1'], description='cytochrome b5 reductase 4', other_designations='cytochrome b5 reductase 4|N-terminal cytochrome b5 and cytochrome b5 oxidoreductase domain-containing protein|NADPH cytochrome B5 oxidoreductase|cytochrome b-type NAD(P)H oxidoreductase|flavohemoprotein b5+b5R|flavohemoprotein b5/b5R', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83859689, end_position_on_the_genomic_accession=83967423, orientation='plus', exon_count=16, OMIM=[608343], no_hdr0=''),
    51168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51168, CurrentID=0, Status='live', Symbol='MYO15A', Aliases=['DFNB3', 'MYO15'], description='myosin XVA', other_designations='unconventional myosin-XV|myosin-XV|unconventional myosin-15', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18108756, end_position_on_the_genomic_accession=18180244, orientation='plus', exon_count=67, OMIM=[602666], no_hdr0=''),
    51170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51170, CurrentID=0, Status='live', Symbol='HSD17B11', Aliases=['17-BETA-HSD11', '17-BETA-HSDXI', '17BHSD11', 'DHRS8', 'PAN1B', 'RETSDR2', 'SDR16C2'], description='hydroxysteroid 17-beta dehydrogenase 11', other_designations='estradiol 17-beta-dehydrogenase 11|17-beta-hydroxysteroid dehydrogenase type XI|CTCL tumor antigen HD-CL-03|CTCL-associated antigen HD-CL-03|cutaneous T-cell lymphoma-associated antigen HD-CL-03|dehydrogenase/reductase SDR family member 8|retinal short-chain dehydrogenase/reductase 2|short chain dehydrogenase/reductase family 16C member 2', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87336515, end_position_on_the_genomic_accession=87391252, orientation='minus', exon_count=8, OMIM=[612831], no_hdr0=''),
    51171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51171, CurrentID=0, Status='live', Symbol='HSD17B14', Aliases=['DHRS10', 'SDR47C1', 'retSDR3'], description='hydroxysteroid 17-beta dehydrogenase 14', other_designations='17-beta-hydroxysteroid dehydrogenase 14|17-beta-HSD 14|17-beta-hydroxysteroid dehydrogenase DHRS10|dehydrogenase/reductase (SDR family) member 10|retinal short-chain dehydrogenase/reductase 3|retinal short-chain dehydrogenase/reductase retSDR3|short chain dehydrogenase/reductase family 47C member 1|testicular tissue protein Li 52', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48813014, end_position_on_the_genomic_accession=48836688, orientation='minus', exon_count=9, OMIM=[612832], no_hdr0=''),
    51172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51172, CurrentID=0, Status='live', Symbol='NAGPA', Aliases=['APAA', 'UCE'], description='N-acetylglucosamine-1-phosphodiester alpha-N-acetylglucosaminidase', other_designations='N-acetylglucosamine-1-phosphodiester alpha-N-acetylglucosaminidase|alpha-N-acetylglucosaminyl phosphodiesterase|lysosomal alpha-N-acetylglucosaminidase|mannose 6-phosphate-uncovering enzyme|phosphodiester alpha-GlcNAcase', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=5024844, end_position_on_the_genomic_accession=5033940, orientation='minus', exon_count=11, OMIM=[607985], no_hdr0=''),
    51174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51174, CurrentID=0, Status='live', Symbol='TUBD1', Aliases=['TUBD'], description='tubulin delta 1', other_designations='tubulin delta chain|delta-tubulin', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59859467, end_position_on_the_genomic_accession=59892948, orientation='minus', exon_count=10, OMIM=[607344], no_hdr0=''),
    51175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51175, CurrentID=0, Status='live', Symbol='TUBE1', Aliases=['TUBE', 'dJ142L7.2'], description='tubulin epsilon 1', other_designations='tubulin epsilon chain|epsilon-tubulin', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=112070663, end_position_on_the_genomic_accession=112087529, orientation='minus', exon_count=13, OMIM=[607345], no_hdr0=''),
    51176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51176, CurrentID=0, Status='live', Symbol='LEF1', Aliases=['LEF-1', 'TCF10', 'TCF1ALPHA', 'TCF7L3'], description='lymphoid enhancer binding factor 1', other_designations='lymphoid enhancer-binding factor 1|T cell-specific transcription factor 1-alpha|TCF1-alpha', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=108047548, end_position_on_the_genomic_accession=108168932, orientation='minus', exon_count=14, OMIM=[153245], no_hdr0=''),
    51177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51177, CurrentID=0, Status='live', Symbol='PLEKHO1', Aliases=['CKIP-1', 'CKIP1', 'JBP', 'OC120'], description='pleckstrin homology domain containing O1', other_designations='pleckstrin homology domain-containing family O member 1|C-Jun-binding protein|CK2 interacting protein 1; HQ0024c protein|CK2-interacting protein 1|PH domain-containing family O member 1|casein kinase 2-interacting protein 1|osteoclast maturation-associated gene 120 protein', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150149565, end_position_on_the_genomic_accession=150160065, orientation='plus', exon_count=7, OMIM=[608335], no_hdr0=''),
    51179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51179, CurrentID=0, Status='live', Symbol='HAO2', Aliases=['GIG16', 'HAOX2'], description='hydroxyacid oxidase 2', other_designations='hydroxyacid oxidase 2|(S)-2-hydroxy-acid oxidase, peroxisomal|cell growth-inhibiting gene 16 protein|glycolate oxidase|hydroxyacid oxidase 2 (long chain)|long chain alpha-hydroxy acid oxidase|long-chain L-2-hydroxy acid oxidase', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119361913, end_position_on_the_genomic_accession=119394130, orientation='plus', exon_count=11, OMIM=[605176], no_hdr0=''),
    51181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51181, CurrentID=0, Status='live', Symbol='DCXR', Aliases=['DCR', 'HCR2', 'HCRII', 'KIDCR', 'P34H', 'PNTSU', 'SDR20C1', 'XR'], description='dicarbonyl and L-xylulose reductase', other_designations='L-xylulose reductase|carbonyl reductase 2|carbonyl reductase II|dicarbonyl/L-xylulose reductase|epididymis secretory sperm binding protein|human carbonyl reductase 2|kidney dicarbonyl reductase|short chain dehydrogenase/reductase family 20C member 1|sperm surface protein P34H', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82035858, end_position_on_the_genomic_accession=82037697, orientation='minus', exon_count=8, OMIM=[608347], no_hdr0=''),
    51182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51182, CurrentID=0, Status='live', Symbol='HSPA14', Aliases=['HSP70-4', 'HSP70L1'], description='heat shock protein family A (Hsp70) member 14', other_designations='heat shock 70 kDa protein 14|HSP70-like protein 1|heat shock protein HSP60|heat shock protein hsp70-related protein', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14838306, end_position_on_the_genomic_accession=14871741, orientation='plus', exon_count=14, OMIM=[610369], no_hdr0=''),
    51184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51184, CurrentID=0, Status='live', Symbol='GPN3', Aliases=['ATPBD1C'], description='GPN-loop GTPase 3', other_designations='GPN-loop GTPase 3|ATP-binding domain 1 family member C|protein x 0004', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110452486, end_position_on_the_genomic_accession=110468721, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    51185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51185, CurrentID=0, Status='live', Symbol='CRBN', Aliases=['MRT2', 'MRT2A'], description='cereblon', other_designations='protein cereblon|protein x 0001', map_location='3p26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=3148490, end_position_on_the_genomic_accession=3179717, orientation='minus', exon_count=12, OMIM=[609262], no_hdr0=''),
    51186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51186, CurrentID=0, Status='live', Symbol='TCEAL9', Aliases=['WBP5', 'WEX6'], description='transcription elongation factor A like 9', other_designations='transcription elongation factor A protein-like 9|TCEA-like protein 9|WBP-5|WW domain binding protein 1|WW domain-binding protein 5|pp21 homolog|transcription elongation factor S-II protein-like 9', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103356506, end_position_on_the_genomic_accession=103358462, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    51187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51187, CurrentID=0, Status='live', Symbol='RSL24D1', Aliases=['C15orf15', 'HRP-L30-iso', 'L30', 'RLP24', 'RPL24', 'RPL24L', 'TVAS3'], description='ribosomal L24 domain containing 1', other_designations='probable ribosome biogenesis protein RLP24|60S ribosomal protein L30 isolog|homolog of yeast ribosomal like protein 24|my024 protein|ribosomal L24 domain-containing protein 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55180806, end_position_on_the_genomic_accession=55196941, orientation='minus', exon_count=6, OMIM=[613262], no_hdr0=''),
    51188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51188, CurrentID=0, Status='live', Symbol='SS18L2', Aliases=['KIAA-iso'], description='SS18 like 2', other_designations='SS18-like protein 2|SYT homolog 2|synovial sarcoma translocation gene on chromosome 18-like 2', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42581840, end_position_on_the_genomic_accession=42596934, orientation='plus', exon_count=4, OMIM=[606473], no_hdr0=''),
    51191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51191, CurrentID=0, Status='live', Symbol='HERC5', Aliases=['CEB1', 'CEBP1'], description='HECT and RLD domain containing E3 ubiquitin protein ligase 5', other_designations='E3 ISG15--protein ligase HERC5|HECT domain and RCC1-like domain-containing protein 5|cyclin-E-binding protein 1|hect domain and RLD 5|probable E3 ubiquitin-protein ligase HERC5', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88456604, end_position_on_the_genomic_accession=88506170, orientation='plus', exon_count=23, OMIM=[608242], no_hdr0=''),
    51192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51192, CurrentID=0, Status='live', Symbol='CKLF', Aliases=['C321', 'CKLF2', 'CKLF3', 'CKLF4', 'HSPC224', 'UCK-1', 'CKLF'], description='chemokine like factor', other_designations='chemokine-like factor|chemokine-like factor 1|chemokine-like factor 2|chemokine-like factor 3|chemokine-like factor 4|transmembrane proteolipid', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66552563, end_position_on_the_genomic_accession=66566287, orientation='plus', exon_count=4, OMIM=[616074], no_hdr0=''),
    51193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51193, CurrentID=0, Status='live', Symbol='ZNF639', Aliases=['ANC-2H01', 'ANC_2H01', 'ZASC1'], description='zinc finger protein 639', other_designations='zinc finger protein 639|zinc finger amplified in esophageal squamous cell carcinomas 1', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179322876, end_position_on_the_genomic_accession=179338583, orientation='plus', exon_count=11, OMIM=[619214], no_hdr0=''),
    51194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51194, CurrentID=0, Status='live', Symbol='IPO11', Aliases=['RanBP11'], description='importin 11', other_designations='importin-11|Ran binding protein 11|imp11|ran-binding protein 11', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=62412763, end_position_on_the_genomic_accession=62628582, orientation='plus', exon_count=31, OMIM=[610889], no_hdr0=''),
    51195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51195, CurrentID=0, Status='live', Symbol='RAPGEFL1', Aliases=['Link-GEFII'], description='Rap guanine nucleotide exchange factor like 1', other_designations='rap guanine nucleotide exchange factor-like 1|Link guanine nucleotide exchange factor II|Rap guanine nucleotide exchange factor (GEF)-like 1|link GEFII', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40177010, end_position_on_the_genomic_accession=40195655, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    51196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51196, CurrentID=0, Status='live', Symbol='PLCE1', Aliases=['NPHS3', 'PLCE', 'PPLC'], description='phospholipase C epsilon 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase epsilon-1|PLC-epsilon-1|pancreas-enriched phospholipase C|phosphoinositide phospholipase C|phosphoinositide phospholipase C-epsilon-1|phosphoinositide-specific phospholipase C epsilon-1', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93993931, end_position_on_the_genomic_accession=94332823, orientation='plus', exon_count=39, OMIM=[608414], no_hdr0=''),
    51199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51199, CurrentID=0, Status='live', Symbol='NIN', Aliases=['SCKL7'], description='ninein', other_designations='ninein|glycogen synthase kinase 3 beta-interacting protein|hNinein|ninein (GSK3B interacting protein)|ninein centrosomal protein', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50719763, end_position_on_the_genomic_accession=50831162, orientation='minus', exon_count=35, OMIM=[608684], no_hdr0=''),
    51200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51200, CurrentID=0, Status='live', Symbol='CPA4', Aliases=['CPA3'], description='carboxypeptidase A4', other_designations='carboxypeptidase A4|carboxypeptidase A3', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130293161, end_position_on_the_genomic_accession=130324180, orientation='plus', exon_count=11, OMIM=[607635], no_hdr0=''),
    51201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51201, CurrentID=0, Status='live', Symbol='ZDHHC2', Aliases=['DHHC2', 'ZNF372'], description='zinc finger DHHC-type palmitoyltransferase 2', other_designations='palmitoyltransferase ZDHHC2|DHHC-2|acyltransferase ZDHHC2|ream|rec|reduced expression associated with metastasis protein|reduced expression in cancer protein|testis tissue sperm-binding protein Li 56e|zinc finger DHHC domain-containing protein 2|zinc finger DHHC-type containing 2|zinc finger protein 372|zinc finger, DHHC domain containing 2', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17156000, end_position_on_the_genomic_accession=17230706, orientation='plus', exon_count=17, OMIM=[618621], no_hdr0=''),
    51202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51202, CurrentID=0, Status='live', Symbol='DDX47', Aliases=['E4-DBP', 'HQ0256', 'MSTP162', 'RRP3'], description='DEAD-box helicase 47', other_designations='probable ATP-dependent RNA helicase DDX47|DEAD (Asp-Glu-Ala-Asp) box polypeptide 47|DEAD box polypeptide 47|DEAD box protein 47|E4-DEAD box protein', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12813346, end_position_on_the_genomic_accession=12829981, orientation='plus', exon_count=12, OMIM=[615428], no_hdr0=''),
    51203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51203, CurrentID=0, Status='live', Symbol='NUSAP1', Aliases=['ANKT', 'BM037', 'LNP', 'NUSAP', 'PRO0310p1', 'Q0310', 'SAPL'], description='nucleolar and spindle associated protein 1', other_designations='nucleolar and spindle-associated protein 1|nucleolar protein ANKT', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41332841, end_position_on_the_genomic_accession=41381050, orientation='plus', exon_count=11, OMIM=[612818], no_hdr0=''),
    51204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51204, CurrentID=0, Status='live', Symbol='TACO1', Aliases=['CCDC44', 'MC4DN8'], description='translational activator of cytochrome c oxidase I', other_designations='translational activator of cytochrome c oxidase 1|clone HQ0477 PRO0477p|coiled-coil domain-containing protein 44|translational activator of COX I|translational activator of mitochondrially encoded cytochrome c oxidase I', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63600895, end_position_on_the_genomic_accession=63608365, orientation='plus', exon_count=5, OMIM=[612958], no_hdr0=''),
    51205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51205, CurrentID=0, Status='live', Symbol='ACP6', Aliases=['ACPL1', 'LPAP', 'PACPL1'], description='acid phosphatase 6, lysophosphatidic', other_designations='lysophosphatidic acid phosphatase type 6|acid phosphatase-like protein 1', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147626182, end_position_on_the_genomic_accession=147670524, orientation='minus', exon_count=14, OMIM=[611471], no_hdr0=''),
    51206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51206, CurrentID=0, Status='live', Symbol='GP6', Aliases=['BDPLT11', 'GPIV', 'GPVI'], description='glycoprotein VI platelet', other_designations='platelet glycoprotein VI|glycoprotein 6|platelet collagen receptor', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55013705, end_position_on_the_genomic_accession=55038264, orientation='minus', exon_count=8, OMIM=[605546], no_hdr0=''),
    51207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51207, CurrentID=0, Status='live', Symbol='DUSP13', Aliases=['BEDPA', 'DUSP13B', 'MDSP', 'SKRP4', 'TMDP', 'DUSP13'], description='dual specificity phosphatase 13', other_designations='dual specificity protein phosphatase 13|branching-enzyme interacting DSP|branching-enzyme interacting dual-specificity protein phosphatase|muscle-restricted DSP|testis- and skeletal-muscle-specific DSP', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75094432, end_position_on_the_genomic_accession=75109221, orientation='minus', exon_count=10, OMIM=[613191], no_hdr0=''),
    51208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51208, CurrentID=0, Status='live', Symbol='CLDN18', Aliases=['SFTA5', 'SFTPJ'], description='claudin 18', other_designations='claudin-18|surfactant associated 5|surfactant associated protein J|surfactant, pulmonary associated protein J', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=137998816, end_position_on_the_genomic_accession=138033649, orientation='plus', exon_count=6, OMIM=[609210], no_hdr0=''),
    51209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51209, CurrentID=0, Status='live', Symbol='RAB9B', Aliases=['RAB9L', 'Rab-9L'], description='RAB9B, member RAS oncogene family', other_designations='ras-related protein Rab-9B|Ras-associated protein 9B|Ras-associated protein RAB9-like', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103776324, end_position_on_the_genomic_accession=103832257, orientation='minus', exon_count=9, OMIM=[300285], no_hdr0=''),
    51213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51213, CurrentID=0, Status='live', Symbol='LUZP4', Aliases=['CT-28', 'CT-8', 'CT28', 'HOM-TES-85'], description='leucine zipper protein 4', other_designations='leucine zipper protein 4|HOM-TES-85 tumor antigen|cancer/testis antigen 28|tumor antigen HOM-TES-85', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=115289715, end_position_on_the_genomic_accession=115307563, orientation='plus', exon_count=4, OMIM=[300616], no_hdr0=''),
    51218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51218, CurrentID=0, Status='live', Symbol='GLRX5', Aliases=['C14orf87', 'FLB4739', 'GRX5', 'PR01238', 'PRO1238', 'PRSA', 'SIDBA3', 'SPAHGC'], description='glutaredoxin 5', other_designations='glutaredoxin-related protein 5, mitochondrial|epididymis secretory sperm binding protein|glutaredoxin 5 homolog|monothiol glutaredoxin-5', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95535050, end_position_on_the_genomic_accession=95544714, orientation='plus', exon_count=2, OMIM=[609588], no_hdr0=''),
    51222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51222, CurrentID=0, Status='live', Symbol='ZNF219', Aliases=['ZFP219'], description='zinc finger protein 219', other_designations='zinc finger protein 219', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21090076, end_position_on_the_genomic_accession=21104722, orientation='minus', exon_count=8, OMIM=[605036], no_hdr0=''),
    51224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51224, CurrentID=0, Status='live', Symbol='ELOA2', Aliases=['HsT832', 'TCEB3B', 'TCEB3L'], description='elongin A2', other_designations='elongin-A2|RNA polymerase II transcription factor SIII subunit A2|transcription elongation factor (SIII) elongin A2 elongin A2|transcription elongation factor B polypeptide 3B|transcription elongation factor B subunit 3B', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47032527, end_position_on_the_genomic_accession=47035621, orientation='minus', exon_count=1, OMIM=[609522], no_hdr0=''),
    51225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51225, CurrentID=0, Status='live', Symbol='ABI3', Aliases=['NESH', 'SSH3BP3'], description='ABI family member 3', other_designations='ABI gene family member 3|new molecule including SH3', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49210582, end_position_on_the_genomic_accession=49223225, orientation='plus', exon_count=8, OMIM=[606363], no_hdr0=''),
    51226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51226, CurrentID=0, Status='live', Symbol='COPZ2', Aliases=['zeta2-COP'], description='COPI coat complex subunit zeta 2', other_designations='coatomer subunit zeta-2|coatomer protein complex subunit zeta 2|nonclathrin coat protein zeta-COP|zeta-2 COP|zeta-2-coat protein', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48026167, end_position_on_the_genomic_accession=48048086, orientation='minus', exon_count=11, OMIM=[615526], no_hdr0=''),
    51227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51227, CurrentID=0, Status='live', Symbol='PIGP', Aliases=['DCRC', 'DCRC-S', 'DEE55', 'DSCR5', 'DSRC', 'EIEE55', 'PIG-P'], description='phosphatidylinositol glycan anchor biosynthesis class P', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit P|Down syndrome critical region gene 5|Down syndrome critical region protein 5|Down syndrome critical region protein C|phosphatidylinositol glycan, class P|phosphatidylinositol-glycan biosynthesis class P protein|phosphatidylinositol-n-acetylglucosaminyltranferase subunit', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37065364, end_position_on_the_genomic_accession=37073071, orientation='minus', exon_count=7, OMIM=[605938], no_hdr0=''),
    51228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51228, CurrentID=0, Status='live', Symbol='GLTP', Aliases=[], description='glycolipid transfer protein', other_designations='glycolipid transfer protein|truncated glycolipid transfer protein', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109850945, end_position_on_the_genomic_accession=109880541, orientation='minus', exon_count=6, OMIM=[608949], no_hdr0=''),
    51230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51230, CurrentID=0, Status='live', Symbol='PHF20', Aliases=['C20orf104', 'GLEA2', 'HCA58', 'NZF', 'TDRD20A', 'TZP'], description='PHD finger protein 20', other_designations='PHD finger protein 20|glioma-expressed antigen 2|hepatocellular carcinoma-associated antigen 58|novel zinc finger protein|transcription factor TZP|tudor domain containing 20A', map_location='20q11.22-q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35772003, end_position_on_the_genomic_accession=35950372, orientation='plus', exon_count=23, OMIM=[610335], no_hdr0=''),
    51231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51231, CurrentID=0, Status='live', Symbol='VRK3', Aliases=[], description='VRK serine/threonine kinase 3', other_designations='inactive serine/threonine-protein kinase VRK3|serine/threonine-protein kinase VRK3|serine/threonine-protein pseudokinase VRK3|vaccinia related kinase 3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49976468, end_position_on_the_genomic_accession=50025535, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    51232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51232, CurrentID=0, Status='live', Symbol='CRIM1', Aliases=['CRIM-1', 'S52'], description='cysteine rich transmembrane BMP regulator 1', other_designations='cysteine-rich motor neuron 1 protein|cysteine rich transmembrane BMP regulator 1 (chordin-like)|cysteine-rich repeat-containing protein S52', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=36355778, end_position_on_the_genomic_accession=36551135, orientation='plus', exon_count=22, OMIM=[606189], no_hdr0=''),
    51233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51233, CurrentID=0, Status='live', Symbol='DRICH1', Aliases=['C22orf43', 'KB-208E9.1'], description='aspartate rich 1', other_designations='aspartate-rich protein 1', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23580872, end_position_on_the_genomic_accession=23637732, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    51234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51234, CurrentID=0, Status='live', Symbol='EMC4', Aliases=['PIG17', 'TMEM85'], description='ER membrane protein complex subunit 4', other_designations='ER membrane protein complex subunit 4|cell proliferation-inducing gene 17 protein|transmembrane protein 85', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34225016, end_position_on_the_genomic_accession=34230156, orientation='plus', exon_count=5, OMIM=[616245], no_hdr0=''),
    51236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51236, CurrentID=0, Status='live', Symbol='HGH1', Aliases=['BRP16', 'BRP16L', 'C8orf30A', 'C8orf30B', 'FAM203A', 'FAM203B'], description='HGH1 homolog', other_designations='protein HGH1 homolog|brain protein 16|brain protein 16-like|family with sequence similarity 203, member A|family with sequence similarity 203, member B|protein FAM203A|protein FAM203B', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144137721, end_position_on_the_genomic_accession=144140851, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    51237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51237, CurrentID=0, Status='live', Symbol='MZB1', Aliases=['MEDA-7', 'PACAP', 'pERp1'], description='marginal zone B and B1 cell specific protein', other_designations='marginal zone B- and B1-cell-specific protein|HSPC190|caspase-2 binding protein|mesenteric estrogen-dependent adipose 7|mesenteric oestrogen-dependent adipose gene- 7|plasma cell-induced ER protein 1|plasma cell-induced resident ER protein|plasma cell-induced resident endoplasmic reticulum protein|proapoptotic caspase adapter protein|proapoptotic caspase adaptor protein', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139387467, end_position_on_the_genomic_accession=139389913, orientation='minus', exon_count=4, OMIM=[609447], no_hdr0=''),
    51239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51239, CurrentID=0, Status='live', Symbol='ANKRD39', Aliases=[], description='ankyrin repeat domain 39', other_designations='ankyrin repeat domain-containing protein 39', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96847990, end_position_on_the_genomic_accession=96858016, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    51241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51241, CurrentID=0, Status='live', Symbol='COX16', Aliases=['C14orf112', 'HSPC203', 'MC4DN22', 'hCOX16'], description='cytochrome c oxidase assembly factor COX16', other_designations='cytochrome c oxidase assembly protein COX16 homolog, mitochondrial|COX16, cytochrome c oxidase assembly homolog', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70325081, end_position_on_the_genomic_accession=70359683, orientation='minus', exon_count=4, OMIM=[618064], no_hdr0=''),
    51244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51244, CurrentID=0, Status='live', Symbol='CCDC174', Aliases=['C3orf19', 'HSPC212', 'IHPM', 'IHPMR', 'ctr1'], description='coiled-coil domain containing 174', other_designations='coiled-coil domain-containing protein 174', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14651762, end_position_on_the_genomic_accession=14672659, orientation='plus', exon_count=11, OMIM=[616735], no_hdr0=''),
    51246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51246, CurrentID=0, Status='live', Symbol='SHISA5', Aliases=['SCOTIN'], description='shisa family member 5', other_designations='protein shisa-5|putative NF-kappa-B-activating protein 120|shisa homolog 5', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48467876, end_position_on_the_genomic_accession=48504810, orientation='minus', exon_count=10, OMIM=[607290], no_hdr0=''),
    51247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51247, CurrentID=0, Status='live', Symbol='PAIP2', Aliases=['PAIP-2A', 'PAIP2'], description='poly(A) binding protein interacting protein 2', other_designations='polyadenylate-binding protein-interacting protein 2|PABC1-interacting protein 2|PABP-interacting protein 2|polyA-binding protein-interacting protein 2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139341850, end_position_on_the_genomic_accession=139369717, orientation='plus', exon_count=4, OMIM=[605604], no_hdr0=''),
    51248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51248, CurrentID=0, Status='live', Symbol='PDZD11', Aliases=['AIPP1', 'PDZK11', 'PISP'], description='PDZ domain containing 11', other_designations='PDZ domain-containing protein 11|ATPase-interacting PDZ protein|PMCA-interacting single-PDZ protein|plasma membrane calcium ATPase-interacting single-PDZ protein', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70286595, end_position_on_the_genomic_accession=70289958, orientation='minus', exon_count=8, OMIM=[300632], no_hdr0=''),
    51249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51249, CurrentID=0, Status='live', Symbol='TMEM69', Aliases=['C1orf154'], description='transmembrane protein 69', other_designations='transmembrane protein 69', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45688181, end_position_on_the_genomic_accession=45694438, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    51250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51250, CurrentID=0, Status='live', Symbol='MTRES1', Aliases=['C6orf203', 'HSPC230', 'PRED31'], description='mitochondrial transcription rescue factor 1', other_designations='mitochondrial transcription rescue factor 1|uncharacterized protein C6orf203', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107028199, end_position_on_the_genomic_accession=107051586, orientation='plus', exon_count=6, OMIM=[618583], no_hdr0=''),
    51251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51251, CurrentID=0, Status='live', Symbol='NT5C3A', Aliases=['NT5C3', "P5'N-1", 'P5N-1', 'PN-I', 'POMP', 'PSN1', 'UMPH', 'UMPH1', 'cN-III', 'hUMP1', 'p36'], description="5'-nucleotidase, cytosolic IIIA", other_designations="cytosolic 5'-nucleotidase 3A|5'-nucleotidase, cytosolic III|7-methylguanosine phosphate-specific 5'-nucleotidase|cytosolic 5'-nucleotidase 3|lupin|pyrimidine 5'-nucleotidase 1|uridine 5'-monophosphate hydrolase 1", map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=33014113, end_position_on_the_genomic_accession=33062776, orientation='minus', exon_count=12, OMIM=[606224], no_hdr0=''),
    51252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51252, CurrentID=0, Status='live', Symbol='FAM178B', Aliases=[], description='family with sequence similarity 178 member B', other_designations='protein FAM178B', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96875882, end_position_on_the_genomic_accession=96986600, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    51253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51253, CurrentID=0, Status='live', Symbol='MRPL37', Aliases=['L2mt', 'L37mt', 'MRP-L2', 'MRP-L37', 'MRPL2', 'RPML2'], description='mitochondrial ribosomal protein L37', other_designations='39S ribosomal protein L37, mitochondrial|39S ribosomal protein L2, mitochondrial|mitochondrial large ribosomal subunit protein mL37|ribosomal protein, mitochondrial, L2', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54200167, end_position_on_the_genomic_accession=54225489, orientation='plus', exon_count=8, OMIM=[611843], no_hdr0=''),
    51255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51255, CurrentID=0, Status='live', Symbol='RNF181', Aliases=['HSPC238'], description='ring finger protein 181', other_designations='E3 ubiquitin-protein ligase RNF181|RING-type E3 ubiquitin transferase RNF181', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85593823, end_position_on_the_genomic_accession=85597708, orientation='plus', exon_count=5, OMIM=[612490], no_hdr0=''),
    51256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51256, CurrentID=0, Status='live', Symbol='TBC1D7', Aliases=['MGCPH', 'PIG51', 'TBC7'], description='TBC1 domain family member 7', other_designations='TBC1 domain family member 7|TS complex subunit 3|cell migration-inducing protein 23', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13304951, end_position_on_the_genomic_accession=13328537, orientation='minus', exon_count=8, OMIM=[612655], no_hdr0=''),
    51257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51257, CurrentID=0, Status='live', Symbol='MARCHF2', Aliases=['HSPC240', 'MARCH-II', 'MARCH2', 'RNF172'], description='membrane associated ring-CH-type finger 2', other_designations='E3 ubiquitin-protein ligase MARCHF2|E3 ubiquitin-protein ligase MARCH2|RING finger protein 172|RING-type E3 ubiquitin transferase MARCH2|RING-type E3 ubiquitin transferase MARCHF2|membrane associated ring finger 2|membrane-associated RING finger protein 2|membrane-associated RING-CH protein II|membrane-associated ring finger (C3HC4) 2, E3 ubiquitin protein ligase', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8413305, end_position_on_the_genomic_accession=8439017, orientation='plus', exon_count=6, OMIM=[613332], no_hdr0=''),
    51258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51258, CurrentID=0, Status='live', Symbol='MRPL51', Aliases=['CDA09', 'HSPC241', 'MRP64', 'bMRP64'], description='mitochondrial ribosomal protein L51', other_designations='39S ribosomal protein L51, mitochondrial|L51mt|MRP-L51|bMRP-64|mitochondrial large ribosomal subunit protein mL51|mitochondrial ribosomal protein 64|mitochondrial ribosomal protein bMRP64', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6491886, end_position_on_the_genomic_accession=6493262, orientation='minus', exon_count=3, OMIM=[611855], no_hdr0=''),
    51259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51259, CurrentID=0, Status='live', Symbol='TMEM216', Aliases=['HSPC244'], description='transmembrane protein 216', other_designations='transmembrane protein 216', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61392587, end_position_on_the_genomic_accession=61398846, orientation='plus', exon_count=5, OMIM=[613277], no_hdr0=''),
    51260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51260, CurrentID=0, Status='live', Symbol='PBDC1', Aliases=['CXorf26'], description='polysaccharide biosynthesis domain containing 1', other_designations='protein PBDC1|UPF0368 protein Cxorf26|polysaccharide biosynthesis domain-containing protein 1', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=76173062, end_position_on_the_genomic_accession=76178314, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    51263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51263, CurrentID=0, Status='live', Symbol='MRPL30', Aliases=['L28MT', 'L30MT', 'MRP-L28', 'MRP-L30', 'MRPL28', 'MRPL28M', 'RPML28'], description='mitochondrial ribosomal protein L30', other_designations='39S ribosomal protein L30, mitochondrial|39S ribosomal protein L28, mitochondrial|mitochondrial large ribosomal subunit protein uL30m', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99181184, end_position_on_the_genomic_accession=99199561, orientation='plus', exon_count=7, OMIM=[611838], no_hdr0=''),
    51264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51264, CurrentID=0, Status='live', Symbol='MRPL27', Aliases=['L27mt'], description='mitochondrial ribosomal protein L27', other_designations='39S ribosomal protein L27, mitochondrial|MRP-L27|mitochondrial large ribosomal subunit protein bL27m', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50367867, end_position_on_the_genomic_accession=50373184, orientation='minus', exon_count=4, OMIM=[611837], no_hdr0=''),
    51265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51265, CurrentID=0, Status='live', Symbol='CDKL3', Aliases=['NKIAMRE'], description='cyclin dependent kinase like 3', other_designations='cyclin-dependent kinase-like 3|serine-threonine protein kinase NKIAMRE', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134236120, end_position_on_the_genomic_accession=134372380, orientation='minus', exon_count=23, OMIM=[608459], no_hdr0=''),
    51266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51266, CurrentID=0, Status='live', Symbol='CLEC1B', Aliases=['1810061I13Rik', 'CLEC2', 'CLEC2B', 'PRO1384', 'QDED721'], description='C-type lectin domain family 1 member B', other_designations='C-type lectin domain family 1 member B|C-type lectin-like receptor 2', map_location='12p13.31-p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9986119, end_position_on_the_genomic_accession=10001899, orientation='minus', exon_count=9, OMIM=[606783], no_hdr0=''),
    51267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51267, CurrentID=0, Status='live', Symbol='CLEC1A', Aliases=['CLEC-1', 'CLEC1'], description='C-type lectin domain family 1 member A', other_designations='C-type lectin domain family 1 member A|C-type lectin-like receptor-1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10069504, end_position_on_the_genomic_accession=10099065, orientation='minus', exon_count=8, OMIM=[606782], no_hdr0=''),
    51268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51268, CurrentID=0, Status='live', Symbol='PIPOX', Aliases=['LPIPOX'], description='pipecolic acid and sarcosine oxidase', other_designations='peroxisomal sarcosine oxidase|L-pipecolate oxidase|L-pipecolic acid oxidase|PSO|pipecolic acid oxidase', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29043141, end_position_on_the_genomic_accession=29057227, orientation='plus', exon_count=9, OMIM=[616713], no_hdr0=''),
    51270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51270, CurrentID=0, Status='live', Symbol='TFDP3', Aliases=['CT30', 'DP4', 'HCA661'], description='transcription factor Dp family member 3', other_designations='transcription factor Dp family member 3|E2F-like protein|cancer/testis antigen 30|hepatocellular carcinoma-associated antigen 661', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=133216662, end_position_on_the_genomic_accession=133218354, orientation='minus', exon_count=1, OMIM=[300772], no_hdr0=''),
    51271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51271, CurrentID=0, Status='live', Symbol='UBAP1', Aliases=['NAG20', 'SPG80', 'UAP', 'UBAP', 'UBAP-1'], description='ubiquitin associated protein 1', other_designations='ubiquitin-associated protein 1|nasopharyngeal carcinoma-associated gene 20 protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34179005, end_position_on_the_genomic_accession=34252523, orientation='plus', exon_count=12, OMIM=[609787], no_hdr0=''),
    51272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51272, CurrentID=0, Status='live', Symbol='BET1L', Aliases=['BET1L1', 'GOLIM3', 'GS15', 'HSPC197'], description='Bet1 golgi vesicular membrane trafficking protein like', other_designations='BET1-like protein|GOS-15|blocked early in transport 1 homolog-like|golgi SNARE 15 kDa protein|golgi SNARE with a size of 15 kDa|golgi integral membrane protein 3|vesicle transport protein GOS15', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=202924, end_position_on_the_genomic_accession=207399, orientation='minus', exon_count=4, OMIM=[615417], no_hdr0=''),
    51274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51274, CurrentID=0, Status='live', Symbol='KLF3', Aliases=['BKLF'], description='Kruppel like factor 3', other_designations='Krueppel-like factor 3|CACCC-box-binding protein BKLF|Kruppel-like factor 3 (basic)|TEF-2|basic Kruppel-like factor|basic krueppel-like factor|basic kruppel like factor|transcript ch138', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38664079, end_position_on_the_genomic_accession=38701517, orientation='plus', exon_count=8, OMIM=[609392], no_hdr0=''),
    51276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51276, CurrentID=0, Status='live', Symbol='ZNF571', Aliases=['HSPC059'], description='zinc finger protein 571', other_designations='zinc finger protein 571', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37564253, end_position_on_the_genomic_accession=37594830, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    51277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51277, CurrentID=0, Status='live', Symbol='DNAJC27', Aliases=['RBJ', 'RabJS'], description='DnaJ heat shock protein family (Hsp40) member C27', other_designations='dnaJ homolog subfamily C member 27|DnaJ (Hsp40) homolog, subfamily C, member 27|Ras-associated protein Rap1|rab and DnaJ domain-containing protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24943636, end_position_on_the_genomic_accession=24972094, orientation='minus', exon_count=9, OMIM=[613527], no_hdr0=''),
    51278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51278, CurrentID=0, Status='live', Symbol='IER5', Aliases=['SBBI48'], description='immediate early response 5', other_designations='immediate early response gene 5 protein', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=181088700, end_position_on_the_genomic_accession=181092900, orientation='plus', exon_count=1, OMIM=[607177], no_hdr0=''),
    51279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51279, CurrentID=0, Status='live', Symbol='C1RL', Aliases=['C1RL1P', 'C1r-LP', 'CLSPa', 'C1RL'], description='complement C1r subcomponent like', other_designations='complement C1r subcomponent-like protein|C1r-like protein|C1r-like serine protease analog protein|complement C1r-like proteinase|complement component 1, r subcomponent-like', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7094554, end_position_on_the_genomic_accession=7109214, orientation='minus', exon_count=6, OMIM=[608974], no_hdr0=''),
    51280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51280, CurrentID=0, Status='live', Symbol='GOLM1', Aliases=['C9orf155', 'GOLPH2', 'GP73', 'HEL46', 'PSEC0257', 'bA379P1.3'], description='golgi membrane protein 1', other_designations='Golgi membrane protein 1|epididymis luminal protein 46|golgi membrane protein GP73|golgi phosphoprotein 2|golgi protein, 73-kD', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=86026146, end_position_on_the_genomic_accession=86100149, orientation='minus', exon_count=11, OMIM=[606804], no_hdr0=''),
    51281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51281, CurrentID=0, Status='live', Symbol='ANKMY1', Aliases=['ZMYND13'], description='ankyrin repeat and MYND domain containing 1', other_designations='ankyrin repeat and MYND domain-containing protein 1|testis-specific ankyrin-like protein 1|zinc finger MYND domain-containing protein 13', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240468632, end_position_on_the_genomic_accession=240561216, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    51282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51282, CurrentID=0, Status='live', Symbol='SCAND1', Aliases=['RAZ1', 'SDP1'], description='SCAN domain containing 1', other_designations='SCAN domain-containing protein 1|SCAN-related protein RAZ1', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35953624, end_position_on_the_genomic_accession=35959472, orientation='minus', exon_count=5, OMIM=[610416], no_hdr0=''),
    51283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51283, CurrentID=0, Status='live', Symbol='BFAR', Aliases=['BAR', 'RNF47'], description='bifunctional apoptosis regulator', other_designations='bifunctional apoptosis regulator|RING finger protein 47|bifunctional apoptosis inhibitor', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14632831, end_position_on_the_genomic_accession=14669236, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    51284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51284, CurrentID=0, Status='live', Symbol='TLR7', Aliases=['IMD74-like', 'TLR7'], description='toll like receptor 7', other_designations='toll-like receptor 7|toll-like receptor 7-like', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=12867072, end_position_on_the_genomic_accession=12890361, orientation='plus', exon_count=3, OMIM=[300365], no_hdr0=''),
    51285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51285, CurrentID=0, Status='live', Symbol='RASL12', Aliases=['RIS'], description='RAS like family 12', other_designations='ras-like protein family member 12|Ras family member Ris|ras-like protein Ris', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65045576, end_position_on_the_genomic_accession=65076704, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    51286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51286, CurrentID=0, Status='live', Symbol='CEND1', Aliases=['BM88'], description='cell cycle exit and neuronal differentiation 1', other_designations='cell cycle exit and neuronal differentiation protein 1|BM88 antigen', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=787115, end_position_on_the_genomic_accession=790090, orientation='minus', exon_count=2, OMIM=[608213], no_hdr0=''),
    51287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51287, CurrentID=0, Status='live', Symbol='COA4', Aliases=['CHCHD8', 'CMC3', 'E2IG2'], description='cytochrome c oxidase assembly factor 4 homolog', other_designations='cytochrome c oxidase assembly factor 4 homolog, mitochondrial|E2-induced gene 2 protein|coiled-coil-helix-coiled-coil-helix domain containing 8|coiled-coil-helix-coiled-coil-helix domain-containing protein 8', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73870258, end_position_on_the_genomic_accession=73876901, orientation='minus', exon_count=4, OMIM=[608016], no_hdr0=''),
    51289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51289, CurrentID=0, Status='live', Symbol='RXFP3', Aliases=['GPCR135', 'RLN3R1', 'RXFPR3', 'SALPR'], description='relaxin family peptide receptor 3', other_designations='relaxin-3 receptor 1|G-protein coupled receptor GPCR135|G-protein coupled receptor SALPR|RLN3 receptor 1|g protein-coupled receptor SALPR|relaxin/insulin like family peptide receptor 3|somatostatin and angiotensin-like peptide receptor', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=33936386, end_position_on_the_genomic_accession=33938918, orientation='plus', exon_count=1, OMIM=[609445], no_hdr0=''),
    51290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51290, CurrentID=0, Status='live', Symbol='ERGIC2', Aliases=['CDA14', 'Erv41', 'PTX1', 'cd002'], description='ERGIC and golgi 2', other_designations='endoplasmic reticulum-Golgi intermediate compartment protein 2|CD14 protein', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=29336544, end_position_on_the_genomic_accession=29381172, orientation='minus', exon_count=16, OMIM=[612236], no_hdr0=''),
    51291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51291, CurrentID=0, Status='live', Symbol='GMIP', Aliases=['ARHGAP46'], description='GEM interacting protein', other_designations='GEM-interacting protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19629476, end_position_on_the_genomic_accession=19643657, orientation='minus', exon_count=22, OMIM=[609694], no_hdr0=''),
    51292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51292, CurrentID=0, Status='live', Symbol='GMPR2', Aliases=['GMPR 2'], description='guanosine monophosphate reductase 2', other_designations="GMP reductase 2|guanosine 5'-monophosphate oxidoreductase 2|guanosine monophosphate reductase isolog", map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24232622, end_position_on_the_genomic_accession=24239242, orientation='plus', exon_count=12, OMIM=[610781], no_hdr0=''),
    51293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51293, CurrentID=0, Status='live', Symbol='CD320', Aliases=['8D6', '8D6A', 'TCBLR', 'TCN2R'], description='CD320 molecule', other_designations='CD320 antigen|8D6 antigen|FDC-SM-8D6|FDC-signaling molecule 8D6|transcobalamin 2 receptor|transcobalamin receptor', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8302127, end_position_on_the_genomic_accession=8308358, orientation='minus', exon_count=5, OMIM=[606475], no_hdr0=''),
    51294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51294, CurrentID=0, Status='live', Symbol='PCDH12', Aliases=['DMJDS1', 'VE-cadherin-2', 'VECAD2'], description='protocadherin 12', other_designations='protocadherin-12|VE-cad-2|VE-cadherin 2|vascular cadherin-2|vascular endothelial cadherin 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141943581, end_position_on_the_genomic_accession=141958812, orientation='minus', exon_count=5, OMIM=[605622], no_hdr0=''),
    51295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51295, CurrentID=0, Status='live', Symbol='ECSIT', Aliases=['SITPEC'], description='ECSIT signaling integrator', other_designations='evolutionarily conserved signaling intermediate in Toll pathway, mitochondrial|ECSIT homolog|ECSIT signalling integrator|likely ortholog of mouse signaling intermediate in Toll pathway evolutionarily conserved', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11505929, end_position_on_the_genomic_accession=11529134, orientation='minus', exon_count=9, OMIM=[608388], no_hdr0=''),
    51296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51296, CurrentID=0, Status='live', Symbol='SLC15A3', Aliases=['OCTP', 'PHT2', 'PTR3'], description='solute carrier family 15 member 3', other_designations='solute carrier family 15 member 3|osteoclast transporter|peptide transporter 3|peptide/histidine transporter 2|solute carrier family 15 (oligopeptide transporter), member 3', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60937084, end_position_on_the_genomic_accession=60952176, orientation='minus', exon_count=9, OMIM=[610408], no_hdr0=''),
    51297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51297, CurrentID=0, Status='live', Symbol='BPIFA1', Aliases=['LUNX', 'NASG', 'PLUNC', 'SPLUNC1', 'SPURT', 'bA49G10.5'], description='BPI fold containing family A member 1', other_designations='BPI fold-containing family A member 1|ligand-binding protein RYA3|lung-specific protein X|nasopharyngeal carcinoma-related protein|palate lung and nasal epithelium clone protein|palate, lung and nasal epithelium associated|protein Plunc|secretory protein in upper respiratory tracts|short PLUNC1|tracheal epithelium enriched protein|von Ebner protein Hl', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33235996, end_position_on_the_genomic_accession=33243306, orientation='plus', exon_count=9, OMIM=[607412], no_hdr0=''),
    51298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51298, CurrentID=0, Status='live', Symbol='THEG', Aliases=['CT561', 'THEG'], description='theg spermatid protein', other_designations='testicular haploid expressed gene protein|Theg homolog|cancer/testis antigen 56|testis-specific', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=361747, end_position_on_the_genomic_accession=376693, orientation='minus', exon_count=10, OMIM=[609503], no_hdr0=''),
    51299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51299, CurrentID=0, Status='live', Symbol='NRN1', Aliases=['NRN', 'dJ380B8.2'], description='neuritin 1', other_designations='neuritin', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=5997999, end_position_on_the_genomic_accession=6007518, orientation='minus', exon_count=7, OMIM=[607409], no_hdr0=''),
    51300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51300, CurrentID=0, Status='live', Symbol='TIMMDC1', Aliases=['C3orf1', 'MC1DN31'], description='translocase of inner mitochondrial membrane domain containing 1', other_designations='complex I assembly factor TIMMDC1, mitochondrial|M5-14 protein|TIMM domain containing-protein 1|translocase of inner mitochondrial membrane domain-containing protein 1|transmembrane protein C3orf1', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119498525, end_position_on_the_genomic_accession=119525090, orientation='plus', exon_count=7, OMIM=[615534], no_hdr0=''),
    51301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51301, CurrentID=0, Status='live', Symbol='GCNT4', Aliases=['C2GNT3', 'LINC01336'], description='glucosaminyl (N-acetyl) transferase 4', other_designations='beta-1,3-galactosyl-O-glycosyl-glycoprotein beta-1,6-N-acetylglucosaminyltransferase 4|core 2 beta-1,6-N-acetylglucosaminyltransferase 3|core 2-branching enzyme 3|core2-GlcNAc-transferase 3|glucosaminyl (N-acetyl) transferase 4, core 2 (beta-1,6-N-acetylglucosaminyltransferase)|long intergenic non-protein coding RNA 1336', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75025346, end_position_on_the_genomic_accession=75052558, orientation='minus', exon_count=4, OMIM=[616782], no_hdr0=''),
    51302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51302, CurrentID=0, Status='live', Symbol='CYP39A1', Aliases=[], description='cytochrome P450 family 39 subfamily A member 1', other_designations='24-hydroxycholesterol 7-alpha-hydroxylase|cytochrome P450, family 39, subfamily A, polypeptide 1|cytochrome P450, subfamily XXXIX (oxysterol 7 alpha-hydroxylase), polypeptide 1', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46549580, end_position_on_the_genomic_accession=46652849, orientation='minus', exon_count=15, OMIM=[605994], no_hdr0=''),
    51303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51303, CurrentID=0, Status='live', Symbol='FKBP11', Aliases=['FKBP19'], description='FKBP prolyl isomerase 11', other_designations='peptidyl-prolyl cis-trans isomerase FKBP11|19 kDa FK506-binding protein|19 kDa FKBP|FK506 binding protein 11, 19 kDa|FK506-binding protein 11|FKBP-11|FKBP-19|PPIase FKBP11|rotamase', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48921963, end_position_on_the_genomic_accession=48925492, orientation='minus', exon_count=8, OMIM=[610571], no_hdr0=''),
    51304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51304, CurrentID=0, Status='live', Symbol='ZDHHC3', Aliases=['DHHC-3', 'DHHC3', 'GODZ', 'ZNF373'], description='zinc finger DHHC-type palmitoyltransferase 3', other_designations='palmitoyltransferase ZDHHC3|DHHC1 protein|Golgi apparatus-specific protein with DHHC zinc finger domain|acyltransferase ZDHHC3|golgi-specific DHHC Zinc Finger Protein|zinc finger DHHC domain-containing protein 3|zinc finger DHHC-type containing 3|zinc finger protein 373|zinc finger, DHHC domain containing 3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44915261, end_position_on_the_genomic_accession=44976182, orientation='minus', exon_count=14, OMIM=[617150], no_hdr0=''),
    51305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51305, CurrentID=0, Status='live', Symbol='KCNK9', Aliases=['BIBARS', 'K2p9.1', 'KT3.2', 'TASK-3', 'TASK3', 'TASK32'], description='potassium two pore domain channel subfamily K member 9', other_designations='potassium channel subfamily K member 9|TWIK-related acid-sensitive K(+) channel 3|TWIK-related acid-sensitive K+ 3|acid-sensitive potassium channel protein TASK-3|potassium 2-pore domain leak channel TASK3|potassium channel, two pore domain subfamily K, member 9|two pore K(+) channel KT3.2|two pore potassium channel KT3.2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=139600838, end_position_on_the_genomic_accession=139703135, orientation='minus', exon_count=5, OMIM=[605874], no_hdr0=''),
    51306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51306, CurrentID=0, Status='live', Symbol='FAM13B', Aliases=['ARHGAP49', 'C5orf51', 'KHCHP', 'N61', 'FAM13B'], description='family with sequence similarity 13 member B', other_designations='protein FAM13B|GAP-like protein N61|family with sequence similarity 13, member B1', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=137937960, end_position_on_the_genomic_accession=138051961, orientation='minus', exon_count=30, OMIM=[609371], no_hdr0=''),
    51307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51307, CurrentID=0, Status='live', Symbol='FAM53C', Aliases=['C5orf6'], description='family with sequence similarity 53 member C', other_designations='protein FAM53C|putative nuclear protein', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138337557, end_position_on_the_genomic_accession=138349729, orientation='plus', exon_count=6, OMIM=[609372], no_hdr0=''),
    51308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51308, CurrentID=0, Status='live', Symbol='REEP2', Aliases=['C5orf19', 'SGC32445', 'SPG72', 'Yip2d'], description='receptor accessory protein 2', other_designations='receptor expression-enhancing protein 2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138439057, end_position_on_the_genomic_accession=138446965, orientation='plus', exon_count=8, OMIM=[609347], no_hdr0=''),
    51309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51309, CurrentID=0, Status='live', Symbol='ARMCX1', Aliases=['ALEX1', 'GASP7'], description='armadillo repeat containing X-linked 1', other_designations='armadillo repeat-containing X-linked protein 1|ARM protein lost in epithelial cancers on chromosome X 1|arm protein lost in epithelial cancers, X chromosome, 1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101550547, end_position_on_the_genomic_accession=101554700, orientation='plus', exon_count=4, OMIM=[300362], no_hdr0=''),
    51310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51310, CurrentID=0, Status='live', Symbol='SLC22A17', Aliases=['24p3R', 'BOCT', 'BOIT', 'NGALR', 'NGALR2', 'NGALR3', 'hBOIT'], description='solute carrier family 22 member 17', other_designations='solute carrier family 22 member 17|24p3 receptor|NGAL receptor|brain-type organic cation transporter|lipocalin-2 receptor|neutrophil gelatinase-associated lipocalin receptor|potent brain type organic ion transporter|solute carrier family 22 (organic cation transporter), member 17', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23346304, end_position_on_the_genomic_accession=23354991, orientation='minus', exon_count=10, OMIM=[611461], no_hdr0=''),
    51311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51311, CurrentID=0, Status='live', Symbol='TLR8', Aliases=['CD288'], description='toll like receptor 8', other_designations='toll-like receptor 8', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=12906620, end_position_on_the_genomic_accession=12923169, orientation='plus', exon_count=3, OMIM=[300366], no_hdr0=''),
    51312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51312, CurrentID=0, Status='live', Symbol='SLC25A37', Aliases=['HT015', 'MFRN', 'MFRN1', 'MSC', 'MSCP', 'PRO1278', 'PRO1584', 'PRO2217'], description='solute carrier family 25 member 37', other_designations='mitoferrin-1|mitochondrial iron transporter 1|mitochondrial solute carrier protein|mitoferrin|predicted protein of HQ2217|solute carrier family 25 (mitochondrial iron transporter), member 37', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23528956, end_position_on_the_genomic_accession=23575463, orientation='plus', exon_count=9, OMIM=[610387], no_hdr0=''),
    51313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51313, CurrentID=0, Status='live', Symbol='GASK1B', Aliases=['AD021', 'AD036', 'C4orf18', 'ENED', 'FAM198B'], description='golgi associated kinase 1B', other_designations='Golgi-associated kinase 1B|expressed in nerve and epithelium during development|family with sequence similarity 198 member B|protein FAM198B', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158124474, end_position_on_the_genomic_accession=158173075, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    51314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51314, CurrentID=0, Status='live', Symbol='NME8', Aliases=['CILD6', 'DNAI8', 'HEL-S-99', 'NM23-H8', 'SPTRX2', 'TXNDC3', 'sptrx-2'], description='NME/NM23 family member 8', other_designations='thioredoxin domain-containing protein 3|epididymis secretory protein Li 99|sperm-specific thioredoxin 2|spermatid-specific thioredoxin-2|thioredoxin domain containing 3 (spermatozoa)', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=37848597, end_position_on_the_genomic_accession=37900397, orientation='plus', exon_count=18, OMIM=[607421], no_hdr0=''),
    51315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51315, CurrentID=0, Status='live', Symbol='KRCC1', Aliases=['CHBP2'], description='lysine rich coiled-coil 1', other_designations='lysine-rich coiled-coil protein 1|cryptogenic hepatitis-binding protein 2', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88027205, end_position_on_the_genomic_accession=88055783, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    51316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51316, CurrentID=0, Status='live', Symbol='PLAC8', Aliases=['C15', 'DGIC', 'PNAS-144', 'onzin'], description='placenta associated 8', other_designations='placenta-specific gene 8 protein|down-regulated in gastrointestinal cancer protein|placenta specific 8', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83090048, end_position_on_the_genomic_accession=83114729, orientation='minus', exon_count=6, OMIM=[607515], no_hdr0=''),
    51317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51317, CurrentID=0, Status='live', Symbol='PHF21A', Aliases=['BHC80', 'BM-006', 'IDDBCS', 'NEDMS'], description='PHD finger protein 21A', other_designations='PHD finger protein 21A|BHC80a|BRAF35-HDAC complex protein BHC80|BRAF35/HDAC2 complex (80 kDa)', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45929319, end_position_on_the_genomic_accession=46121454, orientation='minus', exon_count=28, OMIM=[608325], no_hdr0=''),
    51318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51318, CurrentID=0, Status='live', Symbol='MRPL35', Aliases=['L35mt', 'MRP-L35'], description='mitochondrial ribosomal protein L35', other_designations='39S ribosomal protein L35, mitochondrial|mitochondrial large ribosomal subunit protein bL35m', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86199433, end_position_on_the_genomic_accession=86213794, orientation='plus', exon_count=4, OMIM=[611841], no_hdr0=''),
    51319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51319, CurrentID=0, Status='live', Symbol='RSRC1', Aliases=['BM-011', 'MRT70', 'SFRS21', 'SRrp53'], description='arginine and serine rich coiled-coil 1', other_designations='serine/Arginine-related protein 53|arginine/serine-rich coiled-coil 1|arginine/serine-rich coiled-coil protein 1|splicing factor, arginine/serine-rich 21', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158110052, end_position_on_the_genomic_accession=158545730, orientation='plus', exon_count=11, OMIM=[613352], no_hdr0=''),
    51320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51320, CurrentID=0, Status='live', Symbol='MEX3C', Aliases=['BM-013', 'MEX-3C', 'RKHD2', 'RNF194'], description='mex-3 RNA binding family member C', other_designations='RNA-binding E3 ubiquitin-protein ligase MEX3C|MEX3C variant 1|MEX3C variant 2|RING finger and KH domain-containing protein 2|RING finger protein 194|RING-type E3 ubiquitin transferase MEX3C|RNA-binding protein MEX3C|ring finger and KH domain containing 2', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=51174550, end_position_on_the_genomic_accession=51197681, orientation='minus', exon_count=2, OMIM=[611005], no_hdr0=''),
    51321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51321, CurrentID=0, Status='live', Symbol='AMZ2', Aliases=[], description='archaelysin family metallopeptidase 2', other_designations='archaemetzincin-2|archaemetzincins-2|archeobacterial metalloproteinase-like protein 2', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68206129, end_position_on_the_genomic_accession=68257164, orientation='plus', exon_count=10, OMIM=[615169], no_hdr0=''),
    51322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51322, CurrentID=0, Status='live', Symbol='WAC', Aliases=['BM-016', 'DESSH', 'PRO1741', 'Wwp4'], description='WW domain containing adaptor with coiled-coil', other_designations='WW domain-containing adapter protein with coiled-coil', map_location='10p12.1-p11.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=28532772, end_position_on_the_genomic_accession=28623112, orientation='plus', exon_count=16, OMIM=[615049], no_hdr0=''),
    51324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51324, CurrentID=0, Status='live', Symbol='SPG21', Aliases=['ABHD21', 'ACP33', 'BM-019', 'GL010', 'MAST'], description='SPG21 abhydrolase domain containing, maspardin', other_designations='maspardin|SPG21, maspardin|acid cluster protein 33|spastic paraplegia 21 (autosomal recessive, Mast syndrome)', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64963022, end_position_on_the_genomic_accession=64989914, orientation='minus', exon_count=12, OMIM=[608181], no_hdr0=''),
    51326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51326, CurrentID=0, Status='live', Symbol='ARL17A', Aliases=['ARF1P2', 'ARL17P1'], description='ADP ribosylation factor like GTPase 17A', other_designations='ADP-ribosylation factor-like 17-like|ADP-ribosylation factor 7', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46500213, end_position_on_the_genomic_accession=46579780, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    51327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51327, CurrentID=0, Status='live', Symbol='AHSP', Aliases=['EDRF', 'ERAF'], description='alpha hemoglobin stabilizing protein', other_designations='alpha-hemoglobin-stabilizing protein|alpha hemoglobin stabilising protein|erythroid differentiation associated factor|erythroid differentiation-related factor', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31527900, end_position_on_the_genomic_accession=31528803, orientation='plus', exon_count=4, OMIM=[605821], no_hdr0=''),
    51329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51329, CurrentID=0, Status='live', Symbol='ARL6IP4', Aliases=['SFRS20', 'SR-25', 'SRp25', 'SRrp37'], description='ADP ribosylation factor like GTPase 6 interacting protein 4', other_designations='ADP-ribosylation factor-like protein 6-interacting protein 4|ADP-ribosylation factor GTPase 6 interacting protein 4|ADP-ribosylation factor-like 6 interacting protein 4|ADP-ribosylation-like factor 6 interacting protein 4|ARL-6-interacting protein 4|HSP-975|HSVI binding protein|SR-15|SRp25 nuclear protein|aip-4|splicing factor SRrp37|splicing factor, arginine/serine-rich 20|splicing regulator SRrp38', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122980233, end_position_on_the_genomic_accession=122982909, orientation='plus', exon_count=8, OMIM=[607668], no_hdr0=''),
    51330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51330, CurrentID=0, Status='live', Symbol='TNFRSF12A', Aliases=['CD266', 'FN14', 'TWEAKR'], description='TNF receptor superfamily member 12A', other_designations='tumor necrosis factor receptor superfamily member 12A|FGF-inducible 14|fibroblast growth factor-inducible immediate-early response protein 14|tweak-receptor|type I transmembrane protein Fn14', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3020368, end_position_on_the_genomic_accession=3022383, orientation='plus', exon_count=4, OMIM=[605914], no_hdr0=''),
    51332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51332, CurrentID=0, Status='live', Symbol='SPTBN5', Aliases=['BSPECV', 'HUBSPECV', 'HUSPECV'], description='spectrin beta, non-erythrocytic 5', other_designations='spectrin beta chain, non-erythrocytic 5|beta V spectrin|spectrin beta chain, brain 4|spectrin, non-erythroid beta chain 4', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41848146, end_position_on_the_genomic_accession=41894053, orientation='minus', exon_count=71, OMIM=[605916], no_hdr0=''),
    51333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51333, CurrentID=0, Status='live', Symbol='ZNF771', Aliases=['DSC43'], description='zinc finger protein 771', other_designations='zinc finger protein 771|mesenchymal stem cell protein DSC43', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30407606, end_position_on_the_genomic_accession=30419414, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    51334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51334, CurrentID=0, Status='live', Symbol='PRR16', Aliases=['DSC54', 'LARGEN'], description='proline rich 16', other_designations='protein Largen|mesenchymal stem cell protein DSC54|proline-rich protein 16', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=120464222, end_position_on_the_genomic_accession=120794587, orientation='plus', exon_count=9, OMIM=[615931], no_hdr0=''),
    51335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51335, CurrentID=0, Status='live', Symbol='NGRN', Aliases=['DSC92'], description='neugrin, neurite outgrowth associated', other_designations='neugrin|mesenchymal stem cell protein DSC92|neurite outgrowth associated protein|spinal cord-derived protein FI58G', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90265663, end_position_on_the_genomic_accession=90272211, orientation='plus', exon_count=2, OMIM=[616718], no_hdr0=''),
    51337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51337, CurrentID=0, Status='live', Symbol='THEM6', Aliases=['C8orf55', 'DSCD75'], description='thioesterase superfamily member 6', other_designations='protein THEM6|UPF0670 protein C8orf55|UPF0670 protein THEM6|mesenchymal stem cell protein DSCD75', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142727223, end_position_on_the_genomic_accession=142736927, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    51338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51338, CurrentID=0, Status='live', Symbol='MS4A4A', Aliases=['4SPAN1', 'CD20-L1', 'CD20L1', 'HDCME31P', 'MS4A4', 'MS4A7'], description='membrane spanning 4-domains A4A', other_designations='membrane-spanning 4-domains subfamily A member 4A|CD20 antigen-like 1|Fc epsilon receptor beta subunit homolog|epididymis secretory sperm binding protein|four-span transmembrane protein 1|membrane-spanning 4-domains, subfamily A, member 4', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60280666, end_position_on_the_genomic_accession=60308970, orientation='plus', exon_count=9, OMIM=[606547], no_hdr0=''),
    51339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51339, CurrentID=0, Status='live', Symbol='DACT1', Aliases=['DAPPER', 'DAPPER1', 'DPR1', 'FRODO', 'HDPR1', 'TBS2', 'THYEX3'], description='dishevelled binding antagonist of beta catenin 1', other_designations='dapper homolog 1|dapper antagonist of catenin 1|dapper, antagonist of beta-catenin, homolog 1|hepatocellular carcinoma novel gene 3 protein|heptacellular carcinoma novel gene 3', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58634061, end_position_on_the_genomic_accession=58648321, orientation='plus', exon_count=7, OMIM=[607861], no_hdr0=''),
    51340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51340, CurrentID=0, Status='live', Symbol='CRNKL1', Aliases=['CLF', 'CRN', 'Clf1', 'HCRN', 'MSTP021', 'SYF3'], description='crooked neck pre-mRNA splicing factor 1', other_designations='crooked neck-like protein 1|Crn, crooked neck-like 1|SYF3 pre-mRNA-splicing factor|crooked neck homolog|crooked neck pre-mRNA splicing factor-like 1|crooked neck-like 1', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=20034368, end_position_on_the_genomic_accession=20056046, orientation='minus', exon_count=16, OMIM=[610952], no_hdr0=''),
    51341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51341, CurrentID=0, Status='live', Symbol='ZBTB7A', Aliases=['FBI-1', 'FBI1', 'LRF', 'TIP21', 'ZBTB7', 'ZNF857A', 'pokemon'], description='zinc finger and BTB domain containing 7A', other_designations='zinc finger and BTB domain-containing protein 7A|HIV-1 1st-binding protein 1|HIV-1 inducer of short transcripts binding protein|POK erythroid myeloid ontogenic factor|POZ and Krueppel erythroid myeloid ontogenic factor|TTF-I-interacting peptide 21|factor binding IST protein 1|factor that binds to inducer of short transcripts protein 1|leukemia/lymphoma-related factor|lymphoma related factor|pokemon 1|zinc finger and BTB domain containing 7A, HIV-1 inducer of short transcripts binding protein|zinc finger protein 857A', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4043303, end_position_on_the_genomic_accession=4066899, orientation='minus', exon_count=6, OMIM=[605878], no_hdr0=''),
    51343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51343, CurrentID=0, Status='live', Symbol='FZR1', Aliases=['CDC20C', 'CDH1', 'FZR', 'FZR2', 'HCDH', 'HCDH1'], description='fizzy and cell division cycle 20 related 1', other_designations='fizzy-related protein homolog|CDC20 homolog 1|CDC20-like 1b|CDC20-like protein 1|cdh1/Hct1 homolog|fizzy/cell division cycle 20 related 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3506263, end_position_on_the_genomic_accession=3538334, orientation='plus', exon_count=17, OMIM=[603619], no_hdr0=''),
    51347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51347, CurrentID=0, Status='live', Symbol='TAOK3', Aliases=['DPK', 'JIK', 'MAP3K18', 'hKFC-A'], description='TAO kinase 3', other_designations='serine/threonine-protein kinase TAO3|CTCL-associated antigen HD-CL-09|JNK/SAPK-inhibitory kinase|STE20-like kinase|cutaneous T-cell lymphoma-associated antigen HD-CL-09|dendritic cell-derived protein kinase|jun kinase-inhibitory kinase|kinase from chicken homolog A|thousand and one amino acid protein 3', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118149801, end_position_on_the_genomic_accession=118372950, orientation='minus', exon_count=26, OMIM=[616711], no_hdr0=''),
    51348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51348, CurrentID=0, Status='live', Symbol='KLRF1', Aliases=['CLEC5C', 'NKp80'], description='killer cell lectin like receptor F1', other_designations='killer cell lectin-like receptor subfamily F member 1|C-type lectin domain family 5 member C|activating coreceptor NKp80|killer cell lectin-like receptor subfamily F, member 1|lectin-like receptor F1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9800052, end_position_on_the_genomic_accession=9845005, orientation='plus', exon_count=7, OMIM=[605029], no_hdr0=''),
    51350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51350, CurrentID=0, Status='live', Symbol='KRT76', Aliases=['HUMCYT2A', 'KRT2B', 'KRT2P'], description='keratin 76', other_designations='keratin, type II cytoskeletal 2 oral|CK-2P|K2P|K76|cytokeratin 2|cytokeratin-2P|keratin 2p|keratin 76, type II|type-II keratin Kb9', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52768155, end_position_on_the_genomic_accession=52777345, orientation='minus', exon_count=9, OMIM=[616671], no_hdr0=''),
    51351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51351, CurrentID=0, Status='live', Symbol='ZNF117', Aliases=['H-plk', 'HPF9'], description='zinc finger protein 117', other_designations='zinc finger protein 117|Krueppel-related zinc finger protein|provirus-linked krueppel|zinc finger protein HPF9', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64971776, end_position_on_the_genomic_accession=64991036, orientation='minus', exon_count=4, OMIM=[194624], no_hdr0=''),
    51360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51360, CurrentID=0, Status='live', Symbol='MBTPS2', Aliases=['BRESEK', 'IFAP', 'KFSD', 'KFSDX', 'OI19', 'OLMSX', 'S2P'], description='membrane bound transcription factor peptidase, site 2', other_designations='membrane-bound transcription factor site-2 protease|SREBPs intramembrane protease|endopeptidase S2P|keratosis follicularis spinulosa decalvans|membrane-bound transcription factor protease, site 2|site-2 protease|sterol regulatory element-binding proteins intramembrane protease', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21839617, end_position_on_the_genomic_accession=21885423, orientation='plus', exon_count=11, OMIM=[300294], no_hdr0=''),
    51361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51361, CurrentID=0, Status='live', Symbol='HOOK1', Aliases=['HK1'], description='hook microtubule tethering protein 1', other_designations='protein Hook homolog 1|h-hook1|hHK1|hook homolog 1', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=59814922, end_position_on_the_genomic_accession=59876370, orientation='plus', exon_count=25, OMIM=[607820], no_hdr0=''),
    51362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51362, CurrentID=0, Status='live', Symbol='CDC40', Aliases=['EHB3', 'PCH15', 'PRP17', 'PRPF17'], description='cell division cycle 40', other_designations='pre-mRNA-processing factor 17|EH-binding protein 3|PRP17 homolog|cell division cycle 40 homolog|hPRP17|pre-mRNA splicing factor 17', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110180427, end_position_on_the_genomic_accession=110232232, orientation='plus', exon_count=15, OMIM=[605585], no_hdr0=''),
    51363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51363, CurrentID=0, Status='live', Symbol='CHST15', Aliases=['BRAG', 'GALNAC4S-6ST'], description='carbohydrate sulfotransferase 15', other_designations='carbohydrate sulfotransferase 15|B cell RAG associated protein (GALNAC4S-6ST)|B-cell RAG-associated gene protein|carbohydrate (N-acetylgalactosamine 4-sulfate 6-O) sulfotransferase 15|hBRAG', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124006059, end_position_on_the_genomic_accession=124093684, orientation='minus', exon_count=16, OMIM=[608277], no_hdr0=''),
    51364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51364, CurrentID=0, Status='live', Symbol='ZMYND10', Aliases=['BLU', 'CILD22', 'DNAAF7', 'FLU'], description='zinc finger MYND-type containing 10', other_designations='zinc finger MYND domain-containing protein 10|dynein axonemal assembly factor 7|protein BLu', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50341110, end_position_on_the_genomic_accession=50345732, orientation='minus', exon_count=12, OMIM=[607070], no_hdr0=''),
    51365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51365, CurrentID=0, Status='live', Symbol='PLA1A', Aliases=['PS-PLA1', 'PSPLA1'], description='phospholipase A1 member A', other_designations='phospholipase A1 member A|phosphatidylserine-specific phospholipase A1alpha', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119597876, end_position_on_the_genomic_accession=119629811, orientation='plus', exon_count=13, OMIM=[607460], no_hdr0=''),
    51366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51366, CurrentID=0, Status='live', Symbol='UBR5', Aliases=['DD5', 'EDD', 'EDD1', 'HYD'], description='ubiquitin protein ligase E3 component n-recognin 5', other_designations='E3 ubiquitin-protein ligase UBR5|E3 identified by differential display|E3 ubiquitin-protein ligase, HECT domain-containing 1|HECT-type E3 ubiquitin transferase UBR5|hyperplastic discs protein homolog|progestin-induced protein', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=102252273, end_position_on_the_genomic_accession=102412700, orientation='minus', exon_count=60, OMIM=[608413], no_hdr0=''),
    51367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51367, CurrentID=0, Status='live', Symbol='POP5', Aliases=['HSPC004', 'RPP2', 'RPP20', 'hPop5'], description='POP5 homolog, ribonuclease P/MRP subunit', other_designations='ribonuclease P/MRP protein subunit POP5|processing of precursor 5, ribonuclease P/MRP subunit', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120578764, end_position_on_the_genomic_accession=120581452, orientation='minus', exon_count=5, OMIM=[609992], no_hdr0=''),
    51368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51368, CurrentID=0, Status='live', Symbol='TEX264', Aliases=['ZSIG11'], description='testis expressed 264, ER-phagy receptor', other_designations='testis-expressed protein 264|testis expressed gene 264|testis-expressed sequence 264 protein', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51671252, end_position_on_the_genomic_accession=51704323, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    51371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51371, CurrentID=0, Status='live', Symbol='POMP', Aliases=['C13orf12', 'HSPC014', 'PNAS-110', 'PRAAS2', 'UMP1'], description='proteasome maturation protein', other_designations='proteasome maturation protein|2510048O06Rik|hUMP1|proteassemblin|protein UMP1 homolog|voltage-gated K channel beta subunit 4.1|voltage-gated potassium channel beta subunit 4.1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28659130, end_position_on_the_genomic_accession=28678959, orientation='plus', exon_count=6, OMIM=[613386], no_hdr0=''),
    51372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51372, CurrentID=0, Status='live', Symbol='TMA7', Aliases=['CCDC72', 'HSPC016'], description='translation machinery associated 7 homolog', other_designations='translation machinery-associated protein 7|coiled-coil domain containing 72|coiled-coil domain-containing protein 72|translational machinery associated 7 homolog', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48440257, end_position_on_the_genomic_accession=48444208, orientation='plus', exon_count=4, OMIM=[615808], no_hdr0=''),
    51373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51373, CurrentID=0, Status='live', Symbol='MRPS17', Aliases=['HSPC011', 'MRP-S17', 'RPMS17', 'S17mt'], description='mitochondrial ribosomal protein S17', other_designations='28S ribosomal protein S17, mitochondrial|mitochondrial small ribosomal subunit protein uS17m', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55951877, end_position_on_the_genomic_accession=55956500, orientation='plus', exon_count=3, OMIM=[611980], no_hdr0=''),
    51374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51374, CurrentID=0, Status='live', Symbol='ATRAID', Aliases=['APR--3', 'APR-3', 'APR3', 'C2orf28', 'HSPC013', 'PRO240', 'p18'], description='all-trans retinoic acid induced differentiation factor', other_designations='all-trans retinoic acid-induced differentiation factor|apoptosis related protein APR-3|apoptosis-related protein 3', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27212041, end_position_on_the_genomic_accession=27217183, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    51375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51375, CurrentID=0, Status='live', Symbol='SNX7', Aliases=[], description='sorting nexin 7', other_designations='sorting nexin-7', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=98661284, end_position_on_the_genomic_accession=98760500, orientation='plus', exon_count=12, OMIM=[614904], no_hdr0=''),
    51377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51377, CurrentID=0, Status='live', Symbol='UCHL5', Aliases=['CGI-70', 'INO80R', 'UCH-L5', 'UCH37'], description='ubiquitin C-terminal hydrolase L5', other_designations='ubiquitin carboxyl-terminal hydrolase isozyme L5|INO80 complex subunit R|ubiquitin C-terminal hydrolase UCH37|ubiquitin carboxyl-terminal esterase L5|ubiquitin carboxyl-terminal hydrolase L5|ubiquitin thioesterase L5', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=193012254, end_position_on_the_genomic_accession=193060140, orientation='minus', exon_count=17, OMIM=[610667], no_hdr0=''),
    51378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51378, CurrentID=0, Status='live', Symbol='ANGPT4', Aliases=['ANG3', 'ANG4'], description='angiopoietin 4', other_designations='angiopoietin-4', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=869900, end_position_on_the_genomic_accession=916368, orientation='minus', exon_count=9, OMIM=[603705], no_hdr0=''),
    51379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51379, CurrentID=0, Status='live', Symbol='CRLF3', Aliases=['CREME-9', 'CREME9', 'CRLM9', 'CYTOR4', 'FRWS', 'p48.2'], description='cytokine receptor like factor 3', other_designations='cytokine receptor-like factor 3|cytokine receptor-like molecule 9|cytokine receptor-related protein 4|type I cytokine receptor-like factor p48', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30782684, end_position_on_the_genomic_accession=30824692, orientation='minus', exon_count=8, OMIM=[614853], no_hdr0=''),
    51380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51380, CurrentID=0, Status='live', Symbol='CSAD', Aliases=['CSD', 'PCAP'], description='cysteine sulfinic acid decarboxylase', other_designations='cysteine sulfinic acid decarboxylase|P-selectin cytoplasmic tail-associated protein|aspartate 1-decarboxylase|cysteine sulfinic acid decarboxylase-related protein|cysteine-sulfinate decarboxylase|sulfinoalanine decarboxylase', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53157663, end_position_on_the_genomic_accession=53181663, orientation='minus', exon_count=23, OMIM=[616569], no_hdr0=''),
    51382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51382, CurrentID=0, Status='live', Symbol='ATP6V1D', Aliases=['ATP6M', 'VATD', 'VMA8'], description='ATPase H+ transporting V1 subunit D', other_designations='V-type proton ATPase subunit D|ATPase, H+ transporting lysosomal, member M|ATPase, H+ transporting, lysosomal (vacuolar proton pump)|ATPase, H+ transporting, lysosomal 34kDa, V1 subunit D|H(+)-transporting two-sector ATPase, subunit M|V-ATPase 28 kDa accessory protein|V-ATPase D subunit|V-ATPase subunit D|vacuolar ATP synthase subunit D|vacuolar H-ATPase subunit D|vacuolar proton pump D subunit|vacuolar proton pump delta polypeptide|vacuolar proton pump subunit D|vacuolar proton-ATPase subunit D', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67337872, end_position_on_the_genomic_accession=67359804, orientation='minus', exon_count=9, OMIM=[609398], no_hdr0=''),
    51384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51384, CurrentID=0, Status='live', Symbol='WNT16', Aliases=[], description='Wnt family member 16', other_designations='protein Wnt-16|wingless-type MMTV integration site family member 16b|wingless-type MMTV integration site family, member 16', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=121325367, end_position_on_the_genomic_accession=121341104, orientation='plus', exon_count=5, OMIM=[606267], no_hdr0=''),
    51385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51385, CurrentID=0, Status='live', Symbol='ZNF589', Aliases=['SZF1'], description='zinc finger protein 589', other_designations='zinc finger protein 589|KRAB-zinc finger protein SZF1-1|stem cell zinc finger protein 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48241104, end_position_on_the_genomic_accession=48270990, orientation='plus', exon_count=4, OMIM=[616702], no_hdr0=''),
    51386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51386, CurrentID=0, Status='live', Symbol='EIF3L', Aliases=['EIF3EIP', 'EIF3S11', 'EIF3S6IP', 'HSPC021', 'HSPC025', 'MSTP005'], description='eukaryotic translation initiation factor 3 subunit L', other_designations='eukaryotic translation initiation factor 3 subunit L|eIEF associated protein HSPC021|eukaryotic translation initiation factor 3 subunit 6-interacting protein|eukaryotic translation initiation factor 3 subunit E-interacting protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37848868, end_position_on_the_genomic_accession=37889407, orientation='plus', exon_count=13, OMIM=[619197], no_hdr0=''),
    51388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51388, CurrentID=0, Status='live', Symbol='NIP7', Aliases=['CGI-37', 'HSPC031', 'KD93'], description='nucleolar pre-rRNA processing protein NIP7', other_designations='60S ribosome subunit biogenesis protein NIP7 homolog|NIP7, nucleolar pre-rRNA processing protein|nuclear import 7 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69339772, end_position_on_the_genomic_accession=69343106, orientation='plus', exon_count=5, OMIM=[619204], no_hdr0=''),
    51389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51389, CurrentID=0, Status='live', Symbol='RWDD1', Aliases=['CGI-24', 'PTD013'], description='RWD domain containing 1', other_designations='RWD domain-containing protein 1|DRG family-regulatory protein 2', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116571504, end_position_on_the_genomic_accession=116597675, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    51390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51390, CurrentID=0, Status='live', Symbol='AIG1', Aliases=['AIG-1', 'dJ95L4.1'], description='androgen induced 1', other_designations='androgen-induced gene 1 protein|FAHFA hydrolase AIG1|fatty acid esters of hydroxy fatty acids hydrolase AIG1', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143059213, end_position_on_the_genomic_accession=143343883, orientation='plus', exon_count=17, OMIM=[608514], no_hdr0=''),
    51393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51393, CurrentID=0, Status='live', Symbol='TRPV2', Aliases=['VRL', 'VRL-1', 'VRL1'], description='transient receptor potential cation channel subfamily V member 2', other_designations='transient receptor potential cation channel subfamily V member 2|OTRPC2|osm-9-like TRP channel 2|vanilloid receptor-like protein 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16415543, end_position_on_the_genomic_accession=16437003, orientation='plus', exon_count=16, OMIM=[606676], no_hdr0=''),
    51397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51397, CurrentID=0, Status='live', Symbol='COMMD10', Aliases=['PTD002'], description='COMM domain containing 10', other_designations='COMM domain-containing protein 10', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=116085025, end_position_on_the_genomic_accession=116293287, orientation='plus', exon_count=12, OMIM=[616704], no_hdr0=''),
    51398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51398, CurrentID=0, Status='live', Symbol='WDR83OS', Aliases=['ASTERIX', 'C19orf56', 'PAT-10', 'PAT10', 'PTD008'], description='WD repeat domain 83 opposite strand', other_designations='PAT complex subunit Asterix|UPF0139 membrane protein C19orf56|WDR83 opposite strand|protein Asterix|protein associated with the ER translocon of 10kDa', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12668071, end_position_on_the_genomic_accession=12671023, orientation='minus', exon_count=5, OMIM=[618474], no_hdr0=''),
    51399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51399, CurrentID=0, Status='live', Symbol='TRAPPC4', Aliases=['CGI-104', 'HSPC172', 'NEDESBA', 'PTD009', 'SBDN', 'SYNBINDIN', 'TRS23'], description='trafficking protein particle complex subunit 4', other_designations='trafficking protein particle complex subunit 4|TRS23 homolog|hematopoietic stem/progenitor cell protein 172|trafficking protein particle complex 4', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119018766, end_position_on_the_genomic_accession=119024134, orientation='plus', exon_count=5, OMIM=[610971], no_hdr0=''),
    51400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51400, CurrentID=0, Status='live', Symbol='PPME1', Aliases=['ABDH19', 'PME-1'], description='protein phosphatase methylesterase 1', other_designations='protein phosphatase methylesterase 1|testicular secretory protein Li 39', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74171090, end_position_on_the_genomic_accession=74254703, orientation='plus', exon_count=15, OMIM=[611117], no_hdr0=''),
    51406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51406, CurrentID=0, Status='live', Symbol='NOL7', Aliases=['C6orf90', 'PQBP3', 'RARG-1', 'dJ223E5.2'], description='nucleolar protein 7', other_designations='nucleolar protein 7|nucleolar protein 7, 27kDa|nucleolar protein of 27 kDa|polyglutamine binding protein 3|retinoic acid repressible protein', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13615335, end_position_on_the_genomic_accession=13632470, orientation='plus', exon_count=9, OMIM=[611533], no_hdr0=''),
    51409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51409, CurrentID=0, Status='live', Symbol='HEMK1', Aliases=['HEMK', 'MPRMC', 'MTQ1'], description='HemK methyltransferase family member 1', other_designations='MTRF1L release factor glutamine methyltransferase|HEMK homolog 7kb|m.HsaHemKP|testis secretory sperm-binding protein Li 225n', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50569152, end_position_on_the_genomic_accession=50596166, orientation='plus', exon_count=14, OMIM=[618609], no_hdr0=''),
    51411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51411, CurrentID=0, Status='live', Symbol='BIN2', Aliases=['BRAP-1'], description='bridging integrator 2', other_designations='bridging integrator 2|breast cancer associated protein BRAP1|breast cancer-associated protein 1', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51281038, end_position_on_the_genomic_accession=51324668, orientation='minus', exon_count=15, OMIM=[605936], no_hdr0=''),
    51412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51412, CurrentID=0, Status='live', Symbol='ACTL6B', Aliases=['ACTL6', 'BAF53B', 'DEE76', 'EIEE76', 'IDDSSAD', 'arpNalpha'], description='actin like 6B', other_designations='actin-like protein 6B|53 kDa BRG1-associated factor B|BRG1-associated factor 53B|actin-related protein Baf53b|hArpN alpha', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100643097, end_position_on_the_genomic_accession=100656448, orientation='minus', exon_count=14, OMIM=[612458], no_hdr0=''),
    51421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51421, CurrentID=0, Status='live', Symbol='AMOTL2', Aliases=['LCCP'], description='angiomotin like 2', other_designations='angiomotin-like protein 2|Leman coiled-coil protein', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134355345, end_position_on_the_genomic_accession=134375417, orientation='minus', exon_count=13, OMIM=[614658], no_hdr0=''),
    51422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51422, CurrentID=0, Status='live', Symbol='PRKAG2', Aliases=['AAKG', 'AAKG2', 'CMH6', 'H91620p', 'WPWS'], description='protein kinase AMP-activated non-catalytic subunit gamma 2', other_designations="5'-AMP-activated protein kinase subunit gamma-2|AMPK subunit gamma-2|epididymis secretory sperm binding protein|protein kinase, AMP-activated, gamma 2 non-catalytic subunit", map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151556124, end_position_on_the_genomic_accession=151877115, orientation='minus', exon_count=22, OMIM=[602743], no_hdr0=''),
    51426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51426, CurrentID=0, Status='live', Symbol='POLK', Aliases=['DINB1', 'DINP', 'POLQ'], description='DNA polymerase kappa', other_designations='DNA polymerase kappa|polymerase (DNA directed) kappa', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75511891, end_position_on_the_genomic_accession=75601144, orientation='plus', exon_count=18, OMIM=[605650], no_hdr0=''),
    51427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51427, CurrentID=0, Status='live', Symbol='ZNF107', Aliases=['Y8', 'ZFD25', 'ZNF588', 'smap-7'], description='zinc finger protein 107', other_designations='zinc finger protein 107|C2H2 type zinc-finger protein|zinc finger protein (ZFD25)|zinc finger protein 588', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64665010, end_position_on_the_genomic_accession=64711582, orientation='plus', exon_count=9, OMIM=[603989], no_hdr0=''),
    51428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51428, CurrentID=0, Status='live', Symbol='DDX41', Aliases=['ABS', 'MPLPF'], description='DEAD-box helicase 41', other_designations='probable ATP-dependent RNA helicase DDX41|DEAD (Asp-Glu-Ala-Asp) box polypeptide 41|DEAD box protein 41|DEAD box protein abstrakt homolog|DEAD-box protein abstrakt|putative RNA helicase', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177511577, end_position_on_the_genomic_accession=177516961, orientation='minus', exon_count=17, OMIM=[608170], no_hdr0=''),
    51429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51429, CurrentID=0, Status='live', Symbol='SNX9', Aliases=['SDP1', 'SH3PX1', 'SH3PXD3A', 'WISP'], description='sorting nexin 9', other_designations='sorting nexin-9|SH3 and PX domain-containing protein 1|SH3 and PX domain-containing protein 3A|Wiskott-Aldrich syndrome protein (WASP) interactor protein', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=157716046, end_position_on_the_genomic_accession=157945077, orientation='plus', exon_count=22, OMIM=[605952], no_hdr0=''),
    51430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51430, CurrentID=0, Status='live', Symbol='SUCO', Aliases=['C1orf9', 'CH1', 'OPT', 'SLP1'], description='SUN domain containing ossification factor', other_designations='SUN domain-containing ossification factor|SUN-like protein 1|membrane protein CH1|osteopotentia', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=172532349, end_position_on_the_genomic_accession=172611833, orientation='plus', exon_count=26, OMIM=[619434], no_hdr0=''),
    51433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51433, CurrentID=0, Status='live', Symbol='ANAPC5', Aliases=['APC5'], description='anaphase promoting complex subunit 5', other_designations='anaphase-promoting complex subunit 5|cyclosome subunit 5', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121308245, end_position_on_the_genomic_accession=121354209, orientation='minus', exon_count=18, OMIM=[606948], no_hdr0=''),
    51434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51434, CurrentID=0, Status='live', Symbol='ANAPC7', Aliases=['APC7'], description='anaphase promoting complex subunit 7', other_designations='anaphase-promoting complex subunit 7|cyclosome subunit 7', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110372900, end_position_on_the_genomic_accession=110403730, orientation='minus', exon_count=13, OMIM=[606949], no_hdr0=''),
    51435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51435, CurrentID=0, Status='live', Symbol='SCARA3', Aliases=['APC7', 'CSR', 'CSR1', 'MSLR1', 'MSRL1'], description='scavenger receptor class A member 3', other_designations='scavenger receptor class A member 3|cellular stress response gene protein|cellular stress response protein|macrophage scavenger receptor-like 1', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27633665, end_position_on_the_genomic_accession=27736594, orientation='plus', exon_count=11, OMIM=[602728], no_hdr0=''),
    51438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51438, CurrentID=0, Status='live', Symbol='MAGEC2', Aliases=['CT10', 'HCA587', 'MAGEE1'], description='MAGE family member C2', other_designations='melanoma-associated antigen C2|MAGE-C2 antigen|MAGE-E1 antigen|cancer/testis antigen 10|hepatocellular cancer antigen 587|hepatocellular carcinoma-associated antigen 587|melanoma antigen family C, 2|melanoma antigen family C2|melanoma antigen, family E, 1, cancer/testis specific', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=142202342, end_position_on_the_genomic_accession=142205290, orientation='minus', exon_count=3, OMIM=[300468], no_hdr0=''),
    51439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51439, CurrentID=0, Status='live', Symbol='FAM8A1', Aliases=['AHCP'], description='family with sequence similarity 8 member A1', other_designations='protein FAM8A1|Autosomal Highly Conserved Protein', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17600302, end_position_on_the_genomic_accession=17611715, orientation='plus', exon_count=5, OMIM=[618409], no_hdr0=''),
    51440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51440, CurrentID=0, Status='live', Symbol='HPCAL4', Aliases=['HLP4'], description='hippocalcin like 4', other_designations='hippocalcin-like protein 4', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39678648, end_position_on_the_genomic_accession=39691433, orientation='minus', exon_count=6, OMIM=[619211], no_hdr0=''),
    51441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51441, CurrentID=0, Status='live', Symbol='YTHDF2', Aliases=['CAHL', 'DF2', 'HGRG8', 'NY-REN-2'], description='YTH N6-methyladenosine RNA binding protein 2', other_designations='YTH domain-containing family protein 2|9430020E02Rik|CLL-associated antigen KW-14|YTH N(6)-methyladenosine RNA binding protein 2|YTH domain family, member 2|high-glucose-regulated protein 8|renal carcinoma antigen NY-REN-2', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28736624, end_position_on_the_genomic_accession=28769775, orientation='plus', exon_count=6, OMIM=[610640], no_hdr0=''),
    51442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51442, CurrentID=0, Status='live', Symbol='VGLL1', Aliases=['TDU', 'VGL1'], description='vestigial like family member 1', other_designations='transcription cofactor vestigial-like protein 1|TONDU|WUGSC:H_GS188P18.1b|vestigial like 1|vgl-1', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136532215, end_position_on_the_genomic_accession=136556799, orientation='plus', exon_count=5, OMIM=[300583], no_hdr0=''),
    51444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51444, CurrentID=0, Status='live', Symbol='RNF138', Aliases=['HSD-4', 'NARF', 'STRIN', 'hNARF'], description='ring finger protein 138', other_designations='E3 ubiquitin-protein ligase RNF138|NLK-associated RING finger protein|Nemo-like kinase-associated RING finger protein|RING-type E3 ubiquitin transferase RNF138|nemo-like kinase associated ring finger protein|ring finger protein 138, E3 ubiquitin protein ligase|testicular tissue protein Li 165', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32091858, end_position_on_the_genomic_accession=32131561, orientation='plus', exon_count=9, OMIM=[616319], no_hdr0=''),
    51447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51447, CurrentID=0, Status='live', Symbol='IP6K2', Aliases=['IHPK2', 'InsP6K2', 'PIUS'], description='inositol hexakisphosphate kinase 2', other_designations='inositol hexakisphosphate kinase 2|ATP:1D-myo-inositol-hexakisphosphate phosphotransferase|inositol hexaphosphate kinase 2|insp6 kinase 2|pi uptake stimulator', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48688003, end_position_on_the_genomic_accession=48717258, orientation='minus', exon_count=14, OMIM=[606992], no_hdr0=''),
    51449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51449, CurrentID=0, Status='live', Symbol='PCYOX1', Aliases=['PCL1'], description='prenylcysteine oxidase 1', other_designations='prenylcysteine oxidase 1|prenylcysteine lyase', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70258137, end_position_on_the_genomic_accession=70281185, orientation='plus', exon_count=6, OMIM=[610995], no_hdr0=''),
    51450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51450, CurrentID=0, Status='live', Symbol='PRRX2', Aliases=['PMX2', 'PRX2'], description='paired related homeobox 2', other_designations='paired mesoderm homeobox protein 2|PRX-2|paired-like homeodomain protein PRX2|paired-related homeobox protein 2|testicular tissue protein Li 148|testicular tissue protein Li 160', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129665647, end_position_on_the_genomic_accession=129722674, orientation='plus', exon_count=5, OMIM=[604675], no_hdr0=''),
    51451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51451, CurrentID=0, Status='live', Symbol='LCMT1', Aliases=['CGI-68', 'LCMT', 'PPMT1'], description='leucine carboxyl methyltransferase 1', other_designations='leucine carboxyl methyltransferase 1|[Phosphatase 2A protein]-leucine-carboxy methyltransferase 1|protein phosphatase methyltransferase 1|protein-leucine O-methyltransferase', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=25111702, end_position_on_the_genomic_accession=25178231, orientation='plus', exon_count=12, OMIM=[610286], no_hdr0=''),
    51454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51454, CurrentID=0, Status='live', Symbol='GULP1', Aliases=['CED-6', 'CED6', 'GULP'], description='GULP PTB domain containing engulfment adaptor 1', other_designations='PTB domain-containing engulfment adapter protein 1|GULP, engulfment adaptor PTB domain containing 1|PTB domain adapter protein CED-6|PTB domain adaptor protein CED-6|cell death protein 6 homolog|engulfment adapter protein', map_location='2q32.1-q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=188291699, end_position_on_the_genomic_accession=188595926, orientation='plus', exon_count=21, OMIM=[608165], no_hdr0=''),
    51455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51455, CurrentID=0, Status='live', Symbol='REV1', Aliases=['AIBP80L', 'REV1'], description='REV1 DNA directed polymerase', other_designations='DNA repair protein REV1|REV1 homolog|REV1, polymerase (DNA directed)|REV1- like|alpha integrin-binding protein 80|rev1-like terminal deoxycytidyl transferase', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99400477, end_position_on_the_genomic_accession=99490123, orientation='minus', exon_count=29, OMIM=[606134], no_hdr0=''),
    51458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51458, CurrentID=0, Status='live', Symbol='RHCG', Aliases=['C15orf6', 'PDRC2', 'RHGK', 'SLC42A3'], description='Rh family C glycoprotein', other_designations='ammonium transporter Rh type C|Rh type C glycoprotein|Rhesus blood group, C glycoprotein|rh family type C glycoprotein|rh glycoprotein kidney|rhesus blood group family type C glycoprotein|tumor-related protein DRC2', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89471407, end_position_on_the_genomic_accession=89496583, orientation='minus', exon_count=11, OMIM=[605381], no_hdr0=''),
    51460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51460, CurrentID=0, Status='live', Symbol='SFMBT1', Aliases=['RU1', 'SFMBT', 'hSFMBT'], description='Scm like with four mbt domains 1', other_designations='scm-like with four MBT domains protein 1|Scm-related gene containing four mbt domains|Scm-related gene product containing four mbt domains|renal ubiquitous protein 1', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52899209, end_position_on_the_genomic_accession=53046655, orientation='minus', exon_count=24, OMIM=[607319], no_hdr0=''),
    51463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51463, CurrentID=0, Status='live', Symbol='GPR89B', Aliases=['GPHR', 'GPR89', 'GPR89C', 'SH120', 'UNQ192'], description='G protein-coupled receptor 89B', other_designations='Golgi pH regulator B|G protein-coupled receptor 89C|Golgi pH regulator A|protein GPR89|putative Golgi pH regulator C|putative MAPK-activating protein PM01|putative NF-kappa-B-activating protein 90|putative protein GPR89C', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=147928420, end_position_on_the_genomic_accession=147993592, orientation='plus', exon_count=17, OMIM=[612806], no_hdr0=''),
    51465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51465, CurrentID=0, Status='live', Symbol='UBE2J1', Aliases=['CGI-76', 'HSPC153', 'HSPC205', 'HSU93243', 'NCUBE-1', 'NCUBE1', 'UBC6', 'UBC6E', 'Ubc6p'], description='ubiquitin conjugating enzyme E2 J1', other_designations='ubiquitin-conjugating enzyme E2 J1|E2 ubiquitin-conjugating enzyme J1|HSUBC6e|non-canonical ubiquitin-conjugating enzyme 1|ubiquitin-conjugating enzyme E2, J1 (UBC6 homolog, yeast)|ubiquitin-conjugating enzyme E2, J1, U|yeast ubiquitin-conjugating enzyme UBC6 homolog E', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89326625, end_position_on_the_genomic_accession=89353155, orientation='minus', exon_count=8, OMIM=[616175], no_hdr0=''),
    51466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51466, CurrentID=0, Status='live', Symbol='EVL', Aliases=['RNB6'], description='Enah/Vasp-like', other_designations='ena/VASP-like protein|ena/vasodilator-stimulated phosphoprotein-like|epididymis secretory sperm binding protein', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99971422, end_position_on_the_genomic_accession=100144236, orientation='plus', exon_count=21, OMIM=[616912], no_hdr0=''),
    51471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51471, CurrentID=0, Status='live', Symbol='NAT8B', Aliases=['CML2', 'Hcml2P', 'NAT8B'], description='N-acetyltransferase 8B (putative, gene/pseudogene)', other_designations='putative N-acetyltransferase 8B|ATase1|N-acetyltransferase 8B (GCN5-related, putative, gene/pseudogene)|N-acetyltransferase Camello 2|acetyltransferase 1|camello-like protein 2|probable N-acetyltransferase 8B', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73700509, end_position_on_the_genomic_accession=73701340, orientation='minus', exon_count=1, OMIM=[608190], no_hdr0=''),
    51473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51473, CurrentID=0, Status='live', Symbol='DCDC2', Aliases=['DCDC2A', 'DFNB66', 'NPHP19', 'NSC', 'RU2', 'RU2S'], description='doublecortin domain containing 2', other_designations='doublecortin domain-containing protein 2|nephronophthisis 19', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24171755, end_position_on_the_genomic_accession=24383292, orientation='minus', exon_count=11, OMIM=[605755], no_hdr0=''),
    51474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51474, CurrentID=0, Status='live', Symbol='LIMA1', Aliases=['EPLIN', 'LDLCQ8', 'SREBP3'], description='LIM domain and actin binding 1', other_designations='LIM domain and actin-binding protein 1|epithelial protein lost in neoplasm beta|sterol regulatory element binding protein 3', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50175788, end_position_on_the_genomic_accession=50283520, orientation='minus', exon_count=13, OMIM=[608364], no_hdr0=''),
    51475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51475, CurrentID=0, Status='live', Symbol='CABP2', Aliases=['DFNB93'], description='calcium binding protein 2', other_designations='calcium-binding protein 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67518912, end_position_on_the_genomic_accession=67523446, orientation='minus', exon_count=7, OMIM=[607314], no_hdr0=''),
    51477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51477, CurrentID=0, Status='live', Symbol='ISYNA1', Aliases=['INO1', 'INOS', 'IPS', 'IPS 1', 'IPS-1'], description='inositol-3-phosphate synthase 1', other_designations='inositol-3-phosphate synthase 1|MI-1-P synthase|MIP synthase|myo-inositol 1-phosphate synthase A1|testis secretory sperm-binding protein Li 200a', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18434388, end_position_on_the_genomic_accession=18438649, orientation='minus', exon_count=11, OMIM=[611670], no_hdr0=''),
    51478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51478, CurrentID=0, Status='live', Symbol='HSD17B7', Aliases=['PRAP', 'SDR37C1'], description='hydroxysteroid 17-beta dehydrogenase 7', other_designations='3-keto-steroid reductase/17-beta-hydroxysteroid dehydrogenase 7|17 beta-hydroxysteroid dehydrogenase type VII|17-beta-HSD 7|17-beta-hydroxysteroid dehydrogenase 7|17beta hydroxysteroid dehydrogenase|3-keto-steroid reductase|dihydrotestosterone oxidoreductase|estradiol 17-beta-dehydrogenase 7|short chain dehydrogenase/reductase family 37C member 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162790702, end_position_on_the_genomic_accession=162812823, orientation='plus', exon_count=10, OMIM=[606756], no_hdr0=''),
    51479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51479, CurrentID=0, Status='live', Symbol='ANKFY1', Aliases=['ANKHZN', 'BTBD23', 'ZFYVE14'], description='ankyrin repeat and FYVE domain containing 1', other_designations='rabankyrin-5|Rabankyrin-5|ankyrin repeat and FYVE domain-containing protein 1|ankyrin repeat hooked to zinc finger motif|ankyrin repeats hooked to a zinc finger motif|rank-5', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4163820, end_position_on_the_genomic_accession=4263979, orientation='minus', exon_count=29, OMIM=[607927], no_hdr0=''),
    51480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51480, CurrentID=0, Status='live', Symbol='VCX2', Aliases=['VCX-2rR', 'VCXB', 'VCX2'], description='variable charge X-linked 2', other_designations='variable charge X-linked protein 2|variable charge protein on X with two repeats|variably charged protein X-B|variably charged, X chromosome 2|variably charged, X chromosome B|variably charged, X chromosome, with 2 repeats', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=8169944, end_position_on_the_genomic_accession=8171267, orientation='minus', exon_count=3, OMIM=[300532], no_hdr0=''),
    51481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51481, CurrentID=0, Status='live', Symbol='VCX3A', Aliases=['VCX-8r', 'VCX-A', 'VCX3', 'VCX8R', 'VCXA'], description='variable charge X-linked 3A', other_designations='variable charge X-linked protein 3|variable charge protein on X with eight repeats|variably charged X-A|variably charged protein X-A', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=6533618, end_position_on_the_genomic_accession=6535118, orientation='minus', exon_count=3, OMIM=[300533], no_hdr0=''),
    51490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51490, CurrentID=0, Status='live', Symbol='SPOUT1', Aliases=['C9orf114', 'CENP-32', 'CENP32', 'HSPC109'], description='SPOUT domain containing methyltransferase 1', other_designations='putative methyltransferase C9orf114|centromere protein 32|kinetochore-associated protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128819651, end_position_on_the_genomic_accession=128833309, orientation='minus', exon_count=13, OMIM=[617614], no_hdr0=''),
    51491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51491, CurrentID=0, Status='live', Symbol='NOP16', Aliases=['HSPC111', 'HSPC185'], description='NOP16 nucleolar protein', other_designations='nucleolar protein 16|HBV pre-S2 trans-regulated protein 3|NOP16 nucleolar protein homolog|hypothetical protein HSPC111|nucleolar protein 16 homolog', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176383937, end_position_on_the_genomic_accession=176388606, orientation='minus', exon_count=6, OMIM=[612861], no_hdr0=''),
    51493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51493, CurrentID=0, Status='live', Symbol='RTCB', Aliases=['C22orf28', 'DJ149A16.6', 'FAAP', 'HSPC117'], description="RNA 2',3'-cyclic phosphate and 5'-OH ligase", other_designations="RNA-splicing ligase RtcB homolog|3'-phosphate/5'-hydroxy nucleic acid ligase|ankyrin repeat domain 54|focal adhesion-associated protein|tRNA-splicing ligase RtcB homolog", map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32387582, end_position_on_the_genomic_accession=32412247, orientation='minus', exon_count=12, OMIM=[613901], no_hdr0=''),
    51495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51495, CurrentID=0, Status='live', Symbol='HACD3', Aliases=['B-IND1', 'BIND1', 'HSPC121', 'PTPLAD1'], description='3-hydroxyacyl-CoA dehydratase 3', other_designations='very-long-chain (3R)-3-hydroxyacyl-CoA dehydratase 3|butyrate-induced protein 1|butyrate-induced transcript 1|protein tyrosine phosphatase-like A domain containing 1|protein tyrosine phosphatase-like protein PTPLAD1|protein-tyrosine phosphatase-like A domain-containing protein 1|very-long-chain (3R)-3-hydroxyacyl-[acyl-carrier protein] dehydratase 3', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65530463, end_position_on_the_genomic_accession=65578355, orientation='plus', exon_count=12, OMIM=[615940], no_hdr0=''),
    51496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51496, CurrentID=0, Status='live', Symbol='CTDSPL2', Aliases=['HSPC058', 'HSPC129', 'SCP4'], description='CTD small phosphatase like 2', other_designations='CTD small phosphatase-like protein 2|CTD (carboxy-terminal domain, RNA polymerase II, polypeptide A) small phosphatase like 2|CTDSP-like 2', map_location='15q15.3-q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44427329, end_position_on_the_genomic_accession=44529038, orientation='plus', exon_count=16, OMIM=[618739], no_hdr0=''),
    51497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51497, CurrentID=0, Status='live', Symbol='NELFCD', Aliases=['HSPC130', 'NELF-C', 'NELF-D', 'TH1', 'TH1L'], description='negative elongation factor complex member C/D', other_designations='negative elongation factor C/D|NELF-C/D|TH1 drosophila homolog|TH1-like protein|negative elongation factor proteins C and D|trihydrophobin 1', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58981252, end_position_on_the_genomic_accession=58995133, orientation='plus', exon_count=15, OMIM=[605297], no_hdr0=''),
    51499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51499, CurrentID=0, Status='live', Symbol='TRIAP1', Aliases=['HSPC132', 'MDM35', 'P53CSV', 'WF-1'], description='TP53 regulated inhibitor of apoptosis 1', other_designations='TP53-regulated inhibitor of apoptosis 1|mitochondrial distribution and morphology 35 homolog|p53-inducible cell-survival factor|protein 15E1.1', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120443964, end_position_on_the_genomic_accession=120446384, orientation='minus', exon_count=2, OMIM=[614943], no_hdr0=''),
    51501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51501, CurrentID=0, Status='live', Symbol='HIKESHI', Aliases=['C11orf73', 'HLD13', 'HSPC138', 'HSPC179', 'L7RN6', 'OPI10'], description='heat shock protein nuclear import factor hikeshi', other_designations='protein Hikeshi|Hikeshi, heat shock protein nuclear import factor|lethal, Chr 7, Rinchik 6', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86302229, end_position_on_the_genomic_accession=86345943, orientation='plus', exon_count=8, OMIM=[614908], no_hdr0=''),
    51503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51503, CurrentID=0, Status='live', Symbol='CWC15', Aliases=['AD002', 'C11orf5', 'Cwf15', 'HSPC148', 'ORF5'], description='CWC15 spliceosome associated protein homolog', other_designations='spliceosome-associated protein CWC15 homolog|CWC15 spliceosome-associated protein', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94962620, end_position_on_the_genomic_accession=94973556, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    51504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51504, CurrentID=0, Status='live', Symbol='TRMT112', Aliases=['HSPC152', 'HSPC170', 'TRM112', 'TRMT11-2', 'hTrm112'], description='tRNA methyltransferase activator subunit 11-2', other_designations='multifunctional methyltransferase subunit TRM112-like protein|TRM112-like protein|tRNA methyltransferase 11-2 homolog|tRNA methyltransferase 112 homolog|tRNA methyltransferase subunit 11-2', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64316460, end_position_on_the_genomic_accession=64318596, orientation='minus', exon_count=6, OMIM=[618630], no_hdr0=''),
    51506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51506, CurrentID=0, Status='live', Symbol='UFC1', Aliases=['HSPC155', 'NEDSG'], description='ubiquitin-fold modifier conjugating enzyme 1', other_designations='ubiquitin-fold modifier-conjugating enzyme 1|Ufm1-conjugating enzyme 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161132703, end_position_on_the_genomic_accession=161158856, orientation='plus', exon_count=8, OMIM=[610554], no_hdr0=''),
    51507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51507, CurrentID=0, Status='live', Symbol='RTF2', Aliases=['C20orf43', 'CDAO5', 'HSPC164', 'RTFDC1', 'SHUJUN-3'], description='replication termination factor 2', other_designations='replication termination factor 2|UPF0549 protein C20orf43|protein RTF2 homolog|replication termination factor 2 domain containing 1|replication termination factor 2 domain-containing protein 1', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56468627, end_position_on_the_genomic_accession=56519449, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    51510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51510, CurrentID=0, Status='live', Symbol='CHMP5', Aliases=['C9orf83', 'CGI-34', 'HSPC177', 'PNAS-2', 'SNF7DC2', 'Vps60'], description='charged multivesicular body protein 5', other_designations='charged multivesicular body protein 5|SNF7 domain containing 2|SNF7 domain-containing protein 2|apoptosis-related protein PNAS-2|chromatin-modifying protein 5|hVps60|vacuolar protein sorting-associated protein 60', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33265049, end_position_on_the_genomic_accession=33282070, orientation='plus', exon_count=8, OMIM=[610900], no_hdr0=''),
    51512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51512, CurrentID=0, Status='live', Symbol='GTSE1', Aliases=['B99'], description='G2 and S-phase expressed 1', other_designations='G2 and S phase-expressed protein 1|G-2 and S-phase expressed 1|protein B99 homolog', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46295143, end_position_on_the_genomic_accession=46333699, orientation='plus', exon_count=14, OMIM=[607477], no_hdr0=''),
    51513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51513, CurrentID=0, Status='live', Symbol='ETV7', Aliases=['TEL-2', 'TEL2', 'TELB'], description='ETS variant transcription factor 7', other_designations='transcription factor ETV7|ETS translocation variant 7|ETS variant 7|ETS-related protein Tel2|Ets transcription factor TEL-2b|TEL2 oncogene|ets variant gene 7 (TEL2 oncogene)|tel-related Ets factor', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36354088, end_position_on_the_genomic_accession=36387669, orientation='minus', exon_count=10, OMIM=[605255], no_hdr0=''),
    51514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51514, CurrentID=0, Status='live', Symbol='DTL', Aliases=['CDT2', 'DCAF2', 'L2DTL', 'RAMP'], description='denticleless E3 ubiquitin protein ligase homolog', other_designations='denticleless protein homolog|DDB1- and CUL4-associated factor 2|RA-regulated nuclear matrix-associated protein|lethal(2) denticleless protein homolog|retinoic acid-regulated nuclear matrix-associated protein', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212035748, end_position_on_the_genomic_accession=212105013, orientation='plus', exon_count=16, OMIM=[610617], no_hdr0=''),
    51517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51517, CurrentID=0, Status='live', Symbol='NCKIPSD', Aliases=['AF3P21', 'DIP', 'DIP1', 'ORF1', 'SPIN90', 'VIP54', 'WASLBP', 'WISH'], description='NCK interacting protein with SH3 domain', other_designations='NCK-interacting protein with SH3 domain|54 kDa VacA-interacting protein|54 kDa vimentin-interacting protein|90 kDa SH3 protein interacting with Nck|SH3 adapter protein SPIN90|SH3 protein interacting with Nck, 90 kDa|WASP-interacting SH3-domain protein|dia interacting protein|dia-interacting protein 1|diaphanous protein interacting protein|wiskott-Aldrich syndrome protein-interacting protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48663814, end_position_on_the_genomic_accession=48685941, orientation='minus', exon_count=15, OMIM=[606671], no_hdr0=''),
    51520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51520, CurrentID=0, Status='live', Symbol='LARS1', Aliases=['HSPC192', 'ILFS1', 'LARS', 'LEURS', 'LEUS', 'LFIS', 'LRS', 'PIG44', 'RNTLS', 'hr025Cl'], description='leucyl-tRNA synthetase 1', other_designations='leucine--tRNA ligase, cytoplasmic|cytoplasmic leucyl-tRNA synthetase|cytosolic leucyl-tRNA synthetase|leucine tRNA ligase 1, cytoplasmic|leucine translase|proliferation-inducing gene 44', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146113034, end_position_on_the_genomic_accession=146182731, orientation='minus', exon_count=32, OMIM=[151350], no_hdr0=''),
    51522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51522, CurrentID=0, Status='live', Symbol='TMEM14C', Aliases=['C6orf53', 'HSPC194', 'MSTP073', 'NET26', 'bA421M1.6'], description='transmembrane protein 14C', other_designations='transmembrane protein 14C', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10723070, end_position_on_the_genomic_accession=10731127, orientation='plus', exon_count=6, OMIM=[615318], no_hdr0=''),
    51523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51523, CurrentID=0, Status='live', Symbol='CXXC5', Aliases=['CF5', 'HSPC195', 'RINF', 'WID'], description='CXXC finger protein 5', other_designations='CXXC-type zinc finger protein 5|CXXC finger 5 protein|WT1-induced Inhibitor of Dishevelled|putative MAPK-activating protein PM08|putative NF-kappa-B-activating protein 102|retinoid-inducible nuclear factor', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139647299, end_position_on_the_genomic_accession=139683882, orientation='plus', exon_count=11, OMIM=[612752], no_hdr0=''),
    51524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51524, CurrentID=0, Status='live', Symbol='TMEM138', Aliases=['HSPC196'], description='transmembrane protein 138', other_designations='transmembrane protein 138', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61362361, end_position_on_the_genomic_accession=61378224, orientation='plus', exon_count=8, OMIM=[614459], no_hdr0=''),
    51526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51526, CurrentID=0, Status='live', Symbol='OSER1', Aliases=['C20orf111', 'HSPC207', 'Osr1', 'Perit1', 'dJ1183I21.1'], description='oxidative stress responsive serine rich 1', other_designations='oxidative stress-responsive serine-rich protein 1|oxidative stress-responsive 1|oxidative stress-responsive protein 1|peroxide-inducible transcript 1 protein', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44195939, end_position_on_the_genomic_accession=44217229, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    51527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51527, CurrentID=0, Status='live', Symbol='GSKIP', Aliases=['C14orf129', 'HSPC210'], description='GSK3B interacting protein', other_designations='GSK3B-interacting protein|GSK3-beta interaction protein', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96363526, end_position_on_the_genomic_accession=96387290, orientation='plus', exon_count=5, OMIM=[616605], no_hdr0=''),
    51528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51528, CurrentID=0, Status='live', Symbol='JKAMP', Aliases=['C14orf100', 'C24orf100', 'CDA06', 'HSPC213', 'HSPC327', 'JAMP'], description='JNK1/MAPK8 associated membrane protein', other_designations='JNK1/MAPK8-associated membrane protein|JNK-associated membrane protein|Jun N-terminal kinase 1-associated membrane protein|medulloblastoma antigen MU-MB-50.4', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59484495, end_position_on_the_genomic_accession=59505410, orientation='plus', exon_count=8, OMIM=[611176], no_hdr0=''),
    51529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51529, CurrentID=0, Status='live', Symbol='ANAPC11', Aliases=['APC11', 'Apc11p', 'HSPC214'], description='anaphase promoting complex subunit 11', other_designations='anaphase-promoting complex subunit 11|APC11 anaphase promoting complex subunit 11 homolog|anaphase promoting complex subunit 11 (yeast APC11 homolog)|cyclosome subunit 11|hepatocellular carcinoma-associated RING finger protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81890790, end_position_on_the_genomic_accession=81900533, orientation='plus', exon_count=8, OMIM=[614534], no_hdr0=''),
    51530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51530, CurrentID=0, Status='live', Symbol='ZC3HC1', Aliases=['HSPC216', 'NIPA'], description='zinc finger C3HC-type containing 1', other_designations='nuclear-interacting partner of ALK|hematopoietic stem/progenitor cell protein 216|nuclear interacting partner of anaplastic lymphoma kinase (ALK)', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130018286, end_position_on_the_genomic_accession=130051451, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    51531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51531, CurrentID=0, Status='live', Symbol='TRMO', Aliases=['C9orf156', 'HSPC219', 'NAP1'], description='tRNA methyltransferase O', other_designations='tRNA (adenine(37)-N6)-methyltransferase|Nef (lentivirus myristoylated factor) associated protein 1|Nef associated protein 1|nef-associated protein 1|thioesterase NAP1', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97896855, end_position_on_the_genomic_accession=97922549, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    51533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51533, CurrentID=0, Status='live', Symbol='PHF7', Aliases=['HSPC045', 'HSPC226', 'NYD-SP6'], description='PHD finger protein 7', other_designations='PHD finger protein 7|testicular secretory protein Li 34|testis development protein NYD-SP6', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52410624, end_position_on_the_genomic_accession=52423641, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    51534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51534, CurrentID=0, Status='live', Symbol='VTA1', Aliases=['6orf55', 'C6orf55', 'DRG-1', 'DRG1', 'HSPC228', 'LIP5', 'My012', 'SBP1'], description='vesicle trafficking 1', other_designations='vacuolar protein sorting-associated protein VTA1 homolog|LYST-interacting protein 5|SKD1-binding protein 1|Vps20-associated 1 homolog|dopamine-responsive gene 1 protein|homolog of mouse SKD1-binding protein 1|vesicle (multivesicular body) trafficking 1', map_location='6q24.1-q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=142147263, end_position_on_the_genomic_accession=142224685, orientation='plus', exon_count=8, OMIM=[610902], no_hdr0=''),
    51535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51535, CurrentID=0, Status='live', Symbol='PPHLN1', Aliases=['CR', 'HSPC206', 'HSPC232'], description='periphilin 1', other_designations='periphilin-1|CDC7 expression repressor|gastric cancer antigen Ga50', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=42326126, end_position_on_the_genomic_accession=42448621, orientation='plus', exon_count=16, OMIM=[608150], no_hdr0=''),
    51537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51537, CurrentID=0, Status='live', Symbol='MTFP1', Aliases=['HSPC242', 'MTP18'], description='mitochondrial fission process 1', other_designations='mitochondrial fission process protein 1|mitochondrial 18 kDa protein|mitochondrial fission protein MTP18|mitochondrial protein 18 kDa', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30425768, end_position_on_the_genomic_accession=30429054, orientation='plus', exon_count=4, OMIM=[610235], no_hdr0=''),
    51538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51538, CurrentID=0, Status='live', Symbol='ZCCHC17', Aliases=['HSPC251', 'PS1D', 'pNO40'], description='zinc finger CCHC-type containing 17', other_designations='nucleolar protein of 40 kDa|nucleolar protein 40|pnn-interacting nucleolar protein|putative S1 RNA binding domain protein|zinc finger CCHC domain-containing protein 17|zinc finger, CCHC domain containing 17', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31297032, end_position_on_the_genomic_accession=31365722, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    51540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51540, CurrentID=0, Status='live', Symbol='SCLY', Aliases=['SCL', 'hSCL'], description='selenocysteine lyase', other_designations='selenocysteine lyase', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238061001, end_position_on_the_genomic_accession=238099413, orientation='plus', exon_count=12, OMIM=[611056], no_hdr0=''),
    51542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51542, CurrentID=0, Status='live', Symbol='VPS54', Aliases=['HCC8', 'PPP1R164', 'SLP-8pL', 'WR', 'hVps54L', 'VPS54'], description='VPS54 subunit of GARP complex', other_designations='vacuolar protein sorting-associated protein 54|VPS54, GARP complex subunit|hepatocellular carcinoma protein 8|protein phosphatase 1, regulatory subunit 164|tumor antigen HOM-HCC-8|tumor antigen SLP-8p|vacuolar protein sorting 54 homolog', map_location='2p15-p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=63892149, end_position_on_the_genomic_accession=64019428, orientation='minus', exon_count=25, OMIM=[614633], no_hdr0=''),
    51545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51545, CurrentID=0, Status='live', Symbol='ZNF581', Aliases=['HSPC189'], description='zinc finger protein 581', other_designations='zinc finger protein 581', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55635028, end_position_on_the_genomic_accession=55645623, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    51547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51547, CurrentID=0, Status='live', Symbol='SIRT7', Aliases=['SIR2L7'], description='sirtuin 7', other_designations='NAD-dependent protein deacetylase sirtuin-7|NAD-dependent deacetylase sirtuin-7|NAD-dependent protein deacylase sirtuin-7|SIR2-like protein 7|regulatory protein SIR2 homolog 7|silent mating type information regulation 2, S.cerevisiae, homolog 7|sir2-related protein type 7|sirtuin type 7', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81911939, end_position_on_the_genomic_accession=81918176, orientation='minus', exon_count=11, OMIM=[606212], no_hdr0=''),
    51548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51548, CurrentID=0, Status='live', Symbol='SIRT6', Aliases=['SIR2L6'], description='sirtuin 6', other_designations='NAD-dependent protein deacetylase sirtuin-6|SIR2-like protein 6|regulatory protein SIR2 homolog 6|sir2-related protein type 6|sirtuin type 6', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4174109, end_position_on_the_genomic_accession=4182563, orientation='minus', exon_count=9, OMIM=[606211], no_hdr0=''),
    51550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51550, CurrentID=0, Status='live', Symbol='CINP', Aliases=[], description='cyclin dependent kinase 2 interacting protein', other_designations='cyclin-dependent kinase 2-interacting protein|CDK2-interacting protein', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102348282, end_position_on_the_genomic_accession=102362890, orientation='minus', exon_count=5, OMIM=[613362], no_hdr0=''),
    51552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51552, CurrentID=0, Status='live', Symbol='RAB14', Aliases=['FBP', 'RAB-14'], description='RAB14, member RAS oncogene family', other_designations='ras-related protein Rab-14|F protein-binding protein 1|bA165P4.3 (member RAS oncogene family)|small GTP binding protein RAB14', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121178133, end_position_on_the_genomic_accession=121201869, orientation='minus', exon_count=8, OMIM=[612673], no_hdr0=''),
    51554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51554, CurrentID=0, Status='live', Symbol='ACKR4', Aliases=['CC-CKR-11', 'CCBP2', 'CCR-11', 'CCR10', 'CCR11', 'CCRL1', 'CCX CKR', 'CCX-CKR', 'CKR-11', 'PPR1', 'VSHK1'], description='atypical chemokine receptor 4', other_designations='atypical chemokine receptor 4|C-C CKR-11|C-C chemokine receptor type 11|CC chemokine receptor-like 1|chemocentryx chemokine receptor|chemokine (C-C motif) receptor-like 1|chemokine, cc motif, receptor-like protein 1|orphan seven-transmembrane receptor, chemokine related', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132597270, end_position_on_the_genomic_accession=132602644, orientation='plus', exon_count=2, OMIM=[606065], no_hdr0=''),
    51555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51555, CurrentID=0, Status='live', Symbol='PEX5L', Aliases=['PEX5R', 'PEX5RP', 'PXR2', 'PXR2B', 'TRIP8b'], description='peroxisomal biogenesis factor 5 like', other_designations='PEX5-related protein|HCN channel auxiliary subunit|PEX2-related protein|PEX5-like protein|Pex5p-related protein|peroxin-5-related protein|peroxisome biogenesis factor 5-like|tetratricopeptide repeat-containing Rab8b-interacting protein', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179794958, end_position_on_the_genomic_accession=180037009, orientation='minus', exon_count=21, OMIM=[611058], no_hdr0=''),
    51557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51557, CurrentID=0, Status='live', Symbol='LGSN', Aliases=['GLULD1', 'LGS'], description='lengsin, lens protein with glutamine synthetase domain', other_designations='lengsin|glutamate-ammonia ligase (glutamine synthase) domain containing 1|glutamate-ammonia ligase domain-containing protein 1', map_location='6q12', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=63275951, end_position_on_the_genomic_accession=63567921, orientation='minus', exon_count=15, OMIM=[611470], no_hdr0=''),
    51559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51559, CurrentID=0, Status='live', Symbol='NT5DC3', Aliases=['TU12B1-TY', 'TU12B1TY'], description="5'-nucleotidase domain containing 3", other_designations="5'-nucleotidase domain-containing protein 3", map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103746315, end_position_on_the_genomic_accession=103841239, orientation='minus', exon_count=22, OMIM=[611076], no_hdr0=''),
    51560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51560, CurrentID=0, Status='live', Symbol='RAB6B', Aliases=[], description='RAB6B, member RAS oncogene family', other_designations='ras-related protein Rab-6B|small GTP-binding protein|small GTPase RAB6B', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133824235, end_position_on_the_genomic_accession=133895882, orientation='minus', exon_count=9, OMIM=[615852], no_hdr0=''),
    51561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51561, CurrentID=0, Status='live', Symbol='IL23A', Aliases=['IL-23', 'IL-23A', 'IL23P19', 'P19', 'SGRF'], description='interleukin 23 subunit alpha', other_designations='interleukin-23 subunit alpha|IL-23 subunit alpha|IL-23-A|IL-23p19|JKA3 induced upon T-cell activation|interleukin 23 p19 subunit|interleukin 23, alpha subunit p19|interleukin-23 subunit p19|interleukin-six, G-CSF related factor', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56334159, end_position_on_the_genomic_accession=56340410, orientation='plus', exon_count=6, OMIM=[605580], no_hdr0=''),
    51562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51562, CurrentID=0, Status='live', Symbol='MBIP', Aliases=[], description='MAP3K12 binding inhibitory protein 1', other_designations='MAP3K12-binding inhibitory protein 1|MAPK upstream kinase-binding inhibitory protein|MUK-binding inhibitory protein', map_location='14q13.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=36298558, end_position_on_the_genomic_accession=36320676, orientation='minus', exon_count=10, OMIM=[609431], no_hdr0=''),
    51564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51564, CurrentID=0, Status='live', Symbol='HDAC7', Aliases=['HD7', 'HD7AA', 'HDAC7'], description='histone deacetylase 7', other_designations='histone deacetylase 7|histone deacetylase 7A', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47782722, end_position_on_the_genomic_accession=47820612, orientation='minus', exon_count=31, OMIM=[606542], no_hdr0=''),
    51566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51566, CurrentID=0, Status='live', Symbol='ARMCX3', Aliases=['ALEX3', 'GASP6', 'dJ545K15.2'], description='armadillo repeat containing X-linked 3', other_designations='armadillo repeat-containing X-linked protein 3|1200004E24Rik|ARM protein lost in epithelial cancers on chromosome X 3|arm protein lost in epithelial cancers, X chromosome, 3', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101623138, end_position_on_the_genomic_accession=101631910, orientation='plus', exon_count=5, OMIM=[300364], no_hdr0=''),
    51567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51567, CurrentID=0, Status='live', Symbol='TDP2', Aliases=['AD022', 'EAP2', 'EAPII', 'TTRAP', 'dJ30M3.3', 'hTDP2'], description='tyrosyl-DNA phosphodiesterase 2', other_designations="tyrosyl-DNA phosphodiesterase 2|5'-Tyr-DNA phosphodiesterase|5'-tyrosyl-DNA phosphodiesterase|ETS1-associated protein 2|ETS1-associated protein II|TRAF and TNF receptor-associated protein|VPg unlinkase|epididymis secretory sperm binding protein|tyr-DNA phosphodiesterase 2|tyrosyl-RNA phosphodiesterase", map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24649979, end_position_on_the_genomic_accession=24666899, orientation='minus', exon_count=7, OMIM=[605764], no_hdr0=''),
    51569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51569, CurrentID=0, Status='live', Symbol='UFM1', Aliases=['BM-002', 'C13orf20', 'HLD14'], description='ubiquitin fold modifier 1', other_designations='ubiquitin-fold modifier 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=38349851, end_position_on_the_genomic_accession=38363619, orientation='plus', exon_count=8, OMIM=[610553], no_hdr0=''),
    51571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51571, CurrentID=0, Status='live', Symbol='CYRIB', Aliases=['BM-009', 'CYRI', 'CYRI-B', 'FAM49B', 'L1'], description='CYFIP related Rac1 interactor B', other_designations='CYFIP-related Rac1 interactor B|FAM49B/JPH1 fusion|MTSS1/FAM49B fusion|family with sequence similarity 49 member B|protein FAM49B', map_location='8q24.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=129839593, end_position_on_the_genomic_accession=130017129, orientation='minus', exon_count=23, OMIM=[617978], no_hdr0=''),
    51573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51573, CurrentID=0, Status='live', Symbol='GDE1', Aliases=['363E6.2', 'MIR16'], description='glycerophosphodiester phosphodiesterase 1', other_designations='glycerophosphodiester phosphodiesterase 1|RGS16-interacting membrane protein|glycerophosphoinositol glycerophosphodiesterase GDE1|lysophospholipase D GDE1|membrane interacting protein of RGS16', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19501693, end_position_on_the_genomic_accession=19522098, orientation='minus', exon_count=6, OMIM=[605943], no_hdr0=''),
    51574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51574, CurrentID=0, Status='live', Symbol='LARP7', Aliases=['ALAZS', 'HDCMA18P', 'PIP7S', 'hLARP7'], description='La ribonucleoprotein 7, transcriptional regulator', other_designations='la-related protein 7|La ribonucleoprotein domain family member 7|P-TEFb-interaction protein for 7SK stability', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112637143, end_position_on_the_genomic_accession=112657586, orientation='plus', exon_count=17, OMIM=[612026], no_hdr0=''),
    51575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51575, CurrentID=0, Status='live', Symbol='ESF1', Aliases=['ABTAP', 'C20orf6', 'HDCMC28P', 'bA526K24.1'], description='ESF1 nucleolar pre-rRNA processing protein homolog', other_designations='ESF1 homolog|ABT1-associated protein', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13714325, end_position_on_the_genomic_accession=13784919, orientation='minus', exon_count=14, OMIM=[618765], no_hdr0=''),
    51582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51582, CurrentID=0, Status='live', Symbol='AZIN1', Aliases=['AZI', 'AZI1', 'AZIA1', 'OAZI', 'OAZIN', 'ODC1L'], description='antizyme inhibitor 1', other_designations='antizyme inhibitor 1|ornithine decarboxylase antizyme inhibitor', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=102826302, end_position_on_the_genomic_accession=102864200, orientation='minus', exon_count=13, OMIM=[607909], no_hdr0=''),
    51585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51585, CurrentID=0, Status='live', Symbol='PCF11', Aliases=[], description='PCF11 cleavage and polyadenylation factor subunit', other_designations='pre-mRNA cleavage complex 2 protein Pcf11|PCF11, cleavage and polyadenylation factor subunit, homolog|PCF11p homolog|pre-mRNA cleavage complex II protein Pcf11', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=83157095, end_position_on_the_genomic_accession=83187451, orientation='plus', exon_count=16, OMIM=[608876], no_hdr0=''),
    51586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51586, CurrentID=0, Status='live', Symbol='MED15', Aliases=['ARC105', 'CAG7A', 'CTG7A', 'PCQAP', 'TIG-1', 'TIG1', 'TNRC7'], description='mediator complex subunit 15', other_designations='mediator of RNA polymerase II transcription subunit 15|CTG repeat protein 7a|PC2 (positive cofactor 2, multiprotein complex) glutamine/Q-rich-associated protein|PC2 glutamine/Q-rich-associated protein|PC2-glutamine-rich-associated protein|TPA inducible gene-1|TPA inducible protein|TPA-inducible gene 1 protein|activator-recruited cofactor 105 kDa component|activator-recruited cofactor, 105-kD|positive cofactor 2, glutamine/Q-rich-associated protein|trinucleotide repeat containing 7|trinucleotide repeat-containing gene 7 protein', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20507582, end_position_on_the_genomic_accession=20587621, orientation='plus', exon_count=25, OMIM=[607372], no_hdr0=''),
    51588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51588, CurrentID=0, Status='live', Symbol='PIAS4', Aliases=['PIAS-gamma', 'PIASY', 'Piasg', 'ZMIZ6'], description='protein inhibitor of activated STAT 4', other_designations='E3 SUMO-protein ligase PIAS4|RING-type E3 ubiquitin transferase PIAS4|protein inhibitor of activated STAT protein 4|protein inhibitor of activated STAT protein PIASy|protein inhibitor of activated STAT protein gamma|zinc finger, MIZ-type containing 6', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4007736, end_position_on_the_genomic_accession=4039386, orientation='plus', exon_count=12, OMIM=[605989], no_hdr0=''),
    51592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51592, CurrentID=0, Status='live', Symbol='TRIM33', Aliases=['ECTO', 'PTC7', 'RFG7', 'TF1G', 'TIF1G', 'TIF1GAMMA', 'TIFGAMMA'], description='tripartite motif containing 33', other_designations='E3 ubiquitin-protein ligase TRIM33|RET-fused gene 7 protein|RING-type E3 ubiquitin transferase TRIM33|TIF1-gamma|ectodermin homolog|protein Rfg7|transcriptional intermediary factor 1 gamma', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114392787, end_position_on_the_genomic_accession=114511203, orientation='minus', exon_count=21, OMIM=[605769], no_hdr0=''),
    51593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51593, CurrentID=0, Status='live', Symbol='SRRT', Aliases=['ARS2', 'ASR2', 'serrate'], description='serrate, RNA effector molecule', other_designations='serrate RNA effector molecule homolog|arsenate resistance protein 2|arsenate resistance protein ARS2|arsenite resistance protein|arsenite-resistance protein 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100874971, end_position_on_the_genomic_accession=100888664, orientation='plus', exon_count=23, OMIM=[614469], no_hdr0=''),
    51594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51594, CurrentID=0, Status='live', Symbol='NBAS', Aliases=['ILFS2', 'NAG', 'SOPH'], description='NBAS subunit of NRZ tethering complex', other_designations='neuroblastoma-amplified sequence|NAG/BC035112 fusion|NAG/FAM49A fusion|neuroblastoma amplified sequence|neuroblastoma-amplified gene protein', map_location='2p24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=14998067, end_position_on_the_genomic_accession=15561344, orientation='minus', exon_count=55, OMIM=[608025], no_hdr0=''),
    51596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51596, CurrentID=0, Status='live', Symbol='CUTA', Aliases=['ACHAP', 'C6orf82'], description='cutA divalent cation tolerance homolog', other_designations='protein CutA|acetylcholinesterase-associated protein|brain acetylcholinesterase putative membrane anchor|divalent cation tolerant protein CUTA', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33416442, end_position_on_the_genomic_accession=33418107, orientation='minus', exon_count=6, OMIM=[616953], no_hdr0=''),
    51599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51599, CurrentID=0, Status='live', Symbol='LSR', Aliases=['ILDR3', 'LISCH7'], description='lipolysis stimulated lipoprotein receptor', other_designations='lipolysis-stimulated lipoprotein receptor|LISCH protein|angulin-1|immunoglobulin-like domain containing receptor 3|lipolysis-stimulated remnant|liver-specific bHLH-Zip transcription factor', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35248736, end_position_on_the_genomic_accession=35267964, orientation='plus', exon_count=10, OMIM=[616582], no_hdr0=''),
    51601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51601, CurrentID=0, Status='live', Symbol='LIPT1', Aliases=['LIPT1D'], description='lipoyltransferase 1', other_designations='lipoyltransferase 1, mitochondrial|lipoate biosynthesis protein|lipoyl ligase', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99154967, end_position_on_the_genomic_accession=99163137, orientation='plus', exon_count=7, OMIM=[610284], no_hdr0=''),
    51602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51602, CurrentID=0, Status='live', Symbol='NOP58', Aliases=['HSPC120', 'NOP5', 'NOP5/NOP58'], description='NOP58 ribonucleoprotein', other_designations='nucleolar protein 58|NOP58 ribonucleoprotein homolog|nucleolar protein 5|nucleolar protein NOP5/NOP58', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202265763, end_position_on_the_genomic_accession=202303661, orientation='plus', exon_count=15, OMIM=[616742], no_hdr0=''),
    51603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51603, CurrentID=0, Status='live', Symbol='METTL13', Aliases=['5630401D24Rik', 'CGI-01', 'DFNB26', 'DFNB26M', 'DFNM1', 'EEF1AKNMT', 'KIAA0859', 'feat'], description='methyltransferase 13, eEF1A lysine and N-terminal methyltransferase', other_designations='eEF1A lysine and N-terminal methyltransferase|antiapoptotic protein FEAT|deafness (autosomal recessive, nonsyndromic) modifier 1|deafness (recessive, non-syndromic) modifier 1|deafness (recessive, nonsyndromic) modifier 1|eEF1A-KNMT|faint expression in normal tissues, aberrant overexpression in tumors|methyltransferase like 13|methyltransferase-like protein 13', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171781660, end_position_on_the_genomic_accession=171797716, orientation='plus', exon_count=8, OMIM=[617987], no_hdr0=''),
    51604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51604, CurrentID=0, Status='live', Symbol='PIGT', Aliases=['CGI-06', 'MCAHS3', 'NDAP', 'PNH2'], description='phosphatidylinositol glycan anchor biosynthesis class T', other_designations='GPI transamidase component PIG-T|GPI transamidase subunit|neurotrophin-regulated neuronal development-associated protein|phosphatidylinositol-glycan biosynthesis class T protein', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45416141, end_position_on_the_genomic_accession=45426241, orientation='plus', exon_count=12, OMIM=[610272], no_hdr0=''),
    51605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51605, CurrentID=0, Status='live', Symbol='TRMT6', Aliases=['CGI-09', 'GCD10', 'Gcd10p'], description='tRNA methyltransferase 6 non-catalytic subunit', other_designations='tRNA (adenine(58)-N(1))-methyltransferase non-catalytic subunit TRM6|mRNA methyladenosine-N(1)-methyltransferase non-catalytic subunit TRM6|tRNA methyltransferase 6 homolog|tRNA(m1A58)MTase subunit TRM6', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5937228, end_position_on_the_genomic_accession=5950533, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    51606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51606, CurrentID=0, Status='live', Symbol='ATP6V1H', Aliases=['CGI-11', 'MSTP042', 'NBP1', 'SFD', 'SFDalpha', 'SFDbeta', 'VMA13'], description='ATPase H+ transporting V1 subunit H', other_designations='V-type proton ATPase subunit H|ATPase, H+ transporting, lysosomal 50/57kDa, V1 subunit H|V-ATPase 50/57 kDa subunits|V-ATPase subunit H|nef-binding protein 1|protein VMA13 homolog|vacuolar ATP synthase subunit H|vacuolar ATPase subunit H|vacuolar proton pump subunit H|vacuolar proton pump subunit SFD', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=53715543, end_position_on_the_genomic_accession=53843245, orientation='minus', exon_count=16, OMIM=[608861], no_hdr0=''),
    51608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51608, CurrentID=0, Status='live', Symbol='GET4', Aliases=['C7orf20', 'CEE', 'CGI-20', 'TRC35'], description='guided entry of tail-anchored proteins factor 4', other_designations='Golgi to ER traffic protein 4 homolog|H_NH1244M04.5|conserved edge expressed protein|conserved edge protein|golgi to ER traffic protein 4|transmembrane domain recognition complex 35 kDa subunit|transmembrane domain recognition complex, 35kDa', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=876554, end_position_on_the_genomic_accession=896436, orientation='plus', exon_count=9, OMIM=[612056], no_hdr0=''),
    51611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51611, CurrentID=0, Status='live', Symbol='DPH5', Aliases=['AD-018', 'CGI-30', 'HSPC143', 'NPD015'], description='diphthamide biosynthesis 5', other_designations='diphthine methyl ester synthase|DPH5 homolog|diphthamide biosynthesis methyltransferase|diphthine synthase|protein x 0011', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100975218, end_position_on_the_genomic_accession=101025806, orientation='minus', exon_count=8, OMIM=[611075], no_hdr0=''),
    51614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51614, CurrentID=0, Status='live', Symbol='ERGIC3', Aliases=['C20orf47', 'C2orf47', 'CGI-54', 'Erv46', 'NY-BR-84', 'PRO0989', 'SDBCAG84', 'dJ477O4.2'], description='ERGIC and golgi 3', other_designations='endoplasmic reticulum-Golgi intermediate compartment protein 3|endoplasmic reticulum-localized protein ERp43|serologically defined breast cancer antigen 84|serologically defined breast cancer antigen NY-BR-84', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35542078, end_position_on_the_genomic_accession=35557634, orientation='plus', exon_count=14, OMIM=[616971], no_hdr0=''),
    51616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51616, CurrentID=0, Status='live', Symbol='TAF9B', Aliases=['DN-7', 'DN7', 'TAF9L', 'TAFII31L', 'TFIID-31'], description='TATA-box binding protein associated factor 9b', other_designations='transcription initiation factor TFIID subunit 9B|TAF9-like RNA polymerase II, TATA box binding protein (TBP)-associated factor, 31kDa|TAF9B RNA polymerase II, TATA box binding protein (TBP)-associated factor, 31kDa|TBP-associated factor 9L|neuronal cell death-related protein 7|transcription initiation factor IID, 31kD subunit|transcription-associated factor TAFII31L', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78129748, end_position_on_the_genomic_accession=78139650, orientation='minus', exon_count=7, OMIM=[300754], no_hdr0=''),
    51617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51617, CurrentID=0, Status='live', Symbol='NSG2', Aliases=['CALY3', 'HMP19'], description='neuronal vesicle trafficking associated 2', other_designations='neuronal vesicle trafficking-associated protein 2|calcyon family member 3|hypothalamus golgi apparatus expressed 19 kDa protein|neuron-specific protein family member 2|p19 protein|protein p19', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=174045706, end_position_on_the_genomic_accession=174109179, orientation='plus', exon_count=5, OMIM=[616752], no_hdr0=''),
    51619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51619, CurrentID=0, Status='live', Symbol='UBE2D4', Aliases=['HBUCE1'], description='ubiquitin conjugating enzyme E2 D4 (putative)', other_designations='ubiquitin-conjugating enzyme E2 D4|E2 ubiquitin-conjugating enzyme D4|ubiquitin carrier protein D4|ubiquitin conjugating enzyme E2D 4 (putative)|ubiquitin-conjugating enzyme HBUCE1|ubiquitin-protein ligase D4', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43926422, end_position_on_the_genomic_accession=43956136, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    51621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51621, CurrentID=0, Status='live', Symbol='KLF13', Aliases=['BTEB3', 'FKLF2', 'NSLP1', 'RFLAT-1', 'RFLAT1'], description='Kruppel like factor 13', other_designations='Krueppel-like factor 13|BTE-binding protein 3|RANTES factor of late activated T lymphocytes-1|basic transcription element binding protein 3|novel Sp1-like zinc finger transcription factor 1|transcription factor BTEB3|transcription factor NSLP1', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=31326835, end_position_on_the_genomic_accession=31435665, orientation='plus', exon_count=3, OMIM=[605328], no_hdr0=''),
    51622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51622, CurrentID=0, Status='live', Symbol='CCZ1', Aliases=['C7orf28AA', 'CGI-43', 'H_DJ1163J12.2', 'CCZ1'], description='CCZ1 homolog, vacuolar protein trafficking and biogenesis associated', other_designations='vacuolar fusion protein CCZ1 homolog|CCZ1 vacuolar protein trafficking and biogenesis associated homolog|H_NH0577018.2', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5898733, end_position_on_the_genomic_accession=5926550, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    51626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51626, CurrentID=0, Status='live', Symbol='DYNC2LI1', Aliases=['CGI-60', 'D2LIC', 'LIC3'], description='dynein cytoplasmic 2 light intermediate chain 1', other_designations='cytoplasmic dynein 2 light intermediate chain 1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43774039, end_position_on_the_genomic_accession=43828347, orientation='plus', exon_count=15, OMIM=[617083], no_hdr0=''),
    51629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51629, CurrentID=0, Status='live', Symbol='SLC25A39', Aliases=['CGI-69', 'CGI69'], description='solute carrier family 25 member 39', other_designations='solute carrier family 25 member 39', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44319627, end_position_on_the_genomic_accession=44324845, orientation='minus', exon_count=11, OMIM=[610820], no_hdr0=''),
    51631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51631, CurrentID=0, Status='live', Symbol='LUC7L2', Aliases=['CGI-59', 'CGI-74', 'LUC7B2'], description='LUC7 like 2, pre-mRNA splicing factor', other_designations='putative RNA-binding protein Luc7-like 2|LUC7-like 2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139340472, end_position_on_the_genomic_accession=139423454, orientation='plus', exon_count=13, OMIM=[613056], no_hdr0=''),
    51633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51633, CurrentID=0, Status='live', Symbol='OTUD6B', Aliases=['CGI-77', 'DUBA-5', 'DUBA5', 'IDDFSDA'], description='OTU deubiquitinase 6B', other_designations='deubiquitinase OTUD6B|OTU domain containing 6B|OTU domain-containing protein 6B', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=91070305, end_position_on_the_genomic_accession=91087095, orientation='plus', exon_count=8, OMIM=[612021], no_hdr0=''),
    51634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51634, CurrentID=0, Status='live', Symbol='RBMX2', Aliases=['CGI-79', 'Snu17'], description='RNA binding motif protein X-linked 2', other_designations='RNA-binding motif protein, X-linked 2', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130401987, end_position_on_the_genomic_accession=130413656, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    51635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51635, CurrentID=0, Status='live', Symbol='DHRS7', Aliases=['CGI-86', 'SDR34C1', 'retDSR4', 'retSDR4'], description='dehydrogenase/reductase 7', other_designations='dehydrogenase/reductase SDR family member 7|dehydrogenase/reductase (SDR family) member 7|retinal short-chain dehydrogenase/reductase 4|short chain dehydrogenase/reductase family 34C member 1', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60144119, end_position_on_the_genomic_accession=60169889, orientation='minus', exon_count=8, OMIM=[612833], no_hdr0=''),
    51637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51637, CurrentID=0, Status='live', Symbol='RTRAF', Aliases=['C14orf166', 'CGI-99', 'CGI99', 'CLE', 'CLE7', 'LCRP369', 'RLLM1', 'hCLE', 'hCLE1'], description='RNA transcription, translation and transport factor', other_designations='RNA transcription, translation and transport factor protein|CLE7 homolog|RLL motif containing 1|UPF0568 protein C14orf166', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=51989546, end_position_on_the_genomic_accession=52010694, orientation='plus', exon_count=8, OMIM=[610858], no_hdr0=''),
    51639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51639, CurrentID=0, Status='live', Symbol='SF3B6', Aliases=['CGI-110', 'HSPC175', 'Ht006', 'P14', 'SAP14', 'SAP14a', 'SF3B14', 'SF3B14a'], description='splicing factor 3b subunit 6', other_designations='splicing factor 3B subunit 6|SF3b 14 kDa subunit|pre-mRNA branch site protein p14|spliceosome-associated protein, 14 kDa subunit|spliceosome-associated protein, 14-kDa|splicing factor 3B, 14 kDa subunit|splicing factor 3b, subunit 6, 14kDa', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24067586, end_position_on_the_genomic_accession=24076326, orientation='minus', exon_count=4, OMIM=[607835], no_hdr0=''),
    51642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51642, CurrentID=0, Status='live', Symbol='MRPL48', Aliases=['CGI-118', 'HSPC290', 'L48MT', 'MRP-L48'], description='mitochondrial ribosomal protein L48', other_designations='39S ribosomal protein L48, mitochondrial|mitochondrial large ribosomal subunit protein mL48', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73787874, end_position_on_the_genomic_accession=73865133, orientation='plus', exon_count=12, OMIM=[611853], no_hdr0=''),
    51643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51643, CurrentID=0, Status='live', Symbol='TMBIM4', Aliases=['CGI-119', 'GAAP', 'LFG4', 'S1R', 'ZPRO'], description='transmembrane BAX inhibitor motif containing 4', other_designations='protein lifeguard 4|Golgi anti-apoptotic protein|Z-protein|transmembrane BAX inhibitor motif-containing protein 4', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66135846, end_position_on_the_genomic_accession=66169996, orientation='minus', exon_count=8, OMIM=[616874], no_hdr0=''),
    51645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51645, CurrentID=0, Status='live', Symbol='PPIL1', Aliases=['CGI-124', 'CYPL1', 'PCH14', 'PPIase', 'hCyPX'], description='peptidylprolyl isomerase like 1', other_designations='peptidyl-prolyl cis-trans isomerase-like 1|cyclophilin like 1|cyclophilin-related gene 1|peptidyl-prolyl cis-trans isomerase|peptidylprolyl isomerase (cyclophilin)-like 1|rotamase PPIL1', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36854829, end_position_on_the_genomic_accession=36874803, orientation='minus', exon_count=4, OMIM=[601301], no_hdr0=''),
    51646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51646, CurrentID=0, Status='live', Symbol='YPEL5', Aliases=['CGI-127'], description='yippee like 5', other_designations='protein yippee-like 5', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=30146568, end_position_on_the_genomic_accession=30160533, orientation='plus', exon_count=6, OMIM=[609726], no_hdr0=''),
    51647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51647, CurrentID=0, Status='live', Symbol='CIAO2B', Aliases=['CGI-128', 'CIA2B', 'FAM96B', 'MIP18'], description='cytosolic iron-sulfur assembly component 2B', other_designations='cytosolic iron-sulfur assembly component 2B|MSS19-interacting protein of 18 kDa|family with sequence similarity 96 member B|mitotic spindle-associated MMXD complex subunit MIP18', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66932065, end_position_on_the_genomic_accession=66934402, orientation='minus', exon_count=4, OMIM=[614778], no_hdr0=''),
    51649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51649, CurrentID=0, Status='live', Symbol='MRPS23', Aliases=['CGI-138', 'COXPD46', 'HSPC329', 'MRP-S23'], description='mitochondrial ribosomal protein S23', other_designations='28S ribosomal protein S23, mitochondrial|S23mt|mitochondrial small ribosomal subunit protein mS23', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57834781, end_position_on_the_genomic_accession=57850044, orientation='minus', exon_count=5, OMIM=[611985], no_hdr0=''),
    51650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51650, CurrentID=0, Status='live', Symbol='MRPS33', Aliases=['CGI-139', 'MRP-S33', 'PTD003', 'S33mt'], description='mitochondrial ribosomal protein S33', other_designations='28S ribosomal protein S33, mitochondrial|mitochondrial small ribosomal subunit protein mS33', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141002610, end_position_on_the_genomic_accession=141014952, orientation='minus', exon_count=4, OMIM=[611993], no_hdr0=''),
    51651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51651, CurrentID=0, Status='live', Symbol='PTRH2', Aliases=['BIT1', 'CFAP37', 'CGI-147', 'IMNEPD', 'PTH', 'PTH 2', 'PTH2'], description='peptidyl-tRNA hydrolase 2', other_designations='peptidyl-tRNA hydrolase 2, mitochondrial|bcl-2 inhibitor of transcription 1|cilia and flagella associated protein 37', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59697306, end_position_on_the_genomic_accession=59707626, orientation='minus', exon_count=3, OMIM=[608625], no_hdr0=''),
    51652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51652, CurrentID=0, Status='live', Symbol='CHMP3', Aliases=['CGI-149', 'NEDF', 'VPS24'], description='charged multivesicular body protein 3', other_designations='charged multivesicular body protein 3|25.1 protein|CHMP family, member 3|chromatin-modifying protein 3|neuroendocrine differentiation factor|vacuolar protein sorting 24 homolog|vacuolar protein sorting-associated protein 24', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86503430, end_position_on_the_genomic_accession=86563443, orientation='minus', exon_count=6, OMIM=[610052], no_hdr0=''),
    51654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51654, CurrentID=0, Status='live', Symbol='CDK5RAP1', Aliases=['C20orf34', 'C42', 'CGI-05', 'HSPC167'], description='CDK5 regulatory subunit associated protein 1', other_designations='mitochondrial tRNA methylthiotransferase CDK5RAP1|CDK5 activator-binding protein C42|mt-tRNA-2-methylthio-N6-dimethylallyladenosine synthase|mt-tRNA-N6-(dimethylallyl)adenosine(37) methylthiotransferase', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33358839, end_position_on_the_genomic_accession=33403030, orientation='minus', exon_count=16, OMIM=[608200], no_hdr0=''),
    51655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51655, CurrentID=0, Status='live', Symbol='RASD1', Aliases=['AGS1', 'DEXRAS1', 'MGC:26290'], description='ras related dexamethasone induced 1', other_designations='dexamethasone-induced Ras-related protein 1|RAS, dexamethasone-induced 1|activator of G-protein signaling 1|ras-related protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17494437, end_position_on_the_genomic_accession=17496395, orientation='minus', exon_count=2, OMIM=[605550], no_hdr0=''),
    51657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51657, CurrentID=0, Status='live', Symbol='STYXL1', Aliases=['DUSP24', 'MK-STYX', 'MKSTYX'], description='serine/threonine/tyrosine interacting like 1', other_designations='serine/threonine/tyrosine-interacting-like protein 1|dual specificity phosphatase 24 (putative)|dual specificity phosphatase inhibitor MK-STYX|dual specificity protein phosphatase 24|inactive dual specificity protein phosphatase MK-STYX|map kinase phosphatase-like protein MK-STYX', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75995820, end_position_on_the_genomic_accession=76049344, orientation='minus', exon_count=12, OMIM=[616695], no_hdr0=''),
    51659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51659, CurrentID=0, Status='live', Symbol='GINS2', Aliases=['HSPC037', 'PSF2', 'Pfs2'], description='GINS complex subunit 2', other_designations='DNA replication complex GINS protein PSF2|GINS complex subunit 2 (Psf2 homolog)', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85676198, end_position_on_the_genomic_accession=85688954, orientation='minus', exon_count=5, OMIM=[610609], no_hdr0=''),
    51660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51660, CurrentID=0, Status='live', Symbol='MPC1', Aliases=['BRP44L', 'CGI-129', 'MPYCD', 'SLC54A1'], description='mitochondrial pyruvate carrier 1', other_designations='mitochondrial pyruvate carrier 1|HSPC040 protein|brain protein 44-like protein', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166364919, end_position_on_the_genomic_accession=166382940, orientation='minus', exon_count=7, OMIM=[614738], no_hdr0=''),
    51661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51661, CurrentID=0, Status='live', Symbol='FKBP7', Aliases=['FKBP23', 'PPIase'], description='FKBP prolyl isomerase 7', other_designations='peptidyl-prolyl cis-trans isomerase FKBP7|23 kDa FK506-binding protein|23 kDa FKBP|FK506 binding protein 7|FK506-binding protein 23|FKBP-23|FKBP-7|PPIase FKBP7|rotamase', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178463664, end_position_on_the_genomic_accession=178480817, orientation='minus', exon_count=4, OMIM=[607062], no_hdr0=''),
    51663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51663, CurrentID=0, Status='live', Symbol='ZFR', Aliases=['SPG711', 'ZFR'], description='zinc finger RNA binding protein', other_designations='zinc finger RNA-binding protein|M-phase phosphoprotein homolog', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=32354350, end_position_on_the_genomic_accession=32444740, orientation='minus', exon_count=20, OMIM=[615635], no_hdr0=''),
    51665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51665, CurrentID=0, Status='live', Symbol='ASB1', Aliases=['ASB-1'], description='ankyrin repeat and SOCS box containing 1', other_designations='ankyrin repeat and SOCS box protein 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238426927, end_position_on_the_genomic_accession=238452250, orientation='plus', exon_count=5, OMIM=[605758], no_hdr0=''),
    51666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51666, CurrentID=0, Status='live', Symbol='ASB4', Aliases=['ASB-4'], description='ankyrin repeat and SOCS box containing 4', other_designations='ankyrin repeat and SOCS box protein 4', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=95485439, end_position_on_the_genomic_accession=95544738, orientation='plus', exon_count=6, OMIM=[605761], no_hdr0=''),
    51667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51667, CurrentID=0, Status='live', Symbol='NUB1', Aliases=['BS4L', 'NYREN18', 'NUB1'], description='negative regulator of ubiquitin like proteins 1', other_designations='NEDD8 ultimate buster 1|NEDD8 ultimate buster-1|renal carcinoma antigen NY-REN-18', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151341699, end_position_on_the_genomic_accession=151378449, orientation='plus', exon_count=16, OMIM=[607981], no_hdr0=''),
    51668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51668, CurrentID=0, Status='live', Symbol='HSPB11', Aliases=['C1orf41', 'FAP232', 'HSPCO34', 'IFT25', 'PP25'], description='heat shock protein family B (small) member 11', other_designations='intraflagellar transport protein 25 homolog|heat shock protein beta-11|heat shock protein family B (small), member 11|intraflagellar transport 25 homolog|placental protein 25', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53916573, end_position_on_the_genomic_accession=53946305, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    51669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51669, CurrentID=0, Status='live', Symbol='SARAF', Aliases=['FOAP-7', 'HSPC035', 'TMEM66', 'XTP3'], description='store-operated calcium entry associated regulatory factor', other_designations='store-operated calcium entry-associated regulatory factor|HBV X-transactivated gene 3 protein|HBV XAg-transactivated protein 3|SOCE-associated regulatory factor|testicular secretory protein Li 59|transmembrane protein 66', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30063003, end_position_on_the_genomic_accession=30083208, orientation='minus', exon_count=7, OMIM=[614768], no_hdr0=''),
    51673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51673, CurrentID=0, Status='live', Symbol='TPPP3', Aliases=['CGI-38', 'TPPP/p20', 'p20', 'p25gamma'], description='tubulin polymerization promoting protein family member 3', other_designations='tubulin polymerization-promoting protein family member 3|brain specific protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67389807, end_position_on_the_genomic_accession=67393498, orientation='minus', exon_count=6, OMIM=[616957], no_hdr0=''),
    51676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51676, CurrentID=0, Status='live', Symbol='ASB2', Aliases=['ASB-2'], description='ankyrin repeat and SOCS box containing 2', other_designations='ankyrin repeat and SOCS box protein 2|ankyrin repeat and SOCS box-containing protein 2a', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93934160, end_position_on_the_genomic_accession=93976739, orientation='minus', exon_count=12, OMIM=[605759], no_hdr0=''),
    51678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51678, CurrentID=0, Status='live', Symbol='PALS2', Aliases=['MPP6', 'VAM-1', 'VAM1', 'p55T'], description='protein associated with LIN7 2, MAGUK family member', other_designations='protein PALS2|MAGUK p55 subfamily member 6|MAGUK protein p55T|VELI-associated MAGUK 1|membrane palmitoylated protein 6|membrane protein, palmitoylated 6 (MAGUK p55 subfamily member 6)|protein associated with Lin7 2', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=24573353, end_position_on_the_genomic_accession=24694193, orientation='plus', exon_count=15, OMIM=[606959], no_hdr0=''),
    51684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51684, CurrentID=0, Status='live', Symbol='SUFU', Aliases=['JBTS32', 'PRO1280H', 'SUFUXL', 'SUFU'], description='SUFU negative regulator of hedgehog signaling', other_designations='suppressor of fused homolog|negative regulator of hedgehog signaling', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102502801, end_position_on_the_genomic_accession=102633535, orientation='plus', exon_count=16, OMIM=[607035], no_hdr0=''),
    51686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51686, CurrentID=0, Status='live', Symbol='OAZ3', Aliases=['AZ3', 'OAZ-t', 'TISP15'], description='ornithine decarboxylase antizyme 3', other_designations='ornithine decarboxylase antizyme 3|ODC-Az 3|antizyme 3|testicular secretory protein Li 31', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151762969, end_position_on_the_genomic_accession=151771330, orientation='plus', exon_count=7, OMIM=[605138], no_hdr0=''),
    51690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51690, CurrentID=0, Status='live', Symbol='LSM7', Aliases=['YNL147W'], description='LSM7 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm7|LSM7 U6 small nuclear RNA and mRNA degradation associated|LSM7 homolog, U6 small nuclear RNA associated', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2321521, end_position_on_the_genomic_accession=2328630, orientation='minus', exon_count=5, OMIM=[607287], no_hdr0=''),
    51691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51691, CurrentID=0, Status='live', Symbol='LSM8', Aliases=['NAA38'], description='LSM8 homolog, U6 small nuclear RNA associated', other_designations='LSM8 homolog, U6 small nuclear RNA associated|LSM8 U6 small nuclear RNA associated|MAK31-like protein|N-alpha-acetyltransferase 38, NatC auxiliary subunit|U6 snRNA-associated Sm-like protein LSm8', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=118184164, end_position_on_the_genomic_accession=118204035, orientation='plus', exon_count=4, OMIM=[607288], no_hdr0=''),
    51692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51692, CurrentID=0, Status='live', Symbol='CPSF3', Aliases=['CPSF-73', 'CPSF73'], description='cleavage and polyadenylation specific factor 3', other_designations="cleavage and polyadenylation specificity factor subunit 3|cleavage and polyadenylation specific factor 3, 73kDa|mRNA 3'-end-processing endonuclease CPSF-73", map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9423654, end_position_on_the_genomic_accession=9473101, orientation='plus', exon_count=19, OMIM=[606029], no_hdr0=''),
    51693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51693, CurrentID=0, Status='live', Symbol='TRAPPC2L', Aliases=['HSPC176', 'PERRB'], description='trafficking protein particle complex subunit 2L', other_designations='trafficking protein particle complex subunit 2-like protein|hematopoietic stem/progenitor cells 176|trafficking protein particle complex 2 like', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88856220, end_position_on_the_genomic_accession=88862678, orientation='plus', exon_count=7, OMIM=[610970], no_hdr0=''),
    51696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51696, CurrentID=0, Status='live', Symbol='HECA', Aliases=['HDC', 'HDCL', 'HHDC', 'dJ225E12.1'], description='hdc homolog, cell cycle regulator', other_designations='headcase protein homolog|headcase homolog', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=139135080, end_position_on_the_genomic_accession=139180802, orientation='plus', exon_count=4, OMIM=[607977], no_hdr0=''),
    51699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51699, CurrentID=0, Status='live', Symbol='VPS29', Aliases=['DC15', 'DC7', 'PEP11'], description='VPS29 retromer complex component', other_designations='vacuolar protein sorting-associated protein 29|PEP11 homolog|epididymis secretory sperm binding protein|hVPS29|retromer protein|vacuolar protein sorting 29 homolog|vacuolar sorting protein VPS29/PEP11|vesicle protein sorting 29|x 007 protein', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110491083, end_position_on_the_genomic_accession=110502111, orientation='minus', exon_count=8, OMIM=[606932], no_hdr0=''),
    51700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51700, CurrentID=0, Status='live', Symbol='CYB5R2', Aliases=['B5R.2'], description='cytochrome b5 reductase 2', other_designations='NADH-cytochrome b5 reductase 2|cytochrome b5 reductase b5R.2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7665095, end_position_on_the_genomic_accession=7678569, orientation='minus', exon_count=12, OMIM=[608342], no_hdr0=''),
    51701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51701, CurrentID=0, Status='live', Symbol='NLK', Aliases=[], description='nemo like kinase', other_designations='serine/threonine-protein kinase NLK', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28042647, end_position_on_the_genomic_accession=28205140, orientation='plus', exon_count=13, OMIM=[609476], no_hdr0=''),
    51702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51702, CurrentID=0, Status='live', Symbol='PADI3', Aliases=['PAD3', 'PDI3', 'UHS1'], description='peptidyl arginine deiminase 3', other_designations='protein-arginine deiminase type-3|peptidyl arginine deiminase, type III|peptidylarginine deiminase III|protein-arginine deiminase type III', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17249079, end_position_on_the_genomic_accession=17284233, orientation='plus', exon_count=18, OMIM=[606755], no_hdr0=''),
    51703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51703, CurrentID=0, Status='live', Symbol='ACSL5', Aliases=['ACS2', 'ACS5', 'FACL5'], description='acyl-CoA synthetase long chain family member 5', other_designations='long-chain-fatty-acid--CoA ligase 5|FACL5 for fatty acid coenzyme A ligase 5|LACS 5|arachidonate--CoA ligase|fatty acid coenzyme A ligase 5|fatty-acid-Coenzyme A ligase, long-chain 5|long-chain acyl-CoA synthetase 5|long-chain fatty acid coenzyme A ligase 5', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112374116, end_position_on_the_genomic_accession=112428376, orientation='plus', exon_count=23, OMIM=[605677], no_hdr0=''),
    51704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51704, CurrentID=0, Status='live', Symbol='GPRC5B', Aliases=['RAIG-2', 'RAIG2'], description='G protein-coupled receptor class C group 5 member B', other_designations='G-protein coupled receptor family C group 5 member B|G protein-coupled receptor, family C, group 1, member B|retinoic acid responsive gene protein|retinoic acid-induced gene 2 protein', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19856691, end_position_on_the_genomic_accession=19886045, orientation='minus', exon_count=7, OMIM=[605948], no_hdr0=''),
    51705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51705, CurrentID=0, Status='live', Symbol='EMCN', Aliases=['EMCN2', 'MUC14'], description='endomucin', other_designations='endomucin|MUC-14|endomucin-2|gastric cancer antigen Ga34|mucin-14', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=100395341, end_position_on_the_genomic_accession=100518052, orientation='minus', exon_count=14, OMIM=[608350], no_hdr0=''),
    51706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51706, CurrentID=0, Status='live', Symbol='CYB5R1', Aliases=['B5R.1', 'B5R1', 'B5R2', 'NQO3A2', 'humb5R2'], description='cytochrome b5 reductase 1', other_designations='NADH-cytochrome b5 reductase 1|NAD(P)H:quinone oxidoreductase type 3, polypeptide A2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202961873, end_position_on_the_genomic_accession=202967257, orientation='minus', exon_count=9, OMIM=[608341], no_hdr0=''),
    51710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51710, CurrentID=0, Status='live', Symbol='ZNF44', Aliases=['GIOT-2', 'KOX7', 'ZNF', 'ZNF504', 'ZNF55', 'ZNF58'], description='zinc finger protein 44', other_designations='zinc finger protein 44|gonadotropin inducible transcription repressor-2|gonadotropin-inducible ovary transcription repressor 2|zinc finger protein 55|zinc finger protein 58|zinc finger protein KOX7|zinc finger protein ZnFP12', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12224686, end_position_on_the_genomic_accession=12294898, orientation='minus', exon_count=18, OMIM=[194542], no_hdr0=''),
    51714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51714, CurrentID=0, Status='live', Symbol='SELENOT', Aliases=['SELT'], description='selenoprotein T', other_designations='thioredoxin reductase-like selenoprotein T|thioredoxin reductase-like enzyme', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150603321, end_position_on_the_genomic_accession=150630436, orientation='plus', exon_count=6, OMIM=[607912], no_hdr0=''),
    51715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51715, CurrentID=0, Status='live', Symbol='RAB23', Aliases=['HSPC137'], description='RAB23, member RAS oncogene family', other_designations='ras-related protein Rab-23|RAB family small GTP binding protein RAB 23', map_location='6p12.1-p11.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=57186992, end_position_on_the_genomic_accession=57222307, orientation='minus', exon_count=8, OMIM=[606144], no_hdr0=''),
    51719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51719, CurrentID=0, Status='live', Symbol='CAB39', Aliases=['CGI-66', 'MO25'], description='calcium binding protein 39', other_designations='calcium-binding protein 39|MO25alpha', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230712842, end_position_on_the_genomic_accession=230821075, orientation='plus', exon_count=11, OMIM=[612174], no_hdr0=''),
    51720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51720, CurrentID=0, Status='live', Symbol='UIMC1', Aliases=['RAP80', 'X2HRIP110'], description='ubiquitin interaction motif containing 1', other_designations='BRCA1-A complex subunit RAP80|receptor-associated protein 80|retinoid X receptor-interacting protein 110', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176905005, end_position_on_the_genomic_accession=177022640, orientation='minus', exon_count=22, OMIM=[609433], no_hdr0=''),
    51725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51725, CurrentID=0, Status='live', Symbol='FBXO40', Aliases=['FBX40'], description='F-box protein 40', other_designations='F-box only protein 40|muscle disease-related protein', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121593379, end_position_on_the_genomic_accession=121630295, orientation='plus', exon_count=4, OMIM=[609107], no_hdr0=''),
    51726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51726, CurrentID=0, Status='live', Symbol='DNAJB11', Aliases=['ABBP-2', 'ABBP2', 'DJ9', 'Dj-9', 'EDJ', 'ERdj3', 'ERj3', 'ERj3p', 'PKD6', 'PRO1080', 'UNQ537'], description='DnaJ heat shock protein family (Hsp40) member B11', other_designations='dnaJ homolog subfamily B member 11|APOBEC1-binding protein 2|DnaJ (Hsp40) homolog, subfamily B, member 11|DnaJ protein 9|ER-associated DNAJ protein 3|ER-associated Hsp40 co-chaperone|ER-resident protein ERdj3|PWP1-interacting protein 4|endoplasmic reticulum DNA J domain-containing protein 3', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186570720, end_position_on_the_genomic_accession=186585793, orientation='plus', exon_count=11, OMIM=[611341], no_hdr0=''),
    51727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51727, CurrentID=0, Status='live', Symbol='CMPK1', Aliases=['CK', 'CMK', 'CMPK', 'UMK', 'UMP-CMPK', 'UMPK'], description='cytidine/uridine monophosphate kinase 1', other_designations='UMP-CMP kinase|UMP/CMP kinase|cytidine monophosphate (UMP-CMP) kinase 1, cytosolic|cytidylate kinase|dCMP kinase|deoxycytidylate kinase|nucleoside-diphosphate kinase|uridine monophosphate kinase|uridine monophosphate/cytidine monophosphate kinase', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47333790, end_position_on_the_genomic_accession=47378839, orientation='plus', exon_count=7, OMIM=[191710], no_hdr0=''),
    51728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51728, CurrentID=0, Status='live', Symbol='POLR3K', Aliases=['C11', 'C11-RNP3', 'HLD21', 'My010', 'RPC10', 'RPC11', 'RPC12.5'], description='RNA polymerase III subunit K', other_designations='DNA-directed RNA polymerase III subunit RPC10|DNA-directed RNA polymerase III subunit K|DNA-directed RNA polymerases III 12.5 kDa polypeptide|RNA polymerase III 12.5 kDa subunit|RNA polymerase III subunit C10|RNA polymerase III subunit C11|RNA polymerase III subunit CII|polymerase (RNA) III (DNA directed) polypeptide K, 12.3 kDa|polymerase (RNA) III subunit K', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46407, end_position_on_the_genomic_accession=53608, orientation='minus', exon_count=3, OMIM=[606007], no_hdr0=''),
    51729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51729, CurrentID=0, Status='live', Symbol='WBP11', Aliases=['BUG13', 'CFAP90', 'FAP90', 'NPWBP', 'PPP1R165', 'SIPP1', 'VCTERL', 'VCTRL', 'WBP-11'], description='WW domain binding protein 11', other_designations='WW domain-binding protein 11|Npw38-binding protein NpwBP|SH3 domain-binding protein SNP70|protein phosphatase 1, regulatory subunit 165|splicing factor that interacts with PQBP-1 and PP1|splicing factor, PQBP1 and PP1 interacting', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14784582, end_position_on_the_genomic_accession=14803478, orientation='minus', exon_count=12, OMIM=[618083], no_hdr0=''),
    51733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51733, CurrentID=0, Status='live', Symbol='UPB1', Aliases=['BUP1'], description='beta-ureidopropionase 1', other_designations='beta-ureidopropionase|beta-alanine synthase|n-carbamoyl-beta-alanine amidohydrolase|ureidopropionase, beta', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24495060, end_position_on_the_genomic_accession=24528681, orientation='plus', exon_count=13, OMIM=[606673], no_hdr0=''),
    51734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51734, CurrentID=0, Status='live', Symbol='MSRB1', Aliases=['HSPC270', 'SELENOR', 'SELENOX', 'SELR', 'SELX', 'SEPX1', 'SepR'], description='methionine sulfoxide reductase B1', other_designations='methionine-R-sulfoxide reductase B1|selenoprotein R|selenoprotein X, 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1938229, end_position_on_the_genomic_accession=1943199, orientation='minus', exon_count=4, OMIM=[606216], no_hdr0=''),
    51735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51735, CurrentID=0, Status='live', Symbol='RAPGEF6', Aliases=['KIA001LB', 'PDZ-GEF2', 'PDZGEF2', 'RA-GEF-2', 'RAGEF2'], description='Rap guanine nucleotide exchange factor 6', other_designations='rap guanine nucleotide exchange factor 6|PDZ domain containing guanine nucleotide exchange factor (GEF) 2|PDZ domain-containing guanine nucleotide exchange factor 2|PDZ domain-containing guanine nucleotide exchange factor I|Rap guanine nucleotide exchange factor (GEF) 6', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131423921, end_position_on_the_genomic_accession=131635229, orientation='minus', exon_count=31, OMIM=[610499], no_hdr0=''),
    51738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51738, CurrentID=0, Status='live', Symbol='GHRL', Aliases=['MTLRP'], description='ghrelin and obestatin prepropeptide', other_designations='appetite-regulating hormone|In2c-preproghrelin|ghrelin, growth hormone secretagogue receptor ligand|ghrelin/obestatin preprohormone|ghrelin/obestatin prepropeptide|growth hormone-releasing peptide|motilin-related peptide|prepro-appetite regulatory hormone|preproghrelin', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10285666, end_position_on_the_genomic_accession=10292947, orientation='minus', exon_count=6, OMIM=[605353], no_hdr0=''),
    51741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51741, CurrentID=0, Status='live', Symbol='WWOX', Aliases=['D16S432E', 'DEE28', 'EIEE28', 'FOR', 'FRA16D', 'HHCMA56', 'PRO0128', 'SCAR12', 'SDR41C1', 'WOX1'], description='WW domain containing oxidoreductase', other_designations='WW domain-containing oxidoreductase|WW domain-containing protein WWOX|fragile site FRA16D oxidoreductase|short chain dehydrogenase/reductase family 41C member 1', map_location='16q23.1-q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=78099654, end_position_on_the_genomic_accession=79212667, orientation='plus', exon_count=10, OMIM=[605131], no_hdr0=''),
    51742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51742, CurrentID=0, Status='live', Symbol='ARID4B', Aliases=['BCAA', 'BRCAA1', 'RBBP1L1', 'RBP1L1', 'SAP180'], description='AT-rich interaction domain 4B', other_designations='AT-rich interactive domain-containing protein 4B|180 kDa Sin3-associated polypeptide|ARID domain-containing protein 4B|AT rich interactive domain 4B (RBP1-like)|Rb-binding protein homolog|SIN3A-associated protein 180|breast cancer-associated antigen 1|breast cancer-associated antigen BRCAA1|breast carcinoma-associated antigen|histone deacetylase complex subunit SAP180|retinoblastoma-binding protein 1-like 1|sin3-associated polypeptide p180', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235166895, end_position_on_the_genomic_accession=235328224, orientation='minus', exon_count=28, OMIM=[609696], no_hdr0=''),
    51744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51744, CurrentID=0, Status='live', Symbol='CD244', Aliases=['2B4', 'NAIL', 'NKR2B4', 'Nmrk', 'SLAMF4'], description='CD244 molecule', other_designations='natural killer cell receptor 2B4|CD244 molecule, natural killer cell receptor 2B4|NK cell activation inducing ligand NAIL|NK cell activation-inducing ligand|NK cell type I receptor protein 2B4|SLAM family member 4|h2B4|signaling lymphocytic activation molecule 4', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160830160, end_position_on_the_genomic_accession=160862892, orientation='minus', exon_count=9, OMIM=[605554], no_hdr0=''),
    51747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51747, CurrentID=0, Status='live', Symbol='LUC7L3', Aliases=['CRA', 'CREAP-1', 'CROP', 'LUC7A', 'OA48-18', 'hLuc7A'], description='LUC7 like 3 pre-mRNA splicing factor', other_designations='luc7-like protein 3|CRE-associated protein 1|LUC7-like 3|cAMP regulatory element-associated protein 1|cisplatin resistance-associated-overexpressed protein|okadaic acid-inducible phosphoprotein OA48-18', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50719582, end_position_on_the_genomic_accession=50756219, orientation='plus', exon_count=16, OMIM=[609434], no_hdr0=''),
    51750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51750, CurrentID=0, Status='live', Symbol='RTEL1', Aliases=['C20orf41', 'DKCA4', 'DKCB5', 'NHL', 'PFBMFT3', 'RTEL'], description='regulator of telomere elongation helicase 1', other_designations='regulator of telomere elongation helicase 1|regulator of telomere length', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63657810, end_position_on_the_genomic_accession=63696253, orientation='plus', exon_count=35, OMIM=[608833], no_hdr0=''),
    51751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51751, CurrentID=0, Status='live', Symbol='HIGD1B', Aliases=['CLST11240', 'CLST11240-15'], description='HIG1 hypoxia inducible domain family member 1B', other_designations='HIG1 domain family member 1B', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44844281, end_position_on_the_genomic_accession=44850480, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    51752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51752, CurrentID=0, Status='live', Symbol='ERAP1', Aliases=['A-LAP', 'ALAP', 'APPILS', 'ARTS-1', 'ARTS1', 'ERAAP', 'ERAAP1', 'PILS-AP', 'PILSAP'], description='endoplasmic reticulum aminopeptidase 1', other_designations='endoplasmic reticulum aminopeptidase 1|CTD-2260A17.2|adipocyte-derived leucine aminopeptidase|aminopeptidase PILS|aminopeptidase regulator of TNFR1 shedding|endoplasmic reticulum aminopeptidase associated with antigen processing|puromycin-insensitive leucyl-specific aminopeptidase|type 1 tumor necrosis factor receptor shedding aminopeptidase regulator', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=96760273, end_position_on_the_genomic_accession=96935983, orientation='minus', exon_count=27, OMIM=[606832], no_hdr0=''),
    51754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51754, CurrentID=0, Status='live', Symbol='TMEM8B', Aliases=['C9orf127', 'FP588', 'LINC00950', 'NAG-5', 'NAG5', 'NGX6', 'NGX6a'], description='transmembrane protein 8B', other_designations='transmembrane protein 8B|nasopharyngeal carcinoma expressed 6|nasopharyngeal carcinoma related protein|nasopharyngeal carcinoma-associated gene 6 protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35825817, end_position_on_the_genomic_accession=35865515, orientation='plus', exon_count=19, OMIM=[616888], no_hdr0=''),
    51755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51755, CurrentID=0, Status='live', Symbol='CDK12', Aliases=['CRK7', 'CRKR', 'CRKRS'], description='cyclin dependent kinase 12', other_designations='cyclin-dependent kinase 12|CDC2-related protein kinase 7|Cdc2-related kinase, arginine/serine-rich|cell division cycle 2-related protein kinase 7|cell division protein kinase 12', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39461486, end_position_on_the_genomic_accession=39567560, orientation='plus', exon_count=26, OMIM=[615514], no_hdr0=''),
    51759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51759, CurrentID=0, Status='live', Symbol='C9orf78', Aliases=['CSU2', 'HCA59', 'HSPC220', 'bA409K20.3'], description='chromosome 9 open reading frame 78', other_designations='telomere length and silencing protein 1 homolog|hepatocellular carcinoma-associated antigen 59|uncharacterized protein C9orf78', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129827290, end_position_on_the_genomic_accession=129835307, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    51760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51760, CurrentID=0, Status='live', Symbol='SYT17', Aliases=['Syt-17', 'sytXVII'], description='synaptotagmin 17', other_designations='synaptotagmin-17|B/K protein|synaptotagmin XVII', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19167834, end_position_on_the_genomic_accession=19268334, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    51761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51761, CurrentID=0, Status='live', Symbol='ATP8A2', Aliases=['ATP', 'ATPIB', 'CAMRQ4', 'IB', 'ML-1'], description='ATPase phospholipid transporting 8A2', other_designations='phospholipid-transporting ATPase IB|ATPase, aminophospholipid transporter, class I, type 8A, member 2|ATPase, aminophospholipid transporter-like, class I, type 8A, member 2|P4-ATPase flippase complex alpha subunit ATP8A2|probable phospholipid-transporting ATPase IB', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=25371974, end_position_on_the_genomic_accession=26025851, orientation='plus', exon_count=46, OMIM=[605870], no_hdr0=''),
    51762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51762, CurrentID=0, Status='live', Symbol='RAB8B', Aliases=[], description='RAB8B, member RAS oncogene family', other_designations='ras-related protein Rab-8B|RAB-8b protein', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63189536, end_position_on_the_genomic_accession=63267776, orientation='plus', exon_count=11, OMIM=[613532], no_hdr0=''),
    51763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51763, CurrentID=0, Status='live', Symbol='INPP5K', Aliases=['MDCCAID', 'PPS', 'SKIP'], description='inositol polyphosphate-5-phosphatase K', other_designations='inositol polyphosphate 5-phosphatase K|phosphatidylinositol-3,4,5-trisphosphate 5-phosphatase|phosphatidylinositol-4,5-bisphosphate 5-phosphatase|skeletal muscle and kidney-enriched inositol phosphatase', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1494575, end_position_on_the_genomic_accession=1516735, orientation='minus', exon_count=14, OMIM=[607875], no_hdr0=''),
    51764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51764, CurrentID=0, Status='live', Symbol='GNG13', Aliases=['G(gamma)13', 'h2-35'], description='G protein subunit gamma 13', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-13|G gamma subunit, clone:h2-35|guanine nucleotide binding protein (G protein), gamma 13|guanine nucleotide binding protein 13, gamma', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=798041, end_position_on_the_genomic_accession=800734, orientation='minus', exon_count=3, OMIM=[607298], no_hdr0=''),
    51765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51765, CurrentID=0, Status='live', Symbol='STK26', Aliases=['MASK', 'MST4'], description='serine/threonine kinase 26', other_designations='serine/threonine-protein kinase 26|Mst3 and SOK1-related kinase|STE20-like kinase 4|STE20-like kinase MST4|mammalian Ste20-like protein kinase 4|mammalian sterile 20-like 4|serine/threonine protein kinase 26|serine/threonine protein kinase MST4|serine/threonine-protein kinase MASK', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=132023302, end_position_on_the_genomic_accession=132075943, orientation='plus', exon_count=13, OMIM=[300547], no_hdr0=''),
    51768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51768, CurrentID=0, Status='live', Symbol='TM7SF3', Aliases=[], description='transmembrane 7 superfamily member 3', other_designations='transmembrane 7 superfamily member 3|seven span transmembrane protein|seven transmembrane protein TM7SF3', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26966524, end_position_on_the_genomic_accession=27014427, orientation='minus', exon_count=13, OMIM=[605181], no_hdr0=''),
    51773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51773, CurrentID=0, Status='live', Symbol='RSF1', Aliases=['HBXAP', 'RSF-1', 'XAP8', 'p325'], description='remodeling and spacing factor 1', other_designations='remodeling and spacing factor 1|HBV pX-associated protein 8|hepatitis B virus x-associated protein|p325 subunit of RSF chromatin-remodeling complex', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77660009, end_position_on_the_genomic_accession=77872232, orientation='minus', exon_count=17, OMIM=[608522], no_hdr0=''),
    51776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51776, CurrentID=0, Status='live', Symbol='MAP3K20', Aliases=['AZK', 'CNM6', 'MLK7', 'MLT', 'MLTK', 'MLTKalpha', 'MLTKbeta', 'MRK', 'SFMMP', 'ZAK', 'mlklak', 'pk'], description='mitogen-activated protein kinase kinase kinase 20', other_designations='mitogen-activated protein kinase kinase kinase 20|HCCS-4|MLK-like mitogen-activated protein triple kinase|ZAK1 homolog, leucine zipper and sterile-alpha motif kinase|human cervical cancer suppressor gene 4 protein|mitogen-activated protein kinase kinase kinase MLT|mixed lineage kinase 7|mixed lineage kinase with a leucine zipper and a sterile alpha motif|mixed lineage kinase-related kinase MRK-beta|sterile alpha motif and leucine zipper containing kinase AZK', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=173075435, end_position_on_the_genomic_accession=173268015, orientation='plus', exon_count=23, OMIM=[609479], no_hdr0=''),
    51778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51778, CurrentID=0, Status='live', Symbol='MYOZ2', Aliases=['C4orf5', 'CMH16', 'CS-1', 'FATZ-2'], description='myozenin 2', other_designations='myozenin-2|FATZ-related protein 2|calcineurin-binding protein calsarcin-1|muscle-specific protein', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=119135832, end_position_on_the_genomic_accession=119187789, orientation='plus', exon_count=7, OMIM=[605602], no_hdr0=''),
    51780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51780, CurrentID=0, Status='live', Symbol='KDM3B', Aliases=['5qNCA', 'C5orf7', 'DIJOS', 'JMJD1B', 'NET22'], description='lysine demethylase 3B', other_designations='lysine-specific demethylase 3B|[histone H3]-dimethyl-L-lysine(9) demethylase 3B|jmjC domain-containing histone demethylation protein 2B|jumonji domain containing 1B|jumonji domain-containing protein 1B|lysine (K)-specific demethylase 3B|nuclear protein 5qNCA', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138352685, end_position_on_the_genomic_accession=138437027, orientation='plus', exon_count=28, OMIM=[609373], no_hdr0=''),
    51802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51802, CurrentID=0, Status='live', Symbol='ASIC5', Aliases=['ACCN5', 'HINAC', 'INAC'], description='acid sensing ion channel subunit family member 5', other_designations='acid-sensing ion channel 5|acid sensing (proton gated) ion channel family member 5|acid sensing ion channel family member 5|amiloride-sensitive cation channel 5, intestinal|amiloride-sensitive sodium channel|human intestine Na(+) channel', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155829699, end_position_on_the_genomic_accession=155867303, orientation='minus', exon_count=10, OMIM=[616693], no_hdr0=''),
    51804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51804, CurrentID=0, Status='live', Symbol='SIX4', Aliases=['AREC3'], description='SIX homeobox 4', other_designations='homeobox protein SIX4|sine oculis homeobox homolog 4', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60709539, end_position_on_the_genomic_accession=60724351, orientation='minus', exon_count=5, OMIM=[606342], no_hdr0=''),
    51805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51805, CurrentID=0, Status='live', Symbol='COQ3', Aliases=['DHHBMT', 'DHHBMTASE', 'UG0215E05', 'bA9819.1'], description='coenzyme Q3, methyltransferase', other_designations='ubiquinone biosynthesis O-methyltransferase, mitochondrial|2-polyprenyl-6-hydroxyphenol methylase|2-polyprenyl-6-hydroxyphenyl methylase|3,4-dihydroxy-5-hexaprenylbenzoate methyltransferase|3-demethylubiquinol 3-O-methyltransferase|3-demethylubiquinone-10 3-methyltransferase|DHHB methyltransferase|DHHB-MTase|coenzyme Q3 homolog, methyltransferase|dihydroxyhexaprenylbenzoate methyltransferase|hexaprenyldihydroxybenzoate methyltransferase, mitochondrial|methyltransferase COQ3|polyprenyldihydroxybenzoate methyltransferase', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99369401, end_position_on_the_genomic_accession=99394223, orientation='minus', exon_count=8, OMIM=[605196], no_hdr0=''),
    51806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51806, CurrentID=0, Status='live', Symbol='CALML5', Aliases=['CLSP'], description='calmodulin like 5', other_designations='calmodulin-like protein 5|calmodulin-like skin protein', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5498697, end_position_on_the_genomic_accession=5499570, orientation='minus', exon_count=1, OMIM=[605183], no_hdr0=''),
    51807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51807, CurrentID=0, Status='live', Symbol='TUBA8', Aliases=['CDCBM8', 'TUBAL2'], description='tubulin alpha 8', other_designations='tubulin alpha-8 chain|tubulin alpha chain-like 2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18110809, end_position_on_the_genomic_accession=18131732, orientation='plus', exon_count=5, OMIM=[605742], no_hdr0=''),
    51808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51808, CurrentID=0, Status='live', Symbol='PHAX', Aliases=['RNUXA'], description='phosphorylated adaptor for RNA export', other_designations='phosphorylated adapter RNA export protein|RNA U small nuclear RNA export adapter protein|RNA U, small nuclear RNA export adapter (phosphorylation regulated)|RNA U, small nuclear RNA export adaptor (phosphorylation regulated)', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126600947, end_position_on_the_genomic_accession=126627252, orientation='plus', exon_count=5, OMIM=[604924], no_hdr0=''),
    51809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51809, CurrentID=0, Status='live', Symbol='GALNT7', Aliases=['GALNAC-T7', 'GalNAcT7'], description='polypeptide N-acetylgalactosaminyltransferase 7', other_designations='N-acetylgalactosaminyltransferase 7|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 7|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 7 (GalNAc-T7)|polypeptide GalNAc transferase 7|pp-GaNTase 7|protein-UDP acetylgalactosaminyltransferase 7', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=173168811, end_position_on_the_genomic_accession=173323967, orientation='plus', exon_count=17, OMIM=[605005], no_hdr0=''),
    51816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=51816, CurrentID=0, Status='live', Symbol='ADA2', Aliases=['ADGF', 'CECR1', 'IDGFL', 'PAN', 'SNEDS', 'VAIHS'], description='adenosine deaminase 2', other_designations='adenosine deaminase 2|adenosine deaminase CECR1|cat eye syndrome chromosome region, candidate 1|cat eye syndrome critical region protein 1', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17178790, end_position_on_the_genomic_accession=17221854, orientation='minus', exon_count=13, OMIM=[607575], no_hdr0=''),
    53335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53335, CurrentID=0, Status='live', Symbol='BCL11A', Aliases=['BCL11A-L-S', 'BCL11A-XL', 'BCL11a-M', 'CTIP1', 'DILOS', 'EVI9', 'HBFQTL5', 'ZNF856', 'BCL11A'], description='BAF chromatin remodeling complex subunit BCL11A', other_designations='B-cell lymphoma/leukemia 11A|B cell CLL/lymphoma 11A|B-cell CLL/lymphoma 11A (zinc finger protein)|BCL11A B-cell CLL/lymphoma 11A (zinc finger protein)|BCL11A, BAF complex component|C2H2-type zinc finger protein|COUP-TF-interacting protein 1|ecotropic viral integration site 9 homolog|ecotropic viral integration site 9 protein homolog|zinc finger protein 856', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=60450520, end_position_on_the_genomic_accession=60553654, orientation='minus', exon_count=9, OMIM=[606557], no_hdr0=''),
    53336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53336, CurrentID=0, Status='live', Symbol='CPXCR1', Aliases=['CT77'], description='CPX chromosome region candidate 1', other_designations='CPX chromosomal region candidate gene 1 protein|cancer/testis antigen 77', map_location='Xq21.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=88747225, end_position_on_the_genomic_accession=88754781, orientation='plus', exon_count=3, OMIM=[301055], no_hdr0=''),
    53339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53339, CurrentID=0, Status='live', Symbol='BTBD1', Aliases=['C15orf1', 'NS5ATP8'], description='BTB domain containing 1', other_designations='BTB/POZ domain-containing protein 1|BTB (POZ) domain containing 1|HCV NS5A-transactivated protein 8|hepatitis C virus NS5A-transactivated protein 8', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83016423, end_position_on_the_genomic_accession=83067258, orientation='minus', exon_count=8, OMIM=[608530], no_hdr0=''),
    53340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53340, CurrentID=0, Status='live', Symbol='SPA17', Aliases=['CT22', 'SP17', 'SP17-1'], description='sperm autoantigenic protein 17', other_designations='sperm surface protein Sp17|cancer/testis antigen 22|sperm protein 17', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124673904, end_position_on_the_genomic_accession=124697518, orientation='plus', exon_count=6, OMIM=[608621], no_hdr0=''),
    53342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53342, CurrentID=0, Status='live', Symbol='IL17D', Aliases=['IL-17D'], description='interleukin 17D', other_designations='interleukin-17D', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20701513, end_position_on_the_genomic_accession=20723098, orientation='plus', exon_count=7, OMIM=[607587], no_hdr0=''),
    53343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53343, CurrentID=0, Status='live', Symbol='NUDT9', Aliases=['NUDT10'], description='nudix hydrolase 9', other_designations='ADP-ribose pyrophosphatase, mitochondrial|ADP-ribose diphosphatase|ADP-ribose phosphohydrolase|ADP-ribose pyrosphosphatase NUDT9|ADPR-PPase|adenosine diphosphoribose pyrophosphatase|nucleoside diphosphate linked moiety X-type motif 9|nudix (nucleoside diphosphate linked moiety X)-type motif 9', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87420002, end_position_on_the_genomic_accession=87459455, orientation='plus', exon_count=9, OMIM=[606022], no_hdr0=''),
    53344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53344, CurrentID=0, Status='live', Symbol='CHIC1', Aliases=['BRX'], description='cysteine rich hydrophobic domain 1', other_designations='cysteine-rich hydrophobic domain-containing protein 1|brain X-linked protein', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=73563045, end_position_on_the_genomic_accession=73687111, orientation='plus', exon_count=9, OMIM=[300922], no_hdr0=''),
    53345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53345, CurrentID=0, Status='live', Symbol='TM6SF2', Aliases=[], description='transmembrane 6 superfamily member 2', other_designations='transmembrane 6 superfamily member 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19264366, end_position_on_the_genomic_accession=19273301, orientation='minus', exon_count=10, OMIM=[606563], no_hdr0=''),
    53346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53346, CurrentID=0, Status='live', Symbol='TM6SF1', Aliases=[], description='transmembrane 6 superfamily member 1', other_designations='transmembrane 6 superfamily member 1', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83107587, end_position_on_the_genomic_accession=83145403, orientation='plus', exon_count=15, OMIM=[606562], no_hdr0=''),
    53347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53347, CurrentID=0, Status='live', Symbol='UBASH3A', Aliases=['CLIP4', 'STS-2', 'TULA', 'TULA-1'], description='ubiquitin associated and SH3 domain containing A', other_designations='ubiquitin-associated and SH3 domain-containing protein A|T-cell ubiquitin ligand 1|T-cell ubiquitin ligand protein|cbl-interacting protein 4|suppressor of T-cell receptor signaling 2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42403880, end_position_on_the_genomic_accession=42447684, orientation='plus', exon_count=16, OMIM=[605736], no_hdr0=''),
    53349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53349, CurrentID=0, Status='live', Symbol='ZFYVE1', Aliases=['DFCP1', 'PPP1R172', 'SR3', 'TAFF1', 'ZNFN2A1'], description='zinc finger FYVE-type containing 1', other_designations='zinc finger FYVE domain-containing protein 1|double FYVE-containing protein 1|phosphoinositide-binding protein SR3|protein phosphatase 1, regulatory subunit 172|tandem FYVE fingers-1 protein|zinc finger protein, subfamily 2A, member 1|zinc finger, FYVE domain containing 1', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=72969445, end_position_on_the_genomic_accession=73027136, orientation='minus', exon_count=14, OMIM=[605471], no_hdr0=''),
    53353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53353, CurrentID=0, Status='live', Symbol='LRP1B', Aliases=['LRP-1B', 'LRP-DIT', 'LRPDIT'], description='LDL receptor related protein 1B', other_designations='low-density lipoprotein receptor-related protein 1B|LRP-deleted in tumors|low density lipoprotein receptor related protein-deleted in tumor|low density lipoprotein receptor-related protein 1B|low density lipoprotein-related protein 1B (deleted in tumors)', map_location='2q22.1-q22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=140231423, end_position_on_the_genomic_accession=142132463, orientation='minus', exon_count=92, OMIM=[608766], no_hdr0=''),
    53354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53354, CurrentID=0, Status='live', Symbol='PANK1', Aliases=['PANK'], description='pantothenate kinase 1', other_designations='pantothenate kinase 1|pantothenic acid kinase 1', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89579495, end_position_on_the_genomic_accession=89645242, orientation='minus', exon_count=12, OMIM=[606160], no_hdr0=''),
    53358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53358, CurrentID=0, Status='live', Symbol='SHC3', Aliases=['N-Shc', 'NSHC', 'RAI', 'SHCC'], description='SHC adaptor protein 3', other_designations='SHC-transforming protein 3|SH2 domain protein C3|SHC (Src homology 2 domain containing) transforming protein 3|SHC-transforming protein C|Shc3 p51|neuronal Shc|protein Rai|src homology 2 domain-containing transforming protein C3', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=89005771, end_position_on_the_genomic_accession=89178818, orientation='minus', exon_count=12, OMIM=[605263], no_hdr0=''),
    53371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53371, CurrentID=0, Status='live', Symbol='NUP54', Aliases=[], description='nucleoporin 54', other_designations='nucleoporin p54|54 kDa nucleoporin|nucleoporin 54kD|nucleoporin 54kDa', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76114664, end_position_on_the_genomic_accession=76148434, orientation='minus', exon_count=14, OMIM=[607607], no_hdr0=''),
    53373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53373, CurrentID=0, Status='live', Symbol='TPCN1', Aliases=['TPC1'], description='two pore segment channel 1', other_designations='two pore calcium channel protein 1|two-pore channel 1, homolog|voltage-dependent calcium channel protein TPC1', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113221429, end_position_on_the_genomic_accession=113298589, orientation='plus', exon_count=33, OMIM=[609666], no_hdr0=''),
    53405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53405, CurrentID=0, Status='live', Symbol='CLIC5', Aliases=['DFNB102', 'DFNB103', 'MST130', 'MSTP130'], description='chloride intracellular channel 5', other_designations='chloride intracellular channel protein 5', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=45898451, end_position_on_the_genomic_accession=46129819, orientation='minus', exon_count=14, OMIM=[607293], no_hdr0=''),
    53407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53407, CurrentID=0, Status='live', Symbol='STX18', Aliases=['Ufe1'], description='syntaxin 18', other_designations='syntaxin-18|cell growth-inhibiting gene 9 protein', map_location='4p16.3-p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4418968, end_position_on_the_genomic_accession=4542343, orientation='minus', exon_count=14, OMIM=[606046], no_hdr0=''),
    53615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53615, CurrentID=0, Status='live', Symbol='MBD3', Aliases=[], description='methyl-CpG binding domain protein 3', other_designations='methyl-CpG-binding domain protein 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1573596, end_position_on_the_genomic_accession=1592865, orientation='minus', exon_count=7, OMIM=[603573], no_hdr0=''),
    53616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53616, CurrentID=0, Status='live', Symbol='ADAM22', Aliases=['ADAM 22', 'DEE61', 'EIEE61', 'MDC2'], description='ADAM metallopeptidase domain 22', other_designations='disintegrin and metalloproteinase domain-containing protein 22|a disintegrin and metalloproteinase domain 22|metalloproteinase-disintegrin ADAM22-3|metalloproteinase-like, disintegrin-like, and cysteine-rich protein 2', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87934163, end_position_on_the_genomic_accession=88202889, orientation='plus', exon_count=35, OMIM=[603709], no_hdr0=''),
    53630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53630, CurrentID=0, Status='live', Symbol='BCO1', Aliases=['BCDO', 'BCDO1', 'BCMO', 'BCMO1', 'BCO'], description='beta-carotene oxygenase 1', other_designations="beta,beta-carotene 15,15'-dioxygenase|beta,beta-carotene 15,15'-monooxygenase|beta-carotene 15, 15'-dioxygenase 1|beta-carotene 15,15'-monooxygenase 1|beta-carotene dioxygenase 1", map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81238448, end_position_on_the_genomic_accession=81291142, orientation='plus', exon_count=11, OMIM=[605748], no_hdr0=''),
    53632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53632, CurrentID=0, Status='live', Symbol='PRKAG3', Aliases=['AMPKG3', 'SMGMQTL'], description='protein kinase AMP-activated non-catalytic subunit gamma 3', other_designations="5'-AMP-activated protein kinase subunit gamma-3|5'-AMP-activated protein kinase, gamma-3 subunit|AMPK gamma-3 chain|AMPK gamma3|AMPK subunit gamma-3|protein kinase, AMP-activated, gamma 3 non-catalytic subunit", map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218819949, end_position_on_the_genomic_accession=218831803, orientation='minus', exon_count=13, OMIM=[604976], no_hdr0=''),
    53635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53635, CurrentID=0, Status='live', Symbol='PTOV1', Aliases=['ACID2', 'PTOV-1'], description='PTOV1 extended AT-hook containing adaptor protein', other_designations='prostate tumor-overexpressed gene 1 protein|activator interaction domain-containing protein 2|prostate tumor overexpressed 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49848554, end_position_on_the_genomic_accession=49860742, orientation='plus', exon_count=16, OMIM=[610195], no_hdr0=''),
    53637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53637, CurrentID=0, Status='live', Symbol='S1PR5', Aliases=['EDG8', 'Edg-8', 'S1P5', 'SPPR-1', 'SPPR-2'], description='sphingosine-1-phosphate receptor 5', other_designations='sphingosine 1-phosphate receptor 5|S1P receptor 5|S1P receptor Edg-8|endothelial differentiation G-protein-coupled receptor 8|endothelial differentiation, sphingolipid G-protein-coupled receptor, 8|sphingosine 1-phosphate receptor EDG8|sphingosine 1-phosphate receptor Edg-8', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10512742, end_position_on_the_genomic_accession=10517965, orientation='minus', exon_count=3, OMIM=[605146], no_hdr0=''),
    53820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53820, CurrentID=0, Status='live', Symbol='RIPPLY3', Aliases=['DSCR6'], description='ripply transcriptional repressor 3', other_designations='protein ripply3|Down syndrome critical region gene 6|down syndrome critical region protein 6|ripply3 homolog', map_location='21q22.13', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=37006150, end_position_on_the_genomic_accession=37019662, orientation='plus', exon_count=5, OMIM=[609892], no_hdr0=''),
    53822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53822, CurrentID=0, Status='live', Symbol='FXYD7', Aliases=[], description='FXYD domain containing ion transport regulator 7', other_designations='FXYD domain-containing ion transport regulator 7', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35143255, end_position_on_the_genomic_accession=35154302, orientation='plus', exon_count=6, OMIM=[606684], no_hdr0=''),
    53826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53826, CurrentID=0, Status='live', Symbol='FXYD6', Aliases=[], description='FXYD domain containing ion transport regulator 6', other_designations='FXYD domain-containing ion transport regulator 6|phosphohippolin', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117836981, end_position_on_the_genomic_accession=117877430, orientation='minus', exon_count=11, OMIM=[606683], no_hdr0=''),
    53827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53827, CurrentID=0, Status='live', Symbol='FXYD5', Aliases=['DYSAD', 'HSPC113', 'IWU1', 'KCT1', 'OIT2', 'PRO6241', 'RIC'], description='FXYD domain containing ion transport regulator 5', other_designations='FXYD domain-containing ion transport regulator 5|dysadherin|keratinocytes associated transmembrane protein 1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35154735, end_position_on_the_genomic_accession=35169881, orientation='plus', exon_count=8, OMIM=[606669], no_hdr0=''),
    53828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53828, CurrentID=0, Status='live', Symbol='FXYD4', Aliases=['CHIF'], description='FXYD domain containing ion transport regulator 4', other_designations='FXYD domain-containing ion transport regulator 4|channel-inducing factor', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43371636, end_position_on_the_genomic_accession=43376335, orientation='plus', exon_count=9, OMIM=[616926], no_hdr0=''),
    53829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53829, CurrentID=0, Status='live', Symbol='P2RY13', Aliases=['FKSG77', 'GPCR1', 'GPR86', 'GPR94', 'P2Y13', 'SP174'], description='purinergic receptor P2Y13', other_designations='P2Y purinoceptor 13|G protein-coupled receptor 86|G-protein coupled receptor 94|purinergic receptor P2Y, G-protein coupled, 13', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151326312, end_position_on_the_genomic_accession=151329549, orientation='minus', exon_count=3, OMIM=[606380], no_hdr0=''),
    53831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53831, CurrentID=0, Status='live', Symbol='GPR84', Aliases=['EX33', 'GPCR4'], description='G protein-coupled receptor 84', other_designations='G-protein coupled receptor 84|inflammation-related G protein-coupled receptor EX33', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54362445, end_position_on_the_genomic_accession=54365224, orientation='minus', exon_count=2, OMIM=[606383], no_hdr0=''),
    53832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53832, CurrentID=0, Status='live', Symbol='IL20RA', Aliases=['CRF2-8', 'IL-20R-alpha', 'IL-20R1', 'IL-20RA'], description='interleukin 20 receptor subunit alpha', other_designations='interleukin-20 receptor subunit alpha|class II cytokine receptor ZCYTOR7|cytokine receptor family 2 member 8|interleukin 20 receptor alpha subunit|interleukin 20 receptor, alpha|interleukin-20 receptor I', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136999971, end_position_on_the_genomic_accession=137044965, orientation='minus', exon_count=8, OMIM=[605620], no_hdr0=''),
    53833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53833, CurrentID=0, Status='live', Symbol='IL20RB', Aliases=['DIRS1', 'FNDC6', 'IL-20R2'], description='interleukin 20 receptor subunit beta', other_designations='interleukin-20 receptor subunit beta|IL-20 receptor subunit beta|IL-20R-beta|IL-20RB|fibronectin type III domain containing 6|interleukin 20 receptor beta subunit|interleukin-20 receptor II', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136957983, end_position_on_the_genomic_accession=137011085, orientation='plus', exon_count=9, OMIM=[605621], no_hdr0=''),
    53834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53834, CurrentID=0, Status='live', Symbol='FGFRL1', Aliases=['FGFR-5', 'FGFR5', 'FHFR'], description='fibroblast growth factor receptor like 1', other_designations='fibroblast growth factor receptor-like 1|FGF homologous factor receptor|FGF receptor-like protein 1|FGFR-like protein|fibroblast growth factor receptor 5', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1009930, end_position_on_the_genomic_accession=1026898, orientation='plus', exon_count=10, OMIM=[605830], no_hdr0=''),
    53836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53836, CurrentID=0, Status='live', Symbol='GPR87', Aliases=['FKSG78', 'GPR95', 'KPG_002'], description='G protein-coupled receptor 87', other_designations='G-protein coupled receptor 87|G-protein coupled receptor 95|orphan GPCR 87', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151294086, end_position_on_the_genomic_accession=151316820, orientation='minus', exon_count=3, OMIM=[606379], no_hdr0=''),
    53838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53838, CurrentID=0, Status='live', Symbol='C11orf24', Aliases=['DM4E3'], description='chromosome 11 open reading frame 24', other_designations='uncharacterized protein C11orf24', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68261338, end_position_on_the_genomic_accession=68271973, orientation='minus', exon_count=4, OMIM=[610880], no_hdr0=''),
    53840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53840, CurrentID=0, Status='live', Symbol='TRIM34', Aliases=['IFP1', 'RNF21'], description='tripartite motif containing 34', other_designations='tripartite motif-containing protein 34|interferon-responsive finger protein 1|ring finger protein 21, interferon-responsive', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5619944, end_position_on_the_genomic_accession=5644398, orientation='plus', exon_count=9, OMIM=[605684], no_hdr0=''),
    53841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53841, CurrentID=0, Status='live', Symbol='CDHR5', Aliases=['MLPCDH', 'MU-PCDH', 'MUCDHL', 'MUPCDH'], description='cadherin related family member 5', other_designations='cadherin-related family member 5|differentiation-associated catenin regulator|mu-protocadherin|mucin and cadherin-like protein', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=616583, end_position_on_the_genomic_accession=624967, orientation='minus', exon_count=16, OMIM=[606839], no_hdr0=''),
    53842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53842, CurrentID=0, Status='live', Symbol='CLDN22', Aliases=['CLDN21'], description='claudin 22', other_designations='claudin-22', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183318100, end_position_on_the_genomic_accession=183320276, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    53904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53904, CurrentID=0, Status='live', Symbol='MYO3A', Aliases=['DFNB30'], description='myosin IIIA', other_designations='myosin-IIIa|epididymis secretory sperm binding protein', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=25934229, end_position_on_the_genomic_accession=26212536, orientation='plus', exon_count=43, OMIM=[606808], no_hdr0=''),
    53905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53905, CurrentID=0, Status='live', Symbol='DUOX1', Aliases=['LNOX1', 'NOXEF1', 'THOX1'], description='dual oxidase 1', other_designations='dual oxidase 1|NADPH thyroid oxidase 1|flavoprotein NADPH oxidase|large NOX 1|long NOX 1|nicotinamide adenine dinucleotide phosphate oxidase|thyroid oxidase 1', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45129994, end_position_on_the_genomic_accession=45165578, orientation='plus', exon_count=35, OMIM=[606758], no_hdr0=''),
    53916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53916, CurrentID=0, Status='live', Symbol='RAB4B', Aliases=[], description='RAB4B, member RAS oncogene family', other_designations='ras-related protein Rab-4B|ras-related GTP-binding protein 4b|small GTP binding protein RAB4B', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40778247, end_position_on_the_genomic_accession=40796942, orientation='plus', exon_count=8, OMIM=[612945], no_hdr0=''),
    53917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53917, CurrentID=0, Status='live', Symbol='RAB24', Aliases=[], description='RAB24, member RAS oncogene family', other_designations='ras-related protein Rab-24', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177301198, end_position_on_the_genomic_accession=177303719, orientation='minus', exon_count=7, OMIM=[612415], no_hdr0=''),
    53918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53918, CurrentID=0, Status='live', Symbol='PELO', Aliases=['CGI-17', 'PRO1770'], description='pelota mRNA surveillance and ribosome rescue factor', other_designations='protein pelota homolog|pelota homolog', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=52787916, end_position_on_the_genomic_accession=52804044, orientation='plus', exon_count=3, OMIM=[605757], no_hdr0=''),
    53919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53919, CurrentID=0, Status='live', Symbol='SLCO1C1', Aliases=['OATP-F', 'OATP1', 'OATP14', 'OATP1C1', 'OATPF', 'OATPRP5', 'SLC21A14'], description='solute carrier organic anion transporter family member 1C1', other_designations='solute carrier organic anion transporter family member 1C1|OAT-RP-5|OATP-14|organic anion transporter F|organic anion transporter polypeptide-related protein 5|organic anion transporting polypeptide 14|solute carrier family 21 (organic anion transporter), member 14|solute carrier family 21 member 14|thyroxine transporter', map_location='12p12.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=20681800, end_position_on_the_genomic_accession=20753386, orientation='plus', exon_count=20, OMIM=[613389], no_hdr0=''),
    53938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53938, CurrentID=0, Status='live', Symbol='PPIL3', Aliases=['CYPJ'], description='peptidylprolyl isomerase like 3', other_designations='peptidyl-prolyl cis-trans isomerase-like 3|PPIase|PPIase-like protein 3|cyclophilin J|cyclophilin-like protein 3|cyclophilin-like protein PPIL3|peptidylprolyl cis-trans isomerase-like protein 3|peptidylprolyl isomerase (cyclophilin)-like 3|rotamase PPIL3', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200870907, end_position_on_the_genomic_accession=200889333, orientation='minus', exon_count=11, OMIM=[615811], no_hdr0=''),
    53940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53940, CurrentID=0, Status='live', Symbol='FTHL17', Aliases=['CT38'], description='ferritin heavy chain like 17', other_designations='ferritin heavy polypeptide-like 17|cancer/testis antigen 38|epididymis secretory sperm binding protein|ferritin, heavy polypeptide-like 17', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=31071233, end_position_on_the_genomic_accession=31072041, orientation='minus', exon_count=1, OMIM=[300308], no_hdr0=''),
    53942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53942, CurrentID=0, Status='live', Symbol='CNTN5', Aliases=['HNB-2s', 'NB-2'], description='contactin 5', other_designations='contactin-5|neural adhesion molecule|neural recognition molecule NB-2', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=99020904, end_position_on_the_genomic_accession=100358885, orientation='plus', exon_count=27, OMIM=[607219], no_hdr0=''),
    53944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53944, CurrentID=0, Status='live', Symbol='CSNK1G1', Aliases=['CK1gamma1'], description='casein kinase 1 gamma 1', other_designations='casein kinase I isoform gamma-1', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64165525, end_position_on_the_genomic_accession=64356173, orientation='minus', exon_count=13, OMIM=[606274], no_hdr0=''),
    53947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53947, CurrentID=0, Status='live', Symbol='A4GALT', Aliases=['A14GALT1', 'Gb3S', 'P(k)', 'P1', 'P1PK', 'PK', 'A4GALT'], description='alpha 1,4-galactosyltransferase (P blood group)', other_designations='lactosylceramide 4-alpha-galactosyltransferase|CD77 synthase|GB3 synthase|P blood group (P one antigen)|P one antigen (P blood group)|P(k) antigen synthase|P1/Pk synthase|UDP-galactose:beta-D-galactosyl-beta1-R 4-alpha-D-galactosyltransferase|alpha 14-galactosyltransferase|alpha-1,4-N-acetylglucosaminyltransferase|alpha-1,4-galactosyltransferase|alpha4Gal-T1|globotriaosylceramide synthase|truncated alpha 1,4-galactosyltransferase', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42692115, end_position_on_the_genomic_accession=42721301, orientation='minus', exon_count=10, OMIM=[607922], no_hdr0=''),
    53981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=53981, CurrentID=0, Status='live', Symbol='CPSF2', Aliases=['CPSF100'], description='cleavage and polyadenylation specific factor 2', other_designations='cleavage and polyadenylation specificity factor subunit 2|CPSF 100 kDa subunit|CPSF 100kDa subunit|cleavage and polyadenylation specific factor 2, 100kDa|cleavage and polyadenylation specificity factor 100 kDa subunit', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92121969, end_position_on_the_genomic_accession=92172145, orientation='plus', exon_count=16, OMIM=[606028], no_hdr0=''),
    54014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54014, CurrentID=0, Status='live', Symbol='BRWD1', Aliases=['C21orf107', 'DCAF19', 'N143', 'WDR9', 'WRD9'], description='bromodomain and WD repeat domain containing 1', other_designations='bromodomain and WD repeat-containing protein 1|WD repeat protein WDR9-form2|WD repeat-containing protein 9|transcriptional unit N143', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39184176, end_position_on_the_genomic_accession=39321595, orientation='minus', exon_count=47, OMIM=[617824], no_hdr0=''),
    54020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54020, CurrentID=0, Status='live', Symbol='SLC37A1', Aliases=['G3PP'], description='solute carrier family 37 member 1', other_designations='glucose-6-phosphate exchanger SLC37A1|G-3-P permease|G-3-P transporter|glycerol-3-phosphate permease|glycerol-3-phosphate transporter|solute carrier family 37 (glucose-6-phosphate transporter), member 1|solute carrier family 37 (glycerol-3-phosphate transporter), member 1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42499622, end_position_on_the_genomic_accession=42581436, orientation='plus', exon_count=26, OMIM=[608094], no_hdr0=''),
    54033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54033, CurrentID=0, Status='live', Symbol='RBM11', Aliases=[], description='RNA binding motif protein 11', other_designations='splicing regulator RBM11|putative RNA-binding protein 11', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14216107, end_position_on_the_genomic_accession=14228372, orientation='plus', exon_count=7, OMIM=[617937], no_hdr0=''),
    54039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54039, CurrentID=0, Status='live', Symbol='PCBP3', Aliases=['ALPHA-CP3-OT1', 'PCBP3OT', 'PCBP3'], description='poly(rC) binding protein 3', other_designations='poly(rC)-binding protein 3|PCBP3 overlapping transcript 1|PCBP3-overlapping transcript|poly(rC) binding protein 3 overlapping transcript', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45643725, end_position_on_the_genomic_accession=45942454, orientation='plus', exon_count=35, OMIM=[608502], no_hdr0=''),
    54058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54058, CurrentID=0, Status='live', Symbol='C21orf58', Aliases=[], description='chromosome 21 open reading frame 58', other_designations='uncharacterized protein C21orf58', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46300426, end_position_on_the_genomic_accession=46324046, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    54059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54059, CurrentID=0, Status='live', Symbol='YBEY', Aliases=['C21orf57'], description='ybeY metalloendoribonuclease', other_designations='endoribonuclease YbeY|putative metalloprotease C21orf57|putative ribonuclease|rRNA maturation factor homolog|ybeY metallopeptidase (putative)', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46286056, end_position_on_the_genomic_accession=46314188, orientation='plus', exon_count=10, OMIM=[617461], no_hdr0=''),
    54065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54065, CurrentID=0, Status='live', Symbol='SMIM11', Aliases=['C21orf51', 'FAM165BA', 'SMIM11B', 'SMIM11'], description='small integral membrane protein 11', other_designations='small integral membrane protein 11A|family with sequence similarity 165, member B|protein FAM165B', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34375507, end_position_on_the_genomic_accession=34389151, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54069, CurrentID=0, Status='live', Symbol='MIS18A', Aliases=['B28', 'C21orf45', 'C21orf46', 'FASP1', 'MIS18alpha', 'hMis18alpha'], description='MIS18 kinetochore protein A', other_designations='protein Mis18-alpha|FAPP1-associated protein 1|MIS18 kinetochore protein homolog A', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32154682, end_position_on_the_genomic_accession=32283954, orientation='minus', exon_count=9, OMIM=[618137], no_hdr0=''),
    54084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54084, CurrentID=0, Status='live', Symbol='TSPEAR', Aliases=['C21orf29', 'DFNB98', 'ECTD14', 'TSP-EAR'], description='thrombospondin type laminin G domain and EAR repeats', other_designations='thrombospondin-type laminin G domain and EAR repeat-containing protein|thrombospondin-type laminin G domain and EAR repeats-containing protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44497893, end_position_on_the_genomic_accession=44711572, orientation='minus', exon_count=13, OMIM=[612920], no_hdr0=''),
    54093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54093, CurrentID=0, Status='live', Symbol='SETD4', Aliases=['C21orf18', 'C21orf27'], description='SET domain containing 4', other_designations='SET domain-containing protein 4', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=36034541, end_position_on_the_genomic_accession=36061037, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    54097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54097, CurrentID=0, Status='live', Symbol='FAM3B', Aliases=['2-21', 'C21orf11', 'C21orf76', 'ORF9', 'PANDER', 'PRED44'], description='FAM3 metabolism regulating signaling molecule B', other_designations='protein FAM3B|D21M16SJHU19e|cytokine-like protein 2-21|family with sequence similarity 3 member B|pancreatic derived factor', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41304229, end_position_on_the_genomic_accession=41357727, orientation='plus', exon_count=11, OMIM=[608617], no_hdr0=''),
    54101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54101, CurrentID=0, Status='live', Symbol='RIPK4', Aliases=['ANKK2', 'ANKRD3', 'CHANDS', 'DIK', 'NKRD3', 'PKK', 'PPS2', 'RIP4'], description='receptor interacting serine/threonine kinase 4', other_designations='receptor-interacting serine/threonine-protein kinase 4|PKC-delta-interacting protein kinase|ankyrin repeat domain-containing protein 3|protein kinase C-associated kinase|serine/threonine-protein kinase ANKRD3', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41739373, end_position_on_the_genomic_accession=41767052, orientation='minus', exon_count=8, OMIM=[605706], no_hdr0=''),
    54102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54102, CurrentID=0, Status='live', Symbol='CLIC6', Aliases=['CLIC1L'], description='chloride intracellular channel 6', other_designations='chloride intracellular channel protein 6|chloride channel form A|parchorin', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34668953, end_position_on_the_genomic_accession=34718223, orientation='plus', exon_count=7, OMIM=[615321], no_hdr0=''),
    54103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54103, CurrentID=0, Status='live', Symbol='GSAP', Aliases=['PION'], description='gamma-secretase activating protein', other_designations='gamma-secretase-activating protein|pigeon homolog|protein pigeon homolog', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77310751, end_position_on_the_genomic_accession=77416419, orientation='minus', exon_count=35, OMIM=[613552], no_hdr0=''),
    54106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54106, CurrentID=0, Status='live', Symbol='TLR9', Aliases=['CD289'], description='toll like receptor 9', other_designations='toll-like receptor 9', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52221080, end_position_on_the_genomic_accession=52225645, orientation='minus', exon_count=2, OMIM=[605474], no_hdr0=''),
    54107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54107, CurrentID=0, Status='live', Symbol='POLE3', Aliases=['CHARAC17', 'CHRAC17', 'CHRAC2', 'YBL1', 'p17'], description='DNA polymerase epsilon 3, accessory subunit', other_designations='DNA polymerase epsilon subunit 3|CHRAC-17|DNA polymerase II subunit 3|DNA polymerase epsilon p17 subunit|DNA polymerase epsilon subunit p17|arsenic transactivated protein|asTP|chromatin accessibility complex 17 kDa protein|chromatin accessibility complex subunit 2|histone fold protein CHRAC17|huCHRAC17|polymerase (DNA directed), epsilon 3 (p17 subunit)|polymerase (DNA directed), epsilon 3, accessory subunit|polymerase (DNA) epsilon 3, accessory subunit', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113407235, end_position_on_the_genomic_accession=113410749, orientation='minus', exon_count=5, OMIM=[607267], no_hdr0=''),
    54108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54108, CurrentID=0, Status='live', Symbol='CHRAC1', Aliases=['CHARC1', 'CHARC15', 'CHRAC-1', 'CHRAC-155', 'YCL1', 'CHRAC1'], description='chromatin accessibility complex subunit 1', other_designations='chromatin accessibility complex protein 1|DNA polymerase epsilon subunit p15|chromatin accessibility complex 1|chromatin accessibility complex 15 kDa protein|histone-fold protein CHRAC15', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=140511322, end_position_on_the_genomic_accession=140517154, orientation='plus', exon_count=4, OMIM=[607268], no_hdr0=''),
    54112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54112, CurrentID=0, Status='live', Symbol='GPR88', Aliases=['COCPMR', 'STRG'], description='G protein-coupled receptor 88', other_designations='probable G-protein coupled receptor 88|striatum-specific G-protein coupled receptor', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100538139, end_position_on_the_genomic_accession=100542021, orientation='plus', exon_count=2, OMIM=[607468], no_hdr0=''),
    54145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54145, CurrentID=0, Status='live', Symbol='H2BS1', Aliases=['H2B/s', 'H2BFS'], description='H2B.S histone 1', other_designations='histone H2B type F-S|H2B histone family member S|histone H2B.s|histone protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43565182, end_position_on_the_genomic_accession=43565648, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    54148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54148, CurrentID=0, Status='live', Symbol='MRPL39', Aliases=['C21orf92', 'L39mt', 'L5mt', 'MRP-L5', 'MRPL5', 'MSTP003', 'PRED22', 'PRED66', 'RPML5'], description='mitochondrial ribosomal protein L39', other_designations='39S ribosomal protein L39, mitochondrial|39S ribosomal protein L5, mitochondrial|mitochondrial large ribosomal subunit protein mL39', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=25585656, end_position_on_the_genomic_accession=25607858, orientation='minus', exon_count=12, OMIM=[611845], no_hdr0=''),
    54149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54149, CurrentID=0, Status='live', Symbol='C21orf91', Aliases=['C21orf14', 'C21orf38', 'CSSG1', 'EURL', 'YG81'], description='chromosome 21 open reading frame 91', other_designations='protein EURL homolog|cold sore susceptibility gene 1|early undifferentiated retina and lens', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=17788974, end_position_on_the_genomic_accession=17819356, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    54165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54165, CurrentID=0, Status='live', Symbol='DCUN1D1', Aliases=['DCNL1', 'DCUN1L1', 'RP42', 'SCCRO', 'SCRO', 'Tes3'], description='defective in cullin neddylation 1 domain containing 1', other_designations='DCN1-like protein 1|DCN1, defective in cullin neddylation 1, domain containing 1|DCUN1 domain-containing protein 1|RP42 homolog|defective in cullin neddylation protein 1-like protein 1|squamous cell carcinoma-related oncogene', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=182938074, end_position_on_the_genomic_accession=182986364, orientation='minus', exon_count=10, OMIM=[605905], no_hdr0=''),
    54187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54187, CurrentID=0, Status='live', Symbol='NANS', Aliases=['HEL-S-100', 'SAS', 'SEMDCG', 'SEMDG'], description='N-acetylneuraminate synthase', other_designations='sialic acid synthase|N-acetylneuraminate-9-phosphate synthase|N-acetylneuraminic acid phosphate synthase|N-acetylneuraminic acid synthase|epididymis secretory protein Li 100|sialic acid phosphate synthase', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98056728, end_position_on_the_genomic_accession=98083083, orientation='plus', exon_count=6, OMIM=[605202], no_hdr0=''),
    54205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54205, CurrentID=0, Status='live', Symbol='CYCS', Aliases=['CYC', 'HCS', 'THC4'], description='cytochrome c, somatic', other_designations='cytochrome c', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=25118656, end_position_on_the_genomic_accession=25125260, orientation='minus', exon_count=3, OMIM=[123970], no_hdr0=''),
    54206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54206, CurrentID=0, Status='live', Symbol='ERRFI1', Aliases=['GENE-33', 'MIG-6', 'MIG6', 'RALT'], description='ERBB receptor feedback inhibitor 1', other_designations='ERBB receptor feedback inhibitor 1|mitogen-inducible gene 6 protein|receptor-associated late transducer', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8011725, end_position_on_the_genomic_accession=8026309, orientation='minus', exon_count=5, OMIM=[608069], no_hdr0=''),
    54207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54207, CurrentID=0, Status='live', Symbol='KCNK10', Aliases=['K2p10.1', 'PPP1R97', 'TREK-2', 'TREK2'], description='potassium two pore domain channel subfamily K member 10', other_designations='potassium channel subfamily K member 10|2P domain potassium channel TREK2|TREK-2 K(+) channel subunit|TWIK-related K+ channel 2|outward rectifying potassium channel protein TREK-2|potassium channel TREK-2|potassium channel, subfamily K, member 10|potassium channel, two pore domain subfamily K, member 10|protein phosphatase 1, regulatory subunit 97', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88180108, end_position_on_the_genomic_accession=88326912, orientation='minus', exon_count=11, OMIM=[605873], no_hdr0=''),
    54209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54209, CurrentID=0, Status='live', Symbol='TREM2', Aliases=['PLOSL2', 'TREM-2', 'Trem2a', 'Trem2b', 'Trem2c'], description='triggering receptor expressed on myeloid cells 2', other_designations='triggering receptor expressed on myeloid cells 2|triggering receptor expressed on monocytes 2|triggering receptor expressed on myeloid cells 2a', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41158508, end_position_on_the_genomic_accession=41163116, orientation='minus', exon_count=5, OMIM=[605086], no_hdr0=''),
    54210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54210, CurrentID=0, Status='live', Symbol='TREM1', Aliases=['CD354', 'TREM-1'], description='triggering receptor expressed on myeloid cells 1', other_designations='triggering receptor expressed on myeloid cells 1|triggering receptor expressed on monocytes 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41267385, end_position_on_the_genomic_accession=41286692, orientation='minus', exon_count=6, OMIM=[605085], no_hdr0=''),
    54212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54212, CurrentID=0, Status='live', Symbol='SNTG1', Aliases=['G1SYN', 'SYN4'], description='syntrophin gamma 1', other_designations='gamma-1-syntrophin|gamma1-syntrophin|syntrophin 4', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=49909796, end_position_on_the_genomic_accession=50796692, orientation='plus', exon_count=28, OMIM=[608714], no_hdr0=''),
    54221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54221, CurrentID=0, Status='live', Symbol='SNTG2', Aliases=['G2SYN', 'SYN5'], description='syntrophin gamma 2', other_designations='gamma-2-syntrophin|syntrophin-5', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=950849, end_position_on_the_genomic_accession=1367991, orientation='plus', exon_count=30, OMIM=[608715], no_hdr0=''),
    54328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54328, CurrentID=0, Status='live', Symbol='GPR173', Aliases=['SREB3'], description='G protein-coupled receptor 173', other_designations='probable G-protein coupled receptor 173|super conserved receptor expressed in brain 3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53048789, end_position_on_the_genomic_accession=53080615, orientation='plus', exon_count=3, OMIM=[300253], no_hdr0=''),
    54329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54329, CurrentID=0, Status='live', Symbol='GPR85', Aliases=['SREB', 'SREB2'], description='G protein-coupled receptor 85', other_designations='probable G-protein coupled receptor 85|seven transmembrane helix receptor|super conserved receptor expressed in brain 2', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=113081854, end_position_on_the_genomic_accession=113087724, orientation='minus', exon_count=4, OMIM=[605188], no_hdr0=''),
    54331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54331, CurrentID=0, Status='live', Symbol='GNG2', Aliases=[], description='G protein subunit gamma 2', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-2|g gamma-I|guanine nucleotide binding protein (G protein), gamma 2|guanine nucleotide binding protein gamma 2|guanine nucleotide-binding protein G(I)/G(O) gamma-2 subunit', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=51826174, end_position_on_the_genomic_accession=51969800, orientation='plus', exon_count=13, OMIM=[606981], no_hdr0=''),
    54332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54332, CurrentID=0, Status='live', Symbol='GDAP1', Aliases=['CMT4', 'CMT4A', 'CMTRIA'], description='ganglioside induced differentiation associated protein 1', other_designations='ganglioside-induced differentiation-associated protein 1|Charcot-Marie-Tooth neuropathy 4A', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=74350403, end_position_on_the_genomic_accession=74488872, orientation='plus', exon_count=8, OMIM=[606598], no_hdr0=''),
    54344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54344, CurrentID=0, Status='live', Symbol='DPM3', Aliases=['CDG1O', 'MDDGB15', 'MDDGC15'], description='dolichyl-phosphate mannosyltransferase subunit 3, regulatory', other_designations='dolichol-phosphate mannosyltransferase subunit 3|DPM synthase complex subunit 3|DPM synthase subunit 3|MPD synthase subunit 3|dolichol-phosphate mannose synthase subunit 3|dolichyl-phosphate beta-D-mannosyltransferase subunit 3|dolichyl-phosphate mannosyltransferase polypeptide 3|mannose-P-dolichol synthase subunit 3|prostin 1|testicular tissue protein Li 58', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155139891, end_position_on_the_genomic_accession=155140573, orientation='minus', exon_count=2, OMIM=[605951], no_hdr0=''),
    54345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54345, CurrentID=0, Status='live', Symbol='SOX18', Aliases=['HLTRS', 'HLTS'], description='SRY-box transcription factor 18', other_designations='transcription factor SOX-18|SRY (sex determining region Y)-box 18|SRY-box 18', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64047582, end_position_on_the_genomic_accession=64049639, orientation='minus', exon_count=2, OMIM=[601618], no_hdr0=''),
    54346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54346, CurrentID=0, Status='live', Symbol='UNC93A', Aliases=['Unc-93A', 'dJ366N23.1', 'dJ366N23.2'], description='unc-93 homolog A', other_designations='protein unc-93 homolog A|dJ366N23.1 (putative C. elegans UNC-93 (protein 1, C46F11.1) LIKE)|dJ366N23.2 (putative C. elegans UNC-93 (protein 1, C46F11.1) C-terminal LIKE)|unc93 homolog A', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167269032, end_position_on_the_genomic_accession=167316014, orientation='plus', exon_count=13, OMIM=[607995], no_hdr0=''),
    54360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54360, CurrentID=0, Status='live', Symbol='CYTL1', Aliases=['C17', 'C4orf4'], description='cytokine like 1', other_designations='cytokine-like protein 1|cytokine-like protein C17', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5014586, end_position_on_the_genomic_accession=5019470, orientation='minus', exon_count=5, OMIM=[607930], no_hdr0=''),
    54361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54361, CurrentID=0, Status='live', Symbol='WNT4', Aliases=['SERKAL', 'WNT-4'], description='Wnt family member 4', other_designations='protein Wnt-4|wingless-type MMTV integration site family, member 4', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22117308, end_position_on_the_genomic_accession=22143981, orientation='minus', exon_count=8, OMIM=[603490], no_hdr0=''),
    54363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54363, CurrentID=0, Status='live', Symbol='HAO1', Aliases=['GOX', 'GOX1', 'HAOX1'], description='hydroxyacid oxidase 1', other_designations='hydroxyacid oxidase 1|(S)-2-hydroxy-acid oxidase|glycolate oxidase 1|hydroxyacid oxidase (glycolate oxidase) 1', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=7882985, end_position_on_the_genomic_accession=7940458, orientation='minus', exon_count=8, OMIM=[605023], no_hdr0=''),
    54386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54386, CurrentID=0, Status='live', Symbol='TERF2IP', Aliases=['DRIP5', 'RAP1'], description='TERF2 interacting protein', other_designations='telomeric repeat-binding factor 2-interacting protein 1|TERF2-interacting telomeric protein 1|TRF2-interacting telomeric RAP1 protein|dopamine receptor-interacting protein 5|repressor/activator protein 1 homolog', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75647773, end_position_on_the_genomic_accession=75657432, orientation='plus', exon_count=3, OMIM=[605061], no_hdr0=''),
    54407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54407, CurrentID=0, Status='live', Symbol='SLC38A2', Aliases=['ATA2', 'PRO1068', 'SAT2', 'SNAT2'], description='solute carrier family 38 member 2', other_designations='sodium-coupled neutral amino acid transporter 2|amino acid transporter 2|amino acid transporter A2|protein 40-9-1|system A amino acid transporter 2|system A transporter 1|system N amino acid transporter 2', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=46358188, end_position_on_the_genomic_accession=46372774, orientation='minus', exon_count=16, OMIM=[605180], no_hdr0=''),
    54413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54413, CurrentID=0, Status='live', Symbol='NLGN3', Aliases=['HNL3'], description='neuroligin 3', other_designations='neuroligin-3|gliotactin homolog', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71144389, end_position_on_the_genomic_accession=71175307, orientation='plus', exon_count=11, OMIM=[300336], no_hdr0=''),
    54414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54414, CurrentID=0, Status='live', Symbol='SIAE', Aliases=['AIS6', 'CSE-C', 'CSEC', 'LSE', 'YSG2'], description='sialic acid acetylesterase', other_designations='sialate O-acetylesterase|H-Lse|cytosolic sialic acid 9-O-acetylesterase homolog|sialic acid-specific acetylesterase II', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124633113, end_position_on_the_genomic_accession=124676303, orientation='minus', exon_count=14, OMIM=[610079], no_hdr0=''),
    54429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54429, CurrentID=0, Status='live', Symbol='TAS2R5', Aliases=['T2R5'], description='taste 2 receptor member 5', other_designations='taste receptor type 2 member 5|taste receptor, type 2, member 5', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141790217, end_position_on_the_genomic_accession=141791367, orientation='plus', exon_count=1, OMIM=[605062], no_hdr0=''),
    54431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54431, CurrentID=0, Status='live', Symbol='DNAJC10', Aliases=['ERdj5', 'JPDI', 'MTHr', 'PDIA19'], description='DnaJ heat shock protein family (Hsp40) member C10', other_designations='dnaJ homolog subfamily C member 10|DnaJ (Hsp40) homolog, subfamily C, member 10|ER-resident protein ERdj5|J-domain-containing protein disulfide isomerase-like protein|endoplasmic reticulum DNA J domain-containing protein 5|macrothioredoxin|protein disulfide isomerase family A, member 19', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=182716257, end_position_on_the_genomic_accession=182794464, orientation='plus', exon_count=26, OMIM=[607987], no_hdr0=''),
    54432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54432, CurrentID=0, Status='live', Symbol='YIPF1', Aliases=['DJ167A19.1', 'FinGER1'], description='Yip1 domain family member 1', other_designations='protein YIPF1|YIP1 family member 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53851733, end_position_on_the_genomic_accession=53889797, orientation='minus', exon_count=12, OMIM=[617521], no_hdr0=''),
    54433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54433, CurrentID=0, Status='live', Symbol='GAR1', Aliases=['NOLA1'], description='GAR1 ribonucleoprotein', other_designations='H/ACA ribonucleoprotein complex subunit 1|GAR1 homolog, ribonucleoprotein|GAR1 ribonucleoprotein homolog|nucleolar protein family A member 1|nucleolar protein family A, member 1 (H/ACA small nucleolar RNPs)|snoRNP protein GAR1', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109815510, end_position_on_the_genomic_accession=109824737, orientation='plus', exon_count=8, OMIM=[606468], no_hdr0=''),
    54434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54434, CurrentID=0, Status='live', Symbol='SSH1', Aliases=['SSH1L'], description='slingshot protein phosphatase 1', other_designations='protein phosphatase Slingshot homolog 1|SSH-like protein 1|hSSH-1L|slingshot homolog 1', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108778191, end_position_on_the_genomic_accession=108857606, orientation='minus', exon_count=20, OMIM=[606778], no_hdr0=''),
    54436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54436, CurrentID=0, Status='live', Symbol='SH3TC1', Aliases=[], description='SH3 domain and tetratricopeptide repeats 1', other_designations='SH3 domain and tetratricopeptide repeat-containing protein 1|SH3 domain and tetratricopeptide repeats-containing protein 1', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8182072, end_position_on_the_genomic_accession=8241103, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    54437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54437, CurrentID=0, Status='live', Symbol='SEMA5B', Aliases=['SEMAG', 'SemG'], description='semaphorin 5B', other_designations='semaphorin-5B|sema domain, seven thrombospondin repeats (type 1 and type 1-like), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 5B', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122909082, end_position_on_the_genomic_accession=123028605, orientation='minus', exon_count=26, OMIM=[609298], no_hdr0=''),
    54438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54438, CurrentID=0, Status='live', Symbol='GFOD1', Aliases=['ADG-90', 'C6orf114'], description='glucose-fructose oxidoreductase domain containing 1', other_designations='glucose-fructose oxidoreductase domain-containing protein 1', map_location='6p24.1-p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13357830, end_position_on_the_genomic_accession=13487600, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    54439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54439, CurrentID=0, Status='live', Symbol='RBM27', Aliases=['ARRS1', 'Psc1', 'ZC3H18', 'ZC3H20'], description='RNA binding motif protein 27', other_designations='RNA-binding protein 27|acidic rich RS domain containing 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146203550, end_position_on_the_genomic_accession=146289223, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    54440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54440, CurrentID=0, Status='live', Symbol='SASH3', Aliases=['753P9', 'CXorf9', 'HACS2', 'SH3D6C', 'SLY'], description='SAM and SH3 domain containing 3', other_designations='SAM and SH3 domain-containing protein 3|SH3 protein expressed in lymphocytes homolog', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129779949, end_position_on_the_genomic_accession=129795201, orientation='plus', exon_count=7, OMIM=[300441], no_hdr0=''),
    54442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54442, CurrentID=0, Status='live', Symbol='KCTD5', Aliases=[], description='potassium channel tetramerization domain containing 5', other_designations='BTB/POZ domain-containing protein KCTD5|potassium channel tetramerisation domain containing 5', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2682523, end_position_on_the_genomic_accession=2709030, orientation='plus', exon_count=6, OMIM=[611285], no_hdr0=''),
    54443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54443, CurrentID=0, Status='live', Symbol='ANLN', Aliases=['FSGS8', 'Scraps', 'scra'], description='anillin actin binding protein', other_designations='anillin', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=36389809, end_position_on_the_genomic_accession=36453791, orientation='plus', exon_count=25, OMIM=[616027], no_hdr0=''),
    54453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54453, CurrentID=0, Status='live', Symbol='RIN2', Aliases=['MACS', 'RASSF4'], description='Ras and Rab interactor 2', other_designations='ras and Rab interactor 2|RAB5 interacting protein 2|RAS association (RalGDS/AF-6) domain containing protein JC265|RAS association domain family 4|RAS inhibitor JC265|RAS interaction/interference protein 2', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=19757610, end_position_on_the_genomic_accession=20002456, orientation='plus', exon_count=25, OMIM=[610222], no_hdr0=''),
    54454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54454, CurrentID=0, Status='live', Symbol='ATAD2B', Aliases=[], description='ATPase family AAA domain containing 2B', other_designations='ATPase family AAA domain-containing protein 2B', map_location='2p24.1-p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=23687624, end_position_on_the_genomic_accession=23927123, orientation='minus', exon_count=40, OMIM=[615347], no_hdr0=''),
    54455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54455, CurrentID=0, Status='live', Symbol='FBXO42', Aliases=['Fbx42', 'JFK'], description='F-box protein 42', other_designations='F-box only protein 42|just one F-box and Kelch domain-containing protein', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16246840, end_position_on_the_genomic_accession=16352480, orientation='minus', exon_count=12, OMIM=[609109], no_hdr0=''),
    54456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54456, CurrentID=0, Status='live', Symbol='MOV10L1', Aliases=['CHAMP', 'DJ402G11.8'], description='Mov10 like RISC complex RNA helicase 1', other_designations='RNA helicase Mov10l1|MOV10-like protein 1|Mov10 RISC complex RNA helicase like 1|Mov10-like 1|Mov10l1, Moloney leukemia virus 10-like 1, homolog|cardiac helicase activated by MEF2C protein|moloney leukemia virus 10-like protein 1|putative helicase Mov10l1', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50090006, end_position_on_the_genomic_accession=50161705, orientation='plus', exon_count=33, OMIM=[605794], no_hdr0=''),
    54457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54457, CurrentID=0, Status='live', Symbol='TAF7L', Aliases=['CT40', 'TAF2Q'], description='TATA-box binding protein associated factor 7 like', other_designations='transcription initiation factor TFIID subunit 7-like|RNA polymerase II TBP-associated factor subunit Q|TAF7-like RNA polymerase II, TATA box binding protein (TBP)-associated factor, 50kDa|TATA box-binding protein-associated factor 50 kDa|TBP-associated factor, RNA polymerase II, Q|cancer/testis antigen 40|transcription initiation factor TFIID 50 kDa subunit', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101268257, end_position_on_the_genomic_accession=101293083, orientation='minus', exon_count=14, OMIM=[300314], no_hdr0=''),
    54458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54458, CurrentID=0, Status='live', Symbol='PRR13', Aliases=['TXR1'], description='proline rich 13', other_designations='proline-rich protein 13|taxane-resistance protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53441734, end_position_on_the_genomic_accession=53446638, orientation='plus', exon_count=4, OMIM=[610459], no_hdr0=''),
    54460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54460, CurrentID=0, Status='live', Symbol='MRPS21', Aliases=['MDS016', 'MRP-S21', 'RPMS21'], description='mitochondrial ribosomal protein S21', other_designations='28S ribosomal protein S21, mitochondrial|S21mt|mitochondrial 28S ribosomal protein S21|mitochondrial small ribosomal subunit protein bS21m', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150293842, end_position_on_the_genomic_accession=150308979, orientation='plus', exon_count=3, OMIM=[611984], no_hdr0=''),
    54461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54461, CurrentID=0, Status='live', Symbol='FBXW5', Aliases=['Fbw5'], description='F-box and WD repeat domain containing 5', other_designations='F-box/WD repeat-containing protein 5|F-box and WD-40 domain-containing protein 5|WD repeat-containing F-box protein FBW5', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136940435, end_position_on_the_genomic_accession=136944774, orientation='minus', exon_count=9, OMIM=[609072], no_hdr0=''),
    54462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54462, CurrentID=0, Status='live', Symbol='CCSER2', Aliases=['FAM190B', 'Gcap14', 'KIAA1128', 'bA486O22.1'], description='coiled-coil serine rich protein 2', other_designations='serine-rich coiled-coil domain-containing protein 2|family with sequence similarity 190, member B|protein FAM190B|protein GCAP14 homolog', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84328552, end_position_on_the_genomic_accession=84518517, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    54463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54463, CurrentID=0, Status='live', Symbol='RETREG1', Aliases=['FAM134B', 'JK-1', 'JK1'], description='reticulophagy regulator 1', other_designations='reticulophagy regulator 1|family with sequence similarity 134 member B|protein FAM134B|reticulophagy receptor 1|reticulophagy receptor FAM134B', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=16473038, end_position_on_the_genomic_accession=16617096, orientation='minus', exon_count=13, OMIM=[613114], no_hdr0=''),
    54464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54464, CurrentID=0, Status='live', Symbol='XRN1', Aliases=['SEP1'], description="5'-3' exoribonuclease 1", other_designations="5'-3' exoribonuclease 1|strand-exchange protein 1 homolog", map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142306610, end_position_on_the_genomic_accession=142448062, orientation='minus', exon_count=43, OMIM=[607994], no_hdr0=''),
    54465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54465, CurrentID=0, Status='live', Symbol='ETAA1', Aliases=['ETAA16'], description='ETAA1 activator of ATR kinase', other_designations="ewing's tumor-associated antigen 1|ETAA1, ATR kinase activator|Ewing tumor associated antigen 1|ewing's tumor-associated antigen 16", map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=67397317, end_position_on_the_genomic_accession=67412089, orientation='plus', exon_count=7, OMIM=[613196], no_hdr0=''),
    54466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54466, CurrentID=0, Status='live', Symbol='SPIN2A', Aliases=['DXF34', 'SPIN2', 'TDRD25', 'dJ323P24.1'], description='spindlin family member 2A', other_designations='spindlin-2A|centromeric spin2 copy|spindlin homolog 2|spindlin-like protein 2|spindlin-like protein 2A', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57133043, end_position_on_the_genomic_accession=57138688, orientation='minus', exon_count=6, OMIM=[300621], no_hdr0=''),
    54467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54467, CurrentID=0, Status='live', Symbol='ANKIB1', Aliases=[], description='ankyrin repeat and IBR domain containing 1', other_designations='ankyrin repeat and IBR domain-containing protein 1', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92245974, end_position_on_the_genomic_accession=92401383, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    54468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54468, CurrentID=0, Status='live', Symbol='MIOS', Aliases=['MIO', 'Sea4', 'Yulink'], description='meiosis regulator for oocyte development', other_designations='GATOR complex protein MIOS|H_DJ1159O04.1|WD repeat-containing protein mio|WUGSC:H_DJ1159O04.1|missing oocyte, meiosis regulator, homolog', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7566875, end_position_on_the_genomic_accession=7609144, orientation='plus', exon_count=14, OMIM=[615359], no_hdr0=''),
    54469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54469, CurrentID=0, Status='live', Symbol='ZFAND6', Aliases=['AWP1', 'ZA20D3', 'ZFAND5B'], description='zinc finger AN1-type containing 6', other_designations='AN1-type zinc finger protein 6|protein associated with PRK1|zinc finger, A20 domain containing 3|zinc finger, AN1-type domain 6', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80059676, end_position_on_the_genomic_accession=80138393, orientation='plus', exon_count=13, OMIM=[610183], no_hdr0=''),
    54470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54470, CurrentID=0, Status='live', Symbol='ARMCX6', Aliases=['GASP10'], description='armadillo repeat containing X-linked 6', other_designations='protein ARMCX6', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101615120, end_position_on_the_genomic_accession=101618000, orientation='minus', exon_count=5, OMIM=[301048], no_hdr0=''),
    54471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54471, CurrentID=0, Status='live', Symbol='MIEF1', Aliases=['AltMIEF1', 'HSU79252', 'MID51-MP', 'SMCR7L', 'dJ1104E15.3', 'MIEF1'], description='mitochondrial elongation factor 1', other_designations='mitochondrial dynamics protein MID51|MIEF1 microprotein|SMCR7-like protein|Smith-Magenis syndrome chromosome region, candidate 7-like|alternative MIEF1 protein|mitochondrial dynamic protein MID51|mitochondrial dynamic protein of 51 kDa|mitochondrial dynamics protein of 51 kDa|smith-Magenis syndrome chromosomal region candidate gene 7 protein-like', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39500100, end_position_on_the_genomic_accession=39518133, orientation='plus', exon_count=10, OMIM=[615497], no_hdr0=''),
    54472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54472, CurrentID=0, Status='live', Symbol='TOLLIP', Aliases=['IL-1RAcPIP'], description='toll interacting protein', other_designations='toll-interacting protein|adapter protein', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1274371, end_position_on_the_genomic_accession=1309632, orientation='minus', exon_count=8, OMIM=[606277], no_hdr0=''),
    54474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54474, CurrentID=0, Status='live', Symbol='KRT20', Aliases=['CD20', 'CK-20', 'CK20', 'K20', 'KRT21'], description='keratin 20', other_designations='keratin, type I cytoskeletal 20|cytokeratin 20|keratin 20, type I|protein IT', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40875889, end_position_on_the_genomic_accession=40885242, orientation='minus', exon_count=8, OMIM=[608218], no_hdr0=''),
    54475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54475, CurrentID=0, Status='live', Symbol='NLE1', Aliases=['NLE'], description='notchless homolog 1', other_designations='notchless protein homolog 1|Notchless gene homolog', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35128730, end_position_on_the_genomic_accession=35142304, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    54476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54476, CurrentID=0, Status='live', Symbol='RNF216', Aliases=['CAHH', 'TRIAD3', 'U7I1', 'UBCE7IP1', 'ZIN'], description='ring finger protein 216', other_designations='E3 ubiquitin-protein ligase RNF216|RING-type E3 ubiquitin transferase RNF216|triad domain-containing protein 3|ubiquitin-conjugating enzyme 7-interacting protein 1|zinc finger protein inhibiting NF-kappa-B', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5620047, end_position_on_the_genomic_accession=5781721, orientation='minus', exon_count=20, OMIM=[609948], no_hdr0=''),
    54477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54477, CurrentID=0, Status='live', Symbol='PLEKHA5', Aliases=['PEPP-2', 'PEPP2'], description='pleckstrin homology domain containing A5', other_designations='pleckstrin homology domain-containing family A member 5|PH domain-containing family A member 5|phosphoinositol 3-phosphate-binding protein-2|pleckstrin homology domain containing, family A member 5', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=19129680, end_position_on_the_genomic_accession=19376400, orientation='plus', exon_count=44, OMIM=[607770], no_hdr0=''),
    54478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54478, CurrentID=0, Status='live', Symbol='PIMREG', Aliases=['CATS', 'FAM64A', 'RCS1'], description='PICALM interacting mitotic regulator', other_designations='protein PIMREG|CALM interacting protein expressed in thymus and spleen|CALM-interactor expressed in thymus and spleen|family with sequence similarity 64 member A|protein FAM64A|regulator of chromosome segregation 1|regulator of chromosome segregation protein 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6444455, end_position_on_the_genomic_accession=6451469, orientation='plus', exon_count=7, OMIM=[617611], no_hdr0=''),
    54480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54480, CurrentID=0, Status='live', Symbol='CHPF2', Aliases=['CSGLCA-T', 'CSGlcAT', 'ChSy-3', 'chPF-2'], description='chondroitin polymerizing factor 2', other_designations='chondroitin sulfate glucuronyltransferase|N-acetylgalactosaminyl-proteoglycan 3-beta-glucuronosyltransferase|chondroitin synthase-3', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151232483, end_position_on_the_genomic_accession=151238822, orientation='plus', exon_count=5, OMIM=[608037], no_hdr0=''),
    54482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54482, CurrentID=0, Status='live', Symbol='TRMT13', Aliases=['CCDC76'], description='tRNA methyltransferase 13 homolog', other_designations="tRNA:m(4)X modification enzyme TRM13 homolog|coiled-coil domain containing 76|coiled-coil domain-containing protein 76|tRNA [Gm4] methyltransferase|tRNA guanosine-2'-O-methyltransferase TRM13 homolog", map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100133132, end_position_on_the_genomic_accession=100150496, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    54487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54487, CurrentID=0, Status='live', Symbol='DGCR8', Aliases=['C22orf12', 'DGCRK6', 'Gy1', 'pasha'], description='DGCR8 microprocessor complex subunit', other_designations='microprocessor complex subunit DGCR8|DiGeorge syndrome critical region 8|DiGeorge syndrome critical region gene 8', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20080241, end_position_on_the_genomic_accession=20111872, orientation='plus', exon_count=14, OMIM=[609030], no_hdr0=''),
    54490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54490, CurrentID=0, Status='live', Symbol='UGT2B28', Aliases=[], description='UDP glucuronosyltransferase family 2 member B28', other_designations='UDP-glucuronosyltransferase 2B28|UDP glucuronosyltransferase 2 family, polypeptide B28|UDP glycosyltransferase 2 family, polypeptide B28|UDPGT 2B28', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69280429, end_position_on_the_genomic_accession=69295050, orientation='plus', exon_count=6, OMIM=[606497], no_hdr0=''),
    54491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54491, CurrentID=0, Status='live', Symbol='OTULINL', Aliases=['FAM105A', 'NET20'], description='OTU deubiquitinase with linear linkage specificity like', other_designations='inactive ubiquitin thioesterase OTULINL|family with sequence similarity 105 member A|inactive ubiquitin thioesterase FAM105A|protein FAM105A', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=14581792, end_position_on_the_genomic_accession=14616180, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    54492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54492, CurrentID=0, Status='live', Symbol='NEURL1B', Aliases=['NEURL3', 'RNF67B', 'hNeur2', 'neur2'], description='neuralized E3 ubiquitin protein ligase 1B', other_designations='E3 ubiquitin-protein ligase NEURL1B|E3 ubiquitin-protein ligase NEURL3|RING-type E3 ubiquitin transferase NEURL1B|neuralized 2 alternative protein|neuralized homolog 1B|neuralized-2|neuralized-like protein 1B|neuralized-like protein 3', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172641263, end_position_on_the_genomic_accession=172691540, orientation='plus', exon_count=5, OMIM=[615893], no_hdr0=''),
    54494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54494, CurrentID=0, Status='live', Symbol='C11orf71', Aliases=['URLC7'], description='chromosome 11 open reading frame 71', other_designations='uncharacterized protein C11orf71|up-regulated in lung cancer 7', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114391443, end_position_on_the_genomic_accession=114400511, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    54495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54495, CurrentID=0, Status='live', Symbol='TMX3', Aliases=['PDIA13', 'TXNDC10'], description='thioredoxin related transmembrane protein 3', other_designations='protein disulfide-isomerase TMX3|protein disulfide isomerase family A, member 13|thioredoxin domain containing 10|thioredoxin domain-containing protein 10', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=68673688, end_position_on_the_genomic_accession=68715112, orientation='minus', exon_count=19, OMIM=[616102], no_hdr0=''),
    54496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54496, CurrentID=0, Status='live', Symbol='PRMT7', Aliases=['SBIDDS'], description='protein arginine methyltransferase 7', other_designations='protein arginine N-methyltransferase 7|[Myelin basic protein]-arginine N-methyltransferase PRMT7|histone-arginine N-methyltransferase PRMT7', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68310982, end_position_on_the_genomic_accession=68360876, orientation='plus', exon_count=22, OMIM=[610087], no_hdr0=''),
    54497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54497, CurrentID=0, Status='live', Symbol='HEATR5B', Aliases=['p200', 'p200a'], description='HEAT repeat containing 5B', other_designations='HEAT repeat-containing protein 5B', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=36980895, end_position_on_the_genomic_accession=37084384, orientation='minus', exon_count=38, OMIM=[], no_hdr0=''),
    54498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54498, CurrentID=0, Status='live', Symbol='SMOX', Aliases=['C20orf16', 'PAO', 'PAO-1', 'PAO1', 'PAOH', 'PAOH1', 'SMO'], description='spermine oxidase', other_designations='spermine oxidase|flavin containing amine oxidase|flavin-containing spermine oxidase|polyamine oxidase 1|putative cyclin G1 interacting protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=4148828, end_position_on_the_genomic_accession=4187732, orientation='plus', exon_count=9, OMIM=[615854], no_hdr0=''),
    54499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54499, CurrentID=0, Status='live', Symbol='TMCO1', Aliases=['HP10122', 'PCIA3', 'PNAS-136', 'TMCC4'], description='transmembrane and coiled-coil domains 1', other_designations='calcium load-activated calcium channel|CLAC channel|Ca(2+) load-activated Ca(2+) channel|putative membrane protein|transmembrane and coiled-coil domain-containing protein 1|transmembrane and coiled-coil domains 4|xenogeneic cross-immune protein PCIA3', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165724291, end_position_on_the_genomic_accession=165768922, orientation='minus', exon_count=7, OMIM=[614123], no_hdr0=''),
    54502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54502, CurrentID=0, Status='live', Symbol='RBM47', Aliases=['NET18'], description='RNA binding motif protein 47', other_designations='RNA-binding protein 47', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40423270, end_position_on_the_genomic_accession=40630911, orientation='minus', exon_count=16, OMIM=[619104], no_hdr0=''),
    54503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54503, CurrentID=0, Status='live', Symbol='ZDHHC13', Aliases=['HIP14L', 'HIP3RP'], description='zinc finger DHHC-type palmitoyltransferase 13', other_designations='palmitoyltransferase ZDHHC13|DHHC-13|HIP14-related protein|huntingtin interacting protein HIP3RP|huntingtin-interacting protein 14-related protein|probable palmitoyltransferase ZDHHC13|putative MAPK-activating protein PM03|putative NF-kappa-B-activating protein 209|zinc finger DHHC domain-containing protein 13|zinc finger DHHC-type containing 13|zinc finger, DHHC domain containing 13', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=19117099, end_position_on_the_genomic_accession=19176420, orientation='plus', exon_count=20, OMIM=[612815], no_hdr0=''),
    54504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54504, CurrentID=0, Status='live', Symbol='CPVL', Aliases=['HVLP'], description='carboxypeptidase vitellogenic like', other_designations='probable serine carboxypeptidase CPVL|CP-Mac carboxypeptidase|VCP-like protein|carboxypeptidase WUG|vitellogenic carboxypeptidase-like protein', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=28994636, end_position_on_the_genomic_accession=29195451, orientation='minus', exon_count=25, OMIM=[609780], no_hdr0=''),
    54505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54505, CurrentID=0, Status='live', Symbol='DHX29', Aliases=['DDX29'], description='DExH-box helicase 29', other_designations='ATP-dependent RNA helicase DHX29|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 29|DEAH (Asp-Glu-Ala-His) box polypeptide 29|DEAH box protein 29|DEAH-box helicase 29|nucleic acid helicase DDXx', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55256055, end_position_on_the_genomic_accession=55307694, orientation='minus', exon_count=27, OMIM=[612720], no_hdr0=''),
    54507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54507, CurrentID=0, Status='live', Symbol='ADAMTSL4', Aliases=['ADAMTSL-4', 'ECTOL2', 'TSRC1'], description='ADAMTS like 4', other_designations='ADAMTS-like protein 4|thrombospondin repeat-containing protein 1', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150549378, end_position_on_the_genomic_accession=150560937, orientation='plus', exon_count=21, OMIM=[610113], no_hdr0=''),
    54509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54509, CurrentID=0, Status='live', Symbol='RHOF', Aliases=['ARHF', 'RIF'], description='ras homolog family member F, filopodia associated', other_designations='rho-related GTP-binding protein RhoF|ras homolog family member F (in filopodia)|ras homolog gene family, member F (in filopodia)|rho family GTPase Rif|rho in filopodia', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121777754, end_position_on_the_genomic_accession=121793688, orientation='minus', exon_count=5, OMIM=[618867], no_hdr0=''),
    54510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54510, CurrentID=0, Status='live', Symbol='PCDH18', Aliases=['PCDH68L'], description='protocadherin 18', other_designations='protocadherin-18|protocadherin 68-like protein', map_location='4q28.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=137518918, end_position_on_the_genomic_accession=137532530, orientation='minus', exon_count=4, OMIM=[608287], no_hdr0=''),
    54511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54511, CurrentID=0, Status='live', Symbol='HMGCLL1', Aliases=['ERCHL', 'bA418P12.1', 'er-cHL'], description='3-hydroxymethyl-3-methylglutaryl-CoA lyase like 1', other_designations='3-hydroxymethyl-3-methylglutaryl-CoA lyase, cytoplasmic|3-hydroxy-3-methylglutaryl-CoA lyase-like protein 1|3-hydroxymethyl-3-methylglutaryl-CoA lyase-like protein 1|3-hydroxymethyl-3-methylglutaryl-Coenzyme A lyase-like 1|HMGCL-like 1|endoplasmic reticulum 3-hydroxy-3-methylglutaryl-CoA lyase|endoplasmic reticulum 3-hydroxymethyl-3-methylglutaryl-CoA lyase|probable 3-hydroxymethyl-3-methylglutaryl-CoA lyase 2', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=55434373, end_position_on_the_genomic_accession=55607573, orientation='minus', exon_count=14, OMIM=[619050], no_hdr0=''),
    54512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54512, CurrentID=0, Status='live', Symbol='EXOSC4', Aliases=['RRP41', 'RRP41A', 'Rrp41p', 'SKI6', 'Ski6p', 'hRrp41p', 'p12A'], description='exosome component 4', other_designations='exosome complex component RRP41|exosome complex exonuclease RRP41|exosome component Rrp41|ribosomal RNA-processing protein 41', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144064061, end_position_on_the_genomic_accession=144080648, orientation='plus', exon_count=4, OMIM=[606491], no_hdr0=''),
    54514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54514, CurrentID=0, Status='live', Symbol='DDX4', Aliases=['VASA'], description='DEAD-box helicase 4', other_designations='probable ATP-dependent RNA helicase DDX4|DEAD (Asp-Glu-Ala-Asp) box polypeptide 4|DEAD box protein 4|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 4|vasa homolog', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55737994, end_position_on_the_genomic_accession=55817157, orientation='plus', exon_count=24, OMIM=[605281], no_hdr0=''),
    54516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54516, CurrentID=0, Status='live', Symbol='MTRF1L', Aliases=['HMRF1L', 'MRF1L', 'mtRF1a'], description='mitochondrial translation release factor 1 like', other_designations='peptide chain release factor 1-like, mitochondrial|mitochondrial release factor 1 like|mitochondrial translational release factor 1 like', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=152987362, end_position_on_the_genomic_accession=153003439, orientation='minus', exon_count=7, OMIM=[613542], no_hdr0=''),
    54517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54517, CurrentID=0, Status='live', Symbol='PUS7', Aliases=['IDDABS'], description='pseudouridine synthase 7', other_designations='pseudouridylate synthase 7 homolog|pseudouridylate synthase 7 (putative)', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105456501, end_position_on_the_genomic_accession=105522271, orientation='minus', exon_count=17, OMIM=[616261], no_hdr0=''),
    54518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54518, CurrentID=0, Status='live', Symbol='APBB1IP', Aliases=['INAG1', 'PREL1', 'RARP1', 'RIAM'], description='amyloid beta precursor protein binding family B member 1 interacting protein', other_designations='amyloid beta A4 precursor protein-binding family B member 1-interacting protein|APBB1-interacting protein 1|PREL-1|RARP-1|Rap1-GTP-interacting adaptor molecule|Rap1-interacting adaptor molecule|proline rich EVH1 ligand 1|proline-rich protein 73|rap1-GTP-interacting adapter molecule|retinoic acid-responsive proline-rich protein 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=26438324, end_position_on_the_genomic_accession=26567879, orientation='plus', exon_count=16, OMIM=[609036], no_hdr0=''),
    54520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54520, CurrentID=0, Status='live', Symbol='CCDC93', Aliases=[], description='coiled-coil domain containing 93', other_designations='coiled-coil domain-containing protein 93', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=117915481, end_position_on_the_genomic_accession=118014163, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    54521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54521, CurrentID=0, Status='live', Symbol='WDR44', Aliases=['RAB11BP', 'RPH11', 'SYM-4'], description='WD repeat domain 44', other_designations='WD repeat-containing protein 44|rabphilin-11', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=118346073, end_position_on_the_genomic_accession=118449966, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    54522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54522, CurrentID=0, Status='live', Symbol='ANKRD16', Aliases=[], description='ankyrin repeat domain 16', other_designations='ankyrin repeat domain-containing protein 16', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5861616, end_position_on_the_genomic_accession=5889893, orientation='minus', exon_count=8, OMIM=[618017], no_hdr0=''),
    54529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54529, CurrentID=0, Status='live', Symbol='ASNSD1', Aliases=['NBLA00058', 'NS3TP1'], description='asparagine synthetase domain containing 1', other_designations='asparagine synthetase domain-containing protein 1|HCV NS3-transactivated protein 1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189661459, end_position_on_the_genomic_accession=189670831, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    54531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54531, CurrentID=0, Status='live', Symbol='MIER2', Aliases=['KIAA1193', 'Mi-er2'], description='MIER family member 2', other_designations='mesoderm induction early response protein 2|mesoderm induction early response 1, family member 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=305573, end_position_on_the_genomic_accession=344796, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    54532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54532, CurrentID=0, Status='live', Symbol='USP53', Aliases=[], description='ubiquitin specific peptidase 53', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 53|inactive ubiquitin-specific peptidase 53|ubiquitin specific protease 53|ubiquitin specific proteinase 53', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=119212623, end_position_on_the_genomic_accession=119295518, orientation='plus', exon_count=21, OMIM=[617431], no_hdr0=''),
    54534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54534, CurrentID=0, Status='live', Symbol='MRPL50', Aliases=['MRP-L50'], description='mitochondrial ribosomal protein L50', other_designations='39S ribosomal protein L50, mitochondrial|L50mt|mitochondrial 39S ribosomal protein L50|mitochondrial large ribosomal subunit protein mL50', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101387633, end_position_on_the_genomic_accession=101398618, orientation='minus', exon_count=2, OMIM=[611854], no_hdr0=''),
    54535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54535, CurrentID=0, Status='live', Symbol='CCHCR1', Aliases=['C6orf18', 'HCR', 'SBP', 'pg8'], description='coiled-coil alpha-helical rod protein 1', other_designations='coiled-coil alpha-helical rod protein 1|HCR (a-helix coiled-coil rod homologue)|StAR-binding protein|alpha-helical coiled-coil rod protein|putative gene 8 protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31142439, end_position_on_the_genomic_accession=31158209, orientation='minus', exon_count=20, OMIM=[605310], no_hdr0=''),
    54536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54536, CurrentID=0, Status='live', Symbol='EXOC6', Aliases=['EXOC6A', 'SEC15', 'SEC15L', 'SEC15L1', 'SEC15L3', 'Sec15p'], description='exocyst complex component 6', other_designations='exocyst complex component 6|SEC15-like 1|SEC15-like protein 3|exocyst complex component Sec15A|rsec15-like protein', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92826831, end_position_on_the_genomic_accession=93059490, orientation='plus', exon_count=27, OMIM=[609672], no_hdr0=''),
    54537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54537, CurrentID=0, Status='live', Symbol='SHLD2', Aliases=['FAM35A', 'FAM35A1', 'RINN2', 'bA163M19.1'], description='shieldin complex subunit 2', other_designations='shieldin complex subunit 2|RINN1-REV7-interacting novel NHEJ regulator 2|family with sequence similarity 35 member A|protein FAM35A|shield complex subunit 2', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87094478, end_position_on_the_genomic_accession=87191468, orientation='plus', exon_count=22, OMIM=[618029], no_hdr0=''),
    54538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54538, CurrentID=0, Status='live', Symbol='ROBO4', Aliases=['AOVD3', 'ECSM4', 'MRB'], description='roundabout guidance receptor 4', other_designations='roundabout homolog 4|roundabout homolog 4, magic roundabout|roundabout, axon guidance receptor, homolog 4', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124883691, end_position_on_the_genomic_accession=124897865, orientation='minus', exon_count=18, OMIM=[607528], no_hdr0=''),
    54539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54539, CurrentID=0, Status='live', Symbol='NDUFB11', Aliases=['CI-ESSS', 'ESSS', 'MC1DN30', 'NP17.3', 'Np15', 'P17.3'], description='NADH:ubiquinone oxidoreductase subunit B11', other_designations='NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 11, mitochondrial|NADH dehydrogenase (ubiquinone) 1 beta subcomplex, 11, 17.3kDa|NADH-ubiquinone oxidoreductase ESSS subunit|complex I NP17.3 subunit|complex I-ESSS|neuronal protein 17.3', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47142216, end_position_on_the_genomic_accession=47145491, orientation='minus', exon_count=3, OMIM=[300403], no_hdr0=''),
    54540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54540, CurrentID=0, Status='live', Symbol='FAM193B', Aliases=['IRIZIO'], description='family with sequence similarity 193 member B', other_designations='protein FAM193B', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177519788, end_position_on_the_genomic_accession=177554563, orientation='minus', exon_count=16, OMIM=[615813], no_hdr0=''),
    54541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54541, CurrentID=0, Status='live', Symbol='DDIT4', Aliases=['Dig2', 'REDD-1', 'REDD1'], description='DNA damage inducible transcript 4', other_designations='DNA damage-inducible transcript 4 protein|HIF-1 responsive protein RTP801|protein regulated in development and DNA damage response 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72273924, end_position_on_the_genomic_accession=72276036, orientation='plus', exon_count=3, OMIM=[607729], no_hdr0=''),
    54542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54542, CurrentID=0, Status='live', Symbol='RC3H2', Aliases=['MNAB', 'RNF164'], description='ring finger and CCCH-type domains 2', other_designations='roquin-2|RING finger protein 164|RING-type E3 ubiquitin transferase Roquin-2|membrane associated DNA binding protein|membrane-associated nucleic acid-binding protein|ring finger and CCCH-type zinc finger domain-containing protein 2|ring finger and CCCH-type zinc finger domains 2', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122844556, end_position_on_the_genomic_accession=122905359, orientation='minus', exon_count=22, OMIM=[615231], no_hdr0=''),
    54543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54543, CurrentID=0, Status='live', Symbol='TOMM7', Aliases=['TOM7'], description='translocase of outer mitochondrial membrane 7', other_designations='mitochondrial import receptor subunit TOM7 homolog|translocase of outer membrane 7 kDa subunit homolog|translocase of outer mitochondrial membrane 7 homolog', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=22812974, end_position_on_the_genomic_accession=22822849, orientation='minus', exon_count=3, OMIM=[607980], no_hdr0=''),
    54544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54544, CurrentID=0, Status='live', Symbol='CRCT1', Aliases=['C1orf42', 'NICE-1', 'NICE1'], description='cysteine rich C-terminal 1', other_designations='cysteine-rich C-terminal protein 1|protein NICE-1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152514482, end_position_on_the_genomic_accession=152516010, orientation='plus', exon_count=2, OMIM=[617426], no_hdr0=''),
    54545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54545, CurrentID=0, Status='live', Symbol='MTMR12', Aliases=['3-PAP', 'PIP3AP'], description='myotubularin related protein 12', other_designations='myotubularin-related protein 12|3-phosphatase adapter protein|3-phosphatase adapter subunit|inactive phosphatidylinositol 3-phosphatase 12|phosphatidylinositol 3 phosphate 3-phosphatase adapter subunit|phosphatidylinositol-3 phosphate 3-phosphatase adaptor subunit|phosphatidylinositol-3-phosphate associated protein', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=32227007, end_position_on_the_genomic_accession=32312939, orientation='minus', exon_count=16, OMIM=[606501], no_hdr0=''),
    54546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54546, CurrentID=0, Status='live', Symbol='RNF186', Aliases=[], description='ring finger protein 186', other_designations='E3 ubiquitin-protein ligase RNF186', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19814029, end_position_on_the_genomic_accession=19815283, orientation='minus', exon_count=1, OMIM=[617163], no_hdr0=''),
    54549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54549, CurrentID=0, Status='live', Symbol='SDK2', Aliases=[], description='sidekick cell adhesion molecule 2', other_designations='protein sidekick-2|sidekick homolog 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73334384, end_position_on_the_genomic_accession=73644481, orientation='minus', exon_count=47, OMIM=[607217], no_hdr0=''),
    54550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54550, CurrentID=0, Status='live', Symbol='NECAB2', Aliases=['EFCBP2', 'stip-2'], description='N-terminal EF-hand calcium binding protein 2', other_designations='N-terminal EF-hand calcium-binding protein 2|EF-hand calcium-binding protein 2|neuronal calcium binding 2|neuronal calcium-binding protein 2|synaptotagmin-interacting protein 2', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=83968244, end_position_on_the_genomic_accession=84002776, orientation='plus', exon_count=13, OMIM=[618130], no_hdr0=''),
    54551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54551, CurrentID=0, Status='live', Symbol='MAGEL2', Aliases=['NDNL1', 'PWLS', 'SHFYNG', 'nM15'], description='MAGE family member L2', other_designations='MAGE-like protein 2|melanoma antigen family L2|necdin-like protein 1|protein nM15', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23643549, end_position_on_the_genomic_accession=23647867, orientation='minus', exon_count=1, OMIM=[605283], no_hdr0=''),
    54552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54552, CurrentID=0, Status='live', Symbol='GNL3L', Aliases=['GNL3B'], description='G protein nucleolar 3 like', other_designations='guanine nucleotide-binding protein-like 3-like protein|G protein nucleolar 3B|guanine nucleotide binding protein-like 3 (nucleolar)-like|novel GTPase', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54530219, end_position_on_the_genomic_accession=54567289, orientation='plus', exon_count=16, OMIM=[300873], no_hdr0=''),
    54554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54554, CurrentID=0, Status='live', Symbol='WDR5B', Aliases=[], description='WD repeat domain 5B', other_designations='WD repeat-containing protein 5B', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122411846, end_position_on_the_genomic_accession=122416062, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    54555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54555, CurrentID=0, Status='live', Symbol='DDX49', Aliases=['Dbp8', 'R27090_2'], description='DEAD-box helicase 49', other_designations='probable ATP-dependent RNA helicase DDX49|DEAD (Asp-Glu-Ala-Asp) box polypeptide 49|DEAD box protein 49', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18919703, end_position_on_the_genomic_accession=18928630, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    54556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54556, CurrentID=0, Status='live', Symbol='ING3', Aliases=['Eaf4', 'ING2', 'MEAF4', 'p47ING3'], description='inhibitor of growth family member 3', other_designations='inhibitor of growth protein 3', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=120950749, end_position_on_the_genomic_accession=120977216, orientation='plus', exon_count=13, OMIM=[607493], no_hdr0=''),
    54557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54557, CurrentID=0, Status='live', Symbol='SGTB', Aliases=['SGT2'], description='small glutamine rich tetratricopeptide repeat co-chaperone beta', other_designations='small glutamine-rich tetratricopeptide repeat-containing protein beta|beta-SGT|small glutamine rich protein with tetratricopeptide repeats 2|small glutamine rich tetratricopeptide repeat containing beta|small glutamine-rich tetratricopeptide repeat (TPR)-containing, beta', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65665928, end_position_on_the_genomic_accession=65722821, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    54558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54558, CurrentID=0, Status='live', Symbol='SPATA6', Aliases=['HASH', 'SRF-1', 'SRF1'], description='spermatogenesis associated 6', other_designations='spermatogenesis-associated protein 6|spermatogenesis-related factor-1|testicular tissue protein Li 178', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=48258643, end_position_on_the_genomic_accession=48472204, orientation='minus', exon_count=21, OMIM=[613947], no_hdr0=''),
    54566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54566, CurrentID=0, Status='live', Symbol='EPB41L4B', Aliases=['CG1', 'EHM2', 'LULU2'], description='erythrocyte membrane protein band 4.1 like 4B', other_designations='band 4.1-like protein 4B|FERM-containing protein CG1', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=109171974, end_position_on_the_genomic_accession=109321059, orientation='minus', exon_count=28, OMIM=[610340], no_hdr0=''),
    54567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54567, CurrentID=0, Status='live', Symbol='DLL4', Aliases=['AOS6', 'delta4', 'hdelta2'], description='delta like canonical Notch ligand 4', other_designations='delta-like protein 4|delta 4|delta ligand 4|delta-like 4 homolog|delta-like 4 protein|drosophila Delta homolog 4|notch ligand DLL4|notch ligand delta-2', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40929340, end_position_on_the_genomic_accession=40939073, orientation='plus', exon_count=11, OMIM=[605185], no_hdr0=''),
    54575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54575, CurrentID=0, Status='live', Symbol='UGT1A10', Aliases=['GNT1', 'UDPGT', 'UGT-1A', 'UGT-1J', 'UGT1', 'UGT1-01', 'UGT1-10', 'UGT1.1', 'UGT1.10', 'UGT1A', 'UGT1A1', 'UGT1J', 'hUG-BR1'], description='UDP glucuronosyltransferase family 1 member A10', other_designations='UDP-glucuronosyltransferase 1A10|Bilirubin-specific UDPGT isozyme 1|UDP glucuronosyltransferase 1 family, polypeptide A10|UDP glycosyltransferase 1 family, polypeptide A10|UDP-glucuronosyltransferase 1-1|UDP-glucuronosyltransferase 1-10|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1-J|UDP-glucuronosyltransferase 1A1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233636448, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606435], no_hdr0=''),
    54576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54576, CurrentID=0, Status='live', Symbol='UGT1A8', Aliases=['GNT1', 'UDPGT', 'UDPGT 1-1', 'UDPGT 1-8', 'UGT-1A', 'UGT-1H', 'UGT1', 'UGT1-01', 'UGT1-08', 'UGT1.1', 'UGT1.8', 'UGT1A', 'UGT1A1S', 'UGT1H', 'hUG-BR1', 'UGT1A8'], description='UDP glucuronosyltransferase family 1 member A8', other_designations='UDP-glucuronosyltransferase 1A8|Bilirubin-specific UDPGT isozyme 1|UDP glucuronosyltransferase 1 family, polypeptide A8|UDP glycosyltransferase 1 family, polypeptide A8|UDP-glucuronosyltransferase 1 family polypeptide A8s|UDP-glucuronosyltransferase 1-1|UDP-glucuronosyltransferase 1-8|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1-H|UDP-glucuronosyltransferase 1A1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233617633, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606433], no_hdr0=''),
    54577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54577, CurrentID=0, Status='live', Symbol='UGT1A7', Aliases=['GNT1', 'UDPGT', 'UDPGT 1-7', 'UGT-1A', 'UGT-1G', 'UGT1', 'UGT1-01', 'UGT1-07', 'UGT1.1', 'UGT1.7', 'UGT1A', 'UGT1A1', 'UGT1G', 'hUG-BR1'], description='UDP glucuronosyltransferase family 1 member A7', other_designations='UDP-glucuronosyltransferase 1A7|Bilirubin-specific UDPGT isozyme 1|UDP glucuronosyltransferase 1 family, polypeptide A7|UDP glycosyltransferase 1 family, polypeptide A7|UDP-glucuronosyltransferase 1 family polypeptide A7s|UDP-glucuronosyltransferase 1-1|UDP-glucuronosyltransferase 1-7|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1-G|UDP-glucuronosyltransferase 1A1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233681901, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606432], no_hdr0=''),
    54578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54578, CurrentID=0, Status='live', Symbol='UGT1A6', Aliases=['GNT1', 'HLUGP', 'HLUGP1', 'UDPGT', 'UDPGT 1-6', 'UGT-1A', 'UGT-1C', 'UGT-1E', 'UGT-1F', 'UGT1', 'UGT1-01', 'UGT1-03', 'UGT1-05', 'UGT1-06', 'UGT1.1', 'UGT1.3', 'UGT1.5', 'UGT1.6', 'UGT1A', 'UGT1A1', 'UGT1A3', 'UGT1A5S', 'UGT1C', 'UGT1E', 'UGT1F', 'hUG-BR1', 'UGT1A6'], description='UDP glucuronosyltransferase family 1 member A6', other_designations='UDP-glucuronosyltransferase 1-6|Bilirubin-specific UDPGT isozyme 1|UDP glucuronosyltransferase 1 family, polypeptide A6|UDP glycosyltransferase 1 family, polypeptide A6|UDP-glucuronosyltransferase 1 family polypeptide A6s|UDP-glucuronosyltransferase 1-1|UDP-glucuronosyltransferase 1-3|UDP-glucuronosyltransferase 1-5|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1-C|UDP-glucuronosyltransferase 1-E|UDP-glucuronosyltransferase 1-F|UDP-glucuronosyltransferase 1A1|UDP-glucuronosyltransferase 1A3|UDP-glucuronosyltransferase 1A5|UDP-glucuronosyltransferase 1A6|phenol-metabolizing UDP-glucuronosyltransferase', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233691702, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=6, OMIM=[606431], no_hdr0=''),
    54579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54579, CurrentID=0, Status='live', Symbol='UGT1A5', Aliases=['UDPGT', 'UDPGT 1-5', 'UGT1E'], description='UDP glucuronosyltransferase family 1 member A5', other_designations='UDP-glucuronosyltransferase 1A5|UDP glucuronosyltransferase 1 family, polypeptide A5|UDP glycosyltransferase 1 family, polypeptide A5|UDP-glucuronosyltransferase 1 family polypeptide A5s|UDP-glucuronosyltransferase 1-5|UDP-glucuronosyltransferase 1-E|UGT-1E|UGT1*5', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233712907, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606430], no_hdr0=''),
    54583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54583, CurrentID=0, Status='live', Symbol='EGLN1', Aliases=['C1orf12', 'ECYT3', 'HALAH', 'HIF-PH2', 'HIFPH2', 'HPH-2', 'HPH2', 'PHD2', 'SM20', 'ZMYND6'], description='egl-9 family hypoxia inducible factor 1', other_designations='egl nine homolog 1|HIF-prolyl hydroxylase 2|egl nine-like protein 1|hypoxia-inducible factor prolyl hydroxylase 2|prolyl hydroxylase domain-containing protein 2|zinc finger MYND domain-containing protein 6', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231363756, end_position_on_the_genomic_accession=231422332, orientation='minus', exon_count=5, OMIM=[606425], no_hdr0=''),
    54584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54584, CurrentID=0, Status='live', Symbol='GNB1L', Aliases=['DGCRK3', 'FKSG1', 'GY2', 'WDR14', 'WDVCF'], description='G protein subunit beta 1 like', other_designations='guanine nucleotide-binding protein subunit beta-like protein 1|G-protein beta subunit-like protein|WD repeat-containing protein 14|WD40 repeat-containing protein deleted in VCFS|g protein subunit beta-like protein 1|guanine nucleotide binding protein (G protein), beta polypeptide 1-like|guanine nucleotide binding protein beta-subunit-like polypeptide', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19783223, end_position_on_the_genomic_accession=19854874, orientation='minus', exon_count=8, OMIM=[610778], no_hdr0=''),
    54585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54585, CurrentID=0, Status='live', Symbol='LZTFL1', Aliases=['BBS17'], description='leucine zipper transcription factor like 1', other_designations='leucine zipper transcription factor-like protein 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45823316, end_position_on_the_genomic_accession=45916037, orientation='minus', exon_count=16, OMIM=[606568], no_hdr0=''),
    54586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54586, CurrentID=0, Status='live', Symbol='EQTN', Aliases=['AFAF', 'C9orf11', 'SPACA8'], description='equatorin', other_designations='equatorin|Acrosome formation associated factor|acrosome formation-associated factor|equatorin, sperm acrosome associated|sperm acrosome associated 8', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27284654, end_position_on_the_genomic_accession=27297150, orientation='minus', exon_count=9, OMIM=[617653], no_hdr0=''),
    54587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54587, CurrentID=0, Status='live', Symbol='MXRA8', Aliases=['ASP3'], description='matrix remodeling associated 8', other_designations='matrix remodeling-associated protein 8|limitrin|matrix-remodeling-associated protein 8|matrix-remodelling associated 8', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1352689, end_position_on_the_genomic_accession=1363541, orientation='minus', exon_count=12, OMIM=[617293], no_hdr0=''),
    54596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54596, CurrentID=0, Status='live', Symbol='L1TD1', Aliases=['ECAT11'], description='LINE1 type transposase domain containing 1', other_designations='LINE-1 type transposase domain-containing protein 1|ES cell-associated protein 11|LINE-1 type transposase domain containing 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62194849, end_position_on_the_genomic_accession=62212328, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    54600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54600, CurrentID=0, Status='live', Symbol='UGT1A9', Aliases=['HLUGP4', 'LUGP4', 'UDPGT', 'UDPGT 1-9', 'UGT-1I', 'UGT1-09', 'UGT1-9', 'UGT1.9S', 'UGT1AI', 'UGT1I', 'UGT1A9'], description='UDP glucuronosyltransferase family 1 member A9', other_designations='UDP-glucuronosyltransferase 1A9|UDP glucuronosyltransferase 1 family, polypeptide A9|UDP glycosyltransferase 1 family, polypeptide A9|UDP-glucuronosyltransferase 1 family polypeptide A9s|UDP-glucuronosyltransferase 1-9|UDP-glucuronosyltransferase 1-I', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233671898, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606434], no_hdr0=''),
    54602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54602, CurrentID=0, Status='live', Symbol='NDFIP2', Aliases=['N4WBP5A'], description='Nedd4 family interacting protein 2', other_designations='NEDD4 family-interacting protein 2|MAPK-activating protein PM04 PM05 PM06 PM07|NEDD4 WW domain-binding protein 5A|NF-kappa-B-activating protein 413|putative MAPK-activating protein PM04/PM05/PM06/PM07|putative NF-kappa-B-activating protein 413', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=79481155, end_position_on_the_genomic_accession=79556077, orientation='plus', exon_count=8, OMIM=[610041], no_hdr0=''),
    54606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54606, CurrentID=0, Status='live', Symbol='DDX56', Aliases=['DDX21', 'DDX26', 'NOH61'], description='DEAD-box helicase 56', other_designations='probable ATP-dependent RNA helicase DDX56|61-kd nucleolar helicase|ATP-dependent 61 kDa nucleolar RNA helicase|DEAD (Asp-Glu-Ala-Asp) box helicase 56|DEAD (Asp-Glu-Ala-Asp) box polypeptide 56|DEAD box protein 21|DEAD box protein 56|DEAD-box RNA helicase|nucleolar helicase of 61 kDa|putative nucleolar RNA helicase', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44565804, end_position_on_the_genomic_accession=44573908, orientation='minus', exon_count=14, OMIM=[608023], no_hdr0=''),
    54617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54617, CurrentID=0, Status='live', Symbol='INO80', Aliases=['INO80A', 'INOC1'], description='INO80 complex ATPase subunit', other_designations='chromatin-remodeling ATPase INO80|DNA helicase INO80|DNA helicase-related INO80 complex homolog 1|DNA helicase-related protein INO80|INO80 complex subunit A|homolog of yeast INO80|putative DNA helicase INO80 complex homolog 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40978880, end_position_on_the_genomic_accession=41117778, orientation='minus', exon_count=37, OMIM=[610169], no_hdr0=''),
    54619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54619, CurrentID=0, Status='live', Symbol='CCNJ', Aliases=['bA690P14.1'], description='cyclin J', other_designations='cyclin-J', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96042848, end_position_on_the_genomic_accession=96060870, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    54620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54620, CurrentID=0, Status='live', Symbol='FBXL19', Aliases=['CXXC11', 'Fbl19', 'JHDM1C'], description='F-box and leucine rich repeat protein 19', other_designations='F-box/LRR-repeat protein 19|jumonji C domain-containing histone demethylase 1C', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30922851, end_position_on_the_genomic_accession=30948783, orientation='plus', exon_count=13, OMIM=[609085], no_hdr0=''),
    54621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54621, CurrentID=0, Status='live', Symbol='VSIG10', Aliases=[], description='V-set and immunoglobulin domain containing 10', other_designations='V-set and immunoglobulin domain-containing protein 10', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118063593, end_position_on_the_genomic_accession=118104402, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    54622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54622, CurrentID=0, Status='live', Symbol='ARL15', Aliases=['ARFRP2'], description='ADP ribosylation factor like GTPase 15', other_designations='ADP-ribosylation factor-like protein 15|ADP-ribosylation factor-like 15|ADP-ribosylation factor-related protein 2|ARF-related protein 2', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=53883942, end_position_on_the_genomic_accession=54310590, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    54623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54623, CurrentID=0, Status='live', Symbol='PAF1', Aliases=['F23149_1', 'PD2'], description='PAF1 homolog, Paf1/RNA polymerase II complex component', other_designations='RNA polymerase II-associated factor 1 homolog|Paf1, RNA polymerase II associated factor, homolog|pancreatic differentiation protein 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39385629, end_position_on_the_genomic_accession=39391106, orientation='minus', exon_count=15, OMIM=[610506], no_hdr0=''),
    54625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54625, CurrentID=0, Status='live', Symbol='PARP14', Aliases=['ARTD8', 'BAL2', 'PARP-14', 'pART8'], description='poly(ADP-ribose) polymerase family member 14', other_designations='protein mono-ADP-ribosyltransferase PARP14|ADP-ribosyltransferase diphtheria toxin-like 8|B-aggressive lymphoma 2|b aggressive lymphoma protein 2|collaborator of STAT6|poly [ADP-ribose] polymerase 14', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122680726, end_position_on_the_genomic_accession=122730840, orientation='plus', exon_count=17, OMIM=[610028], no_hdr0=''),
    54626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54626, CurrentID=0, Status='live', Symbol='HES2', Aliases=['bHLHb40'], description='hes family bHLH transcription factor 2', other_designations='transcription factor HES-2|class B basic helix-loop-helix protein 40|hairy and enhancer of split 2', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6415232, end_position_on_the_genomic_accession=6419919, orientation='minus', exon_count=4, OMIM=[609970], no_hdr0=''),
    54627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54627, CurrentID=0, Status='live', Symbol='MAP10', Aliases=['KIAA1383', 'MTR120'], description='microtubule associated protein 10', other_designations='microtubule-associated protein 10|microtubule regulator 120 KDa|microtubule regulator of 120 KDa', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=232805416, end_position_on_the_genomic_accession=232809929, orientation='plus', exon_count=1, OMIM=[618551], no_hdr0=''),
    54629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54629, CurrentID=0, Status='live', Symbol='MINDY2', Aliases=['FAM63B'], description='MINDY lysine 48 deubiquitinase 2', other_designations='ubiquitin carboxyl-terminal hydrolase MINDY-2|MINDY deubiquitinase 2|deubiquitinating enzyme MINDY-2|family with sequence similarity 63 member B|protein FAM63B', map_location='15q21.3-q22.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58771258, end_position_on_the_genomic_accession=58861900, orientation='plus', exon_count=10, OMIM=[618408], no_hdr0=''),
    54657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54657, CurrentID=0, Status='live', Symbol='UGT1A4', Aliases=['GNT1', 'HUG-BR2', 'UDPGT', 'UDPGT 1-4', 'UGT-1A', 'UGT-1D', 'UGT1', 'UGT1-01', 'UGT1-04', 'UGT1.1', 'UGT1.4', 'UGT1A', 'UGT1A1S', 'UGT1D', 'hUG-BR1', 'UGT1A4'], description='UDP glucuronosyltransferase family 1 member A4', other_designations='UDP-glucuronosyltransferase 1A4|Bilirubin-specific UDPGT isozyme 1|UDP glucuronosyltransferase 1 family, polypeptide A4|UDP glycosyltransferase 1 family, polypeptide A4|UDP-glucuronosyltransferase 1 family polypeptide A4s|UDP-glucuronosyltransferase 1-1|UDP-glucuronosyltransferase 1-4|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1-D|UDP-glucuronosyltransferase 1A1|UDPGT 1-1|bilirubin UDP-glucuronosyltransferase isozyme 2|bilirubin-specific UDPGT isozyme 2', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233718736, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606429], no_hdr0=''),
    54658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54658, CurrentID=0, Status='live', Symbol='UGT1A1', Aliases=['BILIQTL1', 'GNT1', 'HUG-BR1', 'UDPGT', 'UDPGT 1-1', 'UGT1', 'UGT1A'], description='UDP glucuronosyltransferase family 1 member A1', other_designations='UDP-glucuronosyltransferase 1A1|UDP glucuronosyltransferase 1 family, polypeptide A1|UDP glycosyltransferase 1 family, polypeptide A1|UDP-glucuronosyltransferase 1-A|UDP-glucuronosyltransferase 1A|UGT-1A|UGT1*1|UGT1-01|UGT1.1|bilirubin UDP-glucuronosyltranserase|bilirubin UDP-glucuronosyltransferase 1-1|bilirubin UDP-glucuronosyltransferase isozyme 1|bilirubin-specific UDPGT isozyme 1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233760270, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[191740], no_hdr0=''),
    54659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54659, CurrentID=0, Status='live', Symbol='UGT1A3', Aliases=['UDPGT', 'UDPGT 1-3', 'UGT-1C', 'UGT1-03', 'UGT1.3S', 'UGT1C', 'UGT1A3'], description='UDP glucuronosyltransferase family 1 member A3', other_designations='UDP-glucuronosyltransferase 1A3|UDP glucuronosyltransferase 1 family, polypeptide A3|UDP glycosyltransferase 1 family, polypeptide A3|UDP-glucuronosyltransferase 1 family polypeptide A3s|UDP-glucuronosyltransferase 1-3|UDP-glucuronosyltransferase 1-C|UDP-glucuronosyltransferase 1A|UGT1*3', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233729042, end_position_on_the_genomic_accession=233773300, orientation='plus', exon_count=5, OMIM=[606428], no_hdr0=''),
    54662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54662, CurrentID=0, Status='live', Symbol='TBC1D13', Aliases=[], description='TBC1 domain family member 13', other_designations='TBC1 domain family member 13|epididymis secretory sperm binding protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128787253, end_position_on_the_genomic_accession=128810432, orientation='plus', exon_count=12, OMIM=[616218], no_hdr0=''),
    54663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54663, CurrentID=0, Status='live', Symbol='WDR74', Aliases=['Nsa1'], description='WD repeat domain 74', other_designations='WD repeat-containing protein 74|NOP seven-associated protein 1', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62832905, end_position_on_the_genomic_accession=62841809, orientation='minus', exon_count=15, OMIM=[617947], no_hdr0=''),
    54664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54664, CurrentID=0, Status='live', Symbol='TMEM106B', Aliases=['HLD16'], description='transmembrane protein 106B', other_designations='transmembrane protein 106B', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=12211294, end_position_on_the_genomic_accession=12243367, orientation='plus', exon_count=9, OMIM=[613413], no_hdr0=''),
    54665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54665, CurrentID=0, Status='live', Symbol='RSBN1', Aliases=['KDM9', 'ROSBIN'], description='round spermatid basic protein 1', other_designations='lysine-specific demethylase 9', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113761832, end_position_on_the_genomic_accession=113812537, orientation='minus', exon_count=8, OMIM=[615858], no_hdr0=''),
    54674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54674, CurrentID=0, Status='live', Symbol='LRRN3', Aliases=['FIGLER5', 'NLRR-3', 'NLRR3'], description='leucine rich repeat neuronal 3', other_designations='leucine-rich repeat neuronal protein 3|fibronectin type III, immunoglobulin and leucine rich repeat domains 5|leucine-rich repeat protein, neuronal 3|neuronal leucine-rich repeat protein 3', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=111091127, end_position_on_the_genomic_accession=111125454, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54675, CurrentID=0, Status='live', Symbol='CRLS1', Aliases=['C20orf155', 'CLS', 'CLS1', 'GCD10', 'dJ967N21.6'], description='cardiolipin synthase 1', other_designations='cardiolipin synthase (CMP-forming)', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=6005938, end_position_on_the_genomic_accession=6040053, orientation='plus', exon_count=11, OMIM=[608188], no_hdr0=''),
    54676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54676, CurrentID=0, Status='live', Symbol='GTPBP2', Aliases=['JABELS'], description='GTP binding protein 2', other_designations='GTP-binding protein 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43620492, end_position_on_the_genomic_accession=43631309, orientation='minus', exon_count=16, OMIM=[607434], no_hdr0=''),
    54677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54677, CurrentID=0, Status='live', Symbol='CROT', Aliases=['COT'], description='carnitine O-octanoyltransferase', other_designations='peroxisomal carnitine O-octanoyltransferase|peroxisomal carnitine acyltransferase', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87345646, end_position_on_the_genomic_accession=87399794, orientation='plus', exon_count=21, OMIM=[606090], no_hdr0=''),
    54680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54680, CurrentID=0, Status='live', Symbol='ZNHIT6', Aliases=['BCD1', 'C1orf181', 'NY-BR-75'], description='zinc finger HIT-type containing 6', other_designations='box C/D snoRNA protein 1|box C/D snoRNA essential 1 homolog|serologically defined breast cancer antigen NY-BR-75|zinc finger HIT domain-containing protein 6|zinc finger, HIT type 6', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85649417, end_position_on_the_genomic_accession=85708458, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    54681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54681, CurrentID=0, Status='live', Symbol='P4HTM', Aliases=['EGLN4', 'HIDEA', 'HIFPH4', 'P4H-TM', 'PH-4', 'PH4', 'PHD4'], description='prolyl 4-hydroxylase, transmembrane', other_designations='transmembrane prolyl 4-hydroxylase|HIF-PH4|HIF-prolyl hydroxylase 4|HPH-4|P4H with transmembrane domain|Prolyl hydroxlase domain-containing 4|hypoxia-inducible factor prolyl 4-hydroxylase|hypoxia-inducible factor prolyl hydroxylase 4|proline 4-hydroxylase|prolyl 4-hydroxylase, transmembrane (endoplasmic reticulum)', map_location='3p21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48989908, end_position_on_the_genomic_accession=49007153, orientation='plus', exon_count=9, OMIM=[614584], no_hdr0=''),
    54682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54682, CurrentID=0, Status='live', Symbol='MANSC1', Aliases=['9130403P13Rik', 'LOH12CR3'], description='MANSC domain containing 1', other_designations='MANSC domain-containing protein 1|loss of heterozygosity 12 chromosomal region 3 protein', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12326056, end_position_on_the_genomic_accession=12350242, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    54700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54700, CurrentID=0, Status='live', Symbol='RRN3', Aliases=['A-270G1.2', 'TIFIA'], description='RRN3 homolog, RNA polymerase I transcription factor', other_designations='RNA polymerase I-specific transcription initiation factor RRN3|RRN3 RNA polymerase I transcription factor homolog|TIF-IA|transcription initiation factor IA|transcription initiation factor TIF-IA', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15060022, end_position_on_the_genomic_accession=15094335, orientation='minus', exon_count=18, OMIM=[605121], no_hdr0=''),
    54704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54704, CurrentID=0, Status='live', Symbol='PDP1', Aliases=['PDH', 'PDP', 'PDPC', 'PPM2A', 'PPM2C'], description='pyruvate dehydrogenase phosphatase catalytic subunit 1', other_designations='pyruvate dehyrogenase phosphatase catalytic subunit 1|PDP 1|PDPC 1|[Pyruvate dehydrogenase [acetyl-transferring]]-phosphatase 1, mitochondrial|protein phosphatase 2C, magnesium-dependent, catalytic subunit|protein phosphatase, Mg2+/Mn2+ dependent 2A|pyruvate dehydrogenase (Lipoamide) phosphatase-phosphatase', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=93916923, end_position_on_the_genomic_accession=93926068, orientation='plus', exon_count=6, OMIM=[605993], no_hdr0=''),
    54707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54707, CurrentID=0, Status='live', Symbol='GPN2', Aliases=['ATPBD1B'], description='GPN-loop GTPase 2', other_designations='GPN-loop GTPase 2|ATP-binding domain 1 family member B', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26876132, end_position_on_the_genomic_accession=26890283, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    54708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54708, CurrentID=0, Status='live', Symbol='MARCHF5', Aliases=['MARCH-V', 'MARCH5', 'MITOL', 'RNF153'], description='membrane associated ring-CH-type finger 5', other_designations='E3 ubiquitin-protein ligase MARCHF5|E3 ubiquitin-protein ligase MARCH5|RING-type E3 ubiquitin transferase MARCH5|RING-type E3 ubiquitin transferase MARCHF5|membrane associated ring finger 5|membrane-associated RING finger protein 5|membrane-associated RING-CH protein V|membrane-associated ring finger (C3HC4) 5|mitochondrial ubiquitin ligase|ring finger protein 153', map_location='10q23.32-q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=92291164, end_position_on_the_genomic_accession=92353964, orientation='plus', exon_count=7, OMIM=[610637], no_hdr0=''),
    54714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54714, CurrentID=0, Status='live', Symbol='CNGB3', Aliases=['ACHM1'], description='cyclic nucleotide gated channel subunit beta 3', other_designations='cyclic nucleotide-gated cation channel beta-3|CNG channel beta-3|cone photoreceptor cGMP-gated cation channel beta-subunit|cyclic nucleotide gated channel beta 3|cyclic nucleotide-gated cation channel modulatory subunit', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86573608, end_position_on_the_genomic_accession=86743634, orientation='minus', exon_count=19, OMIM=[605080], no_hdr0=''),
    54715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54715, CurrentID=0, Status='live', Symbol='RBFOX1', Aliases=['2BP1', 'A2BP1', 'FOX-1', 'FOX1', 'HRNBP1'], description='RNA binding fox-1 homolog 1', other_designations='RNA binding protein fox-1 homolog 1|RNA binding protein, fox-1 homolog 1|ataxin 2-binding protein 1|fox-1 homolog A|fox-1-like RNA-binding protein 1|hexaribonucleotide-binding protein 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=5239752, end_position_on_the_genomic_accession=7713343, orientation='plus', exon_count=29, OMIM=[605104], no_hdr0=''),
    54716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54716, CurrentID=0, Status='live', Symbol='SLC6A20', Aliases=['IMINO', 'SIT1', 'XT3', 'Xtrp3'], description='solute carrier family 6 member 20', other_designations='sodium- and chloride-dependent transporter XTRP3|X transporter protein 3|neurotransmitter transporter RB21A|orphan transporter XT3|sodium-dependent imino acid transporter 1|sodium/imino-acid transporter 1|solute carrier family 6 (neurotransmitter transporter), member 20|solute carrier family 6 (proline IMINO transporter), member 20|transporter rB21A homolog', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45755449, end_position_on_the_genomic_accession=45796553, orientation='minus', exon_count=12, OMIM=[605616], no_hdr0=''),
    54726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54726, CurrentID=0, Status='live', Symbol='OTUD4', Aliases=['DUBA6', 'HIN1', 'HSHIN1'], description='OTU deubiquitinase 4', other_designations='OTU domain-containing protein 4|HIV-1 induced protein HIN-1', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145133650, end_position_on_the_genomic_accession=145180589, orientation='minus', exon_count=23, OMIM=[611744], no_hdr0=''),
    54729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54729, CurrentID=0, Status='live', Symbol='NKX1-1', Aliases=['HSPX153', 'NKX-1.1', 'SAX2'], description='NK1 homeobox 1', other_designations='NK1 transcription factor-related protein 1|HPX-153 homeobox|NK1 transcription factor related, locus 1|homeobox protein 153|homeobox protein SAX-2', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1402932, end_position_on_the_genomic_accession=1406442, orientation='minus', exon_count=2, OMIM=[617869], no_hdr0=''),
    54732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54732, CurrentID=0, Status='live', Symbol='TMED9', Aliases=['GMP25', 'HSGP25L2G', 'p24a2', 'p24alpha2', 'p25'], description='transmembrane p24 trafficking protein 9', other_designations='transmembrane emp24 domain-containing protein 9|glycoprotein 25L2|p24 family protein alpha-2|transmembrane emp24 protein transport domain containing 9', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177592203, end_position_on_the_genomic_accession=177597242, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    54733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54733, CurrentID=0, Status='live', Symbol='SLC35F2', Aliases=['HSNOV1'], description='solute carrier family 35 member F2', other_designations='solute carrier family 35 member F2|lung squamous cell cancer related protein LSCC-3', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107790991, end_position_on_the_genomic_accession=107858787, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    54734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54734, CurrentID=0, Status='live', Symbol='RAB39A', Aliases=['RAB39'], description='RAB39A, member RAS oncogene family', other_designations='ras-related protein Rab-39A|RAB39, member RAS oncogene family|rab-39|rab-related GTP-binding protein', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107928448, end_position_on_the_genomic_accession=107963482, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    54737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54737, CurrentID=0, Status='live', Symbol='MPHOSPH8', Aliases=['HSMPP8', 'TWA3', 'mpp8'], description='M-phase phosphoprotein 8', other_designations='M-phase phosphoprotein 8|M-phase phosphoprotein, mpp|M-phase phosphoprotein, mpp8|two hybrid-associated protein 3 with RanBPM', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19633648, end_position_on_the_genomic_accession=19673441, orientation='plus', exon_count=16, OMIM=[611626], no_hdr0=''),
    54738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54738, CurrentID=0, Status='live', Symbol='FEV', Aliases=['HSRNAFEV', 'PET-1'], description='FEV transcription factor, ETS family member', other_designations='protein FEV|FEV (ETS oncogene family)|FEV, ETS transcription factor|PC12 ETS domain-containing transcription factor 1|fifth Ewing variant protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218981087, end_position_on_the_genomic_accession=218985184, orientation='minus', exon_count=3, OMIM=[607150], no_hdr0=''),
    54739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54739, CurrentID=0, Status='live', Symbol='XAF1', Aliases=['BIRC4BP', 'HSXIAPAF1', 'XIAPAF1'], description='XIAP associated factor 1', other_designations='XIAP-associated factor 1|BIRC4-binding protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6755408, end_position_on_the_genomic_accession=6775647, orientation='plus', exon_count=11, OMIM=[606717], no_hdr0=''),
    54741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54741, CurrentID=0, Status='live', Symbol='LEPROT', Aliases=['LEPR', 'OB-RGRP', 'OBRGRP', 'VPS55'], description='leptin receptor overlapping transcript', other_designations='leptin receptor gene-related protein|DnaJ (Hsp40) homolog, subfamily C, member 6|OB-R gene-related protein|endospanin|endospanin-1|leptin receptor overlapping transcript protein', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65420668, end_position_on_the_genomic_accession=65436007, orientation='plus', exon_count=6, OMIM=[613461], no_hdr0=''),
    54742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54742, CurrentID=0, Status='live', Symbol='LY6K', Aliases=['CT97', 'HSJ001348', 'URLC10', 'ly-6K'], description='lymphocyte antigen 6 family member K', other_designations='lymphocyte antigen 6K|cancer/testis antigen 97|lymphocyte antigen 6 complex, locus K|up-regulated in lung cancer 10', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142700081, end_position_on_the_genomic_accession=142705127, orientation='plus', exon_count=3, OMIM=[615093], no_hdr0=''),
    54749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54749, CurrentID=0, Status='live', Symbol='EPDR1', Aliases=['EPDR', 'MERP-1', 'MERP1', 'UCC1'], description='ependymin related 1', other_designations='mammalian ependymin-related protein 1|ependymin related protein 1|mammalian ependymin related protein 1|upregulated in colorectal cancer gene 1 protein', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=37920640, end_position_on_the_genomic_accession=37951936, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54751, CurrentID=0, Status='live', Symbol='FBLIM1', Aliases=['CAL', 'FBLP-1', 'FBLP1'], description='filamin binding LIM protein 1', other_designations='filamin-binding LIM protein 1|CSX-associated LIM|MIG2-interacting protein|migfilin|mitogen-inducible 2 interacting protein', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15756170, end_position_on_the_genomic_accession=15786590, orientation='plus', exon_count=13, OMIM=[607747], no_hdr0=''),
    54752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54752, CurrentID=0, Status='live', Symbol='FNDC8', Aliases=[], description='fibronectin type III domain containing 8', other_designations='fibronectin type III domain-containing protein 8', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35121615, end_position_on_the_genomic_accession=35130732, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54753, CurrentID=0, Status='live', Symbol='ZNF853', Aliases=[], description='zinc finger protein 853', other_designations='zinc finger protein 853', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6615610, end_position_on_the_genomic_accession=6624290, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54754, CurrentID=0, Status='live', Symbol='NUTM2F', Aliases=['FAM22F', 'NUTMF'], description='NUT family member 2F', other_designations='NUT family member 2F|family with sequence similarity 22, member F|protein FAM22F', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94318198, end_position_on_the_genomic_accession=94328644, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    54756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54756, CurrentID=0, Status='live', Symbol='IL17RD', Aliases=['HH18', 'IL-17RD', 'IL17RLM', 'SEF'], description='interleukin 17 receptor D', other_designations='interleukin-17 receptor D|IL-17 receptor D|IL17Rhom|interleukin-17 receptor-like protein|sef homolog', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57089982, end_position_on_the_genomic_accession=57170317, orientation='minus', exon_count=16, OMIM=[606807], no_hdr0=''),
    54757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54757, CurrentID=0, Status='live', Symbol='FAM20A', Aliases=['AI1G', 'AIGFS', 'FP2747'], description='FAM20A golgi associated secretory pathway pseudokinase', other_designations='pseudokinase FAM20A|family with sequence similarity 20, member A|protein FAM20A', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68530276, end_position_on_the_genomic_accession=68601367, orientation='minus', exon_count=16, OMIM=[611062], no_hdr0=''),
    54758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54758, CurrentID=0, Status='live', Symbol='KLHDC4', Aliases=[], description='kelch domain containing 4', other_designations='kelch domain-containing protein 4', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87693537, end_position_on_the_genomic_accession=87765991, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    54760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54760, CurrentID=0, Status='live', Symbol='PCSK4', Aliases=['PC4', 'SPC5'], description='proprotein convertase subtilisin/kexin type 4', other_designations='proprotein convertase subtilisin/kexin type 4|testicular tissue protein Li 135', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1481428, end_position_on_the_genomic_accession=1490874, orientation='minus', exon_count=18, OMIM=[600487], no_hdr0=''),
    54762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54762, CurrentID=0, Status='live', Symbol='GRAMD1C', Aliases=[], description='GRAM domain containing 1C', other_designations='protein Aster-C|GRAM domain-containing protein 1C', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113828182, end_position_on_the_genomic_accession=113947174, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    54763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54763, CurrentID=0, Status='live', Symbol='ROPN1', Aliases=['CT91', 'ODF6', 'RHPNAP1A', 'ropporin', 'ROPN1'], description='rhophilin associated tail protein 1', other_designations='ropporin-1A|cancer/testis antigen 91|outer dense fiber of sperm tails 6|rhophilin-associated protein 1A|ropporin, rhophilin associated protein 1|testis secretory sperm-binding protein Li 239w', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123969015, end_position_on_the_genomic_accession=123992124, orientation='minus', exon_count=8, OMIM=[611757], no_hdr0=''),
    54764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54764, CurrentID=0, Status='live', Symbol='ZRANB1', Aliases=['TRABID'], description='zinc finger RANBP2-type containing 1', other_designations='ubiquitin thioesterase ZRANB1|TRAF-binding domain-containing protein|TRAF-binding protein domain|hTrabid|zinc finger Ran-binding domain-containing protein 1|zinc finger, RAN-binding domain containing 1', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124939489, end_position_on_the_genomic_accession=124988189, orientation='plus', exon_count=10, OMIM=[611749], no_hdr0=''),
    54765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54765, CurrentID=0, Status='live', Symbol='TRIM44', Aliases=['AN3', 'DIPB', 'HSA249128', 'MC7'], description='tripartite motif containing 44', other_designations='tripartite motif-containing protein 44', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35662692, end_position_on_the_genomic_accession=35818007, orientation='plus', exon_count=5, OMIM=[612298], no_hdr0=''),
    54766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54766, CurrentID=0, Status='live', Symbol='BTG4', Aliases=['APRO3', 'OOMD8', 'PC3B'], description='BTG anti-proliferation factor 4', other_designations='protein BTG4|B-cell translocation gene 4|BTG family member 4|protein PC3b', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111383828, end_position_on_the_genomic_accession=111514734, orientation='minus', exon_count=20, OMIM=[605673], no_hdr0=''),
    54768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54768, CurrentID=0, Status='live', Symbol='HYDIN', Aliases=['CILD51', 'HYDIN2', 'PPP1R31', 'HYDIN'], description='HYDIN axonemal central pair apparatus protein', other_designations='hydrocephalus-inducing protein homolog|protein phosphatase 1, regulatory subunit 31', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70802084, end_position_on_the_genomic_accession=71230722, orientation='minus', exon_count=92, OMIM=[610812], no_hdr0=''),
    54769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54769, CurrentID=0, Status='live', Symbol='DIRAS2', Aliases=['Di-Ras2'], description='DIRAS family GTPase 2', other_designations='GTP-binding protein Di-Ras2|DIRAS family, GTP-binding RAS-like 2|distinct subgroup of the Ras family member 2', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=90609832, end_position_on_the_genomic_accession=90642824, orientation='minus', exon_count=2, OMIM=[607863], no_hdr0=''),
    54776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54776, CurrentID=0, Status='live', Symbol='PPP1R12C', Aliases=['AAVS1', 'LENG3', 'MBS85', 'p84', 'p85'], description='protein phosphatase 1 regulatory subunit 12C', other_designations='protein phosphatase 1 regulatory subunit 12C|leukocyte receptor cluster (LRC) encoded novel gene 3|leukocyte receptor cluster (LRC) member 3|myosin-binding subunit 85|protein phosphatase 1 myosin-binding subunit of 85 kDa|protein phosphatase 1 myosin-binding subunit p85|protein phosphatase 1, regulatory (inhibitor) subunit 12C', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55090913, end_position_on_the_genomic_accession=55117637, orientation='minus', exon_count=22, OMIM=[613245], no_hdr0=''),
    54777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54777, CurrentID=0, Status='live', Symbol='CFAP46', Aliases=['C10orf123', 'C10orf124', 'C10orf92', 'C10orf93', 'TTC40', 'bA288G11.4', 'bA288G11.5', 'bB137A17.2', 'bB137A17.3'], description='cilia and flagella associated protein 46', other_designations='cilia- and flagella-associated protein 46|TPR repeat-containing protein C10orf93|tetratricopeptide repeat domain 40|tetratricopeptide repeat protein 40', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132808392, end_position_on_the_genomic_accession=132942570, orientation='minus', exon_count=58, OMIM=[618543], no_hdr0=''),
    54778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54778, CurrentID=0, Status='live', Symbol='RNF111', Aliases=['ARK', 'hRNF111'], description='ring finger protein 111', other_designations='E3 ubiquitin-protein ligase Arkadia|Arkadia|RING-type E3 ubiquitin transferase Arkadia', map_location='15q22.1-q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58987588, end_position_on_the_genomic_accession=59097419, orientation='plus', exon_count=17, OMIM=[605840], no_hdr0=''),
    54780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54780, CurrentID=0, Status='live', Symbol='NSMCE4A', Aliases=['C10orf86', 'NS4EA', 'NSE4A'], description='NSE4 homolog A, SMC5-SMC6 complex component', other_designations='non-structural maintenance of chromosomes element 4 homolog A|NSE4 homolog, SMC5-SMC6 complex component A|non-SMC element 4 homolog A', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=121957088, end_position_on_the_genomic_accession=121975228, orientation='minus', exon_count=13, OMIM=[612987], no_hdr0=''),
    54784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54784, CurrentID=0, Status='live', Symbol='ALKBH4', Aliases=['ABH4'], description='alkB homolog 4, lysine demethylase', other_designations='alpha-ketoglutarate-dependent dioxygenase alkB homolog 4|DNA N6-methyl adenine demethylase ALKBH4|alkB homolog 4, lysine demthylase|alkB, alkylation repair homolog 4|alkylated DNA repair protein alkB homolog 4|lysine-specific demethylase ALKBH4|probable alpha-ketoglutarate-dependent dioxygenase ABH4', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102456220, end_position_on_the_genomic_accession=102464863, orientation='minus', exon_count=3, OMIM=[613302], no_hdr0=''),
    54785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54785, CurrentID=0, Status='live', Symbol='BORCS6', Aliases=['C17orf59', 'PRO2472'], description='BLOC-1 related complex subunit 6', other_designations='BLOC-1-related complex subunit 6|lysosome-dispersing protein|lyspersin', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8188345, end_position_on_the_genomic_accession=8190180, orientation='minus', exon_count=1, OMIM=[616599], no_hdr0=''),
    54788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54788, CurrentID=0, Status='live', Symbol='DNAJB12', Aliases=['DJ10'], description='DnaJ heat shock protein family (Hsp40) member B12', other_designations='dnaJ homolog subfamily B member 12|DnaJ (Hsp40) homolog, subfamily B, member 12', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72332863, end_position_on_the_genomic_accession=72354919, orientation='minus', exon_count=9, OMIM=[608376], no_hdr0=''),
    54790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54790, CurrentID=0, Status='live', Symbol='TET2', Aliases=['IMD75', 'KIAA1546', 'MDS'], description='tet methylcytosine dioxygenase 2', other_designations='methylcytosine dioxygenase TET2|probable methylcytosine dioxygenase TET2|ten-eleven translocation 2|tet oncogene family member 2', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105145875, end_position_on_the_genomic_accession=105279803, orientation='plus', exon_count=15, OMIM=[612839], no_hdr0=''),
    54793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54793, CurrentID=0, Status='live', Symbol='KCTD9', Aliases=['BTBD27'], description='potassium channel tetramerization domain containing 9', other_designations='BTB/POZ domain-containing protein KCTD9|potassium channel tetramerisation domain containing 9', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=25424357, end_position_on_the_genomic_accession=25458468, orientation='minus', exon_count=13, OMIM=[617265], no_hdr0=''),
    54795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54795, CurrentID=0, Status='live', Symbol='TRPM4', Aliases=['EKVP6', 'LTrpC4', 'PFHB1BB', 'hTRPM4', 'TRPM4'], description='transient receptor potential cation channel subfamily M member 4', other_designations='transient receptor potential cation channel subfamily M member 4|calcium-activated non-selective cation channel 1|long transient receptor potential channel 4|melastatin-4', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49157792, end_position_on_the_genomic_accession=49211841, orientation='plus', exon_count=25, OMIM=[606936], no_hdr0=''),
    54796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54796, CurrentID=0, Status='live', Symbol='BNC2', Aliases=['BSN2', 'LUTO'], description='basonuclin 2', other_designations='zinc finger protein basonuclin-2', map_location='9p22.3-p22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=16409503, end_position_on_the_genomic_accession=16870670, orientation='minus', exon_count=9, OMIM=[608669], no_hdr0=''),
    54797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54797, CurrentID=0, Status='live', Symbol='MED18', Aliases=['SRB5', 'p28b'], description='mediator complex subunit 18', other_designations='mediator of RNA polymerase II transcription subunit 18|TRAP/mediator complex subunit p28b|mediator of RNA polymerase II transcription, subunit 18 homolog', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28329040, end_position_on_the_genomic_accession=28335967, orientation='plus', exon_count=4, OMIM=[612384], no_hdr0=''),
    54798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54798, CurrentID=0, Status='live', Symbol='DCHS2', Aliases=['CDH27', 'CDHJ', 'CDHR7', 'PCDH23', 'PCDHJ'], description='dachsous cadherin-related 2', other_designations='protocadherin-23|cadherin J|cadherin-like 27|cadherin-like protein CDHJ|cadherin-like protein VR8|cadherin-related family member 7|protein dachsous homolog 2|protocadherin 23|protocadherin J|protocadherin PCDHJ', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154231742, end_position_on_the_genomic_accession=154491799, orientation='minus', exon_count=24, OMIM=[612486], no_hdr0=''),
    54799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54799, CurrentID=0, Status='live', Symbol='MBTD1', Aliases=['SA49P01'], description='mbt domain containing 1', other_designations='MBT domain-containing protein 1', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51177419, end_position_on_the_genomic_accession=51260511, orientation='minus', exon_count=21, OMIM=[618705], no_hdr0=''),
    54800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54800, CurrentID=0, Status='live', Symbol='KLHL24', Aliases=['DRE1', 'EBSSH', 'KRIP6'], description='kelch like family member 24', other_designations='kelch-like protein 24|kainate receptor interacting protein for GluR6|kelch-like 24', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183635619, end_position_on_the_genomic_accession=183684519, orientation='plus', exon_count=12, OMIM=[611295], no_hdr0=''),
    54801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54801, CurrentID=0, Status='live', Symbol='HAUS6', Aliases=['Dgt6', 'FAM29A'], description='HAUS augmin like complex subunit 6', other_designations='HAUS augmin-like complex subunit 6|dim gamma-tubulin homolog|family with sequence similarity 29, member A', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19053141, end_position_on_the_genomic_accession=19102904, orientation='minus', exon_count=18, OMIM=[613433], no_hdr0=''),
    54802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54802, CurrentID=0, Status='live', Symbol='TRIT1', Aliases=['COXPD35', 'GRO1', 'IPPT', 'IPT', 'IPTase', 'MOD5', 'hGRO1'], description='tRNA isopentenyltransferase 1', other_designations='tRNA dimethylallyltransferase|IPP transferase|isopentenyl-diphosphate:tRNA isopentenyltransferase|tRNA dimethylallyltransferase, mitochondrial|tRNA isopentenylpyrophosphate transferase', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39838110, end_position_on_the_genomic_accession=39883511, orientation='minus', exon_count=12, OMIM=[617840], no_hdr0=''),
    54805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54805, CurrentID=0, Status='live', Symbol='CNNM2', Aliases=['ACDP2', 'HOMG6', 'HOMGSMR'], description='cyclin and CBS domain divalent metal cation transport mediator 2', other_designations='metal transporter CNNM2|ancient conserved domain-containing protein 2|cyclin M2', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102918294, end_position_on_the_genomic_accession=103090222, orientation='plus', exon_count=9, OMIM=[607803], no_hdr0=''),
    54806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54806, CurrentID=0, Status='live', Symbol='AHI1', Aliases=['AHI-1', 'JBTS3', 'ORF1', 'dJ71N10.1'], description='Abelson helper integration site 1', other_designations='jouberin|abelson helper integration site 1 protein homolog|contatins SH3 and WD40 domains', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=135283532, end_position_on_the_genomic_accession=135497771, orientation='minus', exon_count=35, OMIM=[608894], no_hdr0=''),
    54807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54807, CurrentID=0, Status='live', Symbol='ZNF586', Aliases=[], description='zinc finger protein 586', other_designations='zinc finger protein 586', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57769676, end_position_on_the_genomic_accession=57780616, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54808, CurrentID=0, Status='live', Symbol='DYM', Aliases=['DMC', 'SMC'], description='dymeclin', other_designations='dymeclin|dyggve-Melchior-Clausen syndrome protein', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49036387, end_position_on_the_genomic_accession=49460709, orientation='minus', exon_count=24, OMIM=[607461], no_hdr0=''),
    54809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54809, CurrentID=0, Status='live', Symbol='SAMD9', Aliases=['C7orf5', 'DRIF1', 'M7MLS2', 'MIRAGE', 'NFTC', 'OEF1', 'OEF2'], description='sterile alpha motif domain containing 9', other_designations='sterile alpha motif domain-containing protein 9|SAM domain-containing protein 9|expressed in aggressive fibromatosis', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93099518, end_position_on_the_genomic_accession=93117979, orientation='minus', exon_count=3, OMIM=[610456], no_hdr0=''),
    54810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54810, CurrentID=0, Status='live', Symbol='GIPC2', Aliases=['SEMCAP-2', 'SEMCAP2'], description='GIPC PDZ domain containing family member 2', other_designations='PDZ domain-containing protein GIPC2|PDZ domain protein GIPC2|epididymis secretory sperm binding protein|semaF cytoplasmic domain associated protein 2|semaphorin cytoplasmic domain associated protein 2', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=78044970, end_position_on_the_genomic_accession=78138444, orientation='plus', exon_count=7, OMIM=[619089], no_hdr0=''),
    54811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54811, CurrentID=0, Status='live', Symbol='ZNF562', Aliases=[], description='zinc finger protein 562', other_designations='zinc finger protein 562', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9641807, end_position_on_the_genomic_accession=9675293, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    54812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54812, CurrentID=0, Status='live', Symbol='AFTPH', Aliases=['Nbla10388'], description='aftiphilin', other_designations='aftiphilin|aftiphilin protein', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=64524328, end_position_on_the_genomic_accession=64593005, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    54813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54813, CurrentID=0, Status='live', Symbol='KLHL28', Aliases=['BTBD5'], description='kelch like family member 28', other_designations='kelch-like protein 28|BTB (POZ) domain containing 5|BTB/POZ domain-containing protein 5|kelch-like 28', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=44924324, end_position_on_the_genomic_accession=44961978, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    54814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54814, CurrentID=0, Status='live', Symbol='QPCTL', Aliases=['gQC'], description='glutaminyl-peptide cyclotransferase like', other_designations='glutaminyl-peptide cyclotransferase-like protein|glutaminyl cyclase-like|golgi-resident glutaminyl-peptide cyclotransferase|isoQC', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45692400, end_position_on_the_genomic_accession=45703987, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    54815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54815, CurrentID=0, Status='live', Symbol='GATAD2A', Aliases=['p66alpha'], description='GATA zinc finger domain containing 2A', other_designations='transcriptional repressor p66-alpha|GATA zinc finger domain-containing protein 2A', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19385843, end_position_on_the_genomic_accession=19508932, orientation='plus', exon_count=19, OMIM=[614997], no_hdr0=''),
    54816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54816, CurrentID=0, Status='live', Symbol='ZNF280D', Aliases=['SUHW4', 'ZNF634'], description='zinc finger protein 280D', other_designations='zinc finger protein 280D|suppressor of hairy wing homolog 4|zinc finger protein 634', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=56630176, end_position_on_the_genomic_accession=56733681, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    54819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54819, CurrentID=0, Status='live', Symbol='ZCCHC10', Aliases=[], description='zinc finger CCHC-type containing 10', other_designations='zinc finger CCHC domain-containing protein 10|zinc finger, CCHC domain containing 10', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132996985, end_position_on_the_genomic_accession=133026621, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    54820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54820, CurrentID=0, Status='live', Symbol='NDE1', Aliases=['HOM-TES-87', 'LIS4', 'MHAC', 'NDE', 'NUDE', 'NUDE1'], description='nudE neurodevelopment protein 1', other_designations='nuclear distribution protein nudE homolog 1|LIS1-interacting protein NUDE1, rat homolog|epididymis secretory sperm binding protein|nudE nuclear distribution E homolog 1|nudE nuclear distribution gene E homolog 1', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15643267, end_position_on_the_genomic_accession=15726353, orientation='plus', exon_count=16, OMIM=[609449], no_hdr0=''),
    54821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54821, CurrentID=0, Status='live', Symbol='ERCC6L', Aliases=['PICH', 'RAD26L'], description='ERCC excision repair 6 like, spindle assembly checkpoint helicase', other_designations='DNA excision repair protein ERCC-6-like|ATP-dependent helicase ERCC6-like|Plk1-interacting checkpoint helicase|SNF2/RAD54 family protein|excision repair cross-complementation group 6 like|excision repair cross-complementing rodent repair deficiency complementation group 6 - like|excision repair cross-complementing rodent repair deficiency, complementation group 6-like|excision repair protein ERCC6-like|tumor antigen BJ-HCC-15', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72204665, end_position_on_the_genomic_accession=72239027, orientation='minus', exon_count=3, OMIM=[300687], no_hdr0=''),
    54822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54822, CurrentID=0, Status='live', Symbol='TRPM7', Aliases=['ALSPDC', 'CHAK', 'CHAK1', 'LTRPC7', 'LTrpC-7', 'TRP-PLIK'], description='transient receptor potential cation channel subfamily M member 7', other_designations='transient receptor potential cation channel subfamily M member 7|LTRPC ion channel family member 7|channel-kinase 1|long transient receptor potential channel 7|transient receptor potential-phospholipase C-interacting kinase', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50557158, end_position_on_the_genomic_accession=50686797, orientation='minus', exon_count=43, OMIM=[605692], no_hdr0=''),
    54823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54823, CurrentID=0, Status='live', Symbol='SWT1', Aliases=['C1orf26', 'HsSwt1'], description='SWT1 RNA endoribonuclease homolog', other_designations='transcriptional protein SWT1', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=185157060, end_position_on_the_genomic_accession=185291781, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    54825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54825, CurrentID=0, Status='live', Symbol='CDHR2', Aliases=['PCDH24', 'PCLKC'], description='cadherin related family member 2', other_designations='cadherin-related family member 2|protocadherin-24', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176542511, end_position_on_the_genomic_accession=176595974, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    54826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54826, CurrentID=0, Status='live', Symbol='GIN1', Aliases=['GIN-1', 'TGIN1', 'ZH2C2'], description='gypsy retrotransposon integrase 1', other_designations='gypsy retrotransposon integrase-like protein 1|Ty3/Gypsy integrase 1|zinc finger H2C2 domain-containing protein', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=103086000, end_position_on_the_genomic_accession=103120149, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    54827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54827, CurrentID=0, Status='live', Symbol='NXPE4', Aliases=['C11orf33', 'FAM55D'], description='neurexophilin and PC-esterase domain family member 4', other_designations='NXPE family member 4|family with sequence similarity 55, member D|protein FAM55D', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114570591, end_position_on_the_genomic_accession=114596215, orientation='minus', exon_count=8, OMIM=[618133], no_hdr0=''),
    54828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54828, CurrentID=0, Status='live', Symbol='BCAS3', Aliases=['GAOB1', 'MAAB', 'PHAF2'], description='BCAS3 microtubule associated cell migration factor', other_designations='BCAS3 microtubule associated cell migration factor|breast carcinoma-amplified sequence 3|BCAS4/BCAS3 fusion|Rudhira|breast carcinoma amplified sequence 4/3 fusion protein|metastasis associated antigen of breast cancer|phagophore assembly factor 2|protein Maab1', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60677851, end_position_on_the_genomic_accession=61392831, orientation='plus', exon_count=40, OMIM=[607470], no_hdr0=''),
    54829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54829, CurrentID=0, Status='live', Symbol='ASPN', Aliases=['OS3', 'PLAP-1', 'PLAP1', 'SLRR1C'], description='asporin', other_designations='asporin|asporin (LRR class 1)|asporin proteoglycan|periodontal ligament associated protein 1|small leucine-rich protein 1C', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92456205, end_position_on_the_genomic_accession=92482506, orientation='minus', exon_count=8, OMIM=[608135], no_hdr0=''),
    54830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54830, CurrentID=0, Status='live', Symbol='NUP62CL', Aliases=[], description='nucleoporin 62 C-terminal like', other_designations='nucleoporin-62 C-terminal-like protein|nucleoporin 62kDa C-terminal like', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107123427, end_position_on_the_genomic_accession=107206433, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    54831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54831, CurrentID=0, Status='live', Symbol='BEST2', Aliases=['VMD2L1'], description='bestrophin 2', other_designations='bestrophin-2|VMD2-like gene 1|vitelliform macular dystrophy 2-like 1|vitelliform macular dystrophy 2-like protein 1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12751791, end_position_on_the_genomic_accession=12758458, orientation='plus', exon_count=10, OMIM=[607335], no_hdr0=''),
    54832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54832, CurrentID=0, Status='live', Symbol='VPS13C', Aliases=['PARK23'], description='vacuolar protein sorting 13 homolog C', other_designations='vacuolar protein sorting-associated protein 13C', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=61852389, end_position_on_the_genomic_accession=62060447, orientation='minus', exon_count=88, OMIM=[608879], no_hdr0=''),
    54834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54834, CurrentID=0, Status='live', Symbol='GDAP2', Aliases=['MACROD3', 'SCAR27'], description='ganglioside induced differentiation associated protein 2', other_designations='ganglioside-induced differentiation-associated protein 2', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117863485, end_position_on_the_genomic_accession=117929621, orientation='minus', exon_count=14, OMIM=[618128], no_hdr0=''),
    54836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54836, CurrentID=0, Status='live', Symbol='BSPRY', Aliases=[], description='B-box and SPRY domain containing', other_designations='B box and SPRY domain-containing protein|B-box and SPRY-domain containing protein|zetin 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113349541, end_position_on_the_genomic_accession=113371233, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    54838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54838, CurrentID=0, Status='live', Symbol='WBP1L', Aliases=['C10orf26', 'OPA1L', 'OPAL1'], description='WW domain binding protein 1 like', other_designations='WW domain binding protein 1-like|outcome predictor in acute leukemia 1', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102742708, end_position_on_the_genomic_accession=102816267, orientation='plus', exon_count=6, OMIM=[611129], no_hdr0=''),
    54839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54839, CurrentID=0, Status='live', Symbol='LRRC49', Aliases=['PGs4'], description='leucine rich repeat containing 49', other_designations='leucine-rich repeat-containing protein 49|tubulin polyglutamylase complex subunit 4', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=70853378, end_position_on_the_genomic_accession=71053658, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    54840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54840, CurrentID=0, Status='live', Symbol='APTX', Aliases=['AOA', 'AOA1', 'AXA1', 'EAOH', 'EOAHA', 'FHA-HIT'], description='aprataxin', other_designations='aprataxin|forkhead-associated domain histidine triad-like protein', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32883872, end_position_on_the_genomic_accession=33025120, orientation='minus', exon_count=19, OMIM=[606350], no_hdr0=''),
    54841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54841, CurrentID=0, Status='live', Symbol='BIVM', Aliases=[], description='basic, immunoglobulin-like variable motif containing', other_designations='basic immunoglobulin-like variable motif-containing protein', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102799119, end_position_on_the_genomic_accession=102841533, orientation='plus', exon_count=11, OMIM=[619006], no_hdr0=''),
    54842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54842, CurrentID=0, Status='live', Symbol='MFSD6', Aliases=['MMR2', 'hMMR2'], description='major facilitator superfamily domain containing 6', other_designations='major facilitator superfamily domain-containing protein 6|macrophage MHC class I receptor 2 homolog|macrophage MHC receptor 2', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190407576, end_position_on_the_genomic_accession=190502314, orientation='plus', exon_count=13, OMIM=[613476], no_hdr0=''),
    54843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54843, CurrentID=0, Status='live', Symbol='SYTL2', Aliases=['CHR11SYT', 'EXO4', 'PPP1R151', 'SGA72M', 'SLP2', 'SLP2A'], description='synaptotagmin like 2', other_designations='synaptotagmin-like protein 2|breast cancer-associated antigen SGA-72M|chromosome 11 synaptotagmin|exophilin-4|protein phosphatase 1, regulatory subunit 151', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85694229, end_position_on_the_genomic_accession=85854870, orientation='minus', exon_count=25, OMIM=[612880], no_hdr0=''),
    54845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54845, CurrentID=0, Status='live', Symbol='ESRP1', Aliases=['DFNB109', 'RBM35A', 'RMB35A'], description='epithelial splicing regulatory protein 1', other_designations='epithelial splicing regulatory protein 1|RNA-binding motif protein 35A|RNA-binding protein 35A', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94640999, end_position_on_the_genomic_accession=94707466, orientation='plus', exon_count=16, OMIM=[612959], no_hdr0=''),
    54847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54847, CurrentID=0, Status='live', Symbol='SIDT1', Aliases=['SID-1', 'SID1'], description='SID1 transmembrane family member 1', other_designations='SID1 transmembrane family member 1', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113532296, end_position_on_the_genomic_accession=113629579, orientation='plus', exon_count=29, OMIM=[606816], no_hdr0=''),
    54848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54848, CurrentID=0, Status='live', Symbol='ARHGEF38', Aliases=[], description='Rho guanine nucleotide exchange factor 38', other_designations='rho guanine nucleotide exchange factor 38|Rho guanine nucleotide exchange factor (GEF) 38', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105552604, end_position_on_the_genomic_accession=105682539, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    54849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54849, CurrentID=0, Status='live', Symbol='DEF8', Aliases=[], description='differentially expressed in FDCP 8 homolog', other_designations='differentially expressed in FDCP 8 homolog|DEF-8', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89948755, end_position_on_the_genomic_accession=89968060, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    54850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54850, CurrentID=0, Status='live', Symbol='FBXL12', Aliases=['Fbl12'], description='F-box and leucine rich repeat protein 12', other_designations='F-box/LRR-repeat protein 12|F-box protein FBL12', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9810267, end_position_on_the_genomic_accession=9820528, orientation='minus', exon_count=7, OMIM=[609079], no_hdr0=''),
    54851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54851, CurrentID=0, Status='live', Symbol='ANKRD49', Aliases=['FGIF', 'GBIF'], description='ankyrin repeat domain 49', other_designations='ankyrin repeat domain-containing protein 49|fetal globin-inducing factor', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94493984, end_position_on_the_genomic_accession=94499578, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    54852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54852, CurrentID=0, Status='live', Symbol='PAQR5', Aliases=['MPRG'], description='progestin and adipoQ receptor family member 5', other_designations='membrane progestin receptor gamma|mPR gamma|membrane progesterone P4 receptor gamma|membrane progesterone receptor gamma|progesterone and adipoQ receptor family member 5|progestin and adipoQ receptor family member V', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=69284134, end_position_on_the_genomic_accession=69407780, orientation='plus', exon_count=18, OMIM=[607781], no_hdr0=''),
    54853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54853, CurrentID=0, Status='live', Symbol='WDR55', Aliases=[], description='WD repeat domain 55', other_designations='WD repeat-containing protein 55', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140664831, end_position_on_the_genomic_accession=140674119, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    54854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54854, CurrentID=0, Status='live', Symbol='FAM83E', Aliases=[], description='family with sequence similarity 83 member E', other_designations='protein FAM83E', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48599961, end_position_on_the_genomic_accession=48615239, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    54855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54855, CurrentID=0, Status='live', Symbol='TENT5C', Aliases=['FAM46C'], description='terminal nucleotidyltransferase 5C', other_designations='terminal nucleotidyltransferase 5C|family with sequence similarity 46 member C|non-canonical poly(A) polymerase FAM46C|protein FAM46C|putative nucleotidyltransferase FAM46C', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117606048, end_position_on_the_genomic_accession=117628389, orientation='plus', exon_count=2, OMIM=[613952], no_hdr0=''),
    54856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54856, CurrentID=0, Status='live', Symbol='GON4L', Aliases=['GON-4', 'GON4', 'YARP'], description='gon-4 like', other_designations='GON-4-like protein|2610100B20Rik|YY1AP related protein|YY1AP-related protein1|gon-4 homolog', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155749659, end_position_on_the_genomic_accession=155859431, orientation='minus', exon_count=35, OMIM=[610393], no_hdr0=''),
    54857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54857, CurrentID=0, Status='live', Symbol='GDPD2', Aliases=['GDE3', 'OBDPF'], description='glycerophosphodiester phosphodiesterase domain containing 2', other_designations='glycerophosphoinositol inositolphosphodiesterase GDPD2|glycerophosphodiester phosphodiesterase 3|glycerophosphodiester phosphodiesterase domain-containing protein 2|osteoblast differentiation promoting factor', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70423031, end_position_on_the_genomic_accession=70433391, orientation='plus', exon_count=17, OMIM=[300940], no_hdr0=''),
    54858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54858, CurrentID=0, Status='live', Symbol='PGPEP1', Aliases=['PAP-I', 'PGI', 'PGP', 'PGP-I', 'PGPI', 'Pcp'], description='pyroglutamyl-peptidase I', other_designations='pyroglutamyl-peptidase 1|5-oxoprolyl-peptidase|pGlu-peptidase I|pyroglutamyl aminopeptidase I|pyrrolidone-carboxylate peptidase', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18340598, end_position_on_the_genomic_accession=18369950, orientation='plus', exon_count=6, OMIM=[610694], no_hdr0=''),
    54859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54859, CurrentID=0, Status='live', Symbol='ELP6', Aliases=['C3orf75', 'TMEM103'], description='elongator acetyltransferase complex subunit 6', other_designations='elongator complex protein 6|UPF0405 protein C3orf75|angiotonin-transactivated protein 1|elongator complex protein 6 homolog|transmembrane protein 103', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47495640, end_position_on_the_genomic_accession=47513725, orientation='minus', exon_count=11, OMIM=[615020], no_hdr0=''),
    54860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54860, CurrentID=0, Status='live', Symbol='MS4A12', Aliases=['Ms4a10'], description='membrane spanning 4-domains A12', other_designations='membrane-spanning 4-domains subfamily A member 12', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60492743, end_position_on_the_genomic_accession=60507430, orientation='plus', exon_count=8, OMIM=[606550], no_hdr0=''),
    54861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54861, CurrentID=0, Status='live', Symbol='SNRK', Aliases=['HSNFRK'], description='SNF related kinase', other_designations='SNF-related serine/threonine-protein kinase|SNF-1 related kinase|SNF1-related kinase', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=43286512, end_position_on_the_genomic_accession=43351143, orientation='plus', exon_count=8, OMIM=[612760], no_hdr0=''),
    54862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54862, CurrentID=0, Status='live', Symbol='CC2D1A', Aliases=['Aki-1', 'FREUD-1', 'Freud-1/Aki1', 'Lgd2', 'MRT3', 'TAPE'], description='coiled-coil and C2 domain containing 1A', other_designations='coiled-coil and C2 domain-containing protein 1A|Akt kinase-interacting protein 1|FRE under dual repression-binding protein 1|TBK1-associated protein in endolysosomes|five prime repressor element under dual repression-binding protein 1|five repressor element under dual repression-binding protein 1|putative NF-kappa-B-activating protein 023N|putative NFkB activating protein', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13906149, end_position_on_the_genomic_accession=13930879, orientation='plus', exon_count=28, OMIM=[610055], no_hdr0=''),
    54863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54863, CurrentID=0, Status='live', Symbol='TOR4A', Aliases=['C9orf167'], description='torsin family 4 member A', other_designations='torsin-4A|torsin family protein C9orf167', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137277726, end_position_on_the_genomic_accession=137282641, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    54865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54865, CurrentID=0, Status='live', Symbol='GPATCH4', Aliases=['GPATC4'], description='G-patch domain containing 4', other_designations='G patch domain-containing protein 4', map_location='1q22-q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156594301, end_position_on_the_genomic_accession=156601479, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    54866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54866, CurrentID=0, Status='live', Symbol='PPP1R14D', Aliases=['CPI17-like', 'GBPI-1', 'GBPI1'], description='protein phosphatase 1 regulatory inhibitor subunit 14D', other_designations='protein phosphatase 1 regulatory subunit 14D|PKC-dependent PP1 inhibitory protein|gastrointestinal and brain-specific PP1-inhibitory protein 1|gut and brain phosphatase inhibitor 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40815451, end_position_on_the_genomic_accession=40828793, orientation='minus', exon_count=5, OMIM=[613256], no_hdr0=''),
    54867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54867, CurrentID=0, Status='live', Symbol='TMEM214', Aliases=[], description='transmembrane protein 214', other_designations='transmembrane protein 214', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27032965, end_position_on_the_genomic_accession=27041694, orientation='plus', exon_count=18, OMIM=[615301], no_hdr0=''),
    54868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54868, CurrentID=0, Status='live', Symbol='TMEM104', Aliases=[], description='transmembrane protein 104', other_designations='transmembrane protein 104', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74776499, end_position_on_the_genomic_accession=74839753, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    54869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54869, CurrentID=0, Status='live', Symbol='EPS8L1', Aliases=['DRC3', 'EPS8R1', 'PP10566'], description='EPS8 like 1', other_designations='epidermal growth factor receptor kinase substrate 8-like protein 1|EPS8-like protein 1|EPS8-related protein 1|epidermal growth factor receptor pathway substrate 8-related protein 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55075869, end_position_on_the_genomic_accession=55087923, orientation='plus', exon_count=22, OMIM=[614987], no_hdr0=''),
    54870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54870, CurrentID=0, Status='live', Symbol='QRICH1', Aliases=['AB-DIP', 'VERBRAS'], description='glutamine rich 1', other_designations='transcriptional regulator QRICH1|glutamine-rich protein 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49029707, end_position_on_the_genomic_accession=49094373, orientation='minus', exon_count=13, OMIM=[617387], no_hdr0=''),
    54872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54872, CurrentID=0, Status='live', Symbol='PIGG', Aliases=['GPI7', 'LAS21', 'MRT53', 'PRO4405', 'RLGS1930'], description='phosphatidylinositol glycan anchor biosynthesis class G', other_designations='GPI ethanolamine phosphate transferase 2|phosphatidylinositol-glycan biosynthesis class G protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=499210, end_position_on_the_genomic_accession=540200, orientation='plus', exon_count=18, OMIM=[616918], no_hdr0=''),
    54873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54873, CurrentID=0, Status='live', Symbol='PALMD', Aliases=['C1orf11', 'PALML'], description='palmdelphin', other_designations='palmdelphin|paralemmin-like protein|paralemnin-like protein', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=99646113, end_position_on_the_genomic_accession=99694535, orientation='plus', exon_count=8, OMIM=[610182], no_hdr0=''),
    54874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54874, CurrentID=0, Status='live', Symbol='FNBP1L', Aliases=['C1orf39', 'TOCA1'], description='formin binding protein 1 like', other_designations='formin-binding protein 1-like|toca-1|transducer of Cdc42-dependent actin assembly 1|transducer of Cdc42-dependent actin assembly protein 1', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93448067, end_position_on_the_genomic_accession=93569671, orientation='plus', exon_count=20, OMIM=[608848], no_hdr0=''),
    54875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54875, CurrentID=0, Status='live', Symbol='CNTLN', Aliases=['C9orf101', 'C9orf39', 'bA340N12.1'], description='centlein', other_designations='centlein|centlein, centrosomal protein|centrosomal protein', map_location='9p22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=17134991, end_position_on_the_genomic_accession=17510020, orientation='plus', exon_count=37, OMIM=[611870], no_hdr0=''),
    54876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54876, CurrentID=0, Status='live', Symbol='DCAF16', Aliases=['C4orf30'], description='DDB1 and CUL4 associated factor 16', other_designations='DDB1- and CUL4-associated factor 16', map_location='4p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17793446, end_position_on_the_genomic_accession=17810757, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    54877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54877, CurrentID=0, Status='live', Symbol='ZCCHC2', Aliases=['C18orf49'], description='zinc finger CCHC-type containing 2', other_designations='zinc finger CCHC domain-containing protein 2|zinc finger, CCHC domain containing 2', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=62523025, end_position_on_the_genomic_accession=62587709, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    54878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54878, CurrentID=0, Status='live', Symbol='DPP8', Aliases=['DP8', 'DPRP-1', 'DPRP1', 'MST097', 'MSTP097', 'MSTP135', 'MSTP141'], description='dipeptidyl peptidase 8', other_designations='dipeptidyl peptidase 8|DPP VIII|dipeptidyl peptidase IV-related protein 1|dipeptidyl peptidase VIII|prolyl dipeptidase DPP8', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65442467, end_position_on_the_genomic_accession=65517689, orientation='minus', exon_count=23, OMIM=[606819], no_hdr0=''),
    54879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54879, CurrentID=0, Status='live', Symbol='ST7L', Aliases=['FAM4B', 'ST7R', 'STLR'], description='suppression of tumorigenicity 7 like', other_designations='suppressor of tumorigenicity 7 protein-like|ST7-related protein|tumor suppressor ST7 like', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112517444, end_position_on_the_genomic_accession=112619881, orientation='minus', exon_count=22, OMIM=[617640], no_hdr0=''),
    54880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54880, CurrentID=0, Status='live', Symbol='BCOR', Aliases=['ANOP2', 'MAA2', 'MCOPS2'], description='BCL6 corepressor', other_designations='BCL-6 corepressor|BCL-6 coreceptor|BCL-6 interacting corepressor|BCL6 interacting corepressor', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=40051246, end_position_on_the_genomic_accession=40177390, orientation='minus', exon_count=17, OMIM=[300485], no_hdr0=''),
    54881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54881, CurrentID=0, Status='live', Symbol='TEX10', Aliases=['Ipi1', 'bA208F1.2'], description='testis expressed 10', other_designations='testis-expressed protein 10|testis expressed gene 10|testis-expressed sequence 10 protein', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100302084, end_position_on_the_genomic_accession=100352942, orientation='minus', exon_count=16, OMIM=[616717], no_hdr0=''),
    54882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54882, CurrentID=0, Status='live', Symbol='ANKHD1', Aliases=['MASK', 'MASK1', 'PP2500', 'VBARP'], description='ankyrin repeat and KH domain containing 1', other_designations='ankyrin repeat and KH domain-containing protein 1|HIV-1 Vpr-binding ankyrin repeat protein|multiple ankyrin repeats, single KH-domain homolog', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140401833, end_position_on_the_genomic_accession=140539849, orientation='plus', exon_count=35, OMIM=[610500], no_hdr0=''),
    54883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54883, CurrentID=0, Status='live', Symbol='CWC25', Aliases=['CCDC49'], description='CWC25 spliceosome associated protein homolog', other_designations='pre-mRNA-splicing factor CWC25 homolog|coiled-coil domain-containing protein 49', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38800441, end_position_on_the_genomic_accession=38825325, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    54884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54884, CurrentID=0, Status='live', Symbol='RETSAT', Aliases=[], description='retinol saturase', other_designations='all-trans-retinol 13,14-reductase|PPAR-alpha-regulated and starvation-induced gene protein|all-trans-13,14-dihydroretinol saturase', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85341955, end_position_on_the_genomic_accession=85354528, orientation='minus', exon_count=11, OMIM=[617597], no_hdr0=''),
    54885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54885, CurrentID=0, Status='live', Symbol='TBC1D8B', Aliases=['GRAMD8B', 'NPHS20'], description='TBC1 domain family member 8B', other_designations='TBC1 domain family member 8B|RP11-321G1.1|TBC1 domain family, member 8B (with GRAM domain)', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106802673, end_position_on_the_genomic_accession=106876150, orientation='plus', exon_count=22, OMIM=[301027], no_hdr0=''),
    54886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54886, CurrentID=0, Status='live', Symbol='PLPPR1', Aliases=['LPPR1', 'PRG-3'], description='phospholipid phosphatase related 1', other_designations='phospholipid phosphatase-related protein type 1|lipid phosphate phosphatase-related protein type 1|plasticity related gene 3|plasticity-related gene 3 protein', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101028727, end_position_on_the_genomic_accession=101325135, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    54887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54887, CurrentID=0, Status='live', Symbol='UHRF1BP1', Aliases=['C6orf107', 'ICBP90', 'dJ349A12.1'], description='UHRF1 binding protein 1', other_designations='UHRF1-binding protein 1|ICBP90 binding protein 1|UHRF1 (ICBP90) binding protein 1|ubiquitin-like containing PHD and RING finger domains 1-binding protein 1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34792083, end_position_on_the_genomic_accession=34877514, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    54888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54888, CurrentID=0, Status='live', Symbol='NSUN2', Aliases=['MISU', 'MRT5', 'SAKI', 'TRM4'], description='NOP2/Sun RNA methyltransferase 2', other_designations='RNA cytosine C(5)-methyltransferase NSUN2|5-methycytoisine methyltransferase|Myc-induced SUN-domain-containing protein|NOL1/NOP2/Sun domain family, member 2|NOP2/Sun RNA methyltransferase family member 2|NOP2/Sun domain family, member 2|mRNA cytosine C(5)-methyltransferase|myc-induced SUN domain-containing protein|substrate of AIM1/Aurora kinase B|tRNA (cytosine(34)-C(5))-methyltransferase|tRNA (cytosine-5-)-methyltransferase NSUN2|tRNA cytosine C(5)-methyltransferase|tRNA methyltransferase 4 homolog', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=6599239, end_position_on_the_genomic_accession=6633044, orientation='minus', exon_count=19, OMIM=[610916], no_hdr0=''),
    54890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54890, CurrentID=0, Status='live', Symbol='ALKBH5', Aliases=['ABH5', 'OFOXD', 'OFOXD1'], description='alkB homolog 5, RNA demethylase', other_designations='RNA demethylase ALKBH5|AlkB family member 5, RNA demethylase|alkB, alkylation repair homolog 5|alkylated DNA repair protein alkB homolog 5|alpha-ketoglutarate-dependent dioxygenase alkB homolog 5|oxoglutarate and iron-dependent oxygenase domain containing|probable alpha-ketoglutarate-dependent dioxygenase ABH5', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18183828, end_position_on_the_genomic_accession=18209954, orientation='plus', exon_count=4, OMIM=[613303], no_hdr0=''),
    54891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54891, CurrentID=0, Status='live', Symbol='INO80D', Aliases=[], description='INO80 complex subunit D', other_designations='INO80 complex subunit D', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=205993721, end_position_on_the_genomic_accession=206086174, orientation='minus', exon_count=15, OMIM=[619207], no_hdr0=''),
    54892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54892, CurrentID=0, Status='live', Symbol='NCAPG2', Aliases=['3KS', 'CAP-G2', 'CAPG2', 'LUZP5', 'MTB', 'hCAP-G2'], description='non-SMC condensin II complex subunit G2', other_designations='condensin-2 complex subunit G2|chromosome-associated protein G2|leucine zipper protein 5|more than blood homolog', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=158631169, end_position_on_the_genomic_accession=158704816, orientation='minus', exon_count=33, OMIM=[608532], no_hdr0=''),
    54893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54893, CurrentID=0, Status='live', Symbol='MTMR10', Aliases=[], description='myotubularin related protein 10', other_designations='myotubularin-related protein 10|inactive phosphatidylinositol 3-phosphatase 10', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30919764, end_position_on_the_genomic_accession=30991628, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    54894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54894, CurrentID=0, Status='live', Symbol='RNF43', Aliases=['RNF124', 'SSPCS', 'URCC'], description='ring finger protein 43', other_designations='E3 ubiquitin-protein ligase RNF43|RING-type E3 ubiquitin transferase RNF43', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58352500, end_position_on_the_genomic_accession=58418894, orientation='minus', exon_count=11, OMIM=[612482], no_hdr0=''),
    54896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54896, CurrentID=0, Status='live', Symbol='SLC66A1', Aliases=['LAAT-1', 'LAAT1', 'PQLC2'], description='solute carrier family 66 member 1', other_designations='lysosomal amino acid transporter 1 homolog|PQ loop repeat containing 2|PQ-loop repeat-containing protein 2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19312302, end_position_on_the_genomic_accession=19332611, orientation='plus', exon_count=9, OMIM=[614760], no_hdr0=''),
    54897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54897, CurrentID=0, Status='live', Symbol='CASZ1', Aliases=['CAS11', 'CST', 'SRG', 'ZNF693', 'dJ734G22.1'], description='castor zinc finger 1', other_designations='zinc finger protein castor homolog 1|castor homolog 1, zinc finger|castor-related protein|survival-related|zinc finger protein 693', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10636604, end_position_on_the_genomic_accession=10796650, orientation='minus', exon_count=24, OMIM=[609895], no_hdr0=''),
    54898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54898, CurrentID=0, Status='live', Symbol='ELOVL2', Aliases=['SSC2'], description='ELOVL fatty acid elongase 2', other_designations='elongation of very long chain fatty acids protein 2|3-keto acyl-CoA synthase ELOVL2|ELOVL FA elongase 2|elongation of very long chain fatty acids (FEN1/Elo2, SUR4/Elo3, yeast)-like 2|very long chain 3-ketoacyl-CoA synthase 2|very long chain 3-oxoacyl-CoA synthase 2', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10980759, end_position_on_the_genomic_accession=11044305, orientation='minus', exon_count=11, OMIM=[611814], no_hdr0=''),
    54899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54899, CurrentID=0, Status='live', Symbol='PXK', Aliases=['MONAKA', 'SLOB'], description='PX domain containing serine/threonine kinase like', other_designations='PX domain-containing protein kinase-like protein|PX ser/thr kinase v2|PX serine/threonine kinase|modulator of Na,K-ATPase long form', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58332890, end_position_on_the_genomic_accession=58426127, orientation='plus', exon_count=23, OMIM=[611450], no_hdr0=''),
    54900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54900, CurrentID=0, Status='live', Symbol='LAX1', Aliases=['LAX'], description='lymphocyte transmembrane adaptor 1', other_designations='lymphocyte transmembrane adapter 1|LAT-like membrane associated protein|linker for activation of x cells|membrane-associated adapter protein LAX', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203765132, end_position_on_the_genomic_accession=203778175, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    54901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54901, CurrentID=0, Status='live', Symbol='CDKAL1', Aliases=[], description='CDK5 regulatory subunit associated protein 1 like 1', other_designations='threonylcarbamoyladenosine tRNA methylthiotransferase|tRNA-t(6)A37 methylthiotransferase', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=20534457, end_position_on_the_genomic_accession=21232404, orientation='plus', exon_count=22, OMIM=[611259], no_hdr0=''),
    54902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54902, CurrentID=0, Status='live', Symbol='TTC19', Aliases=['2010204O13Rik', 'MC3DN2'], description='tetratricopeptide repeat domain 19', other_designations='tetratricopeptide repeat protein 19, mitochondrial|TPR repeat protein 19', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15999771, end_position_on_the_genomic_accession=16045428, orientation='plus', exon_count=12, OMIM=[613814], no_hdr0=''),
    54903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54903, CurrentID=0, Status='live', Symbol='MKS1', Aliases=['BBS13', 'JBTS28', 'MES', 'MKS', 'POC12'], description='MKS transition zone complex subunit 1', other_designations='Meckel syndrome type 1 protein|POC12 centriolar protein homolog', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58205436, end_position_on_the_genomic_accession=58219605, orientation='minus', exon_count=20, OMIM=[609883], no_hdr0=''),
    54904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54904, CurrentID=0, Status='live', Symbol='NSD3', Aliases=['KMT3F', 'KMT3G', 'WHISTLE', 'WHSC1L1', 'pp14328'], description='nuclear receptor binding SET domain protein 3', other_designations='histone-lysine N-methyltransferase NSD3|Wolf-Hirschhorn syndrome candidate 1-like 1|nuclear SET domain-containing protein 3|protein whistle', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38269704, end_position_on_the_genomic_accession=38382271, orientation='minus', exon_count=25, OMIM=[607083], no_hdr0=''),
    54905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54905, CurrentID=0, Status='live', Symbol='CYP2W1', Aliases=[], description='cytochrome P450 family 2 subfamily W member 1', other_designations='cytochrome P450 2W1|CYPIIW1|cytochrome P450, family 2, subfamily W, polypeptide 1', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=983155, end_position_on_the_genomic_accession=989640, orientation='plus', exon_count=10, OMIM=[615967], no_hdr0=''),
    54906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54906, CurrentID=0, Status='live', Symbol='TASOR2', Aliases=['C10orf18', 'FAM208B', 'bA318E3.2'], description='transcription activation suppressor family member 2', other_designations='protein TASOR 2|family with sequence similarity 208 member B|protein FAM208B', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5684759, end_position_on_the_genomic_accession=5765779, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    54908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54908, CurrentID=0, Status='live', Symbol='SPDL1', Aliases=['CCDC99'], description='spindle apparatus coiled-coil protein 1', other_designations='protein Spindly|arsenite-related gene 1 protein|coiled-coil domain-containing protein 99|rhabdomyosarcoma antigen MU-RMS-40.4A|rrhabdomyosarcoma antigen protein MU-RMS-40.4A', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=169583661, end_position_on_the_genomic_accession=169604778, orientation='plus', exon_count=15, OMIM=[616401], no_hdr0=''),
    54910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54910, CurrentID=0, Status='live', Symbol='SEMA4C', Aliases=['M-SEMA-F', 'SEMACL1', 'SEMAF', 'SEMAI'], description='semaphorin 4C', other_designations='semaphorin-4C|M-Sema F|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4C', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96859718, end_position_on_the_genomic_accession=96870943, orientation='minus', exon_count=19, OMIM=[604462], no_hdr0=''),
    54913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54913, CurrentID=0, Status='live', Symbol='RPP25', Aliases=[], description='ribonuclease P and MRP subunit p25', other_designations='ribonuclease P protein subunit p25|RNase P protein subunit p25|ribonuclease P 25kDa subunit|ribonuclease P/MRP 25kDa subunit|ribonuclease P/MRP subunit p25', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74954418, end_position_on_the_genomic_accession=74956772, orientation='minus', exon_count=1, OMIM=[619235], no_hdr0=''),
    54914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54914, CurrentID=0, Status='live', Symbol='FOCAD', Aliases=['KIAA1797'], description='focadhesin', other_designations='focadhesin', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=20658309, end_position_on_the_genomic_accession=20995953, orientation='plus', exon_count=50, OMIM=[614606], no_hdr0=''),
    54915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54915, CurrentID=0, Status='live', Symbol='YTHDF1', Aliases=['C20orf21', 'DF1'], description='YTH N6-methyladenosine RNA binding protein 1', other_designations='YTH domain-containing family protein 1|DACA-1|YTH N(6)-methyladenosine RNA binding protein 1|YTH domain family 1|YTH domain family protein 1|YTH domain family, member 1|dermatomyositis associated with cancer putative autoantigen 1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63195429, end_position_on_the_genomic_accession=63216131, orientation='minus', exon_count=6, OMIM=[616529], no_hdr0=''),
    54916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54916, CurrentID=0, Status='live', Symbol='TMEM260', Aliases=['C14orf101', 'SHDRA'], description='transmembrane protein 260', other_designations='transmembrane protein 260|UPF0679 protein C14orf101', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=56579792, end_position_on_the_genomic_accession=56660629, orientation='plus', exon_count=22, OMIM=[617449], no_hdr0=''),
    54918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54918, CurrentID=0, Status='live', Symbol='CMTM6', Aliases=['CKLFSF6', 'PRO2219'], description='CKLF like MARVEL transmembrane domain containing 6', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 6|chemokine-like factor super family 6|chemokine-like factor superfamily 6|chemokine-like factor superfamily member 6', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32481312, end_position_on_the_genomic_accession=32502852, orientation='minus', exon_count=4, OMIM=[607889], no_hdr0=''),
    54919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54919, CurrentID=0, Status='live', Symbol='DNAAF5', Aliases=['CILD18', 'HEATR2'], description='dynein axonemal assembly factor 5', other_designations='dynein axonemal assembly factor 5|dynein assembly factor 5, axonemal|HEAT repeat containing 2|HEAT repeat-containing protein 2', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=726692, end_position_on_the_genomic_accession=786478, orientation='plus', exon_count=14, OMIM=[614864], no_hdr0=''),
    54920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54920, CurrentID=0, Status='live', Symbol='DUS2', Aliases=['DUS2L', 'SMM1', 'URLC8'], description='dihydrouridine synthase 2', other_designations='tRNA-dihydrouridine(20) synthase [NAD(P)+]-like|SMM1 homolog|dihydrouridine synthase 2-like, SMM1 homolog|tRNA-dihydrouridine(20) synthase (NAD(P)(+))|up-regulated in lung cancer protein 8', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68023284, end_position_on_the_genomic_accession=68079320, orientation='plus', exon_count=17, OMIM=[609707], no_hdr0=''),
    54921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54921, CurrentID=0, Status='live', Symbol='CHTF8', Aliases=['CTF8', 'DERPC'], description='chromosome transmission fidelity factor 8', other_designations='chromosome transmission fidelity protein 8 homolog|CTF8, chromosome transmission fidelity factor 8 homolog|decreased expression in renal and prostate cancer protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69118010, end_position_on_the_genomic_accession=69132588, orientation='minus', exon_count=5, OMIM=[613202], no_hdr0=''),
    54922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54922, CurrentID=0, Status='live', Symbol='RASIP1', Aliases=['RAIN'], description='Ras interacting protein 1', other_designations='ras-interacting protein 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48720585, end_position_on_the_genomic_accession=48740610, orientation='minus', exon_count=12, OMIM=[609623], no_hdr0=''),
    54923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54923, CurrentID=0, Status='live', Symbol='LIME1', Aliases=['LIME', 'dJ583P15.4'], description='Lck interacting transmembrane adaptor 1', other_designations='lck-interacting transmembrane adapter 1|lck-interacting membrane protein|lck-interacting molecule', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63735701, end_position_on_the_genomic_accession=63739103, orientation='plus', exon_count=7, OMIM=[609809], no_hdr0=''),
    54925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54925, CurrentID=0, Status='live', Symbol='ZSCAN32', Aliases=['HCCS-5', 'ZNF434'], description='zinc finger and SCAN domain containing 32', other_designations='zinc finger and SCAN domain-containing protein 32|human cervical cancer suppressor gene 5 protein|zinc finger protein 434', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3382085, end_position_on_the_genomic_accession=3402007, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    54926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54926, CurrentID=0, Status='live', Symbol='UBE2R2', Aliases=['CDC34B', 'E2-CDC34B', 'UBC3B'], description='ubiquitin conjugating enzyme E2 R2', other_designations='ubiquitin-conjugating enzyme E2 R2|E2 ubiquitin-conjugating enzyme R2|ubiquitin carrier protein R2|ubiquitin conjugating enzyme E2R 2|ubiquitin-conjugating enzyme E2-CDC34B|ubiquitin-conjugating enzyme UBC3B|ubiquitin-protein ligase R2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33817160, end_position_on_the_genomic_accession=33920399, orientation='plus', exon_count=5, OMIM=[612506], no_hdr0=''),
    54927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54927, CurrentID=0, Status='live', Symbol='CHCHD3', Aliases=['MICOS19', 'MINOS3', 'Mic19', 'PPP1R22'], description='coiled-coil-helix-coiled-coil-helix domain containing 3', other_designations='MICOS complex subunit MIC19|coiled-coil-helix-coiled-coil-helix domain-containing protein 3, mitochondrial|mitochondrial contact site and cristae organizing system subunit 19|mitochondrial inner membrane organizing system 3|protein phosphatase 1, regulatory subunit 22', map_location='7q32.3-q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=132784870, end_position_on_the_genomic_accession=133082090, orientation='minus', exon_count=13, OMIM=[613748], no_hdr0=''),
    54928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54928, CurrentID=0, Status='live', Symbol='BPNT2', Aliases=['GPAPP', 'IMP 3', 'IMP-3', 'IMPA3', 'IMPAD1'], description="3'(2'), 5'-bisphosphate nucleotidase 2", other_designations="Golgi-resident adenosine 3',5'-bisphosphate 3'-phosphatase|Golgi 3-prime phosphoadenosine 5-prime phosphate 3-prime phosphatase|IMPase 3|golgi-resident PAP phosphatase|golgi-resident nucleotide phosphatase|inositol monophosphatase domain containing 1|inositol monophosphatase domain-containing protein 1|inositol-1(or 4)-monophosphatase 3|myo-inositol monophosphatase A3|phosphoadenosine phosphate 3'-nucleotidase", map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56957931, end_position_on_the_genomic_accession=56993874, orientation='minus', exon_count=6, OMIM=[614010], no_hdr0=''),
    54929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54929, CurrentID=0, Status='live', Symbol='TMEM161A', Aliases=['AROS-29', 'AROS29'], description='transmembrane protein 161A', other_designations='transmembrane protein 161A|adaptive response to oxidative stress protein 29', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19119169, end_position_on_the_genomic_accession=19138478, orientation='minus', exon_count=13, OMIM=[618966], no_hdr0=''),
    54930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54930, CurrentID=0, Status='live', Symbol='HAUS4', Aliases=['C14orf94'], description='HAUS augmin like complex subunit 4', other_designations='HAUS augmin-like complex subunit 4|homologous to Augmin subunits', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22946228, end_position_on_the_genomic_accession=22957090, orientation='minus', exon_count=10, OMIM=[613431], no_hdr0=''),
    54931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54931, CurrentID=0, Status='live', Symbol='TRMT10C', Aliases=['COXPD30', 'HNYA', 'MRPP1', 'RG9MTD1'], description='tRNA methyltransferase 10C, mitochondrial RNase P subunit', other_designations='tRNA methyltransferase 10 homolog C|HBV pre-S2 trans-regulated protein 2|RNA (guanine-9-) methyltransferase domain containing 1|mRNA methyladenosine-N(1)-methyltransferase|mitochondrial RNase P subunit 1|mitochondrial ribonuclease P protein 1|renal carcinoma antigen NY-REN-49|tRNA (adenine(9)-N(1))-methyltransferase|tRNA (guanine(9)-N(1))-methyltransferase', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101561868, end_position_on_the_genomic_accession=101566446, orientation='plus', exon_count=2, OMIM=[615423], no_hdr0=''),
    54932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54932, CurrentID=0, Status='live', Symbol='EXD3', Aliases=['Nbr', 'mut-7'], description="exonuclease 3'-5' domain containing 3", other_designations="exonuclease mut-7 homolog|exonuclease 3'-5' domain-containing protein 3|nibbler homolog|testicular tissue protein Li 125", map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137306896, end_position_on_the_genomic_accession=137423262, orientation='minus', exon_count=32, OMIM=[], no_hdr0=''),
    54933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54933, CurrentID=0, Status='live', Symbol='RHBDL2', Aliases=['RRP2'], description='rhomboid like 2', other_designations='rhomboid-related protein 2|rhomboid (veinlet, Drosophila)-like 2|rhomboid protease 2|rhomboid, veinlet-like 2|rhomboid-like protein 2', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38885807, end_position_on_the_genomic_accession=38941830, orientation='minus', exon_count=9, OMIM=[608962], no_hdr0=''),
    54934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54934, CurrentID=0, Status='live', Symbol='KANSL2', Aliases=['C12orf41', 'NSL2'], description='KAT8 regulatory NSL complex subunit 2', other_designations='KAT8 regulatory NSL complex subunit 2|NSL complex protein NSL2|non-specific lethal 2 homolog', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48653211, end_position_on_the_genomic_accession=48682238, orientation='minus', exon_count=10, OMIM=[615488], no_hdr0=''),
    54935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54935, CurrentID=0, Status='live', Symbol='DUSP23', Aliases=['DUSP25', 'LDP-3', 'LDP3', 'MOSP', 'VHZ'], description='dual specificity phosphatase 23', other_designations='dual specificity protein phosphatase 23|VH1-like member Z|VH1-like phosphatase Z|low-molecular-mass dual-specificity phosphatase 3|testicular tissue protein Li 59', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159780962, end_position_on_the_genomic_accession=159782543, orientation='plus', exon_count=2, OMIM=[618361], no_hdr0=''),
    54936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54936, CurrentID=0, Status='live', Symbol='ADPRS', Aliases=['ADPRHL2', 'ARH3', 'CONDSIAS'], description='ADP-ribosylserine hydrolase', other_designations='ADP-ribose glycohydrolase ARH3|ADP-ribosylarginine hydrolase like 2|ADP-ribosylhydrolase 3|ADP-ribosylhydrolase like 2|O-acetyl-ADP-ribose deacetylase ARH3|[Protein ADP-ribosylarginine] hydrolase-like protein 2|[Protein ADP-ribosylserine] hydrolase|poly(ADP-ribose) glycohydrolase ARH3|protein ADP-ribosylarginine hydrolase-like protein 2', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36088885, end_position_on_the_genomic_accession=36093932, orientation='plus', exon_count=6, OMIM=[610624], no_hdr0=''),
    54937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54937, CurrentID=0, Status='live', Symbol='SOHLH2', Aliases=['SOSF2', 'SPATA28', 'TEB1', 'bHLHe81'], description='spermatogenesis and oogenesis specific basic helix-loop-helix 2', other_designations='spermatogenesis- and oogenesis-specific basic helix-loop-helix-containing protein 2|spermatogenesis associated 28|testicular secretory protein Li 50|testicular secretory protein Li 51', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36168217, end_position_on_the_genomic_accession=36214556, orientation='minus', exon_count=12, OMIM=[616066], no_hdr0=''),
    54938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54938, CurrentID=0, Status='live', Symbol='SARS2', Aliases=['SARS', 'SARSM', 'SERS', 'SYS', 'SerRS', 'SerRSmt', 'mtSerRS'], description='seryl-tRNA synthetase 2, mitochondrial', other_designations='serine--tRNA ligase, mitochondrial|mitochondrial seryl-tRNA synthetase|serine tRNA ligase 2, mitochondrial|seryl-tRNA synthetase, mitochondrial|seryl-tRNA(Ser/Sec) synthetase', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38915266, end_position_on_the_genomic_accession=38930763, orientation='minus', exon_count=17, OMIM=[612804], no_hdr0=''),
    54939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54939, CurrentID=0, Status='live', Symbol='COMMD4', Aliases=[], description='COMM domain containing 4', other_designations='COMM domain-containing protein 4', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75336035, end_position_on_the_genomic_accession=75343227, orientation='plus', exon_count=10, OMIM=[616701], no_hdr0=''),
    54940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54940, CurrentID=0, Status='live', Symbol='OCIAD1', Aliases=['ASRIJ', 'OCIA', 'TPA018'], description='OCIA domain containing 1', other_designations='OCIA domain-containing protein 1|ovarian cancer immunoreactive antigen domain containing 1|ovarian cancer immunoreactive antigen domain containing 1A|ovarian carcinoma immunoreactive antigen', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48830924, end_position_on_the_genomic_accession=48861815, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    54941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54941, CurrentID=0, Status='live', Symbol='RNF125', Aliases=['TNORS', 'TRAC-1', 'TRAC1'], description='ring finger protein 125', other_designations='E3 ubiquitin-protein ligase RNF125|T-cell RING activation protein 1|T-cell ring protein identified in activation screen|ring finger protein 125, E3 ubiquitin protein ligase', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32018585, end_position_on_the_genomic_accession=32090756, orientation='plus', exon_count=7, OMIM=[610432], no_hdr0=''),
    54942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54942, CurrentID=0, Status='live', Symbol='ABITRAM', Aliases=['C9orf6', 'CG-8', 'FAM206A', 'Simiate'], description='actin binding transcription modulator', other_designations='protein Abitram|family with sequence similarity 206 member A|protein FAM206A|protein Simiate', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=108934397, end_position_on_the_genomic_accession=108950745, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    54943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54943, CurrentID=0, Status='live', Symbol='DNAJC28', Aliases=['C21orf55', 'C21orf78'], description='DnaJ heat shock protein family (Hsp40) member C28', other_designations='dnaJ homolog subfamily C member 28|DnaJ (Hsp40) homolog, subfamily C, member 28', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33488055, end_position_on_the_genomic_accession=33491716, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    54946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54946, CurrentID=0, Status='live', Symbol='SLC41A3', Aliases=['SLC41A1-L2'], description='solute carrier family 41 member 3', other_designations='solute carrier family 41 member 3|SLC41A1-like 2', map_location='3q21.2-q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126006357, end_position_on_the_genomic_accession=126101550, orientation='minus', exon_count=14, OMIM=[610803], no_hdr0=''),
    54947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54947, CurrentID=0, Status='live', Symbol='LPCAT2', Aliases=['AGPAT11', 'AYTL1', 'LysoPAFAT'], description='lysophosphatidylcholine acyltransferase 2', other_designations='lysophosphatidylcholine acyltransferase 2|1-AGP acyltransferase 11|1-AGPAT 11|1-acylglycerol-3-phosphate O-acyltransferase 11|1-acylglycerophosphocholine O-acyltransferase|1-alkenylglycerophosphocholine O-acyltransferase|1-alkylglycerophosphocholine O-acetyltransferase|LPAAT-alpha|LPC acyltransferase 2|LPCAT-2|acetyl-CoA:lyso-PAF acetyltransferase|acetyl-CoA:lyso-platelet-activating factor acetyltransferase|acyl-CoA:lysophosphatidylcholine acyltransferase 2|acyltransferase-like 1|lyso-PAF acetyltransferase|lyso-platelet-activating factor (PAF) acetyltransferase|lysoPC acyltransferase 2|lysophosphatidic acid acyltransferase alpha', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55509055, end_position_on_the_genomic_accession=55586666, orientation='plus', exon_count=17, OMIM=[612040], no_hdr0=''),
    54948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54948, CurrentID=0, Status='live', Symbol='MRPL16', Aliases=['L16mt', 'MRP-L16', 'PNAS-111'], description='mitochondrial ribosomal protein L16', other_designations='39S ribosomal protein L16, mitochondrial|mitochondrial large ribosomal subunit protein uL16m', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59806140, end_position_on_the_genomic_accession=59810778, orientation='minus', exon_count=4, OMIM=[611829], no_hdr0=''),
    54949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54949, CurrentID=0, Status='live', Symbol='SDHAF2', Aliases=['C11orf79', 'PGL2', 'SDH5'], description='succinate dehydrogenase complex assembly factor 2', other_designations='succinate dehydrogenase assembly factor 2, mitochondrial|SDH assembly factor 2|hSDH5|succinate dehydrogenase subunit 5, mitochondrial', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61430124, end_position_on_the_genomic_accession=61446733, orientation='plus', exon_count=4, OMIM=[613019], no_hdr0=''),
    54951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54951, CurrentID=0, Status='live', Symbol='COMMD8', Aliases=[], description='COMM domain containing 8', other_designations='COMM domain-containing protein 8', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=47450787, end_position_on_the_genomic_accession=47463702, orientation='minus', exon_count=5, OMIM=[616656], no_hdr0=''),
    54952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54952, CurrentID=0, Status='live', Symbol='TRNAU1AP', Aliases=['PRO1902', 'SECP43', 'TRSPAP1'], description='tRNA selenocysteine 1 associated protein 1', other_designations='tRNA selenocysteine 1-associated protein 1|tRNA selenocysteine associated protein (SECP43)|tRNA selenocysteine-associated protein 1', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28553085, end_position_on_the_genomic_accession=28578545, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    54953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54953, CurrentID=0, Status='live', Symbol='ODR4', Aliases=['C1orf27', 'TTG1', 'odr-4'], description='odr-4 GPCR localization factor homolog', other_designations='protein odr-4 homolog|LAG1-interacting protein|odorant response abnormal 4|transactivated by recombinant transforming growth factor beta 1|transactivated by transforming growth factor beta protein 1', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=186375762, end_position_on_the_genomic_accession=186421375, orientation='plus', exon_count=16, OMIM=[609335], no_hdr0=''),
    54954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54954, CurrentID=0, Status='live', Symbol='FAM120C', Aliases=['CXorf17', 'ORF34'], description='family with sequence similarity 120C', other_designations='constitutive coactivator of PPAR-gamma-like protein 2|tumor antigen BJ-HCC-21', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54068324, end_position_on_the_genomic_accession=54183284, orientation='minus', exon_count=18, OMIM=[300741], no_hdr0=''),
    54955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54955, CurrentID=0, Status='live', Symbol='C1orf109', Aliases=[], description='chromosome 1 open reading frame 109', other_designations='uncharacterized protein C1orf109', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37681570, end_position_on_the_genomic_accession=37692336, orientation='minus', exon_count=7, OMIM=[614799], no_hdr0=''),
    54956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54956, CurrentID=0, Status='live', Symbol='PARP16', Aliases=['ARTD15', 'C15orf30', 'pART15'], description='poly(ADP-ribose) polymerase family member 16', other_designations='protein mono-ADP-ribosyltransferase PARP16|ADP-ribosyltransferase diphtheria toxin-like 15|PARP-16|mono [ADP-ribose] polymerase PARP16|poly [ADP-ribose] polymerase 16', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65231691, end_position_on_the_genomic_accession=65286891, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    54957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54957, CurrentID=0, Status='live', Symbol='TXNL4B', Aliases=['DLP', 'Dim2'], description='thioredoxin like 4B', other_designations='thioredoxin-like protein 4B|Dim1-like protein', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72044261, end_position_on_the_genomic_accession=72094378, orientation='minus', exon_count=8, OMIM=[617722], no_hdr0=''),
    54958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54958, CurrentID=0, Status='live', Symbol='TMEM160', Aliases=[], description='transmembrane protein 160', other_designations='transmembrane protein 160', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47045909, end_position_on_the_genomic_accession=47048624, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    54959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54959, CurrentID=0, Status='live', Symbol='ODAM', Aliases=['APIN'], description='odontogenic, ameloblast associated', other_designations='odontogenic ameloblast-associated protein|odontogenic, ameloblast asssociated', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70195725, end_position_on_the_genomic_accession=70204576, orientation='plus', exon_count=12, OMIM=[614843], no_hdr0=''),
    54960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54960, CurrentID=0, Status='live', Symbol='GEMIN8', Aliases=['FAM51A1'], description='gem nuclear organelle associated protein 8', other_designations='gem-associated protein 8|family with sequence similarity 51, member A1|gemin-8', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=14002494, end_position_on_the_genomic_accession=14029918, orientation='minus', exon_count=7, OMIM=[300962], no_hdr0=''),
    54961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54961, CurrentID=0, Status='live', Symbol='SSH3', Aliases=['SSH3L'], description='slingshot protein phosphatase 3', other_designations='protein phosphatase Slingshot homolog 3|SSH-3L|SSH-like protein 3|hSSH-3L|slingshot 3|slingshot homolog 3', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67303478, end_position_on_the_genomic_accession=67312607, orientation='plus', exon_count=14, OMIM=[606780], no_hdr0=''),
    54962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54962, CurrentID=0, Status='live', Symbol='TIPIN', Aliases=[], description='TIMELESS interacting protein', other_designations='TIMELESS-interacting protein|CSM3 homolog', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66334974, end_position_on_the_genomic_accession=66387273, orientation='minus', exon_count=12, OMIM=[610716], no_hdr0=''),
    54963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54963, CurrentID=0, Status='live', Symbol='UCKL1', Aliases=['UCK1L', 'URKL1'], description='uridine-cytidine kinase 1 like 1', other_designations='uridine-cytidine kinase-like 1|UCK1-LIKE', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63939829, end_position_on_the_genomic_accession=63956447, orientation='minus', exon_count=20, OMIM=[610866], no_hdr0=''),
    54964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54964, CurrentID=0, Status='live', Symbol='C1orf56', Aliases=['MENT'], description='chromosome 1 open reading frame 56', other_designations='protein MENT|methylated in normal thymocytes protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151047751, end_position_on_the_genomic_accession=151051420, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    54965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54965, CurrentID=0, Status='live', Symbol='PIGX', Aliases=['PIG-X'], description='phosphatidylinositol glycan anchor biosynthesis class X', other_designations='phosphatidylinositol-glycan biosynthesis class X protein|GPI-mannosyltransferase subunit', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196712377, end_position_on_the_genomic_accession=196736007, orientation='plus', exon_count=7, OMIM=[610276], no_hdr0=''),
    54967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54967, CurrentID=0, Status='live', Symbol='CT55', Aliases=['BJHCC20A', 'CXorf48'], description='cancer/testis antigen 55', other_designations='cancer/testis antigen 55|BRCA2-interacting protein|tumor antigen BJ-HCC-20', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135156536, end_position_on_the_genomic_accession=135171827, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    54968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54968, CurrentID=0, Status='live', Symbol='TMEM70', Aliases=['MC5DN2'], description='transmembrane protein 70', other_designations='transmembrane protein 70, mitochondrial', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73976195, end_position_on_the_genomic_accession=73982783, orientation='plus', exon_count=4, OMIM=[612418], no_hdr0=''),
    54969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54969, CurrentID=0, Status='live', Symbol='HPF1', Aliases=['C4orf27'], description='histone PARylation factor 1', other_designations='histone PARylation factor 1|UPF0609 protein C4orf27', map_location='4q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=169729470, end_position_on_the_genomic_accession=169757944, orientation='minus', exon_count=8, OMIM=[616614], no_hdr0=''),
    54970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54970, CurrentID=0, Status='live', Symbol='TTC12', Aliases=['CILD45', 'TPARM'], description='tetratricopeptide repeat domain 12', other_designations='tetratricopeptide repeat protein 12|TPR repeat protein 12', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113314569, end_position_on_the_genomic_accession=113385952, orientation='plus', exon_count=33, OMIM=[610732], no_hdr0=''),
    54971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54971, CurrentID=0, Status='live', Symbol='BANP', Aliases=['BEND1', 'SMAR1', 'SMARBP1'], description='BTG3 associated nuclear protein', other_designations='protein BANP|BEN domain-containing protein 1|scaffold/matrix-associated region-1-binding protein', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87949216, end_position_on_the_genomic_accession=88077318, orientation='plus', exon_count=31, OMIM=[611564], no_hdr0=''),
    54972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54972, CurrentID=0, Status='live', Symbol='TMEM132A', Aliases=['GBP', 'HSPA5BP1'], description='transmembrane protein 132A', other_designations='transmembrane protein 132A|GRP78-binding protein|HSPA5-binding protein 1|glucose-regulated protein, 78kDa|heat shock 70kDa protein 5 (glucose-regulated protein, 78kDa) binding protein 1|heat shock 70kDa protein 5 binding protein 1', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60924460, end_position_on_the_genomic_accession=60937159, orientation='plus', exon_count=11, OMIM=[617363], no_hdr0=''),
    54973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54973, CurrentID=0, Status='live', Symbol='INTS11', Aliases=['CPSF3L', 'CPSF73L', 'INT11', 'RC-68', 'RC68'], description='integrator complex subunit 11', other_designations='integrator complex subunit 11|CPSF3-like protein|cleavage and polyadenylation specific factor 3-like|cleavage and polyadenylation-specific factor 3-like protein|protein related to CPSF subunits of 68 kDa|related to CPSF subunits 68 kDa', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1311597, end_position_on_the_genomic_accession=1324660, orientation='minus', exon_count=19, OMIM=[611354], no_hdr0=''),
    54974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54974, CurrentID=0, Status='live', Symbol='THG1L', Aliases=['ICF45', 'IHG-1', 'IHG1', 'SCAR28', 'THG1', 'hTHG1'], description='tRNA-histidine guanylyltransferase 1 like', other_designations='probable tRNA(His) guanylyltransferase|induced by high glucose-1|induced in high glucose-1|interphase cytoplasmic foci protein 45', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157731420, end_position_on_the_genomic_accession=157741449, orientation='plus', exon_count=8, OMIM=[618802], no_hdr0=''),
    54976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54976, CurrentID=0, Status='live', Symbol='C20orf27', Aliases=[], description='chromosome 20 open reading frame 27', other_designations='UPF0687 protein C20orf27', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3753508, end_position_on_the_genomic_accession=3768388, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    54977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54977, CurrentID=0, Status='live', Symbol='SLC25A38', Aliases=['SIDBA2'], description='solute carrier family 25 member 38', other_designations='mitochondrial glycine transporter|appoptosin|mitochondrial glycine transporter GlyC', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39383353, end_position_on_the_genomic_accession=39397351, orientation='plus', exon_count=10, OMIM=[610819], no_hdr0=''),
    54978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54978, CurrentID=0, Status='live', Symbol='SLC35F6', Aliases=['ANT2BP', 'C2orf18', 'TANGO9'], description='solute carrier family 35 member F6', other_designations='solute carrier family 35 member F6|ANT2-binding protein|transmembrane protein C2orf18|transport and golgi organization 9 homolog', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26764284, end_position_on_the_genomic_accession=26781231, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    54979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54979, CurrentID=0, Status='live', Symbol='PLAAT2', Aliases=['HRASLS2', 'PLA1/2-2', 'PLAAT-2'], description='phospholipase A and acyltransferase 2', other_designations='phospholipase A and acyltransferase 2|HRAS like suppressor 2|phospholipase A/acyltransferase-2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63552759, end_position_on_the_genomic_accession=63565072, orientation='minus', exon_count=6, OMIM=[613866], no_hdr0=''),
    54980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54980, CurrentID=0, Status='live', Symbol='C2orf42', Aliases=[], description='chromosome 2 open reading frame 42', other_designations='uncharacterized protein C2orf42', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70149885, end_position_on_the_genomic_accession=70191026, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    54981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54981, CurrentID=0, Status='live', Symbol='NMRK1', Aliases=['C9orf95', 'NRK1', 'bA235O14.2'], description='nicotinamide riboside kinase 1', other_designations='nicotinamide riboside kinase 1|NRK 1|RNK 1|nicotinic acid riboside kinase 1|nmR-K 1|ribosylnicotinamide kinase 1|ribosylnicotinic acid kinase 1', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=75060577, end_position_on_the_genomic_accession=75088319, orientation='minus', exon_count=13, OMIM=[608704], no_hdr0=''),
    54982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54982, CurrentID=0, Status='live', Symbol='CLN6', Aliases=['CLN4A', 'HsT18960', 'nclf'], description='CLN6 transmembrane ER protein', other_designations='ceroid-lipofuscinosis neuronal protein 6|ceroid-lipofuscinosis neuronal 6 late infantile|ceroid-lipofuscinosis, neuronal 6, late infantile', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68206992, end_position_on_the_genomic_accession=68229728, orientation='minus', exon_count=7, OMIM=[606725], no_hdr0=''),
    54984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54984, CurrentID=0, Status='live', Symbol='PINX1', Aliases=['Gno1', 'LPTL', 'LPTS', 'Pxr1'], description='PIN2 (TERF1) interacting telomerase inhibitor 1', other_designations='PIN2/TERF1-interacting telomerase inhibitor 1|67-11-3 protein|PIN2-interacting protein 1|TRF1-interacting protein 1|hepatocellular carcinoma-related putative tumor suppressor|liver-related putative tumor suppressor|pin2-interacting protein X1|protein 67-11-3', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10764961, end_position_on_the_genomic_accession=10839875, orientation='minus', exon_count=7, OMIM=[606505], no_hdr0=''),
    54985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54985, CurrentID=0, Status='live', Symbol='HCFC1R1', Aliases=['HPIP'], description='host cell factor C1 regulator 1', other_designations='host cell factor C1 regulator 1|HCF-1 beta-propeller-interacting protein|host cell factor C1 regulator 1 (XPO1 dependent)', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3022620, end_position_on_the_genomic_accession=3024286, orientation='minus', exon_count=5, OMIM=[618818], no_hdr0=''),
    54986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54986, CurrentID=0, Status='live', Symbol='ULK4', Aliases=['FAM7C1', 'REC01035'], description='unc-51 like kinase 4', other_designations='serine/threonine-protein kinase ULK4', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=41246599, end_position_on_the_genomic_accession=41962103, orientation='minus', exon_count=40, OMIM=[617010], no_hdr0=''),
    54987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54987, CurrentID=0, Status='live', Symbol='CZIB', Aliases=['C1orf123'], description='CXXC motif containing zinc binding protein', other_designations='CXXC motif containing zinc binding protein|UPF0587 protein C1orf123', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53214099, end_position_on_the_genomic_accession=53220634, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    54988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54988, CurrentID=0, Status='live', Symbol='ACSM5', Aliases=[], description='acyl-CoA synthetase medium chain family member 5', other_designations='acyl-coenzyme A synthetase ACSM5, mitochondrial', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20409534, end_position_on_the_genomic_accession=20441336, orientation='plus', exon_count=14, OMIM=[614361], no_hdr0=''),
    54989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54989, CurrentID=0, Status='live', Symbol='ZNF770', Aliases=['PRO1914'], description='zinc finger protein 770', other_designations='zinc finger protein 770', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34978341, end_position_on_the_genomic_accession=34988287, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    54991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54991, CurrentID=0, Status='live', Symbol='C1orf159', Aliases=[], description='chromosome 1 open reading frame 159', other_designations='uncharacterized protein C1orf159', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1081823, end_position_on_the_genomic_accession=1116089, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    54993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54993, CurrentID=0, Status='live', Symbol='ZSCAN2', Aliases=['ZFP29', 'ZNF854'], description='zinc finger and SCAN domain containing 2', other_designations='zinc finger and SCAN domain-containing protein 2|zfp-29|zinc finger protein 29 homolog|zinc finger protein 854', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84601009, end_position_on_the_genomic_accession=84623718, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    54994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54994, CurrentID=0, Status='live', Symbol='GID8', Aliases=['C20orf11', 'TWA1'], description='GID complex subunit 8 homolog', other_designations='glucose-induced degradation protein 8 homolog|protein C20orf11|two hybrid associated protein No. 1 with RanBPM|two hybrid-associated protein 1 with RanBPM', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62938147, end_position_on_the_genomic_accession=62948475, orientation='plus', exon_count=5, OMIM=[611625], no_hdr0=''),
    54995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54995, CurrentID=0, Status='live', Symbol='OXSM', Aliases=['CEM1', 'FASN2D', 'KASI', 'KS'], description='3-oxoacyl-ACP synthase, mitochondrial', other_designations='3-oxoacyl-[acyl-carrier-protein] synthase, mitochondrial|3-ketoacyl-acyl carrier protein synthase|3-oxoacyl-acyl-carrier-protein synthase|acyl-malonyl acyl carrier protein-condensing enzyme|beta-ketoacyl synthase|beta-ketoacyl-ACP synthase|type II mitochondrial beta-ketoacyl synthase', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=25788283, end_position_on_the_genomic_accession=25794534, orientation='plus', exon_count=3, OMIM=[610324], no_hdr0=''),
    54996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54996, CurrentID=0, Status='live', Symbol='MTARC2', Aliases=['MARC2', 'MOSC2'], description='mitochondrial amidoxime reducing component 2', other_designations='mitochondrial amidoxime reducing component 2|MOCO sulphurase C-terminal domain containing 2|MOSC domain-containing protein 2, mitochondrial|moco sulfurase C-terminal domain-containing protein 2|molybdenum cofactor sulfurase C-terminal domain-containing protein 2', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220747417, end_position_on_the_genomic_accession=220784815, orientation='plus', exon_count=10, OMIM=[614127], no_hdr0=''),
    54997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54997, CurrentID=0, Status='live', Symbol='TESC', Aliases=['CHP3', 'TSC'], description='tescalcin', other_designations='calcineurin B homologous protein 3|calcineurin-like EF hand protein 3', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=117038923, end_position_on_the_genomic_accession=117099490, orientation='minus', exon_count=9, OMIM=[611585], no_hdr0=''),
    54998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=54998, CurrentID=0, Status='live', Symbol='AURKAIP1', Aliases=['AIP', 'AKIP', 'MRP-S38'], description='aurora kinase A interacting protein 1', other_designations='aurora kinase A-interacting protein|28S ribosomal protein S38, mitochondrial|AURKA-interacting protein|aurora-A kinase interacting protein|mitochondrial small ribosomal subunit protein mS38', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1373730, end_position_on_the_genomic_accession=1375516, orientation='minus', exon_count=4, OMIM=[609183], no_hdr0=''),
    55001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55001, CurrentID=0, Status='live', Symbol='TTC22', Aliases=[], description='tetratricopeptide repeat domain 22', other_designations='tetratricopeptide repeat protein 22|TPR repeat protein 22', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54779696, end_position_on_the_genomic_accession=54802379, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55002, CurrentID=0, Status='live', Symbol='TMCO3', Aliases=['C13orf11'], description='transmembrane and coiled-coil domains 3', other_designations='transmembrane and coiled-coil domain-containing protein 3|putative LAG1-interacting protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113490993, end_position_on_the_genomic_accession=113550229, orientation='plus', exon_count=23, OMIM=[617134], no_hdr0=''),
    55003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55003, CurrentID=0, Status='live', Symbol='PAK1IP1', Aliases=['MAK11', 'PIP1', 'WDR84', 'bA421M1.5', 'hPIP1'], description='PAK1 interacting protein 1', other_designations='p21-activated protein kinase-interacting protein 1|PAK/PLC-interacting protein 1|WD repeat-containing protein 84', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10690865, end_position_on_the_genomic_accession=10709782, orientation='plus', exon_count=12, OMIM=[607811], no_hdr0=''),
    55004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55004, CurrentID=0, Status='live', Symbol='LAMTOR1', Aliases=['C11orf59', 'PDRO', 'Ragulator1', 'p18', 'p27RF-Rho'], description='late endosomal/lysosomal adaptor, MAPK and MTOR activator 1', other_designations='ragulator complex protein LAMTOR1|RhoA activator C11orf59|late endosomal/lysosomal adaptor and MAPK and MTOR activator 1|lipid raft adaptor protein p18|p27Kip1-releasing factor from RhoA|p27kip1 releasing factor from RhoA|protein associated with DRMs and endosomes|ragulator complex protein PDRO', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72097292, end_position_on_the_genomic_accession=72103297, orientation='minus', exon_count=5, OMIM=[613510], no_hdr0=''),
    55005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55005, CurrentID=0, Status='live', Symbol='RMND1', Aliases=['C6orf96', 'COXPD11', 'RMD1', 'bA351K16', 'bA351K16.3'], description='required for meiotic nuclear division 1 homolog', other_designations='required for meiotic nuclear division protein 1 homolog', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151404548, end_position_on_the_genomic_accession=151452169, orientation='minus', exon_count=14, OMIM=[614917], no_hdr0=''),
    55006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55006, CurrentID=0, Status='live', Symbol='TRMT61B', Aliases=[], description='tRNA methyltransferase 61B', other_designations='tRNA (adenine(58)-N(1))-methyltransferase, mitochondrial|mRNA methyladenosine-N(1)-methyltransferase|potential tRNA (adenine(58)-N(1))-methyltransferase catalytic subunit TRMT61B|potential tRNA (adenine-N(1)-)-methyltransferase catalytic subunit TRMT61B|tRNA methyltransferase 61 homolog B', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28849821, end_position_on_the_genomic_accession=28870360, orientation='minus', exon_count=8, OMIM=[619404], no_hdr0=''),
    55007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55007, CurrentID=0, Status='live', Symbol='FAM118A', Aliases=['C22orf8'], description='family with sequence similarity 118 member A', other_designations='protein FAM118A|bK268H5.C22.4', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=45308960, end_position_on_the_genomic_accession=45341955, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    55008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55008, CurrentID=0, Status='live', Symbol='HERC6', Aliases=[], description='HECT and RLD domain containing E3 ubiquitin protein ligase family member 6', other_designations='probable E3 ubiquitin-protein ligase HERC6|HECT domain and RCC1-like domain-containing protein 6|HECT-type E3 ubiquitin transferase HERC6|hect domain and RLD 6|potential ubiquitin ligase', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88378485, end_position_on_the_genomic_accession=88443097, orientation='plus', exon_count=23, OMIM=[609249], no_hdr0=''),
    55009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55009, CurrentID=0, Status='live', Symbol='FAM174C', Aliases=['C19orf24'], description='family with sequence similarity 174 member C', other_designations='protein FAM174C', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1275530, end_position_on_the_genomic_accession=1279228, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    55010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55010, CurrentID=0, Status='live', Symbol='PARPBP', Aliases=['AROM', 'C12orf48', 'PARI'], description='PARP1 binding protein', other_designations='PCNA-interacting partner', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102120183, end_position_on_the_genomic_accession=102197520, orientation='plus', exon_count=17, OMIM=[613687], no_hdr0=''),
    55011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55011, CurrentID=0, Status='live', Symbol='PIH1D1', Aliases=['DNAAF14', 'MOT48', 'NOP17', 'Pih1'], description='PIH1 domain containing 1', other_designations='PIH1 domain-containing protein 1|nucleolar protein 17 homolog', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49446298, end_position_on_the_genomic_accession=49452392, orientation='minus', exon_count=9, OMIM=[611480], no_hdr0=''),
    55012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55012, CurrentID=0, Status='live', Symbol='PPP2R3C', Aliases=['C14orf10', 'G4-1', 'G5pr', 'GDRM', 'SPGF36'], description="protein phosphatase 2 regulatory subunit B''gamma", other_designations="serine/threonine-protein phosphatase 2A regulatory subunit B'' subunit gamma|protein phosphatase 2 (formerly 2A), regulatory subunit B''|protein phosphatase 2, regulatory subunit B'', gamma|protein phosphatase subunit G5PR|rhabdomyosarcoma antigen MU-RMS-40.6A|rhabdomyosarcoma antigen Mu-RMS-40.6C", map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35085472, end_position_on_the_genomic_accession=35122662, orientation='minus', exon_count=16, OMIM=[615902], no_hdr0=''),
    55013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55013, CurrentID=0, Status='live', Symbol='MCUB', Aliases=['CCDC109B'], description='mitochondrial calcium uniporter dominant negative subunit beta', other_designations='calcium uniporter regulatory subunit MCUb, mitochondrial|coiled-coil domain containing 109B|coiled-coil domain-containing protein 109B|mitochondrial calcium uniporter dominant negative beta subunit|mitochondrial calcium uniporter regulatory subunit MCUb', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109560246, end_position_on_the_genomic_accession=109688719, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    55014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55014, CurrentID=0, Status='live', Symbol='STX17', Aliases=[], description='syntaxin 17', other_designations='syntaxin-17', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99906654, end_position_on_the_genomic_accession=99974541, orientation='plus', exon_count=12, OMIM=[604204], no_hdr0=''),
    55015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55015, CurrentID=0, Status='live', Symbol='PRPF39', Aliases=[], description='pre-mRNA processing factor 39', other_designations='pre-mRNA-processing factor 39|PRP39 homolog|PRP39 pre-mRNA processing factor 39 homolog', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=45084116, end_position_on_the_genomic_accession=45116282, orientation='plus', exon_count=14, OMIM=[614907], no_hdr0=''),
    55016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55016, CurrentID=0, Status='live', Symbol='MARCHF1', Aliases=['MARCH-I', 'MARCH1', 'RNF171'], description='membrane associated ring-CH-type finger 1', other_designations='E3 ubiquitin-protein ligase MARCHF1|E3 ubiquitin-protein ligase MARCH1|RING finger protein 171|RING-type E3 ubiquitin transferase MARCH1|RING-type E3 ubiquitin transferase MARCHF1|membrane associated ring finger 1|membrane-associated RING finger protein 1|membrane-associated RING-CH protein I|membrane-associated ring finger (C3HC4) 1, E3 ubiquitin protein ligase', map_location='4q32.2-q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163524298, end_position_on_the_genomic_accession=164384050, orientation='minus', exon_count=12, OMIM=[613331], no_hdr0=''),
    55017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55017, CurrentID=0, Status='live', Symbol='C14orf119', Aliases=[], description='chromosome 14 open reading frame 119', other_designations='uncharacterized protein C14orf119|My028 protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23095505, end_position_on_the_genomic_accession=23100456, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    55018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55018, CurrentID=0, Status='live', Symbol='ANKRD40CL', Aliases=['C17orf73', 'LINC00483'], description='ANKRD40 C-terminal like', other_designations='putative ANKRD40 C-terminal-like protein|long intergenic non-protein coding RNA 483', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50761030, end_position_on_the_genomic_accession=50767577, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    55020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55020, CurrentID=0, Status='live', Symbol='TTC38', Aliases=['LL22NC03-5H6.5'], description='tetratricopeptide repeat domain 38', other_designations='tetratricopeptide repeat protein 38|TPR repeat protein 38', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46267966, end_position_on_the_genomic_accession=46294008, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    55022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55022, CurrentID=0, Status='live', Symbol='PID1', Aliases=['HMFN2073', 'NYGGF4', 'P-CLI1', 'PCLI1'], description='phosphotyrosine interaction domain containing 1', other_designations='PTB-containing, cubilin and LRP1-interacting protein|phosphotyrosine interaction domain-containing protein 1', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=229023973, end_position_on_the_genomic_accession=229271287, orientation='minus', exon_count=7, OMIM=[612930], no_hdr0=''),
    55023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55023, CurrentID=0, Status='live', Symbol='PHIP', Aliases=['BRWD2', 'CHUJANS', 'DCAF14', 'DIDOD', 'WDR11', 'ndrp'], description='pleckstrin homology domain interacting protein', other_designations='PH-interacting protein|DDB1 and CUL4 associated factor 14|IRS-1 PH domain-binding protein|WD repeat-containing protein 11', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=78934419, end_position_on_the_genomic_accession=79078294, orientation='minus', exon_count=42, OMIM=[612870], no_hdr0=''),
    55024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55024, CurrentID=0, Status='live', Symbol='BANK1', Aliases=['BANK'], description='B cell scaffold protein with ankyrin repeats 1', other_designations='B-cell scaffold protein with ankyrin repeats', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=101790482, end_position_on_the_genomic_accession=102074812, orientation='plus', exon_count=19, OMIM=[610292], no_hdr0=''),
    55026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55026, CurrentID=0, Status='live', Symbol='TMEM255A', Aliases=['FAM70A'], description='transmembrane protein 255A', other_designations='transmembrane protein 255A|family with sequence similarity 70, member A|protein FAM70A', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120250984, end_position_on_the_genomic_accession=120311536, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    55027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55027, CurrentID=0, Status='live', Symbol='HEATR3', Aliases=['SYO1'], description='HEAT repeat containing 3', other_designations='HEAT repeat-containing protein 3|symportin 1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50065941, end_position_on_the_genomic_accession=50107272, orientation='plus', exon_count=17, OMIM=[614951], no_hdr0=''),
    55028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55028, CurrentID=0, Status='live', Symbol='C17orf80', Aliases=['HLC-8', 'MIG3', 'SPEP1'], description='chromosome 17 open reading frame 80', other_designations='uncharacterized protein C17orf80|cell migration-inducing gene 3 protein|human lung cancer oncogene 8 protein|lung cancer-related protein 8|sperm-expressed protein 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73232433, end_position_on_the_genomic_accession=73248959, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    55030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55030, CurrentID=0, Status='live', Symbol='FBXO34', Aliases=['CGI-301', 'Fbx34'], description='F-box protein 34', other_designations='F-box only protein 34|protein CGI-301', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55271421, end_position_on_the_genomic_accession=55353611, orientation='plus', exon_count=7, OMIM=[609104], no_hdr0=''),
    55031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55031, CurrentID=0, Status='live', Symbol='USP47', Aliases=['TRFP'], description='ubiquitin specific peptidase 47', other_designations='ubiquitin carboxyl-terminal hydrolase 47|Trf (TATA binding protein-related factor)-proximal homolog|deubiquitinating enzyme 47|ubiquitin thioesterase 47|ubiquitin thiolesterase 47|ubiquitin-specific-processing protease 47', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=11841972, end_position_on_the_genomic_accession=11961887, orientation='plus', exon_count=31, OMIM=[614460], no_hdr0=''),
    55032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55032, CurrentID=0, Status='live', Symbol='SLC35A5', Aliases=[], description='solute carrier family 35 member A5', other_designations='probable UDP-sugar transporter protein SLC35A5', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112561320, end_position_on_the_genomic_accession=112585579, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    55033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55033, CurrentID=0, Status='live', Symbol='FKBP14', Aliases=['EDSKMH', 'EDSKSCL2', 'FKBP22', 'IPBP12'], description='FKBP prolyl isomerase 14', other_designations='peptidyl-prolyl cis-trans isomerase FKBP14|22 kDa FK506-binding protein|22 kDa FKBP|FK506 binding protein 14, 22 kDa|FK506-binding protein 14|FKBP-22|PPIase FKBP14|rotamase', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30010587, end_position_on_the_genomic_accession=30026702, orientation='minus', exon_count=5, OMIM=[614505], no_hdr0=''),
    55034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55034, CurrentID=0, Status='live', Symbol='MOCOS', Aliases=['HMCS', 'MCS', 'MOS'], description='molybdenum cofactor sulfurase', other_designations='molybdenum cofactor sulfurase', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36187497, end_position_on_the_genomic_accession=36272157, orientation='plus', exon_count=15, OMIM=[613274], no_hdr0=''),
    55035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55035, CurrentID=0, Status='live', Symbol='NOL8', Aliases=['C9orf34', 'NOP132', 'bA62C3.3', 'bA62C3.4'], description='nucleolar protein 8', other_designations='nucleolar protein 8|nucleolar protein Nop132', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92297358, end_position_on_the_genomic_accession=92325994, orientation='minus', exon_count=20, OMIM=[611534], no_hdr0=''),
    55036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55036, CurrentID=0, Status='live', Symbol='CCDC40', Aliases=['CFAP172', 'CILD15', 'FAP172'], description='coiled-coil domain containing 40', other_designations='coiled-coil domain-containing protein 40', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80036632, end_position_on_the_genomic_accession=80100613, orientation='plus', exon_count=27, OMIM=[613799], no_hdr0=''),
    55037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55037, CurrentID=0, Status='live', Symbol='PTCD3', Aliases=['COXPD51', 'MRP-S39'], description='pentatricopeptide repeat domain 3', other_designations='pentatricopeptide repeat domain-containing protein 3, mitochondrial|28S ribosomal protein S39, mitochondrial|TRG-15|mitochondrial small ribosomal subunit protein mS39|pentatricopeptide repeat-containing protein 3, mitochondrial|transformation-related gene 15 protein', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86106235, end_position_on_the_genomic_accession=86142157, orientation='plus', exon_count=24, OMIM=[614918], no_hdr0=''),
    55038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55038, CurrentID=0, Status='live', Symbol='CDCA4', Aliases=['HEPP', 'SEI-3/HEPP'], description='cell division cycle associated 4', other_designations='cell division cycle-associated protein 4|hematopoietic progenitor protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105009573, end_position_on_the_genomic_accession=105021083, orientation='minus', exon_count=3, OMIM=[612270], no_hdr0=''),
    55039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55039, CurrentID=0, Status='live', Symbol='TRMT12', Aliases=['TRM12', 'TYW2'], description='tRNA methyltransferase 12 homolog', other_designations='tRNA wybutosine-synthesizing protein 2 homolog|alpha-amino-alpha-carboxypropyl transferase TYW2|homolog of yeast tRNA methyltransferase|tRNA methyltranferase 12 homolog|tRNA(Phe) (4-demethylwyosine(37)-C(7)) aminocarboxypropyltransferase|tRNA-yW-synthesizing protein 2', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124450820, end_position_on_the_genomic_accession=124453026, orientation='plus', exon_count=1, OMIM=[611244], no_hdr0=''),
    55040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55040, CurrentID=0, Status='live', Symbol='EPN3', Aliases=[], description='epsin 3', other_designations='epsin-3|EPS-15-interacting protein 3', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50532735, end_position_on_the_genomic_accession=50543750, orientation='plus', exon_count=10, OMIM=[607264], no_hdr0=''),
    55041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55041, CurrentID=0, Status='live', Symbol='PLEKHB2', Aliases=['EVT2'], description='pleckstrin homology domain containing B2', other_designations='pleckstrin homology domain-containing family B member 2|PH domain-containing family B member 2|evectin-2|pleckstrin homology domain containing, family B (evectins) member 2', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131104847, end_position_on_the_genomic_accession=131149847, orientation='plus', exon_count=11, OMIM=[618452], no_hdr0=''),
    55048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55048, CurrentID=0, Status='live', Symbol='VPS37C', Aliases=[], description='VPS37C subunit of ESCRT-I', other_designations='vacuolar protein sorting-associated protein 37C|ESCRT-I complex subunit VPS37C|VPS37C, ESCRT-I subunit|hVps37C|vacuolar protein sorting 37 homolog C|vacuolar protein sorting 37C', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61130257, end_position_on_the_genomic_accession=61161426, orientation='minus', exon_count=7, OMIM=[610038], no_hdr0=''),
    55049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55049, CurrentID=0, Status='live', Symbol='REX1BD', Aliases=['C19orf60'], description='required for excision 1-B domain containing', other_designations='required for excision 1-B domain-containing protein|uncharacterized protein C19orf60', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18588798, end_position_on_the_genomic_accession=18592337, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    55051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55051, CurrentID=0, Status='live', Symbol='NRDE2', Aliases=['C14orf102'], description='NRDE-2, necessary for RNA interference, domain containing', other_designations='nuclear exosome regulator NRDE2|UPF0614 protein C14orf102|protein NRDE2 homolog', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90267860, end_position_on_the_genomic_accession=90331969, orientation='minus', exon_count=16, OMIM=[618631], no_hdr0=''),
    55052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55052, CurrentID=0, Status='live', Symbol='MRPL20', Aliases=['L20mt', 'MRP-L20'], description='mitochondrial ribosomal protein L20', other_designations='39S ribosomal protein L20, mitochondrial|mitochondrial large ribosomal subunit protein bL20m', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1401909, end_position_on_the_genomic_accession=1407293, orientation='minus', exon_count=4, OMIM=[611833], no_hdr0=''),
    55054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55054, CurrentID=0, Status='live', Symbol='ATG16L1', Aliases=['APG16L', 'ATG16A', 'ATG16L', 'IBD10', 'WDR30'], description='autophagy related 16 like 1', other_designations='autophagy-related protein 16-1|APG16L beta|ATG16 autophagy related 16-like 1|WD repeat domain 30', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233251647, end_position_on_the_genomic_accession=233295674, orientation='plus', exon_count=19, OMIM=[610767], no_hdr0=''),
    55055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55055, CurrentID=0, Status='live', Symbol='ZWILCH', Aliases=['KNTC1AP', 'hZwilch'], description='zwilch kinetochore protein', other_designations='protein zwilch homolog|Zwilch, kinetochore associated, homolog|homolog of Drosophila Zwilch', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66505126, end_position_on_the_genomic_accession=66550130, orientation='plus', exon_count=20, OMIM=[609984], no_hdr0=''),
    55057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55057, CurrentID=0, Status='live', Symbol='CRYBG2', Aliases=['AIM1L'], description='crystallin beta-gamma domain containing 2', other_designations='beta/gamma crystallin domain-containing protein 2|absent in melanoma 1 like|absent in melanoma 1-like protein|beta-gamma crystallin domain containing 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26321860, end_position_on_the_genomic_accession=26354130, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    55061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55061, CurrentID=0, Status='live', Symbol='SUSD4', Aliases=['PRO222'], description='sushi domain containing 4', other_designations='sushi domain-containing protein 4|YHGM196|testicular secretory protein Li 55', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223220826, end_position_on_the_genomic_accession=223365271, orientation='minus', exon_count=15, OMIM=[615827], no_hdr0=''),
    55062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55062, CurrentID=0, Status='live', Symbol='WIPI1', Aliases=['ATG18', 'ATG18A', 'WIPI49'], description='WD repeat domain, phosphoinositide interacting 1', other_designations='WD repeat domain phosphoinositide-interacting protein 1|WIPI-1 alpha|atg18 protein homolog', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=68421281, end_position_on_the_genomic_accession=68457496, orientation='minus', exon_count=14, OMIM=[609224], no_hdr0=''),
    55063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55063, CurrentID=0, Status='live', Symbol='ZCWPW1', Aliases=['ZCW1'], description='zinc finger CW-type and PWWP domain containing 1', other_designations='zinc finger CW-type PWWP domain protein 1|zinc finger CW-type and PWWP domain 1|zinc finger, CW-type with PWWP domain 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100400826, end_position_on_the_genomic_accession=100429996, orientation='minus', exon_count=19, OMIM=[618900], no_hdr0=''),
    55064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55064, CurrentID=0, Status='live', Symbol='SPATA6L', Aliases=['C9orf68', 'bA6J24.2'], description='spermatogenesis associated 6 like', other_designations='spermatogenesis associated 6-like protein', map_location='9p24.2-p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4540643, end_position_on_the_genomic_accession=4666674, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    55065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55065, CurrentID=0, Status='live', Symbol='SLC52A1', Aliases=['GPCR42', 'GPR172B', 'PAR2', 'RBFVD', 'RFT1', 'RFVT1', 'hRFT1', 'huPAR-2'], description='solute carrier family 52 member 1', other_designations='solute carrier family 52, riboflavin transporter, member 1|G protein-coupled receptor 172B|G-protein coupled receptor GPCR42|PERV-A receptor 2|porcine endogenous retrovirus A receptor 2|solute carrier family 52 (riboflavin transporter), member 1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5032602, end_position_on_the_genomic_accession=5035426, orientation='minus', exon_count=5, OMIM=[607883], no_hdr0=''),
    55066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55066, CurrentID=0, Status='live', Symbol='PDPR', Aliases=['PDP3'], description='pyruvate dehydrogenase phosphatase regulatory subunit', other_designations='pyruvate dehydrogenase phosphatase regulatory subunit, mitochondrial', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70113626, end_position_on_the_genomic_accession=70163631, orientation='plus', exon_count=24, OMIM=[617835], no_hdr0=''),
    55068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55068, CurrentID=0, Status='live', Symbol='ENOX1', Aliases=['CNOX', 'PIG38', 'bA64J21.1', 'cCNOX'], description='ecto-NOX disulfide-thiol exchanger 1', other_designations='ecto-NOX disulfide-thiol exchanger 1|candidate growth-related and time keeping constitutive hydroquinone (NADH) oxidase|candidate growth-related and time keeping constitutive hydroquinone [NADH] oxidase|cell proliferation-inducing gene 38 protein|constitutive Ecto-NOX|ecto-NADPH oxidase disulfide-thiol exchanger 1', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=43213130, end_position_on_the_genomic_accession=43786976, orientation='minus', exon_count=28, OMIM=[610914], no_hdr0=''),
    55069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55069, CurrentID=0, Status='live', Symbol='TMEM248', Aliases=['C7orf42'], description='transmembrane protein 248', other_designations='transmembrane protein 248|UPF0458 protein C7orf42', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66921208, end_position_on_the_genomic_accession=66958551, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    55070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55070, CurrentID=0, Status='live', Symbol='DET1', Aliases=[], description='DET1 partner of COP1 E3 ubiquitin ligase', other_designations='DET1 homolog|DET1, COP1 ubiquitin ligase partner|de-etiolated homolog 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88501919, end_position_on_the_genomic_accession=88546703, orientation='minus', exon_count=11, OMIM=[608727], no_hdr0=''),
    55071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55071, CurrentID=0, Status='live', Symbol='C9orf40', Aliases=[], description='chromosome 9 open reading frame 40', other_designations='uncharacterized protein C9orf40', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=74946583, end_position_on_the_genomic_accession=74952912, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    55072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55072, CurrentID=0, Status='live', Symbol='RNF31', Aliases=['HOIP', 'Paul', 'ZIBRA'], description='ring finger protein 31', other_designations='E3 ubiquitin-protein ligase RNF31|HOIL-1-interacting protein|RING-type E3 ubiquitin transferase RNF31|zinc in-between-RING-finger ubiquitin-associated domain protein', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24146875, end_position_on_the_genomic_accession=24160655, orientation='plus', exon_count=22, OMIM=[612487], no_hdr0=''),
    55074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55074, CurrentID=0, Status='live', Symbol='OXR1', Aliases=['CHEGDD', 'Nbla00307', 'TLDC3'], description='oxidation resistance 1', other_designations='oxidation resistance protein 1|TBC/LysM-associated domain containing 3|putative protein product of Nbla00307', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=106270178, end_position_on_the_genomic_accession=106752694, orientation='plus', exon_count=24, OMIM=[605609], no_hdr0=''),
    55075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55075, CurrentID=0, Status='live', Symbol='UACA', Aliases=['NUCLING'], description='uveal autoantigen with coiled-coil domains and ankyrin repeats', other_designations='uveal autoantigen with coiled-coil domains and ankyrin repeats|nuclear membrane binding protein', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=70654554, end_position_on_the_genomic_accession=70778823, orientation='minus', exon_count=22, OMIM=[612516], no_hdr0=''),
    55076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55076, CurrentID=0, Status='live', Symbol='TMEM45A', Aliases=['DERP7', 'DNAPTP4'], description='transmembrane protein 45A', other_designations='transmembrane protein 45A|DNA polymerase-transactivated protein 4|dermal papilla derived protein 7', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100492619, end_position_on_the_genomic_accession=100577446, orientation='plus', exon_count=10, OMIM=[616928], no_hdr0=''),
    55079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55079, CurrentID=0, Status='live', Symbol='FEZF2', Aliases=['FEZ', 'FEZL', 'FKSG36', 'TOF', 'ZFP312', 'ZNF312'], description='FEZ family zinc finger 2', other_designations='fez family zinc finger protein 2|forebrain embryonic zinc finger-like protein 2|testis tissue sperm-binding protein Li 80P|too few|zinc finger protein 312', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=62369681, end_position_on_the_genomic_accession=62373550, orientation='minus', exon_count=5, OMIM=[607414], no_hdr0=''),
    55080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55080, CurrentID=0, Status='live', Symbol='TAPBPL', Aliases=['TAPBP-R', 'TAPBPR'], description='TAP binding protein like', other_designations='tapasin-related protein|TAP binding protein related|TAP-binding protein-related protein|TAPASIN-R|tapasin-like', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6451656, end_position_on_the_genomic_accession=6472006, orientation='plus', exon_count=12, OMIM=[607081], no_hdr0=''),
    55081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55081, CurrentID=0, Status='live', Symbol='IFT57', Aliases=['ESRRBL1', 'HIPPI', 'MHS4R2', 'OFD18'], description='intraflagellar transport 57', other_designations='intraflagellar transport protein 57 homolog|HIP1 protein interactor|HIP1-interacting protein|dermal papilla-derived protein 8|estrogen-related receptor beta like 1|estrogen-related receptor beta-like protein 1|huntingtin interacting protein-1 interacting protein|intraflagellar transport 57 homolog', map_location='3q13.12-q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108160812, end_position_on_the_genomic_accession=108222424, orientation='minus', exon_count=11, OMIM=[606621], no_hdr0=''),
    55082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55082, CurrentID=0, Status='live', Symbol='ARGLU1', Aliases=[], description='arginine and glutamate rich 1', other_designations='arginine and glutamate-rich protein 1', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=106541673, end_position_on_the_genomic_accession=106568164, orientation='minus', exon_count=4, OMIM=[614046], no_hdr0=''),
    55083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55083, CurrentID=0, Status='live', Symbol='KIF26B', Aliases=[], description='kinesin family member 26B', other_designations='kinesin-like protein KIF26B', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=245154985, end_position_on_the_genomic_accession=245709432, orientation='plus', exon_count=15, OMIM=[614026], no_hdr0=''),
    55084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55084, CurrentID=0, Status='live', Symbol='SOBP', Aliases=['JXC1', 'MRAMS'], description='sine oculis binding protein homolog', other_designations='sine oculis-binding protein homolog|jackson circler protein 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107490104, end_position_on_the_genomic_accession=107661306, orientation='plus', exon_count=12, OMIM=[613667], no_hdr0=''),
    55086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55086, CurrentID=0, Status='live', Symbol='RADX', Aliases=['CXorf57'], description='RPA1 related single stranded DNA binding protein, X-linked', other_designations='RPA-related protein RADX|RPA-related and RAD51-antagonist, X-chromosome|RPA-related, RAD51-antagonist on X-chromosome|uncharacterized protein CXorf57', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106611957, end_position_on_the_genomic_accession=106679443, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    55088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55088, CurrentID=0, Status='live', Symbol='CCDC186', Aliases=['C10orf118', 'CCCP-1', 'CCCP1', 'golgin104'], description='coiled-coil domain containing 186', other_designations='coiled-coil domain-containing protein 186|CTCL tumor antigen HD-CL-01/L14-2|CTCL tumor antigen L14-2', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114120862, end_position_on_the_genomic_accession=114174255, orientation='minus', exon_count=18, OMIM=[619249], no_hdr0=''),
    55089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55089, CurrentID=0, Status='live', Symbol='SLC38A4', Aliases=['ATA3', 'NAT3', 'PAAT', 'SNAT4'], description='solute carrier family 38 member 4', other_designations='sodium-coupled neutral amino acid transporter 4|N amino acid transporter 3|Na(+)-coupled neutral amino acid transporter 4|amino acid transporter A3|amino acid transporter system A3|system A amino acid transporter 3|system N amino acid transporter 3', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=46764761, end_position_on_the_genomic_accession=46832422, orientation='minus', exon_count=18, OMIM=[608065], no_hdr0=''),
    55090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55090, CurrentID=0, Status='live', Symbol='MED9', Aliases=['MED25'], description='mediator complex subunit 9', other_designations='mediator of RNA polymerase II transcription subunit 9|mediator of RNA polymerase II transcription, subunit 9 homolog|mediator subunit 25', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17477000, end_position_on_the_genomic_accession=17493221, orientation='plus', exon_count=2, OMIM=[609878], no_hdr0=''),
    55092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55092, CurrentID=0, Status='live', Symbol='TMEM51', Aliases=['C1orf72'], description='transmembrane protein 51', other_designations='transmembrane protein 51', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15152418, end_position_on_the_genomic_accession=15220478, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    55093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55093, CurrentID=0, Status='live', Symbol='NTAQ1', Aliases=['C8orf32', 'WDYHV1'], description='N-terminal glutamine amidase 1', other_designations='protein N-terminal glutamine amidohydrolase|N-terminal Gln amidase|WDYHV motif containing 1|WDYHV motif-containing protein 1|nt(Q)-amidase|protein NH2-terminal glutamine deamidase', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123416701, end_position_on_the_genomic_accession=123467527, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    55094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55094, CurrentID=0, Status='live', Symbol='GPATCH1', Aliases=['ECGP', 'GPATC1'], description='G-patch domain containing 1', other_designations='G patch domain-containing protein 1|evolutionarily conserved G patch domain containing|evolutionarily conserved G-patch domain-containing protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33081168, end_position_on_the_genomic_accession=33130542, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    55095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55095, CurrentID=0, Status='live', Symbol='SAMD4B', Aliases=['SMGB', 'Smaug2'], description='sterile alpha motif domain containing 4B', other_designations='protein Smaug homolog 2|SAM domain-containing protein 4B|smaug 2|smaug homolog B|sterile alpha motif domain-containing protein 4B', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39342421, end_position_on_the_genomic_accession=39390748, orientation='plus', exon_count=19, OMIM=[619231], no_hdr0=''),
    55096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55096, CurrentID=0, Status='live', Symbol='EBLN2', Aliases=['EBLN-2'], description='endogenous Bornavirus like nucleoprotein 2', other_designations='endogenous Bornavirus-like nucleoprotein 2|EBLN-1|endogenous Borna-like N element-1|endogenous Borna-like N element-2', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=73061659, end_position_on_the_genomic_accession=73063337, orientation='plus', exon_count=1, OMIM=[613250], no_hdr0=''),
    55100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55100, CurrentID=0, Status='live', Symbol='WDR70', Aliases=[], description='WD repeat domain 70', other_designations='WD repeat-containing protein 70', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=37379318, end_position_on_the_genomic_accession=37753435, orientation='plus', exon_count=19, OMIM=[617233], no_hdr0=''),
    55101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55101, CurrentID=0, Status='live', Symbol='DMAC2', Aliases=['ATP5SL'], description='distal membrane arm assembly component 2', other_designations='distal membrane-arm assembly complex protein 2|ATP synthase subunit s-like protein|ATP5S like|distal membrane arm assembly complex 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41431318, end_position_on_the_genomic_accession=41447822, orientation='minus', exon_count=8, OMIM=[617262], no_hdr0=''),
    55102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55102, CurrentID=0, Status='live', Symbol='ATG2B', Aliases=['C14orf103'], description='autophagy related 2B', other_designations='autophagy-related protein 2 homolog B|ATG2 autophagy related 2 homolog B', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96279195, end_position_on_the_genomic_accession=96363341, orientation='minus', exon_count=42, OMIM=[616226], no_hdr0=''),
    55103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55103, CurrentID=0, Status='live', Symbol='RALGPS2', Aliases=['dJ595C2.1'], description='Ral GEF with PH domain and SH3 binding motif 2', other_designations='ras-specific guanine nucleotide-releasing factor RalGPS2|Ral-A exchange factor RalGPS2|ral GEF with PH domain and SH3-binding motif 2|ralA exchange factor RalGPS2', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=178725233, end_position_on_the_genomic_accession=178921842, orientation='plus', exon_count=21, OMIM=[617819], no_hdr0=''),
    55105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55105, CurrentID=0, Status='live', Symbol='GPATCH2', Aliases=['CT110', 'GPATC2', 'PPP1R30', 'Pfa1'], description='G-patch domain containing 2', other_designations='G patch domain-containing protein 2|cancer/testis antigen 110|protein phosphatase 1, regulatory subunit 30', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=217426992, end_position_on_the_genomic_accession=217631090, orientation='minus', exon_count=14, OMIM=[616836], no_hdr0=''),
    55106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55106, CurrentID=0, Status='live', Symbol='SLFN12', Aliases=['SLFN3'], description='schlafen family member 12', other_designations='schlafen family member 12', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35407171, end_position_on_the_genomic_accession=35433310, orientation='minus', exon_count=8, OMIM=[614955], no_hdr0=''),
    55107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55107, CurrentID=0, Status='live', Symbol='ANO1', Aliases=['DOG1', 'ORAOV2', 'TAOS2', 'TMEM16A'], description='anoctamin 1', other_designations='anoctamin-1|Ca2+-activated Cl- channel|anoctamin 1, calcium activated chloride channel|calcium activated chloride channel|discovered on gastrointestinal stromal tumors protein 1|oral cancer overexpressed 2|transmembrane protein 16A (eight membrane-spanning domains)|tumor-amplified and overexpressed sequence 2', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69985907, end_position_on_the_genomic_accession=70189530, orientation='plus', exon_count=30, OMIM=[610108], no_hdr0=''),
    55108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55108, CurrentID=0, Status='live', Symbol='BSDC1', Aliases=[], description='BSD domain containing 1', other_designations='BSD domain-containing protein 1', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32364633, end_position_on_the_genomic_accession=32394441, orientation='minus', exon_count=12, OMIM=[617518], no_hdr0=''),
    55109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55109, CurrentID=0, Status='live', Symbol='AGGF1', Aliases=['GPATC7', 'GPATCH7', 'HSU84971', 'HUS84971', 'VG5Q'], description='angiogenic factor with G-patch and FHA domains 1', other_designations='angiogenic factor with G patch and FHA domains 1|G patch domain-containing protein 7|angiogenic factor VG5Q|vasculogenesis gene on 5q protein', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77030404, end_position_on_the_genomic_accession=77065234, orientation='plus', exon_count=14, OMIM=[608464], no_hdr0=''),
    55110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55110, CurrentID=0, Status='live', Symbol='MAGOHB', Aliases=['MGN2', 'mago', 'magoh'], description='mago homolog B, exon junction complex subunit', other_designations='protein mago nashi homolog 2|mago homolog B, exon junction complex core component|mago-nashi homolog B', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10604190, end_position_on_the_genomic_accession=10613609, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    55111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55111, CurrentID=0, Status='live', Symbol='PLEKHJ1', Aliases=['GNRPX'], description='pleckstrin homology domain containing J1', other_designations='pleckstrin homology domain-containing family J member 1|PH domain-containing family J member 1|guanine nucleotide releasing protein x', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2229981, end_position_on_the_genomic_accession=2236724, orientation='minus', exon_count=7, OMIM=[617834], no_hdr0=''),
    55112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55112, CurrentID=0, Status='live', Symbol='DYNC2I1', Aliases=['CFAP163', 'DIC6', 'FAP163', 'SRPS6', 'SRTD8', 'WDR60'], description='dynein 2 intermediate chain 1', other_designations='cytoplasmic dynein 2 intermediate chain 1|WD repeat domain 60|WD repeat-containing protein 60|testicular secretory protein Li 66', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=158839245, end_position_on_the_genomic_accession=158958695, orientation='plus', exon_count=35, OMIM=[615462], no_hdr0=''),
    55113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55113, CurrentID=0, Status='live', Symbol='XKR8', Aliases=['XRG8', 'hXkr8'], description='XK related 8', other_designations='XK-related protein 8|X Kell blood group precursor-related family, member 8|X-linked Kx blood group related 8|XK, Kell blood group complex subunit-related family, member 8', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27959557, end_position_on_the_genomic_accession=27968093, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    55114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55114, CurrentID=0, Status='live', Symbol='ARHGAP17', Aliases=['MST066', 'MST110', 'MSTP038', 'MSTP066', 'MSTP110', 'NADRIN', 'PP367', 'PP4534', 'RICH-1', 'RICH1', 'WBP15'], description='Rho GTPase activating protein 17', other_designations='rho GTPase-activating protein 17|RhoGAP interacting with CIP4 homologs 1|neuron-associated developmentally regulated protein|rho-type GTPase-activating protein 17', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=24919389, end_position_on_the_genomic_accession=25015601, orientation='minus', exon_count=26, OMIM=[608293], no_hdr0=''),
    55116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55116, CurrentID=0, Status='live', Symbol='TMEM39B', Aliases=[], description='transmembrane protein 39B', other_designations='transmembrane protein 39B', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32072031, end_position_on_the_genomic_accession=32102866, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    55117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55117, CurrentID=0, Status='live', Symbol='SLC6A15', Aliases=['NTT73', 'SBAT1', 'V7-3', 'hv7-3'], description='solute carrier family 6 member 15', other_designations='sodium-dependent neutral amino acid transporter B(0)AT2|homolog of rat orphan transporter v7-3|orphan sodium- and chloride-dependent neurotransmitter transporter NTT73|orphan transporter v7-3|sodium- and chloride-dependent neurotransmitter transporter NTT73|sodium-coupled branched-chain amino-acid transporter 1|sodium/chloride dependent neurotransmitter transporter Homo sapiens orphan neurotransmitter transporter NTT7|solute carrier family 6 (neurotransmitter transporter), member 15|solute carrier family 6 (neutral amino acid transporter), member 15|transporter v7-3', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=84859491, end_position_on_the_genomic_accession=84912803, orientation='minus', exon_count=13, OMIM=[607971], no_hdr0=''),
    55118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55118, CurrentID=0, Status='live', Symbol='CRTAC1', Aliases=['ASPIC', 'ASPIC1', 'CEP-68', 'CEP68', 'LOTUS'], description='cartilage acidic protein 1', other_designations='cartilage acidic protein 1|acidic secreted protein in cartilage|chondrocyte expressed protein 68 kDa CEP-68', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97854711, end_position_on_the_genomic_accession=98030621, orientation='minus', exon_count=20, OMIM=[606276], no_hdr0=''),
    55119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55119, CurrentID=0, Status='live', Symbol='PRPF38B', Aliases=['NET1'], description='pre-mRNA processing factor 38B', other_designations='pre-mRNA-splicing factor 38B|PRP38 pre-mRNA processing factor 38 domain containing B|sarcoma antigen NY-SAR-27', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108692310, end_position_on_the_genomic_accession=108702928, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    55120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55120, CurrentID=0, Status='live', Symbol='FANCL', Aliases=['FAAP43', 'PHF9', 'POG'], description='FA complementation group L', other_designations='E3 ubiquitin-protein ligase FANCL|Fanconi anemia complementation group L|PHD finger protein 9|RING-type E3 ubiquitin transferase FANCL|fanconi anemia group L protein|fanconi anemia-associated polypeptide of 43 kDa', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=58159243, end_position_on_the_genomic_accession=58241681, orientation='minus', exon_count=14, OMIM=[608111], no_hdr0=''),
    55122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55122, CurrentID=0, Status='live', Symbol='AKIRIN2', Aliases=['C6orf166', 'FBI1', 'dJ486L4.2'], description='akirin 2', other_designations='akirin-2|fourteen-three-three beta interactant 1', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87674860, end_position_on_the_genomic_accession=87702233, orientation='minus', exon_count=5, OMIM=[615165], no_hdr0=''),
    55124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55124, CurrentID=0, Status='live', Symbol='PIWIL2', Aliases=['CT80', 'HILI', 'PIWIL1L', 'mili'], description='piwi like RNA-mediated gene silencing 2', other_designations='piwi-like protein 2|cancer/testis antigen 80|piwi-like 2|piwil2-like protein|testicular tissue protein Li 141', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22275314, end_position_on_the_genomic_accession=22357568, orientation='plus', exon_count=25, OMIM=[610312], no_hdr0=''),
    55125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55125, CurrentID=0, Status='live', Symbol='CEP192', Aliases=['PPP1R62'], description='centrosomal protein 192', other_designations='centrosomal protein of 192 kDa|192 kDa centrosomal protein|centrosomal protein 192kDa|cep192/SPD-2|protein phosphatase 1, regulatory subunit 62', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12991301, end_position_on_the_genomic_accession=13125053, orientation='plus', exon_count=46, OMIM=[616426], no_hdr0=''),
    55127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55127, CurrentID=0, Status='live', Symbol='HEATR1', Aliases=['BAP28', 'UTP10'], description='HEAT repeat containing 1', other_designations='HEAT repeat-containing protein 1|U3 small nucleolar RNA-associated protein 10 homolog|UTP10, small subunit (SSU) processome component, homolog|protein BAP28', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236549005, end_position_on_the_genomic_accession=236604516, orientation='minus', exon_count=45, OMIM=[], no_hdr0=''),
    55128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55128, CurrentID=0, Status='live', Symbol='TRIM68', Aliases=['GC109', 'RNF137', 'SS-56', 'SS56'], description='tripartite motif containing 68', other_designations='E3 ubiquitin-protein ligase TRIM68|RING-type E3 ubiquitin transferase TRIM68|Ro/SSA1 related protein|SSA protein SS-56|ring finger protein 137|tripartite motif-containing protein 68', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4598672, end_position_on_the_genomic_accession=4608231, orientation='minus', exon_count=7, OMIM=[613184], no_hdr0=''),
    55129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55129, CurrentID=0, Status='live', Symbol='ANO10', Aliases=['SCAR10', 'TMEM16K'], description='anoctamin 10', other_designations='anoctamin-10|transmembrane protein 16K', map_location='3p22.1-p21.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=43365848, end_position_on_the_genomic_accession=43691594, orientation='minus', exon_count=20, OMIM=[613726], no_hdr0=''),
    55130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55130, CurrentID=0, Status='live', Symbol='ODAD2', Aliases=['ARMC4', 'CILD23', 'gudu'], description='outer dynein arm docking complex subunit 2', other_designations='outer dynein arm-docking complex subunit 2|armadillo repeat containing 4|armadillo repeat-containing protein 4|testis tissue sperm-binding protein Li 74n', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27812166, end_position_on_the_genomic_accession=27999500, orientation='minus', exon_count=30, OMIM=[615408], no_hdr0=''),
    55131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55131, CurrentID=0, Status='live', Symbol='RBM28', Aliases=['ANES'], description='RNA binding motif protein 28', other_designations='RNA-binding protein 28|2810480G15Rik', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128297685, end_position_on_the_genomic_accession=128343908, orientation='minus', exon_count=19, OMIM=[612074], no_hdr0=''),
    55132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55132, CurrentID=0, Status='live', Symbol='LARP1B', Aliases=['LARP2'], description='La ribonucleoprotein 1B', other_designations='la-related protein 1B|La ribonucleoprotein domain family member 1B|La ribonucleoprotein domain family, member 2|la-related protein 2', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=128060655, end_position_on_the_genomic_accession=128222931, orientation='plus', exon_count=29, OMIM=[], no_hdr0=''),
    55133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55133, CurrentID=0, Status='live', Symbol='SRBD1', Aliases=[], description='S1 RNA binding domain 1', other_designations='S1 RNA-binding domain-containing protein 1|H_NH0576F01.1|WUGSC:H_NH0576F01.1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=45388680, end_position_on_the_genomic_accession=45611294, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    55135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55135, CurrentID=0, Status='live', Symbol='WRAP53', Aliases=['DKCB3', 'TCAB1', 'WDR79'], description='WD repeat containing antisense to TP53', other_designations='telomerase Cajal body protein 1|WD repeat-containing protein 79|WD repeat-containing protein WRAP53|WD40 protein Wrap53|WD40 repeat-containing protein antisense to TP53|WD40 repeat-containing protein encoding RNA antisense to p53|WRAP53beta', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7686071, end_position_on_the_genomic_accession=7703502, orientation='plus', exon_count=13, OMIM=[612661], no_hdr0=''),
    55137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55137, CurrentID=0, Status='live', Symbol='FIGN', Aliases=[], description='fidgetin, microtubule severing factor', other_designations='fidgetin', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=163602611, end_position_on_the_genomic_accession=163736155, orientation='minus', exon_count=4, OMIM=[605295], no_hdr0=''),
    55138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55138, CurrentID=0, Status='live', Symbol='FAM90A1', Aliases=[], description='family with sequence similarity 90 member A1', other_designations='protein FAM90A1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8221260, end_position_on_the_genomic_accession=8227618, orientation='minus', exon_count=7, OMIM=[613041], no_hdr0=''),
    55139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55139, CurrentID=0, Status='live', Symbol='ANKZF1', Aliases=['Vms1', 'ZNF744'], description='ankyrin repeat and zinc finger peptidyl tRNA hydrolase 1', other_designations='ankyrin repeat and zinc finger domain-containing protein 1|ankyrin repeat and zinc finger domain containing 1|zinc finger protein 744', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219229806, end_position_on_the_genomic_accession=219236679, orientation='plus', exon_count=13, OMIM=[617541], no_hdr0=''),
    55140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55140, CurrentID=0, Status='live', Symbol='ELP3', Aliases=['KAT9'], description='elongator acetyltransferase complex subunit 3', other_designations='elongator complex protein 3|elongation protein 3 homolog|protein lysine acetyltransferase ELP3|tRNA uridine(34) acetyltransferase', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28090232, end_position_on_the_genomic_accession=28191153, orientation='plus', exon_count=18, OMIM=[612722], no_hdr0=''),
    55142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55142, CurrentID=0, Status='live', Symbol='HAUS2', Aliases=['C15orf25', 'CEP27', 'HsT17025'], description='HAUS augmin like complex subunit 2', other_designations='HAUS augmin-like complex subunit 2|centrosomal protein 27kDa|centrosomal protein of 27 kDa', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42548828, end_position_on_the_genomic_accession=42569994, orientation='plus', exon_count=7, OMIM=[613429], no_hdr0=''),
    55143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55143, CurrentID=0, Status='live', Symbol='CDCA8', Aliases=['BOR', 'BOREALIN', 'DasraB', 'MESRGP'], description='cell division cycle associated 8', other_designations='borealin|Dasra B|cell division cycle-associated protein 8|dasra-B|hDasra-B|pluripotent embryonic stem cell-related gene 3 protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37692516, end_position_on_the_genomic_accession=37709719, orientation='plus', exon_count=11, OMIM=[609977], no_hdr0=''),
    55144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55144, CurrentID=0, Status='live', Symbol='LRRC8D', Aliases=['HsLRRC8D', 'LRRC5'], description='leucine rich repeat containing 8 VRAC subunit D', other_designations='volume-regulated anion channel subunit LRRC8D|leucine rich repeat containing 5|leucine rich repeat containing 8 family member D|leucine-rich repeat-containing protein 5|leucine-rich repeat-containing protein 8D', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89821014, end_position_on_the_genomic_accession=89936611, orientation='plus', exon_count=7, OMIM=[612890], no_hdr0=''),
    55145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55145, CurrentID=0, Status='live', Symbol='THAP1', Aliases=['DYT6'], description='THAP domain containing 1', other_designations='THAP domain-containing protein 1|4833431A01Rik|THAP domain containing, apoptosis associated protein 1|THAP domain protein 1|nuclear proapoptotic factor', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42836674, end_position_on_the_genomic_accession=42843325, orientation='minus', exon_count=3, OMIM=[609520], no_hdr0=''),
    55146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55146, CurrentID=0, Status='live', Symbol='ZDHHC4', Aliases=['ZNF374'], description='zinc finger DHHC-type palmitoyltransferase 4', other_designations='palmitoyltransferase ZDHHC4|DHHC-4|probable palmitoyltransferase ZDHHC4|zinc finger DHHC domain-containing protein 4|zinc finger DHHC-type containing 4|zinc finger protein 374|zinc finger, DHHC domain containing 4', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6577413, end_position_on_the_genomic_accession=6589374, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    55147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55147, CurrentID=0, Status='live', Symbol='RBM23', Aliases=['CAPERbeta', 'PP239', 'RNPC4'], description='RNA binding motif protein 23', other_designations='probable RNA-binding protein 23|CAPER beta|RNA-binding region (RNP1, RRM) containing 4|RNA-binding region-containing protein 4|coactivator of activating protein-1 and estrogen recep- tors beta|splicing factor SF2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22893204, end_position_on_the_genomic_accession=22919182, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    55148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55148, CurrentID=0, Status='live', Symbol='UBR7', Aliases=['C14orf130', 'LICAS'], description='ubiquitin protein ligase E3 component n-recognin 7', other_designations='putative E3 ubiquitin-protein ligase UBR7|N-recognin-7|RING-type E3 ubiquitin transferase UBR7|ubiquitin protein ligase E3 component n-recognin 7 (putative)', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93207256, end_position_on_the_genomic_accession=93229215, orientation='plus', exon_count=11, OMIM=[613816], no_hdr0=''),
    55149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55149, CurrentID=0, Status='live', Symbol='MTPAP', Aliases=['PAPD1', 'SPAX4', 'TENT6'], description='mitochondrial poly(A) polymerase', other_designations='poly(A) RNA polymerase, mitochondrial|PAP-associated domain-containing protein 1|TUTase 1|polynucleotide adenylyltransferase|terminal uridylyltransferase 1', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=30309801, end_position_on_the_genomic_accession=30349278, orientation='minus', exon_count=9, OMIM=[613669], no_hdr0=''),
    55150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55150, CurrentID=0, Status='live', Symbol='C19orf73', Aliases=[], description='chromosome 19 open reading frame 73', other_designations='putative uncharacterized protein C19orf73', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49118402, end_position_on_the_genomic_accession=49119143, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    55151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55151, CurrentID=0, Status='live', Symbol='TMEM38B', Aliases=['C9orf87', 'D4Ertd89e', 'OI14', 'TRIC-B', 'TRICB', 'bA219P18.1'], description='transmembrane protein 38B', other_designations='trimeric intracellular cation channel type B', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=105694541, end_position_on_the_genomic_accession=105776629, orientation='plus', exon_count=10, OMIM=[611236], no_hdr0=''),
    55152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55152, CurrentID=0, Status='live', Symbol='DALRD3', Aliases=['DEE86', 'EIEE86'], description='DALR anticodon binding domain containing 3', other_designations='DALR anticodon-binding domain-containing protein 3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49015399, end_position_on_the_genomic_accession=49021505, orientation='minus', exon_count=13, OMIM=[618904], no_hdr0=''),
    55153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55153, CurrentID=0, Status='live', Symbol='SDAD1', Aliases=[], description='SDA1 domain containing 1', other_designations='protein SDA1 homolog|SDA1 domain-containing protein 1|nucleolar protein 130', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75949911, end_position_on_the_genomic_accession=75990962, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    55154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55154, CurrentID=0, Status='live', Symbol='MSTO1', Aliases=['LST005', 'MMYAT', 'MST'], description='misato mitochondrial distribution and morphology regulator 1', other_designations='protein misato homolog 1|misato 1, mitochondrial distribution and morphology regulator|misato homolog 1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155610170, end_position_on_the_genomic_accession=155614967, orientation='plus', exon_count=14, OMIM=[617619], no_hdr0=''),
    55156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55156, CurrentID=0, Status='live', Symbol='ARMC1', Aliases=['Arcp'], description='armadillo repeat containing 1', other_designations='armadillo repeat-containing protein 1', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=65602458, end_position_on_the_genomic_accession=65634194, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    55157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55157, CurrentID=0, Status='live', Symbol='DARS2', Aliases=['ASPRS', 'LBSL', 'MT-ASPRS', 'mtAspRS'], description='aspartyl-tRNA synthetase 2, mitochondrial', other_designations='aspartate--tRNA ligase, mitochondrial|aspartate tRNA ligase 2, mitochondrial|aspartyl-tRNA synthetase, mitochondrial', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173824673, end_position_on_the_genomic_accession=173858546, orientation='plus', exon_count=18, OMIM=[610956], no_hdr0=''),
    55159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55159, CurrentID=0, Status='live', Symbol='RFWD3', Aliases=['FANCW', 'RNF201'], description='ring finger and WD repeat domain 3', other_designations='E3 ubiquitin-protein ligase RFWD3|RING finger and WD repeat domain-containing protein 3|RING finger protein 201|RING-type E3 ubiquitin transferase RFWD3', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74621396, end_position_on_the_genomic_accession=74666892, orientation='minus', exon_count=18, OMIM=[614151], no_hdr0=''),
    55160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55160, CurrentID=0, Status='live', Symbol='ARHGEF10L', Aliases=['GrinchGEF'], description='Rho guanine nucleotide exchange factor 10 like', other_designations='rho guanine nucleotide exchange factor 10-like protein|Rho guanine nucleotide exchange factor (GEF) 10-like', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17513442, end_position_on_the_genomic_accession=17697875, orientation='plus', exon_count=37, OMIM=[612494], no_hdr0=''),
    55161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55161, CurrentID=0, Status='live', Symbol='TMEM33', Aliases=['1600019D15Rik', 'Pom33', 'SHINC-3', 'SHINC3'], description='transmembrane protein 33', other_designations='transmembrane protein 33', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41935120, end_position_on_the_genomic_accession=41960803, orientation='plus', exon_count=8, OMIM=[618515], no_hdr0=''),
    55163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55163, CurrentID=0, Status='live', Symbol='PNPO', Aliases=['HEL-S-302', 'PDXPO'], description="pyridoxamine 5'-phosphate oxidase", other_designations="pyridoxine-5'-phosphate oxidase|epididymis secretory protein Li 302|epididymis secretory sperm binding protein|pyridoxal 5'-phosphate synthase|pyridoxamine-phosphate oxidase|pyridoxine 5'-phosphate oxidase", map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47941524, end_position_on_the_genomic_accession=47949308, orientation='plus', exon_count=8, OMIM=[603287], no_hdr0=''),
    55164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55164, CurrentID=0, Status='live', Symbol='SHQ1', Aliases=['GRIM-1', 'Shq1p'], description='SHQ1, H/ACA ribonucleoprotein assembly factor', other_designations='protein SHQ1 homolog|SHQ1 homolog|gene associated with retinoid and interferon-induced mortality 1', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=72725702, end_position_on_the_genomic_accession=72848475, orientation='minus', exon_count=18, OMIM=[613663], no_hdr0=''),
    55165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55165, CurrentID=0, Status='live', Symbol='CEP55', Aliases=['C10orf3', 'CT111', 'MARCH', 'URCC6'], description='centrosomal protein 55', other_designations='centrosomal protein of 55 kDa|cancer/testis antigen 111|centrosomal protein 55kDa|up-regulated in colon cancer 6', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93496612, end_position_on_the_genomic_accession=93529094, orientation='plus', exon_count=9, OMIM=[610000], no_hdr0=''),
    55166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55166, CurrentID=0, Status='live', Symbol='CENPQ', Aliases=['C6orf139', 'CENP-Q'], description='centromere protein Q', other_designations='centromere protein Q', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49463327, end_position_on_the_genomic_accession=49493107, orientation='plus', exon_count=9, OMIM=[611506], no_hdr0=''),
    55167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55167, CurrentID=0, Status='live', Symbol='MSL2', Aliases=['MSL-2L1', 'RNF184', 'MSL2'], description='MSL complex subunit 2', other_designations='E3 ubiquitin-protein ligase MSL2|E3 ubiquitin-protein transferase MSL2|MSL2-like 1|male-specific lethal 2 homolog|male-specific lethal 2-like 1|male-specific lethal-2 homolog 1|ring finger protein 184', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136148917, end_position_on_the_genomic_accession=136197300, orientation='minus', exon_count=5, OMIM=[614802], no_hdr0=''),
    55168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55168, CurrentID=0, Status='live', Symbol='MRPS18A', Aliases=['HumanS18b', 'MRP-S18-3', 'MRP-S18-a', 'MRPS18-3', 'S18bmt', 'S18mt-a'], description='mitochondrial ribosomal protein S18A', other_designations='39S ribosomal protein S18a, mitochondrial|28S ribosomal protein S18-3, mitochondrial|28S ribosomal protein S18a, mitochondrial|39S ribosomal protein S18-3, mitochondrial|mitochondrial large ribosomal subunit protein bS18a|mitochondrial large ribosomal subunit protein bS18m-A|mitochondrial large ribosomal subunit protein mL66|mitochondrial ribosomal protein S18-3', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43671202, end_position_on_the_genomic_accession=43687793, orientation='minus', exon_count=6, OMIM=[611981], no_hdr0=''),
    55170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55170, CurrentID=0, Status='live', Symbol='PRMT6', Aliases=['HRMT1L6'], description='protein arginine methyltransferase 6', other_designations='protein arginine N-methyltransferase 6|HMT1 hnRNP methyltransferase-like 6|heterogeneous nuclear ribonucleoprotein methyltransferase-like protein 6|histone-arginine N-methyltransferase PRMT6', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=107056674, end_position_on_the_genomic_accession=107059294, orientation='plus', exon_count=1, OMIM=[608274], no_hdr0=''),
    55171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55171, CurrentID=0, Status='live', Symbol='TBCCD1', Aliases=[], description='TBCC domain containing 1', other_designations='TBCC domain-containing protein 1', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=186546067, end_position_on_the_genomic_accession=186570543, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55172, CurrentID=0, Status='live', Symbol='DNAAF2', Aliases=['C14orf104', 'CILD10', 'KTU', 'PF13'], description='dynein axonemal assembly factor 2', other_designations='protein kintoun|dynein assembly factor 2, axonemal|kintoun', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49625174, end_position_on_the_genomic_accession=49635244, orientation='minus', exon_count=3, OMIM=[612517], no_hdr0=''),
    55173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55173, CurrentID=0, Status='live', Symbol='MRPS10', Aliases=['MRP-S10', 'PNAS-122'], description='mitochondrial ribosomal protein S10', other_designations='28S ribosomal protein S10, mitochondrial|S10mt|mitochondrial 28S ribosomal protein S10|mitochondrial small ribosomal subunit protein uS10m', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42206801, end_position_on_the_genomic_accession=42217870, orientation='minus', exon_count=8, OMIM=[611976], no_hdr0=''),
    55174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55174, CurrentID=0, Status='live', Symbol='INTS10', Aliases=['C8orf35', 'INT10'], description='integrator complex subunit 10', other_designations='integrator complex subunit 10', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=19817149, end_position_on_the_genomic_accession=19852078, orientation='plus', exon_count=23, OMIM=[611353], no_hdr0=''),
    55175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55175, CurrentID=0, Status='live', Symbol='KLHL11', Aliases=[], description='kelch like family member 11', other_designations='kelch-like protein 11', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41848514, end_position_on_the_genomic_accession=41865423, orientation='minus', exon_count=3, OMIM=[619078], no_hdr0=''),
    55176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55176, CurrentID=0, Status='live', Symbol='SEC61A2', Aliases=[], description='SEC61 translocon subunit alpha 2', other_designations='protein transport protein Sec61 subunit alpha isoform 2|SEC61 translocon alpha 2 subunit|Sec61 alpha 2 subunit|Sec61 alpha form 2|protein transport protein Sec61 subunit alpha|sec61 alpha-2', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12129641, end_position_on_the_genomic_accession=12169958, orientation='plus', exon_count=15, OMIM=[618271], no_hdr0=''),
    55177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55177, CurrentID=0, Status='live', Symbol='RMDN3', Aliases=['FAM82A2', 'FAM82C', 'RMD-3', 'RMD3', 'ptpip51'], description='regulator of microtubule dynamics 3', other_designations='regulator of microtubule dynamics protein 3|TCPTP-interacting protein 51|cerebral protein 10|family with sequence similarity 82, member A2|family with sequence similarity 82, member C|microtubule-associated protein|protein tyrosine phosphatase-interacting protein 51', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40735887, end_position_on_the_genomic_accession=40755254, orientation='minus', exon_count=14, OMIM=[611873], no_hdr0=''),
    55178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55178, CurrentID=0, Status='live', Symbol='MRM3', Aliases=['RMTL1', 'RNMTL1'], description='mitochondrial rRNA methyltransferase 3', other_designations="rRNA methyltransferase 3, mitochondrial|16S rRNA (guanosine(1370)-2'-O)-methyltransferase|16S rRNA [Gm1370] 2'-O-methyltransferase|RNA methyltransferase like 1|RNA methyltransferase-like protein 1|putative RNA methyltransferase", map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=782353, end_position_on_the_genomic_accession=792509, orientation='plus', exon_count=4, OMIM=[612600], no_hdr0=''),
    55179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55179, CurrentID=0, Status='live', Symbol='FAIM', Aliases=['FAIM1'], description='Fas apoptotic inhibitory molecule', other_designations='fas apoptotic inhibitory molecule 1', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138608099, end_position_on_the_genomic_accession=138633376, orientation='plus', exon_count=8, OMIM=[617535], no_hdr0=''),
    55180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55180, CurrentID=0, Status='live', Symbol='LINS1', Aliases=['LINS', 'MRT27', 'WINS1'], description='lines homolog 1', other_designations='protein Lines homolog 1|WINS1 protein with Drosophila Lines (Lin) homologous domain|mental retardation, non-syndromic, autosomal recessive, 27|truncated LINS1|wnt-signaling molecule Lines homolog 1', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=100566914, end_position_on_the_genomic_accession=100603032, orientation='minus', exon_count=10, OMIM=[610350], no_hdr0=''),
    55181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55181, CurrentID=0, Status='live', Symbol='SMG8', Aliases=['ALKUS', 'C17orf71'], description='SMG8 nonsense mediated mRNA decay factor', other_designations='protein SMG8|amplified in breast cancer gene 2 protein|protein smg-8 homolog|smg-8 homolog, nonsense mediated mRNA decay factor', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59210035, end_position_on_the_genomic_accession=59215230, orientation='plus', exon_count=4, OMIM=[613175], no_hdr0=''),
    55182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55182, CurrentID=0, Status='live', Symbol='RNF220', Aliases=['C1orf164'], description='ring finger protein 220', other_designations='E3 ubiquitin-protein ligase RNF220|RING-type E3 ubiquitin transferase RNF220', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44405160, end_position_on_the_genomic_accession=44651724, orientation='plus', exon_count=22, OMIM=[616136], no_hdr0=''),
    55183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55183, CurrentID=0, Status='live', Symbol='RIF1', Aliases=[], description='replication timing regulatory factor 1', other_designations='telomere-associated protein RIF1|RAP1 interacting factor homolog|rap1-interacting factor 1 homolog', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151409902, end_position_on_the_genomic_accession=151534200, orientation='plus', exon_count=41, OMIM=[608952], no_hdr0=''),
    55184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55184, CurrentID=0, Status='live', Symbol='DZANK1', Aliases=['ANKRD64', 'C20orf12', 'C20orf84'], description='double zinc ribbon and ankyrin repeat domains 1', other_designations='double zinc ribbon and ankyrin repeat-containing protein 1|ankyrin repeat domain 64|ankyrin repeat-containing protein C20orf12', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18383367, end_position_on_the_genomic_accession=18467180, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    55186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55186, CurrentID=0, Status='live', Symbol='SLC25A36', Aliases=['PNC2'], description='solute carrier family 25 member 36', other_designations='solute carrier family 25 member 36|epididymis secretory sperm binding protein|solute carrier family 25 (pyrimidine nucleotide carrier ), member 36', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=140941836, end_position_on_the_genomic_accession=140980995, orientation='plus', exon_count=8, OMIM=[616149], no_hdr0=''),
    55187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55187, CurrentID=0, Status='live', Symbol='VPS13D', Aliases=['SCAR4'], description='vacuolar protein sorting 13 homolog D', other_designations='vacuolar protein sorting-associated protein 13D|vacuolar protein sorting 13D', map_location='1p36.22-p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12230030, end_position_on_the_genomic_accession=12512047, orientation='plus', exon_count=70, OMIM=[608877], no_hdr0=''),
    55188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55188, CurrentID=0, Status='live', Symbol='RIC8B', Aliases=['RIC8', 'hSyn'], description='RIC8 guanine nucleotide exchange factor B', other_designations='synembryn-B|brain synembrin|brain synembryn|resistance to inhibitors of cholinesterase 8 homolog B', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106774621, end_position_on_the_genomic_accession=106889316, orientation='plus', exon_count=17, OMIM=[609147], no_hdr0=''),
    55190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55190, CurrentID=0, Status='live', Symbol='NUDT11', Aliases=['APS1', 'ASP1', 'DIPP3b', 'DIPP3beta', 'hDIPP3beta'], description='nudix hydrolase 11', other_designations="diphosphoinositol polyphosphate phosphohydrolase 3-beta|DIPP-3-beta|DIPP3-beta|diadenosine 5',5'''-P1,P6-hexaphosphate hydrolase 3-beta|diadenosine hexaphosphate hydrolase (AMP-forming)|diphosphoinositol polyphosphate phosphohydrolase 3, beta|hAps1|nucleoside diphosphate-linked moiety X motif 11|nudix (nucleoside diphosphate linked moiety X)-type motif 11|nudix motif 11", map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51490011, end_position_on_the_genomic_accession=51496592, orientation='minus', exon_count=2, OMIM=[300528], no_hdr0=''),
    55191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55191, CurrentID=0, Status='live', Symbol='NADSYN1', Aliases=['VCRL3'], description='NAD synthetase 1', other_designations='glutamine-dependent NAD(+) synthetase|NAD(+) synthase|NAD(+) synthetase|glutamine-dependent NAD synthetase', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71453203, end_position_on_the_genomic_accession=71501816, orientation='plus', exon_count=21, OMIM=[608285], no_hdr0=''),
    55192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55192, CurrentID=0, Status='live', Symbol='DNAJC17', Aliases=[], description='DnaJ heat shock protein family (Hsp40) member C17', other_designations='dnaJ homolog subfamily C member 17|DnaJ (Hsp40) homolog, subfamily C, member 17', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40765161, end_position_on_the_genomic_accession=40807477, orientation='minus', exon_count=10, OMIM=[616844], no_hdr0=''),
    55193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55193, CurrentID=0, Status='live', Symbol='PBRM1', Aliases=['BAF180', 'PB1', 'RCC'], description='polybromo 1', other_designations='protein polybromo-1|BRG1-associated factor 180|polybromo-1D', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52545367, end_position_on_the_genomic_accession=52685913, orientation='minus', exon_count=37, OMIM=[606083], no_hdr0=''),
    55194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55194, CurrentID=0, Status='live', Symbol='EVA1B', Aliases=['C1orf78', 'FAM176B'], description='eva-1 homolog B', other_designations='protein eva-1 homolog B|family with sequence similarity 176, member B|protein FAM176B', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36322030, end_position_on_the_genomic_accession=36324154, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    55195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55195, CurrentID=0, Status='live', Symbol='CCDC198', Aliases=['C14orf105'], description='coiled-coil domain containing 198', other_designations='uncharacterized protein CCDC198|uncharacterized protein C14orf105', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57469300, end_position_on_the_genomic_accession=57493981, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55196, CurrentID=0, Status='live', Symbol='RESF1', Aliases=['C12orf35', 'GET', 'KIAA1551', 'UTA2-1'], description='retroelement silencing factor 1', other_designations='retroelement silencing factor 1|gonad expressed transcript|uncharacterized protein C12orf35', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31959415, end_position_on_the_genomic_accession=31993107, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55197, CurrentID=0, Status='live', Symbol='RPRD1A', Aliases=['HsT3101', 'P15RS'], description='regulation of nuclear pre-mRNA domain containing 1A', other_designations='regulation of nuclear pre-mRNA domain-containing protein 1A|CDKN2B-related protein|Cyclin-dependent kinase inhibitor 2B-related protein (p15INK4B-related protein)|cyclin-dependent kinase 2B-inhibitor-related protein|p15INK4B-related protein', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35982385, end_position_on_the_genomic_accession=36067576, orientation='minus', exon_count=13, OMIM=[610347], no_hdr0=''),
    55198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55198, CurrentID=0, Status='live', Symbol='APPL2', Aliases=['DIP13B'], description='adaptor protein, phosphotyrosine interacting with PH domain and leucine zipper 2', other_designations='DCC-interacting protein 13-beta|DIP13 beta|adapter protein containing PH domain, PTB domain and leucine zipper motif 2|adaptor protein, phosphotyrosine interaction, PH domain and leucine zipper containing 2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=105173297, end_position_on_the_genomic_accession=105236174, orientation='minus', exon_count=24, OMIM=[606231], no_hdr0=''),
    55200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55200, CurrentID=0, Status='live', Symbol='PLEKHG6', Aliases=['MyoGEF'], description='pleckstrin homology and RhoGEF domain containing G6', other_designations='pleckstrin homology domain-containing family G member 6|PH domain-containing family G member 6|myosin II interacting GEF|myosin interacting guanine nucleotide exchange factor|pleckstrin homology domain containing, family G (with RhoGef domain) member 6', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6310332, end_position_on_the_genomic_accession=6328506, orientation='plus', exon_count=20, OMIM=[611743], no_hdr0=''),
    55201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55201, CurrentID=0, Status='live', Symbol='MAP1S', Aliases=['BPY2IP1', 'C19orf5', 'MAP8', 'VCY2IP-1', 'VCY2IP1'], description='microtubule associated protein 1S', other_designations='microtubule-associated protein 1S|BPY2-interacting protein 1|MAP-1S|VCY2-interacting protein 1|microtubule-associated protein 8|variable charge Y chromosome 2-interacting protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17719480, end_position_on_the_genomic_accession=17734513, orientation='plus', exon_count=8, OMIM=[607573], no_hdr0=''),
    55203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55203, CurrentID=0, Status='live', Symbol='LGI2', Aliases=['LGIL2'], description='leucine rich repeat LGI family member 2', other_designations='leucine-rich repeat LGI family member 2|LGI1-like protein 2|leucine-rich glioma-inactivated protein 2|leucine-rich, glioma inactivated 2', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=24991960, end_position_on_the_genomic_accession=25030946, orientation='minus', exon_count=10, OMIM=[608301], no_hdr0=''),
    55204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55204, CurrentID=0, Status='live', Symbol='GOLPH3L', Aliases=['GPP34R'], description='golgi phosphoprotein 3 like', other_designations='Golgi phosphoprotein 3-like|GPP34-related protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150646230, end_position_on_the_genomic_accession=150697154, orientation='minus', exon_count=6, OMIM=[612208], no_hdr0=''),
    55205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55205, CurrentID=0, Status='live', Symbol='ZNF532', Aliases=[], description='zinc finger protein 532', other_designations='zinc finger protein 532', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=58862600, end_position_on_the_genomic_accession=58986480, orientation='plus', exon_count=21, OMIM=[619066], no_hdr0=''),
    55206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55206, CurrentID=0, Status='live', Symbol='SBNO1', Aliases=['MOP3', 'Sno'], description='strawberry notch homolog 1', other_designations='protein strawberry notch homolog 1|monocyte protein 3', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123289109, end_position_on_the_genomic_accession=123364847, orientation='minus', exon_count=32, OMIM=[614274], no_hdr0=''),
    55207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55207, CurrentID=0, Status='live', Symbol='ARL8B', Aliases=['ARL10C', 'Gie1'], description='ADP ribosylation factor like GTPase 8B', other_designations='ADP-ribosylation factor-like protein 8B|ADP-ribosylation factor-like 10C|ADP-ribosylation factor-like 8B|ADP-ribosylation factor-like protein 10C|novel small G protein indispensable for equal chromosome segregation 1', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=5122292, end_position_on_the_genomic_accession=5180911, orientation='plus', exon_count=7, OMIM=[616596], no_hdr0=''),
    55208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55208, CurrentID=0, Status='live', Symbol='DCUN1D2', Aliases=['C13orf17', 'DCNL2'], description='defective in cullin neddylation 1 domain containing 2', other_designations='DCN1-like protein 2|DCN1, defective in cullin neddylation 1, domain containing 2|DCUN1 domain-containing protein 2|defective in cullin neddylation protein 1-like protein 2', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113455819, end_position_on_the_genomic_accession=113492047, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    55209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55209, CurrentID=0, Status='live', Symbol='SETD5', Aliases=[], description='SET domain containing 5', other_designations='histone-lysine N-methyltransferase SETD5|SET domain-containing protein 5', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9397615, end_position_on_the_genomic_accession=9478154, orientation='plus', exon_count=36, OMIM=[615743], no_hdr0=''),
    55210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55210, CurrentID=0, Status='live', Symbol='ATAD3A', Aliases=['HAYOS', 'PHRINL'], description='ATPase family AAA domain containing 3A', other_designations='ATPase family AAA domain-containing protein 3A', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1512143, end_position_on_the_genomic_accession=1534686, orientation='plus', exon_count=18, OMIM=[612316], no_hdr0=''),
    55211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55211, CurrentID=0, Status='live', Symbol='DPPA4', Aliases=['2410091M23Rik'], description='developmental pluripotency associated 4', other_designations='developmental pluripotency-associated protein 4', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=109326141, end_position_on_the_genomic_accession=109339635, orientation='minus', exon_count=9, OMIM=[614125], no_hdr0=''),
    55212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55212, CurrentID=0, Status='live', Symbol='BBS7', Aliases=['BBS2L1'], description='Bardet-Biedl syndrome 7', other_designations='Bardet-Biedl syndrome 7 protein|BBS2-like 1', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121824329, end_position_on_the_genomic_accession=121870487, orientation='minus', exon_count=19, OMIM=[607590], no_hdr0=''),
    55213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55213, CurrentID=0, Status='live', Symbol='RCBTB1', Aliases=['CLLD7', 'CLLL7', 'GLP', 'RDEOA'], description='RCC1 and BTB domain containing protein 1', other_designations='RCC1 and BTB domain-containing protein 1|CLL deletion region gene 7 protein|GDP/GTP exchange factor (GEF)-like protein|chronic lymphocytic leukemia deletion region gene 7 protein|regulator of chromosome condensation (RCC1) and BTB (POZ) domain containing protein 1|regulator of chromosome condensation and BTB domain-containing protein 1', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49531944, end_position_on_the_genomic_accession=49585587, orientation='minus', exon_count=18, OMIM=[607867], no_hdr0=''),
    55214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55214, CurrentID=0, Status='live', Symbol='P3H2', Aliases=['LEPREL1', 'MCVD', 'MLAT4'], description='prolyl 3-hydroxylase 2', other_designations='prolyl 3-hydroxylase 2|leprecan-like 1|myxoid liposarcoma-associated protein 4|procollagen-proline 3-dioxygenase 2|prolyl 3-hydroxylase 3', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=189956728, end_position_on_the_genomic_accession=190122278, orientation='minus', exon_count=17, OMIM=[610341], no_hdr0=''),
    55215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55215, CurrentID=0, Status='live', Symbol='FANCI', Aliases=['KIAA1794'], description='FA complementation group I', other_designations='Fanconi anemia group I protein|Fanconi anemia complementation group I', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89243973, end_position_on_the_genomic_accession=89317259, orientation='plus', exon_count=38, OMIM=[611360], no_hdr0=''),
    55216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55216, CurrentID=0, Status='live', Symbol='NKAPD1', Aliases=['C11orf57'], description='NKAP domain containing 1', other_designations='uncharacterized protein NKAPD1|NKAP domain containing protein 1|uncharacterized protein C11orf57', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112074299, end_position_on_the_genomic_accession=112085150, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    55217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55217, CurrentID=0, Status='live', Symbol='TMLHE', Aliases=['AUTSX6', 'BBOX2', 'TMLD', 'TMLHD', 'XAP130', 'TMLHE'], description='trimethyllysine hydroxylase, epsilon', other_designations='trimethyllysine dioxygenase, mitochondrial|TML hydroxylase|TML-alpha-ketoglutarate dioxygenase|butyrobetaine (gamma), 2-oxoglutarate dioxygenase (gamma-butyrobetaine hydroxylase) 2|epsilon-trimethyllysine 2-oxoglutarate dioxygenase|epsilon-trimethyllysine hydroxylase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155489011, end_position_on_the_genomic_accession=155612952, orientation='minus', exon_count=11, OMIM=[300777], no_hdr0=''),
    55218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55218, CurrentID=0, Status='live', Symbol='EXD2', Aliases=['C14orf114', 'EXDL2'], description="exonuclease 3'-5' domain containing 2", other_designations="exonuclease 3'-5' domain-containing protein 2|3'-5' exoribonuclease EXD2|exonuclease 3'-5' domain-like 2|exonuclease 3'-5' domain-like-containing protein 2", map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69191498, end_position_on_the_genomic_accession=69244018, orientation='plus', exon_count=13, OMIM=[616940], no_hdr0=''),
    55219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55219, CurrentID=0, Status='live', Symbol='MACO1', Aliases=['MACOILIN', 'TMEM57'], description='macoilin 1', other_designations='macoilin|transmembrane protein 57', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25430897, end_position_on_the_genomic_accession=25500209, orientation='plus', exon_count=11, OMIM=[610301], no_hdr0=''),
    55220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55220, CurrentID=0, Status='live', Symbol='KLHDC8A', Aliases=[], description='kelch domain containing 8A', other_designations='kelch domain-containing protein 8A|S-delta-E1|substitute for delta-EGFR expression 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205336061, end_position_on_the_genomic_accession=205357039, orientation='minus', exon_count=9, OMIM=[614503], no_hdr0=''),
    55222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55222, CurrentID=0, Status='live', Symbol='LRRC20', Aliases=[], description='leucine rich repeat containing 20', other_designations='leucine-rich repeat-containing protein 20', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70298975, end_position_on_the_genomic_accession=70382625, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    55223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55223, CurrentID=0, Status='live', Symbol='TRIM62', Aliases=['DEAR1'], description='tripartite motif containing 62', other_designations='E3 ubiquitin-protein ligase TRIM62|RING-type E3 ubiquitin transferase TRIM62|ductal epithelium-associated RING Chromosome 1|tripartite motif-containing protein 62', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33145399, end_position_on_the_genomic_accession=33184774, orientation='minus', exon_count=8, OMIM=[616755], no_hdr0=''),
    55224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55224, CurrentID=0, Status='live', Symbol='ETNK2', Aliases=['EKI2', 'HMFT1716'], description='ethanolamine kinase 2', other_designations='ethanolamine kinase 2|ethanolamine kinase-like protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204131062, end_position_on_the_genomic_accession=204152044, orientation='minus', exon_count=12, OMIM=[609859], no_hdr0=''),
    55225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55225, CurrentID=0, Status='live', Symbol='RAVER2', Aliases=[], description='ribonucleoprotein, PTB binding 2', other_designations='ribonucleoprotein PTB-binding 2|protein raver-2', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=64744979, end_position_on_the_genomic_accession=64833411, orientation='plus', exon_count=13, OMIM=[609953], no_hdr0=''),
    55226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55226, CurrentID=0, Status='live', Symbol='NAT10', Aliases=['ALP', 'Kre33', 'NET43'], description='N-acetyltransferase 10', other_designations='RNA cytidine acetyltransferase|18S rRNA cytosine acetyltransferase|N-acetyltransferase 10 (GCN5-related)|N-acetyltransferase-like protein', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=34105629, end_position_on_the_genomic_accession=34146908, orientation='plus', exon_count=29, OMIM=[609221], no_hdr0=''),
    55227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55227, CurrentID=0, Status='live', Symbol='LRRC1', Aliases=['LANO', 'dJ523E19.1'], description='leucine rich repeat containing 1', other_designations='leucine-rich repeat-containing protein 1|LANO adapter protein|LAP (leucine-rich repeats and PDZ) and no PDZ protein|LAP and no PDZ protein', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53794497, end_position_on_the_genomic_accession=53924125, orientation='plus', exon_count=19, OMIM=[608195], no_hdr0=''),
    55228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55228, CurrentID=0, Status='live', Symbol='PNMA8A', Aliases=['PNMAL1'], description='PNMA family member 8A', other_designations='paraneoplastic antigen-like protein 8A|PNMA-like protein 1|paraneoplastic Ma antigen family like 1|paraneoplastic Ma antigen family member 8A', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46466502, end_position_on_the_genomic_accession=46471577, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    55229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55229, CurrentID=0, Status='live', Symbol='PANK4', Aliases=[], description='pantothenate kinase 4 (inactive)', other_designations="4'-phosphopantetheine phosphatase|inactive pantothenic acid kinase 4|pantothenic acid kinase 4", map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2508537, end_position_on_the_genomic_accession=2526622, orientation='minus', exon_count=20, OMIM=[606162], no_hdr0=''),
    55230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55230, CurrentID=0, Status='live', Symbol='USP40', Aliases=[], description='ubiquitin specific peptidase 40', other_designations='ubiquitin carboxyl-terminal hydrolase 40|deubiquitinating enzyme 40|ubiquitin specific protease 40|ubiquitin thioesterase 40|ubiquitin thiolesterase 40|ubiquitin-specific-processing protease 40', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233475521, end_position_on_the_genomic_accession=233566789, orientation='minus', exon_count=44, OMIM=[610570], no_hdr0=''),
    55231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55231, CurrentID=0, Status='live', Symbol='CCDC87', Aliases=[], description='coiled-coil domain containing 87', other_designations='coiled-coil domain-containing protein 87', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66590176, end_position_on_the_genomic_accession=66593063, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    55233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55233, CurrentID=0, Status='live', Symbol='MOB1A', Aliases=['C2orf6', 'MATS1', 'MOB1', 'MOBK1B', 'MOBKL1B', 'Mob4B'], description='MOB kinase activator 1A', other_designations='MOB kinase activator 1A|MOB1 Mps One Binder homolog A|MOB1, Mps One Binder kinase activator-like 1B|mob1 alpha|mob1 homolog 1B|mps one binder kinase activator-like 1B', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74152528, end_position_on_the_genomic_accession=74178879, orientation='minus', exon_count=7, OMIM=[609281], no_hdr0=''),
    55234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55234, CurrentID=0, Status='live', Symbol='SMU1', Aliases=['BWD', 'SMU-1', 'fSAP57'], description='SMU1 DNA replication regulator and spliceosomal factor', other_designations='WD40 repeat-containing protein SMU1|DNA replication regulator and spliceosomal factor|brain-enriched WD-repeat protein|functional spliceosome-associated protein 57|smu-1 suppressor of mec-8 and unc-52 homolog|smu-1 suppressor of mec-8 and unc-52 protein homolog', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33041765, end_position_on_the_genomic_accession=33076705, orientation='minus', exon_count=12, OMIM=[617811], no_hdr0=''),
    55236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55236, CurrentID=0, Status='live', Symbol='UBA6', Aliases=['E1-L2', 'MOP-4', 'UBE1L2'], description='ubiquitin like modifier activating enzyme 6', other_designations='ubiquitin-like modifier-activating enzyme 6|UBA6, ubiquitin-activating enzyme E1|monocyte protein 4|ubiquitin-activating enzyme 6|ubiquitin-activating enzyme E1-like 2|ubiquitin-activating enzyme E1-like protein 2', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67612652, end_position_on_the_genomic_accession=67701155, orientation='minus', exon_count=33, OMIM=[611361], no_hdr0=''),
    55237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55237, CurrentID=0, Status='live', Symbol='VRTN', Aliases=['C14orf115', 'vertnin'], description='vertebrae development associated', other_designations='vertnin|vertebrae development homolog (pig)', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74303076, end_position_on_the_genomic_accession=74360008, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    55238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55238, CurrentID=0, Status='live', Symbol='SLC38A7', Aliases=['SNAT7'], description='solute carrier family 38 member 7', other_designations='putative sodium-coupled neutral amino acid transporter 7|amino acid transporter', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58665109, end_position_on_the_genomic_accession=58684770, orientation='minus', exon_count=13, OMIM=[614236], no_hdr0=''),
    55239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55239, CurrentID=0, Status='live', Symbol='OGFOD1', Aliases=['TPA1'], description='2-oxoglutarate and iron dependent oxygenase domain containing 1', other_designations='prolyl 3-hydroxylase OGFOD1|2-oxoglutarate and iron-dependent oxygenase domain-containing protein 1|TPA1, termination and polyadenylation 1, homolog|termination and polyadenylation 1 homolog|uS12 prolyl 3-hydroxylase', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56451524, end_position_on_the_genomic_accession=56479104, orientation='plus', exon_count=14, OMIM=[615857], no_hdr0=''),
    55240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55240, CurrentID=0, Status='live', Symbol='STEAP3', Aliases=['AHMIO2', 'STMP3', 'TSAP6', 'dudlin-2', 'dudulin-2', 'pHyde'], description='STEAP3 metalloreductase', other_designations='metalloreductase STEAP3|STEAP family member 3, metalloreductase|six-transmembrane epithelial antigen of prostate 3|tumor suppressor pHyde|tumor suppressor-activated pathway protein 6', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119222476, end_position_on_the_genomic_accession=119265652, orientation='plus', exon_count=11, OMIM=[609671], no_hdr0=''),
    55243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55243, CurrentID=0, Status='live', Symbol='KIRREL1', Aliases=['KIRREL', 'NEPH1', 'NPHS23'], description='kirre like nephrin family adhesion molecule 1', other_designations='kin of IRRE-like protein 1|kin of IRRE like|kin of irregular chiasm-like protein 1|nephrin related|nephrin-like protein 1', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157993613, end_position_on_the_genomic_accession=158100262, orientation='plus', exon_count=15, OMIM=[607428], no_hdr0=''),
    55244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55244, CurrentID=0, Status='live', Symbol='SLC47A1', Aliases=['MATE1'], description='solute carrier family 47 member 1', other_designations='multidrug and toxin extrusion protein 1|MATE-1|hMATE-1|multidrug and toxin extrusion 1|solute carrier family 47 (multidrug and toxin extrusion), member 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19533854, end_position_on_the_genomic_accession=19579034, orientation='plus', exon_count=17, OMIM=[609832], no_hdr0=''),
    55245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55245, CurrentID=0, Status='live', Symbol='UQCC1', Aliases=['BFZB', 'C20orf44', 'CBP3', 'UQCC'], description='ubiquinol-cytochrome c reductase complex assembly factor 1', other_designations='ubiquinol-cytochrome-c reductase complex assembly factor 1|bFGF-repressed Zic-binding protein|basic FGF-repressed Zic-binding protein|cytochrome B protein synthesis 3 homolog|ubiquinol-cytochrome c reductase complex chaperone CBP3 homolog', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35302578, end_position_on_the_genomic_accession=35412047, orientation='minus', exon_count=12, OMIM=[611797], no_hdr0=''),
    55246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55246, CurrentID=0, Status='live', Symbol='CCDC25', Aliases=[], description='coiled-coil domain containing 25', other_designations='coiled-coil domain-containing protein 25', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27733316, end_position_on_the_genomic_accession=27772640, orientation='minus', exon_count=10, OMIM=[619100], no_hdr0=''),
    55247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55247, CurrentID=0, Status='live', Symbol='NEIL3', Aliases=['FGP2', 'FPG2', 'NEI3', 'ZGRF3', 'hFPG2', 'hNEI3'], description='nei like DNA glycosylase 3', other_designations='endonuclease 8-like 3|DNA glycosylase FPG2|DNA glycosylase hFPG2|DNA glycosylase/AP lyase Neil3|endonuclease VIII-like 3|nei endonuclease VIII-like 3|nei-like protein 3|zinc finger, GRF-type containing 3', map_location='4q34.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=177309871, end_position_on_the_genomic_accession=177362936, orientation='plus', exon_count=10, OMIM=[608934], no_hdr0=''),
    55248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55248, CurrentID=0, Status='live', Symbol='PACC1', Aliases=['ASOR', 'C1orf75', 'PAC', 'PAORAC', 'TMEM206', 'hPAC', 'hTMEM206'], description='proton activated chloride channel 1', other_designations='proton-activated chloride channel|acid-sensitive outwardly-rectifying anion channel|proton-activated outwardly rectifying anion channel|transmembrane protein 206', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212363928, end_position_on_the_genomic_accession=212414886, orientation='minus', exon_count=11, OMIM=[618427], no_hdr0=''),
    55249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55249, CurrentID=0, Status='live', Symbol='YY1AP1', Aliases=['GRNG', 'HCCA1', 'HCCA2', 'YY1AP'], description='YY1 associated protein 1', other_designations='YY1-associated protein 1|hepatocellular carcinoma susceptibility protein|hepatocellular carcinoma-associated protein 2', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155659442, end_position_on_the_genomic_accession=155688996, orientation='minus', exon_count=14, OMIM=[607860], no_hdr0=''),
    55250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55250, CurrentID=0, Status='live', Symbol='ELP2', Aliases=['MRT58', 'SHINC-2', 'STATIP1', 'StIP'], description='elongator acetyltransferase complex subunit 2', other_designations='elongator complex protein 2|STAT3-interacting protein 1|elongation protein 2 homolog|elongator protein 2|signal transducer and activator of transcription 3 interacting protein 1', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36129899, end_position_on_the_genomic_accession=36180557, orientation='plus', exon_count=23, OMIM=[616054], no_hdr0=''),
    55251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55251, CurrentID=0, Status='live', Symbol='PCMTD2', Aliases=['C20orf36'], description='protein-L-isoaspartate (D-aspartate) O-methyltransferase domain containing 2', other_designations='protein-L-isoaspartate O-methyltransferase domain-containing protein 2', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64255748, end_position_on_the_genomic_accession=64276226, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    55252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55252, CurrentID=0, Status='live', Symbol='ASXL2', Aliases=['ASXH2', 'SHAPNS'], description='ASXL transcriptional regulator 2', other_designations='putative Polycomb group protein ASXL2|additional sex combs like 2, transcriptional regulator|additional sex combs-like protein 2|polycomb group protein ASXH2', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=25733753, end_position_on_the_genomic_accession=25878487, orientation='minus', exon_count=16, OMIM=[612991], no_hdr0=''),
    55253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55253, CurrentID=0, Status='live', Symbol='TYW1', Aliases=['RSAFD1A', 'YPL207W', 'TYW1'], description='tRNA-yW synthesizing protein 1 homolog', other_designations='S-adenosyl-L-methionine-dependent tRNA 4-demethylwyosine synthase TYW1|radical S-adenosyl methionine and flavodoxin domain-containing protein 1|radical S-adenosyl methionine and flavodoxin domains 1|tRNA wybutosine-synthesizing protein 1 homolog|tRNA-yW synthesizing protein 1 homolog A', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66996830, end_position_on_the_genomic_accession=67239515, orientation='plus', exon_count=18, OMIM=[611243], no_hdr0=''),
    55254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55254, CurrentID=0, Status='live', Symbol='TMEM39A', Aliases=['SUSR2'], description='transmembrane protein 39A', other_designations='transmembrane protein 39A|suppressor of SQST-1 aggregates in rpl-43 mutants', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119428949, end_position_on_the_genomic_accession=119463632, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    55255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55255, CurrentID=0, Status='live', Symbol='WDR41', Aliases=['MSTP048'], description='WD repeat domain 41', other_designations='WD repeat-containing protein 41', map_location='5q13.3-q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77426652, end_position_on_the_genomic_accession=77620611, orientation='minus', exon_count=15, OMIM=[617502], no_hdr0=''),
    55256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55256, CurrentID=0, Status='live', Symbol='ADI1', Aliases=['APL1', 'ARD', 'Fe-ARD', 'HMFT1638', 'MTCBP1', 'Ni-ARD', 'SIPL', 'mtnD'], description='acireductone dioxygenase 1', other_designations='1,2-dihydroxy-3-keto-5-methylthiopentene dioxygenase|MT1-MMP cytoplasmic tail-binding protein-1|acireductone dioxygenase (Fe(2+)-requiring)|acireductone dioxygenase (Ni(2+)-requiring)|membrane-type 1 matrix metalloproteinase cytoplasmic tail binding protein-1|submergence induced protein 2|submergence-induced protein-like factor', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3497366, end_position_on_the_genomic_accession=3519531, orientation='minus', exon_count=5, OMIM=[613400], no_hdr0=''),
    55257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55257, CurrentID=0, Status='live', Symbol='MRGBP', Aliases=['C20orf20', 'Eaf7', 'MRG15BP', 'URCC4'], description='MRG domain binding protein', other_designations='MRG/MORF4L-binding protein|MRG-binding protein|MRG/MORF4L binding protein|up-regulated in colon cancer 4', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62796473, end_position_on_the_genomic_accession=62801729, orientation='plus', exon_count=5, OMIM=[611157], no_hdr0=''),
    55258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55258, CurrentID=0, Status='live', Symbol='THNSL2', Aliases=['SOFAT', 'THS2', 'TSH2'], description='threonine synthase like 2', other_designations='threonine synthase-like 2|secreted osteoclastogenic factor of activated T cells', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88170346, end_position_on_the_genomic_accession=88186631, orientation='plus', exon_count=9, OMIM=[611261], no_hdr0=''),
    55259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55259, CurrentID=0, Status='live', Symbol='DNAI7', Aliases=['CASC1', 'CFAP94', 'LAS1', 'PPP1R54'], description='dynein axonemal intermediate chain 7', other_designations='dynein axonemal intermediate chain 7|dynein intermediate chain CFAP94, axonemal|cancer susceptibility 1|cancer susceptibility candidate 1|cancer susceptibility candidate gene 1 protein|cilia and flagella associated protein 94|lung adenoma susceptibility 1-like protein|protein CASC1|protein phosphatase 1 regulatory subunit 54', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=25107057, end_position_on_the_genomic_accession=25195160, orientation='minus', exon_count=19, OMIM=[616906], no_hdr0=''),
    55260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55260, CurrentID=0, Status='live', Symbol='TMEM143', Aliases=[], description='transmembrane protein 143', other_designations='transmembrane protein 143', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48332356, end_position_on_the_genomic_accession=48363940, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    55262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55262, CurrentID=0, Status='live', Symbol='TRAPPC14', Aliases=['C7orf43', 'MAP11', 'MCPH25'], description='trafficking protein particle complex subunit 14', other_designations='trafficking protein particle complex subunit 14|microtubule associated protein 11|trafficking protein particle complex 14|uncharacterized protein C7orf43', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100154423, end_position_on_the_genomic_accession=100158723, orientation='minus', exon_count=11, OMIM=[618350], no_hdr0=''),
    55266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55266, CurrentID=0, Status='live', Symbol='TMEM19', Aliases=[], description='transmembrane protein 19', other_designations='transmembrane protein 19', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71686082, end_position_on_the_genomic_accession=71705047, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    55268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55268, CurrentID=0, Status='live', Symbol='ECHDC2', Aliases=[], description='enoyl-CoA hydratase domain containing 2', other_designations='enoyl-CoA hydratase domain-containing protein 2, mitochondrial|enoyl Coenzyme A hydratase domain containing 2', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52895910, end_position_on_the_genomic_accession=52927212, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    55269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55269, CurrentID=0, Status='live', Symbol='PSPC1', Aliases=['PSP1'], description='paraspeckle component 1', other_designations='paraspeckle component 1|paraspeckle protein 1', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19674752, end_position_on_the_genomic_accession=19782945, orientation='minus', exon_count=16, OMIM=[612408], no_hdr0=''),
    55270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55270, CurrentID=0, Status='live', Symbol='NUDT15', Aliases=['MTH2D', 'NUDT15'], description='nudix hydrolase 15', other_designations='nucleotide triphosphate diphosphatase NUDT15|8-oxo-dGTPase NUDT15|mutT homolog 2|nucleoside diphosphate-linked to another moiety X hydrolase 15|nudix (nucleoside diphosphate linked moiety X)-type motif 15|probable 7,8-dihydro-8-oxoguanine triphosphatase NUDT15|probable 8-oxo-dGTP diphosphatase NUDT15', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48037726, end_position_on_the_genomic_accession=48052755, orientation='plus', exon_count=5, OMIM=[615792], no_hdr0=''),
    55272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55272, CurrentID=0, Status='live', Symbol='IMP3', Aliases=['BRMS2', 'C15orf12', 'MRPS4'], description='IMP U3 small nucleolar ribonucleoprotein 3', other_designations='U3 small nucleolar ribonucleoprotein protein IMP3|IMP3, U3 small nucleolar ribonucleoprotein, homolog|U3 snoRNP protein 3 homolog|U3 snoRNP protein IMP3', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75639093, end_position_on_the_genomic_accession=75640224, orientation='minus', exon_count=1, OMIM=[612980], no_hdr0=''),
    55273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55273, CurrentID=0, Status='live', Symbol='TMEM100', Aliases=[], description='transmembrane protein 100', other_designations='transmembrane protein 100', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=55719627, end_position_on_the_genomic_accession=55732081, orientation='minus', exon_count=6, OMIM=[616334], no_hdr0=''),
    55274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55274, CurrentID=0, Status='live', Symbol='PHF10', Aliases=['BAF45A', 'XAP135'], description='PHD finger protein 10', other_designations='PHD finger protein 10|BRG1-associated factor 45a|BRG1-associated factor, 45-KD, A|PHD zinc finger protein XAP135', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169703902, end_position_on_the_genomic_accession=169724500, orientation='minus', exon_count=12, OMIM=[613069], no_hdr0=''),
    55275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55275, CurrentID=0, Status='live', Symbol='VPS53', Aliases=['HCCS1', 'PCH2E', 'hVps53L', 'pp13624'], description='VPS53 subunit of GARP complex', other_designations='vacuolar protein sorting-associated protein 53 homolog|VPS53, GARP complex subunit|hepatocellular carcinoma suppressor 1', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=508668, end_position_on_the_genomic_accession=714846, orientation='minus', exon_count=27, OMIM=[615850], no_hdr0=''),
    55276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55276, CurrentID=0, Status='live', Symbol='PGM2', Aliases=['MSTP006'], description='phosphoglucomutase 2', other_designations='phosphoglucomutase-2|PGM 2|glucose phosphomutase 2|phosphodeoxyribomutase', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37826686, end_position_on_the_genomic_accession=37862937, orientation='plus', exon_count=15, OMIM=[172000], no_hdr0=''),
    55277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55277, CurrentID=0, Status='live', Symbol='FGGY', Aliases=[], description='FGGY carbohydrate kinase domain containing', other_designations='FGGY carbohydrate kinase domain-containing protein|D-ribulokinase', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=59296405, end_position_on_the_genomic_accession=59762730, orientation='plus', exon_count=30, OMIM=[611370], no_hdr0=''),
    55278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55278, CurrentID=0, Status='live', Symbol='QRSL1', Aliases=['COXPD40', 'GatA'], description='glutaminyl-tRNA amidotransferase subunit QRSL1', other_designations='glutamyl-tRNA(Gln) amidotransferase subunit A, mitochondrial|QRSL1, glutaminyl-tRNA amidotransferase subunit A|glu-AdT subunit A|glutaminyl-tRNA synthase (glutamine-hydrolyzing)-like 1|glutaminyl-tRNA synthase-like protein 1|glutamyl-tRNA(Gln) amidotransferase subunit A homolog|glutamyl-tRNA(Gln) amidotransferase, subunit A', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106629578, end_position_on_the_genomic_accession=106668417, orientation='plus', exon_count=12, OMIM=[617209], no_hdr0=''),
    55279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55279, CurrentID=0, Status='live', Symbol='ZNF654', Aliases=[], description='zinc finger protein 654', other_designations='zinc finger protein 654|melanoma-associated antigen', map_location='3p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=88059197, end_position_on_the_genomic_accession=88144660, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    55280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55280, CurrentID=0, Status='live', Symbol='CWF19L1', Aliases=['C19L1', 'SCAR17', 'hDrn1'], description='CWF19 like cell cycle control factor 1', other_designations='CWF19-like protein 1|CWF19 like 1, cell cycle control|CWF19-like 1 cell cycle control|human Dbr1 associated ribonuclease 1', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100232298, end_position_on_the_genomic_accession=100267638, orientation='minus', exon_count=14, OMIM=[616120], no_hdr0=''),
    55281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55281, CurrentID=0, Status='live', Symbol='TMEM140', Aliases=[], description='transmembrane protein 140', other_designations='transmembrane protein 140', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135148072, end_position_on_the_genomic_accession=135166215, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    55282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55282, CurrentID=0, Status='live', Symbol='LRRC36', Aliases=['RORBP70', 'XLHSRF2'], description='leucine rich repeat containing 36', other_designations='leucine-rich repeat-containing protein 36|ROR gamma binding protein 70|heat shock regulated 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67326815, end_position_on_the_genomic_accession=67385206, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    55283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55283, CurrentID=0, Status='live', Symbol='MCOLN3', Aliases=['TRP-ML3', 'TRPML3'], description='mucolipin TRP cation channel 3', other_designations='mucolipin-3|mucolipin 3|transient receptor potential channel mucolipin 3', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85018082, end_position_on_the_genomic_accession=85048902, orientation='minus', exon_count=17, OMIM=[607400], no_hdr0=''),
    55284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55284, CurrentID=0, Status='live', Symbol='UBE2W', Aliases=['UBC-16', 'UBC16'], description='ubiquitin conjugating enzyme E2 W', other_designations='ubiquitin-conjugating enzyme E2 W|E2 ubiquitin-conjugating enzyme W|N-terminal E2 ubiquitin-conjugating enzyme|N-terminus-conjugating E2|ubiquitin carrier protein W|ubiquitin conjugating enzyme E2 W (putative)|ubiquitin conjugating enzyme E2W (putative)|ubiquitin-conjugating enzyme 16|ubiquitin-conjugating enzyme 2W|ubiquitin-protein ligase W', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73780096, end_position_on_the_genomic_accession=73878862, orientation='minus', exon_count=10, OMIM=[614277], no_hdr0=''),
    55285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55285, CurrentID=0, Status='live', Symbol='RBM41', Aliases=[], description='RNA binding motif protein 41', other_designations='RNA-binding protein 41', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107052102, end_position_on_the_genomic_accession=107118822, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    55286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55286, CurrentID=0, Status='live', Symbol='C4orf19', Aliases=[], description='chromosome 4 open reading frame 19', other_designations='uncharacterized protein C4orf19', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37453454, end_position_on_the_genomic_accession=37596146, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55287, CurrentID=0, Status='live', Symbol='TMEM40', Aliases=[], description='transmembrane protein 40', other_designations='transmembrane protein 40', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12733528, end_position_on_the_genomic_accession=12769457, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    55288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55288, CurrentID=0, Status='live', Symbol='RHOT1', Aliases=['ARHT1', 'MIRO-1', 'MIRO1'], description='ras homolog family member T1', other_designations='mitochondrial Rho GTPase 1|mitochondrial Rho (MIRO) GTPase 1|rac-GTP binding protein-like protein|ras homolog gene family, member T1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32142502, end_position_on_the_genomic_accession=32253374, orientation='plus', exon_count=28, OMIM=[613888], no_hdr0=''),
    55289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55289, CurrentID=0, Status='live', Symbol='ACOXL', Aliases=[], description='acyl-CoA oxidase like', other_designations='acyl-coenzyme A oxidase-like protein|acyl-CoA oxidase-like protein', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110732539, end_position_on_the_genomic_accession=111120610, orientation='plus', exon_count=34, OMIM=[], no_hdr0=''),
    55290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55290, CurrentID=0, Status='live', Symbol='BRF2', Aliases=['BRFU', 'TFIIIB50'], description='BRF2 RNA polymerase III transcription initiation factor subunit', other_designations='transcription factor IIIB 50 kDa subunit|B-related factor 2|BRF-2|BRF2, RNA polymerase III transcription initiation factor 50 kDa subunit|BRF2, subunit of RNA polymerase III transcription initiation factor, BRF1-like|RNA polymerase III transcription initiation factor BRFU|hBRFU|hTFIIIB50|transcription factor IIB- related factor, TFIIIB50', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37843268, end_position_on_the_genomic_accession=37849861, orientation='minus', exon_count=4, OMIM=[607013], no_hdr0=''),
    55291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55291, CurrentID=0, Status='live', Symbol='PPP6R3', Aliases=['C11orf23', 'PP6R3', 'SAP190', 'SAPL', 'SAPLa', 'SAPS3'], description='protein phosphatase 6 regulatory subunit 3', other_designations='serine/threonine-protein phosphatase 6 regulatory subunit 3|SAPS domain family, member 3|sporulation-induced transcript 4-associated protein SAPL', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68460724, end_position_on_the_genomic_accession=68615334, orientation='plus', exon_count=30, OMIM=[610879], no_hdr0=''),
    55293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55293, CurrentID=0, Status='live', Symbol='UEVLD', Aliases=['ATTP', 'UEV3'], description='UEV and lactate/malate dehyrogenase domains', other_designations='ubiquitin-conjugating enzyme E2 variant 3|EV and lactate/malate dehydrogenase domain-containing protein|UEV-3|signaling molecule ATTP', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18529609, end_position_on_the_genomic_accession=18588734, orientation='minus', exon_count=14, OMIM=[610985], no_hdr0=''),
    55294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55294, CurrentID=0, Status='live', Symbol='FBXW7', Aliases=['AGO', 'CDC4', 'FBW6', 'FBW7', 'FBX30', 'FBXO30', 'FBXW6', 'SEL-10', 'SEL10', 'hAgo', 'hCdc4'], description='F-box and WD repeat domain containing 7', other_designations='F-box/WD repeat-containing protein 7|F-box and WD repeat domain containing 7, E3 ubiquitin protein ligase|F-box and WD-40 domain protein 7 (archipelago homolog, Drosophila)|F-box protein FBW7|F-box protein FBX30|F-box protein SEL-10|archipelago|homolog of C elegans sel-10', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=152320544, end_position_on_the_genomic_accession=152536873, orientation='minus', exon_count=18, OMIM=[606278], no_hdr0=''),
    55295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55295, CurrentID=0, Status='live', Symbol='KLHL26', Aliases=[], description='kelch like family member 26', other_designations='kelch-like protein 26|kelch-like 26', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18637028, end_position_on_the_genomic_accession=18671721, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    55296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55296, CurrentID=0, Status='live', Symbol='TBC1D19', Aliases=[], description='TBC1 domain family member 19', other_designations='TBC1 domain family member 19', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=26584084, end_position_on_the_genomic_accession=26858919, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    55297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55297, CurrentID=0, Status='live', Symbol='CCDC91', Aliases=['HSD8', 'p56'], description='coiled-coil domain containing 91', other_designations='coiled-coil domain-containing protein 91|GGA-binding partner|p56 accessory protein', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=28190446, end_position_on_the_genomic_accession=28550166, orientation='plus', exon_count=21, OMIM=[617366], no_hdr0=''),
    55298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55298, CurrentID=0, Status='live', Symbol='RNF121', Aliases=[], description='ring finger protein 121', other_designations='RING finger protein 121', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71928701, end_position_on_the_genomic_accession=71997597, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    55299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55299, CurrentID=0, Status='live', Symbol='BRIX1', Aliases=['BRIX', 'BXDC2'], description='biogenesis of ribosomes BRX1', other_designations='ribosome biogenesis protein BRX1 homolog|BRX1, biogenesis of ribosomes, homolog|brix domain containing 2|brix domain-containing protein 2', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34915711, end_position_on_the_genomic_accession=34925996, orientation='plus', exon_count=10, OMIM=[618466], no_hdr0=''),
    55300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55300, CurrentID=0, Status='live', Symbol='PI4K2B', Aliases=['PI4KIIB', 'PIK42B'], description='phosphatidylinositol 4-kinase type 2 beta', other_designations='phosphatidylinositol 4-kinase type 2-beta|PI4KII-BETA|phosphatidylinositol 4-kinase type-II beta', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25234033, end_position_on_the_genomic_accession=25279204, orientation='plus', exon_count=11, OMIM=[612101], no_hdr0=''),
    55301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55301, CurrentID=0, Status='live', Symbol='OLAH', Aliases=['AURA1', 'SAST', 'TE2', 'THEDC1'], description='oleoyl-ACP hydrolase', other_designations='S-acyl fatty acid synthase thioesterase, medium chain|augmented in rheumatoid arthritis 1|oleoyl-acyl-carrier-protein hydrolase|thioesterase 2|thioesterase II|thioesterase domain containing 1|thioesterase domain-containing protein 1', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15032224, end_position_on_the_genomic_accession=15073853, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    55303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55303, CurrentID=0, Status='live', Symbol='GIMAP4', Aliases=['IAN-1', 'IAN1', 'IMAP4', 'MSTP062'], description='GTPase, IMAP family member 4', other_designations='GTPase IMAP family member 4|human immune associated nucleotide 1|immune-associated nucleotide-binding protein 1|immunity associated protein 4|immunity-associated nucleotide 1 protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150567390, end_position_on_the_genomic_accession=150573953, orientation='plus', exon_count=3, OMIM=[608087], no_hdr0=''),
    55304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55304, CurrentID=0, Status='live', Symbol='SPTLC3', Aliases=['C20orf38', 'LCB 3', 'LCB2B', 'LCB3', 'SPT 3', 'SPT3', 'SPTLC2L', 'dJ718P11', 'dJ718P11.1', 'hLCB2b'], description='serine palmitoyltransferase long chain base subunit 3', other_designations='serine palmitoyltransferase 3|long chain base biosynthesis protein 2b|long chain base biosynthesis protein 3|serine palmitoyltransferase, long chain base subunit 2-like (aminotransferase 2)|serine-palmitoyl-CoA transferase 3', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13008972, end_position_on_the_genomic_accession=13169103, orientation='plus', exon_count=15, OMIM=[611120], no_hdr0=''),
    55308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55308, CurrentID=0, Status='live', Symbol='DDX19A', Aliases=['DDX19-DDX19L', 'DDX19L'], description='DEAD-box helicase 19A', other_designations='ATP-dependent RNA helicase DDX19A|DDX19-like protein|DEAD (Asp-Glu-Ala-As) box polypeptide 19A|DEAD (Asp-Glu-Ala-Asp) box polypeptide 19A|DEAD box protein 19A|RNA helicase', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70346871, end_position_on_the_genomic_accession=70373383, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    55311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55311, CurrentID=0, Status='live', Symbol='ZNF444', Aliases=['EZF-2', 'EZF2', 'ZSCAN17'], description='zinc finger protein 444', other_designations='zinc finger protein 444|endothelial zinc finger protein 2|zinc finger and SCAN domain-containing protein 17', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56132509, end_position_on_the_genomic_accession=56160893, orientation='plus', exon_count=12, OMIM=[607874], no_hdr0=''),
    55312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55312, CurrentID=0, Status='live', Symbol='RFK', Aliases=['RIFK'], description='riboflavin kinase', other_designations="riboflavin kinase|0610038L10Rik|ATP:riboflavin 5'-phosphotransferase|flavokinase", map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=76385526, end_position_on_the_genomic_accession=76394426, orientation='minus', exon_count=4, OMIM=[613010], no_hdr0=''),
    55313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55313, CurrentID=0, Status='live', Symbol='CPPED1', Aliases=['CSTP1'], description='calcineurin like phosphoesterase domain containing 1', other_designations='serine/threonine-protein phosphatase CPPED1|calcineurin-like phosphoesterase domain-containing protein 1|complete S-transactivated protein 1', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=12659799, end_position_on_the_genomic_accession=12803887, orientation='minus', exon_count=4, OMIM=[615603], no_hdr0=''),
    55314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55314, CurrentID=0, Status='live', Symbol='TMEM144', Aliases=[], description='transmembrane protein 144', other_designations='transmembrane protein 144', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158201597, end_position_on_the_genomic_accession=158255416, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    55315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55315, CurrentID=0, Status='live', Symbol='SLC29A3', Aliases=['ENT3', 'HCLAP', 'HJCD', 'PHID'], description='solute carrier family 29 member 3', other_designations='equilibrative nucleoside transporter 3|solute carrier family 29 (equilibrative nucleoside transporter), member 3|solute carrier family 29 (nucleoside transporters), member 3', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71319259, end_position_on_the_genomic_accession=71363387, orientation='plus', exon_count=6, OMIM=[612373], no_hdr0=''),
    55316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55316, CurrentID=0, Status='live', Symbol='RSAD1', Aliases=['HemW'], description='radical S-adenosyl methionine domain containing 1', other_designations='radical S-adenosyl methionine domain-containing protein 1, mitochondrial|oxygen-independent coproporphyrinogen-III oxidase-like protein RSAD1|putative heme chaperone', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50478860, end_position_on_the_genomic_accession=50485974, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    55317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55317, CurrentID=0, Status='live', Symbol='AP5S1', Aliases=['C20orf29'], description='adaptor related protein complex 5 subunit sigma 1', other_designations='AP-5 complex subunit sigma-1|adapter-related protein complex 5 sigma subunit|adaptor related protein complex 5 sigma 1 subunit|adaptor-related protein complex 5 sigma subunit|protein C20orf29|sigma5', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3820547, end_position_on_the_genomic_accession=3828838, orientation='plus', exon_count=3, OMIM=[614824], no_hdr0=''),
    55319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55319, CurrentID=0, Status='live', Symbol='TMA16', Aliases=['C4orf43'], description='translation machinery associated 16 homolog', other_designations='translation machinery-associated protein 16|UPF0534 protein C4orf43', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163494690, end_position_on_the_genomic_accession=163520539, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55320, CurrentID=0, Status='live', Symbol='MIS18BP1', Aliases=['C14orf106', 'HSA242977', 'KNL2', 'M18BP1'], description='MIS18 binding protein 1', other_designations='mis18-binding protein 1|P243|hsKNL-2|kinetochore null 2 homolog|kinetochore-associated protein KNL-2 homolog|putative protein p243 which interacts with transcription factor Sp1', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=45203190, end_position_on_the_genomic_accession=45257190, orientation='minus', exon_count=19, OMIM=[618139], no_hdr0=''),
    55321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55321, CurrentID=0, Status='live', Symbol='TMEM74B', Aliases=['C20orf46'], description='transmembrane protein 74B', other_designations='transmembrane protein 74B|transmembrane protein C20orf46', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1180569, end_position_on_the_genomic_accession=1188138, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    55322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55322, CurrentID=0, Status='live', Symbol='C5orf22', Aliases=[], description='chromosome 5 open reading frame 22', other_designations='UPF0489 protein C5orf22', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=31532275, end_position_on_the_genomic_accession=31555053, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    55323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55323, CurrentID=0, Status='live', Symbol='LARP6', Aliases=['ACHN'], description='La ribonucleoprotein 6, translational regulator', other_designations='la-related protein 6|La ribonucleoprotein domain family member 6|acheron|death-associated LA motif protein', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=70829130, end_position_on_the_genomic_accession=70854157, orientation='minus', exon_count=5, OMIM=[611300], no_hdr0=''),
    55324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55324, CurrentID=0, Status='live', Symbol='ABCF3', Aliases=['EST201864'], description='ATP binding cassette subfamily F member 3', other_designations='ATP-binding cassette sub-family F member 3|ATP-binding cassette, sub-family F (GCN20), member 3', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184186160, end_position_on_the_genomic_accession=184194012, orientation='plus', exon_count=21, OMIM=[618967], no_hdr0=''),
    55325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55325, CurrentID=0, Status='live', Symbol='UFSP2', Aliases=['BHD', 'C4orf20', 'SEMDDR'], description='UFM1 specific peptidase 2', other_designations='ufm1-specific protease 2', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185399537, end_position_on_the_genomic_accession=185425964, orientation='minus', exon_count=12, OMIM=[611482], no_hdr0=''),
    55326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55326, CurrentID=0, Status='live', Symbol='AGPAT5', Aliases=['1AGPAT5', 'LPAATE'], description='1-acylglycerol-3-phosphate O-acyltransferase 5', other_designations='1-acyl-sn-glycerol-3-phosphate acyltransferase epsilon|1-AGP acyltransferase 5|1-AGPAT 5|1-acylglycerol-3-phosphate O-acyltransferase 5 (lysophosphatidic acid acyltransferase, epsilon)|lysophosphatidic acid acyltransferase epsilon|testicular tissue protein Li 144', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6708587, end_position_on_the_genomic_accession=6761503, orientation='plus', exon_count=8, OMIM=[614796], no_hdr0=''),
    55327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55327, CurrentID=0, Status='live', Symbol='LIN7C', Aliases=['LIN-7-C', 'LIN-7C', 'MALS-3', 'MALS3', 'VELI3'], description='lin-7 homolog C, crumbs cell polarity complex component', other_designations='protein lin-7 homolog C|LIN-7 protein 3|mammalian lin-seven protein 3|veli-3|vertebrate lin-7 homolog 3', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=27494418, end_position_on_the_genomic_accession=27506769, orientation='minus', exon_count=5, OMIM=[612332], no_hdr0=''),
    55328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55328, CurrentID=0, Status='live', Symbol='RNLS', Aliases=['C10orf59', 'RENALASE'], description='renalase, FAD dependent amine oxidase', other_designations='renalase|MAO-C|alpha-NAD(P)H oxidase/anomerase|monoamine oxidase-C', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88176052, end_position_on_the_genomic_accession=88584480, orientation='minus', exon_count=16, OMIM=[609360], no_hdr0=''),
    55329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55329, CurrentID=0, Status='live', Symbol='MNS1', Aliases=['HTX9', 'SPATA40'], description='meiosis specific nuclear structural 1', other_designations='meiosis-specific nuclear structural protein 1|spermatogenesis associated 40', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=56428724, end_position_on_the_genomic_accession=56465137, orientation='minus', exon_count=10, OMIM=[610766], no_hdr0=''),
    55330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55330, CurrentID=0, Status='live', Symbol='BLOC1S4', Aliases=['BCAS4L', 'BLOS4', 'CNO'], description='biogenesis of lysosomal organelles complex 1 subunit 4', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 4|BLOC-1 subunit 4|biogenesis of lysosomal organelles complex-1, subunit 4, cappuccino|cappuccino homolog|protein cappuccino homolog', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6716174, end_position_on_the_genomic_accession=6717664, orientation='plus', exon_count=1, OMIM=[605695], no_hdr0=''),
    55331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55331, CurrentID=0, Status='live', Symbol='ACER3', Aliases=['APHC', 'PHCA', 'PLDECO'], description='alkaline ceramidase 3', other_designations='alkaline ceramidase 3|alkCDase 3|alkaline CDase 3|alkaline dihydroceramidase SB89|alkaline phytoceramidase|phytoceramidase, alkaline', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76860888, end_position_on_the_genomic_accession=77026797, orientation='plus', exon_count=16, OMIM=[617036], no_hdr0=''),
    55332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55332, CurrentID=0, Status='live', Symbol='DRAM1', Aliases=['DRAM'], description='DNA damage regulated autophagy modulator 1', other_designations='DNA damage-regulated autophagy modulator protein 1|damage-regulated autophagy modulator', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101877327, end_position_on_the_genomic_accession=101923623, orientation='plus', exon_count=8, OMIM=[610776], no_hdr0=''),
    55333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55333, CurrentID=0, Status='live', Symbol='SYNJ2BP', Aliases=['ARIP2', 'OMP25'], description='synaptojanin 2 binding protein', other_designations='synaptojanin-2-binding protein|activin receptor interacting protein 5|mitochondrial outer membrane protein 25', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70366499, end_position_on_the_genomic_accession=70417090, orientation='minus', exon_count=4, OMIM=[609411], no_hdr0=''),
    55334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55334, CurrentID=0, Status='live', Symbol='SLC39A9', Aliases=['ZIP-9', 'ZIP9'], description='solute carrier family 39 member 9', other_designations='zinc transporter ZIP9|solute carrier family 39 (zinc transporter), member 9|zinc transporter SLC39A9|zrt- and Irt-like protein 9', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69398374, end_position_on_the_genomic_accession=69462390, orientation='plus', exon_count=9, OMIM=[619116], no_hdr0=''),
    55335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55335, CurrentID=0, Status='live', Symbol='NIPSNAP3B', Aliases=['FP944', 'NIPSNAP3', 'SNAP1'], description='nipsnap homolog 3B', other_designations='protein NipSnap homolog 3B', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104763741, end_position_on_the_genomic_accession=104777764, orientation='plus', exon_count=8, OMIM=[608872], no_hdr0=''),
    55336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55336, CurrentID=0, Status='live', Symbol='FBXL8', Aliases=['FBL8'], description='F-box and leucine rich repeat protein 8', other_designations='F-box/LRR-repeat protein 8|F-box protein FBL8', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67159957, end_position_on_the_genomic_accession=67164174, orientation='plus', exon_count=3, OMIM=[609077], no_hdr0=''),
    55337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55337, CurrentID=0, Status='live', Symbol='SHFL', Aliases=['C19orf66', 'IRAV', 'RyDEN', 'SFL'], description='shiftless antiviral inhibitor of ribosomal frameshifting', other_designations='shiftless antiviral inhibitor of ribosomal frameshifting protein|Repressor of yield of Dengue virus|UPF0515 protein C19orf66|interferon-regulated antiviral protein|repressor of yield of DENV protein|shiftless', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10086119, end_position_on_the_genomic_accession=10093249, orientation='plus', exon_count=10, OMIM=[616808], no_hdr0=''),
    55339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55339, CurrentID=0, Status='live', Symbol='WDR33', Aliases=['NET14', 'WDC146'], description='WD repeat domain 33', other_designations="pre-mRNA 3' end processing protein WDR33|WD repeat-containing protein 33|WD repeat-containing protein WDC146|WD repeat-containing protein of 146 kDa", map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127701027, end_position_on_the_genomic_accession=127811187, orientation='minus', exon_count=25, OMIM=[618082], no_hdr0=''),
    55340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55340, CurrentID=0, Status='live', Symbol='GIMAP5', Aliases=['HIMAP3', 'IAN-5', 'IAN4', 'IAN4L1', 'IAN5', 'IMAP3', 'IROD'], description='GTPase, IMAP family member 5', other_designations='GTPase IMAP family member 5|immune associated nucleotide 4 like 1|immune-associated nucleotide-binding protein 5|immunity associated protein 3|immunity-associated nucleotide 5 protein|inhibitor of radiation- and OA-induced apoptosis, Irod/Ian5', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150737418, end_position_on_the_genomic_accession=150743646, orientation='plus', exon_count=3, OMIM=[608086], no_hdr0=''),
    55341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55341, CurrentID=0, Status='live', Symbol='LSG1', Aliases=[], description='large 60S subunit nuclear export GTPase 1', other_designations='large subunit GTPase 1 homolog|hLsg1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194640788, end_position_on_the_genomic_accession=194672191, orientation='minus', exon_count=15, OMIM=[610780], no_hdr0=''),
    55342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55342, CurrentID=0, Status='live', Symbol='STRBP', Aliases=['HEL162', 'ILF3L', 'SPNR', 'p74'], description='spermatid perinuclear RNA binding protein', other_designations='spermatid perinuclear RNA-binding protein|epididymis luminal protein 162|epididymis secretory sperm binding protein', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=123109494, end_position_on_the_genomic_accession=123268586, orientation='minus', exon_count=26, OMIM=[611138], no_hdr0=''),
    55343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55343, CurrentID=0, Status='live', Symbol='SLC35C1', Aliases=['CDG2C', 'FUCT1'], description='solute carrier family 35 member C1', other_designations='GDP-fucose transporter 1|solute carrier family 35 (GDP-fucose transporter), member C1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45804072, end_position_on_the_genomic_accession=45813016, orientation='plus', exon_count=5, OMIM=[605881], no_hdr0=''),
    55344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55344, CurrentID=0, Status='live', Symbol='PLCXD1', Aliases=['LL0XNC01-136G2.1'], description='phosphatidylinositol specific phospholipase C X domain containing 1', other_designations='PI-PLC X domain-containing protein 1', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=276356, end_position_on_the_genomic_accession=303356, orientation='plus', exon_count=12, OMIM=[300974], no_hdr0=''),
    55345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55345, CurrentID=0, Status='live', Symbol='ZGRF1', Aliases=['C4orf21'], description='zinc finger GRF-type containing 1', other_designations='protein ZGRF1|GRF-type zinc finger domain-containing protein 1', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112539339, end_position_on_the_genomic_accession=112636995, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    55346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55346, CurrentID=0, Status='live', Symbol='TCP11L1', Aliases=['dJ85M6.3'], description='t-complex 11 like 1', other_designations='T-complex protein 11-like protein 1|t-complex 11, testis-specific-like 1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33039499, end_position_on_the_genomic_accession=33079454, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    55347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55347, CurrentID=0, Status='live', Symbol='ABHD10', Aliases=[], description='abhydrolase domain containing 10, depalmitoylase', other_designations='palmitoyl-protein thioesterase ABHD10, mitochondrial|abhydrolase domain-containing protein 10, mitochondrial|acyl-protein thioesterase ABHD10|alpha/beta hydrolase domain-containing protein 10, mitochondrial|mycophenolic acid acyl-glucuronide esterase, mitochondrial', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111979026, end_position_on_the_genomic_accession=111993368, orientation='plus', exon_count=6, OMIM=[618756], no_hdr0=''),
    55349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55349, CurrentID=0, Status='live', Symbol='CHDH', Aliases=[], description='choline dehydrogenase', other_designations='choline dehydrogenase, mitochondrial|CDH|CHD', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53812335, end_position_on_the_genomic_accession=53846419, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55351, CurrentID=0, Status='live', Symbol='STK32B', Aliases=['HSA250839', 'STK32', 'STKG6', 'YANK2'], description='serine/threonine kinase 32B', other_designations='serine/threonine-protein kinase 32B|gene for serine/threonine protein kinase|yet another novel kinase 2', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5051480, end_position_on_the_genomic_accession=5500994, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    55352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55352, CurrentID=0, Status='live', Symbol='COPRS', Aliases=['C17orf79', 'COPR5', 'HSA272196', 'TTP1'], description='coordinator of PRMT5 and differentiation stimulator', other_designations='coordinator of PRMT5 and differentiation stimulator|cooperator of PRMT5|coordinator of PRMT5, differentiation stimulator', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31851871, end_position_on_the_genomic_accession=31859244, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    55353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55353, CurrentID=0, Status='live', Symbol='LAPTM4B', Aliases=['LAPTM4beta', 'LC27'], description='lysosomal protein transmembrane 4 beta', other_designations='lysosomal-associated transmembrane protein 4B|lysosomal associated protein transmembrane 4 beta|lysosome-associated transmembrane protein 4-beta', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=97775788, end_position_on_the_genomic_accession=97853013, orientation='plus', exon_count=7, OMIM=[613296], no_hdr0=''),
    55355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55355, CurrentID=0, Status='live', Symbol='HJURP', Aliases=['FAKTS', 'URLC9', 'hFLEG1'], description='Holliday junction recognition protein', other_designations='Holliday junction recognition protein|14-3-3-associated AKT substrate|fetal liver expressing gene 1|fetal liver-expressing gene 1 protein|up-regulated in lung cancer 9', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233836702, end_position_on_the_genomic_accession=233854535, orientation='minus', exon_count=9, OMIM=[612667], no_hdr0=''),
    55356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55356, CurrentID=0, Status='live', Symbol='SLC22A15', Aliases=['FLIPT1', 'PRO34686'], description='solute carrier family 22 member 15', other_designations='solute carrier family 22 member 15|flipt 1|fly-like putative organic ion transporter 1|fly-like putative transporter 1|solute carrier family 22 (organic cation transporter), member 15|trans-like protein', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115976513, end_position_on_the_genomic_accession=116070054, orientation='plus', exon_count=15, OMIM=[608275], no_hdr0=''),
    55357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55357, CurrentID=0, Status='live', Symbol='TBC1D2', Aliases=['PARIS-1', 'PARIS1A', 'TBC1D2'], description='TBC1 domain family member 2', other_designations='TBC1 domain family member 2A|TBC1 domain family, member 2A|armus|prostate antigen recognized and identified by SEREX 1', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98198998, end_position_on_the_genomic_accession=98255649, orientation='minus', exon_count=17, OMIM=[609871], no_hdr0=''),
    55359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55359, CurrentID=0, Status='live', Symbol='STYK1', Aliases=['NOK', 'SuRTK106'], description='serine/threonine/tyrosine kinase 1', other_designations='tyrosine-protein kinase STYK1|novel oncogene with kinase domain|protein PK-unique', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10618923, end_position_on_the_genomic_accession=10674318, orientation='minus', exon_count=14, OMIM=[611433], no_hdr0=''),
    55361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55361, CurrentID=0, Status='live', Symbol='PI4K2A', Aliases=['PI4KII', 'PIK42A'], description='phosphatidylinositol 4-kinase type 2 alpha', other_designations='phosphatidylinositol 4-kinase type 2-alpha|phosphatidylinositol 4-kinase type II (PI4KII)|phosphatidylinositol 4-kinase type II-alpha', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97640686, end_position_on_the_genomic_accession=97676434, orientation='plus', exon_count=9, OMIM=[609763], no_hdr0=''),
    55362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55362, CurrentID=0, Status='live', Symbol='TMEM63B', Aliases=['C6orf110'], description='transmembrane protein 63B', other_designations='CSC1-like protein 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44126628, end_position_on_the_genomic_accession=44155519, orientation='plus', exon_count=27, OMIM=[], no_hdr0=''),
    55363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55363, CurrentID=0, Status='live', Symbol='HEMGN', Aliases=['CT155', 'EDAG', 'EDAG-1', 'NDR'], description='hemogen', other_designations='hemogen|erythroid differentiation-associated gene protein|hemopoietic gene protein|negative differentiation regulator protein', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97926791, end_position_on_the_genomic_accession=97944852, orientation='minus', exon_count=6, OMIM=[610715], no_hdr0=''),
    55364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55364, CurrentID=0, Status='live', Symbol='IMPACT', Aliases=['RWDD5'], description='impact RWD domain protein', other_designations='protein IMPACT|Impact homolog|RWD domain containing 5|imprinted and ancient gene protein homolog', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=24426670, end_position_on_the_genomic_accession=24453531, orientation='plus', exon_count=12, OMIM=[615319], no_hdr0=''),
    55365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55365, CurrentID=0, Status='live', Symbol='TMEM176A', Aliases=['GS188', 'HCA112', 'MS4B1'], description='transmembrane protein 176A', other_designations='transmembrane protein 176A|hepatocellular carcinoma-associated antigen 112|likley ortholog of mouse GS188', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150800543, end_position_on_the_genomic_accession=150805119, orientation='plus', exon_count=7, OMIM=[610334], no_hdr0=''),
    55366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55366, CurrentID=0, Status='live', Symbol='LGR4', Aliases=['BNMD17', 'GPR48'], description='leucine rich repeat containing G protein-coupled receptor 4', other_designations='leucine-rich repeat-containing G-protein coupled receptor 4|G protein-coupled receptor 48', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=27365961, end_position_on_the_genomic_accession=27472790, orientation='minus', exon_count=18, OMIM=[606666], no_hdr0=''),
    55367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55367, CurrentID=0, Status='live', Symbol='PIDD1', Aliases=['LRDD', 'PIDD'], description='p53-induced death domain protein 1', other_designations='p53-induced death domain-containing protein 1|leucine-rich repeat and death domain-containing protein|leucine-rich repeats and death domain containing|p53-induced protein with a death domain', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=799179, end_position_on_the_genomic_accession=809867, orientation='minus', exon_count=18, OMIM=[605247], no_hdr0=''),
    55374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55374, CurrentID=0, Status='live', Symbol='TMCO6', Aliases=['PRO1580'], description='transmembrane and coiled-coil domains 6', other_designations='transmembrane and coiled-coil domain-containing protein 6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140596529, end_position_on_the_genomic_accession=140647411, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    55379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55379, CurrentID=0, Status='live', Symbol='LRRC59', Aliases=['PRO1855', 'p34'], description='leucine rich repeat containing 59', other_designations='leucine-rich repeat-containing protein 59|ribosome-binding protein p34', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50381238, end_position_on_the_genomic_accession=50397523, orientation='minus', exon_count=7, OMIM=[614854], no_hdr0=''),
    55388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55388, CurrentID=0, Status='live', Symbol='MCM10', Aliases=['CNA43', 'DNA43', 'IMD80', 'PRO2249'], description='minichromosome maintenance 10 replication initiation factor', other_designations='protein MCM10 homolog|MCM10 minichromosome maintenance deficient 10|homolog of yeast MCM10|hsMCM10|minichromosome maintenance complex component 10', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13161558, end_position_on_the_genomic_accession=13211110, orientation='plus', exon_count=21, OMIM=[609357], no_hdr0=''),
    55390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55390, CurrentID=0, Status='live', Symbol='PRO2268', Aliases=[], description='uncharacterized protein PRO2268', other_designations='uncharacterized protein LOC55390', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[614354], no_hdr0=''),
    55421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55421, CurrentID=0, Status='live', Symbol='NCBP3', Aliases=['C17orf85', 'ELG', 'HSA277841'], description='nuclear cap binding subunit 3', other_designations='nuclear cap-binding protein subunit 3|CTD-3195I5.1|CTD-3195I5.5', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3802158, end_position_on_the_genomic_accession=3846246, orientation='minus', exon_count=15, OMIM=[616624], no_hdr0=''),
    55422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55422, CurrentID=0, Status='live', Symbol='ZNF331', Aliases=['RITA', 'ZNF361', 'ZNF463'], description='zinc finger protein 331', other_designations='zinc finger protein 331|C2H2-like zinc finger protein rearranged in thyroid adenomas|KRAB zinc finger protein|zinc finger protein 361|zinc finger protein 463', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53503819, end_position_on_the_genomic_accession=53580269, orientation='plus', exon_count=22, OMIM=[606043], no_hdr0=''),
    55423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55423, CurrentID=0, Status='live', Symbol='SIRPG', Aliases=['CD172g', 'SIRP-B2', 'SIRPB2', 'SIRPgamma', 'bA77C3.1'], description='signal regulatory protein gamma', other_designations='signal-regulatory protein gamma|CD172 antigen-like family member B|CD172g antigen|SIRP beta 2|SIRP-gamma|signal-regulatory protein beta-2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1629152, end_position_on_the_genomic_accession=1686516, orientation='minus', exon_count=8, OMIM=[605466], no_hdr0=''),
    55425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55425, CurrentID=0, Status='live', Symbol='GPALPP1', Aliases=['AD029', 'KIAA1704', 'LSR7', 'bA245H20.2'], description='GPALPP motifs containing 1', other_designations='GPALPP motifs-containing protein 1|lipopolysaccharide specific response-7 protein|lipopolysaccharide-specific response protein 7', map_location='13q14.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=44989538, end_position_on_the_genomic_accession=45037669, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    55432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55432, CurrentID=0, Status='live', Symbol='YOD1', Aliases=['DUBA8', 'OTUD2', 'PRO0907'], description='YOD1 deubiquitinase', other_designations='ubiquitin thioesterase OTU1|DUBA-8|HIN-7|HIV-1-induced protease 7|OTU domain containing 2|OTU domain-containing protein 2|YOD1 OTU deubiquinating enzyme 1 homolog ( yeast)|hsHIN7', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207043849, end_position_on_the_genomic_accession=207053116, orientation='minus', exon_count=4, OMIM=[612023], no_hdr0=''),
    55435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55435, CurrentID=0, Status='live', Symbol='AP1AR', Aliases=['2C18', 'C4orf16', 'GBAR', 'PRO0971', 'gamma-BAR'], description='adaptor related protein complex 1 associated regulatory protein', other_designations='AP-1 complex-associated regulatory protein|adapter-related protein complex 1-associated regulatory protein|gadkin|gamma-1-adaptin brefeldin A resistance protein|gamma-A1-adaptin and kinesin interactor|gamma1-adaptin brefeldin A resistance protein, gamma-BAR', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112231787, end_position_on_the_genomic_accession=112273110, orientation='plus', exon_count=12, OMIM=[610851], no_hdr0=''),
    55437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55437, CurrentID=0, Status='live', Symbol='STRADB', Aliases=['ALS2CR2', 'CALS-21', 'ILPIP', 'ILPIPA', 'PAPK', 'PRO1038'], description='STE20 related adaptor beta', other_designations='STE20-related kinase adapter protein beta|ILP-interacting protein ILPIPA|STE20-related kinase adaptor beta|STRAD beta|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 2|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 2 protein|pseudokinase ALS2CR2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201451734, end_position_on_the_genomic_accession=201480846, orientation='plus', exon_count=12, OMIM=[607333], no_hdr0=''),
    55450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55450, CurrentID=0, Status='live', Symbol='CAMK2N1', Aliases=['PRO1489'], description='calcium/calmodulin dependent protein kinase II inhibitor 1', other_designations='calcium/calmodulin-dependent protein kinase II inhibitor 1|CaMKIINalpha|caMKII inhibitory protein alpha|caMKIIN-alpha', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20482391, end_position_on_the_genomic_accession=20486210, orientation='minus', exon_count=2, OMIM=[614986], no_hdr0=''),
    55454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55454, CurrentID=0, Status='live', Symbol='CSGALNACT2', Aliases=['CHGN2', 'ChGn-2', 'GALNACT-2', 'GALNACT2', 'PRO0082', 'beta4GalNAcT'], description='chondroitin sulfate N-acetylgalactosaminyltransferase 2', other_designations='chondroitin sulfate N-acetylgalactosaminyltransferase 2|beta 4 GalNAcT-2|chondroitin beta1,4 N-acetylgalactosaminyltransferase 2|glucuronylgalactosylproteoglycan 4-beta-N-acetylgalactosaminyltransferase 2', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43138445, end_position_on_the_genomic_accession=43185308, orientation='plus', exon_count=11, OMIM=[616616], no_hdr0=''),
    55466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55466, CurrentID=0, Status='live', Symbol='DNAJA4', Aliases=['MST104', 'MSTP104', 'PRO1472'], description='DnaJ heat shock protein family (Hsp40) member A4', other_designations='dnaJ homolog subfamily A member 4|DnaJ (Hsp40) homolog, subfamily A, member 4', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78264145, end_position_on_the_genomic_accession=78282191, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    55471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55471, CurrentID=0, Status='live', Symbol='NDUFAF7', Aliases=['C2orf56', 'MidA', 'PRO1853'], description='NADH:ubiquinone oxidoreductase complex assembly factor 7', other_designations='protein arginine methyltransferase NDUFAF7, mitochondrial|NADH dehydrogenase (ubiquinone) complex I, assembly factor 7|NADH dehydrogenase [ubiquinone] complex I, assembly factor 7|mitochondrial dysfunction protein A homolog|protein midA homolog, mitochondrial', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37231658, end_position_on_the_genomic_accession=37271365, orientation='plus', exon_count=14, OMIM=[615898], no_hdr0=''),
    55486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55486, CurrentID=0, Status='live', Symbol='PARL', Aliases=['PRO2207', 'PSARL', 'PSARL1', 'PSENIP2', 'RHBDS1'], description='presenilin associated rhomboid like', other_designations='presenilins-associated rhomboid-like protein, mitochondrial|mitochondrial intramembrane-cleaving protease PARL|rhomboid 7 homolog 1', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183826488, end_position_on_the_genomic_accession=183884901, orientation='minus', exon_count=13, OMIM=[607858], no_hdr0=''),
    55500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55500, CurrentID=0, Status='live', Symbol='ETNK1', Aliases=['EKI', 'EKI 1', 'EKI1', 'Nbla10396'], description='ethanolamine kinase 1', other_designations='ethanolamine kinase 1|putative protein product of Nbla10396', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=22625145, end_position_on_the_genomic_accession=22690665, orientation='plus', exon_count=13, OMIM=[609858], no_hdr0=''),
    55501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55501, CurrentID=0, Status='live', Symbol='CHST12', Aliases=['C4S-2', 'C4ST-2', 'C4ST2'], description='carbohydrate sulfotransferase 12', other_designations='carbohydrate sulfotransferase 12|carbohydrate (chondroitin 4) sulfotransferase 12|chondroitin 4-O-sulfotransferase 2|chondroitin 4-sulfotransferase 2|sulfotransferase Hlo', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2403489, end_position_on_the_genomic_accession=2448484, orientation='plus', exon_count=8, OMIM=[610129], no_hdr0=''),
    55502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55502, CurrentID=0, Status='live', Symbol='HES6', Aliases=['C-HAIRY1', 'HES-6', 'bHLHb41', 'bHLHc23'], description='hes family bHLH transcription factor 6', other_designations='transcription cofactor HES-6|class B basic helix-loop-helix protein 41|hairy and enhancer of split 6', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238238267, end_position_on_the_genomic_accession=238240038, orientation='minus', exon_count=4, OMIM=[610331], no_hdr0=''),
    55503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55503, CurrentID=0, Status='live', Symbol='TRPV6', Aliases=['ABP/ZF', 'CAT1', 'CATL', 'ECAC2', 'HRPTTN', 'HSA277909', 'LP6728', 'ZFAB'], description='transient receptor potential cation channel subfamily V member 6', other_designations='transient receptor potential cation channel subfamily V member 6|Alu-binding protein with zinc finger domain|calcium transport protein 1|calcium transporter-like protein|epithelial apical membrane calcium transporter/channel CaT1|epithelial calcium channel 2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142871208, end_position_on_the_genomic_accession=142885745, orientation='minus', exon_count=15, OMIM=[606680], no_hdr0=''),
    55504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55504, CurrentID=0, Status='live', Symbol='TNFRSF19', Aliases=['TAJ', 'TAJ-alpha', 'TRADE', 'TROY'], description='TNF receptor superfamily member 19', other_designations='tumor necrosis factor receptor superfamily member 19|toxicity and JNK inducer', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23570248, end_position_on_the_genomic_accession=23676093, orientation='plus', exon_count=12, OMIM=[606122], no_hdr0=''),
    55505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55505, CurrentID=0, Status='live', Symbol='NOP10', Aliases=['DKCB1', 'NOLA3P', 'NOP10'], description='NOP10 ribonucleoprotein', other_designations='H/ACA ribonucleoprotein complex subunit 3|NOP10 ribonucleoprotein homolog|homolog of yeast Nop10p|nucleolar protein 10|nucleolar protein family A member 3|nucleolar protein family A, member 3 (H/ACA small nucleolar RNPs)|snoRNP protein NOP10', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34341719, end_position_on_the_genomic_accession=34343136, orientation='minus', exon_count=2, OMIM=[606471], no_hdr0=''),
    55506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55506, CurrentID=0, Status='live', Symbol='MACROH2A2', Aliases=['H2AFY2'], description='macroH2A.2 histone', other_designations='core histone macro-H2A.2|H2A histone family member Y2|core histone macroH2A2.2|histone macroH2A2|mH2A2', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70052846, end_position_on_the_genomic_accession=70112282, orientation='plus', exon_count=9, OMIM=[616141], no_hdr0=''),
    55507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55507, CurrentID=0, Status='live', Symbol='GPRC5D', Aliases=[], description='G protein-coupled receptor class C group 5 member D', other_designations='G-protein coupled receptor family C group 5 member D|orphan G-protein coupled receptor', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12940518, end_position_on_the_genomic_accession=12955908, orientation='minus', exon_count=5, OMIM=[607437], no_hdr0=''),
    55508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55508, CurrentID=0, Status='live', Symbol='SLC35E3', Aliases=['BLOV1'], description='solute carrier family 35 member E3', other_designations='solute carrier family 35 member E3|bladder cancer-overexpressed gene 1 protein|solute carrier family 35, member E2', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68746176, end_position_on_the_genomic_accession=68781468, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55509, CurrentID=0, Status='live', Symbol='BATF3', Aliases=['JDP1', 'JUNDM1', 'SNFT'], description='basic leucine zipper ATF-like transcription factor 3', other_designations='basic leucine zipper transcriptional factor ATF-like 3|21 kDa small nuclear factor isolated from T-cells|21-kD small nuclear factor isolated from T cells|B-ATF-3|Jun dimerization protein 1|Jun dimerization protein p21SNFT|basic leucine zipper transcription factor, ATF-like 3', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212686417, end_position_on_the_genomic_accession=212699943, orientation='minus', exon_count=6, OMIM=[612470], no_hdr0=''),
    55510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55510, CurrentID=0, Status='live', Symbol='DDX43', Aliases=['CT13', 'HAGE'], description='DEAD-box helicase 43', other_designations='probable ATP-dependent RNA helicase DDX43|DEAD (Asp-Glu-Ala-Asp) box polypeptide 43|DEAD box protein HAGE|DEAD-box protein 43|cancer/testis antigen 13|helical antigen', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73394828, end_position_on_the_genomic_accession=73417566, orientation='plus', exon_count=17, OMIM=[606286], no_hdr0=''),
    55511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55511, CurrentID=0, Status='live', Symbol='SAGE1', Aliases=['CT14', 'SAGE'], description='sarcoma antigen 1', other_designations='sarcoma antigen 1|cancer/testis antigen 14|putative tumor antigen', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135893700, end_position_on_the_genomic_accession=135913062, orientation='plus', exon_count=22, OMIM=[300359], no_hdr0=''),
    55512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55512, CurrentID=0, Status='live', Symbol='SMPD3', Aliases=['NSMASE2'], description='sphingomyelin phosphodiesterase 3', other_designations='sphingomyelin phosphodiesterase 3|nSMase-2|neutral sphingomyelinase 2|neutral sphingomyelinase II', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68358327, end_position_on_the_genomic_accession=68448703, orientation='minus', exon_count=16, OMIM=[605777], no_hdr0=''),
    55515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55515, CurrentID=0, Status='live', Symbol='ASIC4', Aliases=['ACCN4', 'BNAC4'], description='acid sensing ion channel subunit family member 4', other_designations='acid-sensing ion channel 4|acid sensing ion channel family member 4|acid-sensing (proton-gated) ion channel family member 4|amiloride-sensitive cation channel 4, pituitary|amiloride-sensitive cation channel family member 4, pituitary|brain sodium channel 4', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219514482, end_position_on_the_genomic_accession=219538772, orientation='plus', exon_count=11, OMIM=[606715], no_hdr0=''),
    55520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55520, CurrentID=0, Status='live', Symbol='ELAC1', Aliases=['D29'], description='elaC ribonuclease Z 1', other_designations="zinc phosphodiesterase ELAC protein 1|RNase Z 1|RNaseZ(S)|deleted in Ma29|elaC homolog 1|elaC homolog protein 1|ribonuclease Z 1|tRNA 3 endonuclease 1|tRNA 3' processing endoribonuclease|tRNA Z (short form)|tRNase Z 1|tRNase ZS", map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50968040, end_position_on_the_genomic_accession=50988121, orientation='plus', exon_count=4, OMIM=[608079], no_hdr0=''),
    55521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55521, CurrentID=0, Status='live', Symbol='TRIM36', Aliases=['ANPH', 'HAPRIN', 'RBCC728', 'RNF98'], description='tripartite motif containing 36', other_designations='E3 ubiquitin-protein ligase TRIM36|RING finger protein 98|RING-type E3 ubiquitin transferase TRIM36|tripartite motif protein 36|tripartite motif-containing protein 36|zinc-binding protein Rbcc728', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115124772, end_position_on_the_genomic_accession=115180296, orientation='minus', exon_count=16, OMIM=[609317], no_hdr0=''),
    55526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55526, CurrentID=0, Status='live', Symbol='DHTKD1', Aliases=['AAKAD', 'AMOXAD', 'CMT2Q'], description='dehydrogenase E1 and transketolase domain containing 1', other_designations='probable 2-oxoglutarate dehydrogenase E1 component DHKTD1, mitochondrial|dehydrogenase E1 and transketolase domain-containing protein 1', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12068954, end_position_on_the_genomic_accession=12123221, orientation='plus', exon_count=17, OMIM=[614984], no_hdr0=''),
    55527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55527, CurrentID=0, Status='live', Symbol='FEM1A', Aliases=['EPRAP'], description='fem-1 homolog A', other_designations='protein fem-1 homolog A|FEM1-alpha|prostaglandin E receptor 4-associated protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4791734, end_position_on_the_genomic_accession=4801273, orientation='plus', exon_count=1, OMIM=[613538], no_hdr0=''),
    55529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55529, CurrentID=0, Status='live', Symbol='PIP4P2', Aliases=['TMEM55A'], description='phosphatidylinositol-4,5-bisphosphate 4-phosphatase 2', other_designations='type 2 phosphatidylinositol 4,5-bisphosphate 4-phosphatase|PtdIns-4,5-P(2) 4-phosphatase type II|ptdIns-4,5-P2 4-Ptase II|transmembrane protein 55A|type 2 PtdIns-4,5-P2 4-Ptase|type II PtdIns-4,5-P(2) 4-phosphatase|type II phosphatidylinositol 4,5-bisphosphate 4-phosphatase', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90993802, end_position_on_the_genomic_accession=91040896, orientation='minus', exon_count=8, OMIM=[609864], no_hdr0=''),
    55530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55530, CurrentID=0, Status='live', Symbol='SVOP', Aliases=[], description='SV2 related protein', other_designations='synaptic vesicle 2-related protein|SV2 related protein homolog', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108907741, end_position_on_the_genomic_accession=109021068, orientation='minus', exon_count=16, OMIM=[611699], no_hdr0=''),
    55531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55531, CurrentID=0, Status='live', Symbol='ELMOD1', Aliases=[], description='ELMO domain containing 1', other_designations='ELMO domain-containing protein 1|ELMO/CED-12 domain containing 1', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107591009, end_position_on_the_genomic_accession=107666779, orientation='plus', exon_count=13, OMIM=[615456], no_hdr0=''),
    55532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55532, CurrentID=0, Status='live', Symbol='SLC30A10', Aliases=['HMDPC', 'HMNDYT1', 'ZNT10', 'ZNT8', 'ZRC1', 'ZnT-10'], description='solute carrier family 30 member 10', other_designations='zinc transporter 10|manganese transporter SLC30A10|zinc transporter 8', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=219910395, end_position_on_the_genomic_accession=219959098, orientation='minus', exon_count=6, OMIM=[611146], no_hdr0=''),
    55534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55534, CurrentID=0, Status='live', Symbol='MAML3', Aliases=['CAGH3', 'ERDA3', 'GDN', 'MAM-2', 'MAM2', 'TNRC3', 'mam-3'], description='mastermind like transcriptional coactivator 3', other_designations='mastermind-like protein 3|CAG repeat containing (glia-derived nexin I alpha)|expanded repeat domain, CAG/CTG 3|polyglutamine rich|trinucleotide repeat containing 3', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139716753, end_position_on_the_genomic_accession=140154184, orientation='minus', exon_count=5, OMIM=[608991], no_hdr0=''),
    55536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55536, CurrentID=0, Status='live', Symbol='CDCA7L', Aliases=['JPO2', 'R1', 'RAM2'], description='cell division cycle associated 7 like', other_designations='cell division cycle-associated 7-like protein|transcription factor RAM2', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=21900899, end_position_on_the_genomic_accession=21945899, orientation='minus', exon_count=11, OMIM=[609685], no_hdr0=''),
    55540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55540, CurrentID=0, Status='live', Symbol='IL17RB', Aliases=['CRL4', 'EVI27', 'IL17BR', 'IL17RH1'], description='interleukin 17 receptor B', other_designations='interleukin-17 receptor B|IL-17 receptor B|IL-17 receptor homolog 1|IL-17B receptor|IL-17RB|IL-17Rh1|cytokine receptor CRL4|cytokine receptor-like 4|interleukin 17 receptor homolog 1|interleukin-17B receptor', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53846568, end_position_on_the_genomic_accession=53865794, orientation='plus', exon_count=11, OMIM=[605458], no_hdr0=''),
    55544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55544, CurrentID=0, Status='live', Symbol='RBM38', Aliases=['HSRNASEB', 'RNPC1', 'SEB4B', 'SEB4D', 'dJ800J21.2'], description='RNA binding motif protein 38', other_designations='RNA-binding protein 38|CLL-associated antigen KW-5|RNA-binding region (RNP1, RRM) containing 1|RNA-binding region-containing protein 1|ssDNA-binding protein SEB4', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57391396, end_position_on_the_genomic_accession=57409333, orientation='plus', exon_count=6, OMIM=[612428], no_hdr0=''),
    55552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55552, CurrentID=0, Status='live', Symbol='ZNF823', Aliases=['HSZFP36'], description='zinc finger protein 823', other_designations='zinc finger protein 823|ZFP 36 for a zinc finger protein|zinc finger protein ZFP-36', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11721265, end_position_on_the_genomic_accession=11738997, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    55553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55553, CurrentID=0, Status='live', Symbol='SOX6', Aliases=['HSSOX6', 'SOXD', 'TOLCAS'], description='SRY-box transcription factor 6', other_designations='transcription factor SOX-6|SRY (sex determining region Y)-box 6|SRY-box 6|SRY-box containing gene 6', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=15966449, end_position_on_the_genomic_accession=16738477, orientation='minus', exon_count=22, OMIM=[607257], no_hdr0=''),
    55554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55554, CurrentID=0, Status='live', Symbol='KLK15', Aliases=['ACO', 'HSRNASPH'], description='kallikrein related peptidase 15', other_designations='kallikrein-15|ACO protease|kallikrein-like serine protease|prostinogen', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50825289, end_position_on_the_genomic_accession=50834337, orientation='minus', exon_count=6, OMIM=[610601], no_hdr0=''),
    55556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55556, CurrentID=0, Status='live', Symbol='ENOSF1', Aliases=['FUCD', 'RTS', 'TYMSAS'], description='enolase superfamily member 1', other_designations='mitochondrial enolase superfamily member 1|L-fuconate dehydratase|antisense RNA to thymidylate synthase', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=670318, end_position_on_the_genomic_accession=712660, orientation='minus', exon_count=19, OMIM=[607427], no_hdr0=''),
    55558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55558, CurrentID=0, Status='live', Symbol='PLXNA3', Aliases=['6.3', 'HSSEXGENE', 'PLXN3', 'PLXN4', 'XAP-6'], description='plexin A3', other_designations='plexin-A3|Sex chromosome X transmembrane protein of HGF receptor family 3|plexin-4|semaphorin receptor SEX', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154458281, end_position_on_the_genomic_accession=154477779, orientation='plus', exon_count=33, OMIM=[300022], no_hdr0=''),
    55559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55559, CurrentID=0, Status='live', Symbol='HAUS7', Aliases=['UCHL5IP', 'UIP1'], description='HAUS augmin like complex subunit 7', other_designations='HAUS augmin-like complex subunit 7|26S proteasome-associated UCH37-interacting protein 1|X-linked protein STS1769', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153447668, end_position_on_the_genomic_accession=153495465, orientation='minus', exon_count=14, OMIM=[300540], no_hdr0=''),
    55561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55561, CurrentID=0, Status='live', Symbol='CDC42BPG', Aliases=['DMPK2', 'HSMDPKIN', 'KAPPA-200', 'MRCKG', 'MRCKgamma'], description='CDC42 binding protein kinase gamma', other_designations='serine/threonine-protein kinase MRCK gamma|CDC42 binding protein kinase gamma (DMPK-like)|DMPK-like gamma|MRCK gamma|myotonic dystrophy kinase-related CDC42-binding kinase gamma|myotonic dystrophy protein kinase like protein|myotonic dystrophy protein kinase-like alpha|myotonic dystrophy protein kinase-like gamma', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64823052, end_position_on_the_genomic_accession=64844686, orientation='minus', exon_count=40, OMIM=[613991], no_hdr0=''),
    55565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55565, CurrentID=0, Status='live', Symbol='ZNF821', Aliases=[], description='zinc finger protein 821', other_designations='zinc finger protein 821', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71859680, end_position_on_the_genomic_accession=71885353, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    55567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55567, CurrentID=0, Status='live', Symbol='DNAH3', Aliases=['DNAHC3-B', 'DNAHC3B', 'HDHC8', 'HEL-36', 'HSADHC3'], description='dynein axonemal heavy chain 3', other_designations='dynein axonemal heavy chain 3|dynein heavy chain 3, axonemal|axonemal beta dynein heavy chain 3|axonemal dynein, heavy chain|ciliary dynein heavy chain 3|dynein, axonemal, heavy polypeptide 3|epididymis luminal protein 36', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20933111, end_position_on_the_genomic_accession=21159537, orientation='minus', exon_count=69, OMIM=[603334], no_hdr0=''),
    55568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55568, CurrentID=0, Status='live', Symbol='GALNT10', Aliases=['GALNACT10', 'PPGALNACT10', 'PPGANTASE10'], description='polypeptide N-acetylgalactosaminyltransferase 10', other_designations='polypeptide N-acetylgalactosaminyltransferase 10|GalNAc transferase 10|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 10|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 10 (GalNAc-T10)', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154190733, end_position_on_the_genomic_accession=154420984, orientation='plus', exon_count=12, OMIM=[608043], no_hdr0=''),
    55571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55571, CurrentID=0, Status='live', Symbol='CNOT11', Aliases=['C2orf29', 'C40'], description='CCR4-NOT transcription complex subunit 11', other_designations='CCR4-NOT transcription complex subunit 11|UPF0760 protein C2orf29', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101252886, end_position_on_the_genomic_accession=101270316, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55572, CurrentID=0, Status='live', Symbol='FOXRED1', Aliases=['FP634', 'H17', 'MC1DN19'], description='FAD dependent oxidoreductase domain containing 1', other_designations='FAD-dependent oxidoreductase domain-containing protein 1', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126269043, end_position_on_the_genomic_accession=126278132, orientation='plus', exon_count=12, OMIM=[613622], no_hdr0=''),
    55573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55573, CurrentID=0, Status='live', Symbol='CDV3', Aliases=['H41'], description='CDV3 homolog', other_designations='protein CDV3 homolog|carnitine deficiency-associated gene expressed in ventricle 3', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133573629, end_position_on_the_genomic_accession=133590274, orientation='plus', exon_count=8, OMIM=[618789], no_hdr0=''),
    55576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55576, CurrentID=0, Status='live', Symbol='STAB2', Aliases=['FEEL2', 'FELE-2', 'FELL2', 'FEX2', 'HARE', 'SCARH1'], description='stabilin 2', other_designations='stabilin-2|CD44-like precursor FELL|FAS1 EGF-like and X-link domain containing adhesion molecule-2|fasciclin egf-like, laminin-type egf-like, and link domain-containing scavenger receptor-2|hepatic hyaluronan clearance receptor|hyaluronan receptor for endocytosis|hyaluronic acid receptor for endocytosis', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103587250, end_position_on_the_genomic_accession=103766724, orientation='plus', exon_count=73, OMIM=[608561], no_hdr0=''),
    55577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55577, CurrentID=0, Status='live', Symbol='NAGK', Aliases=['GNK', 'HSA242910'], description='N-acetylglucosamine kinase', other_designations='N-acetyl-D-glucosamine kinase|epididymis secretory sperm binding protein|glcNAc kinase', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71068278, end_position_on_the_genomic_accession=71079808, orientation='plus', exon_count=9, OMIM=[606828], no_hdr0=''),
    55578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55578, CurrentID=0, Status='live', Symbol='SUPT20H', Aliases=['C13', 'C13orf19', 'FAM48A', 'FP757', 'P38IP', 'SPT20'], description='SPT20 homolog, SAGA complex component', other_designations='transcription factor SPT20 homolog|family with sequence similarity 48, member A|protein FAM48A|suppressor of Ty 20 homolog|transcription factor (p38 interacting protein)|tumor rejection antigen', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=37009312, end_position_on_the_genomic_accession=37059714, orientation='minus', exon_count=28, OMIM=[613417], no_hdr0=''),
    55582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55582, CurrentID=0, Status='live', Symbol='KIF27', Aliases=[], description='kinesin family member 27', other_designations='kinesin-like protein KIF27', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83832795, end_position_on_the_genomic_accession=83921544, orientation='minus', exon_count=25, OMIM=[611253], no_hdr0=''),
    55584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55584, CurrentID=0, Status='live', Symbol='CHRNA9', Aliases=['HSA243342', 'NACHRA9'], description='cholinergic receptor nicotinic alpha 9 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-9|NACHR alpha 9|acetylcholine receptor, neuronal nicotinic, alpha-9 subunit|cholinergic receptor, nicotinic alpha 9|cholinergic receptor, nicotinic, alpha 9 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 9|neuronal acetylcholine receptor protein, alpha-9 subunit|nicotinic acetylcholine receptor subunit alpha 9', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40335333, end_position_on_the_genomic_accession=40355217, orientation='plus', exon_count=5, OMIM=[605116], no_hdr0=''),
    55585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55585, CurrentID=0, Status='live', Symbol='UBE2Q1', Aliases=['GTAP', 'NICE-5', 'NICE5', 'PRO3094', 'UBE2Q'], description='ubiquitin conjugating enzyme E2 Q1', other_designations='ubiquitin-conjugating enzyme E2 Q1|E2 ubiquitin-conjugating enzyme Q1|galactosyl transferase-associated protein|protein NICE-5|ubiquitin carrier protein Q1|ubiquitin conjugating enzyme E2Q family member 1|ubiquitin-conjugating enzyme E2Q (putative) 1|ubiquitin-protein ligase Q1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154548577, end_position_on_the_genomic_accession=154558662, orientation='minus', exon_count=13, OMIM=[617429], no_hdr0=''),
    55586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55586, CurrentID=0, Status='live', Symbol='MIOX', Aliases=['ALDRL6'], description='myo-inositol oxygenase', other_designations='inositol oxygenase|MI oxygenase|aldehyde reductase (aldose reductase) like 6|aldehyde reductase-like 6|kidney-specific protein 32|renal-specific oxidoreductase', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50483988, end_position_on_the_genomic_accession=50490648, orientation='plus', exon_count=12, OMIM=[606774], no_hdr0=''),
    55588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55588, CurrentID=0, Status='live', Symbol='MED29', Aliases=['IXL', 'MED2'], description='mediator complex subunit 29', other_designations='mediator of RNA polymerase II transcription subunit 29|intersex-like protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39391378, end_position_on_the_genomic_accession=39400641, orientation='plus', exon_count=4, OMIM=[612914], no_hdr0=''),
    55589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55589, CurrentID=0, Status='live', Symbol='BMP2K', Aliases=['BIKE', 'HRIHFB2017'], description='BMP2 inducible kinase', other_designations='BMP-2-inducible protein kinase', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=78776350, end_position_on_the_genomic_accession=78916365, orientation='plus', exon_count=18, OMIM=[617648], no_hdr0=''),
    55591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55591, CurrentID=0, Status='live', Symbol='VEZT', Aliases=['VEZATIN'], description='vezatin, adherens junctions transmembrane protein', other_designations='vezatin', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95217746, end_position_on_the_genomic_accession=95302799, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    55593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55593, CurrentID=0, Status='live', Symbol='OTUD5', Aliases=['DUBA', 'MCAND'], description='OTU deubiquitinase 5', other_designations='OTU domain-containing protein 5|OTU domain containing 5|deubiquinating enzyme A|deubiquitinating enzyme A', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48922024, end_position_on_the_genomic_accession=48960783, orientation='minus', exon_count=13, OMIM=[300713], no_hdr0=''),
    55596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55596, CurrentID=0, Status='live', Symbol='ZCCHC8', Aliases=['PFBMFT5'], description='zinc finger CCHC-type containing 8', other_designations='zinc finger CCHC domain-containing protein 8|TRAMP-like complex RNA-binding factor ZCCHC8|zinc finger, CCHC domain containing 8', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122471600, end_position_on_the_genomic_accession=122501184, orientation='minus', exon_count=17, OMIM=[616381], no_hdr0=''),
    55599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55599, CurrentID=0, Status='live', Symbol='RNPC3', Aliases=['IGHD5', 'RBM40', 'RNP', 'SNRNP65'], description='RNA binding region (RNP1, RRM) containing 3', other_designations='RNA-binding region-containing protein 3|RNA-binding motif protein 40|RNA-binding protein 40|U11/U12 small nuclear ribonucleoprotein 65 kDa protein|U11/U12 snRNP 65 kDa protein|U11/U12 snRNP 65K|U11/U12-65K', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=103525699, end_position_on_the_genomic_accession=103555239, orientation='plus', exon_count=15, OMIM=[618016], no_hdr0=''),
    55600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55600, CurrentID=0, Status='live', Symbol='ITLN1', Aliases=['HL-1', 'HL1', 'INTL', 'ITLN', 'LFR', 'hIntL', 'omentin'], description='intelectin 1', other_designations='intelectin-1|ITLN-1|endothelial lectin HL-1|galactofuranose-binding lectin|intelectin 1 (galactofuranose binding)|intestinal lactoferrin receptor', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160876540, end_position_on_the_genomic_accession=160885180, orientation='minus', exon_count=8, OMIM=[609873], no_hdr0=''),
    55601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55601, CurrentID=0, Status='live', Symbol='DDX60', Aliases=[], description='DExD/H-box helicase 60', other_designations='probable ATP-dependent RNA helicase DDX60|ATP-dependent RNA helicase DDX60|DEAD (Asp-Glu-Ala-Asp) box polypeptide 60|DEAD box protein 60|DEAD-box helicase 60', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=168216293, end_position_on_the_genomic_accession=168325981, orientation='minus', exon_count=44, OMIM=[613974], no_hdr0=''),
    55602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55602, CurrentID=0, Status='live', Symbol='CDKN2AIP', Aliases=['CARF'], description='CDKN2A interacting protein', other_designations='CDKN2A-interacting protein|collaborates/cooperates with ARF (alternate reading frame) protein|collaborator of ARF', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183444636, end_position_on_the_genomic_accession=183449064, orientation='plus', exon_count=3, OMIM=[615914], no_hdr0=''),
    55603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55603, CurrentID=0, Status='live', Symbol='TENT5A', Aliases=['C6orf37', 'FAM46A', 'OI18', 'XTP11'], description='terminal nucleotidyltransferase 5A', other_designations='terminal nucleotidyltransferase 5A|HBV X-transactivated gene 11 protein|HBV XAg-transactivated protein 11|family with sequence similarity 46 member A|protein FAM46A|putative nucleotidyltransferase FAM46A|retinal expressed gene C6orf37', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=81745730, end_position_on_the_genomic_accession=81752681, orientation='minus', exon_count=3, OMIM=[611357], no_hdr0=''),
    55604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55604, CurrentID=0, Status='live', Symbol='CARMIL1', Aliases=['CARMILa', 'LRRC16', 'LRRC16A', 'dJ501N12.1', 'dJ501N12.5', 'CARMIL1'], description='capping protein regulator and myosin 1 linker 1', other_designations='F-actin-uncapping protein LRRC16A|CARMIL homolog|capping protein regulator and myosin 1 linker protein 1|capping protein, Arp2/3 and myosin-I linker homolog 1|capping protein, Arp2/3 and myosin-I linker protein 1|capping protein, Arp2/3, and Myosin-I Linker homolog 1|leucine rich repeat containing 16|leucine rich repeat containing 16A|leucine-rich repeat-containing protein 16A|testicular tissue protein Li 107', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25279374, end_position_on_the_genomic_accession=25620530, orientation='plus', exon_count=41, OMIM=[609593], no_hdr0=''),
    55605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55605, CurrentID=0, Status='live', Symbol='KIF21A', Aliases=['CFEOM1', 'FEOM1', 'FEOM3A'], description='kinesin family member 21A', other_designations='kinesin-like protein KIF21A|kinesin-like protein KIF2|renal carcinoma antigen NY-REN-62', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=39293228, end_position_on_the_genomic_accession=39443147, orientation='minus', exon_count=38, OMIM=[608283], no_hdr0=''),
    55607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55607, CurrentID=0, Status='live', Symbol='PPP1R9A', Aliases=['NRB1', 'NRBI', 'Neurabin-I'], description='protein phosphatase 1 regulatory subunit 9A', other_designations='neurabin-1|neural tissue-specific F-actin-binding protein I|protein phosphatase 1, regulatory (inhibitor) subunit 9A', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=94907202, end_position_on_the_genomic_accession=95296415, orientation='plus', exon_count=29, OMIM=[602468], no_hdr0=''),
    55608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55608, CurrentID=0, Status='live', Symbol='ANKRD10', Aliases=[], description='ankyrin repeat domain 10', other_designations='ankyrin repeat domain-containing protein 10', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110878540, end_position_on_the_genomic_accession=110915071, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55609, CurrentID=0, Status='live', Symbol='ZNF280C', Aliases=['SUHW3', 'ZNF633', 'ZPET'], description='zinc finger protein 280C', other_designations='zinc finger protein 280C|suppressor of hairy wing homolog 3|zinc finger protein 633|zinc finger protein proximal to RAD eighteen', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130202707, end_position_on_the_genomic_accession=130268899, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    55610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55610, CurrentID=0, Status='live', Symbol='VPS50', Aliases=['CCDC132', 'VPS54L'], description='VPS50 subunit of EARP/GARPII complex', other_designations='syndetin|EARP/GARPII complex subunit VPS50|VPS50, EARP/GARPII complex subunit|coiled-coil domain containing 132|coiled-coil domain-containing protein 132', map_location='7q21.2-q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93232366, end_position_on_the_genomic_accession=93361123, orientation='plus', exon_count=31, OMIM=[616465], no_hdr0=''),
    55611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55611, CurrentID=0, Status='live', Symbol='OTUB1', Aliases=['HSPC263', 'OTB1', 'OTU1'], description='OTU deubiquitinase, ubiquitin aldehyde binding 1', other_designations='ubiquitin thioesterase OTUB1|OTU domain, ubiquitin aldehyde binding 1|OTU domain-containing ubiquitin aldehyde-binding protein 1|OTU-domain Ubal-binding 1|deubiquitinating enzyme OTUB1|otubain-1|ubiquitin-specific protease otubain 1|ubiquitin-specific-processing protease OTUB1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63986438, end_position_on_the_genomic_accession=63998412, orientation='plus', exon_count=7, OMIM=[608337], no_hdr0=''),
    55612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55612, CurrentID=0, Status='live', Symbol='FERMT1', Aliases=['C20orf42', 'DTGCU2', 'KIND1', 'UNC112A', 'URP1'], description='FERM domain containing kindlin 1', other_designations='fermitin family homolog 1|UNC112 related protein 1|fermitin family member 1|kindlerin|kindlin 1|kindlin syndrome protein|unc-112-related protein 1', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=6074845, end_position_on_the_genomic_accession=6123609, orientation='minus', exon_count=15, OMIM=[607900], no_hdr0=''),
    55613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55613, CurrentID=0, Status='live', Symbol='MTMR8', Aliases=[], description='myotubularin related protein 8', other_designations='myotubularin-related protein 8|phosphatidylinositol-3,5-bisphosphate 3-phosphatase|phosphatidylinositol-3-phosphate phosphatase', map_location='Xq11.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=64268081, end_position_on_the_genomic_accession=64395452, orientation='minus', exon_count=14, OMIM=[301061], no_hdr0=''),
    55614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55614, CurrentID=0, Status='live', Symbol='KIF16B', Aliases=['C20orf23', 'KISC20ORF', 'SNX23'], description='kinesin family member 16B', other_designations='kinesin-like protein KIF16B|kinesin motor protein|sorting nexin 23|testis secretory sperm-binding protein Li 201a', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=16272104, end_position_on_the_genomic_accession=16573457, orientation='minus', exon_count=29, OMIM=[618171], no_hdr0=''),
    55615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55615, CurrentID=0, Status='live', Symbol='PRR5', Aliases=['FLJ20185k', 'PP610', 'PROTOR-1', 'PROTOR1'], description='proline rich 5', other_designations='proline-rich protein 5|Rho GTPase activating protein 8|proline rich 5 (renal)|protein observed with Rictor-1', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44668751, end_position_on_the_genomic_accession=44737681, orientation='plus', exon_count=11, OMIM=[609406], no_hdr0=''),
    55616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55616, CurrentID=0, Status='live', Symbol='ASAP3', Aliases=['ACAP4', 'CENTB6', 'DDEFL1', 'UPLC1'], description='ArfGAP with SH3 domain, ankyrin repeat and PH domain 3', other_designations='arf-GAP with SH3 domain, ANK repeat and PH domain-containing protein 3|ARF6 GTPase-activating protein|ArfGAP with SH3 domain, ankyrin repeat and PH domain 3 1|centaurin, beta 6|development and differentiation enhancing factor-like 1|protein up-regulated in liver cancer 1|up-regulated in liver cancer 1 (UPLC1)', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23428563, end_position_on_the_genomic_accession=23484631, orientation='minus', exon_count=26, OMIM=[616594], no_hdr0=''),
    55617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55617, CurrentID=0, Status='live', Symbol='TASP1', Aliases=['C20orf13', 'SULEHS', 'dJ585I14.2'], description='taspase 1', other_designations='threonine aspartase 1', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13104760, end_position_on_the_genomic_accession=13638932, orientation='minus', exon_count=24, OMIM=[608270], no_hdr0=''),
    55619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55619, CurrentID=0, Status='live', Symbol='DOCK10', Aliases=['DRIP2', 'Nbla10300', 'ZIZ3'], description='dedicator of cytokinesis 10', other_designations='dedicator of cytokinesis protein 10|dopamine receptor interacting protein 2|zizimin3', map_location='2q36.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=224765090, end_position_on_the_genomic_accession=225042689, orientation='minus', exon_count=59, OMIM=[611518], no_hdr0=''),
    55620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55620, CurrentID=0, Status='live', Symbol='STAP2', Aliases=['BKS'], description='signal transducing adaptor family member 2', other_designations='signal-transducing adaptor protein 2|BRK substrate|breast tumor kinase substrate|brk kinase substrate', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4324043, end_position_on_the_genomic_accession=4338877, orientation='minus', exon_count=13, OMIM=[607881], no_hdr0=''),
    55621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55621, CurrentID=0, Status='live', Symbol='TRMT1', Aliases=['MRT68', 'TRM1'], description='tRNA methyltransferase 1', other_designations='tRNA (guanine(26)-N(2))-dimethyltransferase|N(2),N(2)-dimethylguanosine tRNA methyltransferase|TRM1 tRNA methyltransferase 1 homolog|tRNA 2,2-dimethylguanosine-26 methyltransferase|tRNA methyltransferase 1 homolog|tRNA(guanine-26,N(2)-N(2)) methyltransferase|tRNA(m(2,2)G26)dimethyltransferase', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13104907, end_position_on_the_genomic_accession=13116740, orientation='minus', exon_count=17, OMIM=[611669], no_hdr0=''),
    55622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55622, CurrentID=0, Status='live', Symbol='TTC27', Aliases=[], description='tetratricopeptide repeat domain 27', other_designations='tetratricopeptide repeat protein 27|TPR repeat protein 27', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32628035, end_position_on_the_genomic_accession=32821051, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    55623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55623, CurrentID=0, Status='live', Symbol='THUMPD1', Aliases=['Tan1'], description='THUMP domain containing 1', other_designations='THUMP domain-containing protein 1', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20730589, end_position_on_the_genomic_accession=20741830, orientation='minus', exon_count=8, OMIM=[616662], no_hdr0=''),
    55624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55624, CurrentID=0, Status='live', Symbol='POMGNT1', Aliases=['GNTI.2', 'GnT I.2', 'LGMD2O', 'LGMDR15', 'MEB', 'MGAT1.2', 'RP76', 'gnT-I.2'], description='protein O-linked mannose N-acetylglucosaminyltransferase 1 (beta 1,2-)', other_designations='protein O-linked-mannose beta-1,2-N-acetylglucosaminyltransferase 1|UDP-GlcNAc:alpha-D-mannoside beta-1,2-N-acetylglucosaminyltransferase I.2', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46188683, end_position_on_the_genomic_accession=46220305, orientation='minus', exon_count=25, OMIM=[606822], no_hdr0=''),
    55625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55625, CurrentID=0, Status='live', Symbol='ZDHHC7', Aliases=['DHHC7', 'SERZ-B', 'SERZ1', 'ZNF370'], description='zinc finger DHHC-type palmitoyltransferase 7', other_designations='palmitoyltransferase ZDHHC7|DHHC-7|Sertoli cell gene with zinc finger domain-I(2)|Sertoli cell gene with zinc finger domain-beta|acyltransferase ZDHHC7|zinc finger DHHC domain-containing protein 7|zinc finger DHHC-type containing 7|zinc finger protein 370|zinc finger, DHHC domain containing 7', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84974175, end_position_on_the_genomic_accession=85011535, orientation='minus', exon_count=10, OMIM=[614604], no_hdr0=''),
    55626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55626, CurrentID=0, Status='live', Symbol='AMBRA1', Aliases=['DCAF3', 'WDR94'], description='autophagy and beclin 1 regulator 1', other_designations='activating molecule in BECN1-regulated autophagy protein 1|DDB1 and CUL4 associated factor 3|WD repeat domain 94|activating molecule in beclin-1-regulated autophagy|autophagy/beclin-1 regulator 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46396412, end_position_on_the_genomic_accession=46594055, orientation='minus', exon_count=25, OMIM=[611359], no_hdr0=''),
    55627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55627, CurrentID=0, Status='live', Symbol='SMPD4', Aliases=['NEDMABA', 'NEDMEBA', 'NET13', 'NSMASE-3', 'NSMASE3', 'SKNY'], description='sphingomyelin phosphodiesterase 4', other_designations='sphingomyelin phosphodiesterase 4|neutral sphingomyelinase 3|neutral sphingomyelinase III|sphingomyelin phosphodiesterase 4, neutral membrane (neutral sphingomyelinase-3)', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130151392, end_position_on_the_genomic_accession=130181757, orientation='minus', exon_count=21, OMIM=[610457], no_hdr0=''),
    55628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55628, CurrentID=0, Status='live', Symbol='ZNF407', Aliases=[], description='zinc finger protein 407', other_designations='zinc finger protein 407', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74590475, end_position_on_the_genomic_accession=75065671, orientation='plus', exon_count=13, OMIM=[615894], no_hdr0=''),
    55629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55629, CurrentID=0, Status='live', Symbol='PNRC2', Aliases=[], description='proline rich nuclear receptor coactivator 2', other_designations='proline-rich nuclear receptor coactivator 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23959164, end_position_on_the_genomic_accession=23963462, orientation='plus', exon_count=4, OMIM=[611882], no_hdr0=''),
    55630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55630, CurrentID=0, Status='live', Symbol='SLC39A4', Aliases=['AEZ', 'AWMS2', 'ZIP4'], description='solute carrier family 39 member 4', other_designations='zinc transporter ZIP4|solute carrier family 39 (zinc transporter), member 4|zrt- and Irt-like protein 4', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144412414, end_position_on_the_genomic_accession=144417146, orientation='minus', exon_count=12, OMIM=[607059], no_hdr0=''),
    55631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55631, CurrentID=0, Status='live', Symbol='LRRC40', Aliases=['dJ677H15.1'], description='leucine rich repeat containing 40', other_designations='leucine-rich repeat-containing protein 40|testicular tissue protein Li 109', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=70144805, end_position_on_the_genomic_accession=70205676, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    55632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55632, CurrentID=0, Status='live', Symbol='G2E3', Aliases=['KIAA1333', 'PHF7B'], description='G2/M-phase specific E3 ubiquitin protein ligase', other_designations='G2/M phase-specific E3 ubiquitin-protein ligase|G2/M phase-specific HECT-type E3 ubiquitin transferase|G2/M-phase specific E3 ubiquitin ligase|PHD finger protein 7B', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=30559136, end_position_on_the_genomic_accession=30620064, orientation='plus', exon_count=16, OMIM=[611299], no_hdr0=''),
    55633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55633, CurrentID=0, Status='live', Symbol='TBC1D22B', Aliases=['C6orf197'], description='TBC1 domain family member 22B', other_designations='TBC1 domain family member 22B', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37257772, end_position_on_the_genomic_accession=37332970, orientation='plus', exon_count=14, OMIM=[616880], no_hdr0=''),
    55634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55634, CurrentID=0, Status='live', Symbol='KRBOX4', Aliases=['ZNF673'], description='KRAB box domain containing 4', other_designations='KRAB domain-containing protein 4|KRAB box domain-containing protein 4|putative zinc finger transcription factor|zinc finger family member 673|zinc finger protein 673', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46447297, end_position_on_the_genomic_accession=46474639, orientation='plus', exon_count=7, OMIM=[300585], no_hdr0=''),
    55635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55635, CurrentID=0, Status='live', Symbol='DEPDC1', Aliases=['DEP.8-V2', 'DEPDC1A', 'SDP35', 'DEPDC1'], description='DEP domain containing 1', other_designations='DEP domain-containing protein 1A|cell cycle control protein SDP35', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=68474152, end_position_on_the_genomic_accession=68497082, orientation='minus', exon_count=12, OMIM=[612002], no_hdr0=''),
    55636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55636, CurrentID=0, Status='live', Symbol='CHD7', Aliases=['CRG', 'HH5', 'IS3', 'KAL5'], description='chromodomain helicase DNA binding protein 7', other_designations='chromodomain-helicase-DNA-binding protein 7|ATP-dependent helicase CHD7|CHARGE association', map_location='8q12.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=60678740, end_position_on_the_genomic_accession=60868028, orientation='plus', exon_count=42, OMIM=[608892], no_hdr0=''),
    55638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55638, CurrentID=0, Status='live', Symbol='SYBU', Aliases=['GOLSYN', 'OCSYN', 'SNPHL'], description='syntabulin', other_designations='syntabulin|GOLSYN A protein|GOLSYN B protein|GOLSYN C protein|Golgi-localized protein|golgi-localized syntaphilin-related protein|implicated in syntaxin trafficking in neurons|microtubule-associated protein|syntabulin (syntaxin-interacting)|syntaxin-1-binding protein', map_location='8q23.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109573978, end_position_on_the_genomic_accession=109691600, orientation='minus', exon_count=15, OMIM=[611568], no_hdr0=''),
    55640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55640, CurrentID=0, Status='live', Symbol='FLVCR2', Aliases=['C14orf58', 'CCT', 'EPV', 'FLVCRL14q', 'MFSD7C', 'PVHH', 'SLC49A2'], description='FLVCR heme transporter 2', other_designations='feline leukemia virus subgroup C receptor-related protein 2|calcium-chelate transporter|feline leukemia virus subgroup C cellular receptor family member 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75578620, end_position_on_the_genomic_accession=75648167, orientation='plus', exon_count=11, OMIM=[610865], no_hdr0=''),
    55643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55643, CurrentID=0, Status='live', Symbol='BTBD2', Aliases=[], description='BTB domain containing 2', other_designations='BTB/POZ domain-containing protein 2|BTB (POZ) domain containing 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1985438, end_position_on_the_genomic_accession=2015714, orientation='minus', exon_count=10, OMIM=[608531], no_hdr0=''),
    55644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55644, CurrentID=0, Status='live', Symbol='OSGEP', Aliases=['GAMOS3', 'GCPL1', 'KAE11', 'PRSMG1', 'TCS3', 'OSGEP'], description='O-sialoglycoprotein endopeptidase', other_designations='probable tRNA N6-adenosine threonylcarbamoyltransferase|N6-L-threonylcarbamoyladenine synthase|hOSGEP|probable O-sialoglycoprotein endopeptidase|probable tRNA threonylcarbamoyladenosine biosynthesis protein OSGEP|t(6)A synthase|t(6)A37 threonylcarbamoyladenosine biosynthesis protein OSGEP|tRNA threonylcarbamoyladenosine biosynthesis protein OSGEP', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20446401, end_position_on_the_genomic_accession=20454812, orientation='minus', exon_count=11, OMIM=[610107], no_hdr0=''),
    55646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55646, CurrentID=0, Status='live', Symbol='LYAR', Aliases=['ZC2HC2', 'ZLYAR'], description='Ly1 antibody reactive', other_designations='cell growth-regulating nucleolar protein|Ly1 antibody reactive homolog', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4267701, end_position_on_the_genomic_accession=4290195, orientation='minus', exon_count=11, OMIM=[617684], no_hdr0=''),
    55647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55647, CurrentID=0, Status='live', Symbol='RAB20', Aliases=[], description='RAB20, member RAS oncogene family', other_designations='ras-related protein Rab-20', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110523066, end_position_on_the_genomic_accession=110561722, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    55650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55650, CurrentID=0, Status='live', Symbol='PIGV', Aliases=['GPI-MT-II', 'HPMRS1', 'PIG-V'], description='phosphatidylinositol glycan anchor biosynthesis class V', other_designations='GPI mannosyltransferase 2|GPI mannosyltransferase II|Ybr004c homolog|dol-P-Man dependent GPI mannosyltransferase', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26787054, end_position_on_the_genomic_accession=26800659, orientation='plus', exon_count=6, OMIM=[610274], no_hdr0=''),
    55651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55651, CurrentID=0, Status='live', Symbol='NHP2', Aliases=['DKCB2P', 'NOLA2', 'NHP2'], description='NHP2 ribonucleoprotein', other_designations='H/ACA ribonucleoprotein complex subunit 2|NHP2 ribonucleoprotein homolog|NHP2-like protein|nucleolar protein family A, member 2 (H/ACA small nucleolar RNPs)|snoRNP protein NHP2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178149463, end_position_on_the_genomic_accession=178153885, orientation='minus', exon_count=4, OMIM=[606470], no_hdr0=''),
    55652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55652, CurrentID=0, Status='live', Symbol='SLC48A1', Aliases=['HRG-1', 'HRG1', 'hHRG-1'], description='solute carrier family 48 member 1', other_designations='heme transporter HRG1|heme-responsive gene 1 protein homolog|solute carrier family 48 (heme transporter), member 1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47753619, end_position_on_the_genomic_accession=47782753, orientation='plus', exon_count=11, OMIM=[612187], no_hdr0=''),
    55653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55653, CurrentID=0, Status='live', Symbol='BCAS4', Aliases=['CNOL'], description='breast carcinoma amplified sequence 4', other_designations='breast carcinoma-amplified sequence 4|BCAS4/BCAS3 fusion|breast carcinoma amplified sequence 4/3 fusion protein', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50794894, end_position_on_the_genomic_accession=50877736, orientation='plus', exon_count=9, OMIM=[607471], no_hdr0=''),
    55654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55654, CurrentID=0, Status='live', Symbol='TMEM127', Aliases=[], description='transmembrane protein 127', other_designations='transmembrane protein 127', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96248514, end_position_on_the_genomic_accession=96265997, orientation='minus', exon_count=5, OMIM=[613403], no_hdr0=''),
    55655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55655, CurrentID=0, Status='live', Symbol='NLRP2', Aliases=['CLR19.9', 'NALP2', 'NBS1', 'PAN1', 'PYPAF2'], description='NLR family pyrin domain containing 2', other_designations='NACHT, LRR and PYD domains-containing protein 2|NACHT, leucine rich repeat and PYD containing 2|PYRIN domain and NACHT domain-containing protein 1|PYRIN-containing APAF1-like protein 2|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 2|nucleotide-binding site protein 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54965284, end_position_on_the_genomic_accession=55001138, orientation='plus', exon_count=14, OMIM=[609364], no_hdr0=''),
    55656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55656, CurrentID=0, Status='live', Symbol='INTS8', Aliases=['C8orf52', 'INT8', 'NEDCHS'], description='integrator complex subunit 8', other_designations='integrator complex subunit 8|protein kaonashi-1', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94823287, end_position_on_the_genomic_accession=94894664, orientation='plus', exon_count=30, OMIM=[611351], no_hdr0=''),
    55657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55657, CurrentID=0, Status='live', Symbol='ZNF692', Aliases=['AREBP', 'Zfp692'], description='zinc finger protein 692', other_designations='zinc finger protein 692|AICAR responsive element binding protein', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248850004, end_position_on_the_genomic_accession=248860761, orientation='minus', exon_count=14, OMIM=[617758], no_hdr0=''),
    55658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55658, CurrentID=0, Status='live', Symbol='RNF126', Aliases=[], description='ring finger protein 126', other_designations='E3 ubiquitin-protein ligase RNF126', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=647526, end_position_on_the_genomic_accession=663214, orientation='minus', exon_count=10, OMIM=[615177], no_hdr0=''),
    55659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55659, CurrentID=0, Status='live', Symbol='ZNF416', Aliases=[], description='zinc finger protein 416', other_designations='zinc finger protein 416', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57571015, end_position_on_the_genomic_accession=57578911, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    55660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55660, CurrentID=0, Status='live', Symbol='PRPF40A', Aliases=['FBP-11', 'FBP11', 'FLAF1', 'FNBP3', 'HIP-10', 'HIP10', 'HYPA', 'NY-REN-6', 'Prp40'], description='pre-mRNA processing factor 40 homolog A', other_designations='pre-mRNA-processing factor 40 homolog A|Fas-ligand associated factor 1|Huntingtin-interacting protein A|NY-REN-6 antigen|PRP40 pre-mRNA processing factor 40 homolog A|fas ligand-associated factor 1|formin binding protein 3|formin-binding protein 11|huntingtin yeast partner A|huntingtin-interacting protein 10|renal carcinoma antigen NY-REN-6', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=152651593, end_position_on_the_genomic_accession=152718019, orientation='minus', exon_count=31, OMIM=[612941], no_hdr0=''),
    55661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55661, CurrentID=0, Status='live', Symbol='DDX27', Aliases=['DRS1', 'Drs1p', 'HSPC259', 'PP3241', 'RHLP', 'dJ686N3.1'], description='DEAD-box helicase 27', other_designations='probable ATP-dependent RNA helicase DDX27|DEAD (Asp-Glu-Ala-Asp) box polypeptide 27|DEAD box protein 27|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 27|Deficiency of ribosomal subunits protein 1 homolog|RNA helicase-like protein', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49219416, end_position_on_the_genomic_accession=49244073, orientation='plus', exon_count=22, OMIM=[616621], no_hdr0=''),
    55662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55662, CurrentID=0, Status='live', Symbol='HIF1AN', Aliases=['FIH1'], description='hypoxia inducible factor 1 subunit alpha inhibitor', other_designations='hypoxia-inducible factor 1-alpha inhibitor|FIH-1|factor inhibiting HIF-1|factor inhibiting HIF1|hypoxia inducible factor 1 alpha subunit inhibitor|hypoxia-inducible factor asparagine hydroxylase|peptide-aspartate beta-dioxygenase', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100535921, end_position_on_the_genomic_accession=100559998, orientation='plus', exon_count=8, OMIM=[606615], no_hdr0=''),
    55663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55663, CurrentID=0, Status='live', Symbol='ZNF446', Aliases=['ZKSCAN20', 'ZSCAN30', 'ZSCAN52'], description='zinc finger protein 446', other_designations='zinc finger protein 446|zinc finger protein with KRAB and SCAN domains 20', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58476352, end_position_on_the_genomic_accession=58489533, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    55664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55664, CurrentID=0, Status='live', Symbol='CDC37L1', Aliases=['CDC37B', 'HARC'], description='cell division cycle 37 like 1', other_designations='hsp90 co-chaperone Cdc37-like 1|CDC37 cell division cycle 37 homolog-like 1|Hsp90-associating relative of Cdc37|cell division cycle 37 homolog-like 1', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4679569, end_position_on_the_genomic_accession=4708399, orientation='plus', exon_count=7, OMIM=[610346], no_hdr0=''),
    55665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55665, CurrentID=0, Status='live', Symbol='URGCP', Aliases=['URG4'], description='upregulator of cell proliferation', other_designations='up-regulator of cell proliferation|HBV X protein up-regulated gene 4 protein|HBxAg up-regulated gene 4 protein|up-regulated gene 4', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43875913, end_position_on_the_genomic_accession=43926726, orientation='minus', exon_count=8, OMIM=[610337], no_hdr0=''),
    55666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55666, CurrentID=0, Status='live', Symbol='NPLOC4', Aliases=['NPL4'], description='NPL4 homolog, ubiquitin recognition factor', other_designations='nuclear protein localization protein 4 homolog|NPLOC4 ubiquitin recognition factor|nuclear protein localization 4 homolog', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81556885, end_position_on_the_genomic_accession=81637148, orientation='minus', exon_count=21, OMIM=[606590], no_hdr0=''),
    55667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55667, CurrentID=0, Status='live', Symbol='DENND4C', Aliases=['C9orf55', 'C9orf55B', 'RAB10GEF', 'bA513M16.3'], description='DENN domain containing 4C', other_designations='DENN domain-containing protein 4C|DENN/MADD domain containing 4A pseudogene|DENN/MADD domain containing 4C', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19230513, end_position_on_the_genomic_accession=19374281, orientation='plus', exon_count=36, OMIM=[], no_hdr0=''),
    55668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55668, CurrentID=0, Status='live', Symbol='GPATCH2L', Aliases=['C14orf118'], description='G-patch domain containing 2 like', other_designations='G patch domain-containing protein 2-like', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=76151912, end_position_on_the_genomic_accession=76214473, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    55669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55669, CurrentID=0, Status='live', Symbol='MFN1', Aliases=['hfzo1', 'hfzo2'], description='mitofusin 1', other_designations='mitofusin-1|fzo homolog|mitochondrial transmembrane GTPase FZO-2|mitochondrial transmembrane GTPase Fzo-1|putative transmembrane GTPase|transmembrane GTPase MFN1', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179347709, end_position_on_the_genomic_accession=179394936, orientation='plus', exon_count=19, OMIM=[608506], no_hdr0=''),
    55670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55670, CurrentID=0, Status='live', Symbol='PEX26', Aliases=['PBD7A', 'PBD7BM1T', 'Pex26pM1T', 'PEX26'], description='peroxisomal biogenesis factor 26', other_designations='peroxisome assembly protein 26|peroxin-26|peroxisome biogenesis disorder, complementation group 8|peroxisome biogenesis disorder, complementation group A|peroxisome biogenesis factor 26', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18077990, end_position_on_the_genomic_accession=18105396, orientation='plus', exon_count=5, OMIM=[608666], no_hdr0=''),
    55671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55671, CurrentID=0, Status='live', Symbol='PPP4R3A', Aliases=['FLFL1', 'KIAA2010', 'MSTP033', 'PP4R3', 'PP4R3A', 'SMEK1', 'smk-1', 'smk1'], description='protein phosphatase 4 regulatory subunit 3A', other_designations='serine/threonine-protein phosphatase 4 regulatory subunit 3A|SMEK homolog 1, suppressor of mek1', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91457508, end_position_on_the_genomic_accession=91510554, orientation='minus', exon_count=19, OMIM=[610351], no_hdr0=''),
    55672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55672, CurrentID=0, Status='live', Symbol='NBPF1', Aliases=['AB13', 'AB14', 'AB23', 'AD2', 'NBG', 'NBPF'], description='NBPF member 1', other_designations='neuroblastoma breakpoint family member 1', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16562323, end_position_on_the_genomic_accession=16613564, orientation='minus', exon_count=28, OMIM=[610501], no_hdr0=''),
    55676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55676, CurrentID=0, Status='live', Symbol='SLC30A6', Aliases=['MST103', 'MSTP103', 'ZNT6'], description='solute carrier family 30 member 6', other_designations='zinc transporter 6|solute carrier family 30 (zinc transporter), member 6', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32165850, end_position_on_the_genomic_accession=32224379, orientation='plus', exon_count=19, OMIM=[611148], no_hdr0=''),
    55677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55677, CurrentID=0, Status='live', Symbol='IWS1', Aliases=[], description='interacts with SUPT6H, CTD assembly factor 1', other_designations='protein IWS1 homolog|IWS1 homolog|IWS1, SUPT6H interacting protein|IWS1-like protein|interacts with Spt6', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127480807, end_position_on_the_genomic_accession=127526886, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    55679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55679, CurrentID=0, Status='live', Symbol='LIMS2', Aliases=['LGMD2W', 'MDRCMTT', 'PINCH-2', 'PINCH2'], description='LIM zinc finger domain containing 2', other_designations='LIM and senescent cell antigen-like-containing domain protein 2|ILK-binding protein|LIM and senescent cell antigen-like domains 2|LIM-type zinc finger domains 2|particularly interesting new Cys-His protein 2', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127638421, end_position_on_the_genomic_accession=127681786, orientation='minus', exon_count=18, OMIM=[607908], no_hdr0=''),
    55680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55680, CurrentID=0, Status='live', Symbol='RUFY2', Aliases=['RABIP4R', 'ZFYVE13'], description='RUN and FYVE domain containing 2', other_designations='RUN and FYVE domain-containing protein 2|Run- and FYVE-domain containing protein|antigen MU-RMS-40.17|rab4-interacting protein related', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68341112, end_position_on_the_genomic_accession=68407302, orientation='minus', exon_count=22, OMIM=[610328], no_hdr0=''),
    55681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55681, CurrentID=0, Status='live', Symbol='SCYL2', Aliases=['AMC4', 'AMCNACC', 'CVAK104'], description='SCY1 like pseudokinase 2', other_designations='SCY1-like protein 2|SCY1-like 2|SCY1-like, kinase-like 2|coated vesicle-associated kinase of 104 kDa', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100267177, end_position_on_the_genomic_accession=100341715, orientation='plus', exon_count=20, OMIM=[616365], no_hdr0=''),
    55683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55683, CurrentID=0, Status='live', Symbol='KANSL3', Aliases=['KIAA1310', 'NSL3', 'Rcd1'], description='KAT8 regulatory NSL complex subunit 3', other_designations='KAT8 regulatory NSL complex subunit 3|NSL complex protein NSL3|non-specific lethal 3 homolog|serum inhibited-related protein|testis development protein PRTD', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96593170, end_position_on_the_genomic_accession=96638378, orientation='minus', exon_count=28, OMIM=[617742], no_hdr0=''),
    55684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55684, CurrentID=0, Status='live', Symbol='RABL6', Aliases=['C9orf86', 'PARF', 'RBEL1', 'pp8875'], description='RAB, member RAS oncogene family like 6', other_designations='rab-like protein 6|Rab-like GTP-binding protein 1C|partner of ARF|putative GTP-binding protein Parf', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136807948, end_position_on_the_genomic_accession=136841187, orientation='plus', exon_count=16, OMIM=[610615], no_hdr0=''),
    55686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55686, CurrentID=0, Status='live', Symbol='MREG', Aliases=['DSU', 'WDT2'], description='melanoregulin', other_designations='melanoregulin|dilute suppressor protein homolog|whn-dependent transcript 2', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=215939097, end_position_on_the_genomic_accession=216034096, orientation='minus', exon_count=12, OMIM=[609207], no_hdr0=''),
    55687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55687, CurrentID=0, Status='live', Symbol='TRMU', Aliases=['LCAL3', 'MTO2', 'MTU1', 'TRMT', 'TRMT1'], description='tRNA mitochondrial 2-thiouridylase', other_designations='mitochondrial tRNA-specific 2-thiouridylase 1|MTO2 homolog|lung cancer associated lncRNA 3|mitochondrial 5-methylaminomethyl-2-thiouridylate-methyltransferase|tRNA 5-methylaminomethyl-2-thiouridylate methyltransferase', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46335714, end_position_on_the_genomic_accession=46357340, orientation='plus', exon_count=12, OMIM=[610230], no_hdr0=''),
    55689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55689, CurrentID=0, Status='live', Symbol='YEATS2', Aliases=['FAME4'], description='YEATS domain containing 2', other_designations='YEATS domain-containing protein 2', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183697797, end_position_on_the_genomic_accession=183812625, orientation='plus', exon_count=35, OMIM=[613373], no_hdr0=''),
    55690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55690, CurrentID=0, Status='live', Symbol='PACS1', Aliases=['MRD17', 'SHMS'], description='phosphofurin acidic cluster sorting protein 1', other_designations='phosphofurin acidic cluster sorting protein 1|PACS-1|cytosolic sorting protein PACS-1', map_location='11q13.1-q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66070272, end_position_on_the_genomic_accession=66244744, orientation='plus', exon_count=27, OMIM=[607492], no_hdr0=''),
    55691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55691, CurrentID=0, Status='live', Symbol='FRMD4A', Aliases=['CCAFCA', 'FRMD4', 'bA295P9.4'], description='FERM domain containing 4A', other_designations='FERM domain-containing protein 4A|FERM domain containing 4', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13638300, end_position_on_the_genomic_accession=14330924, orientation='minus', exon_count=38, OMIM=[616305], no_hdr0=''),
    55692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55692, CurrentID=0, Status='live', Symbol='LUC7L', Aliases=['LUC7B1', 'Luc7', 'SR+89', 'hLuc7B1'], description='LUC7 like', other_designations='putative RNA-binding protein Luc7-like 1|putative SR protein LUC7B1|sarcoplasmic reticulum protein LUC7B1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=188969, end_position_on_the_genomic_accession=229449, orientation='minus', exon_count=12, OMIM=[607782], no_hdr0=''),
    55693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55693, CurrentID=0, Status='live', Symbol='KDM4D', Aliases=['JMJD2D'], description='lysine demethylase 4D', other_designations='lysine-specific demethylase 4D|[histone H3]-trimethyl-L-lysine(9) demethylase 4D|jmjC domain-containing histone demethylation protein 3D|jumonji domain containing 2D|jumonji domain-containing protein 2D|lysine (K)-specific demethylase 4D', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94973709, end_position_on_the_genomic_accession=94999519, orientation='plus', exon_count=3, OMIM=[609766], no_hdr0=''),
    55695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55695, CurrentID=0, Status='live', Symbol='NSUN5', Aliases=['NOL1', 'NOL1RA', 'WBSCR20', 'WBSCR20A', 'p120', 'p120(NOL1)', 'NSUN5'], description='NOP2/Sun RNA methyltransferase 5', other_designations='28S rRNA (cytosine-C(5))-methyltransferase|NOL1-related protein|NOL1/NOP2/Sun domain family member 5|NOP2/Sun RNA methyltransferase family member 5|NOP2/Sun domain family, member 5|NOP2/Sun domain family, member 5A|Williams Beuren syndrome chromosome region 20A|Williams-Beuren syndrome chromosomal region 20A protein|Williams-Beuren syndrome critical region protein 20 copy A|probable 28S rRNA (cytosine-C(5))-methyltransferase|putative methyltransferase NSUN5', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73302516, end_position_on_the_genomic_accession=73308826, orientation='minus', exon_count=9, OMIM=[615732], no_hdr0=''),
    55696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55696, CurrentID=0, Status='live', Symbol='RBM22', Aliases=['Cwc2', 'ZC3H16', 'fSAP47'], description='RNA binding motif protein 22', other_designations='pre-mRNA-splicing factor RBM22|functional spliceosome-associated protein 47|zinc finger CCCH domain-containing protein 16', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150690792, end_position_on_the_genomic_accession=150701089, orientation='minus', exon_count=11, OMIM=[612430], no_hdr0=''),
    55697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55697, CurrentID=0, Status='live', Symbol='VAC14', Aliases=['ArPIKfyve', 'TAX1BP2', 'TRX'], description='VAC14 component of PIKFYVE complex', other_designations='protein VAC14 homolog|Vac14, PIKFYVE complex component', map_location='16q22.1-q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70687439, end_position_on_the_genomic_accession=70801158, orientation='minus', exon_count=24, OMIM=[604632], no_hdr0=''),
    55698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55698, CurrentID=0, Status='live', Symbol='RADIL', Aliases=['RASIP2'], description='Rap associating with DIL domain', other_designations='ras-associating and dilute domain-containing protein|Rap GTPase interactor|Ras association and DIL domains', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=4797055, end_position_on_the_genomic_accession=4883716, orientation='minus', exon_count=15, OMIM=[611491], no_hdr0=''),
    55699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55699, CurrentID=0, Status='live', Symbol='IARS2', Aliases=['CAGSSS', 'ILERS'], description='isoleucyl-tRNA synthetase 2, mitochondrial', other_designations='isoleucine--tRNA ligase, mitochondrial|isoleucine tRNA ligase 2, mitochondrial|isoleucine-tRNA synthetase 2, mitochondrial|isoleucyl-tRNA synthetase, mitochondrial|mitochondrial isoleucine tRNA synthetase', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220094132, end_position_on_the_genomic_accession=220148041, orientation='plus', exon_count=23, OMIM=[612801], no_hdr0=''),
    55700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55700, CurrentID=0, Status='live', Symbol='MAP7D1', Aliases=['PARCC1', 'RPRC1'], description='MAP7 domain containing 1', other_designations='MAP7 domain-containing protein 1|arginine/proline rich coiled-coil 1|arginine/proline-rich coiled-coil domain-containing protein 1|proline arginine rich coiled coil 1|proline/arginine-rich coiled-coil domain-containing protein 1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36156150, end_position_on_the_genomic_accession=36180849, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    55701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55701, CurrentID=0, Status='live', Symbol='ARHGEF40', Aliases=['SOLO'], description='Rho guanine nucleotide exchange factor 40', other_designations='rho guanine nucleotide exchange factor 40|Rho guanine nucleotide exchange factor (GEF) 40|protein SOLO', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21061276, end_position_on_the_genomic_accession=21090248, orientation='plus', exon_count=27, OMIM=[610018], no_hdr0=''),
    55702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55702, CurrentID=0, Status='live', Symbol='YJU2', Aliases=['CCDC94'], description='YJU2 splicing factor homolog', other_designations='splicing factor YJU2|coiled-coil domain containing 94|coiled-coil domain-containing protein 94', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4247080, end_position_on_the_genomic_accession=4269088, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    55703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55703, CurrentID=0, Status='live', Symbol='POLR3B', Aliases=['C128', 'HLD8', 'INMAP', 'RPC2'], description='RNA polymerase III subunit B', other_designations='DNA-directed RNA polymerase III subunit RPC2|DNA-directed RNA polymerase III 127.6 kDa polypeptide|DNA-directed RNA polymerase III subunit B|RNA polymerase III subunit C2|interphase nucleus and mitotic apparatus associated protein|polymerase (RNA) III (DNA directed) polypeptide B|polymerase (RNA) III subunit B', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106357712, end_position_on_the_genomic_accession=106510198, orientation='plus', exon_count=30, OMIM=[614366], no_hdr0=''),
    55704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55704, CurrentID=0, Status='live', Symbol='CCDC88A', Aliases=['APE', 'GIRDIN', 'GIV', 'GRDN', 'HkRP1', 'KIAA1212', 'PEHO', 'PEHOL'], description='coiled-coil domain containing 88A', other_designations='girdin|AKT-phosphorylation enhancer|Hook-related protein 1|g alpha-interacting vesicle-associated protein|girders of actin filaments', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55287817, end_position_on_the_genomic_accession=55419856, orientation='minus', exon_count=33, OMIM=[609736], no_hdr0=''),
    55705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55705, CurrentID=0, Status='live', Symbol='IPO9', Aliases=['Imp9'], description='importin 9', other_designations='importin-9|ran-binding protein 9|ranBP9', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201829157, end_position_on_the_genomic_accession=201884291, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    55706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55706, CurrentID=0, Status='live', Symbol='NDC1', Aliases=['NET3', 'TMEM48'], description='NDC1 transmembrane nucleoporin', other_designations='nucleoporin NDC1|nuclear division cycle 1 homolog|transmembrane protein 48', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53765478, end_position_on_the_genomic_accession=53838296, orientation='minus', exon_count=19, OMIM=[610115], no_hdr0=''),
    55707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55707, CurrentID=0, Status='live', Symbol='NECAP2', Aliases=[], description='NECAP endocytosis associated 2', other_designations='adaptin ear-binding coat-associated protein 2|adaptin-ear-binding coat-associated protein 2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16440724, end_position_on_the_genomic_accession=16460078, orientation='plus', exon_count=9, OMIM=[611624], no_hdr0=''),
    55709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55709, CurrentID=0, Status='live', Symbol='KBTBD4', Aliases=['BKLHD4', 'HSPC252'], description='kelch repeat and BTB domain containing 4', other_designations='kelch repeat and BTB domain-containing protein 4|BTB and kelch domain containing 4|BTB and kelch domain-containing protein 4|kelch repeat and BTB (POZ) domain containing 4', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47572197, end_position_on_the_genomic_accession=47578970, orientation='minus', exon_count=5, OMIM=[617645], no_hdr0=''),
    55711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55711, CurrentID=0, Status='live', Symbol='FAR2', Aliases=['HEL-S-81', 'MLSTD1', 'SDR10E2'], description='fatty acyl-CoA reductase 2', other_designations='fatty acyl-CoA reductase 2|epididymis secretory protein Li 81|male sterility domain-containing protein 1|short chain dehydrogenase/reductase family 10E, member 2', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=29149101, end_position_on_the_genomic_accession=29335617, orientation='plus', exon_count=14, OMIM=[616156], no_hdr0=''),
    55713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55713, CurrentID=0, Status='live', Symbol='ZNF334', Aliases=[], description='zinc finger protein 334', other_designations='zinc finger protein 334', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46463660, end_position_on_the_genomic_accession=46513559, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    55714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55714, CurrentID=0, Status='live', Symbol='TENM3', Aliases=['MCOPCB9', 'MCOPS15', 'ODZ3', 'TEN3', 'TNM3', 'Ten-m3', 'ten-3'], description='teneurin transmembrane protein 3', other_designations='teneurin-3|ODZ3-like protein|odz, odd Oz/ten-m homolog 3|protein Odd Oz/ten-m homolog 3|tenascin-M3|testicular tissue protein Li 195', map_location='4q34.3-q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=181447613, end_position_on_the_genomic_accession=182803024, orientation='plus', exon_count=39, OMIM=[610083], no_hdr0=''),
    55715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55715, CurrentID=0, Status='live', Symbol='DOK4', Aliases=['IRS-5', 'IRS5'], description='docking protein 4', other_designations='docking protein 4|downstream of tyrosine kinase 4|insulin receptor substrate 5', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57471922, end_position_on_the_genomic_accession=57487322, orientation='minus', exon_count=10, OMIM=[608333], no_hdr0=''),
    55716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55716, CurrentID=0, Status='live', Symbol='LMBR1L', Aliases=['LIMR'], description='limb development membrane protein 1 like', other_designations='protein LMBR1L|limb development membrane protein 1 like-protein|limb region 1 homolog-like|limb region 1 protein homolog-like|limb region 1-like protein -like|lipocalin-1 interacting membrane receptor|lipocalin-interacting membrane receptor', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49096551, end_position_on_the_genomic_accession=49110897, orientation='minus', exon_count=19, OMIM=[610007], no_hdr0=''),
    55717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55717, CurrentID=0, Status='live', Symbol='WDR11', Aliases=['BRWD2', 'DR11', 'HH14', 'SRI1', 'WDR15'], description='WD repeat domain 11', other_designations='WD repeat-containing protein 11|WD repeat domain 15|WD repeat-containing protein 15|bromodomain and WD repeat-containing protein 2|sensitization to ricin complex subunit 1', map_location='10q26.12', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=120851313, end_position_on_the_genomic_accession=120909525, orientation='plus', exon_count=30, OMIM=[606417], no_hdr0=''),
    55718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55718, CurrentID=0, Status='live', Symbol='POLR3E', Aliases=['C37', 'RPC5', 'SIN'], description='RNA polymerase III subunit E', other_designations='DNA-directed RNA polymerase III subunit RPC5|DNA-directed RNA polymerase III 80 kDa polypeptide|RNA polymerase III 80 kDa subunit RPC5|RNA polymerase III subunit C5|polymerase (RNA) III (DNA directed) polypeptide E (80kD)|polymerase (RNA) III subunit E', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22297409, end_position_on_the_genomic_accession=22335096, orientation='plus', exon_count=21, OMIM=[617815], no_hdr0=''),
    55719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55719, CurrentID=0, Status='live', Symbol='SLF2', Aliases=['C10orf6', 'FAM178A'], description='SMC5-SMC6 complex localization factor 2', other_designations='SMC5-SMC6 complex localization factor protein 2|family with sequence similarity 178, member A|protein FAM178A|smc5/6 localization factor 1', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100909416, end_position_on_the_genomic_accession=100965134, orientation='plus', exon_count=21, OMIM=[610348], no_hdr0=''),
    55720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55720, CurrentID=0, Status='live', Symbol='TSR1', Aliases=[], description='TSR1 ribosome maturation factor', other_designations='pre-rRNA-processing protein TSR1 homolog', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2322396, end_position_on_the_genomic_accession=2336457, orientation='minus', exon_count=15, OMIM=[611214], no_hdr0=''),
    55721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55721, CurrentID=0, Status='live', Symbol='IQCC', Aliases=[], description='IQ motif containing C', other_designations='IQ domain-containing protein C', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32205671, end_position_on_the_genomic_accession=32208682, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    55722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55722, CurrentID=0, Status='live', Symbol='CEP72', Aliases=[], description='centrosomal protein 72', other_designations='centrosomal protein of 72 kDa|centrosomal protein 72kDa', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=612340, end_position_on_the_genomic_accession=668744, orientation='plus', exon_count=20, OMIM=[616475], no_hdr0=''),
    55723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55723, CurrentID=0, Status='live', Symbol='ASF1B', Aliases=['CIA-II'], description='anti-silencing function 1B histone chaperone', other_designations='histone chaperone ASF1B|ASF1 anti-silencing function 1 homolog B|CCG1-interacting factor A-II|anti-silencing function protein 1 homolog B|hAsf1|hAsf1b|hCIA-II', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14119512, end_position_on_the_genomic_accession=14136589, orientation='minus', exon_count=4, OMIM=[609190], no_hdr0=''),
    55726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55726, CurrentID=0, Status='live', Symbol='INTS13', Aliases=['ASUN', 'C12orf11', 'GCT1', 'Mat89Bb', 'NET48', 'SPATA30'], description='integrator complex subunit 13', other_designations='integrator complex subunit 13|asunder, spermatogenesis regulator homolog (Drosphila)|cell cycle regulator Mat89Bb homolog|germ cell tumor 1|protein asunder homolog|sarcoma antigen NY-SAR-95|spermatogenesis associated 30', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26905171, end_position_on_the_genomic_accession=26938338, orientation='minus', exon_count=19, OMIM=[615079], no_hdr0=''),
    55727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55727, CurrentID=0, Status='live', Symbol='BTBD7', Aliases=['FUP1'], description='BTB domain containing 7', other_designations='BTB/POZ domain-containing protein 7|BTB (POZ) domain containing 7', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93237550, end_position_on_the_genomic_accession=93333036, orientation='minus', exon_count=13, OMIM=[610386], no_hdr0=''),
    55728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55728, CurrentID=0, Status='live', Symbol='N4BP2', Aliases=['B3BP'], description='NEDD4 binding protein 2', other_designations='NEDD4-binding protein 2|BCL-3-binding protein', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40056223, end_position_on_the_genomic_accession=40187039, orientation='plus', exon_count=23, OMIM=[619139], no_hdr0=''),
    55729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55729, CurrentID=0, Status='live', Symbol='ATF7IP', Aliases=['AM', 'ATF-IP', 'MCAF', 'MCAF1', 'p621'], description='activating transcription factor 7 interacting protein', other_designations='activating transcription factor 7-interacting protein 1|ATF-interacting protein|ATF7-interacting protein|ATFa-associated modulator|MBD1-containing chromatin-associated factor 1', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14365640, end_position_on_the_genomic_accession=14502935, orientation='plus', exon_count=22, OMIM=[613644], no_hdr0=''),
    55731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55731, CurrentID=0, Status='live', Symbol='FAM222B', Aliases=['C17orf63'], description='family with sequence similarity 222 member B', other_designations='protein FAM222B|uncharacterized protein C17orf63', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28755979, end_position_on_the_genomic_accession=28854985, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    55732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55732, CurrentID=0, Status='live', Symbol='C1orf112', Aliases=[], description='chromosome 1 open reading frame 112', other_designations='uncharacterized protein C1orf112', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169794730, end_position_on_the_genomic_accession=169854080, orientation='plus', exon_count=29, OMIM=[], no_hdr0=''),
    55733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55733, CurrentID=0, Status='live', Symbol='HHAT', Aliases=['MART2', 'NNMS', 'SKI1', 'Skn'], description='hedgehog acyltransferase', other_designations='protein-cysteine N-palmitoyltransferase HHAT|melanoma antigen recognized by T-cells 2|skinny hedgehog protein 1', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=210327873, end_position_on_the_genomic_accession=210676298, orientation='plus', exon_count=18, OMIM=[605743], no_hdr0=''),
    55734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55734, CurrentID=0, Status='live', Symbol='ZFP64', Aliases=['ZNF338'], description='ZFP64 zinc finger protein', other_designations='zinc finger protein 64|zinc finger protein 338|zinc finger protein 64 homolog', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=52084011, end_position_on_the_genomic_accession=52191789, orientation='minus', exon_count=14, OMIM=[618111], no_hdr0=''),
    55735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55735, CurrentID=0, Status='live', Symbol='DNAJC11', Aliases=['dJ126A5.1'], description='DnaJ heat shock protein family (Hsp40) member C11', other_designations='dnaJ homolog subfamily C member 11|DnaJ (Hsp40) homolog, subfamily C, member 11|novel DnaJ domain-containing protein', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6634168, end_position_on_the_genomic_accession=6701833, orientation='minus', exon_count=16, OMIM=[614827], no_hdr0=''),
    55737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55737, CurrentID=0, Status='live', Symbol='VPS35', Aliases=['MEM3', 'PARK17'], description='VPS35 retromer complex component', other_designations='vacuolar protein sorting-associated protein 35|hVPS35|maternal-embryonic 3|vacuolar protein sorting 35 homolog', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46656132, end_position_on_the_genomic_accession=46689194, orientation='minus', exon_count=17, OMIM=[601501], no_hdr0=''),
    55738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55738, CurrentID=0, Status='live', Symbol='ARFGAP1', Aliases=['ARF1GAP', 'HRIHFB2281'], description='ADP ribosylation factor GTPase activating protein 1', other_designations='ADP-ribosylation factor GTPase-activating protein 1|ARF1-directed GTPase-activating protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63272813, end_position_on_the_genomic_accession=63289790, orientation='plus', exon_count=18, OMIM=[608377], no_hdr0=''),
    55739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55739, CurrentID=0, Status='live', Symbol='NAXD', Aliases=['CARKD', 'LP3298', 'PEBEL2'], description='NAD(P)HX dehydratase', other_designations='ATP-dependent (S)-NAD(P)H-hydrate dehydratase|ATP-dependent NAD(P)H-hydrate dehydratase|ATP-dependent NAD(P)HX dehydratase|carbohydrate kinase domain containing|carbohydrate kinase domain-containing protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110615460, end_position_on_the_genomic_accession=110639996, orientation='plus', exon_count=10, OMIM=[615910], no_hdr0=''),
    55740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55740, CurrentID=0, Status='live', Symbol='ENAH', Aliases=['ENA', 'MENA', 'NDPP1'], description='ENAH actin regulator', other_designations='protein enabled homolog|enabled homolog|mammalian enabled variant 11a|mammalian enabled variant pan', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225486829, end_position_on_the_genomic_accession=225660046, orientation='minus', exon_count=20, OMIM=[609061], no_hdr0=''),
    55741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55741, CurrentID=0, Status='live', Symbol='EDEM2', Aliases=['C20orf31', 'C20orf49', 'bA4204.1'], description='ER degradation enhancing alpha-mannosidase like protein 2', other_designations='ER degradation-enhancing alpha-mannosidase-like protein 2|ER degradation enhancer, mannosidase alpha-like 2|ER degradation-enhancing alpha-mannosidase-like 2|ER degradation-enhancing-mannosidase-like protein 2', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35115364, end_position_on_the_genomic_accession=35147336, orientation='minus', exon_count=11, OMIM=[610302], no_hdr0=''),
    55742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55742, CurrentID=0, Status='live', Symbol='PARVA', Aliases=['CH-ILKBP', 'MXRA2'], description='parvin alpha', other_designations='alpha-parvin|actopaxin|calponin-like integrin-linked kinase-binding protein|matrix-remodeling-associated protein 2', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=12376441, end_position_on_the_genomic_accession=12535356, orientation='plus', exon_count=14, OMIM=[608120], no_hdr0=''),
    55743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55743, CurrentID=0, Status='live', Symbol='CHFR', Aliases=['RNF116', 'RNF196'], description='checkpoint with forkhead and ring finger domains', other_designations='E3 ubiquitin-protein ligase CHFR|RING finger protein 196|RING-type E3 ubiquitin transferase CHFR|checkpoint with forkhead and ring finger domains, E3 ubiquitin protein ligase', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132832356, end_position_on_the_genomic_accession=132887618, orientation='minus', exon_count=19, OMIM=[605209], no_hdr0=''),
    55744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55744, CurrentID=0, Status='live', Symbol='COA1', Aliases=['C7orf44', 'MITRAC15'], description='cytochrome c oxidase assembly factor 1', other_designations='cytochrome c oxidase assembly factor 1 homolog|cytochrome c oxidase assembly protein 1 homolog|mitochondrial translation regulation assembly intermediate of cytochrome c oxidase protein of 15 kDa', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43608452, end_position_on_the_genomic_accession=43729533, orientation='minus', exon_count=17, OMIM=[614769], no_hdr0=''),
    55745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55745, CurrentID=0, Status='live', Symbol='AP5M1', Aliases=['C14orf108', 'MUDENG', 'Mu5', 'MuD'], description='adaptor related protein complex 5 subunit mu 1', other_designations='AP-5 complex subunit mu-1|AP-5 complex subunit mu|MHD domain-containing death-inducing protein|MU-2/AP1M2 domain containing, death-inducing|Mu-2 related death-inducing|adapter-related protein complex 5 mu subunit|adapter-related protein complex 5 subunit mu-1|adaptor related protein complex 5 mu 1 subunit|mu-2-related death-inducing protein|putative HIV-1 infection-related protein', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57268915, end_position_on_the_genomic_accession=57298742, orientation='plus', exon_count=9, OMIM=[614368], no_hdr0=''),
    55746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55746, CurrentID=0, Status='live', Symbol='NUP133', Aliases=['GAMOS8', 'NPHS18', 'hNUP133'], description='nucleoporin 133', other_designations='nuclear pore complex protein Nup133|133 kDa nucleoporin|nucleoporin 133kD|nucleoporin 133kDa|nucleoporin Nup133', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229440259, end_position_on_the_genomic_accession=229508342, orientation='minus', exon_count=26, OMIM=[607613], no_hdr0=''),
    55748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55748, CurrentID=0, Status='live', Symbol='CNDP2', Aliases=['CN2', 'CPGL', 'HEL-S-13', 'HsT2298', 'PEPA'], description='carnosine dipeptidase 2', other_designations='cytosolic non-specific dipeptidase|CNDP dipeptidase 2 (metallopeptidase M20 family)|carnosinase-2|carnosine dipeptidase II|cytosolic nonspecific dipeptidase|epididymis secretory protein Li 13|glutamate carboxypeptidase-like protein 1|peptidase A', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74496363, end_position_on_the_genomic_accession=74523454, orientation='plus', exon_count=15, OMIM=[169800], no_hdr0=''),
    55749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55749, CurrentID=0, Status='live', Symbol='CCAR1', Aliases=[], description='cell division cycle and apoptosis regulator 1', other_designations='cell division cycle and apoptosis regulator protein 1|cell cycle and apoptosis regulatory protein 1|death inducer with SAP domain', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68721239, end_position_on_the_genomic_accession=68792377, orientation='plus', exon_count=25, OMIM=[612569], no_hdr0=''),
    55750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55750, CurrentID=0, Status='live', Symbol='AGK', Aliases=['CATC5', 'CTRCT38', 'MTDPS10', 'MULK'], description='acylglycerol kinase', other_designations='acylglycerol kinase, mitochondrial|hAGK|hsMuLK|multi-substrate lipid kinase|multiple substrate lipid kinase', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141551410, end_position_on_the_genomic_accession=141662153, orientation='plus', exon_count=19, OMIM=[610345], no_hdr0=''),
    55751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55751, CurrentID=0, Status='live', Symbol='TMEM184C', Aliases=['TMEM34'], description='transmembrane protein 184C', other_designations='transmembrane protein 184C|transmembrane protein 34', map_location='4q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=147617371, end_position_on_the_genomic_accession=147637273, orientation='plus', exon_count=10, OMIM=[613937], no_hdr0=''),
    55752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55752, CurrentID=0, Status='live', Symbol='SEPTIN11', Aliases=['SEPT11'], description='septin 11', other_designations='septin-11|epididymis secretory sperm binding protein', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76949752, end_position_on_the_genomic_accession=77040154, orientation='plus', exon_count=13, OMIM=[612887], no_hdr0=''),
    55753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55753, CurrentID=0, Status='live', Symbol='OGDHL', Aliases=[], description='oxoglutarate dehydrogenase L', other_designations='2-oxoglutarate dehydrogenase-like, mitochondrial|2-oxoglutarate dehydrogenase complex component E1-like|OGDC-E1-like|alpha-ketoglutarate dehydrogenase-like|oxoglutarate dehydrogenase like', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49734641, end_position_on_the_genomic_accession=49762379, orientation='minus', exon_count=25, OMIM=[617513], no_hdr0=''),
    55754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55754, CurrentID=0, Status='live', Symbol='TMEM30A', Aliases=['C6orf67', 'CDC50A'], description='transmembrane protein 30A', other_designations='cell cycle control protein 50A|P4-ATPase flippase complex beta subunit TMEM30A', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=75252924, end_position_on_the_genomic_accession=75284792, orientation='minus', exon_count=7, OMIM=[611028], no_hdr0=''),
    55755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55755, CurrentID=0, Status='live', Symbol='CDK5RAP2', Aliases=['C48', 'Cep215', 'MCPH3'], description='CDK5 regulatory subunit associated protein 2', other_designations='CDK5 regulatory subunit-associated protein 2|CDK5 activator-binding protein C48|centrosomal protein 215 kDa|centrosomin', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120388875, end_position_on_the_genomic_accession=120580167, orientation='minus', exon_count=39, OMIM=[608201], no_hdr0=''),
    55756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55756, CurrentID=0, Status='live', Symbol='INTS9', Aliases=['CPSF2L', 'INT9', 'RC74'], description='integrator complex subunit 9', other_designations='integrator complex subunit 9|protein related to CPSF subunits of 74 kDa', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28767661, end_position_on_the_genomic_accession=28890226, orientation='minus', exon_count=20, OMIM=[611352], no_hdr0=''),
    55757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55757, CurrentID=0, Status='live', Symbol='UGGT2', Aliases=['HUGT2', 'UGCGL2', 'UGT2'], description='UDP-glucose glycoprotein glucosyltransferase 2', other_designations='UDP-glucose:glycoprotein glucosyltransferase 2|UDP-Glc:glycoprotein glucosyltransferase 2|UDP-glucose ceramide glucosyltransferase-like 1|UDP-glucose ceramide glucosyltransferase-like 2', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=95801580, end_position_on_the_genomic_accession=96053437, orientation='minus', exon_count=46, OMIM=[605898], no_hdr0=''),
    55758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55758, CurrentID=0, Status='live', Symbol='RCOR3', Aliases=[], description='REST corepressor 3', other_designations='REST corepressor 3', map_location='1q32.2-q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211259366, end_position_on_the_genomic_accession=211316385, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    55759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55759, CurrentID=0, Status='live', Symbol='WDR12', Aliases=['YTM1'], description='WD repeat domain 12', other_designations='ribosome biogenesis protein WDR12|WD repeat-containing protein 12', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202874261, end_position_on_the_genomic_accession=202911673, orientation='minus', exon_count=13, OMIM=[616620], no_hdr0=''),
    55760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55760, CurrentID=0, Status='live', Symbol='DHX32', Aliases=['DDX32', 'DHLP1'], description='DEAH-box helicase 32 (putative)', other_designations='putative pre-mRNA-splicing factor ATP-dependent RNA helicase DHX32|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 32|DEAD/H box 32|DEAD/H helicase-like protein-1|DEAH (Asp-Glu-Ala-His) box polypeptide 32|DEAH box protein 32|huDDX32', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125836337, end_position_on_the_genomic_accession=125881292, orientation='minus', exon_count=11, OMIM=[607960], no_hdr0=''),
    55761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55761, CurrentID=0, Status='live', Symbol='TTC17', Aliases=[], description='tetratricopeptide repeat domain 17', other_designations='tetratricopeptide repeat protein 17|TPR repeat protein 17', map_location='11p12-p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=43358885, end_position_on_the_genomic_accession=43494931, orientation='plus', exon_count=27, OMIM=[619388], no_hdr0=''),
    55762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55762, CurrentID=0, Status='live', Symbol='ZNF701', Aliases=[], description='zinc finger protein 701', other_designations='zinc finger protein 701', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52570285, end_position_on_the_genomic_accession=52627269, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    55763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55763, CurrentID=0, Status='live', Symbol='EXOC1', Aliases=['BM-102', 'SEC3', 'SEC3L1', 'SEC3P'], description='exocyst complex component 1', other_designations='exocyst complex component 1|SEC3-like 1|exocyst complex component Sec3', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55853648, end_position_on_the_genomic_accession=55905086, orientation='plus', exon_count=21, OMIM=[607879], no_hdr0=''),
    55764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55764, CurrentID=0, Status='live', Symbol='IFT122', Aliases=['CED', 'CED1', 'FAP80', 'SPG', 'WDR10', 'WDR10p', 'WDR140'], description='intraflagellar transport 122', other_designations='intraflagellar transport protein 122 homolog|WD repeat domain 10|WD repeat-containing protein 10|WD repeat-containing protein 140|intraflagellar transport 122 homolog', map_location='3q21.3-q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129440075, end_position_on_the_genomic_accession=129520507, orientation='plus', exon_count=34, OMIM=[606045], no_hdr0=''),
    55765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55765, CurrentID=0, Status='live', Symbol='INAVA', Aliases=['C1orf106'], description='innate immunity activator', other_designations='innate immunity activator protein|uncharacterized protein C1orf106', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200891074, end_position_on_the_genomic_accession=200915742, orientation='plus', exon_count=12, OMIM=[618051], no_hdr0=''),
    55766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55766, CurrentID=0, Status='live', Symbol='H2AJ', Aliases=['H2AFJ'], description='H2A.J histone', other_designations='histone H2A.J|H2A histone family member J|H2a/j|buforin I', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14774405, end_position_on_the_genomic_accession=14778002, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    55768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55768, CurrentID=0, Status='live', Symbol='NGLY1', Aliases=['CDDG', 'CDG1V', 'PNG-1', 'PNG1', 'PNGase'], description='N-glycanase 1', other_designations='peptide-N(4)-(N-acetyl-beta-glucosaminyl)asparagine amidase|hPNGase|peptide:N-glycanase', map_location='3p24.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=25718944, end_position_on_the_genomic_accession=25790039, orientation='minus', exon_count=16, OMIM=[610661], no_hdr0=''),
    55769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55769, CurrentID=0, Status='live', Symbol='ZNF83', Aliases=['HPF1', 'ZNF816B'], description='zinc finger protein 83', other_designations='zinc finger protein 83|zinc finger protein 816B|zinc finger protein HPF1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52612377, end_position_on_the_genomic_accession=52690496, orientation='minus', exon_count=11, OMIM=[194558], no_hdr0=''),
    55770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55770, CurrentID=0, Status='live', Symbol='EXOC2', Aliases=['NEDFACH', 'SEC5', 'SEC5L1', 'Sec5p'], description='exocyst complex component 2', other_designations='exocyst complex component 2|SEC5-like 1|exocyst complex component Sec5', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=485154, end_position_on_the_genomic_accession=693141, orientation='minus', exon_count=34, OMIM=[615329], no_hdr0=''),
    55771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55771, CurrentID=0, Status='live', Symbol='PRR11', Aliases=[], description='proline rich 11', other_designations='proline-rich protein 11|transcription repressor of MHCII', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59155355, end_position_on_the_genomic_accession=59206709, orientation='plus', exon_count=11, OMIM=[615920], no_hdr0=''),
    55773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55773, CurrentID=0, Status='live', Symbol='TBC1D23', Aliases=['NS4ATP1', 'PCH11'], description='TBC1 domain family member 23', other_designations='TBC1 domain family member 23|HCV non-structural protein 4A-transactivated protein 1|HCV nonstructural protein 4A-transactivated protein 1', map_location='3q12.1-q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100260992, end_position_on_the_genomic_accession=100325238, orientation='plus', exon_count=20, OMIM=[617687], no_hdr0=''),
    55775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55775, CurrentID=0, Status='live', Symbol='TDP1', Aliases=[], description='tyrosyl-DNA phosphodiesterase 1', other_designations='tyrosyl-DNA phosphodiesterase 1|tyr-DNA phosphodiesterase 1', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=89954923, end_position_on_the_genomic_accession=90044768, orientation='plus', exon_count=23, OMIM=[607198], no_hdr0=''),
    55776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55776, CurrentID=0, Status='live', Symbol='SAYSD1', Aliases=['C6orf64'], description='SAYSVFN motif domain containing 1', other_designations='SAYSvFN domain-containing protein 1', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39104063, end_position_on_the_genomic_accession=39115186, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    55777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55777, CurrentID=0, Status='live', Symbol='MBD5', Aliases=['MRD1'], description='methyl-CpG binding domain protein 5', other_designations='methyl-CpG-binding domain protein 5|methyl-CpG-binding protein MBD5', map_location='2q23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=148021011, end_position_on_the_genomic_accession=148516971, orientation='plus', exon_count=18, OMIM=[611472], no_hdr0=''),
    55778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55778, CurrentID=0, Status='live', Symbol='ZNF839', Aliases=['C14orf131'], description='zinc finger protein 839', other_designations='zinc finger protein 839|renal carcinoma antigen NY-REN-50', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102317506, end_position_on_the_genomic_accession=102342614, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    55779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55779, CurrentID=0, Status='live', Symbol='CFAP44', Aliases=['SPGF20', 'WDR52'], description='cilia and flagella associated protein 44', other_designations='cilia- and flagella-associated protein 44|WD repeat domain 52|WD repeat-containing protein 52', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113286930, end_position_on_the_genomic_accession=113441514, orientation='minus', exon_count=35, OMIM=[617559], no_hdr0=''),
    55780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55780, CurrentID=0, Status='live', Symbol='ERMARD', Aliases=['C6orf70', 'PVNH6', 'dJ266L20.3'], description='ER membrane associated RNA degradation', other_designations='endoplasmic reticulum membrane-associated RNA degradation protein|transmembrane protein C6orf70', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169751622, end_position_on_the_genomic_accession=169781600, orientation='plus', exon_count=21, OMIM=[615532], no_hdr0=''),
    55781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55781, CurrentID=0, Status='live', Symbol='RIOK2', Aliases=['RIO2'], description='RIO kinase 2', other_designations='serine/threonine-protein kinase RIO2', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=97160867, end_position_on_the_genomic_accession=97183247, orientation='minus', exon_count=11, OMIM=[617754], no_hdr0=''),
    55783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55783, CurrentID=0, Status='live', Symbol='CMTR2', Aliases=['AFT', 'FTSJD1', 'HMTr2', 'MTr2'], description='cap methyltransferase 2', other_designations="cap-specific mRNA (nucleoside-2'-O-)-methyltransferase 2|FtsJ methyltransferase domain containing 1|adrift homolog|cap2 2'O-ribose methyltransferase 2|ftsJ methyltransferase domain-containing protein 1|protein adrift homolog", map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71281392, end_position_on_the_genomic_accession=71290178, orientation='minus', exon_count=4, OMIM=[616190], no_hdr0=''),
    55784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55784, CurrentID=0, Status='live', Symbol='MCTP2', Aliases=[], description='multiple C2 and transmembrane domain containing 2', other_designations='multiple C2 and transmembrane domain-containing protein 2|multiple C2 domains, transmembrane 2|multiple C2-domains with two transmembrane regions 2 1', map_location='15q26.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=94231561, end_position_on_the_genomic_accession=94483952, orientation='plus', exon_count=34, OMIM=[616297], no_hdr0=''),
    55785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55785, CurrentID=0, Status='live', Symbol='FGD6', Aliases=['ZFYVE24'], description='FYVE, RhoGEF and PH domain containing 6', other_designations='FYVE, RhoGEF and PH domain-containing protein 6|zinc finger FYVE domain-containing protein 24', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95076749, end_position_on_the_genomic_accession=95217467, orientation='minus', exon_count=21, OMIM=[613520], no_hdr0=''),
    55786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55786, CurrentID=0, Status='live', Symbol='ZNF415', Aliases=['Pact', 'ZfLp'], description='zinc finger protein 415', other_designations='zinc finger protein 415', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53107879, end_position_on_the_genomic_accession=53132952, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    55787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55787, CurrentID=0, Status='live', Symbol='TXLNG', Aliases=['CXorf15', 'ELRG', 'FIAT', 'LSR5X', 'TXLNG'], description='taxilin gamma', other_designations='gamma-taxilin|environmental LPS-responding|environmental lipopolysaccharide-responding gene protein|factor inhibiting ATF4-mediated transcription|factor inhibiting activating transcription factor 4 (ATF4)-mediated transcription|lipopolysaccharide specific response-5 protein|lipopolysaccharide-specific response protein 5', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16786432, end_position_on_the_genomic_accession=16844519, orientation='plus', exon_count=15, OMIM=[300677], no_hdr0=''),
    55788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55788, CurrentID=0, Status='live', Symbol='LMBRD1', Aliases=['C6orf209', 'LMBD1', 'MAHCF', 'NESI'], description='LMBR1 domain containing 1', other_designations='lysosomal cobalamin transport escort protein LMBD1|HDAg-L-interacting protein NESI|hepatitis delta antigen-L interacting protein|liver regeneration p-53 related protein|nuclear export signal-interacting protein|probable lysosomal cobalamin transporter', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=69674010, end_position_on_the_genomic_accession=69797010, orientation='minus', exon_count=17, OMIM=[612625], no_hdr0=''),
    55789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55789, CurrentID=0, Status='live', Symbol='DEPDC1B', Aliases=['BRCC3', 'XTP1'], description='DEP domain containing 1B', other_designations='DEP domain-containing protein 1B|HBV X-transactivated gene 8 protein|HBV XAg-transactivated protein 8|HBxAg transactivated protein 1|breast cancer cell 3', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=60596912, end_position_on_the_genomic_accession=60700166, orientation='minus', exon_count=15, OMIM=[616073], no_hdr0=''),
    55790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55790, CurrentID=0, Status='live', Symbol='CSGALNACT1', Aliases=['CSGalNAcT-1', 'ChGn', 'ChGn-1', 'SDJLABA', 'beta4GalNAcT'], description='chondroitin sulfate N-acetylgalactosaminyltransferase 1', other_designations='chondroitin sulfate N-acetylgalactosaminyltransferase 1|beta4GalNAcT-1|chondroitin beta-1,4-N-acetylgalactosaminyltransferase 1|chondroitin beta1,4 N-acetylgalactosaminyltransferase|glucuronylgalactosylproteoglycan 4-beta-N- acetylgalactosaminyltransferase', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=19404161, end_position_on_the_genomic_accession=19757908, orientation='minus', exon_count=34, OMIM=[616615], no_hdr0=''),
    55791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55791, CurrentID=0, Status='live', Symbol='LRIF1', Aliases=['C1orf103', 'HBiX1', 'RIF1'], description='ligand dependent nuclear receptor interacting factor 1', other_designations='ligand-dependent nuclear receptor-interacting factor 1|HP1-binding protein enriched in inactive X chromosome protein 1|receptor-interacting factor 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110877252, end_position_on_the_genomic_accession=110963962, orientation='minus', exon_count=5, OMIM=[615354], no_hdr0=''),
    55793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55793, CurrentID=0, Status='live', Symbol='MINDY1', Aliases=['FAM63A', 'MINDY-1'], description='MINDY lysine 48 deubiquitinase 1', other_designations='ubiquitin carboxyl-terminal hydrolase MINDY-1|MINDY deubiquitinase 1|MIU-containing novel DUB family member 1|deubiquitinating enzyme MINDY-1|family with sequence similarity 63 member A|motif interacting with Ub-containing novel DUB|protein FAM63A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150996536, end_position_on_the_genomic_accession=151008393, orientation='minus', exon_count=13, OMIM=[618407], no_hdr0=''),
    55794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55794, CurrentID=0, Status='live', Symbol='DDX28', Aliases=['MDDX28'], description='DEAD-box helicase 28', other_designations='probable ATP-dependent RNA helicase DDX28|DEAD (Asp-Glu-Ala-Asp) box polypeptide 28|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 28|mitochondrial DEAD box protein 28|mitochondrial DEAD-box polypeptide 28', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68020916, end_position_on_the_genomic_accession=68023232, orientation='minus', exon_count=1, OMIM=[607618], no_hdr0=''),
    55795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55795, CurrentID=0, Status='live', Symbol='PCID2', Aliases=['F10'], description='PCI domain containing 2', other_designations='PCI domain-containing protein 2|CSN12-like protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113165002, end_position_on_the_genomic_accession=113209467, orientation='minus', exon_count=23, OMIM=[613713], no_hdr0=''),
    55796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55796, CurrentID=0, Status='live', Symbol='MBNL3', Aliases=['CHCR', 'MBLX', 'MBLX39', 'MBXL'], description='muscleblind like splicing regulator 3', other_designations='muscleblind-like protein 3|Cys3His CCG1-required protein|muscleblind-like 3|muscleblind-like X-linked protein', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=132369320, end_position_on_the_genomic_accession=132490035, orientation='minus', exon_count=18, OMIM=[300413], no_hdr0=''),
    55798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55798, CurrentID=0, Status='live', Symbol='METTL2B', Aliases=['METL', 'METTL2', 'METTL2A', 'PSENIP1'], description='methyltransferase 2B, methylcytidine', other_designations='tRNA N(3)-methylcytidine methyltransferase METTL2B|methyltransferase like 2B|methyltransferase-like protein 2B', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128476748, end_position_on_the_genomic_accession=128506602, orientation='plus', exon_count=9, OMIM=[607846], no_hdr0=''),
    55799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55799, CurrentID=0, Status='live', Symbol='CACNA2D3', Aliases=['HSA272268'], description='calcium voltage-gated channel auxiliary subunit alpha2delta 3', other_designations='voltage-dependent calcium channel subunit alpha-2/delta-3|calcium channel alpha2-delta3 subunit|calcium channel, voltage-dependent, alpha 2/delta 3 subunit|calcium channel, voltage-dependent, alpha 2/delta subunit 3|voltage-gated calcium channel subunit alpha-2/delta-3', map_location='3p21.1-p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=54122552, end_position_on_the_genomic_accession=55074557, orientation='plus', exon_count=38, OMIM=[606399], no_hdr0=''),
    55800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55800, CurrentID=0, Status='live', Symbol='SCN3B', Aliases=['ATFB16', 'BRGDA7', 'HSA243396', 'SCNB3'], description='sodium voltage-gated channel beta subunit 3', other_designations='sodium channel subunit beta-3|sodium channel, voltage-gated, type III, beta subunit|voltage-gated sodium channel beta-3 subunit', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123629187, end_position_on_the_genomic_accession=123654624, orientation='minus', exon_count=7, OMIM=[608214], no_hdr0=''),
    55801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55801, CurrentID=0, Status='live', Symbol='IL26', Aliases=['AK155', 'IL-26'], description='interleukin 26', other_designations='interleukin-26', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68201349, end_position_on_the_genomic_accession=68225810, orientation='minus', exon_count=5, OMIM=[605679], no_hdr0=''),
    55802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55802, CurrentID=0, Status='live', Symbol='DCP1A', Aliases=['HSA275986', 'Nbla00360', 'SMAD4IP1', 'SMIF'], description='decapping mRNA 1A', other_designations='mRNA-decapping enzyme 1A|DCP1 decapping enzyme homolog A|DCP1 decapping enzyme-like protein A|Smad4-interacting transcriptional co-activator|decapping enzyme hDcp1a|putative protein product of Nbla00360|transcription factor SMIF', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53283429, end_position_on_the_genomic_accession=53347543, orientation='minus', exon_count=11, OMIM=[607010], no_hdr0=''),
    55803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55803, CurrentID=0, Status='live', Symbol='ADAP2', Aliases=['CENTA2', 'HSA272195', 'cent-b'], description='ArfGAP with dual PH domains 2', other_designations='arf-GAP with dual PH domain-containing protein 2|centaurin beta|centaurin-alpha 2 protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30921904, end_position_on_the_genomic_accession=30959398, orientation='plus', exon_count=11, OMIM=[608635], no_hdr0=''),
    55805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55805, CurrentID=0, Status='live', Symbol='LRP2BP', Aliases=[], description='LRP2 binding protein', other_designations='LRP2-binding protein|megBP|megalin-binding protein', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185362862, end_position_on_the_genomic_accession=185397287, orientation='minus', exon_count=12, OMIM=[619020], no_hdr0=''),
    55806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55806, CurrentID=0, Status='live', Symbol='HR', Aliases=['ALUNC', 'AU', 'HSA277165', 'HYPT4', 'MUHH', 'MUHH1'], description='HR lysine demethylase and nuclear receptor corepressor', other_designations='lysine-specific demethylase hairless|[histone H3]-dimethyl-L-lysine(9) demethylase hairless|hair growth associated|hairless homolog|protein hairless', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22114419, end_position_on_the_genomic_accession=22133384, orientation='minus', exon_count=20, OMIM=[602302], no_hdr0=''),
    55808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55808, CurrentID=0, Status='live', Symbol='ST6GALNAC1', Aliases=['HSY11339', 'SIAT7A', 'ST6GalNAcI', 'STYI'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 1', other_designations='alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase 1|GalNAc alpha-2, 6-sialyltransferase I, long form|SIAT7-A|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 1|ST6 GalNAc alpha-2,6-sialyltransferase 1|ST6GALNAC1, alpha-2,6-sialyltransferase 1|ST6GalNAc I|galNAc alpha-2,6-sialyltransferase I|sialyltransferase 7 ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase) A|sialyltransferase 7A', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76617769, end_position_on_the_genomic_accession=76643758, orientation='minus', exon_count=12, OMIM=[610138], no_hdr0=''),
    55809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55809, CurrentID=0, Status='live', Symbol='TRERF1', Aliases=['BCAR2', 'HSA277276', 'RAPA', 'TREP132', 'TReP-132', 'dJ139D8.5'], description='transcriptional regulating factor 1', other_designations='transcriptional-regulating factor 1|breast cancer anti-estrogen resistance 2|rapa-1|rapa-2|transcriptional regulating protein 132|zinc finger protein rapa|zinc finger transcription factor TReP-132', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42224931, end_position_on_the_genomic_accession=42452224, orientation='minus', exon_count=23, OMIM=[610322], no_hdr0=''),
    55810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55810, CurrentID=0, Status='live', Symbol='FOXJ2', Aliases=['FHX'], description='forkhead box J2', other_designations='forkhead box protein J2|FOXJ2 forkhead factor|fork head homologous X', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8032680, end_position_on_the_genomic_accession=8055522, orientation='plus', exon_count=14, OMIM=[619162], no_hdr0=''),
    55811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55811, CurrentID=0, Status='live', Symbol='ADCY10', Aliases=['HCA2', 'HEL-S-7a', 'SAC', 'SACI', 'Sacy', 'hsAC'], description='adenylate cyclase 10', other_designations="adenylate cyclase type 10|3',5'-cyclic AMP synthetase|AH-related protein|ATP pyrophosphate-lyase|adenylate cyclase 10, soluble|epididymis secretory sperm binding protein Li 7a|germ cell soluble adenylyl cyclase|testicular soluble adenylyl cyclase (SAC)", map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167809080, end_position_on_the_genomic_accession=167916389, orientation='minus', exon_count=36, OMIM=[605205], no_hdr0=''),
    55812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55812, CurrentID=0, Status='live', Symbol='SPATA7', Aliases=['HEL-S-296', 'HSD-3.1', 'HSD3', 'LCA3'], description='spermatogenesis associated 7', other_designations='spermatogenesis-associated protein 7|epididymis secretory protein Li 296|epididymis secretory sperm binding protein|spermatogenesis-associated protein HSD3', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88385638, end_position_on_the_genomic_accession=88470350, orientation='plus', exon_count=16, OMIM=[609868], no_hdr0=''),
    55813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55813, CurrentID=0, Status='live', Symbol='UTP6', Aliases=['C17orf40', 'HCA66'], description='UTP6 small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 6 homolog|UTP6, small subunit (SSU) processome component, homolog|hepatocellular carcinoma-associated antigen 66|multiple hat domains protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31860904, end_position_on_the_genomic_accession=31901708, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    55814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55814, CurrentID=0, Status='live', Symbol='BDP1', Aliases=['DFNB112', 'HSA238520', 'TAF3B1', 'TFC5', "TFIIIB''", 'TFIIIB150', 'TFIIIB90', 'TFNR'], description='B double prime 1, subunit of RNA polymerase III transcription initiation factor IIIB', other_designations="transcription factor TFIIIB component B'' homolog|RNA polymerase III transcription initiation factor B''|TATA box binding protein (TBP)-associated factor, RNA polymerase III, GTF3B subunit 1|transcription factor IIIB 150|transcription factor-like nuclear regulator", map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=71455636, end_position_on_the_genomic_accession=71578288, orientation='plus', exon_count=42, OMIM=[607012], no_hdr0=''),
    55815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55815, CurrentID=0, Status='live', Symbol='TSNAXIP1', Aliases=['TXI1'], description='translin associated factor X interacting protein 1', other_designations='translin-associated factor X-interacting protein 1|trax-interacting protein 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67806573, end_position_on_the_genomic_accession=67828068, orientation='plus', exon_count=15, OMIM=[607720], no_hdr0=''),
    55816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55816, CurrentID=0, Status='live', Symbol='DOK5', Aliases=['C20orf180', 'IRS-6', 'IRS6'], description='docking protein 5', other_designations='docking protein 5|downstream of tyrosine kinase 5|insulin receptor substrate 6', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=54475593, end_position_on_the_genomic_accession=54651171, orientation='plus', exon_count=11, OMIM=[608334], no_hdr0=''),
    55818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55818, CurrentID=0, Status='live', Symbol='KDM3A', Aliases=['JHDM2A', 'JHMD2A', 'JMJD1', 'JMJD1A', 'TSGA'], description='lysine demethylase 3A', other_designations='lysine-specific demethylase 3A|[histone H3]-dimethyl-L-lysine(9) demethylase 3A|jmjC domain-containing histone demethylation protein 2A|jumonji C domain-containing histone demethylase 2A|jumonji domain-containing protein 1A|lysine (K)-specific demethylase 3A|testis-specific protein A', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86440647, end_position_on_the_genomic_accession=86492716, orientation='plus', exon_count=28, OMIM=[611512], no_hdr0=''),
    55819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55819, CurrentID=0, Status='live', Symbol='RNF130', Aliases=['G1RP', 'G1RZFP', 'GOLIATH', 'GP'], description='ring finger protein 130', other_designations='E3 ubiquitin-protein ligase RNF130|RING-type E3 ubiquitin transferase RNF130|g1-related zinc finger protein|goliath homolog', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179911651, end_position_on_the_genomic_accession=180071759, orientation='minus', exon_count=10, OMIM=[619163], no_hdr0=''),
    55821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55821, CurrentID=0, Status='live', Symbol='ALLC', Aliases=['ALC'], description='allantoicase', other_designations='probable allantoicase|allantoate amidinohydrolase', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3645368, end_position_on_the_genomic_accession=3702671, orientation='plus', exon_count=18, OMIM=[612396], no_hdr0=''),
    55823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55823, CurrentID=0, Status='live', Symbol='VPS11', Aliases=['END1', 'HLD12', 'PEP5', 'RNF108', 'hVPS11'], description='VPS11 core subunit of CORVET and HOPS complexes', other_designations='vacuolar protein sorting-associated protein 11 homolog|RING finger protein 108|VPS11, CORVET/HOPS core subunit|vacuolar protein sorting 11 homolog', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119067792, end_position_on_the_genomic_accession=119081972, orientation='plus', exon_count=17, OMIM=[608549], no_hdr0=''),
    55824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55824, CurrentID=0, Status='live', Symbol='PAG1', Aliases=['CBP', 'PAG'], description='phosphoprotein membrane anchor with glycosphingolipid microdomains 1', other_designations='phosphoprotein associated with glycosphingolipid-enriched microdomains 1|Csk-binding protein|phosphoprotein associated with glycosphingolipid microdomains 1|transmembrane adapter protein PAG|transmembrane adaptor protein PAG|transmembrane phosphoprotein Cbp', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=80967810, end_position_on_the_genomic_accession=81112068, orientation='minus', exon_count=11, OMIM=[605767], no_hdr0=''),
    55825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55825, CurrentID=0, Status='live', Symbol='PECR', Aliases=['DCRRP', 'HPDHASE', 'HSA250303', 'PVIARL', 'SDR29C1', 'TERP'], description='peroxisomal trans-2-enoyl-CoA reductase', other_designations='peroxisomal trans-2-enoyl-CoA reductase|2,4-dienoyl-CoA reductase-related protein|DCR-RP|pVI-ARL|putative short chain alcohol dehydrogenase|short chain dehydrogenase/reductase family 29C member 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216031656, end_position_on_the_genomic_accession=216081843, orientation='minus', exon_count=10, OMIM=[605843], no_hdr0=''),
    55827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55827, CurrentID=0, Status='live', Symbol='DCAF6', Aliases=['1200006M05Rik', 'ARCAP', 'IQWD1', 'MSTP055', 'NRIP', 'PC326'], description='DDB1 and CUL4 associated factor 6', other_designations='DDB1- and CUL4-associated factor 6|IQ motif and WD repeat-containing protein 1|IQ motif and WD repeats 1|androgen receptor complex-associated protein|nuclear receptor interaction protein', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167936239, end_position_on_the_genomic_accession=168075836, orientation='plus', exon_count=26, OMIM=[610494], no_hdr0=''),
    55829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55829, CurrentID=0, Status='live', Symbol='SELENOS', Aliases=['AD-015', 'ADO15', 'SBBI8', 'SELS', 'SEPS1', 'VIMP'], description='selenoprotein S', other_designations='selenoprotein S|VCP interacting membrane selenoprotein|VCP-interacting membrane protein|tanis|valosin-containing protein-interacting membrane protein', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101270809, end_position_on_the_genomic_accession=101277485, orientation='minus', exon_count=7, OMIM=[607918], no_hdr0=''),
    55830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55830, CurrentID=0, Status='live', Symbol='GLT8D1', Aliases=['AD-017', 'MSTP139'], description='glycosyltransferase 8 domain containing 1', other_designations='glycosyltransferase 8 domain-containing protein 1|glycosyltransferase AD-017', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52694486, end_position_on_the_genomic_accession=52705796, orientation='minus', exon_count=12, OMIM=[618399], no_hdr0=''),
    55831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55831, CurrentID=0, Status='live', Symbol='EMC3', Aliases=['POB', 'TMEM111'], description='ER membrane protein complex subunit 3', other_designations='ER membrane protein complex subunit 3|30 kDa protein|partial optokinetic response b|transmembrane protein 111', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9962682, end_position_on_the_genomic_accession=10011118, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    55832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55832, CurrentID=0, Status='live', Symbol='CAND1', Aliases=['TIP120', 'TIP120A'], description='cullin associated and neddylation dissociated 1', other_designations='cullin-associated NEDD8-dissociated protein 1|TBP-interacting protein of 120 kDa A|p120 CAND1', map_location='12q14.3-q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=67269358, end_position_on_the_genomic_accession=67319953, orientation='plus', exon_count=17, OMIM=[607727], no_hdr0=''),
    55833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55833, CurrentID=0, Status='live', Symbol='UBAP2', Aliases=['UBAP-2'], description='ubiquitin associated protein 2', other_designations='ubiquitin-associated protein 2|AD-012 protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33921693, end_position_on_the_genomic_accession=34049199, orientation='minus', exon_count=32, OMIM=[], no_hdr0=''),
    55835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55835, CurrentID=0, Status='live', Symbol='CENPJ', Aliases=['BM032', 'CENP-J', 'CPAP', 'LAP', 'LIP1', 'MCPH6', 'SASS4', 'SCKL4', 'Sas-4'], description='centromere protein J', other_designations='centromere protein J|LAG-3-associated protein|LYST-interacting protein 1|LYST-interacting protein LIP1|LYST-interacting protein LIP7|Spindle assembly abnormal 4|centrosomal P4.1-associated protein', map_location='13q12.12-q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24882279, end_position_on_the_genomic_accession=24922889, orientation='minus', exon_count=20, OMIM=[609279], no_hdr0=''),
    55837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55837, CurrentID=0, Status='live', Symbol='EAPP', Aliases=['BM036', 'C14orf11'], description='E2F associated phosphoprotein', other_designations='E2F-associated phosphoprotein', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34515938, end_position_on_the_genomic_accession=34539721, orientation='minus', exon_count=7, OMIM=[609486], no_hdr0=''),
    55839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55839, CurrentID=0, Status='live', Symbol='CENPN', Aliases=['BM039', 'C16orf60', 'CENP-N', 'ICEN32'], description='centromere protein N', other_designations='centromere protein N|interphase centromere complex protein 32', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81007214, end_position_on_the_genomic_accession=81033107, orientation='plus', exon_count=13, OMIM=[611509], no_hdr0=''),
    55840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55840, CurrentID=0, Status='live', Symbol='EAF2', Aliases=['BM040', 'TRAITS', 'U19'], description='ELL associated factor 2', other_designations='ELL-associated factor 2|testosterone-regulated apoptosis inducer and tumor suppressor protein', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121835180, end_position_on_the_genomic_accession=121886526, orientation='plus', exon_count=9, OMIM=[607659], no_hdr0=''),
    55841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55841, CurrentID=0, Status='live', Symbol='WWC3', Aliases=['BM042'], description='WWC family member 3', other_designations='protein WWC3', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=10015254, end_position_on_the_genomic_accession=10144474, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    55843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55843, CurrentID=0, Status='live', Symbol='ARHGAP15', Aliases=['BM046'], description='Rho GTPase activating protein 15', other_designations='rho GTPase-activating protein 15|rho-type GTPase-activating protein 15', map_location='2q22.2-q22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=143070973, end_position_on_the_genomic_accession=143768352, orientation='plus', exon_count=23, OMIM=[610578], no_hdr0=''),
    55844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55844, CurrentID=0, Status='live', Symbol='PPP2R2D', Aliases=['B55D', 'B55delta', 'MDS026'], description='protein phosphatase 2 regulatory subunit Bdelta', other_designations='serine/threonine-protein phosphatase 2A 55 kDa regulatory subunit B delta isoform|protein phosphatase 2 regulatory subunit B, delta', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=131900934, end_position_on_the_genomic_accession=131971535, orientation='plus', exon_count=12, OMIM=[613992], no_hdr0=''),
    55845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55845, CurrentID=0, Status='live', Symbol='BRK1', Aliases=['C3orf10', 'HSPC300', 'MDS027', 'hHBrk1'], description='BRICK1 subunit of SCAR/WAVE actin nucleating complex', other_designations='protein BRICK1|BRICK1, SCAR/WAVE actin nucleating complex subunit|haematopoietic stem/progenitor cell protein 300', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10115675, end_position_on_the_genomic_accession=10127190, orientation='plus', exon_count=3, OMIM=[611183], no_hdr0=''),
    55846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55846, CurrentID=0, Status='live', Symbol='ITFG2', Aliases=['FGGAP1', 'KICS3', 'MDS028'], description='integrin alpha FG-GAP repeat containing 2', other_designations='KICSTOR complex protein ITFG2|FG-GAP repeat containing 1|integrin-alpha FG-GAP repeat-containing protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2812644, end_position_on_the_genomic_accession=2859907, orientation='plus', exon_count=20, OMIM=[617421], no_hdr0=''),
    55847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55847, CurrentID=0, Status='live', Symbol='CISD1', Aliases=['C10orf70', 'MDS029', 'ZCD1', 'mitoNEET'], description='CDGSH iron sulfur domain 1', other_designations='CDGSH iron-sulfur domain-containing protein 1|zinc finger CDGSH-type domain 1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=58269162, end_position_on_the_genomic_accession=58289586, orientation='plus', exon_count=3, OMIM=[611932], no_hdr0=''),
    55848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55848, CurrentID=0, Status='live', Symbol='PLGRKT', Aliases=['AD025', 'C9orf46', 'MDS030', 'PLG-RKT', 'Plg-R(KT)'], description='plasminogen receptor with a C-terminal lysine', other_designations='plasminogen receptor (KT)|5033414D02Rik|plasminogen receptor, C-terminal lysine transmembrane protein|transmembrane protein C9orf46', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5357966, end_position_on_the_genomic_accession=5438539, orientation='minus', exon_count=8, OMIM=[618444], no_hdr0=''),
    55850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55850, CurrentID=0, Status='live', Symbol='USE1', Aliases=['D12', 'MDS032', 'P31', 'SLT1'], description='unconventional SNARE in the ER 1', other_designations='vesicle transport protein USE1|Q-SNARE|SNARE-like tail-anchored protein 1 homolog|USE1-like protein|protein p31|putative MAPK activating protein PM26|unconventional SNARE in the ER 1 homolog', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17215346, end_position_on_the_genomic_accession=17219831, orientation='plus', exon_count=8, OMIM=[610675], no_hdr0=''),
    55851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55851, CurrentID=0, Status='live', Symbol='PSENEN', Aliases=['ACNINV2', 'MDS033', 'MSTP064', 'PEN-2', 'PEN2'], description='presenilin enhancer, gamma-secretase subunit', other_designations='gamma-secretase subunit PEN-2|hematopoietic stem/progenitor cells protein MDS033|presenilin enhancer 2 homolog', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35745651, end_position_on_the_genomic_accession=35747519, orientation='plus', exon_count=4, OMIM=[607632], no_hdr0=''),
    55852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55852, CurrentID=0, Status='live', Symbol='TEX2', Aliases=['HT008', 'TMEM96'], description='testis expressed 2', other_designations='testis-expressed protein 2|testis expressed sequence 2|testis-expressed sequence 2 protein|transmembrane protein 96', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64147227, end_position_on_the_genomic_accession=64263265, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    55854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55854, CurrentID=0, Status='live', Symbol='ZC3H15', Aliases=['HT010', 'LEREPO4', 'MSTP012'], description='zinc finger CCCH-type containing 15', other_designations='zinc finger CCCH domain-containing protein 15|DRG family-regulatory protein 1|likely ortholog of mouse immediate early response erythropoietin 4', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=186486253, end_position_on_the_genomic_accession=186509361, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    55856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55856, CurrentID=0, Status='live', Symbol='ACOT13', Aliases=['HT012', 'PNAS-27', 'THEM2'], description='acyl-CoA thioesterase 13', other_designations='acyl-coenzyme A thioesterase 13|hotdog-fold thioesterase superfamily member 2|hypothalamus protein HT012|palmitoyl-CoA hydrolase|thioesterase superfamily member 2', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24667077, end_position_on_the_genomic_accession=24705046, orientation='plus', exon_count=4, OMIM=[615652], no_hdr0=''),
    55857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55857, CurrentID=0, Status='live', Symbol='KIZ', Aliases=['C20orf19', 'HT013', 'Kizuna', 'NCRNA00153', 'PLK1S1', 'RP69'], description='kizuna centrosomal protein', other_designations='centrosomal protein kizuna|polo-like kinase 1 substrate 1', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=21125975, end_position_on_the_genomic_accession=21246622, orientation='plus', exon_count=15, OMIM=[615757], no_hdr0=''),
    55858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55858, CurrentID=0, Status='live', Symbol='TMEM165', Aliases=['CDG2K', 'FT27', 'GDT1', 'SLC64A1', 'TMPT27', 'TPARL'], description='transmembrane protein 165', other_designations='transmembrane protein 165|TPA regulated locus|transmembrane protein PT27|transmembrane protein TPARL', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55395653, end_position_on_the_genomic_accession=55453397, orientation='plus', exon_count=9, OMIM=[614726], no_hdr0=''),
    55859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55859, CurrentID=0, Status='live', Symbol='BEX1', Aliases=['BEX2', 'HBEX2', 'HGR74-h'], description='brain expressed X-linked 1', other_designations='protein BEX1|brain-expressed X-linked protein 1|ovarian granulosa cell 13.0 kDa protein hGR74', map_location='Xq22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103062651, end_position_on_the_genomic_accession=103064171, orientation='minus', exon_count=3, OMIM=[300690], no_hdr0=''),
    55860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55860, CurrentID=0, Status='live', Symbol='ACTR10', Aliases=['ACTR11', 'Arp10', 'Arp11', 'HARP11'], description='actin related protein 10', other_designations='actin-related protein 10|actin related protein 10 homolog|actin-related protein 11', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58200149, end_position_on_the_genomic_accession=58235636, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    55861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55861, CurrentID=0, Status='live', Symbol='DBNDD2', Aliases=['C20orf35', 'CK1BP', 'HSMNP1'], description='dysbindin domain containing 2', other_designations='dysbindin domain-containing protein 2|SCF apoptosis response protein 1|casein kinase-1 binding protein|dysbindin (dystrobrevin binding protein 1) domain containing 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45405993, end_position_on_the_genomic_accession=45410610, orientation='plus', exon_count=6, OMIM=[611453], no_hdr0=''),
    55862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55862, CurrentID=0, Status='live', Symbol='ECHDC1', Aliases=['HEL-S-76', 'MMCD', 'dJ351K20.2'], description='ethylmalonyl-CoA decarboxylase 1', other_designations='ethylmalonyl-CoA decarboxylase|enoyl CoA hydratase domain containing 1|enoyl Coenzyme A hydratase domain containing 1|enoyl-CoA hydratase domain-containing protein 1|epididymis secretory protein Li 76|methylmalonyl-CoA decarboxylase', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127288712, end_position_on_the_genomic_accession=127344179, orientation='minus', exon_count=11, OMIM=[612136], no_hdr0=''),
    55863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55863, CurrentID=0, Status='live', Symbol='TMEM126B', Aliases=['HT007', 'MC1DN29'], description='transmembrane protein 126B', other_designations='complex I assembly factor TMEM126B, mitochondrial', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85628573, end_position_on_the_genomic_accession=85636540, orientation='plus', exon_count=7, OMIM=[615533], no_hdr0=''),
    55867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55867, CurrentID=0, Status='live', Symbol='SLC22A11', Aliases=['OAT4', 'hOAT4'], description='solute carrier family 22 member 11', other_designations='solute carrier family 22 member 11|organic anion transporter 4|solute carrier family 22 (organic anion/cation transporter), member 11|solute carrier family 22 (organic anion/urate transporter), member 11', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64555847, end_position_on_the_genomic_accession=64572875, orientation='plus', exon_count=10, OMIM=[607097], no_hdr0=''),
    55869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55869, CurrentID=0, Status='live', Symbol='HDAC8', Aliases=['CDA07', 'CDLS5', 'HD8', 'HDACL1', 'KDAC8', 'MRXS6', 'RPD3', 'WTS'], description='histone deacetylase 8', other_designations='histone deacetylase 8|histone deacetylase-like 1', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72329516, end_position_on_the_genomic_accession=72573099, orientation='minus', exon_count=17, OMIM=[300269], no_hdr0=''),
    55870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55870, CurrentID=0, Status='live', Symbol='ASH1L', Aliases=['ASH11', 'KMT2H', 'MRD52', 'ASH1L'], description='ASH1 like histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase ASH1L|ASH1-like protein|absent small and homeotic disks protein 1 homolog|ash1 (absent, small, or homeotic)-like|lysine N-methyltransferase 2H|probable histone-lysine N-methyltransferase ASH1L', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155335263, end_position_on_the_genomic_accession=155563160, orientation='minus', exon_count=33, OMIM=[607999], no_hdr0=''),
    55871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55871, CurrentID=0, Status='live', Symbol='CBWD1', Aliases=['COBP'], description='COBW domain containing 1', other_designations='COBW domain-containing protein 1|COBW-like protein|NPC-A-6 COBW domain-containing protein 1|cobalamin synthase W domain-containing protein 1|cobalamin synthetase W domain-containing protein 1', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120837, end_position_on_the_genomic_accession=179083, orientation='minus', exon_count=19, OMIM=[611078], no_hdr0=''),
    55872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55872, CurrentID=0, Status='live', Symbol='PBK', Aliases=['CT84', 'HEL164', 'Nori-3', 'SPK', 'TOPK'], description='PDZ binding kinase', other_designations='lymphokine-activated killer T-cell-originated protein kinase|MAPKK-like protein kinase|T-LAK cell-originated protein kinase|cancer/testis antigen 84|epididymis luminal protein 164|serine/threonine protein kinase|spermatogenesis-related protein kinase', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27809624, end_position_on_the_genomic_accession=27837817, orientation='minus', exon_count=8, OMIM=[611210], no_hdr0=''),
    55876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55876, CurrentID=0, Status='live', Symbol='GSDMB', Aliases=['GSDMB-1', 'GSDML', 'PP4052', 'PRO2521'], description='gasdermin B', other_designations='gasdermin-B|gasdermin-like protein|gasderminB-1', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39904595, end_position_on_the_genomic_accession=39918635, orientation='minus', exon_count=11, OMIM=[611221], no_hdr0=''),
    55879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55879, CurrentID=0, Status='live', Symbol='GABRQ', Aliases=['THETA'], description='gamma-aminobutyric acid type A receptor subunit theta', other_designations='gamma-aminobutyric acid receptor subunit theta|GABA(A) receptor subunit theta|gamma-aminobutyric acid (GABA) A receptor, theta|gamma-aminobutyric acid type A receptor theta subunit', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152637895, end_position_on_the_genomic_accession=152659828, orientation='plus', exon_count=10, OMIM=[300349], no_hdr0=''),
    55884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55884, CurrentID=0, Status='live', Symbol='WSB2', Aliases=['SBA2'], description='WD repeat and SOCS box containing 2', other_designations='WD repeat and SOCS box-containing protein 2|CS box-containing WD protein|WSB-2', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118032687, end_position_on_the_genomic_accession=118062430, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    55885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55885, CurrentID=0, Status='live', Symbol='LMO3', Aliases=['RBTN3', 'RBTNL2', 'RHOM3', 'Rhom-3'], description='LIM domain only 3', other_designations='LIM domain only protein 3|LIM domain only 3 (rhombotin-like 2)|neuronal-specific transcription factor DAT1|rhombotin-3', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=16548372, end_position_on_the_genomic_accession=16610233, orientation='minus', exon_count=13, OMIM=[180386], no_hdr0=''),
    55888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55888, CurrentID=0, Status='live', Symbol='ZKSCAN7', Aliases=['ZFP', 'ZNF167', 'ZNF448', 'ZNF64', 'ZSCAN39'], description='zinc finger with KRAB and SCAN domains 7', other_designations='zinc finger protein with KRAB and SCAN domains 7|zinc finger protein 167|zinc finger protein 448|zinc finger protein 64', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44555193, end_position_on_the_genomic_accession=44583483, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55889, CurrentID=0, Status='live', Symbol='GOLGA6B', Aliases=['GOLGA', 'GOLGA6D'], description='golgin A6 family member B', other_designations='golgin subfamily A member 6B|Golgin subfamily A member 6B|Putative golgin subfamily A member 6D|golgi autoantigen, golgin subfamily a, 6B|golgin-like protein|putative golgin subfamily A member 6B', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72654697, end_position_on_the_genomic_accession=72669599, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    55890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55890, CurrentID=0, Status='live', Symbol='GPRC5C', Aliases=['RAIG-3', 'RAIG3'], description='G protein-coupled receptor class C group 5 member C', other_designations='G-protein coupled receptor family C group 5 member C|orphan G-protein coupled receptor|retinoic acid responsive gene protein|retinoic acid-induced gene 3 protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74431350, end_position_on_the_genomic_accession=74451658, orientation='plus', exon_count=7, OMIM=[605949], no_hdr0=''),
    55891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55891, CurrentID=0, Status='live', Symbol='LENEP', Aliases=['LEP503'], description='lens epithelial protein', other_designations='lens epithelial cell protein LEP503', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154993586, end_position_on_the_genomic_accession=154994321, orientation='plus', exon_count=2, OMIM=[607377], no_hdr0=''),
    55892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55892, CurrentID=0, Status='live', Symbol='MYNN', Aliases=['OSZF', 'SBBIZ1', 'ZBTB31', 'ZNF902'], description='myoneurin', other_designations='myoneurin|zinc finger and BTB domain-containing protein 31|zinc finger protein with BTB/POZ domain', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169773396, end_position_on_the_genomic_accession=169789716, orientation='plus', exon_count=9, OMIM=[606042], no_hdr0=''),
    55893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55893, CurrentID=0, Status='live', Symbol='ZNF395', Aliases=['HDBP-2', 'HDBP2', 'HDRF-2', 'PBF', 'PRF-1', 'PRF1', 'Si-1-8-14'], description='zinc finger protein 395', other_designations="zinc finger protein 395|HD gene regulatory region-binding protein 2|HD-regulating factor 2|Huntington's disease gene regulatory region-binding protein 2|huntington disease gene regulatory region-binding protein 2|papillomavirus regulatory factor 1|papillomavirus regulatory factor PRF-1|papillomavirus-binding factor", map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28345590, end_position_on_the_genomic_accession=28386460, orientation='minus', exon_count=10, OMIM=[609494], no_hdr0=''),
    55894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55894, CurrentID=0, Status='live', Symbol='DEFB103B', Aliases=['BD-3', 'DEFB-3', 'DEFB103', 'DEFB3', 'HBD-3', 'HBD3', 'HBP-3', 'HBP3'], description='defensin beta 103B', other_designations='beta-defensin 103|beta-defensin 3|defensin-like protein', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7428888, end_position_on_the_genomic_accession=7430348, orientation='minus', exon_count=2, OMIM=[606611], no_hdr0=''),
    55897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55897, CurrentID=0, Status='live', Symbol='MESP1', Aliases=['bHLHc5'], description='mesoderm posterior bHLH transcription factor 1', other_designations='mesoderm posterior protein 1|class C basic helix-loop-helix protein 5|mesoderm posterior 1 homolog|mesoderm posterior basic helix-loop-helix transcription factor 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89734772, end_position_on_the_genomic_accession=89751249, orientation='minus', exon_count=7, OMIM=[608689], no_hdr0=''),
    55898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55898, CurrentID=0, Status='live', Symbol='UNC45A', Aliases=['GC-UNC45', 'GCUNC-45', 'GCUNC45', 'IRO039700', 'OOHE', 'SMAP-1', 'SMAP1', 'UNC-45A'], description='unc-45 myosin chaperone A', other_designations='protein unc-45 homolog A|general cell UNC45|smooth muscle cell associated protein-1|unc-45 homolog A', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90930180, end_position_on_the_genomic_accession=90954093, orientation='plus', exon_count=22, OMIM=[611219], no_hdr0=''),
    55900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55900, CurrentID=0, Status='live', Symbol='ZNF302', Aliases=['HSD16', 'MST154', 'MSTP154', 'ZNF135L', 'ZNF140L', 'ZNF327'], description='zinc finger protein 302', other_designations='zinc finger protein 302|zinc finger protein 327', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34677648, end_position_on_the_genomic_accession=34686396, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    55901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55901, CurrentID=0, Status='live', Symbol='THSD1', Aliases=['ANIB12', 'TMTSP', 'UNQ3010'], description='thrombospondin type 1 domain containing 1', other_designations='thrombospondin type-1 domain-containing protein 1|4833423O18Rik|thrombospondin, type I, domain containing 1|transmembrane molecule with thrombospondin module', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52377167, end_position_on_the_genomic_accession=52406172, orientation='minus', exon_count=5, OMIM=[616821], no_hdr0=''),
    55902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55902, CurrentID=0, Status='live', Symbol='ACSS2', Aliases=['ACAS2', 'ACECS', 'ACS', 'ACSA', 'AceCS1', 'dJ1161H23.1'], description='acyl-CoA synthetase short chain family member 2', other_designations='acetyl-coenzyme A synthetase, cytoplasmic|acetate thiokinase|acetate-CoA ligase|acetyl-CoA synthetase 1|acetyl-Coenzyme A synthetase 2 (ADP forming)|acyl-activating enzyme|cytoplasmic acetyl-coenzyme A synthetase|propionate--CoA ligase', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34874942, end_position_on_the_genomic_accession=34927962, orientation='plus', exon_count=22, OMIM=[605832], no_hdr0=''),
    55904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55904, CurrentID=0, Status='live', Symbol='KMT2E', Aliases=['HDCMC04P', 'MLL5', 'NKp44L', 'ODLURO'], description='lysine methyltransferase 2E (inactive)', other_designations='inactive histone-lysine N-methyltransferase 2E|histone-lysine N-methyltransferase 2E|histone-lysine N-methyltransferase MLL5|inactive lysine N-methyltransferase 2E|lysine (K)-specific methyltransferase 2E|myeloid/lymphoid or mixed-lineage leukemia 5 (trithorax homolog, Drosophila)|myeloid/lymphoid or mixed-lineage leukemia protein 5', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=104940949, end_position_on_the_genomic_accession=105115019, orientation='plus', exon_count=33, OMIM=[608444], no_hdr0=''),
    55905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55905, CurrentID=0, Status='live', Symbol='RNF114', Aliases=['PSORS12', 'ZNF313'], description='ring finger protein 114', other_designations='E3 ubiquitin-protein ligase RNF114|RING-type E3 ubiquitin transferase RNF114|zinc finger protein 228|zinc finger protein 313', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49936397, end_position_on_the_genomic_accession=49953885, orientation='plus', exon_count=6, OMIM=[612451], no_hdr0=''),
    55906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55906, CurrentID=0, Status='live', Symbol='ZC4H2', Aliases=['HCA127', 'KIAA1166', 'MCS', 'MRXS4', 'WRWF', 'WRWFFR', 'WWS'], description='zinc finger C4H2-type containing', other_designations='zinc finger C4H2 domain-containing protein|Miles-Carpenter X-linked mental retardation syndrome|Miles-Carpenter syndrome (mental retardation, X-linked, syndromic-4, with congenital contractures and low fingertip arches)|hepatocellular carcinoma-associated antigen 127|zinc finger, C4H2 domain containing', map_location='Xq11.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=64915807, end_position_on_the_genomic_accession=65034741, orientation='minus', exon_count=6, OMIM=[300897, 309605], no_hdr0=''),
    55907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55907, CurrentID=0, Status='live', Symbol='CMAS', Aliases=['CSS'], description='cytidine monophosphate N-acetylneuraminic acid synthetase', other_designations="N-acylneuraminate cytidylyltransferase|CMP-N-acetylneuraminic acid synthase|CMP-N-acetylneuraminic acid synthetase|CMP-Neu5Ac synthetase|CMP-NeuNAc synthase|CMP-NeuNAc synthetase|CMP-sialic acid synthetase|cytidine 5'-monophosphate N-acetylneuraminic acid synthetase", map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=22046218, end_position_on_the_genomic_accession=22065668, orientation='plus', exon_count=8, OMIM=[603316], no_hdr0=''),
    55908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55908, CurrentID=0, Status='live', Symbol='ANGPTL8', Aliases=['C19orf80', 'PRO1185', 'PVPA599', 'RIFL', 'TD26'], description='angiopoietin like 8', other_designations='angiopoietin-like protein 8|betatrophin variant 1|betatrophin variant 2|hepatocellular carcinoma-associated gene TD26|hepatocellular carcinoma-associated protein TD26|lipasin|refeeding-induced fat and liver protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11239619, end_position_on_the_genomic_accession=11241943, orientation='plus', exon_count=4, OMIM=[616223], no_hdr0=''),
    55909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55909, CurrentID=0, Status='live', Symbol='BIN3', Aliases=[], description='bridging integrator 3', other_designations='bridging integrator 3', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22620418, end_position_on_the_genomic_accession=22669148, orientation='minus', exon_count=12, OMIM=[606396], no_hdr0=''),
    55911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55911, CurrentID=0, Status='live', Symbol='APOBR', Aliases=['APOB100R', 'APOB48R'], description='apolipoprotein B receptor', other_designations='apolipoprotein B receptor|apoB-48R|apolipoprotein B-100 receptor|apolipoprotein B-48 receptor|apolipoprotein B100 receptor|apolipoprotein B48 receptor', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28494643, end_position_on_the_genomic_accession=28498964, orientation='plus', exon_count=4, OMIM=[605220], no_hdr0=''),
    55914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55914, CurrentID=0, Status='live', Symbol='ERBIN', Aliases=['ERBB2IP', 'HEL-S-78', 'LAP2'], description='erbb2 interacting protein', other_designations='erbin|densin-180-like protein|epididymis secretory protein Li 78|protein LAP2', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65926575, end_position_on_the_genomic_accession=66082546, orientation='plus', exon_count=29, OMIM=[606944], no_hdr0=''),
    55915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55915, CurrentID=0, Status='live', Symbol='LANCL2', Aliases=['GPR69B', 'TASP'], description='LanC like 2', other_designations='lanC-like protein 2|G protein-coupled receptor 69B|LanC (bacterial lantibiotic synthetase component C)-like 2|LanC lantibiotic synthetase component C-like 2|testis-specific adriamycin sensitivity protein', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55365337, end_position_on_the_genomic_accession=55433737, orientation='plus', exon_count=9, OMIM=[612919], no_hdr0=''),
    55916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55916, CurrentID=0, Status='live', Symbol='NXT2', Aliases=['P15-2'], description='nuclear transport factor 2 like export factor 2', other_designations='NTF2-related export protein 2|protein p15-2', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=109535824, end_position_on_the_genomic_accession=109544698, orientation='plus', exon_count=7, OMIM=[300320], no_hdr0=''),
    55917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55917, CurrentID=0, Status='live', Symbol='CTTNBP2NL', Aliases=[], description='CTTNBP2 N-terminal like', other_designations='CTTNBP2 N-terminal-like protein', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112391085, end_position_on_the_genomic_accession=112461164, orientation='plus', exon_count=8, OMIM=[615100], no_hdr0=''),
    55920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55920, CurrentID=0, Status='live', Symbol='RCC2', Aliases=['TD-60'], description='regulator of chromosome condensation 2', other_designations='protein RCC2|RCC1-like protein TD-60|epididymis secretory sperm binding protein|telophase disk protein of 60 kDa', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17406760, end_position_on_the_genomic_accession=17439677, orientation='minus', exon_count=13, OMIM=[609587], no_hdr0=''),
    55922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55922, CurrentID=0, Status='live', Symbol='NKRF', Aliases=['ITBA4', 'NRF'], description='NFKB repressing factor', other_designations='NF-kappa-B-repressing factor|transcription factor NRF', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119588337, end_position_on_the_genomic_accession=119606424, orientation='minus', exon_count=4, OMIM=[300440], no_hdr0=''),
    55924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55924, CurrentID=0, Status='live', Symbol='INKA2', Aliases=['C1orf183', 'FAM212B'], description='inka box actin regulator 2', other_designations='PAK4-inhibitor INKA2|HInca-r|family with sequence similarity 212 member B|induced in neural crest by AP2-alpha protein-related homolog|protein FAM212B', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111722064, end_position_on_the_genomic_accession=111755797, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    55929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55929, CurrentID=0, Status='live', Symbol='DMAP1', Aliases=['DNMAP1', 'DNMTAP1', 'EAF2', 'MEAF2', 'SWC4'], description='DNA methyltransferase 1 associated protein 1', other_designations='DNA methyltransferase 1-associated protein 1|DNMT1 associated protein 1', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44213471, end_position_on_the_genomic_accession=44220673, orientation='plus', exon_count=11, OMIM=[605077], no_hdr0=''),
    55930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55930, CurrentID=0, Status='live', Symbol='MYO5C', Aliases=[], description='myosin VC', other_designations='unconventional myosin-Vc|myosin 5C|myosin-Vc', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52192318, end_position_on_the_genomic_accession=52295804, orientation='minus', exon_count=41, OMIM=[610022], no_hdr0=''),
    55937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55937, CurrentID=0, Status='live', Symbol='APOM', Aliases=['G3a', 'HSPC336', 'NG20', 'apo-M'], description='apolipoprotein M', other_designations='apolipoprotein M|NG20-like protein|alternative name: G3a, NG20|protein G3a', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31652404, end_position_on_the_genomic_accession=31658210, orientation='plus', exon_count=7, OMIM=[606907], no_hdr0=''),
    55954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55954, CurrentID=0, Status='live', Symbol='ZMAT5', Aliases=['SNRNP20', 'U11/U12-20K', 'ZC3H19'], description='zinc finger matrin-type 5', other_designations='zinc finger matrin-type protein 5|U11/U12 small nuclear ribonucleoprotein 20 kDa protein|U11/U12 snRNP 20 kDa protein|U11/U12 snRNP 20K|zinc finger CCCH-type containing 19', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29730956, end_position_on_the_genomic_accession=29767007, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    55957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55957, CurrentID=0, Status='live', Symbol='LIN37', Aliases=['F25965', 'ZK418.4', 'lin-37'], description='lin-37 DREAM MuvB core complex component', other_designations='protein lin-37 homolog|antolefinin|lin-37 homolog|protein F25965', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35748576, end_position_on_the_genomic_accession=35754519, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    55958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55958, CurrentID=0, Status='live', Symbol='KLHL9', Aliases=[], description='kelch like family member 9', other_designations='kelch-like protein 9', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21329665, end_position_on_the_genomic_accession=21335404, orientation='minus', exon_count=1, OMIM=[611201], no_hdr0=''),
    55959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55959, CurrentID=0, Status='live', Symbol='SULF2', Aliases=['HSULF-2'], description='sulfatase 2', other_designations='extracellular sulfatase Sulf-2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=47657406, end_position_on_the_genomic_accession=47786627, orientation='minus', exon_count=24, OMIM=[610013], no_hdr0=''),
    55964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55964, CurrentID=0, Status='live', Symbol='SEPTIN3', Aliases=['SEP3', 'SEPT3', 'bK250D10.3'], description='septin 3', other_designations='neuronal-specific septin-3', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41969443, end_position_on_the_genomic_accession=41998221, orientation='plus', exon_count=13, OMIM=[608314], no_hdr0=''),
    55966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55966, CurrentID=0, Status='live', Symbol='AJAP1', Aliases=['MOT8', 'SHREW-1', 'SHREW1'], description='adherens junctions associated protein 1', other_designations='adherens junction-associated protein 1|membrane protein shrew-1|transmembrane protein SHREW1', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=4654609, end_position_on_the_genomic_accession=4792534, orientation='plus', exon_count=8, OMIM=[610972], no_hdr0=''),
    55967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55967, CurrentID=0, Status='live', Symbol='NDUFA12', Aliases=['B17.2', 'DAP13', 'MC1DN23'], description='NADH:ubiquinone oxidoreductase subunit A12', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 12|13 kDa differentiation-associated protein|CI-B17.2|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 12|NADH-ubiquinone oxidoreductase subunit B17.2|complex I B17.2 subunit', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=94971333, end_position_on_the_genomic_accession=95003697, orientation='minus', exon_count=4, OMIM=[614530], no_hdr0=''),
    55968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55968, CurrentID=0, Status='live', Symbol='NSFL1C', Aliases=['P47', 'UBX1', 'UBXD10', 'UBXN2C', 'dJ776F14.1'], description='NSFL1 cofactor', other_designations='NSFL1 cofactor p47|NSFL1 (p97) cofactor (p47)|SHP1 homolog|UBX domain-containing protein 2C|p97 cofactor p47', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1442166, end_position_on_the_genomic_accession=1467793, orientation='minus', exon_count=13, OMIM=[606610], no_hdr0=''),
    55969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55969, CurrentID=0, Status='live', Symbol='RAB5IF', Aliases=['C20orf24', 'PNAS-11', 'RCAF1', 'RIP5'], description='RAB5 interacting factor', other_designations='respirasome Complex Assembly Factor 1|rab5-interacting protein|respirasome complex assembly factor 1|uncharacterized protein C20orf24', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36605779, end_position_on_the_genomic_accession=36612557, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    55970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55970, CurrentID=0, Status='live', Symbol='GNG12', Aliases=[], description='G protein subunit gamma 12', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-12|G-protein gamma-12 subunit|guanine nucleotide binding protein (G protein), gamma 12', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67701475, end_position_on_the_genomic_accession=67833467, orientation='minus', exon_count=6, OMIM=[615405], no_hdr0=''),
    55971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55971, CurrentID=0, Status='live', Symbol='BAIAP2L1', Aliases=['IRTKS'], description='BAR/IMD domain containing adaptor protein 2 like 1', other_designations='brain-specific angiogenesis inhibitor 1-associated protein 2-like protein 1|BAI1 associated protein 2 like 1|BAI1-associated protein 2-like protein 1|insulin receptor tyrosine kinase substrate', map_location='7q21.3-q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98291650, end_position_on_the_genomic_accession=98401090, orientation='minus', exon_count=14, OMIM=[611877], no_hdr0=''),
    55972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55972, CurrentID=0, Status='live', Symbol='SLC25A40', Aliases=['MCFP'], description='solute carrier family 25 member 40', other_designations='solute carrier family 25 member 40|mitochondrial carrier family protein', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87833568, end_position_on_the_genomic_accession=87876360, orientation='minus', exon_count=12, OMIM=[610821], no_hdr0=''),
    55973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55973, CurrentID=0, Status='live', Symbol='BCAP29', Aliases=['BAP29'], description='B cell receptor associated protein 29', other_designations='B-cell receptor-associated protein 29|BCR-associated protein 29', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107580007, end_position_on_the_genomic_accession=107623317, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    55974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55974, CurrentID=0, Status='live', Symbol='SLC50A1', Aliases=['HsSWEET1', 'RAG1AP1', 'SCP', 'SWEET1', 'slv'], description='solute carrier family 50 member 1', other_designations='sugar transporter SWEET1|RAG1-activating protein 1|RP11-540D14.5|RZPDo834D038D|probable sugar transporter RAG1AP1|recombination activating gene 1 activating protein 1|solute carrier family 50 (sugar efflux transporter), member 1|solute carrier family 50 (sugar transporter), member 1|stromal cell protein', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155135375, end_position_on_the_genomic_accession=155138853, orientation='plus', exon_count=7, OMIM=[613683], no_hdr0=''),
    55975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55975, CurrentID=0, Status='live', Symbol='KLHL7', Aliases=['CISS3', 'KLHL6', 'PERCHING', 'SBBI26'], description='kelch like family member 7', other_designations='kelch-like protein 7|kelch-like 6|kelch-like 7|kelch/BTB', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23105785, end_position_on_the_genomic_accession=23177914, orientation='plus', exon_count=15, OMIM=[611119], no_hdr0=''),
    55997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55997, CurrentID=0, Status='live', Symbol='CFC1', Aliases=['CFC1B', 'CRYPTIC', 'DTGA2', 'HTX2'], description='cripto, FRL-1, cryptic family 1', other_designations='cryptic protein|cryptic family protein 1|heterotaxy 2 (autosomal dominant)', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130592165, end_position_on_the_genomic_accession=130599575, orientation='minus', exon_count=7, OMIM=[605194], no_hdr0=''),
    55998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=55998, CurrentID=0, Status='live', Symbol='NXF5', Aliases=[], description='nuclear RNA export factor 5', other_designations='nuclear RNA export factor 5|TAP-like protein 1|TAPL-1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101832112, end_position_on_the_genomic_accession=101857577, orientation='minus', exon_count=20, OMIM=[300319], no_hdr0=''),
    56000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56000, CurrentID=0, Status='live', Symbol='NXF3', Aliases=[], description='nuclear RNA export factor 3', other_designations='nuclear RNA export factor 3|TAP-like protein 3|TAPL-3', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103075810, end_position_on_the_genomic_accession=103093143, orientation='minus', exon_count=20, OMIM=[300316], no_hdr0=''),
    56001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56001, CurrentID=0, Status='live', Symbol='NXF2', Aliases=['CT39', 'TAPL-2', 'TCP11X2'], description='nuclear RNA export factor 2', other_designations='nuclear RNA export factor 2|TAP-like protein 2|cancer/testis antigen 39|t-complex protein 11 homolog', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102247167, end_position_on_the_genomic_accession=102326722, orientation='plus', exon_count=23, OMIM=[300315], no_hdr0=''),
    56005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56005, CurrentID=0, Status='live', Symbol='MYDGF', Aliases=['C19orf10', 'EUROIMAGE1875335', 'IL25', 'IL27', 'IL27w', 'R33729_1', 'SF20'], description='myeloid derived growth factor', other_designations='myeloid-derived growth factor|UPF0556 protein C19orf10|interleukin 27 working designation|interleukin-25|stromal cell-derived growth factor SF20', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4657545, end_position_on_the_genomic_accession=4670391, orientation='minus', exon_count=7, OMIM=[606746], no_hdr0=''),
    56006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56006, CurrentID=0, Status='live', Symbol='SMG9', Aliases=['C19orf61', 'F17127_1', 'HBMS'], description='SMG9 nonsense mediated mRNA decay factor', other_designations='protein SMG9|protein smg-9 homolog', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43727983, end_position_on_the_genomic_accession=43754962, orientation='minus', exon_count=15, OMIM=[613176], no_hdr0=''),
    56033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56033, CurrentID=0, Status='live', Symbol='BARX1', Aliases=[], description='BARX homeobox 1', other_designations='homeobox protein BarH-like 1|BarH-like homeobox 1', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93951627, end_position_on_the_genomic_accession=93955355, orientation='minus', exon_count=4, OMIM=[603260], no_hdr0=''),
    56034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56034, CurrentID=0, Status='live', Symbol='PDGFC', Aliases=['FALLOTEIN', 'SCDGF'], description='platelet derived growth factor C', other_designations='platelet-derived growth factor C|PDGF-C|VEGF-E|secretory growth factor-like protein|spinal cord-derived growth factor', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=156760454, end_position_on_the_genomic_accession=156971799, orientation='minus', exon_count=9, OMIM=[608452], no_hdr0=''),
    56052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56052, CurrentID=0, Status='live', Symbol='ALG1', Aliases=['CDG1K', 'HMAT1', 'HMT-1', 'HMT1', 'MT-1', 'Mat-1', 'hMat-1'], description='ALG1 chitobiosyldiphosphodolichol beta-mannosyltransferase', other_designations='chitobiosyldiphosphodolichol beta-mannosyltransferase|GDP-Man:GlcNAc2-PP-dolichol mannosyltransferase|GDP-mannose-dolichol diphosphochitobiose mannosyltransferase|asparagine-linked glycosylation 1 homolog (yeast, beta-1,4-mannosyltransferase)|asparagine-linked glycosylation 1, beta-1,4-mannosyltransferase homolog|asparagine-linked glycosylation protein 1 homolog|beta-1,4-mannosyltransferase|mannosyltransferase-1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=5071825, end_position_on_the_genomic_accession=5087379, orientation='plus', exon_count=14, OMIM=[605907], no_hdr0=''),
    56061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56061, CurrentID=0, Status='live', Symbol='UBFD1', Aliases=['UBPH'], description='ubiquitin family domain containing 1', other_designations='ubiquitin domain-containing protein UBFD1|ubiquitin-binding protein homolog', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23557557, end_position_on_the_genomic_accession=23574393, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    56062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56062, CurrentID=0, Status='live', Symbol='KLHL4', Aliases=['DKELCHL', 'KHL4'], description='kelch like family member 4', other_designations='kelch-like protein 4', map_location='Xq21.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=87517730, end_position_on_the_genomic_accession=87670050, orientation='plus', exon_count=12, OMIM=[300348], no_hdr0=''),
    56063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56063, CurrentID=0, Status='live', Symbol='TMEM234', Aliases=['AASL548', 'C1orf91', 'PRO1105', 'RP4-622L5', 'dJ622L5.7'], description='transmembrane protein 234', other_designations='transmembrane protein 234', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32204807, end_position_on_the_genomic_accession=32222353, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    56097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56097, CurrentID=0, Status='live', Symbol='PCDHGC5', Aliases=['PCDH-GAMMA-C5'], description='protocadherin gamma subfamily C, 5', other_designations='protocadherin gamma-C5', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141489081, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606306], no_hdr0=''),
    56098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56098, CurrentID=0, Status='live', Symbol='PCDHGC4', Aliases=['PCDH-GAMMA-C4'], description='protocadherin gamma subfamily C, 4', other_designations='protocadherin gamma-C4', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141485030, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606305], no_hdr0=''),
    56099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56099, CurrentID=0, Status='live', Symbol='PCDHGB7', Aliases=['ME6', 'PCDH-GAMMA-B7'], description='protocadherin gamma subfamily B, 7', other_designations='protocadherin gamma-B7|cadherin ME6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141417677, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606304], no_hdr0=''),
    56100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56100, CurrentID=0, Status='live', Symbol='PCDHGB6', Aliases=['PCDH-GAMMA-B6'], description='protocadherin gamma subfamily B, 6', other_designations='protocadherin gamma-B6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141408021, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=5, OMIM=[606303], no_hdr0=''),
    56101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56101, CurrentID=0, Status='live', Symbol='PCDHGB5', Aliases=['PCDH-GAMMA-B5'], description='protocadherin gamma subfamily B, 5', other_designations='protocadherin gamma-B5', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141397947, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606302], no_hdr0=''),
    56102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56102, CurrentID=0, Status='live', Symbol='PCDHGB3', Aliases=['PCDH-GAMMA-B3'], description='protocadherin gamma subfamily B, 3', other_designations='protocadherin gamma-B3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141370242, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606301], no_hdr0=''),
    56103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56103, CurrentID=0, Status='live', Symbol='PCDHGB2', Aliases=['PCDH-GAMMA-B2'], description='protocadherin gamma subfamily B, 2', other_designations='protocadherin gamma-B2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141359994, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606300], no_hdr0=''),
    56104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56104, CurrentID=0, Status='live', Symbol='PCDHGB1', Aliases=['PCDH-GAMMA-B1'], description='protocadherin gamma subfamily B, 1', other_designations='protocadherin gamma-B1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141350099, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606299], no_hdr0=''),
    56105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56105, CurrentID=0, Status='live', Symbol='PCDHGA11', Aliases=['PCDH-GAMMA-A11'], description='protocadherin gamma subfamily A, 11', other_designations='protocadherin gamma-A11', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141421051, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606298], no_hdr0=''),
    56106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56106, CurrentID=0, Status='live', Symbol='PCDHGA10', Aliases=['PCDH-GAMMA-A10'], description='protocadherin gamma subfamily A, 10', other_designations='protocadherin gamma-A10', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141412987, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606297], no_hdr0=''),
    56107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56107, CurrentID=0, Status='live', Symbol='PCDHGA9', Aliases=['PCDH-GAMMA-A9'], description='protocadherin gamma subfamily A, 9', other_designations='protocadherin gamma-A9', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141402778, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606296], no_hdr0=''),
    56108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56108, CurrentID=0, Status='live', Symbol='PCDHGA7', Aliases=['PCDH-GAMMA-A7'], description='protocadherin gamma subfamily A, 7', other_designations='protocadherin gamma-A7', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141382742, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606294], no_hdr0=''),
    56109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56109, CurrentID=0, Status='live', Symbol='PCDHGA6', Aliases=['PCDH-GAMMA-A6'], description='protocadherin gamma subfamily A, 6', other_designations='protocadherin gamma-A6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141373891, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606293], no_hdr0=''),
    56110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56110, CurrentID=0, Status='live', Symbol='PCDHGA5', Aliases=['CDH-GAMMA-A5', 'ME3', 'PCDH-GAMMA-A5'], description='protocadherin gamma subfamily A, 5', other_designations='protocadherin gamma-A5|cadherin ME3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141364162, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606292], no_hdr0=''),
    56111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56111, CurrentID=0, Status='live', Symbol='PCDHGA4', Aliases=['PCDH-GAMMA-A4'], description='protocadherin gamma subfamily A, 4', other_designations='protocadherin gamma-A4', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141355021, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606291], no_hdr0=''),
    56112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56112, CurrentID=0, Status='live', Symbol='PCDHGA3', Aliases=['PCDH-GAMMA-A3'], description='protocadherin gamma subfamily A, 3', other_designations='protocadherin gamma-A3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141343829, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606290], no_hdr0=''),
    56113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56113, CurrentID=0, Status='live', Symbol='PCDHGA2', Aliases=['PCDH-GAMMA-A2'], description='protocadherin gamma subfamily A, 2', other_designations='protocadherin gamma-A2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141338760, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606289], no_hdr0=''),
    56114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56114, CurrentID=0, Status='live', Symbol='PCDHGA1', Aliases=['PCDH-GAMMA-A1'], description='protocadherin gamma subfamily A, 1', other_designations='protocadherin gamma-A1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141330514, end_position_on_the_genomic_accession=141512975, orientation='plus', exon_count=4, OMIM=[606288], no_hdr0=''),
    56121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56121, CurrentID=0, Status='live', Symbol='PCDHB15', Aliases=['PCDH-BETA15'], description='protocadherin beta 15', other_designations='protocadherin beta-15', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141245395, end_position_on_the_genomic_accession=141249365, orientation='plus', exon_count=1, OMIM=[606341], no_hdr0=''),
    56122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56122, CurrentID=0, Status='live', Symbol='PCDHB14', Aliases=['PCDH-BETA14'], description='protocadherin beta 14', other_designations='protocadherin beta-14', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141223343, end_position_on_the_genomic_accession=141227759, orientation='plus', exon_count=1, OMIM=[606340], no_hdr0=''),
    56123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56123, CurrentID=0, Status='live', Symbol='PCDHB13', Aliases=['PCDH-BETA13'], description='protocadherin beta 13', other_designations='protocadherin beta-13', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141213919, end_position_on_the_genomic_accession=141218979, orientation='plus', exon_count=1, OMIM=[606339], no_hdr0=''),
    56124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56124, CurrentID=0, Status='live', Symbol='PCDHB12', Aliases=['PCDH-BETA12'], description='protocadherin beta 12', other_designations='protocadherin beta-12|PCDH-beta-12', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141208719, end_position_on_the_genomic_accession=141212571, orientation='plus', exon_count=1, OMIM=[606338], no_hdr0=''),
    56125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56125, CurrentID=0, Status='live', Symbol='PCDHB11', Aliases=['ME2', 'PCDH-BETA11'], description='protocadherin beta 11', other_designations='protocadherin beta-11|PCDH-beta-11|cadherin ME2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141199627, end_position_on_the_genomic_accession=141203779, orientation='plus', exon_count=1, OMIM=[606337], no_hdr0=''),
    56126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56126, CurrentID=0, Status='live', Symbol='PCDHB10', Aliases=['PCDH-BETA10', 'PCHB10'], description='protocadherin beta 10', other_designations='protocadherin beta-10|PCDH-beta-10', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141192353, end_position_on_the_genomic_accession=141195647, orientation='plus', exon_count=1, OMIM=[606336], no_hdr0=''),
    56127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56127, CurrentID=0, Status='live', Symbol='PCDHB9', Aliases=['PCDH-BETA9', 'PCDH3H'], description='protocadherin beta 9', other_designations='protocadherin beta-9|PCDH-beta-9|protocadherin-3h', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141187161, end_position_on_the_genomic_accession=141191541, orientation='plus', exon_count=1, OMIM=[606335], no_hdr0=''),
    56128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56128, CurrentID=0, Status='live', Symbol='PCDHB8', Aliases=['PCDH-BETA8', 'PCDH3I'], description='protocadherin beta 8', other_designations='protocadherin beta-8|protocadherin-3i', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141177790, end_position_on_the_genomic_accession=141180539, orientation='plus', exon_count=1, OMIM=[606334], no_hdr0=''),
    56129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56129, CurrentID=0, Status='live', Symbol='PCDHB7', Aliases=['PCDH-BETA7'], description='protocadherin beta 7', other_designations='protocadherin beta-7', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141172644, end_position_on_the_genomic_accession=141176383, orientation='plus', exon_count=1, OMIM=[606333], no_hdr0=''),
    56130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56130, CurrentID=0, Status='live', Symbol='PCDHB6', Aliases=['PCDH-BETA6'], description='protocadherin beta 6', other_designations='protocadherin beta-6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141150057, end_position_on_the_genomic_accession=141153287, orientation='plus', exon_count=1, OMIM=[606332], no_hdr0=''),
    56131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56131, CurrentID=0, Status='live', Symbol='PCDHB4', Aliases=['PCDH-BETA4'], description='protocadherin beta 4', other_designations='protocadherin beta-4', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141121818, end_position_on_the_genomic_accession=141125623, orientation='plus', exon_count=1, OMIM=[606330], no_hdr0=''),
    56132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56132, CurrentID=0, Status='live', Symbol='PCDHB3', Aliases=['PCDH-BETA3'], description='protocadherin beta 3', other_designations='protocadherin beta-3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141100473, end_position_on_the_genomic_accession=141103827, orientation='plus', exon_count=1, OMIM=[606329], no_hdr0=''),
    56133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56133, CurrentID=0, Status='live', Symbol='PCDHB2', Aliases=['PCDH-BETA2'], description='protocadherin beta 2', other_designations='protocadherin beta-2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141094615, end_position_on_the_genomic_accession=141098703, orientation='plus', exon_count=1, OMIM=[606328], no_hdr0=''),
    56134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56134, CurrentID=0, Status='live', Symbol='PCDHAC2', Aliases=['PCDH-ALPHA-C2'], description='protocadherin alpha subfamily C, 2', other_designations='protocadherin alpha-C2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140966476, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606321], no_hdr0=''),
    56135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56135, CurrentID=0, Status='live', Symbol='PCDHAC1', Aliases=['PCDH-ALPHA-C1'], description='protocadherin alpha subfamily C, 1', other_designations='protocadherin alpha-C1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140926299, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606320], no_hdr0=''),
    56136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56136, CurrentID=0, Status='live', Symbol='PCDHA13', Aliases=['CNR5', 'CNRN5', 'CNRS5', 'CRNR5', 'PCDH-ALPHA13'], description='protocadherin alpha 13', other_designations='protocadherin alpha-13|KIAA0345-like 1|PCDH-alpha-13|ortholog of mouse CNR5', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140882124, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606319], no_hdr0=''),
    56137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56137, CurrentID=0, Status='live', Symbol='PCDHA12', Aliases=['PCDH-ALPHA12'], description='protocadherin alpha 12', other_designations='protocadherin alpha-12|KIAA0345-like 2|PCDH-alpha-12', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140875308, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606318], no_hdr0=''),
    56138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56138, CurrentID=0, Status='live', Symbol='PCDHA11', Aliases=['CNR7', 'CNRN7', 'CNRS7', 'CRNR7', 'PCDH-ALPHA11'], description='protocadherin alpha 11', other_designations='protocadherin alpha-11|KIAA0345-like 3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140867513, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606317], no_hdr0=''),
    56139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56139, CurrentID=0, Status='live', Symbol='PCDHA10', Aliases=['CNR8', 'CNRN8', 'CNRS8', 'CRNR8', 'PCDH-ALPHA10'], description='protocadherin alpha 10', other_designations='protocadherin alpha-10|KIAA0345-like 4|PCDH-alpha-10|ortholog to mouse CNR8', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140855897, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606316], no_hdr0=''),
    56140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56140, CurrentID=0, Status='live', Symbol='PCDHA8', Aliases=['PCDH-ALPHA8'], description='protocadherin alpha 8', other_designations='protocadherin alpha-8|KIAA0345-like 6|PCDH-alpha-8', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140841187, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606314], no_hdr0=''),
    56141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56141, CurrentID=0, Status='live', Symbol='PCDHA7', Aliases=['CNR4', 'CNRN4', 'CNRS4', 'CRNR4', 'PCDH-ALPHA7'], description='protocadherin alpha 7', other_designations='protocadherin alpha-7|KIAA0345-like 7|PCDH-alpha-7|ortholog to mouse CNR4', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140834269, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606313], no_hdr0=''),
    56142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56142, CurrentID=0, Status='live', Symbol='PCDHA6', Aliases=['CNR2', 'CNRN2', 'CNRS2', 'CRNR2', 'PCDH-ALPHA6'], description='protocadherin alpha 6', other_designations='protocadherin alpha-6|KIAA0345-like 8|PCDH-alpha-6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140827960, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606312], no_hdr0=''),
    56143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56143, CurrentID=0, Status='live', Symbol='PCDHA5', Aliases=['CNR6', 'CNRN6', 'CNRS6', 'CRNR6', 'PCDH-ALPHA5'], description='protocadherin alpha 5', other_designations='protocadherin alpha-5|KIAA0345-like 9|PCDH-alpha-5|ortholog of mouse CNR6', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140821613, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606311], no_hdr0=''),
    56144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56144, CurrentID=0, Status='live', Symbol='PCDHA4', Aliases=['CNR1', 'CNRN1', 'CRNR1', 'PCDH-ALPHA4'], description='protocadherin alpha 4', other_designations='protocadherin alpha-4|KIAA0345-like 10|PCDH-alpha-4|ortholog of mouse CNR1|ortholog of mouse CNR1, KIAA0345-like 10', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140807068, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606310], no_hdr0=''),
    56145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56145, CurrentID=0, Status='live', Symbol='PCDHA3', Aliases=['PCDH-ALPHA3'], description='protocadherin alpha 3', other_designations='protocadherin alpha-3|KIAA0345-like 11|PCDH-alpha-3', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140801057, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606309], no_hdr0=''),
    56146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56146, CurrentID=0, Status='live', Symbol='PCDHA2', Aliases=['PCDH-ALPHA2'], description='protocadherin alpha 2', other_designations='protocadherin alpha-2|KIAA0345-like 12', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140794852, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=5, OMIM=[606308], no_hdr0=''),
    56147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56147, CurrentID=0, Status='live', Symbol='PCDHA1', Aliases=['PCDH-ALPHA1'], description='protocadherin alpha 1', other_designations='protocadherin alpha-1|KIAA0345-like 13|PCDH-alpha-1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140786136, end_position_on_the_genomic_accession=141012347, orientation='plus', exon_count=4, OMIM=[606307], no_hdr0=''),
    56154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56154, CurrentID=0, Status='live', Symbol='TEX15', Aliases=['CT42', 'SPGF25'], description='testis expressed 15, meiosis and synapsis associated', other_designations='testis-expressed protein 15|cancer/testis antigen 42|testis-expressed sequence 15 protein', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30831544, end_position_on_the_genomic_accession=30913008, orientation='minus', exon_count=12, OMIM=[605795], no_hdr0=''),
    56155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56155, CurrentID=0, Status='live', Symbol='TEX14', Aliases=['CT113', 'SPGF23'], description='testis expressed 14, intercellular bridge forming factor', other_designations='inactive serine/threonine-protein kinase TEX14|cancer/testis antigen 113|protein kinase-like protein SgK307|sugen kinase 307|testis-expressed protein 14|testis-expressed sequence 14 protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58556678, end_position_on_the_genomic_accession=58692045, orientation='minus', exon_count=35, OMIM=[605792], no_hdr0=''),
    56156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56156, CurrentID=0, Status='live', Symbol='TEX13B', Aliases=['TGC3B', 'TSGA5'], description='testis expressed 13B', other_designations='testis-expressed protein 13B|testis expressed sequence 13B|testis-expressed sequence 13B protein', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107980864, end_position_on_the_genomic_accession=107982370, orientation='minus', exon_count=3, OMIM=[300313], no_hdr0=''),
    56157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56157, CurrentID=0, Status='live', Symbol='TEX13A', Aliases=[], description='testis expressed 13A', other_designations='testis-expressed protein 13A|testis-expressed sequence 13A protein', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=105218929, end_position_on_the_genomic_accession=105220694, orientation='minus', exon_count=3, OMIM=[300312], no_hdr0=''),
    56158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56158, CurrentID=0, Status='live', Symbol='TEX12', Aliases=[], description='testis expressed 12', other_designations='testis-expressed protein 12|testis expressed sequence 12|testis-expressed sequence 12 protein variant 1|testis-expressed sequence 12 protein variant 2|testis-expressed sequence 12 protein variant 3', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112167372, end_position_on_the_genomic_accession=112172556, orientation='plus', exon_count=5, OMIM=[605791], no_hdr0=''),
    56159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56159, CurrentID=0, Status='live', Symbol='TEX11', Aliases=['MZIP4', 'SPGFX2', 'Spo22', 'TGC1', 'TSGA3', 'ZIP4', 'ZIP4H'], description='testis expressed 11', other_designations='testis-expressed protein 11|protein ZIP4 homolog|testis expressed sequence 11|testis-expressed sequence 11 protein', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70511227, end_position_on_the_genomic_accession=70908711, orientation='minus', exon_count=36, OMIM=[300311], no_hdr0=''),
    56160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56160, CurrentID=0, Status='live', Symbol='NSMCE3', Aliases=['HCA4', 'LICS', 'MAGEG1', 'MAGEL3', 'NDNL2', 'NSE3'], description='NSE3 homolog, SMC5-SMC6 complex component', other_designations='non-structural maintenance of chromosomes element 3 homolog|MAGE-G1 antigen|hepatocellular carcinoma-associated protein 4|hepatocellular carcinoma-associated protein HCA4|melanoma antigen, family G, 1|melanoma-associated antigen G1|necdin-like 2, SMC5-SMC6 complex component|necdin-like gene 2|necdin-like protein 2|non-SMC element 3 homolog', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=29264989, end_position_on_the_genomic_accession=29269822, orientation='minus', exon_count=1, OMIM=[608243], no_hdr0=''),
    56163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56163, CurrentID=0, Status='live', Symbol='RNF17', Aliases=['Mmip-2', 'SPATA23', 'TDRD4'], description='ring finger protein 17', other_designations='RING finger protein 17|spermatogenesis associated 23|tudor domain containing 4|tudor domain-containing protein 4', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24747641, end_position_on_the_genomic_accession=24888816, orientation='plus', exon_count=44, OMIM=[605793], no_hdr0=''),
    56164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56164, CurrentID=0, Status='live', Symbol='STK31', Aliases=['SGK396', 'TDRD8'], description='serine/threonine kinase 31', other_designations='serine/threonine-protein kinase 31|serine/threonine-protein kinase NYD-SPK|sugen kinase 396|testis tissue sperm-binding protein Li 78m|tudor domain containing 8', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23710140, end_position_on_the_genomic_accession=23832515, orientation='plus', exon_count=24, OMIM=[605790], no_hdr0=''),
    56165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56165, CurrentID=0, Status='live', Symbol='TDRD1', Aliases=['CT41.1'], description='tudor domain containing 1', other_designations='tudor domain-containing protein 1|cancer/testis antigen 41.1|testicular tissue protein Li 193', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114174442, end_position_on_the_genomic_accession=114232669, orientation='plus', exon_count=30, OMIM=[605796], no_hdr0=''),
    56169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56169, CurrentID=0, Status='live', Symbol='GSDMC', Aliases=['MLZE'], description='gasdermin C', other_designations='gasdermin-C|melanoma-derived leucine zipper, extra-nuclear factor|melanoma-derived leucine zipper-containing extranuclear factor', map_location='8q24.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=129705903, end_position_on_the_genomic_accession=129786624, orientation='minus', exon_count=21, OMIM=[608384], no_hdr0=''),
    56171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56171, CurrentID=0, Status='live', Symbol='DNAH7', Aliases=[], description='dynein axonemal heavy chain 7', other_designations='dynein axonemal heavy chain 7|dynein heavy chain 7, axonemal|axonemal beta dynein heavy chain 7|axonemal dynein heavy chain 7|ciliary dynein heavy chain 7|dynein heavy chain-like protein 2|dynein, axonemal, heavy polypeptide 7|hDHC2', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=195737604, end_position_on_the_genomic_accession=196068837, orientation='minus', exon_count=68, OMIM=[610061], no_hdr0=''),
    56172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56172, CurrentID=0, Status='live', Symbol='ANKH', Aliases=['ANK', 'CCAL2', 'CMDJ', 'CPPDD', 'HANK', 'MANK', 'SLC62A1'], description='ANKH inorganic pyrophosphate transport regulator', other_designations='progressive ankylosis protein homolog|ankylosis, progressive homolog', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=14704800, end_position_on_the_genomic_accession=14871778, orientation='minus', exon_count=14, OMIM=[605145], no_hdr0=''),
    56180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56180, CurrentID=0, Status='live', Symbol='MOSPD1', Aliases=['DJ473B4'], description='motile sperm domain containing 1', other_designations='motile sperm domain-containing protein 1', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134887626, end_position_on_the_genomic_accession=134915314, orientation='minus', exon_count=8, OMIM=[300674], no_hdr0=''),
    56181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56181, CurrentID=0, Status='live', Symbol='MTFR1L', Aliases=['FAM54B', 'HYST1888', 'MST116', 'MSTP116'], description='mitochondrial fission regulator 1 like', other_designations='mitochondrial fission regulator 1-like|family with sequence similarity 54 member B|protein FAM54B', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25819954, end_position_on_the_genomic_accession=25832938, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    56203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56203, CurrentID=0, Status='live', Symbol='LMOD3', Aliases=['NEM10'], description='leiomodin 3', other_designations='leiomodin-3|leiomodin 3 (fetal)|leiomodin, fetal form', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=69106065, end_position_on_the_genomic_accession=69122595, orientation='minus', exon_count=4, OMIM=[616112], no_hdr0=''),
    56204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56204, CurrentID=0, Status='live', Symbol='FAM214A', Aliases=['KIAA1370'], description='family with sequence similarity 214 member A', other_designations='protein FAM214A', map_location='15q21.2-q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=52581321, end_position_on_the_genomic_accession=52709815, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    56241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56241, CurrentID=0, Status='live', Symbol='SUSD2', Aliases=['BK65A6.2', 'W5C5'], description='sushi domain containing 2', other_designations='sushi domain-containing protein 2|Sushi domain (SCR repeat) containing|testicular tissue protein Li 190', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24181487, end_position_on_the_genomic_accession=24189106, orientation='plus', exon_count=15, OMIM=[615825], no_hdr0=''),
    56242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56242, CurrentID=0, Status='live', Symbol='ZNF253', Aliases=['BMZF-1', 'BMZF1', 'ZNF411'], description='zinc finger protein 253', other_designations='zinc finger protein 253|DNA-binding protein|bone marrow zinc finger 1|zinc finger protein 411', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19865830, end_position_on_the_genomic_accession=19894674, orientation='plus', exon_count=4, OMIM=[606954], no_hdr0=''),
    56243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56243, CurrentID=0, Status='live', Symbol='KIAA1217', Aliases=['ETL4', 'SKT'], description='KIAA1217', other_designations='sickle tail protein homolog|likely orthologue of Mus musculus enhancer trap locus 4', map_location='10p12.2-p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=23694727, end_position_on_the_genomic_accession=24547843, orientation='plus', exon_count=32, OMIM=[617367], no_hdr0=''),
    56244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56244, CurrentID=0, Status='live', Symbol='BTNL2', Aliases=['BTL-II', 'BTN7', 'HSBLMHC1', 'SS2'], description='butyrophilin like 2', other_designations='butyrophilin-like protein 2|butyrophilin-like 2 (MHC class II associated)|truncated BTNL2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32393339, end_position_on_the_genomic_accession=32408879, orientation='minus', exon_count=8, OMIM=[606000], no_hdr0=''),
    56245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56245, CurrentID=0, Status='live', Symbol='C21orf62', Aliases=['B37', 'C21orf120', 'PRED81'], description='chromosome 21 open reading frame 62', other_designations='uncharacterized protein C21orf62', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32790673, end_position_on_the_genomic_accession=32813808, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    56246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56246, CurrentID=0, Status='live', Symbol='MRAP', Aliases=['B27', 'C21orf61', 'FALP', 'FGD2', 'GCCD2'], description='melanocortin 2 receptor accessory protein', other_designations='melanocortin-2 receptor accessory protein|fat cell-specific low molecular weight protein|fat tissue-specific low MW protein', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32291813, end_position_on_the_genomic_accession=32314784, orientation='plus', exon_count=6, OMIM=[609196], no_hdr0=''),
    56252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56252, CurrentID=0, Status='live', Symbol='YLPM1', Aliases=['C14orf170', 'PPP1R169', 'ZAP113', 'ZAP3'], description='YLP motif containing 1', other_designations='YLP motif-containing protein 1|nuclear protein ZAP3|protein phosphatase 1, regulatory subunit 169', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74763316, end_position_on_the_genomic_accession=74837318, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    56253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56253, CurrentID=0, Status='live', Symbol='CRTAM', Aliases=['CD355'], description='cytotoxic and regulatory T cell molecule', other_designations='cytotoxic and regulatory T-cell molecule|class-I MHC-restricted T-cell-associated molecule', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=122838419, end_position_on_the_genomic_accession=122872643, orientation='plus', exon_count=10, OMIM=[612597], no_hdr0=''),
    56254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56254, CurrentID=0, Status='live', Symbol='RNF20', Aliases=['BRE1', 'BRE1A', 'hBRE1'], description='ring finger protein 20', other_designations='E3 ubiquitin-protein ligase BRE1A|BRE1 E3 ubiquitin ligase homolog|RING-type E3 ubiquitin transferase BRE1A|homolog of S. cerevisiae BRE1', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101533853, end_position_on_the_genomic_accession=101563344, orientation='plus', exon_count=21, OMIM=[607699], no_hdr0=''),
    56255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56255, CurrentID=0, Status='live', Symbol='TMX4', Aliases=['DJ971N18.2', 'PDIA14', 'TXNDC13'], description='thioredoxin related transmembrane protein 4', other_designations='thioredoxin-related transmembrane protein 4|protein disulfide isomerase family A, member 14|thioredoxin domain containing 13|thioredoxin domain-containing protein 13', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=7977346, end_position_on_the_genomic_accession=8019761, orientation='minus', exon_count=8, OMIM=[616766], no_hdr0=''),
    56256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56256, CurrentID=0, Status='live', Symbol='SERTAD4', Aliases=['DJ667H12.2'], description='SERTA domain containing 4', other_designations='SERTA domain-containing protein 4', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=210232796, end_position_on_the_genomic_accession=210246863, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    56257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56257, CurrentID=0, Status='live', Symbol='MEPCE', Aliases=['BCDIN3'], description='methylphosphate capping enzyme', other_designations='7SK snRNA methylphosphate capping enzyme|bicoid-interacting protein 3 homolog|bin3 homolog|bin3, bicoid-interacting 3, homolog', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100428790, end_position_on_the_genomic_accession=100434118, orientation='plus', exon_count=6, OMIM=[611478], no_hdr0=''),
    56259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56259, CurrentID=0, Status='live', Symbol='CTNNBL1', Aliases=['C20orf33', 'NAP', 'P14L', 'PP8304', 'dJ633O20.1'], description='catenin beta like 1', other_designations='beta-catenin-like protein 1|nuclear associated protein|testis development protein NYD-SP19', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37694030, end_position_on_the_genomic_accession=37872124, orientation='plus', exon_count=19, OMIM=[611537], no_hdr0=''),
    56261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56261, CurrentID=0, Status='live', Symbol='GPCPD1', Aliases=['EDI3', 'GDE5', 'GDPD6', 'PREI4'], description='glycerophosphocholine phosphodiesterase 1', other_designations='glycerophosphocholine phosphodiesterase GPCPD1|endometrial differential 3|glycerophosphocholine phosphodiesterase GDE1 homolog|glycerophosphodiester phosphodiesterase 5|preimplantation protein 4|putative glycerophosphocholine phosphodiesterase GPCPD1|putative glycerophosphodiester phosphodiesterase 5', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5544439, end_position_on_the_genomic_accession=5611046, orientation='minus', exon_count=24, OMIM=[614124], no_hdr0=''),
    56262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56262, CurrentID=0, Status='live', Symbol='LRRC8A', Aliases=['AGM5', 'HsLRRC8A', 'LRRC8', 'SWELL1'], description='leucine rich repeat containing 8 VRAC subunit A', other_designations='volume-regulated anion channel subunit LRRC8A|leucine rich repeat containing 8 family member A|leucine-rich repeat-containing protein 8A|swelling protein 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128882133, end_position_on_the_genomic_accession=128918042, orientation='plus', exon_count=10, OMIM=[608360], no_hdr0=''),
    56265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56265, CurrentID=0, Status='live', Symbol='CPXM1', Aliases=['CPX1', 'CPXM'], description='carboxypeptidase X, M14 family member 1', other_designations='probable carboxypeptidase X1|carboxypeptidase X (M14 family), member 1|carboxypeptidase-like protein X1|metallocarboxypeptidase CPX-1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2794074, end_position_on_the_genomic_accession=2800627, orientation='minus', exon_count=14, OMIM=[609555], no_hdr0=''),
    56267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56267, CurrentID=0, Status='live', Symbol='KYAT3', Aliases=['CCBL2', 'KAT3', 'KATIII'], description='kynurenine aminotransferase 3', other_designations='kynurenine--oxoglutarate transaminase 3|cysteine-S-conjugate beta-lyase 2|kynurenine aminotransferase III|kynurenine--glyoxylate transaminase|kynurenine--oxoglutarate transaminase III', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=88921044, end_position_on_the_genomic_accession=88992960, orientation='minus', exon_count=17, OMIM=[610656], no_hdr0=''),
    56269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56269, CurrentID=0, Status='live', Symbol='IRGC', Aliases=['CINEMA', 'IFGGE1', 'Iigp5', 'R30953_1', 'IRGC'], description='immunity related GTPase cinema', other_designations='interferon-inducible GTPase 5|immunity-related GTPase cinema 1|immunity-related GTPase family, cinema 1|interferon-gamma-inducible GTPase IFGGE protein', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43716068, end_position_on_the_genomic_accession=43720021, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    56270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56270, CurrentID=0, Status='live', Symbol='WDR45B', Aliases=['NEDSBAS', 'WDR45L', 'WIPI-3', 'WIPI3'], description='WD repeat domain 45B', other_designations='WD repeat domain phosphoinositide-interacting protein 3|WD repeat protein 45-like|WD repeat-containing protein 45-like|WD repeat-containing protein 45B|WDR45-like protein|WIPI3 long|WIPI49-like protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82614562, end_position_on_the_genomic_accession=82648530, orientation='minus', exon_count=11, OMIM=[609226], no_hdr0=''),
    56271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56271, CurrentID=0, Status='live', Symbol='BEX4', Aliases=['BEXL1'], description='brain expressed X-linked 4', other_designations='protein BEX4|BEX family member 4|BEX1-like protein 1|brain expressed X-linked-like 1|nerve growth factor receptor-associated protein 3', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103215092, end_position_on_the_genomic_accession=103217246, orientation='plus', exon_count=3, OMIM=[300692], no_hdr0=''),
    56287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56287, CurrentID=0, Status='live', Symbol='GKN1', Aliases=['AMP18', 'BRICD1', 'CA11', 'FOV', 'foveolin'], description='gastrokine 1', other_designations='gastrokine-1|18 kDa antrum mucosa protein|BRICHOS domain containing 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68974636, end_position_on_the_genomic_accession=68980976, orientation='plus', exon_count=6, OMIM=[606402], no_hdr0=''),
    56288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56288, CurrentID=0, Status='live', Symbol='PARD3', Aliases=['ASIP', 'Baz', 'PAR3', 'PAR3alpha', 'PARD-3A', 'PPP1R118', 'SE2-5L16', 'SE2-5LT1', 'SE2-5T2', 'PARD3'], description='par-3 family cell polarity regulator', other_designations='partitioning defective 3 homolog|CTCL tumor antigen se2-5|PAR3-alpha|atypical PKC isotype-specific interacting protein|bazooka|par-3 family cell polarity regulator alpha|par-3 partitioning defective 3 homolog|protein phosphatase 1, regulatory subunit 118', map_location='10p11.22-p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=34109561, end_position_on_the_genomic_accession=34815296, orientation='minus', exon_count=26, OMIM=[606745], no_hdr0=''),
    56300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56300, CurrentID=0, Status='live', Symbol='IL36G', Aliases=['IL-1F9', 'IL-1H1', 'IL-1RP2', 'IL1E', 'IL1F9', 'IL1H1', 'IL1RP2'], description='interleukin 36 gamma', other_designations='interleukin-36 gamma|IL-1 related protein 2|IL-1-epsilon|interleukin 1-related protein 2|interleukin-1 epsilon|interleukin-1 family member 9|interleukin-1 homolog 1', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112978006, end_position_on_the_genomic_accession=112985658, orientation='plus', exon_count=5, OMIM=[605542], no_hdr0=''),
    56301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56301, CurrentID=0, Status='live', Symbol='SLC7A10', Aliases=['ASC1', 'HASC-1', 'asc-1'], description='solute carrier family 7 member 10', other_designations='asc-type amino acid transporter 1|solute carrier family 7 (neutral amino acid transporter light chain, asc system), member 10|solute carrier family 7, (cationic amino acid transporter, y+ system) member 10|solute carrier family 7, (neutral amino acid transporter, y+ system) member 10', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33208664, end_position_on_the_genomic_accession=33225850, orientation='minus', exon_count=11, OMIM=[607959], no_hdr0=''),
    56302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56302, CurrentID=0, Status='live', Symbol='TRPV5', Aliases=['CAT2', 'ECAC1', 'OTRPC3'], description='transient receptor potential cation channel subfamily V member 5', other_designations='transient receptor potential cation channel subfamily V member 5|calcium transport protein 2|calcium transporter 2|epithelial calcium channel 1|osm-9-like TRP channel 3', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142908101, end_position_on_the_genomic_accession=142933746, orientation='minus', exon_count=15, OMIM=[606679], no_hdr0=''),
    56311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56311, CurrentID=0, Status='live', Symbol='ANKRD7', Aliases=['TSA806'], description='ankyrin repeat domain 7', other_designations='ankyrin repeat domain-containing protein 7|testicular tissue protein Li 19|testis-specific ankyrin motif containing protein|testis-specific protein TSA806', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=118224704, end_position_on_the_genomic_accession=118242732, orientation='plus', exon_count=7, OMIM=[610731], no_hdr0=''),
    56339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56339, CurrentID=0, Status='live', Symbol='METTL3', Aliases=['IME4', 'M6A', 'MT-A70', 'Spo8', 'hMETTL3'], description='methyltransferase 3, N6-adenosine-methyltransferase complex catalytic subunit', other_designations="N6-adenosine-methyltransferase catalytic subunit|N6-adenosine-methyltransferase 70 kDa subunit|adoMet-binding subunit of the human mRNA (N6-adenosine)-methyltransferase|mRNA (2'-O-methyladenosine-N(6)-)-methyltransferase|mRNA m(6)A methyltransferase|methyltransferase like 3|methyltransferase-like protein 3", map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21498138, end_position_on_the_genomic_accession=21511340, orientation='minus', exon_count=10, OMIM=[612472], no_hdr0=''),
    56341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56341, CurrentID=0, Status='live', Symbol='PRMT8', Aliases=['HRMT1L3', 'HRMT1L4'], description='protein arginine methyltransferase 8', other_designations='protein arginine N-methyltransferase 8|HMT1 hnRNP methyltransferase-like 3|arginine methyltransferase 8|heterogeneous nuclear ribonucleoprotein methyltransferase-like protein 4|protein arginine N-methyltransferase 4', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=3381349, end_position_on_the_genomic_accession=3593973, orientation='plus', exon_count=12, OMIM=[610086], no_hdr0=''),
    56342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56342, CurrentID=0, Status='live', Symbol='PPAN', Aliases=['BXDC3', 'SSF', 'SSF-1', 'SSF1', 'SSF2'], description='peter pan homolog', other_designations='suppressor of SWI4 1 homolog|brix domain-containing protein 3|homolog of S. cerevisiae SSF1|second-step splicing factor 1|suppressor of sterile four 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10106223, end_position_on_the_genomic_accession=10112012, orientation='plus', exon_count=11, OMIM=[607793], no_hdr0=''),
    56344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56344, CurrentID=0, Status='live', Symbol='CABP5', Aliases=['CABP3'], description='calcium binding protein 5', other_designations='calcium-binding protein 5|calcium-binding protein 3', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48029383, end_position_on_the_genomic_accession=48048342, orientation='minus', exon_count=8, OMIM=[607315], no_hdr0=''),
    56413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56413, CurrentID=0, Status='live', Symbol='LTB4R2', Aliases=['BLT2', 'BLTR2', 'JULF2', 'KPG_004', 'LTB4-R 2', 'LTB4-R2', 'NOP9'], description='leukotriene B4 receptor 2', other_designations='leukotriene B4 receptor 2|LTB4 receptor JULF2|leukotriene B4 receptor BLT2|seven transmembrane receptor BLTR2', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24310140, end_position_on_the_genomic_accession=24312038, orientation='plus', exon_count=2, OMIM=[605773], no_hdr0=''),
    56474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56474, CurrentID=0, Status='live', Symbol='CTPS2', Aliases=['GATD5B'], description='CTP synthase 2', other_designations="CTP synthase 2|CTP synthase II|CTP synthetase type 2|UTP-ammonia ligase 2|cytidine 5'-triphosphate synthetase 2", map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16587999, end_position_on_the_genomic_accession=16712917, orientation='minus', exon_count=24, OMIM=[300380], no_hdr0=''),
    56475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56475, CurrentID=0, Status='live', Symbol='RPRM', Aliases=['REPRIMO'], description='reprimo, TP53 dependent G2 arrest mediator homolog', other_designations='protein reprimo|candidate mediator of the p53 dependent G2 arrest|reprimo, TP53 dependant G2 arrest mediator candidate|reprimo, TP53 dependent G2 arrest mediator candidate', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=153477338, end_position_on_the_genomic_accession=153478762, orientation='minus', exon_count=1, OMIM=[612171], no_hdr0=''),
    56477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56477, CurrentID=0, Status='live', Symbol='CCL28', Aliases=['CCK1', 'MEC', 'SCYA28'], description='C-C motif chemokine ligand 28', other_designations='C-C motif chemokine 28|CC chemokine CCL28|chemokine (C-C motif) ligand 28 splice variant chi|mucosae-associated epithelial chemokine|small inducible cytokine A28|small inducible cytokine subfamily A (Cys-Cys), member 28', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43356972, end_position_on_the_genomic_accession=43412391, orientation='minus', exon_count=8, OMIM=[605240], no_hdr0=''),
    56478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56478, CurrentID=0, Status='live', Symbol='EIF4ENIF1', Aliases=['4E-T', 'Clast4'], description='eukaryotic translation initiation factor 4E nuclear import factor 1', other_designations='eukaryotic translation initiation factor 4E transporter|2610509L04Rik|4E-transporter|eIF4E transporter', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31434648, end_position_on_the_genomic_accession=31489950, orientation='minus', exon_count=22, OMIM=[607445], no_hdr0=''),
    56479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56479, CurrentID=0, Status='live', Symbol='KCNQ5', Aliases=['Kv7.5', 'MRD46'], description='potassium voltage-gated channel subfamily Q member 5', other_designations='potassium voltage-gated channel subfamily KQT member 5|KQT-like 5|potassium channel protein|potassium channel subunit alpha KvLQT5|potassium channel, voltage gated KQT-like subfamily Q, member 5|voltage-gated potassium channel subunit Kv7.5', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=72621843, end_position_on_the_genomic_accession=73198853, orientation='plus', exon_count=17, OMIM=[607357], no_hdr0=''),
    56521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56521, CurrentID=0, Status='live', Symbol='DNAJC12', Aliases=['HPANBH4', 'JDP1'], description='DnaJ heat shock protein family (Hsp40) member C12', other_designations='dnaJ homolog subfamily C member 12|DnaJ (Hsp40) homolog, subfamily C, member 12|J domain containing protein 1 (JDP1)|J domain protein 1|j domain-containing protein 1', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=67796665, end_position_on_the_genomic_accession=67838188, orientation='minus', exon_count=6, OMIM=[606060], no_hdr0=''),
    56547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56547, CurrentID=0, Status='live', Symbol='MMP26', Aliases=[], description='matrix metallopeptidase 26', other_designations='matrix metalloproteinase-26|MMP-26|endometase|matrilysin 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4704784, end_position_on_the_genomic_accession=4992429, orientation='plus', exon_count=9, OMIM=[605470], no_hdr0=''),
    56548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56548, CurrentID=0, Status='live', Symbol='CHST7', Aliases=['C6ST-2', 'GST-5'], description='carbohydrate sulfotransferase 7', other_designations='carbohydrate sulfotransferase 7|N-acetylglucosamine 6-O-sulfotransferase 4|carbohydrate (N-acetylglucosamine 6-O) sulfotransferase 7|chondroitin 6-sulfotransferase-2|galactose/N-acetylglucosamine/N-acetylglucosamine 6-O-sulfotransferase 5|glcNAc6ST-4|gn6st-4', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46573765, end_position_on_the_genomic_accession=46598496, orientation='plus', exon_count=2, OMIM=[300375], no_hdr0=''),
    56603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56603, CurrentID=0, Status='live', Symbol='CYP26B1', Aliases=['CYP26A2', 'P450RAI-2', 'P450RAI2', 'RHFCA'], description='cytochrome P450 family 26 subfamily B member 1', other_designations='cytochrome P450 26B1|cytochrome P450 family 26 subfamily A member 1|cytochrome P450 retinoic acid-inactivating 2|cytochrome P450 retinoid metabolizing protein|cytochrome P450, family 26, subfamily B, polypeptide 1|cytochrome P450, subfamily XXVIB, polypeptide 1|retinoic acid-metabolizing cytochrome', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=72129238, end_position_on_the_genomic_accession=72147862, orientation='minus', exon_count=8, OMIM=[605207], no_hdr0=''),
    56605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56605, CurrentID=0, Status='live', Symbol='ERO1B', Aliases=['ERO1LB', 'Ero1beta'], description='endoplasmic reticulum oxidoreductase 1 beta', other_designations='ERO1-like protein beta|ERO1-L-beta|ERO1-like beta|endoplasmic oxidoreductin-1-like protein B|endoplasmic reticulum oxidoreductase beta|endoplasmic reticulum oxidoreductin-1-like protein B|oxidoreductin-1-L-beta', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236213064, end_position_on_the_genomic_accession=236281983, orientation='minus', exon_count=17, OMIM=[615437], no_hdr0=''),
    56606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56606, CurrentID=0, Status='live', Symbol='SLC2A9', Aliases=['GLUT9', 'GLUTX', 'UAQTL2', 'URATv1'], description='solute carrier family 2 member 9', other_designations='solute carrier family 2, facilitated glucose transporter member 9|GLUT-9|glucose transporter type 9|human glucose transporter-like protein-9|solute carrier family 2 (facilitated glucose transporter), member 9|urate transporter|urate voltage-driven efflux transporter 1', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9771125, end_position_on_the_genomic_accession=10040270, orientation='minus', exon_count=27, OMIM=[606142], no_hdr0=''),
    56616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56616, CurrentID=0, Status='live', Symbol='DIABLO', Aliases=['DFNA64', 'SMAC'], description='diablo IAP-binding mitochondrial protein', other_designations='diablo homolog, mitochondrial|diablo-like protein|direct IAP-binding protein with low pI|second mitochondria-derived activator of caspase', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122207662, end_position_on_the_genomic_accession=122227456, orientation='minus', exon_count=8, OMIM=[605219], no_hdr0=''),
    56623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56623, CurrentID=0, Status='live', Symbol='INPP5E', Aliases=['CORS1', 'CPD4', 'JBTS1', 'MORMS', 'PPI5PIV', 'pharbin'], description='inositol polyphosphate-5-phosphatase E', other_designations='phosphatidylinositol polyphosphate 5-phosphatase type IV|72 kDa inositol polyphosphate 5-phosphatase|phosphatidylinositol-3,4,5-trisphosphate 5-phosphatase|phosphatidylinositol-4,5-bisphosphate 5-phosphatase', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136428619, end_position_on_the_genomic_accession=136439861, orientation='minus', exon_count=10, OMIM=[613037], no_hdr0=''),
    56624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56624, CurrentID=0, Status='live', Symbol='ASAH2', Aliases=['BCDase', 'HNAC1', 'LCDase', 'N-CDase', 'NCDase'], description='N-acylsphingosine amidohydrolase 2', other_designations='neutral ceramidase|N-acylsphingosine amidohydrolase (non-lysosomal ceramidase) 2|acylsphingosine deacylase 2|mitochondrial ceramidase|neutral/alkaline ceramidase|non-lysosomal ceramidase', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50184861, end_position_on_the_genomic_accession=50251564, orientation='minus', exon_count=23, OMIM=[611202], no_hdr0=''),
    56647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56647, CurrentID=0, Status='live', Symbol='BCCIP', Aliases=['TOK-1', 'TOK1'], description='BRCA2 and CDKN1A interacting protein', other_designations='BRCA2 and CDKN1A-interacting protein|BCCIPalpha|BCCIPbeta|BRCA2 and Cip1/p21 interacting protein|TOK-1alpha|TOK-1beta|cdk inhibitor p21 binding protein|p21- and CDK-associated protein 1|protein TOK-1', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125823546, end_position_on_the_genomic_accession=125853695, orientation='plus', exon_count=9, OMIM=[611883], no_hdr0=''),
    56648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56648, CurrentID=0, Status='live', Symbol='EIF5A2', Aliases=['EIF-5A2', 'eIF5AII'], description='eukaryotic translation initiation factor 5A2', other_designations='eukaryotic translation initiation factor 5A-2|eIF-5A-2|eukaryotic initiation factor 5A', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170888418, end_position_on_the_genomic_accession=170908637, orientation='minus', exon_count=5, OMIM=[605782], no_hdr0=''),
    56649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56649, CurrentID=0, Status='live', Symbol='TMPRSS4', Aliases=['CAP2', 'CAPH2', 'MT-SP2', 'TMPRSS3'], description='transmembrane serine protease 4', other_designations='transmembrane protease serine 4|channel-activating protease 2|channel-activating serine protease 2|membrane-type serine protease 2|transmembrane protease, serine 4|transmembrane serine protease 3|type II membrane serine protease', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118077016, end_position_on_the_genomic_accession=118125505, orientation='plus', exon_count=16, OMIM=[606565], no_hdr0=''),
    56650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56650, CurrentID=0, Status='live', Symbol='CLDND1', Aliases=['C3orf4', 'GENX-3745', 'Z38'], description='claudin domain containing 1', other_designations='claudin domain-containing protein 1|claudin domain containing 1 protein|membrane protein GENX-3745', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98515483, end_position_on_the_genomic_accession=98522902, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    56652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56652, CurrentID=0, Status='live', Symbol='TWNK', Aliases=['ATXN8', 'C10orf2', 'IOSCA', 'MTDPS7', 'PEO', 'PEO1', 'PEOA3', 'PRLTS5', 'SANDO', 'SCA8', 'TWINL'], description='twinkle mtDNA helicase', other_designations='twinkle protein, mitochondrial|T7 gp4-like protein with intramitochondrial nucleoid localization|T7 helicase-related protein with intramitochondrial nucleoid localization|T7-like mitochondrial DNA helicase|ataxin 8|progressive external ophthalmoplegia 1 protein', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100987543, end_position_on_the_genomic_accession=100994403, orientation='plus', exon_count=5, OMIM=[606075], no_hdr0=''),
    56654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56654, CurrentID=0, Status='live', Symbol='NPDC1', Aliases=['CAB', 'CAB-', 'CAB-1', 'CAB1', 'NPDC-1'], description='neural proliferation, differentiation and control 1', other_designations='neural proliferation differentiation and control protein 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137039463, end_position_on_the_genomic_accession=137046177, orientation='minus', exon_count=9, OMIM=[605798], no_hdr0=''),
    56655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56655, CurrentID=0, Status='live', Symbol='POLE4', Aliases=['YHHQ1', 'p12'], description='DNA polymerase epsilon 4, accessory subunit', other_designations='DNA polymerase epsilon subunit 4|DNA polymerase II subunit 4|DNA polymerase epsilon subunit p12|polymerase (DNA) epsilon 4, accessory subunit|polymerase (DNA-directed), epsilon 4, accessory subunit', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74958643, end_position_on_the_genomic_accession=74970128, orientation='plus', exon_count=4, OMIM=[607269], no_hdr0=''),
    56656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56656, CurrentID=0, Status='live', Symbol='OR2S2', Aliases=['OR37A', 'OST715'], description='olfactory receptor family 2 subfamily S member 2', other_designations='olfactory receptor 2S2|olfactory receptor OR9-3', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35957108, end_position_on_the_genomic_accession=35958154, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    56658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56658, CurrentID=0, Status='live', Symbol='TRIM39', Aliases=['RNF23', 'TFPB', 'TRIM39'], description='tripartite motif containing 39', other_designations='E3 ubiquitin-protein ligase TRIM39|RING-type E3 ubiquitin transferase TRIM39|ring finger protein 23|testis-abundant finger protein|tripartite motif-containing protein 39', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30326469, end_position_on_the_genomic_accession=30343729, orientation='plus', exon_count=10, OMIM=[605700], no_hdr0=''),
    56659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56659, CurrentID=0, Status='live', Symbol='KCNK13', Aliases=['K2p13.1', 'THIK-1', 'THIK1'], description='potassium two pore domain channel subfamily K member 13', other_designations='potassium channel subfamily K member 13|K2P13.1 potassium channel|potassium channel, subfamily K, member 13|potassium channel, two pore domain subfamily K, member 13|tandem pore domain halothane-inhibited potassium channel 1|tandem pore domain potassium channel THIK-1', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90061994, end_position_on_the_genomic_accession=90185853, orientation='plus', exon_count=2, OMIM=[607367], no_hdr0=''),
    56660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56660, CurrentID=0, Status='live', Symbol='KCNK12', Aliases=['K2p12.1', 'THIK-2', 'THIK2'], description='potassium two pore domain channel subfamily K member 12', other_designations='potassium channel subfamily K member 12|potassium channel, subfamily K, member 12|potassium channel, two pore domain subfamily K, member 12|tandem pore domain halothane-inhibited potassium channel 2|tandem pore domain potassium channel THIK-2', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47509290, end_position_on_the_genomic_accession=47570985, orientation='minus', exon_count=2, OMIM=[607366], no_hdr0=''),
    56666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56666, CurrentID=0, Status='live', Symbol='PANX2', Aliases=['PX2', 'hPANX2'], description='pannexin 2', other_designations='pannexin-2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50170731, end_position_on_the_genomic_accession=50180295, orientation='plus', exon_count=4, OMIM=[608421], no_hdr0=''),
    56667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56667, CurrentID=0, Status='live', Symbol='MUC13', Aliases=['DRCC1', 'MUC-13'], description='mucin 13, cell surface associated', other_designations='mucin-13|down-regulated in colon cancer 1|mucin 13, epithelial transmembrane', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=124905442, end_position_on_the_genomic_accession=124934751, orientation='minus', exon_count=12, OMIM=[612181], no_hdr0=''),
    56670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56670, CurrentID=0, Status='live', Symbol='SUCNR1', Aliases=['GPR91'], description='succinate receptor 1', other_designations='succinate receptor 1|G-protein coupled receptor 91|P2Y purinoceptor 1', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151873643, end_position_on_the_genomic_accession=151884619, orientation='plus', exon_count=3, OMIM=[606381], no_hdr0=''),
    56672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56672, CurrentID=0, Status='live', Symbol='AKIP1', Aliases=['BCA3', 'C11orf17'], description='A-kinase interacting protein 1', other_designations='A-kinase-interacting protein 1|A kinase (PRKA) interacting protein 1|breast cancer associated gene 3|koyt binding protein 1|koyt binding protein 2|koyt binding protein 3|proline-rich protein BCA3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8911117, end_position_on_the_genomic_accession=8920079, orientation='plus', exon_count=6, OMIM=[609191], no_hdr0=''),
    56673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56673, CurrentID=0, Status='live', Symbol='C11orf16', Aliases=[], description='chromosome 11 open reading frame 16', other_designations='uncharacterized protein C11orf16', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8920076, end_position_on_the_genomic_accession=8932947, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    56674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56674, CurrentID=0, Status='live', Symbol='TMEM9B', Aliases=['C11orf15'], description='TMEM9 domain family member B', other_designations='transmembrane protein 9B', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8947202, end_position_on_the_genomic_accession=8964947, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    56675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56675, CurrentID=0, Status='live', Symbol='NRIP3', Aliases=['C11orf14', 'NY-SAR-105'], description='nuclear receptor interacting protein 3', other_designations='nuclear receptor-interacting protein 3|sarcoma antigen NY-SAR-105', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8980576, end_position_on_the_genomic_accession=9004651, orientation='minus', exon_count=9, OMIM=[613125], no_hdr0=''),
    56676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56676, CurrentID=0, Status='live', Symbol='ASCL3', Aliases=['HASH3', 'SGN1', 'bHLHa42'], description='achaete-scute family bHLH transcription factor 3', other_designations='achaete-scute homolog 3|achaete-scute complex homolog 3|bHLH transcription factor Sgn-1 (Salivary Glands 1)|bHLH transcriptional regulator Sgn-1|class A basic helix-loop-helix protein 42', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8937578, end_position_on_the_genomic_accession=8943016, orientation='minus', exon_count=2, OMIM=[609154], no_hdr0=''),
    56681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56681, CurrentID=0, Status='live', Symbol='SAR1A', Aliases=['SAR1', 'SARA1', 'Sara', 'masra2'], description='secretion associated Ras related GTPase 1A', other_designations='GTP-binding protein SAR1a|COPII-associated small GTPase|SAR1 gene homolog A|SAR1 homolog A|SAR1a gene homolog 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70147289, end_position_on_the_genomic_accession=70170514, orientation='minus', exon_count=8, OMIM=[607691], no_hdr0=''),
    56683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56683, CurrentID=0, Status='live', Symbol='CFAP298', Aliases=['C21orf48', 'C21orf59', 'CILD26', 'FBB18', 'Kur'], description='cilia and flagella associated protein 298', other_designations='cilia- and flagella-associated protein 298|UPF0769 protein C21orf59|kurly homolog|prostate cancer upregulated protein 1|protein kurly homolog', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32599354, end_position_on_the_genomic_accession=32612377, orientation='minus', exon_count=7, OMIM=[615494], no_hdr0=''),
    56704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56704, CurrentID=0, Status='live', Symbol='JPH1', Aliases=['CMT2K', 'JP-1', 'JP1'], description='junctophilin 1', other_designations='junctophilin-1|junctophilin type 1', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=74234700, end_position_on_the_genomic_accession=74321540, orientation='minus', exon_count=6, OMIM=[605266], no_hdr0=''),
    56729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56729, CurrentID=0, Status='live', Symbol='RETN', Aliases=['ADSF', 'FIZZ31', 'RSTN', 'XCP1', 'RETN'], description='resistin', other_designations='resistin|C/EBP-epsilon regulated myeloid-specific secreted cysteine-rich protein precursor 1|adipose tissue-specific secretory factor|c/EBP-epsilon-regulated myeloid-specific secreted cysteine-rich protein|cysteine-rich secreted protein A12-alpha-like 2|cysteine-rich secreted protein FIZZ3|found in inflammatory zone 3|resistin delta2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7669049, end_position_on_the_genomic_accession=7670455, orientation='plus', exon_count=4, OMIM=[605565], no_hdr0=''),
    56731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56731, CurrentID=0, Status='live', Symbol='SLC2A4RG', Aliases=['GEF', 'HDBP-1', 'HDBP1', 'Si-1-2', 'Si-1-2-19'], description='SLC2A4 regulator', other_designations="SLC2A4 regulator|GLUT4 enhancer factor|Huntington's disease gene regulatory region-binding protein 1", map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63739776, end_position_on_the_genomic_accession=63744050, orientation='plus', exon_count=8, OMIM=[609493], no_hdr0=''),
    56751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56751, CurrentID=0, Status='live', Symbol='BARHL1', Aliases=[], description='BarH like homeobox 1', other_designations='barH-like 1 homeobox protein', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132582606, end_position_on_the_genomic_accession=132590252, orientation='plus', exon_count=3, OMIM=[605211], no_hdr0=''),
    56776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56776, CurrentID=0, Status='live', Symbol='FMN2', Aliases=[], description='formin 2', other_designations='formin-2', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=240091883, end_position_on_the_genomic_accession=240475187, orientation='plus', exon_count=23, OMIM=[606373], no_hdr0=''),
    56829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56829, CurrentID=0, Status='live', Symbol='ZC3HAV1', Aliases=['ARTD13', 'FLB6421', 'PARP13', 'ZAP', 'ZC3H2', 'ZC3HDC2'], description='zinc finger CCCH-type containing, antiviral 1', other_designations='zinc finger CCCH-type antiviral protein 1|ADP-ribosyltransferase diphtheria toxin-like 13|inactive Poly [ADP-ribose] polymerase 13|zinc finger CCCH domain-containing protein 2|zinc finger CCCH-type, antiviral 1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139043515, end_position_on_the_genomic_accession=139109720, orientation='minus', exon_count=13, OMIM=[607312], no_hdr0=''),
    56832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56832, CurrentID=0, Status='live', Symbol='IFNK', Aliases=['IFNT1', 'INFE1'], description='interferon kappa', other_designations='interferon kappa|IFN-kappa|interferon-like protein', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27524290, end_position_on_the_genomic_accession=27526498, orientation='plus', exon_count=2, OMIM=[615326], no_hdr0=''),
    56833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56833, CurrentID=0, Status='live', Symbol='SLAMF8', Aliases=['BLAME', 'CD353', 'SBBI42'], description='SLAM family member 8', other_designations='SLAM family member 8|B lymphocyte activator macrophage expressed|BCM-like membrane protein', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159826689, end_position_on_the_genomic_accession=159837497, orientation='plus', exon_count=7, OMIM=[606620], no_hdr0=''),
    56834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56834, CurrentID=0, Status='live', Symbol='GPR137', Aliases=['C11orf4A', 'TM7SF1L1', 'GPR137'], description='G protein-coupled receptor 137', other_designations='integral membrane protein GPR137|transmembrane 7 superfamily member 1-like 1 protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64270337, end_position_on_the_genomic_accession=64289500, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    56848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56848, CurrentID=0, Status='live', Symbol='SPHK2', Aliases=['SK 2', 'SK-2', 'SPK 2', 'SPK-2'], description='sphingosine kinase 2', other_designations='sphingosine kinase 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48619409, end_position_on_the_genomic_accession=48630407, orientation='plus', exon_count=9, OMIM=[607092], no_hdr0=''),
    56849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56849, CurrentID=0, Status='live', Symbol='TCEAL7', Aliases=['WEX5'], description='transcription elongation factor A like 7', other_designations='transcription elongation factor A protein-like 7|TCEA-like protein 7|transcription elongation factor A (SII)-like 7|transcription elongation factor S-II protein-like 7', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103330239, end_position_on_the_genomic_accession=103332326, orientation='plus', exon_count=3, OMIM=[300771], no_hdr0=''),
    56850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56850, CurrentID=0, Status='live', Symbol='GRIPAP1', Aliases=['GRASP-1'], description='GRIP1 associated protein 1', other_designations='GRIP1-associated protein 1', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48973723, end_position_on_the_genomic_accession=49002264, orientation='minus', exon_count=26, OMIM=[300408], no_hdr0=''),
    56851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56851, CurrentID=0, Status='live', Symbol='EMC7', Aliases=['C11orf3', 'C15orf24', 'HT022', 'ORF1-FL1'], description='ER membrane protein complex subunit 7', other_designations='ER membrane protein complex subunit 7|UPF0480 protein C15orf24|chromosome 15 hypothetical ATG/GTP binding protein', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34084017, end_position_on_the_genomic_accession=34101862, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    56852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56852, CurrentID=0, Status='live', Symbol='RAD18', Aliases=['RNF73'], description='RAD18 E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase RAD18|RAD18 homolog|RAD18, S. cerevisiae, homolog|RING finger protein 73|RING-type E3 ubiquitin transferase RAD18|hHR18|hRAD18|postreplication repair protein RAD18|postreplication repair protein hRAD18p', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=8877075, end_position_on_the_genomic_accession=8969249, orientation='minus', exon_count=14, OMIM=[605256], no_hdr0=''),
    56853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56853, CurrentID=0, Status='live', Symbol='CELF4', Aliases=['BRUNOL4', 'CELF-4'], description='CUGBP Elav-like family member 4', other_designations='CUGBP Elav-like family member 4|CUG-BP- and ETR-3-like factor 4|LYST-interacting protein LIP9|RNA-binding protein BRUNOL4|bruno-like 4, RNA binding protein|bruno-like protein 4', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=37243040, end_position_on_the_genomic_accession=37565798, orientation='minus', exon_count=17, OMIM=[612679], no_hdr0=''),
    56882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56882, CurrentID=0, Status='live', Symbol='CDC42SE1', Aliases=['SCIP1', 'SPEC1'], description='CDC42 small effector 1', other_designations='CDC42 small effector protein 1|1300002M12Rik|CDC42-binding protein SCIP1|signaling molecule SPEC1 beta|small effector of CDC42 protein 1|small protein effector 1 of Cdc42', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151050980, end_position_on_the_genomic_accession=151059626, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    56884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56884, CurrentID=0, Status='live', Symbol='FSTL5', Aliases=[], description='follistatin like 5', other_designations='follistatin-related protein 5|follistatin-like protein 5', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=161383897, end_position_on_the_genomic_accession=162164000, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    56886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56886, CurrentID=0, Status='live', Symbol='UGGT1', Aliases=['HUGT1', 'UGCGL1', 'UGT1'], description='UDP-glucose glycoprotein glucosyltransferase 1', other_designations='UDP-glucose:glycoprotein glucosyltransferase 1|UDP--Glc:glycoprotein glucosyltransferase|UDP-glucose ceramide glucosyltransferase-like 1', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=128091184, end_position_on_the_genomic_accession=128195677, orientation='plus', exon_count=44, OMIM=[605897], no_hdr0=''),
    56888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56888, CurrentID=0, Status='live', Symbol='KCMF1', Aliases=['DEBT91', 'FIGC', 'PCMF', 'ZZZ1'], description='potassium channel modulatory factor 1', other_designations='E3 ubiquitin-protein ligase KCMF1|FGF-induced in gastric cancer|FGF-induced ubiquitin-protein ligase in gastric cancers|RING-type E3 ubiquitin transferase KCMF1|ZZ-type zinc finger-containing protein 1|differentially expressed in branching tubulogenesis 91|zinc finger, ZZ domain containing 1', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=84971161, end_position_on_the_genomic_accession=85059472, orientation='plus', exon_count=9, OMIM=[614719], no_hdr0=''),
    56889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56889, CurrentID=0, Status='live', Symbol='TM9SF3', Aliases=['EP70-P-iso', 'SMBP'], description='transmembrane 9 superfamily member 3', other_designations='transmembrane 9 superfamily member 3|SM-11044-binding protein|dinucleotide oxidase disulfide thiol exchanger 3 superfamily member 3|endomembrane protein emp70 precursor isolog', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96518110, end_position_on_the_genomic_accession=96587012, orientation='minus', exon_count=16, OMIM=[616872], no_hdr0=''),
    56890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56890, CurrentID=0, Status='live', Symbol='MDM1', Aliases=[], description='Mdm1 nuclear protein', other_designations='nuclear protein MDM1|Mdm4, transformed 3T3 cell double minute 1, p53 binding protein|nuclear protein double minute 1', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68294566, end_position_on_the_genomic_accession=68332362, orientation='minus', exon_count=17, OMIM=[613813], no_hdr0=''),
    56891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56891, CurrentID=0, Status='live', Symbol='LGALS14', Aliases=['CLC2', 'PPL13'], description='galectin 14', other_designations='placental protein 13-like|Charcot-Leyden crystal protein 2|gal-14|lectin, galactoside-binding, soluble, 14|placental protein 13-like protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39704481, end_position_on_the_genomic_accession=39709444, orientation='plus', exon_count=5, OMIM=[607260], no_hdr0=''),
    56892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56892, CurrentID=0, Status='live', Symbol='TCIM', Aliases=['C8orf4', 'TC-1', 'TC1'], description='transcriptional and immune response regulator', other_designations='transcriptional and immune response regulator|human thyroid cancer 1|protein C8orf4|thyroid cancer protein 1', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=40153482, end_position_on_the_genomic_accession=40155310, orientation='plus', exon_count=1, OMIM=[607702], no_hdr0=''),
    56893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56893, CurrentID=0, Status='live', Symbol='UBQLN4', Aliases=['A1U', 'A1Up', 'C1orf6', 'CIP75', 'UBIN'], description='ubiquilin 4', other_designations='ubiquilin-4|ataxin-1 interacting ubiquitin-like protein|ataxin-1 ubiquitin-like interacting protein|ataxin-1 ubiquitin-like-interacting protein A1U|connexin43-interacting protein of 75 kDa', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156033129, end_position_on_the_genomic_accession=156053798, orientation='minus', exon_count=13, OMIM=[605440], no_hdr0=''),
    56894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56894, CurrentID=0, Status='live', Symbol='AGPAT3', Aliases=['1-AGPAT 3', 'LPAAT-GAMMA1', 'LPAAT3'], description='1-acylglycerol-3-phosphate O-acyltransferase 3', other_designations='1-acyl-sn-glycerol-3-phosphate acyltransferase gamma|1-AGP acyltransferase 3|lysophosphatidic acid acyltransferase gamma|lysophosphatidic acid acyltransferase-gamma1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43865160, end_position_on_the_genomic_accession=43987592, orientation='plus', exon_count=20, OMIM=[614794], no_hdr0=''),
    56895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56895, CurrentID=0, Status='live', Symbol='AGPAT4', Aliases=['1-AGPAT4', 'LPAAT-delta', 'dJ473J16.2'], description='1-acylglycerol-3-phosphate O-acyltransferase 4', other_designations='1-acyl-sn-glycerol-3-phosphate acyltransferase delta|1-AGP acyltransferase 4|1-AGPAT 4|1-acylglycerol-3-phosphate O-acyltransferase 4 (lysophosphatidic acid acyltransferase, delta)|lysophosphatidic acid acyltransferase delta|lysophosphatidic acid acyltransferase-delta (LPAAT-delta)', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=161129967, end_position_on_the_genomic_accession=161274108, orientation='minus', exon_count=10, OMIM=[614795], no_hdr0=''),
    56896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56896, CurrentID=0, Status='live', Symbol='DPYSL5', Aliases=['CRAM', 'CRMP-5', 'CRMP5', 'CV2', 'Ulip6'], description='dihydropyrimidinase like 5', other_designations='dihydropyrimidinase-related protein 5|CRMP3-associated molecule|DRP-5|ULIP-6|UNC33-like phosphoprotein 6|collapsin response mediator protein-5', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26847995, end_position_on_the_genomic_accession=26950351, orientation='plus', exon_count=14, OMIM=[608383], no_hdr0=''),
    56897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56897, CurrentID=0, Status='live', Symbol='WRNIP1', Aliases=['CFAP93', 'FAP93', 'WHIP', 'bA420G6.2'], description='WRN helicase interacting protein 1', other_designations='ATPase WRNIP1|Werner helicase interacting protein 1|putative helicase RUVBL', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2765341, end_position_on_the_genomic_accession=2786952, orientation='plus', exon_count=8, OMIM=[608196], no_hdr0=''),
    56898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56898, CurrentID=0, Status='live', Symbol='BDH2', Aliases=['DHRS6', 'EFA6R', 'PRO20933', 'SDR15C1', 'UCPA-OR', 'UNQ6308'], description='3-hydroxybutyrate dehydrogenase 2', other_designations='3-hydroxybutyrate dehydrogenase type 2|3-hydroxybutyrate dehydrogenase, type 2|R-beta-hydroxybutyrate dehydrogenase|dehydrogenase/reductase SDR family member 6|oxidoreductase UCPA|short chain dehydrogenase/reductase family 15C member 1', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=103077592, end_position_on_the_genomic_accession=103099862, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    56899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56899, CurrentID=0, Status='live', Symbol='ANKS1B', Aliases=['AIDA', 'AIDA-1', 'ANKS2', 'EB-1', 'EB1', 'cajalin-2'], description='ankyrin repeat and sterile alpha motif domain containing 1B', other_designations='ankyrin repeat and sterile alpha motif domain-containing protein 1B|E2a-Pbx1-associated protein|amyloid-beta precursor protein intracellular domain associated protein 1|cajalin 2', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=98729904, end_position_on_the_genomic_accession=99984936, orientation='minus', exon_count=40, OMIM=[607815], no_hdr0=''),
    56900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56900, CurrentID=0, Status='live', Symbol='TMEM167B', Aliases=['AD-020', 'C1orf119'], description='transmembrane protein 167B', other_designations='protein kish-B', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109090764, end_position_on_the_genomic_accession=109096934, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    56901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56901, CurrentID=0, Status='live', Symbol='NDUFA4L2', Aliases=['COXFA4L2', 'MISTRH', 'NUOMS'], description='NDUFA4 mitochondrial complex associated like 2', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 4-like 2|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 4-like 2|NADH:ubiquinone oxidoreductase MLRQ subunit homolog|cytochrome c oxidase subunit FA4 like 2|mitochondrial stress response hypoxia', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57234903, end_position_on_the_genomic_accession=57240762, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    56902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56902, CurrentID=0, Status='live', Symbol='PNO1', Aliases=['KHRBP1', 'RRP20'], description='partner of NOB1 homolog', other_designations='RNA-binding protein PNO1|KH-type RNA-binding protein 1|RNA binding protein', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68157888, end_position_on_the_genomic_accession=68176238, orientation='plus', exon_count=8, OMIM=[618710], no_hdr0=''),
    56903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56903, CurrentID=0, Status='live', Symbol='PAPOLB', Aliases=['PAPT', 'TPAP'], description='poly(A) polymerase beta', other_designations='poly(A) polymerase beta|PAP-beta|poly(A) polymerase beta (testis specific)|polynucleotide adenylyltransferase beta|testis-specific poly(A) polymerase', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=4857738, end_position_on_the_genomic_accession=4862030, orientation='minus', exon_count=1, OMIM=[607436], no_hdr0=''),
    56904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56904, CurrentID=0, Status='live', Symbol='SH3GLB2', Aliases=['PP6569', 'PP9455', 'RRIG1'], description='SH3 domain containing GRB2 like, endophilin B2', other_designations='endophilin-B2|SH3 domain-containing GRB2-like protein B2|SH3-containing protein SH3GLB2|SH3-domain GRB2-like endophilin B2|retinoid receptor-induced gene 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129007036, end_position_on_the_genomic_accession=129028331, orientation='minus', exon_count=13, OMIM=[609288], no_hdr0=''),
    56905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56905, CurrentID=0, Status='live', Symbol='C15orf39', Aliases=[], description='chromosome 15 open reading frame 39', other_designations='uncharacterized protein C15orf39', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75201882, end_position_on_the_genomic_accession=75212169, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    56906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56906, CurrentID=0, Status='live', Symbol='THAP10', Aliases=[], description='THAP domain containing 10', other_designations='THAP domain-containing protein 10', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=70881342, end_position_on_the_genomic_accession=70892433, orientation='minus', exon_count=3, OMIM=[612538], no_hdr0=''),
    56907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56907, CurrentID=0, Status='live', Symbol='SPIRE1', Aliases=['Spir-1'], description='spire type actin nucleation factor 1', other_designations='protein spire homolog 1|spire actin nucleation factor 1|spire family actin nucleation factor 1|spire homolog 1', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12446512, end_position_on_the_genomic_accession=12662091, orientation='minus', exon_count=24, OMIM=[609216], no_hdr0=''),
    56910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56910, CurrentID=0, Status='live', Symbol='STARD7', Aliases=['FAME2', 'GTT1'], description='StAR related lipid transfer domain containing 7', other_designations='stAR-related lipid transfer protein 7, mitochondrial|START domain containing 7|START domain-containing protein 7|StAR-related lipid transfer (START) domain containing 7|gestational trophoblastic tumor protein 1', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96184859, end_position_on_the_genomic_accession=96208827, orientation='minus', exon_count=8, OMIM=[616712], no_hdr0=''),
    56911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56911, CurrentID=0, Status='live', Symbol='MAP3K7CL', Aliases=['C21orf7', 'HC21ORF7', 'TAK1L', 'TAKL', 'TAKL-1', 'TAKL-2', 'TAKL-4'], description='MAP3K7 C-terminal like', other_designations='MAP3K7 C-terminal-like protein|TAK1-like protein 1|TAK1-like protein 2|TAK1-like protein 4|TGF-beta activated kinase', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=29077114, end_position_on_the_genomic_accession=29175887, orientation='plus', exon_count=18, OMIM=[611110], no_hdr0=''),
    56912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56912, CurrentID=0, Status='live', Symbol='IFT46', Aliases=['C11orf2', 'C11orf60', 'CFAP32'], description='intraflagellar transport 46', other_designations='intraflagellar transport protein 46 homolog|UPF0360|cilia and flagella associated protein 32|intraflagellar transport 46 homolog|intraflagellar transport protein IFT46', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118544536, end_position_on_the_genomic_accession=118576456, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    56913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56913, CurrentID=0, Status='live', Symbol='C1GALT1', Aliases=['C1GALT', 'T-synthase'], description='core 1 synthase, glycoprotein-N-acetylgalactosamine 3-beta-galactosyltransferase 1', other_designations='glycoprotein-N-acetylgalactosamine 3-beta-galactosyltransferase 1|B3Gal-T8|core 1 O-glycan T-synthase|core 1 UDP-galactose:N-acetylgalactosamine-alpha-R beta 1,3-galactosyltransferase 1|core 1 beta3-Gal-T1|epididymis secretory sperm binding protein', map_location='7p22.1-p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7182544, end_position_on_the_genomic_accession=7248616, orientation='plus', exon_count=12, OMIM=[610555], no_hdr0=''),
    56914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56914, CurrentID=0, Status='live', Symbol='OTOR', Aliases=['FDP', 'MIAL1'], description='otoraplin', other_designations='otoraplin|fibrocyte-derived protein|melanoma inhibitory activity-like protein', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=16748358, end_position_on_the_genomic_accession=16752164, orientation='plus', exon_count=4, OMIM=[606067], no_hdr0=''),
    56915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56915, CurrentID=0, Status='live', Symbol='EXOSC5', Aliases=['RRP41B', 'RRP46', 'Rrp46p', 'hRrp46p', 'p12B'], description='exosome component 5', other_designations='exosome complex component RRP46|chronic myelogenous leukemia tumor antigen 28|exosome complex exonuclease RRP46|exosome component Rrp46|ribosomal RNA-processing protein 46', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41386374, end_position_on_the_genomic_accession=41397359, orientation='minus', exon_count=6, OMIM=[606492], no_hdr0=''),
    56916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56916, CurrentID=0, Status='live', Symbol='SMARCAD1', Aliases=['ADERM', 'BASNS', 'ETL1', 'HEL1', 'HRZ'], description='SWI/SNF-related, matrix-associated actin-dependent regulator of chromatin, subfamily a, containing DEAD/H box 1', other_designations='SWI/SNF-related matrix-associated actin-dependent regulator of chromatin subfamily A containing DEAD/H box 1|ATP-dependent helicase 1', map_location='4q22.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=94207608, end_position_on_the_genomic_accession=94291292, orientation='plus', exon_count=30, OMIM=[612761], no_hdr0=''),
    56917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56917, CurrentID=0, Status='live', Symbol='MEIS3', Aliases=['MRG2'], description='Meis homeobox 3', other_designations='homeobox protein Meis3|Meis1, myeloid ecotropic viral integration site 1 homolog 3|meis1-related protein 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47403124, end_position_on_the_genomic_accession=47422233, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    56918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56918, CurrentID=0, Status='live', Symbol='C2orf83', Aliases=[], description='chromosome 2 open reading frame 83', other_designations='folate transporter-like protein C2orf83', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227610090, end_position_on_the_genomic_accession=227633320, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    56919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56919, CurrentID=0, Status='live', Symbol='DHX33', Aliases=['DDX33'], description='DEAH-box helicase 33', other_designations='ATP-dependent RNA helicase DHX33|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 33|DEAH (Asp-Glu-Ala-His) box polypeptide 33|DEAH box protein 33|putative ATP-dependent RNA helicase DHX33', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5440917, end_position_on_the_genomic_accession=5469055, orientation='minus', exon_count=12, OMIM=[614405], no_hdr0=''),
    56920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56920, CurrentID=0, Status='live', Symbol='SEMA3G', Aliases=['sem2'], description='semaphorin 3G', other_designations='semaphorin-3G|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3G|semaphorin sem2', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52433035, end_position_on_the_genomic_accession=52445113, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    56922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56922, CurrentID=0, Status='live', Symbol='MCCC1', Aliases=['MCC-B', 'MCCA', 'MCCCalpha'], description='methylcrotonyl-CoA carboxylase subunit 1', other_designations='methylcrotonoyl-CoA carboxylase subunit alpha, mitochondrial|3-methylcrotonyl-CoA carboxylase 1|3-methylcrotonyl-CoA carboxylase biotin-containing subunit|3-methylcrotonyl-CoA:carbon dioxide ligase subunit alpha|MCCase subunit alpha|methylcrotonoyl-CoA carboxylase 1 (alpha)|methylcrotonoyl-CoA carboxylase alpha|methylcrotonoyl-Coenzyme A carboxylase 1 (alpha)', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183015218, end_position_on_the_genomic_accession=183099587, orientation='minus', exon_count=22, OMIM=[609010], no_hdr0=''),
    56923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56923, CurrentID=0, Status='live', Symbol='NMUR2', Aliases=['FM-4', 'FM4', 'NMU-R2', 'NMU2R', 'TGR-1', 'TGR1'], description='neuromedin U receptor 2', other_designations='neuromedin-U receptor 2|G-protein coupled receptor FM-4|G-protein coupled receptor TGR-1|growth hormone secretagogue receptor family, member 4', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=152391546, end_position_on_the_genomic_accession=152405279, orientation='minus', exon_count=4, OMIM=[605108], no_hdr0=''),
    56924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56924, CurrentID=0, Status='live', Symbol='PAK6', Aliases=['PAK5'], description='p21 (RAC1) activated kinase 6', other_designations='serine/threonine-protein kinase PAK 6|p21 protein (Cdc42/Rac)-activated kinase 6|p21(CDKN1A)-activated kinase 6', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40239063, end_position_on_the_genomic_accession=40277487, orientation='plus', exon_count=12, OMIM=[608110], no_hdr0=''),
    56925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56925, CurrentID=0, Status='live', Symbol='LXN', Aliases=['ECI', 'TCI'], description='latexin', other_designations='latexin|MUM|endogenous carboxypeptidase inhibitor|tissue carboxypeptidase inhibitor', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158666414, end_position_on_the_genomic_accession=158672722, orientation='minus', exon_count=5, OMIM=[609305], no_hdr0=''),
    56926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56926, CurrentID=0, Status='live', Symbol='NCLN', Aliases=['NET59'], description='nicalin', other_designations='nicalin|nicalin homolog|nicastrin-like protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3185930, end_position_on_the_genomic_accession=3209575, orientation='plus', exon_count=15, OMIM=[609156], no_hdr0=''),
    56927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56927, CurrentID=0, Status='live', Symbol='GPR108', Aliases=['LUSTR2'], description='G protein-coupled receptor 108', other_designations='protein GPR108|lung seven transmembrane receptor 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6729914, end_position_on_the_genomic_accession=6737580, orientation='minus', exon_count=19, OMIM=[618491], no_hdr0=''),
    56928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56928, CurrentID=0, Status='live', Symbol='SPPL2B', Aliases=['IMP-4', 'IMP4', 'PSH4', 'PSL1'], description='signal peptide peptidase like 2B', other_designations='signal peptide peptidase-like 2B|SPP-like 2B|intramembrane protease 4|presenilin homologous protein 4|presenilin-like protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2328571, end_position_on_the_genomic_accession=2355095, orientation='plus', exon_count=16, OMIM=[608239], no_hdr0=''),
    56929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56929, CurrentID=0, Status='live', Symbol='FEM1C', Aliases=['EUROIMAGE686608', 'EUROIMAGE783647', 'FEM1A'], description='fem-1 homolog C', other_designations='protein fem-1 homolog C|FEM1-gamma', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115520908, end_position_on_the_genomic_accession=115544778, orientation='minus', exon_count=5, OMIM=[608767], no_hdr0=''),
    56931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56931, CurrentID=0, Status='live', Symbol='DUS3L', Aliases=['DUS3'], description='dihydrouridine synthase 3 like', other_designations='tRNA-dihydrouridine(47) synthase [NAD(P)(+)]-like', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5785136, end_position_on_the_genomic_accession=5791210, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    56934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56934, CurrentID=0, Status='live', Symbol='CA10', Aliases=['CA-RPX', 'CARPX', 'HUCEP-15'], description='carbonic anhydrase 10', other_designations='carbonic anhydrase-related protein 10|CA-RP X|CARP X|carbonic anhydrase X|carbonic anhydrase-related protein X|cerebral protein-15|epididymis secretory sperm binding protein', map_location='17q21.33-q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51630313, end_position_on_the_genomic_accession=52160023, orientation='minus', exon_count=12, OMIM=[604642], no_hdr0=''),
    56935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56935, CurrentID=0, Status='live', Symbol='SMCO4', Aliases=['C11orf75', 'FN5'], description='single-pass membrane protein with coiled-coil domains 4', other_designations='single-pass membrane and coiled-coil domain-containing protein 4|UPF0443 protein C11orf75', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93478472, end_position_on_the_genomic_accession=93553979, orientation='minus', exon_count=7, OMIM=[609477], no_hdr0=''),
    56936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56936, CurrentID=0, Status='live', Symbol='CCDC177', Aliases=['C14orf162', 'PLPL'], description='coiled-coil domain containing 177', other_designations='coiled-coil domain-containing protein 177|myelin proteolipid protein-like protein', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69569799, end_position_on_the_genomic_accession=69574871, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    56937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56937, CurrentID=0, Status='live', Symbol='PMEPA1', Aliases=['STAG1', 'TMEPAI'], description='prostate transmembrane protein, androgen induced 1', other_designations='protein TMEPAI|solid tumor-associated 1 protein|transmembrane, prostate androgen induced RNA', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57648396, end_position_on_the_genomic_accession=57711472, orientation='minus', exon_count=7, OMIM=[606564], no_hdr0=''),
    56938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56938, CurrentID=0, Status='live', Symbol='ARNTL2', Aliases=['BMAL2', 'CLIF', 'MOP9', 'PASD9', 'bHLHe6'], description='aryl hydrocarbon receptor nuclear translocator like 2', other_designations='aryl hydrocarbon receptor nuclear translocator-like protein 2|CYCLE-like factor|PAS domain-containing protein 9|basic-helix-loop-helix-PAS protein MOP9|brain and muscle ARNT-like 2|class E basic helix-loop-helix protein 6|member of PAS protein 9|transcription factor BMAL2', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27332836, end_position_on_the_genomic_accession=27425286, orientation='plus', exon_count=20, OMIM=[614517], no_hdr0=''),
    56940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56940, CurrentID=0, Status='live', Symbol='DUSP22', Aliases=['JKAP', 'JSP-1', 'JSP1', 'LMW-DSP2', 'LMWDSP2', 'MKP-x', 'MKPX', 'VHX'], description='dual specificity phosphatase 22', other_designations='dual specificity protein phosphatase 22|JNK-stimulating phosphatase 1|JNK-stimulatory phosphatase-1|MAP kinase phosphatase x|epididymis secretory sperm binding protein|homolog of mouse dual specificity phosphatase LMW-DSP2|low molecular weight dual specificity phosphatase 2|mitogen-activated protein kinase phosphatase x', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=292459, end_position_on_the_genomic_accession=351355, orientation='plus', exon_count=9, OMIM=[616778], no_hdr0=''),
    56941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56941, CurrentID=0, Status='live', Symbol='HMCES', Aliases=['C3orf37', 'DC12', 'SRAPD1'], description='5-hydroxymethylcytosine binding, ES cell specific', other_designations='abasic site processing protein HMCES|5-hydroxymethylcytosine (hmC) binding, ES cell-specific|ES cell-specific 5hmC-binding protein|SOS response associated peptidase domain containing 1|SRAP domain-containing protein 1|UPF0361 protein C3orf37|embryonic stem cell-specific 5-hydroxymethylcytosine-binding protein|peptidase HMCES|putative endonuclease HMCES|putative peptidase SRAPD1', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129278832, end_position_on_the_genomic_accession=129306186, orientation='plus', exon_count=8, OMIM=[618288], no_hdr0=''),
    56942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56942, CurrentID=0, Status='live', Symbol='CMC2', Aliases=['2310061C15Rik', 'C16orf61', 'DC13'], description='C-X9-C motif containing 2', other_designations='COX assembly mitochondrial protein 2 homolog|C-x(9)-C motif containing 2', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=80966448, end_position_on_the_genomic_accession=81007036, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    56943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56943, CurrentID=0, Status='live', Symbol='ENY2', Aliases=['DC6', 'Sus1', 'e(y)2'], description='ENY2 transcription and export complex 2 subunit', other_designations='transcription and mRNA export factor ENY2|enhancer of yellow 2 homolog|enhancer of yellow 2 transcription factor homolog', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109334347, end_position_on_the_genomic_accession=109345954, orientation='plus', exon_count=5, OMIM=[619015], no_hdr0=''),
    56944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56944, CurrentID=0, Status='live', Symbol='OLFML3', Aliases=['HNOEL-iso', 'OLF44'], description='olfactomedin like 3', other_designations='olfactomedin-like protein 3|olfactomedin, 44-kd', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113979474, end_position_on_the_genomic_accession=113982254, orientation='plus', exon_count=4, OMIM=[610088], no_hdr0=''),
    56945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56945, CurrentID=0, Status='live', Symbol='MRPS22', Aliases=['C3orf5', 'COXPD5', 'GIBT', 'GK002', 'MRP-S22', 'ODG7', 'RPMS22'], description='mitochondrial ribosomal protein S22', other_designations='28S ribosomal protein S22, mitochondrial|S22mt|mitochondrial small ribosomal subunit protein mS22', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139343994, end_position_on_the_genomic_accession=139357140, orientation='plus', exon_count=9, OMIM=[605810], no_hdr0=''),
    56946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56946, CurrentID=0, Status='live', Symbol='EMSY', Aliases=['C11orf30', 'GL002'], description='EMSY transcriptional repressor, BRCA2 interacting', other_designations='BRCA2-interacting transcriptional repressor EMSY|EMSY, BRCA2 interacting transcriptional repressor|protein EMSY', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76444928, end_position_on_the_genomic_accession=76553031, orientation='plus', exon_count=23, OMIM=[608574], no_hdr0=''),
    56947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56947, CurrentID=0, Status='live', Symbol='MFF', Aliases=['C2orf33', 'EMPF2', 'GL004'], description='mitochondrial fission factor', other_designations='mitochondrial fission factor', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227325233, end_position_on_the_genomic_accession=227357836, orientation='plus', exon_count=13, OMIM=[614785], no_hdr0=''),
    56948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56948, CurrentID=0, Status='live', Symbol='SDR39U1', Aliases=['C14orf124', 'HCDI'], description='short chain dehydrogenase/reductase family 39U member 1', other_designations='epimerase family protein SDR39U1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24439766, end_position_on_the_genomic_accession=24442843, orientation='minus', exon_count=8, OMIM=[616162], no_hdr0=''),
    56949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56949, CurrentID=0, Status='live', Symbol='XAB2', Aliases=['HCNP', 'HCRN', 'NTC90', 'SYF1'], description='XPA binding protein 2', other_designations='pre-mRNA-splicing factor SYF1|SYF1 homolog, RNA splicing factor|SYF1 pre-mRNA-splicing factor|crn-related protein kim1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7619525, end_position_on_the_genomic_accession=7629545, orientation='minus', exon_count=19, OMIM=[610850], no_hdr0=''),
    56950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56950, CurrentID=0, Status='live', Symbol='SMYD2', Aliases=['HSKM-B', 'KMT3C', 'ZMYND14'], description='SET and MYND domain containing 2', other_designations='N-lysine methyltransferase SMYD2|SET and MYND domain-containing protein 2|histone methyltransferase SMYD2|lysine N-methyltransferase 3C|zinc finger, MYND domain containing 14', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=214281159, end_position_on_the_genomic_accession=214337136, orientation='plus', exon_count=12, OMIM=[610663], no_hdr0=''),
    56951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56951, CurrentID=0, Status='live', Symbol='C5orf15', Aliases=['HTGN29', 'KCT2'], description='chromosome 5 open reading frame 15', other_designations='keratinocyte-associated transmembrane protein 2|keratinocytes associated transmembrane protein 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=133955510, end_position_on_the_genomic_accession=133968625, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    56952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56952, CurrentID=0, Status='live', Symbol='PRTFDC1', Aliases=['HHGP'], description='phosphoribosyl transferase domain containing 1', other_designations='phosphoribosyltransferase domain-containing protein 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=24848614, end_position_on_the_genomic_accession=24952606, orientation='minus', exon_count=9, OMIM=[610751], no_hdr0=''),
    56953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56953, CurrentID=0, Status='live', Symbol='NT5M', Aliases=['dNT-2', 'dNT2', 'mdN'], description="5',3'-nucleotidase, mitochondrial", other_designations="5'(3')-deoxyribonucleotidase, mitochondrial|5' nucleotidase, mitochondrial|5(3)-deoxyribonucleotidase|deoxy-5'-nucleotidase 2|mitochondrial 5' nucleotidase", map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17303373, end_position_on_the_genomic_accession=17347663, orientation='plus', exon_count=8, OMIM=[605292], no_hdr0=''),
    56954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56954, CurrentID=0, Status='live', Symbol='NIT2', Aliases=['HEL-S-8a'], description='nitrilase family member 2', other_designations='omega-amidase NIT2|Nit protein 2|epididymis secretory sperm binding protein Li 8a|nitrilase homolog 2', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100334757, end_position_on_the_genomic_accession=100361635, orientation='plus', exon_count=10, OMIM=[616769], no_hdr0=''),
    56955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56955, CurrentID=0, Status='live', Symbol='MEPE', Aliases=['OF45'], description='matrix extracellular phosphoglycoprotein', other_designations='matrix extracellular phosphoglycoprotein|matrix, extracellular phosphoglycoprotein with ASARM motif (bone)|osteoblast/osteocyte factor 45|osteoregulin', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87821398, end_position_on_the_genomic_accession=87846792, orientation='plus', exon_count=7, OMIM=[605912], no_hdr0=''),
    56956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56956, CurrentID=0, Status='live', Symbol='LHX9', Aliases=[], description='LIM homeobox 9', other_designations='LIM/homeobox protein Lhx9|LIM homeobox protein 9', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197912464, end_position_on_the_genomic_accession=197935478, orientation='plus', exon_count=9, OMIM=[606066], no_hdr0=''),
    56957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56957, CurrentID=0, Status='live', Symbol='OTUD7B', Aliases=['CEZANNE', 'ZA20D1'], description='OTU deubiquitinase 7B', other_designations='OTU domain-containing protein 7B|OTU domain containing 7B|cellular zinc finger anti-NF-kappa-B protein|cellular zinc finger anti-NF-kappaB Cezanne|zinc finger A20 domain-containing protein 1|zinc finger protein Cezanne|zinc finger, A20 domain containing 1', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149937812, end_position_on_the_genomic_accession=150010776, orientation='minus', exon_count=14, OMIM=[611748], no_hdr0=''),
    56961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56961, CurrentID=0, Status='live', Symbol='SHD', Aliases=[], description='Src homology 2 domain containing transforming protein D', other_designations='SH2 domain-containing adapter protein D|src homology 2 domain-containing transforming protein D', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4279069, end_position_on_the_genomic_accession=4290722, orientation='plus', exon_count=7, OMIM=[610481], no_hdr0=''),
    56963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56963, CurrentID=0, Status='live', Symbol='RGMA', Aliases=['RGM'], description='repulsive guidance molecule BMP co-receptor a', other_designations='repulsive guidance molecule A|RGM domain family, member A|repulsive guidance molecule family member a', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=93035271, end_position_on_the_genomic_accession=93089211, orientation='minus', exon_count=7, OMIM=[607362], no_hdr0=''),
    56964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56964, CurrentID=0, Status='live', Symbol='WDR93', Aliases=['C1d-87', 'CFAP297', 'FAP297'], description='WD repeat domain 93', other_designations='WD repeat-containing protein 93', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89690074, end_position_on_the_genomic_accession=89744390, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    56965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56965, CurrentID=0, Status='live', Symbol='PARP6', Aliases=['ARTD17', 'PARP-6-B1', 'PARP-6-C', 'pART17'], description='poly(ADP-ribose) polymerase family member 6', other_designations='protein mono-ADP-ribosyltransferase PARP6|ADP-ribosyltransferase diphtheria toxin-like 17|PARP-6|poly [ADP-ribose] polymerase 6', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72241181, end_position_on_the_genomic_accession=72272554, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    56967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56967, CurrentID=0, Status='live', Symbol='C14orf132', Aliases=['C14orf88'], description='chromosome 14 open reading frame 132', other_designations='uncharacterized protein C14orf132', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96039362, end_position_on_the_genomic_accession=96093971, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    56970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56970, CurrentID=0, Status='live', Symbol='ATXN7L3', Aliases=['SGF11'], description='ataxin 7 like 3', other_designations='ataxin-7-like protein 3', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44191805, end_position_on_the_genomic_accession=44199884, orientation='minus', exon_count=14, OMIM=[619010], no_hdr0=''),
    56971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56971, CurrentID=0, Status='live', Symbol='CEACAM19', Aliases=['CEACM19', 'CEAL1'], description='CEA cell adhesion molecule 19', other_designations='carcinoembryonic antigen-related cell adhesion molecule 19|carcinoembryonic antigen related cell adhesion molecule 19|carcinoembryonic antigen-like 1', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44665860, end_position_on_the_genomic_accession=44684355, orientation='plus', exon_count=9, OMIM=[606691], no_hdr0=''),
    56975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56975, CurrentID=0, Status='live', Symbol='FAM20C', Aliases=['DMP-4', 'DMP4', 'G-CK', 'GEF-CK', 'RNS'], description='FAM20C golgi associated secretory pathway kinase', other_designations='extracellular serine/threonine protein kinase FAM20C|Golgi casein kinase|dentin matrix protein 4|family with sequence similarity 20, member C|golgi-enriched fraction casein kinase', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=192571, end_position_on_the_genomic_accession=260772, orientation='plus', exon_count=14, OMIM=[611061], no_hdr0=''),
    56977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56977, CurrentID=0, Status='live', Symbol='STOX2', Aliases=[], description='storkhead box 2', other_designations='storkhead-box protein 2', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183796331, end_position_on_the_genomic_accession=184023530, orientation='plus', exon_count=11, OMIM=[617359], no_hdr0=''),
    56978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56978, CurrentID=0, Status='live', Symbol='PRDM8', Aliases=['EPM10', 'KMT8D', 'PFM5'], description='PR/SET domain 8', other_designations='PR domain zinc finger protein 8|PR domain 8|PR-domain containing protein 8', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=80183418, end_position_on_the_genomic_accession=80204329, orientation='plus', exon_count=13, OMIM=[616639], no_hdr0=''),
    56979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56979, CurrentID=0, Status='live', Symbol='PRDM9', Aliases=['KMT8B', 'MEISETZ', 'MSBP3', 'PFM6', 'ZNF899'], description='PR/SET domain 9', other_designations='histone-lysine N-methyltransferase PRDM9|PR domain 9|PR domain containing 9|PR domain zinc finger protein 9|[histone H3]-lysine36 N-trimethyltransferase PRDM9|[histone H3]-lysine4 N-trimethyltransferase PRDM9|[histone H3]-lysine9 N-trimethyltransferase PRDM9|[histone H4]-N-methyl-L-lysine20 N-methyltransferase PRDM9|[histone H4]-lysine20 N-methyltransferase PRDM9|histone methyl transferase|minisatellite binding protein 3 (115kD)|protein-lysine N-methyltransferase PRDM9', map_location='5p14.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=23507155, end_position_on_the_genomic_accession=23528093, orientation='plus', exon_count=12, OMIM=[609760], no_hdr0=''),
    56980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56980, CurrentID=0, Status='live', Symbol='PRDM10', Aliases=['PFM7', 'TRIS'], description='PR/SET domain 10', other_designations='PR domain zinc finger protein 10|PR domain 10|PR domain containing 10|PR domain-containing protein 10|PR-domain family member 7|PRDM zinc finger transcription factor|tristanin', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=129899711, end_position_on_the_genomic_accession=130003097, orientation='minus', exon_count=24, OMIM=[618319], no_hdr0=''),
    56981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56981, CurrentID=0, Status='live', Symbol='PRDM11', Aliases=['PFM8'], description='PR/SET domain 11', other_designations='PR domain-containing protein 11|PR-domain containing protein 11', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45094159, end_position_on_the_genomic_accession=45235114, orientation='plus', exon_count=15, OMIM=[616347], no_hdr0=''),
    56983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56983, CurrentID=0, Status='live', Symbol='POGLUT1', Aliases=['C3orf9', 'CLP46', 'KDELCL1', 'KTELC1', 'LGMD2Z', 'LGMDR21', 'MDS010', 'MDSRP', 'Rumi', 'hCLP46'], description='protein O-glucosyltransferase 1', other_designations='protein O-glucosyltransferase 1|9630046K23Rik|CAP10-like 46 kDa protein|KDELC family like 1|KTEL (Lys-Tyr-Glu-Leu) containing 1|KTEL motif-containing protein 1|O-glucosyltransferase Rumi homolog|hRumi|myelodysplastic syndromes relative protein|protein O-xylosyltransferase POGLUT1|x 010 protein', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119468955, end_position_on_the_genomic_accession=119494708, orientation='plus', exon_count=13, OMIM=[615618], no_hdr0=''),
    56984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56984, CurrentID=0, Status='live', Symbol='PSMG2', Aliases=['CLAST3', 'HCCA3', 'HsT1707', 'MDS003', 'PAC2', 'PRAAS4', 'TNFSF5IP1'], description='proteasome assembly chaperone 2', other_designations='proteasome assembly chaperone 2|CD40 ligand-activated specific transcript 3|HDCMC29P|HSPC260|PAC-2|hepatocellular carcinoma susceptibility protein|hepatocellular carcinoma-susceptibility protein 3|likely ortholog of mouse CD40 ligand-activated specific transcript 3 (Clast3)|proteasome (prosome, macropain) assembly chaperone 2|proteasome assembling chaperone 2|tumor necrosis factor superfamily member 5-induced protein 1|x 003 protein', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12658738, end_position_on_the_genomic_accession=12725740, orientation='plus', exon_count=8, OMIM=[609702], no_hdr0=''),
    56985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56985, CurrentID=0, Status='live', Symbol='ADPRM', Aliases=['C17orf48', 'MDS006', 'NBLA03831'], description='ADP-ribose/CDP-alcohol diphosphatase, manganese dependent', other_designations='manganese-dependent ADP-ribose/CDP-alcohol diphosphatase|ADP-ribose/CDP-alcohol pyrophosphatase|ADPRibase-Mn|CDP-choline phosphohydrolase', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10697594, end_position_on_the_genomic_accession=10711558, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    56986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56986, CurrentID=0, Status='live', Symbol='DTWD1', Aliases=['MDS009'], description='DTW domain containing 1', other_designations='tRNA-uridine aminocarboxypropyltransferase 1|DTW domain-containing protein 1|x 009 protein', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49621022, end_position_on_the_genomic_accession=49656232, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    56987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56987, CurrentID=0, Status='live', Symbol='BBX', Aliases=['ARTC1', 'HBP2', 'HSPC339', 'MDS001'], description='BBX high mobility group box domain containing', other_designations='HMG box transcription factor BBX|Ag recognized by Treg cells 1|BBX, HMG-box containing|HMG box-containing protein 2|bobby sox homolog|x 001 protein', map_location='3q13.12', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=107522962, end_position_on_the_genomic_accession=107811339, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    56990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56990, CurrentID=0, Status='live', Symbol='CDC42SE2', Aliases=['SPEC2'], description='CDC42 small effector 2', other_designations='CDC42 small effector protein 2|non-kinase Cdc42 effector protein SPEC2|small effector of CDC42 protein 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131264053, end_position_on_the_genomic_accession=131394672, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    56992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56992, CurrentID=0, Status='live', Symbol='KIF15', Aliases=['HKLP2', 'KLP2', 'KNSL7', 'NY-BR-62'], description='kinesin family member 15', other_designations='kinesin-like protein KIF15|kinesin-like 7|kinesin-like protein 2|kinesin-like protein 7|serologically defined breast cancer antigen NY-BR-62', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44761740, end_position_on_the_genomic_accession=44853274, orientation='plus', exon_count=40, OMIM=[617569], no_hdr0=''),
    56993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56993, CurrentID=0, Status='live', Symbol='TOMM22', Aliases=['1C9-2', 'MST065', 'MSTP065', 'TOM22'], description='translocase of outer mitochondrial membrane 22', other_designations='mitochondrial import receptor subunit TOM22 homolog|mitochondrial import receptor Tom22|translocase of outer membrane 22 kDa subunit homolog|translocase of outer mitochondrial membrane 22 homolog', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38681957, end_position_on_the_genomic_accession=38685421, orientation='plus', exon_count=4, OMIM=[607046], no_hdr0=''),
    56994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56994, CurrentID=0, Status='live', Symbol='CHPT1', Aliases=['CPT', 'CPT1'], description='choline phosphotransferase 1', other_designations='cholinephosphotransferase 1|AAPT1-like protein|cholinephosphotransferase 1 alpha|diacylglycerol cholinephosphotransferase 1|hCPT1|phosphatidylcholine synthesizing enzyme', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101697640, end_position_on_the_genomic_accession=101752038, orientation='plus', exon_count=14, OMIM=[616747], no_hdr0=''),
    56995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56995, CurrentID=0, Status='live', Symbol='TULP4', Aliases=['TUSP'], description='TUB like protein 4', other_designations='tubby-related protein 4|tubby like protein 4|tubby super-family protein|tubby superfamily protein', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158232236, end_position_on_the_genomic_accession=158511828, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    56996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56996, CurrentID=0, Status='live', Symbol='SLC12A9', Aliases=['CCC6', 'CIP1', 'WO3.3', 'hCCC6'], description='solute carrier family 12 member 9', other_designations='solute carrier family 12 member 9|CCC-interacting protein 1|cation-chloride cotransporter 6|cation-chloride cotransporter-interacting protein 1|potassium-chloride transporter 9|solute carrier family 12 (potassium/chloride transporters), member 9', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100826869, end_position_on_the_genomic_accession=100867012, orientation='plus', exon_count=16, OMIM=[616861], no_hdr0=''),
    56997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56997, CurrentID=0, Status='live', Symbol='COQ8A', Aliases=['ADCK3', 'ARCA2', 'CABC1', 'COQ10D4', 'COQ8', 'SCAR9'], description='coenzyme Q8A', other_designations='atypical kinase COQ8A, mitochondrial|aarF domain-containing protein kinase 3|atypical kinase ADCK3, mitochondrial|chaperone activity of bc1 complex-like, mitochondrial|chaperone, ABC1 activity of bc1 complex homolog|coenzyme Q protein 8A|coenzyme Q8 homolog', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226939339, end_position_on_the_genomic_accession=226987544, orientation='plus', exon_count=20, OMIM=[606980], no_hdr0=''),
    56998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56998, CurrentID=0, Status='live', Symbol='CTNNBIP1', Aliases=['ICAT'], description='catenin beta interacting protein 1', other_designations='beta-catenin-interacting protein 1|beta-catenin-interacting protein ICAT|inhibitor of beta-catenin and Tcf-4', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9848276, end_position_on_the_genomic_accession=9910322, orientation='minus', exon_count=8, OMIM=[607758], no_hdr0=''),
    56999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=56999, CurrentID=0, Status='live', Symbol='ADAMTS9', Aliases=[], description='ADAM metallopeptidase with thrombospondin type 1 motif 9', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 9|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 9', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=64515654, end_position_on_the_genomic_accession=64688000, orientation='minus', exon_count=41, OMIM=[605421], no_hdr0=''),
    57001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57001, CurrentID=0, Status='live', Symbol='SDHAF3', Aliases=['ACN9', 'DC11', 'LYRM10', 'Sdh7'], description='succinate dehydrogenase complex assembly factor 3', other_designations='succinate dehydrogenase assembly factor 3, mitochondrial|ACN9 homolog|SDH assembly factor 3|protein ACN9 homolog, mitochondrial', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=97117698, end_position_on_the_genomic_accession=97181763, orientation='plus', exon_count=2, OMIM=[615773], no_hdr0=''),
    57002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57002, CurrentID=0, Status='live', Symbol='YAE1', Aliases=['C7orf36', 'CIAB2', 'GK003D1', 'YAE1'], description='YAE1 maturation factor of ABCE1', other_designations='protein YAE1 homolog|YAE1, ABCE1 maturation factor|Yae1 domain containing 1|yae1 domain-containing protein 1', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=39566404, end_position_on_the_genomic_accession=39612089, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    57003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57003, CurrentID=0, Status='live', Symbol='CCDC47', Aliases=['GK001', 'MSTP041', 'THNS'], description='coiled-coil domain containing 47', other_designations='PAT complex subunit CCDC47|Calumin|coiled-coil domain-containing protein 47', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63745255, end_position_on_the_genomic_accession=63773597, orientation='minus', exon_count=14, OMIM=[618260], no_hdr0=''),
    57007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57007, CurrentID=0, Status='live', Symbol='ACKR3', Aliases=['CMKOR1', 'CXC-R7', 'CXCR-7', 'CXCR7', 'GPR159', 'RDC-1', 'RDC1'], description='atypical chemokine receptor 3', other_designations='atypical chemokine receptor 3|C-X-C chemokine receptor type 7|G protein-coupled receptor|G-protein coupled receptor 159|G-protein coupled receptor RDC1 homolog|chemokine (C-X-C motif) receptor 7|chemokine orphan receptor 1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=236537131, end_position_on_the_genomic_accession=236582358, orientation='plus', exon_count=6, OMIM=[610376], no_hdr0=''),
    57010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57010, CurrentID=0, Status='live', Symbol='CABP4', Aliases=['CRSD', 'CSNB2B'], description='calcium binding protein 4', other_designations='calcium-binding protein 4', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67452403, end_position_on_the_genomic_accession=67461774, orientation='plus', exon_count=9, OMIM=[608965], no_hdr0=''),
    57016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57016, CurrentID=0, Status='live', Symbol='AKR1B10', Aliases=['AKR1B11', 'AKR1B12', 'ALDRLn', 'ARL-1', 'ARL1', 'HIS', 'HSI'], description='aldo-keto reductase family 1 member B10', other_designations='aldo-keto reductase family 1 member B10|ARP|SI reductase|aldo-keto reductase family 1, member B10 (aldose reductase)|aldo-keto reductase family 1, member B11 (aldose reductase-like)|aldose reductase-like 1|aldose reductase-like peptide|aldose reductase-related protein|hARP|small intestine reductase', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134527567, end_position_on_the_genomic_accession=134541412, orientation='plus', exon_count=11, OMIM=[604707], no_hdr0=''),
    57017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57017, CurrentID=0, Status='live', Symbol='COQ9', Aliases=['C16orf49', 'COQ10D5'], description='coenzyme Q9', other_designations='ubiquinone biosynthesis protein COQ9, mitochondrial|coenzyme Q9 homolog', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57447479, end_position_on_the_genomic_accession=57461270, orientation='plus', exon_count=9, OMIM=[612837], no_hdr0=''),
    57018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57018, CurrentID=0, Status='live', Symbol='CCNL1', Aliases=['ANIA6A', 'BM-001', 'PRO1073', 'ania-6a'], description='cyclin L1', other_designations='cyclin-L1|cyclin L ania-6a|cyclin L gamma|cyclin-L', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=157143121, end_position_on_the_genomic_accession=157160180, orientation='minus', exon_count=13, OMIM=[613384], no_hdr0=''),
    57019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57019, CurrentID=0, Status='live', Symbol='CIAPIN1', Aliases=['Anamorsin', 'CIAE2', 'DRE2', 'PRO0915'], description='cytokine induced apoptosis inhibitor 1', other_designations='anamorsin|fe-S cluster assembly protein DRE2 homolog|predicted protein of HQ0915', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57428187, end_position_on_the_genomic_accession=57447385, orientation='minus', exon_count=9, OMIM=[608943], no_hdr0=''),
    57020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57020, CurrentID=0, Status='live', Symbol='VPS35L', Aliases=['C16orf62', 'EC97', 'RTSC3'], description='VPS35 endosomal protein sorting factor like', other_designations='VPS35 endosomal protein-sorting factor-like|UPF0505 protein C16orf62|esophageal cancer associated protein', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19555703, end_position_on_the_genomic_accession=19701163, orientation='plus', exon_count=33, OMIM=[618981], no_hdr0=''),
    57026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57026, CurrentID=0, Status='live', Symbol='PDXP', Aliases=['CIN', 'PLP', 'dJ37E16.5'], description='pyridoxal phosphatase', other_designations='chronophin|PLP phosphatase|pyridoxal (pyridoxine, vitamin B6) phosphatase|pyridoxal phosphate phosphatase|testicular secretory protein Li 36', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37658723, end_position_on_the_genomic_accession=37666932, orientation='plus', exon_count=2, OMIM=[609246], no_hdr0=''),
    57030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57030, CurrentID=0, Status='live', Symbol='SLC17A7', Aliases=['BNPI', 'VGLUT1'], description='solute carrier family 17 member 7', other_designations='vesicular glutamate transporter 1|brain-specific Na(+)-dependent inorganic phosphate cotransporter|brain-specific Na-dependent inorganic phosphate cotransporter|solute carrier family 17 (sodium-dependent inorganic phosphate cotransporter), member 7|solute carrier family 17 (vesicular glutamate transporter), member 7', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49429401, end_position_on_the_genomic_accession=49441527, orientation='minus', exon_count=12, OMIM=[605208], no_hdr0=''),
    57035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57035, CurrentID=0, Status='live', Symbol='RSRP1', Aliases=['C1orf63', 'NPD014'], description='arginine and serine rich protein 1', other_designations='arginine/serine-rich protein 1|UPF0471 protein C1orf63', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25242249, end_position_on_the_genomic_accession=25338254, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    57037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57037, CurrentID=0, Status='live', Symbol='ANKMY2', Aliases=['ZMYND20'], description='ankyrin repeat and MYND domain containing 2', other_designations='ankyrin repeat and MYND domain-containing protein 2', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16599779, end_position_on_the_genomic_accession=16645816, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    57038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57038, CurrentID=0, Status='live', Symbol='RARS2', Aliases=['ArgRS', 'DALRD2', 'PCH6', 'PRO1992', 'RARSL'], description='arginyl-tRNA synthetase 2, mitochondrial', other_designations='probable arginine--tRNA ligase, mitochondrial|probable arginyl-tRNA synthetase, mitochondrial', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87513938, end_position_on_the_genomic_accession=87589996, orientation='minus', exon_count=26, OMIM=[611524], no_hdr0=''),
    57045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57045, CurrentID=0, Status='live', Symbol='TWSG1', Aliases=['TSG'], description='twisted gastrulation BMP signaling modulator 1', other_designations='twisted gastrulation protein homolog 1|twisted gastrulation homolog 1', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9334773, end_position_on_the_genomic_accession=9402420, orientation='plus', exon_count=5, OMIM=[605049], no_hdr0=''),
    57046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57046, CurrentID=0, Status='live', Symbol='HRES2', Aliases=[], description='HTLV-1 related endogenous sequence 2', other_designations='HTLV-1 related endogenous sequence 2', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    57047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57047, CurrentID=0, Status='live', Symbol='PLSCR2', Aliases=[], description='phospholipid scramblase 2', other_designations='phospholipid scramblase 2|PL scramblase 2|ca(2+)-dependent phospholipid scramblase 2', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=146391363, end_position_on_the_genomic_accession=146497163, orientation='minus', exon_count=25, OMIM=[607610], no_hdr0=''),
    57048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57048, CurrentID=0, Status='live', Symbol='PLSCR3', Aliases=[], description='phospholipid scramblase 3', other_designations='phospholipid scramblase 3|PL scramblase 3|ca(2+)-dependent phospholipid scramblase 3', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7389727, end_position_on_the_genomic_accession=7394525, orientation='minus', exon_count=8, OMIM=[607611], no_hdr0=''),
    57050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57050, CurrentID=0, Status='live', Symbol='UTP3', Aliases=['CRL1', 'CRLZ1', 'SAS10'], description='UTP3 small subunit processome component', other_designations='something about silencing protein 10|UTP3 homolog|UTP3, small subunit processome component homolog|charged amino acid rich leucine zipper 1 homolog|charged amino acid-rich leucine zipper 1|disrupter of silencing 10|disrupter of silencing SAS10', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70688532, end_position_on_the_genomic_accession=70690551, orientation='plus', exon_count=1, OMIM=[611614], no_hdr0=''),
    57053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57053, CurrentID=0, Status='live', Symbol='CHRNA10', Aliases=[], description='cholinergic receptor nicotinic alpha 10 subunit', other_designations='neuronal acetylcholine receptor subunit alpha-10|NACHR alpha-10|acetylcholine receptor, nicotinic, alpha 10 (neuronal)|cholinergic receptor, nicotinic alpha 10|cholinergic receptor, nicotinic, alpha 10 (neuronal)|cholinergic receptor, nicotinic, alpha polypeptide 10|nicotinic acetylcholine receptor subunit alpha-10', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3665587, end_position_on_the_genomic_accession=3673629, orientation='minus', exon_count=4, OMIM=[606372], no_hdr0=''),
    57054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57054, CurrentID=0, Status='live', Symbol='DAZ3', Aliases=['pDP1679'], description='deleted in azoospermia 3', other_designations='deleted in azoospermia protein 3', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=24763069, end_position_on_the_genomic_accession=24813393, orientation='minus', exon_count=19, OMIM=[400027], no_hdr0=''),
    57055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57055, CurrentID=0, Status='live', Symbol='DAZ2', Aliases=['pDP1678'], description='deleted in azoospermia 2', other_designations='deleted in azoospermia protein 2', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=23219457, end_position_on_the_genomic_accession=23291356, orientation='plus', exon_count=28, OMIM=[400026], no_hdr0=''),
    57057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57057, CurrentID=0, Status='live', Symbol='TBX20', Aliases=['ASD4'], description='T-box transcription factor 20', other_designations='T-box transcription factor TBX20|T-box 20|T-box protein 20', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=35199936, end_position_on_the_genomic_accession=35254100, orientation='minus', exon_count=8, OMIM=[606061], no_hdr0=''),
    57060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57060, CurrentID=0, Status='live', Symbol='PCBP4', Aliases=['CBP', 'LIP4', 'MCG10'], description='poly(rC) binding protein 4', other_designations='poly(rC)-binding protein 4|LYST-interacting protein|RNA binding protein MCG10|alpha-CP4', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51957454, end_position_on_the_genomic_accession=51967466, orientation='minus', exon_count=15, OMIM=[608503], no_hdr0=''),
    57062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57062, CurrentID=0, Status='live', Symbol='DDX24', Aliases=[], description='DEAD-box helicase 24', other_designations='ATP-dependent RNA helicase DDX24|DEAD (Asp-Glu-Ala-Asp) box helicase 24|DEAD (Asp-Glu-Ala-Asp) box polypeptide 24|DEAD box protein 24|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 24|S. cerevisiae CHL1-like helicase', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94048287, end_position_on_the_genomic_accession=94081202, orientation='minus', exon_count=9, OMIM=[606181], no_hdr0=''),
    57082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57082, CurrentID=0, Status='live', Symbol='KNL1', Aliases=['AF15Q14', 'CASC5', 'CT29', 'D40', 'MCPH4', 'PPP1R55', 'Spc7', 'hKNL-1', 'hSpc105'], description='kinetochore scaffold 1', other_designations='kinetochore scaffold 1|ALL1-fused gene from chromosome 15q14 protein|blinkin, bub-linking kinetochore protein|cancer susceptibility candidate 5|cancer susceptibility candidate gene 5 protein|cancer/testis antigen 29|kinetochore null 1 homolog|kinetochore-null protein 1|microcephaly, primary autosomal recessive 4|protein phosphatase 1, regulatory subunit 55', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40594012, end_position_on_the_genomic_accession=40664342, orientation='plus', exon_count=27, OMIM=[609173], no_hdr0=''),
    57084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57084, CurrentID=0, Status='live', Symbol='SLC17A6', Aliases=['DNPI', 'VGLUT2'], description='solute carrier family 17 member 6', other_designations='vesicular glutamate transporter 2|differentiation-associated BNPI|differentiation-associated Na(+)-dependent inorganic phosphate cotransporter|differentiation-associated Na-dependent inorganic phosphate cotransporter|solute carrier family 17 (sodium-dependent inorganic phosphate cotransporter), member 6|solute carrier family 17 (vesicular glutamate transporter), member 6', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22338381, end_position_on_the_genomic_accession=22379503, orientation='plus', exon_count=12, OMIM=[607563], no_hdr0=''),
    57085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57085, CurrentID=0, Status='live', Symbol='AGTRAP', Aliases=['ATRAP'], description='angiotensin II receptor associated protein', other_designations='type-1 angiotensin II receptor-associated protein|AT1 receptor-associated protein|ATI receptor-associated protein|angiotensin II, type I receptor-associated protein', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11736121, end_position_on_the_genomic_accession=11750771, orientation='plus', exon_count=7, OMIM=[608729], no_hdr0=''),
    57088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57088, CurrentID=0, Status='live', Symbol='PLSCR4', Aliases=['TRA1'], description='phospholipid scramblase 4', other_designations='phospholipid scramblase 4|Ca(2+)-dependent phospholipid scramblase 4|PL scramblase 4|cell growth inhibiting protein 43', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=146192335, end_position_on_the_genomic_accession=146251125, orientation='minus', exon_count=12, OMIM=[607612], no_hdr0=''),
    57089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57089, CurrentID=0, Status='live', Symbol='ENTPD7', Aliases=['LALP1'], description='ectonucleoside triphosphate diphosphohydrolase 7', other_designations='ectonucleoside triphosphate diphosphohydrolase 7|NTPDase 7|lysosomal apyrase-like protein 1', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99659509, end_position_on_the_genomic_accession=99711241, orientation='plus', exon_count=15, OMIM=[616753], no_hdr0=''),
    57091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57091, CurrentID=0, Status='live', Symbol='CASS4', Aliases=['C20orf32', 'CAS4', 'HEFL', 'HEPL'], description='Cas scaffold protein family member 4', other_designations='cas scaffolding protein family member 4|HEF-like protein|HEF1-EFS-p130Cas-like protein', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56411550, end_position_on_the_genomic_accession=56460382, orientation='plus', exon_count=7, OMIM=[618888], no_hdr0=''),
    57092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57092, CurrentID=0, Status='live', Symbol='PCNP', Aliases=[], description='PEST proteolytic signal containing nuclear protein', other_designations='PEST proteolytic signal-containing nuclear protein|PEST-containing nuclear protein', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101574094, end_position_on_the_genomic_accession=101594465, orientation='plus', exon_count=7, OMIM=[615210], no_hdr0=''),
    57093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57093, CurrentID=0, Status='live', Symbol='TRIM49', Aliases=['RNF18A', 'TRIM49L2', 'TRIM49'], description='tripartite motif containing 49', other_designations='tripartite motif-containing protein 49|ring finger protein 18|testis-specific RING Finger protein|testis-specific ring-finger protein', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89766436, end_position_on_the_genomic_accession=89808575, orientation='minus', exon_count=11, OMIM=[606124], no_hdr0=''),
    57094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57094, CurrentID=0, Status='live', Symbol='CPA6', Aliases=['CPAH', 'ETL5', 'FEB11'], description='carboxypeptidase A6', other_designations='carboxypeptidase A6|carboxypeptidase B', map_location='8q13.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=67422038, end_position_on_the_genomic_accession=67747114, orientation='minus', exon_count=13, OMIM=[609562], no_hdr0=''),
    57095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57095, CurrentID=0, Status='live', Symbol='PITHD1', Aliases=['C1orf128', 'HT014', 'TXNL1CL'], description='PITH domain containing 1', other_designations='PITH domain-containing protein 1|PITH (C-terminal proteasome-interacting domain of thioredoxin-like) domain containing 1|TXNL1 C-terminal like', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23778417, end_position_on_the_genomic_accession=23788232, orientation='plus', exon_count=6, OMIM=[618784], no_hdr0=''),
    57096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57096, CurrentID=0, Status='live', Symbol='RPGRIP1', Aliases=['CORD13', 'LCA6', 'RGI1', 'RGRIP', 'RPGRIPd', 'RPGRIP1'], description='RPGR interacting protein 1', other_designations='X-linked retinitis pigmentosa GTPase regulator-interacting protein 1|retinitis pigmentosa GTPase regulator interacting protein 1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21280083, end_position_on_the_genomic_accession=21351316, orientation='plus', exon_count=26, OMIM=[605446], no_hdr0=''),
    57097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57097, CurrentID=0, Status='live', Symbol='PARP11', Aliases=['ARTD11', 'C12orf6', 'MIB006'], description='poly(ADP-ribose) polymerase family member 11', other_designations='protein mono-ADP-ribosyltransferase PARP11|ADP-ribosyltransferase diphtheria toxin-like 11|poly [ADP-ribose] polymerase 11', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=3808861, end_position_on_the_genomic_accession=3873471, orientation='minus', exon_count=12, OMIM=[616706], no_hdr0=''),
    57099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57099, CurrentID=0, Status='live', Symbol='AVEN', Aliases=['PDCD12'], description='apoptosis and caspase activation inhibitor', other_designations='cell death regulator Aven|apoptosis, caspase activation inhibitor|programmed cell death 12', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=33851785, end_position_on_the_genomic_accession=34074877, orientation='minus', exon_count=15, OMIM=[605265], no_hdr0=''),
    57101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57101, CurrentID=0, Status='live', Symbol='ANO2', Aliases=['C12orf3', 'TMEM16B'], description='anoctamin 2', other_designations='anoctamin-2|anoctamin 2, calcium activated chloride channel|transmembrane protein 16B (eight membrane-spanning domains)', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=5560241, end_position_on_the_genomic_accession=5948790, orientation='minus', exon_count=39, OMIM=[610109], no_hdr0=''),
    57102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57102, CurrentID=0, Status='live', Symbol='C12orf4', Aliases=[], description='chromosome 12 open reading frame 4', other_designations='protein C12orf4', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4487735, end_position_on_the_genomic_accession=4538508, orientation='minus', exon_count=15, OMIM=[616082], no_hdr0=''),
    57103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57103, CurrentID=0, Status='live', Symbol='TIGAR', Aliases=['C12orf5', 'FR2BP'], description='TP53 induced glycolysis regulatory phosphatase', other_designations='fructose-2,6-bisphosphatase TIGAR|TP53-induced glycolysis and apoptosis regulator|fructose-2,6-bisphosphate 2-phosphatase|probable fructose-2,6-bisphosphatase TIGAR|transactivated by NS3TP2 protein', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=4321213, end_position_on_the_genomic_accession=4360028, orientation='plus', exon_count=6, OMIM=[610775], no_hdr0=''),
    57104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57104, CurrentID=0, Status='live', Symbol='PNPLA2', Aliases=['1110001C14Rik', 'ATGL', 'FP17548', 'PEDF-R', 'TTS-2.2', 'TTS2', 'iPLA2zeta'], description='patatin like phospholipase domain containing 2', other_designations='patatin-like phospholipase domain-containing protein 2|IPLA2-zeta|TTS2.2|adipose triglyceride lipase|calcium-independent phospholipase A2|desnutrin|mutant patatin-like phospholipase domain containing 2|pigment epithelium-derived factor|transport-secretion protein 2.2|triglyceride hydrolase', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=818914, end_position_on_the_genomic_accession=825573, orientation='plus', exon_count=10, OMIM=[609059], no_hdr0=''),
    57105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57105, CurrentID=0, Status='live', Symbol='CYSLTR2', Aliases=['CYSLT2', 'CYSLT2R', 'GPCR21', 'HG57', 'HPN321', 'KPG_011', 'PSEC0146', 'hGPCR21'], description='cysteinyl leukotriene receptor 2', other_designations='cysteinyl leukotriene receptor 2|G-protein coupled receptor GPCR21|G-protein coupled receptor HG57|cysteinyl leukotriene CysLT2 receptor', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=48653929, end_position_on_the_genomic_accession=48711226, orientation='plus', exon_count=6, OMIM=[605666], no_hdr0=''),
    57106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57106, CurrentID=0, Status='live', Symbol='NAT14', Aliases=['KLP1'], description='N-acetyltransferase 14 (putative)', other_designations='N-acetyltransferase 14|K562 cell-derived leucine-zipper-like protein 1|K562 cells-derived leucine-zipper-like protein 1|N-acetyltransferase 14 (GCN5-related, putative)', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55485188, end_position_on_the_genomic_accession=55487566, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    57107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57107, CurrentID=0, Status='live', Symbol='PDSS2', Aliases=['C6orf210', 'COQ10D3', 'COQ1B', 'DLP1', 'bA59I9.3', 'hDLP1'], description='decaprenyl diphosphate synthase subunit 2', other_designations='all trans-polyprenyl-diphosphate synthase PDSS2|all-trans-decaprenyl-diphosphate synthase subunit 2|decaprenyl pyrophosphate synthase subunit 2|decaprenyl pyrophosphate synthetase subunit 2|prenyl (decaprenyl) diphosphate synthase, subunit 2|solanesyl-diphosphate synthase subunit 2|subunit 2 of decaprenyl diphosphate synthase', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107152557, end_position_on_the_genomic_accession=107459681, orientation='minus', exon_count=11, OMIM=[610564], no_hdr0=''),
    57109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57109, CurrentID=0, Status='live', Symbol='REXO4', Aliases=['REX4', 'XPMC2', 'XPMC2H'], description="REX4 homolog, 3'-5' exonuclease", other_designations='RNA exonuclease 4|REX4, RNA exonuclease 4 homolog|XPMC2 prevents mitotic catastrophe 2 homolog|Xenopus prevents mitotic catastrophe 2 homolog|exonuclease XPMC2', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133406058, end_position_on_the_genomic_accession=133418172, orientation='minus', exon_count=11, OMIM=[602930], no_hdr0=''),
    57110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57110, CurrentID=0, Status='live', Symbol='PLAAT1', Aliases=['A-C1', 'H-REV107', 'HRASLS', 'HRASLS1', 'HRSL1', 'HSD28', 'PLA/AT1', 'PLAAT-1'], description='phospholipase A and acyltransferase 1', other_designations='phospholipase A and acyltransferase 1|H-REV107 protein-related protein|HRAS like suppressor|HRAS-like suppressor 1|phospholipase A/acyltransferase 1|phospholipid-metabolizing enzyme A-C1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=193241128, end_position_on_the_genomic_accession=193281639, orientation='plus', exon_count=8, OMIM=[606487], no_hdr0=''),
    57111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57111, CurrentID=0, Status='live', Symbol='RAB25', Aliases=['CATX-8', 'RAB11C'], description='RAB25, member RAS oncogene family', other_designations='ras-related protein Rab-25', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156061160, end_position_on_the_genomic_accession=156070504, orientation='plus', exon_count=5, OMIM=[612942], no_hdr0=''),
    57113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57113, CurrentID=0, Status='live', Symbol='TRPC7', Aliases=['TRP7'], description='transient receptor potential cation channel subfamily C member 7', other_designations='short transient receptor potential channel 7|likley ortholog of mouse transient receptor potential cation channel, subfamily C, member 7|putative capacitative calcium channel|transient receptor protein 7', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=136212745, end_position_on_the_genomic_accession=136365545, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    57115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57115, CurrentID=0, Status='live', Symbol='PGLYRP4', Aliases=['PGLYRPIbeta', 'PGRP-Ibeta', 'PGRPIB', 'SBBI67'], description='peptidoglycan recognition protein 4', other_designations='peptidoglycan recognition protein 4|PGRP-I-beta|peptidoglycan recognition protein I-beta|peptidoglycan recognition protein intermediate beta', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153327410, end_position_on_the_genomic_accession=153348844, orientation='minus', exon_count=12, OMIM=[608198], no_hdr0=''),
    57116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57116, CurrentID=0, Status='live', Symbol='ZNF695', Aliases=['SBZF3'], description='zinc finger protein 695', other_designations='zinc finger protein 695|zinc finger protein SBZF3', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=246945546, end_position_on_the_genomic_accession=247008057, orientation='minus', exon_count=6, OMIM=[616348], no_hdr0=''),
    57117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57117, CurrentID=0, Status='live', Symbol='INTS12', Aliases=['INT12', 'PHF22', 'SBBI22'], description='integrator complex subunit 12', other_designations='integrator complex subunit 12|PHD finger protein 22|hypothetical nuclear factor SBBI22', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105682627, end_position_on_the_genomic_accession=105708725, orientation='minus', exon_count=10, OMIM=[611355], no_hdr0=''),
    57118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57118, CurrentID=0, Status='live', Symbol='CAMK1D', Aliases=['CKLiK', 'CaM-K1', 'CaMKID'], description='calcium/calmodulin dependent protein kinase ID', other_designations='calcium/calmodulin-dependent protein kinase type 1D|CAMK1D/ANAPC5 fusion|CaM kinase ID|CamKI-like protein kinase|caM kinase I delta|caM-KI delta|caMKI delta', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12349514, end_position_on_the_genomic_accession=12835545, orientation='plus', exon_count=18, OMIM=[607957], no_hdr0=''),
    57119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57119, CurrentID=0, Status='live', Symbol='EPPIN', Aliases=['CT71', 'CT72', 'SPINLW1', 'WAP7', 'WFDC7', 'dJ461P17.2'], description='epididymal peptidase inhibitor', other_designations='eppin|WAP four-disulfide core domain protein 7|cancer/testis antigen 71|cancer/testis antigen 72|epididymal protease inhibitor|epididymis secretory sperm binding protein|protease inhibitor WAP7|serine peptidase inhibitor-like, with Kunitz and WAP domains 1 (eppin)', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45540626, end_position_on_the_genomic_accession=45547401, orientation='minus', exon_count=4, OMIM=[609031], no_hdr0=''),
    57120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57120, CurrentID=0, Status='live', Symbol='GOPC', Aliases=['CAL', 'FIG1', 'PIST', 'dJ94G16.2', 'GOPC'], description='golgi associated PDZ and coiled-coil motif containing', other_designations='Golgi-associated PDZ and coiled-coil motif-containing protein|CFTR-associated ligand|PDZ protein interacting specifically with TC10|PDZ/coiled-coil domain binding partner for the rho-family GTPase TC10|dJ94G16.2 PIST|fused in glioblastoma|golgi-associated PDZ and coiled-coil motif containing protein', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117560269, end_position_on_the_genomic_accession=117602520, orientation='minus', exon_count=10, OMIM=[606845], no_hdr0=''),
    57121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57121, CurrentID=0, Status='live', Symbol='LPAR5', Aliases=['GPR92', 'GPR93', 'KPG_010', 'LPA5'], description='lysophosphatidic acid receptor 5', other_designations='lysophosphatidic acid receptor 5|G protein-coupled receptor 92|G-protein coupled receptor 93|LPA receptor 5|LPA-5', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6618835, end_position_on_the_genomic_accession=6635959, orientation='minus', exon_count=3, OMIM=[606926], no_hdr0=''),
    57122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57122, CurrentID=0, Status='live', Symbol='NUP107', Aliases=['NPHS11', 'NUP84', 'ODG6', 'ODG6; GAMOS7'], description='nucleoporin 107', other_designations='nuclear pore complex protein Nup107|nucleoporin 107kDa', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=68686971, end_position_on_the_genomic_accession=68745809, orientation='plus', exon_count=28, OMIM=[607617], no_hdr0=''),
    57124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57124, CurrentID=0, Status='live', Symbol='CD248', Aliases=['CD164L1', 'TEM1'], description='CD248 molecule', other_designations='endosialin|2610111G01Rik|CD164 sialomucin-like 1|CD248 antigen, endosialin|CD248 molecule, endosialin|tumor endothelial marker 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66314494, end_position_on_the_genomic_accession=66317044, orientation='minus', exon_count=1, OMIM=[606064], no_hdr0=''),
    57125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57125, CurrentID=0, Status='live', Symbol='PLXDC1', Aliases=['TEM3', 'TEM7'], description='plexin domain containing 1', other_designations='plexin domain-containing protein 1|2410003I07Rik|tumor endothelial marker 3|tumor endothelial marker 7', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39063313, end_position_on_the_genomic_accession=39151637, orientation='minus', exon_count=14, OMIM=[606826], no_hdr0=''),
    57126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57126, CurrentID=0, Status='live', Symbol='CD177', Aliases=['HNA-2a', 'HNA2A', 'NB1', 'NB1 GP', 'PRV-1', 'PRV1'], description='CD177 molecule', other_designations='CD177 antigen|NB1 glycoprotein|cell surface receptor|human neutrophil alloantigen 2a|polycythemia rubra vera protein 1', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43353686, end_position_on_the_genomic_accession=43366063, orientation='plus', exon_count=11, OMIM=[162860], no_hdr0=''),
    57127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57127, CurrentID=0, Status='live', Symbol='RHBG', Aliases=['SLC42A2'], description='Rh family B glycoprotein', other_designations='ammonium transporter Rh type B|Rhesus blood group, B glycoprotein', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156366044, end_position_on_the_genomic_accession=156385219, orientation='plus', exon_count=16, OMIM=[607079], no_hdr0=''),
    57128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57128, CurrentID=0, Status='live', Symbol='LYRM4', Aliases=['C6orf149', 'CGI-203', 'COXPD19', 'ISD11'], description='LYR motif containing 4', other_designations='LYR motif-containing protein 4|homolog of yeast Isd11|mitochondrial matrix Nfs1 interacting protein', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=5031029, end_position_on_the_genomic_accession=5260950, orientation='minus', exon_count=13, OMIM=[613311], no_hdr0=''),
    57129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57129, CurrentID=0, Status='live', Symbol='MRPL47', Aliases=['CGI-204', 'L47mt', 'MRP-L47', 'NCM1'], description='mitochondrial ribosomal protein L47', other_designations='39S ribosomal protein L47, mitochondrial|mitochondrial large ribosomal subunit protein uL29m|nasopharyngeal carcinoma metastasis-related 1|nasopharyngeal carcinoma metastasis-related protein 1', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179588285, end_position_on_the_genomic_accession=179604646, orientation='minus', exon_count=7, OMIM=[611852], no_hdr0=''),
    57130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57130, CurrentID=0, Status='live', Symbol='ATP13A1', Aliases=['ATP13A', 'CGI-152'], description='ATPase 13A1', other_designations='endoplasmic reticulum transmembrane helix translocase|ATPase type 13A1|cation transporting ATPase|endoplasmic reticulum P5A-ATPase|manganese-transporting ATPase 13A1|probable cation-transporting ATPase 13A1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19645198, end_position_on_the_genomic_accession=19663676, orientation='minus', exon_count=26, OMIM=[619118], no_hdr0=''),
    57132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57132, CurrentID=0, Status='live', Symbol='CHMP1B', Aliases=['C10orf2', 'C18-ORF2', 'C18orf2', 'CHMP1.5', 'Vps46-2', 'Vps46B', 'hVps46-2'], description='charged multivesicular body protein 1B', other_designations='charged multivesicular body protein 1b|chromatin modifying protein 1B|chromatin-modifying protein 1b|vacuolar protein sorting 46-2|vacuolar protein sorting-associated protein 46-2', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=11851413, end_position_on_the_genomic_accession=11854444, orientation='plus', exon_count=1, OMIM=[606486], no_hdr0=''),
    57134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57134, CurrentID=0, Status='live', Symbol='MAN1C1', Aliases=['HMIC', 'MAN1A3', 'MAN1C', 'pp6318'], description='mannosidase alpha class 1C member 1', other_designations='mannosyl-oligosaccharide 1,2-alpha-mannosidase IC|1,2-alpha-mannosidase IC|processing alpha-1,2-mannosidase IC', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25616791, end_position_on_the_genomic_accession=25786207, orientation='plus', exon_count=14, OMIM=[616772], no_hdr0=''),
    57135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57135, CurrentID=0, Status='live', Symbol='DAZ4', Aliases=['pDP1680', 'pDP1681'], description='deleted in azoospermia 4', other_designations='deleted in azoospermia protein 4', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=24833806, end_position_on_the_genomic_accession=24907040, orientation='plus', exon_count=29, OMIM=[400048], no_hdr0=''),
    57136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57136, CurrentID=0, Status='live', Symbol='APMAP', Aliases=['BSCv', 'C20orf3'], description='adipocyte plasma membrane associated protein', other_designations='adipocyte plasma membrane-associated protein|protein BSCv', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=24962925, end_position_on_the_genomic_accession=24992930, orientation='minus', exon_count=9, OMIM=[615884], no_hdr0=''),
    57139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57139, CurrentID=0, Status='live', Symbol='RGL3', Aliases=[], description='ral guanine nucleotide dissociation stimulator like 3', other_designations='ral guanine nucleotide dissociation stimulator-like 3|RalGEF-like protein 3, mouse homolog|ralGDS-like 3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11394060, end_position_on_the_genomic_accession=11419314, orientation='minus', exon_count=19, OMIM=[616743], no_hdr0=''),
    57140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57140, CurrentID=0, Status='live', Symbol='RNPEPL1', Aliases=[], description='arginyl aminopeptidase like 1', other_designations='aminopeptidase RNPEPL1|RNPEP-like 1|aminopeptidase B-like 1|argininyl aminopeptidase-like 1|arginyl aminopeptidase (aminopeptidase B)-like 1|methionyl aminopeptidase', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240568484, end_position_on_the_genomic_accession=240581372, orientation='plus', exon_count=11, OMIM=[605287], no_hdr0=''),
    57142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57142, CurrentID=0, Status='live', Symbol='RTN4', Aliases=['ASY', 'NI220/250', 'NOGO', 'NSP', 'NSP-CL', 'Nbla00271', 'Nbla10545', 'RTN-X-A', 'RTN4-B1', 'RTN4-B2', 'RTN4-C', 'RTN4'], description='reticulon 4', other_designations='reticulon-4|Human NogoA|My043 protein|foocen|neurite growth inhibitor 220|neurite outgrowth inhibitor|neuroendocrine-specific protein C homolog|reticulon 5', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=54972189, end_position_on_the_genomic_accession=55137831, orientation='minus', exon_count=17, OMIM=[604475], no_hdr0=''),
    57143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57143, CurrentID=0, Status='live', Symbol='ADCK1', Aliases=[], description='aarF domain containing kinase 1', other_designations='aarF domain-containing protein kinase 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77800064, end_position_on_the_genomic_accession=77935014, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    57144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57144, CurrentID=0, Status='live', Symbol='PAK5', Aliases=['PAK7'], description='p21 (RAC1) activated kinase 5', other_designations='serine/threonine-protein kinase PAK 5|PAK-5|PAK-7|p21 (RAC1) activated kinase 7|p21 protein (Cdc42/Rac)-activated kinase 7|p21(CDKN1A)-activated kinase 7|p21-activated kinase 5|p21-activated kinase 7|p21CDKN1A-activated kinase 7|protein kinase PAK5|serine/threonine-protein kinase PAK 7|serine/threonine-protein kinase PAK7', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=9537370, end_position_on_the_genomic_accession=9839076, orientation='minus', exon_count=16, OMIM=[608038], no_hdr0=''),
    57146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57146, CurrentID=0, Status='live', Symbol='LDAF1', Aliases=['TMEM159'], description='lipid droplet assembly factor 1', other_designations='lipid droplet assembly factor 1|PROMETHIN|transmembrane protein 159', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21158349, end_position_on_the_genomic_accession=21180616, orientation='plus', exon_count=10, OMIM=[611304], no_hdr0=''),
    57147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57147, CurrentID=0, Status='live', Symbol='SCYL3', Aliases=['PACE-1', 'PACE1'], description='SCY1 like pseudokinase 3', other_designations='protein-associating with the carboxyl-terminal domain of ezrin|SCY1-like 3|SCY1-like protein 3|SCY1-like, kinase-like 3|ezrin-binding partner PACE-1 (PACE-1)|ezrin-binding protein PACE-1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169849631, end_position_on_the_genomic_accession=169894267, orientation='minus', exon_count=15, OMIM=[608192], no_hdr0=''),
    57148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57148, CurrentID=0, Status='live', Symbol='RALGAPB', Aliases=['KIAA1219', 'RalGAPbeta'], description='Ral GTPase activating protein non-catalytic subunit beta', other_designations='ral GTPase-activating protein subunit beta|Ral GTPase activating protein non-catalytic beta subunit|Ral GTPase activating protein, beta subunit (non-catalytic)', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38472820, end_position_on_the_genomic_accession=38578861, orientation='plus', exon_count=33, OMIM=[618833], no_hdr0=''),
    57149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57149, CurrentID=0, Status='live', Symbol='LYRM1', Aliases=['A211C6.1'], description='LYR motif containing 1', other_designations='LYR motif-containing protein 1', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20899626, end_position_on_the_genomic_accession=20925006, orientation='plus', exon_count=13, OMIM=[614709], no_hdr0=''),
    57150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57150, CurrentID=0, Status='live', Symbol='SMIM8', Aliases=['C6orf162', 'dJ102H19.2'], description='small integral membrane protein 8', other_designations='small integral membrane protein 8|UPF0708 protein C6orf162', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87322588, end_position_on_the_genomic_accession=87342329, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    57151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57151, CurrentID=0, Status='live', Symbol='LYZL6', Aliases=['HEL-S-6a', 'LYC1', 'LYZB', 'PRO1485', 'TKAL754', 'UNQ754'], description='lysozyme like 6', other_designations='lysozyme-like protein 6|epididymis secretory sperm binding protein Li 6a|lysozyme B|lysozyme homolog', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35934518, end_position_on_the_genomic_accession=35943713, orientation='minus', exon_count=5, OMIM=[612751], no_hdr0=''),
    57152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57152, CurrentID=0, Status='live', Symbol='SLURP1', Aliases=['ANUP', 'ARS', 'ArsB', 'LY6-MT', 'LY6LS', 'MDM'], description='secreted LY6/PLAUR domain containing 1', other_designations='secreted Ly-6/uPAR-related protein 1|ARS(component B)-81/S|SLURP-1|anti-neoplastic urinary protein|lymphocyte antigen 6-like secreted|secreted Ly6/uPAR related protein 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142740949, end_position_on_the_genomic_accession=142742406, orientation='minus', exon_count=3, OMIM=[606119], no_hdr0=''),
    57153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57153, CurrentID=0, Status='live', Symbol='SLC44A2', Aliases=['CTL2', 'PP1292'], description='solute carrier family 44 member 2', other_designations='choline transporter-like protein 2|solute carrier family 44 (choline transporter), member 2|testicular tissue protein Li 47', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10602455, end_position_on_the_genomic_accession=10644557, orientation='plus', exon_count=24, OMIM=[606106], no_hdr0=''),
    57154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57154, CurrentID=0, Status='live', Symbol='SMURF1', Aliases=[], description='SMAD specific E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase SMURF1|E3 ubiquitin ligase SMURF1|HECT-type E3 ubiquitin transferase SMURF1|Smad ubiquitination regulatory factor 1|Smad-specific E3 ubiquitin ligase 1|hSMURF1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99027435, end_position_on_the_genomic_accession=99144118, orientation='minus', exon_count=19, OMIM=[605568], no_hdr0=''),
    57156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57156, CurrentID=0, Status='live', Symbol='TMEM63C', Aliases=['C14orf171', 'CSC1', 'hsCSC1'], description='transmembrane protein 63C', other_designations='calcium permeable stress-gated cation channel 1|calcium permeable stress-gated cation channel 1 homolog', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77181798, end_position_on_the_genomic_accession=77259495, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    57157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57157, CurrentID=0, Status='live', Symbol='PHTF2', Aliases=[], description='putative homeodomain transcription factor 2', other_designations='protein PHTF2', map_location='7q11.23-q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77798773, end_position_on_the_genomic_accession=77957504, orientation='plus', exon_count=22, OMIM=[616785], no_hdr0=''),
    57158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57158, CurrentID=0, Status='live', Symbol='JPH2', Aliases=['CMH17', 'JP-2', 'JP2'], description='junctophilin 2', other_designations='junctophilin-2|junctophilin type 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44106590, end_position_on_the_genomic_accession=44187946, orientation='minus', exon_count=8, OMIM=[605267], no_hdr0=''),
    57159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57159, CurrentID=0, Status='live', Symbol='TRIM54', Aliases=['MURF', 'MURF-3', 'RNF30', 'muRF3'], description='tripartite motif containing 54', other_designations='tripartite motif-containing protein 54|muscle-specific RING finger protein 3|ring finger protein 30', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27282429, end_position_on_the_genomic_accession=27307439, orientation='plus', exon_count=10, OMIM=[606474], no_hdr0=''),
    57161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57161, CurrentID=0, Status='live', Symbol='PELI2', Aliases=[], description='pellino E3 ubiquitin protein ligase family member 2', other_designations='E3 ubiquitin-protein ligase pellino homolog 2|RING-type E3 ubiquitin transferase pellino homolog 2|pellino homolog 2|pellino-2|protein pellino homolog 2', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=56118329, end_position_on_the_genomic_accession=56301586, orientation='plus', exon_count=12, OMIM=[614798], no_hdr0=''),
    57162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57162, CurrentID=0, Status='live', Symbol='PELI1', Aliases=[], description='pellino E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase pellino homolog 1|RING-type E3 ubiquitin transferase pellino homolog 1|pellino homolog 1|pellino-1|pellino-related intracellular-signaling molecule|protein pellino homolog 1', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=64092652, end_position_on_the_genomic_accession=64144421, orientation='minus', exon_count=11, OMIM=[614797], no_hdr0=''),
    57165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57165, CurrentID=0, Status='live', Symbol='GJC2', Aliases=['CX46.6', 'Cx47', 'GJA12', 'HLD2', 'LMPH1C', 'LMPHM3', 'PMLDAR', 'SPG44'], description='gap junction protein gamma 2', other_designations='gap junction gamma-2 protein|connexin-46.6|connexin-47|gap junction alpha-12 protein|gap junction protein, gamma 2, 47kDa', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228149930, end_position_on_the_genomic_accession=228159826, orientation='plus', exon_count=2, OMIM=[608803], no_hdr0=''),
    57167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57167, CurrentID=0, Status='live', Symbol='SALL4', Aliases=['DRRS', 'HSAL4', 'IVIC', 'ZNF797'], description='spalt like transcription factor 4', other_designations='sal-like protein 4|zinc finger protein 797|zinc finger protein SALL4', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=51782331, end_position_on_the_genomic_accession=51802521, orientation='minus', exon_count=8, OMIM=[607343], no_hdr0=''),
    57168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57168, CurrentID=0, Status='live', Symbol='ASPHD2', Aliases=[], description='aspartate beta-hydroxylase domain containing 2', other_designations='aspartate beta-hydroxylase domain-containing protein 2', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26429260, end_position_on_the_genomic_accession=26445015, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    57169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57169, CurrentID=0, Status='live', Symbol='ZNFX1', Aliases=[], description='zinc finger NFX1-type containing 1', other_designations='NFX1-type zinc finger-containing protein 1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=49245900, end_position_on_the_genomic_accession=49278057, orientation='minus', exon_count=14, OMIM=[618931], no_hdr0=''),
    57171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57171, CurrentID=0, Status='live', Symbol='DOLPP1', Aliases=['LSFR2'], description='dolichyldiphosphatase 1', other_designations='dolichyldiphosphatase 1|dolichyl pyrophosphate phosphatase 1|linked to Surfeit genes in Fugu rubripes 2', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129080988, end_position_on_the_genomic_accession=129090438, orientation='plus', exon_count=8, OMIM=[614516], no_hdr0=''),
    57172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57172, CurrentID=0, Status='live', Symbol='CAMK1G', Aliases=['CLICK3', 'CLICKIII', 'VWS1', 'dJ272L16.1'], description='calcium/calmodulin dependent protein kinase IG', other_designations='calcium/calmodulin-dependent protein kinase type 1G|CLICK III|caM kinase I gamma|caM kinase IG|caM-KI gamma|caMK-like CREB kinase III|caMKI gamma|caMKIG', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209583714, end_position_on_the_genomic_accession=209613939, orientation='plus', exon_count=13, OMIM=[614994], no_hdr0=''),
    57175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57175, CurrentID=0, Status='live', Symbol='CORO1B', Aliases=['CORONIN-2'], description='coronin 1B', other_designations='coronin-1B|coronin, actin binding protein, 1B', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67435510, end_position_on_the_genomic_accession=67443809, orientation='minus', exon_count=12, OMIM=[609849], no_hdr0=''),
    57176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57176, CurrentID=0, Status='live', Symbol='VARS2', Aliases=['COXPD20', 'VALRSL', 'VARSL', 'VARS2'], description='valyl-tRNA synthetase 2, mitochondrial', other_designations='valine--tRNA ligase, mitochondrial|valine tRNA ligase 2, mitochondrial (putative)|valyl-tRNA synthetase like', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30914238, end_position_on_the_genomic_accession=30926459, orientation='plus', exon_count=30, OMIM=[612802], no_hdr0=''),
    57178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57178, CurrentID=0, Status='live', Symbol='ZMIZ1', Aliases=['MIZ', 'NEDDFSA', 'RAI17', 'TRAFIP10', 'ZIMP10'], description='zinc finger MIZ-type containing 1', other_designations='zinc finger MIZ domain-containing protein 1|retinoic acid induced 17|zinc finger-containing, Miz1, PIAS-like protein on chromosome 10', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79068966, end_position_on_the_genomic_accession=79316519, orientation='plus', exon_count=30, OMIM=[607159], no_hdr0=''),
    57179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57179, CurrentID=0, Status='live', Symbol='KIAA1191', Aliases=['p33MONOX', 'p60MONOX'], description='KIAA1191', other_designations='putative monooxygenase p33MONOX|brain-derived rescue factor p60MONOX|flavin monooxygenase motif-containing protein of 33 kDa|flavine monooxygenase motif-containing protein of 33 kDa|p60MONOX brain-derived rescue factor', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176346061, end_position_on_the_genomic_accession=176361865, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    57180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57180, CurrentID=0, Status='live', Symbol='ACTR3B', Aliases=['ARP11', 'ARP3BETA'], description='actin related protein 3B', other_designations='actin-related protein 3B|ARP3 actin related protein 3 homolog B|ARP3-beta|actin-like protein 3B|actin-related protein 3-beta|actin-related protein ARP4|actin-related protein Arp11', map_location='7q36.1-q36.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=152759752, end_position_on_the_genomic_accession=153070979, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    57181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57181, CurrentID=0, Status='live', Symbol='SLC39A10', Aliases=['LZT-Hs2'], description='solute carrier family 39 member 10', other_designations='zinc transporter ZIP10|ZIP-10|solute carrier family 39 (metal ion transporter), member 10|solute carrier family 39 (zinc transporter), member 10|zrt- and Irt-like protein 10', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=195575944, end_position_on_the_genomic_accession=195737701, orientation='plus', exon_count=17, OMIM=[608733], no_hdr0=''),
    57182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57182, CurrentID=0, Status='live', Symbol='ANKRD50', Aliases=[], description='ankyrin repeat domain 50', other_designations='ankyrin repeat domain-containing protein 50', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=124664048, end_position_on_the_genomic_accession=124712732, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    57184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57184, CurrentID=0, Status='live', Symbol='FAM219B', Aliases=['C15orf17'], description='family with sequence similarity 219 member B', other_designations='protein FAM219B|uncharacterized protein C15orf17', map_location='15q24.1-q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74899174, end_position_on_the_genomic_accession=74907228, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    57185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57185, CurrentID=0, Status='live', Symbol='NIPAL3', Aliases=['DJ462O23.2', 'NPAL3', 'SLC57A5'], description='NIPA like domain containing 3', other_designations='NIPA-like protein 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24413360, end_position_on_the_genomic_accession=24472983, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    57186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57186, CurrentID=0, Status='live', Symbol='RALGAPA2', Aliases=['AS250', 'C20orf74', 'bA287B20.1', 'dJ1049G11', 'dJ1049G11.4', 'p220'], description='Ral GTPase activating protein catalytic subunit alpha 2', other_designations='ral GTPase-activating protein subunit alpha-2|250 kDa substrate of Akt|Ral GTPase activating protein catalytic alpha subunit 2|Ral GTPase activating protein, alpha subunit 2 (catalytic)|RapGAPalpha2|akt substrate AS250|ral GTPase-activating protein alpha subunit 2', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=20389530, end_position_on_the_genomic_accession=20712644, orientation='minus', exon_count=47, OMIM=[618836], no_hdr0=''),
    57187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57187, CurrentID=0, Status='live', Symbol='THOC2', Aliases=['CXorf3', 'MRX12', 'MRX35', 'THO2', 'dJ506G2.1', 'hTREX120'], description='THO complex 2', other_designations='THO complex subunit 2|mental retardation, X-linked 12|mental retardation, X-linked 35', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=123600563, end_position_on_the_genomic_accession=123733054, orientation='minus', exon_count=41, OMIM=[300395], no_hdr0=''),
    57188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57188, CurrentID=0, Status='live', Symbol='ADAMTSL3', Aliases=['ADAMTSL-3'], description='ADAMTS like 3', other_designations='ADAMTS-like protein 3|a disintegrin-like and metalloprotease domain with thrombospondin type I motifs-like 3|punctin-2', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=83654095, end_position_on_the_genomic_accession=84039842, orientation='plus', exon_count=35, OMIM=[609199], no_hdr0=''),
    57189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57189, CurrentID=0, Status='live', Symbol='DENND11', Aliases=['KIAA1147', 'LCHN', 'PRO2561'], description='DENN domain containing 11', other_designations='DENN domain-containing protein 11|predicted protein of HQ2561|protein LCHN', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141652381, end_position_on_the_genomic_accession=141702188, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    57190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57190, CurrentID=0, Status='live', Symbol='SELENON', Aliases=['CFTD', 'MDRS1', 'RSMD1', 'RSS', 'SELN', 'SEPN1'], description='selenoprotein N', other_designations='selenoprotein N|selenoprotein N, 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25800193, end_position_on_the_genomic_accession=25818221, orientation='plus', exon_count=13, OMIM=[606210], no_hdr0=''),
    57191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57191, CurrentID=0, Status='live', Symbol='VN1R1', Aliases=['V1RL1', 'VNR19I1', 'ZVNH1', 'ZVNR1'], description='vomeronasal 1 receptor 1', other_designations='vomeronasal type-1 receptor 1|G-protein coupled receptor GPCR24|V1R-like 1|V1r-like receptor 1|V3r-related gene protein|hGPCR24|vomeronasal olfactory receptor chromosome 19 subtype I member 1|vomeronasal olfactory receptor, (chromosome 19) subtype I, member 1', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57454790, end_position_on_the_genomic_accession=57457140, orientation='minus', exon_count=1, OMIM=[605234], no_hdr0=''),
    57192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57192, CurrentID=0, Status='live', Symbol='MCOLN1', Aliases=['MG-2', 'ML1', 'ML4', 'MLIV', 'MST080', 'MSTP080', 'TRP-ML1', 'TRPM-L1', 'TRPML1'], description='mucolipin TRP cation channel 1', other_designations='mucolipin-1|mucolipidin|mucolipidosis type IV protein|mucolipin 1|transient receptor potential cation channel mucolipin subfamily member 1|transient receptor potential channel mucolipin 1|transient receptor potential mucolipin 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7522624, end_position_on_the_genomic_accession=7534009, orientation='plus', exon_count=14, OMIM=[605248], no_hdr0=''),
    57194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57194, CurrentID=0, Status='live', Symbol='ATP10A', Aliases=['ATP10C', 'ATPVA', 'ATPVC'], description='ATPase phospholipid transporting 10A (putative)', other_designations='phospholipid-transporting ATPase VA|ATPase type IV, phospholipid transporting (P-type)|ATPase, Class V, type 10C|ATPase, class V, type 10A|P4-ATPase flippase complex alpha subunit ATP10A|aminophospholipid translocase VA|probable phospholipid-transporting ATPase VA', map_location='15q12', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=25672241, end_position_on_the_genomic_accession=25865144, orientation='minus', exon_count=28, OMIM=[605855], no_hdr0=''),
    57198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57198, CurrentID=0, Status='live', Symbol='ATP8B2', Aliases=['ATPID'], description='ATPase phospholipid transporting 8B2', other_designations='phospholipid-transporting ATPase ID|36/8-9 fusion protein with epitope for anti-lectin antibody|ATPase, aminophospholipid transporter, class I, type 8B, member 2|ATPase, class I, type 8B, member 2|P4-ATPase flippase complex alpha subunit ATP8B2|probable phospholipid-transporting ATPase ID', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154325525, end_position_on_the_genomic_accession=154351304, orientation='plus', exon_count=30, OMIM=[605867], no_hdr0=''),
    57205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57205, CurrentID=0, Status='live', Symbol='ATP10D', Aliases=['ATPVD'], description='ATPase phospholipid transporting 10D (putative)', other_designations='phospholipid-transporting ATPase VD|ATPase, class V, type 10D|P4-ATPase flippase complex alpha subunit ATP10D|probable phospholipid-transporting ATPase VD|type IV aminophospholipid transporting ATPase', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=47485275, end_position_on_the_genomic_accession=47593486, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    57209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57209, CurrentID=0, Status='live', Symbol='ZNF248', Aliases=['bA162G10.3'], description='zinc finger protein 248', other_designations='zinc finger protein 248|KRAB protein domain|Kruppel-type zinc finger protein|bA162G10.3 (zinc finger protein)', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=37758452, end_position_on_the_genomic_accession=37858202, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    57210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57210, CurrentID=0, Status='live', Symbol='SLC45A4', Aliases=[], description='solute carrier family 45 member 4', other_designations='solute carrier family 45 member 4', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=141207169, end_position_on_the_genomic_accession=141308321, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    57211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57211, CurrentID=0, Status='live', Symbol='ADGRG6', Aliases=['APG1', 'DREG', 'GPR126', 'LCCS9', 'PR126', 'PS1TP2', 'VIGR'], description='adhesion G protein-coupled receptor G6', other_designations='adhesion G-protein coupled receptor G6|G-protein coupled receptor 126|HBV PreS1-transactivated protein 2|developmentally regulated G-protein-coupled receptor|vascular-inducible G protein-coupled receptor', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=142302007, end_position_on_the_genomic_accession=142446261, orientation='plus', exon_count=28, OMIM=[612243], no_hdr0=''),
    57213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57213, CurrentID=0, Status='live', Symbol='SPRYD7', Aliases=['C13orf1', 'CLLD6'], description='SPRY domain containing 7', other_designations='SPRY domain-containing protein 7|CLL deletion region gene 6 protein|chronic lymphocytic leukemia deletion region gene 6 protein|epididymis secretory sperm binding protein', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49912702, end_position_on_the_genomic_accession=49936501, orientation='minus', exon_count=6, OMIM=[607866], no_hdr0=''),
    57214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57214, CurrentID=0, Status='live', Symbol='CEMIP', Aliases=['CCSP1', 'HYBID', 'KIAA1199', 'TMEM2L'], description='cell migration inducing hyaluronidase 1', other_designations='cell migration-inducing and hyaluronan-binding protein|cell migration inducing hyaluronan binding protein|cell migration inducing protein, hyaluronan binding|colon cancer secreted protein 1|hyaluronan-binding protein involved in hyaluronan depolymerization', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80779370, end_position_on_the_genomic_accession=80951771, orientation='plus', exon_count=30, OMIM=[608366], no_hdr0=''),
    57215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57215, CurrentID=0, Status='live', Symbol='THAP11', Aliases=['CTG-B43a', 'CTG-B45d', 'HRIHFB2206', 'RONIN'], description='THAP domain containing 11', other_designations='THAP domain-containing protein 11', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67842320, end_position_on_the_genomic_accession=67844195, orientation='plus', exon_count=1, OMIM=[609119], no_hdr0=''),
    57216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57216, CurrentID=0, Status='live', Symbol='VANGL2', Aliases=['LPP1', 'LTAP', 'STB1', 'STBM', 'STBM1'], description='VANGL planar cell polarity protein 2', other_designations='vang-like protein 2|loop-tail protein 1 homolog|loop-tail-associated protein|strabismus 1|van Gogh-like protein 2|vang-like 2 (van gogh, Drosophila)', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160400564, end_position_on_the_genomic_accession=160428674, orientation='plus', exon_count=11, OMIM=[600533], no_hdr0=''),
    57217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57217, CurrentID=0, Status='live', Symbol='TTC7A', Aliases=['GIDID', 'MINAT', 'TTC7'], description='tetratricopeptide repeat domain 7A', other_designations='tetratricopeptide repeat protein 7A|TPR repeat protein 7A', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46915866, end_position_on_the_genomic_accession=47076123, orientation='plus', exon_count=32, OMIM=[609332], no_hdr0=''),
    57221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57221, CurrentID=0, Status='live', Symbol='ARFGEF3', Aliases=['A7322', 'BIG3', 'C6orf92', 'KIAA1244', 'PPP1R33', 'dJ171N11.1'], description='ARFGEF family member 3', other_designations='brefeldin A-inhibited guanine nucleotide-exchange protein 3|protein phosphatase 1, regulatory subunit 33', map_location='6q23.3-q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138161690, end_position_on_the_genomic_accession=138344663, orientation='plus', exon_count=34, OMIM=[617411], no_hdr0=''),
    57222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57222, CurrentID=0, Status='live', Symbol='ERGIC1', Aliases=['AMC2', 'AMCN', 'ERGIC-32', 'ERGIC32', 'NET24'], description='endoplasmic reticulum-golgi intermediate compartment 1', other_designations='endoplasmic reticulum-Golgi intermediate compartment protein 1|ER-Golgi intermediate compartment 32 kDa protein|endoplasmic reticulum-golgi intermediate compartment (ERGIC) 1|endoplasmic reticulum-golgi intermediate compartment 32 kDa protein', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172834251, end_position_on_the_genomic_accession=172952683, orientation='plus', exon_count=14, OMIM=[617946], no_hdr0=''),
    57223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57223, CurrentID=0, Status='live', Symbol='PPP4R3B', Aliases=['FLFL2', 'PP4R3B', 'PSY2', 'SMEK2', 'smk1'], description='protein phosphatase 4 regulatory subunit 3B', other_designations='serine/threonine-protein phosphatase 4 regulatory subunit 3B|SMEK homolog 2, suppressor of mek1', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55547292, end_position_on_the_genomic_accession=55618132, orientation='minus', exon_count=20, OMIM=[610352], no_hdr0=''),
    57224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57224, CurrentID=0, Status='live', Symbol='NHSL1', Aliases=['C6orf63'], description='NHS like 1', other_designations='NHS-like protein 1', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138422043, end_position_on_the_genomic_accession=138692616, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    57226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57226, CurrentID=0, Status='live', Symbol='LYRM2', Aliases=['DJ122O8.2'], description='LYR motif containing 2', other_designations='LYR motif-containing protein 2', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89632224, end_position_on_the_genomic_accession=89638747, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    57228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57228, CurrentID=0, Status='live', Symbol='SMAGP', Aliases=['hSMAGP'], description='small cell adhesion glycoprotein', other_designations='small cell adhesion glycoprotein|small cell transmembrane and glycosylated protein|small trans-membrane and glycosylated protein|small transmembrane and glycosylated protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51244558, end_position_on_the_genomic_accession=51270415, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    57231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57231, CurrentID=0, Status='live', Symbol='SNX14', Aliases=['RGS-PX2', 'SCAR20'], description='sorting nexin 14', other_designations='sorting nexin-14', map_location='6q14.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=85505496, end_position_on_the_genomic_accession=85593858, orientation='minus', exon_count=31, OMIM=[616105], no_hdr0=''),
    57232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57232, CurrentID=0, Status='live', Symbol='ZNF630', Aliases=['dJ54B20.2'], description='zinc finger protein 630', other_designations='zinc finger protein 630|dJ54B20.2 (novel KRAB box containing C2H2 type zinc finger protein)', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48057516, end_position_on_the_genomic_accession=48071640, orientation='minus', exon_count=6, OMIM=[300819], no_hdr0=''),
    57282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57282, CurrentID=0, Status='live', Symbol='SLC4A10', Aliases=['NBCn2', 'NCBE'], description='solute carrier family 4 member 10', other_designations='sodium-driven chloride bicarbonate exchanger|solute carrier family 4, sodium bicarbonate cotransporter-like, member 10|solute carrier family 4, sodium bicarbonate transporter, member 10', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=161620963, end_position_on_the_genomic_accession=161985270, orientation='plus', exon_count=35, OMIM=[605556], no_hdr0=''),
    57292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57292, CurrentID=0, Status='live', Symbol='KIR2DL5A', Aliases=['CD158F', 'KIR2DL5', 'KIR2DL5.1', 'KIR2DL5.3'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 5A', other_designations='killer cell immunoglobulin-like receptor 2DL5A|killer cell immunoglobulin-like receptor KIR2DL5A|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 5|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 5A', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[605305], no_hdr0=''),
    57325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57325, CurrentID=0, Status='live', Symbol='KAT14', Aliases=['ATAC2', 'CRP2BP', 'CSRP2BP', 'PRO1194', 'dJ717M23.1'], description='lysine acetyltransferase 14', other_designations='cysteine-rich protein 2-binding protein|ADA2A-containing complex subunit 2|ATAC component 2 homolog|CRP2 binding partner|CRP2 binding protein|CSRP2-binding protein', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18137153, end_position_on_the_genomic_accession=18188372, orientation='plus', exon_count=14, OMIM=[617501], no_hdr0=''),
    57326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57326, CurrentID=0, Status='live', Symbol='PBXIP1', Aliases=['HPIP'], description='PBX homeobox interacting protein 1', other_designations='pre-B-cell leukemia transcription factor-interacting protein 1|hematopoietic PBX-interacting protein|pre-B-cell leukemia homeobox interacting protein 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154944080, end_position_on_the_genomic_accession=154956099, orientation='minus', exon_count=11, OMIM=[618819], no_hdr0=''),
    57332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57332, CurrentID=0, Status='live', Symbol='CBX8', Aliases=['PC3', 'RC1'], description='chromobox 8', other_designations='chromobox protein homolog 8|Pc class 3 homolog|chromobox homolog 8 (Pc class homolog, Drosophila)|polycomb 3|rectachrome 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79792132, end_position_on_the_genomic_accession=79797077, orientation='minus', exon_count=5, OMIM=[617354], no_hdr0=''),
    57333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57333, CurrentID=0, Status='live', Symbol='RCN3', Aliases=['RLP49'], description='reticulocalbin 3', other_designations='reticulocalbin-3|EF-hand calcium-binding protein RLP49|reticulocabin|reticulocalbin 3, EF-hand calcium binding domain', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49527579, end_position_on_the_genomic_accession=49543638, orientation='plus', exon_count=7, OMIM=[619032], no_hdr0=''),
    57335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57335, CurrentID=0, Status='live', Symbol='ZNF286A', Aliases=['ZNF286'], description='zinc finger protein 286A', other_designations='zinc finger protein 286A|zinc finger protein ZNF286', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15699752, end_position_on_the_genomic_accession=15720787, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    57336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57336, CurrentID=0, Status='live', Symbol='ZNF287', Aliases=['ZKSCAN13', 'ZSCAN45'], description='zinc finger protein 287', other_designations='zinc finger protein 287|zinc finger protein with KRAB and SCAN domains 13', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16546689, end_position_on_the_genomic_accession=16569212, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    57337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57337, CurrentID=0, Status='live', Symbol='SENP7', Aliases=[], description='SUMO specific peptidase 7', other_designations='sentrin-specific protease 7|SUMO-1-specific protease 2|SUMO1/sentrin specific peptidase 7|sentrin/SUMO-specific protease SENP7', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101324205, end_position_on_the_genomic_accession=101513883, orientation='minus', exon_count=27, OMIM=[612846], no_hdr0=''),
    57338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57338, CurrentID=0, Status='live', Symbol='JPH3', Aliases=['CAGL237', 'HDL2', 'JP-3', 'JP3', 'TNRC22'], description='junctophilin 3', other_designations='junctophilin-3|junctophilin type 3|trinucleotide repeat containing 22', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87601835, end_position_on_the_genomic_accession=87698156, orientation='plus', exon_count=8, OMIM=[605268], no_hdr0=''),
    57343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57343, CurrentID=0, Status='live', Symbol='ZNF304', Aliases=[], description='zinc finger protein 304', other_designations='zinc finger protein 304|KRAB-containing zinc finger protein', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57351253, end_position_on_the_genomic_accession=57359898, orientation='plus', exon_count=5, OMIM=[613840], no_hdr0=''),
    57348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57348, CurrentID=0, Status='live', Symbol='TTYH1', Aliases=[], description='tweety family member 1', other_designations='protein tweety homolog 1|hTTY1|tweety homolog 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54415464, end_position_on_the_genomic_accession=54436904, orientation='plus', exon_count=14, OMIM=[605784], no_hdr0=''),
    57369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57369, CurrentID=0, Status='live', Symbol='GJD2', Aliases=['CX36', 'GJA9'], description='gap junction protein delta 2', other_designations='gap junction delta-2 protein|connexin-36|gap junction alpha-9 protein|gap junction protein, delta 2, 36kDa', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34751032, end_position_on_the_genomic_accession=34754998, orientation='minus', exon_count=2, OMIM=[607058], no_hdr0=''),
    57379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57379, CurrentID=0, Status='live', Symbol='AICDA', Aliases=['AID', 'ARP2', 'CDA2', 'HEL-S-284', 'HIGM2'], description='activation induced cytidine deaminase', other_designations="single-stranded DNA cytosine deaminase|cytidine aminohydrolase|epididymis secretory protein Li 284|integrated into Burkitt's lymphoma cell line Ramos", map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8602170, end_position_on_the_genomic_accession=8612970, orientation='minus', exon_count=5, OMIM=[605257], no_hdr0=''),
    57380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57380, CurrentID=0, Status='live', Symbol='MRS2', Aliases=['HPTL', 'MRS2'], description='magnesium transporter MRS2', other_designations='magnesium transporter MRS2 homolog, mitochondrial|MRS2, magnesium transporter|MRS2-like protein|MRS2-like, magnesium homeostasis factor|putative magnesium transporter', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24402936, end_position_on_the_genomic_accession=24426190, orientation='plus', exon_count=12, OMIM=[619307], no_hdr0=''),
    57381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57381, CurrentID=0, Status='live', Symbol='RHOJ', Aliases=['ARHJ', 'RASL7B', 'TC10B', 'TCL'], description='ras homolog family member J', other_designations='rho-related GTP-binding protein RhoJ|RAS-like, family 7, member B|TC10-like Rho GTPase|ras homolog gene family, member J|ras-like protein family member 7B|tc10-like GTP-binding protein', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63204412, end_position_on_the_genomic_accession=63293508, orientation='plus', exon_count=7, OMIM=[607653], no_hdr0=''),
    57393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57393, CurrentID=0, Status='live', Symbol='CLTRN', Aliases=['NX-17', 'NX17', 'TMEM27'], description='collectrin, amino acid transport regulator', other_designations='collectrin|kidney-specific membrane protein|transmembrane protein 27', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15627318, end_position_on_the_genomic_accession=15675624, orientation='minus', exon_count=8, OMIM=[300631], no_hdr0=''),
    57396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57396, CurrentID=0, Status='live', Symbol='CLK4', Aliases=[], description='CDC like kinase 4', other_designations='dual specificity protein kinase CLK4|protein serine threonine kinase Clk4', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178602664, end_position_on_the_genomic_accession=178627050, orientation='minus', exon_count=13, OMIM=[607969], no_hdr0=''),
    57402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57402, CurrentID=0, Status='live', Symbol='S100A14', Aliases=['BCMP84', 'S100A15'], description='S100 calcium binding protein A14', other_designations='protein S100-A14|S114|breast cancer membrane protein 84', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153614255, end_position_on_the_genomic_accession=153616917, orientation='minus', exon_count=6, OMIM=[607986], no_hdr0=''),
    57403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57403, CurrentID=0, Status='live', Symbol='RAB22A', Aliases=[], description='RAB22A, member RAS oncogene family', other_designations='ras-related protein Rab-22A|GTP-binding protein RAB22A|rab-22', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58309715, end_position_on_the_genomic_accession=58367507, orientation='plus', exon_count=7, OMIM=[612966], no_hdr0=''),
    57404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57404, CurrentID=0, Status='live', Symbol='CYP20A1', Aliases=['CYP-M'], description='cytochrome P450 family 20 subfamily A member 1', other_designations='cytochrome P450 20A1|cytochrome P450 monooxygenase|cytochrome P450, family 20, subfamily A, polypeptide 1', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203238982, end_position_on_the_genomic_accession=203306026, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    57405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57405, CurrentID=0, Status='live', Symbol='SPC25', Aliases=['AD024', 'SPBC25', 'hSpc25'], description='SPC25 component of NDC80 kinetochore complex', other_designations='kinetochore protein Spc25|2600017H08Rik|SPC25, NDC80 kinetochore complex component, homolog|spindle pole body component 25 homolog', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=168865045, end_position_on_the_genomic_accession=168890443, orientation='minus', exon_count=8, OMIM=[609395], no_hdr0=''),
    57406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57406, CurrentID=0, Status='live', Symbol='ABHD6', Aliases=[], description='abhydrolase domain containing 6, acylglycerol lipase', other_designations='monoacylglycerol lipase ABHD6|2-arachidonoylglycerol hydrolase|abhydrolase domain-containing protein 6|lipase protein', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58237532, end_position_on_the_genomic_accession=58294736, orientation='plus', exon_count=10, OMIM=[616966], no_hdr0=''),
    57407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57407, CurrentID=0, Status='live', Symbol='NMRAL1', Aliases=['HSCARG', 'SDR48A1'], description='NmrA like redox sensor 1', other_designations='nmrA-like family domain-containing protein 1|NmrA-like family domain containing 1|epididymis secretory sperm binding protein|short chain dehydrogenase/reductase family 48A, member 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4461688, end_position_on_the_genomic_accession=4476337, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    57408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57408, CurrentID=0, Status='live', Symbol='LRTM1', Aliases=['HT017'], description='leucine rich repeats and transmembrane domains 1', other_designations='leucine-rich repeat and transmembrane domain-containing protein 1', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=54918231, end_position_on_the_genomic_accession=54967102, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    57409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57409, CurrentID=0, Status='live', Symbol='MIF4GD', Aliases=['AD023', 'MIFD', 'SLIP1'], description='MIF4G domain containing', other_designations='MIF4G domain-containing protein|SLBP (stem loop binding protein)-interacting protein 1|SLBP-interacting protein 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75266228, end_position_on_the_genomic_accession=75271292, orientation='minus', exon_count=10, OMIM=[612072], no_hdr0=''),
    57410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57410, CurrentID=0, Status='live', Symbol='SCYL1', Aliases=['GKLP', 'HT019', 'NKTL', 'NTKL', 'P105', 'SCAR21', 'TAPK', 'TEIF', 'TRAP'], description='SCY1 like pseudokinase 1', other_designations='N-terminal kinase-like protein|SCY1-like protein 1|SCY1-like, kinase-like 1|coated vesicle-associated kinase of 90 kDa|likely ortholog of mouse N-terminal kinase-like protein|telomerase regulation-associated protein|telomerase transcriptional elements-interacting factor|teratoma-associated tyrosine kinase', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65525081, end_position_on_the_genomic_accession=65538710, orientation='plus', exon_count=17, OMIM=[607982], no_hdr0=''),
    57412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57412, CurrentID=0, Status='live', Symbol='AS3MT', Aliases=['CYT19'], description='arsenite methyltransferase', other_designations='arsenite methyltransferase|S-adenosyl-L-methionine:arsenic(III) methyltransferase|S-adenosylmethionine:arsenic (III) methyltransferase|arsenic (+3 oxidation state) methyltransferase|methylarsonite methyltransferase|methyltransferase cyt19', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102869470, end_position_on_the_genomic_accession=102901899, orientation='plus', exon_count=11, OMIM=[611806], no_hdr0=''),
    57413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57413, CurrentID=0, Status='live', Symbol='TMIGD3', Aliases=['AD026'], description='transmembrane and immunoglobulin domain containing 3', other_designations='transmembrane and immunoglobulin domain containing 3|AD026 protein (AD026)|transmembrane domain-containing protein TMIGD3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111483348, end_position_on_the_genomic_accession=111563962, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    57414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57414, CurrentID=0, Status='live', Symbol='RHBDD2', Aliases=['NPD007', 'RHBDL7'], description='rhomboid domain containing 2', other_designations='rhomboid domain-containing protein 2|rhomboid, veinlet-like 7', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75879015, end_position_on_the_genomic_accession=75888926, orientation='plus', exon_count=6, OMIM=[615203], no_hdr0=''),
    57415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57415, CurrentID=0, Status='live', Symbol='C3orf14', Aliases=['HT021'], description='chromosome 3 open reading frame 14', other_designations='uncharacterized protein C3orf14', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=62319022, end_position_on_the_genomic_accession=62336213, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    57418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57418, CurrentID=0, Status='live', Symbol='WDR18', Aliases=['Ipi3', 'R32184_1'], description='WD repeat domain 18', other_designations='WD repeat-containing protein 18|Involved in Processing ITS2 3 homolog', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=982928, end_position_on_the_genomic_accession=994557, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    57419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57419, CurrentID=0, Status='live', Symbol='SLC24A3', Aliases=['NCKX3'], description='solute carrier family 24 member 3', other_designations='sodium/potassium/calcium exchanger 3|Na(+)/K(+)/Ca(2+)-exchange protein 3|sodium calcium exchanger|solute carrier family 24 (sodium/potassium/calcium exchanger), member 3', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=19212642, end_position_on_the_genomic_accession=19722926, orientation='plus', exon_count=17, OMIM=[609839], no_hdr0=''),
    57446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57446, CurrentID=0, Status='live', Symbol='NDRG3', Aliases=[], description='NDRG family member 3', other_designations='protein NDRG3|N-myc downstream-regulated gene 3 protein', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36651766, end_position_on_the_genomic_accession=36746127, orientation='minus', exon_count=20, OMIM=[605273], no_hdr0=''),
    57447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57447, CurrentID=0, Status='live', Symbol='NDRG2', Aliases=['SYLD'], description='NDRG family member 2', other_designations='protein NDRG2|N-myc downstream regulator 2|N-myc downstream-regulated gene 2 protein|NDR1-related protein NDR2|cytoplasmic protein Ndr1|syld709613 protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21016763, end_position_on_the_genomic_accession=21070872, orientation='minus', exon_count=22, OMIM=[605272], no_hdr0=''),
    57448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57448, CurrentID=0, Status='live', Symbol='BIRC6', Aliases=['APOLLON', 'BRUCE'], description='baculoviral IAP repeat containing 6', other_designations='baculoviral IAP repeat-containing protein 6|BIR repeat-containing ubiquitin-conjugating enzyme|RING-type E3 ubiquitin transferase BIRC6|ubiquitin-conjugating BIR-domain enzyme apollon', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32356907, end_position_on_the_genomic_accession=32618882, orientation='plus', exon_count=78, OMIM=[605638], no_hdr0=''),
    57449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57449, CurrentID=0, Status='live', Symbol='PLEKHG5', Aliases=['CMTRIC', 'DSMA4', 'GEF720', 'Syx', 'Tech'], description='pleckstrin homology and RhoGEF domain containing G5', other_designations='pleckstrin homology domain-containing family G member 5|NFkB activating protein|PH domain-containing family G member 5|guanine nucleotide exchange factor 720|novel PH domain-containing protein|pleckstrin homology domain containing, family G (with RhoGef domain) member 5|synectin-binding guanine exchange factor', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6466092, end_position_on_the_genomic_accession=6520092, orientation='minus', exon_count=29, OMIM=[611101], no_hdr0=''),
    57451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57451, CurrentID=0, Status='live', Symbol='TENM2', Aliases=['ODZ2', 'TEN-M2', 'TEN2', 'TNM2', 'ten-2'], description='teneurin transmembrane protein 2', other_designations='teneurin-2|neurestin alpha|odd Oz/ten-m homolog 2|odz, odd Oz/ten-m homolog 2|protein Odd Oz/ten-m homolog 2|tenascin-M2', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=166979066, end_position_on_the_genomic_accession=168264159, orientation='plus', exon_count=36, OMIM=[610119], no_hdr0=''),
    57452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57452, CurrentID=0, Status='live', Symbol='GALNT16', Aliases=['GALNACT16', 'GALNTL1', 'GalNAc-T16'], description='polypeptide N-acetylgalactosaminyltransferase 16', other_designations='polypeptide N-acetylgalactosaminyltransferase 16|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase-like protein 1|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 16|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase-like 1|galNAc-T-like protein 1|polypeptide GalNAc transferase 16|polypeptide GalNAc transferase-like protein 1|polypeptide N-acetylgalactosaminyltransferase-like protein 1|pp-GaNTase-like protein 1|protein-UDP acetylgalactosaminyltransferase-like protein 1|putative polypeptide N-acetylgalactosaminyltransferase-like protein 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69259546, end_position_on_the_genomic_accession=69379904, orientation='plus', exon_count=20, OMIM=[615132], no_hdr0=''),
    57453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57453, CurrentID=0, Status='live', Symbol='DSCAML1', Aliases=['DSCAM2'], description='DS cell adhesion molecule like 1', other_designations='Down syndrome cell adhesion molecule-like protein 1|DSCAM-like 1|Downs syndrome cell adhesion molecule like 1|down syndrome cell adhesion molecule 2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117427772, end_position_on_the_genomic_accession=117817514, orientation='minus', exon_count=38, OMIM=[611782], no_hdr0=''),
    57455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57455, CurrentID=0, Status='live', Symbol='REXO1', Aliases=['ELOABP1', 'EloA-BP1', 'REX1', 'TCEB3BP1'], description='RNA exonuclease 1 homolog', other_designations='RNA exonuclease 1 homolog|REX1, RNA exonuclease 1 homolog|elongin-A-binding protein 1|transcription elongation factor B polypeptide 3-binding protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1815248, end_position_on_the_genomic_accession=1848683, orientation='minus', exon_count=19, OMIM=[609614], no_hdr0=''),
    57456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57456, CurrentID=0, Status='live', Symbol='KIAA1143', Aliases=[], description='KIAA1143', other_designations='uncharacterized protein KIAA1143', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44748744, end_position_on_the_genomic_accession=44761619, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    57458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57458, CurrentID=0, Status='live', Symbol='TMCC3', Aliases=[], description='transmembrane and coiled-coil domain family 3', other_designations='transmembrane and coiled-coil domain protein 3|transmembrane and coiled-coil domains 3|transmembrane and coiled-coil domains protein 3', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=94567122, end_position_on_the_genomic_accession=94650557, orientation='minus', exon_count=5, OMIM=[617459], no_hdr0=''),
    57459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57459, CurrentID=0, Status='live', Symbol='GATAD2B', Aliases=['GANDS', 'MRD18', 'P66beta', 'p68'], description='GATA zinc finger domain containing 2B', other_designations='transcriptional repressor p66-beta|GATA zinc finger domain-containing protein 2B|transcription repressor p66 beta component of the MeCP1 complex', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153804725, end_position_on_the_genomic_accession=153923953, orientation='minus', exon_count=13, OMIM=[614998], no_hdr0=''),
    57460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57460, CurrentID=0, Status='live', Symbol='PPM1H', Aliases=['ARHCL1', 'NERPP-2C', 'URCC2'], description='protein phosphatase, Mg2+/Mn2+ dependent 1H', other_designations='protein phosphatase 1H|neurite extension-related protein phosphatase related to PP2C|protein phosphatase 1H (PP2C domain containing)|ras homolog gene family, member C like 1', map_location='12q14.1-q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=62643992, end_position_on_the_genomic_accession=62935150, orientation='minus', exon_count=13, OMIM=[616016], no_hdr0=''),
    57461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57461, CurrentID=0, Status='live', Symbol='ISY1', Aliases=['FSAP33'], description='ISY1 splicing factor homolog', other_designations='pre-mRNA-splicing factor ISY1 homolog|functional spliceosome-associated protein 33', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129127415, end_position_on_the_genomic_accession=129161063, orientation='minus', exon_count=12, OMIM=[612764], no_hdr0=''),
    57462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57462, CurrentID=0, Status='live', Symbol='MYORG', Aliases=['IBGC7', 'KIAA1161', 'NET37'], description='myogenesis regulating glycosidase (putative)', other_designations='myogenesis-regulating glycosidase', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34366149, end_position_on_the_genomic_accession=34376952, orientation='minus', exon_count=3, OMIM=[618255], no_hdr0=''),
    57463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57463, CurrentID=0, Status='live', Symbol='AMIGO1', Aliases=['ALI2', 'AMIGO', 'AMIGO-1'], description='adhesion molecule with Ig like domain 1', other_designations='amphoterin-induced protein 1|alivin-2|amphoterin-induced gene and ORF', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109504178, end_position_on_the_genomic_accession=109509742, orientation='minus', exon_count=2, OMIM=[615689], no_hdr0=''),
    57464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57464, CurrentID=0, Status='live', Symbol='STRIP2', Aliases=['FAM40B', 'FAR11B'], description='striatin interacting protein 2', other_designations='striatin-interacting protein 2|FAR11 factor arrest 11 homolog B|family with sequence similarity 40, member B|homolog of yeast FAR11 protein 2|protein FAM40B', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129434432, end_position_on_the_genomic_accession=129488399, orientation='plus', exon_count=24, OMIM=[617919], no_hdr0=''),
    57465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57465, CurrentID=0, Status='live', Symbol='TBC1D24', Aliases=['DEE16', 'DFNA65', 'DFNB86', 'DOORS', 'EIEE16', 'EPRPDC', 'FIME', 'TLDC6'], description='TBC1 domain family member 24', other_designations='TBC1 domain family member 24|TBC/LysM-associated domain containing 6|skywalker homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2475104, end_position_on_the_genomic_accession=2509669, orientation='plus', exon_count=10, OMIM=[613577], no_hdr0=''),
    57466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57466, CurrentID=0, Status='live', Symbol='SCAF4', Aliases=['SFRS15', 'SRA4'], description='SR-related CTD associated factor 4', other_designations='SR-related and CTD-associated factor 4|CTD-binding SR-like protein rA4|SR-like CTD-associated factor 4|pre-mRNA splicing SR protein rA4|splicing factor serine alanine 15|splicing factor, arginine/serine-rich 15', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=31668987, end_position_on_the_genomic_accession=31732118, orientation='minus', exon_count=20, OMIM=[616023], no_hdr0=''),
    57467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57467, CurrentID=0, Status='live', Symbol='HHATL', Aliases=['C3orf3', 'GUP1', 'MBOAT3', 'MSTP002', 'OACT3'], description='hedgehog acyltransferase like', other_designations='protein-cysteine N-palmitoyltransferase HHAT-like protein|GUP1 glycerol uptake/transporter homolog|glycerol uptake/transporter homolog|hedgehog acyltransferase-like protein|membrane bound O-acyltransferase domain containing 3', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42692663, end_position_on_the_genomic_accession=42702849, orientation='minus', exon_count=14, OMIM=[608116], no_hdr0=''),
    57468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57468, CurrentID=0, Status='live', Symbol='SLC12A5', Aliases=['DEE34', 'EIEE34', 'EIG14', 'KCC2', 'hKCC2'], description='solute carrier family 12 member 5', other_designations='solute carrier family 12 member 5|K-Cl cotransporter 2|electroneutral potassium-chloride cotransporter 2|erythroid K-Cl cotransporter 2|neuronal K-Cl cotransporter|solute carrier family 12 (potassium/chloride transporter), member 5', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46021686, end_position_on_the_genomic_accession=46060150, orientation='plus', exon_count=27, OMIM=[606726], no_hdr0=''),
    57469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57469, CurrentID=0, Status='live', Symbol='PNMA8B', Aliases=['PNMAL2'], description='PNMA family member 8B', other_designations='paraneoplastic antigen-like protein 8B|PNMA-like 2|PNMA-like protein 2|paraneoplastic Ma antigen family like 2|paraneoplastic Ma antigen family member 8B', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46491191, end_position_on_the_genomic_accession=46495867, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    57470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57470, CurrentID=0, Status='live', Symbol='LRRC47', Aliases=[], description='leucine rich repeat containing 47', other_designations='leucine-rich repeat-containing protein 47', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3778559, end_position_on_the_genomic_accession=3796498, orientation='minus', exon_count=7, OMIM=[619154], no_hdr0=''),
    57471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57471, CurrentID=0, Status='live', Symbol='ERMN', Aliases=['JN', 'KIAA1189'], description='ermin', other_designations='ermin|ermin, ERM-like protein|juxtanodin', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157318631, end_position_on_the_genomic_accession=157327712, orientation='minus', exon_count=5, OMIM=[610072], no_hdr0=''),
    57472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57472, CurrentID=0, Status='live', Symbol='CNOT6', Aliases=['CCR4', 'Ccr4a'], description='CCR4-NOT transcription complex subunit 6', other_designations='CCR4-NOT transcription complex subunit 6|carbon catabolite repression 4 protein|carbon catabolite repressor protein 4 homolog|cytoplasmic deadenylase', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180494373, end_position_on_the_genomic_accession=180578358, orientation='plus', exon_count=16, OMIM=[608951], no_hdr0=''),
    57473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57473, CurrentID=0, Status='live', Symbol='ZNF512B', Aliases=['GM632'], description='zinc finger protein 512B', other_designations='zinc finger protein 512B', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63956703, end_position_on_the_genomic_accession=63969930, orientation='minus', exon_count=20, OMIM=[617886], no_hdr0=''),
    57474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57474, CurrentID=0, Status='live', Symbol='ZNF490', Aliases=[], description='zinc finger protein 490', other_designations='zinc finger protein 490', map_location='19p13.2-p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12576100, end_position_on_the_genomic_accession=12610813, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    57475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57475, CurrentID=0, Status='live', Symbol='PLEKHH1', Aliases=[], description='pleckstrin homology, MyTH4 and FERM domain containing H1', other_designations='pleckstrin homology domain-containing family H member 1|PH domain-containing family H member 1|pleckstrin homology domain containing, family H (with MyTH4 domain) member 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67533155, end_position_on_the_genomic_accession=67589766, orientation='plus', exon_count=31, OMIM=[], no_hdr0=''),
    57476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57476, CurrentID=0, Status='live', Symbol='GRAMD1B', Aliases=['LINC01059'], description='GRAM domain containing 1B', other_designations='protein Aster-B|GRAM domain-containing protein 1B|long intergenic non-protein coding RNA 1059', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123358299, end_position_on_the_genomic_accession=123627770, orientation='plus', exon_count=34, OMIM=[], no_hdr0=''),
    57477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57477, CurrentID=0, Status='live', Symbol='SHROOM4', Aliases=['SHAP', 'shrm4'], description='shroom family member 4', other_designations='protein Shroom4|second homolog of apical protein', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=50575534, end_position_on_the_genomic_accession=50814194, orientation='minus', exon_count=14, OMIM=[300579], no_hdr0=''),
    57478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57478, CurrentID=0, Status='live', Symbol='USP31', Aliases=[], description='ubiquitin specific peptidase 31', other_designations='ubiquitin carboxyl-terminal hydrolase 31|deubiquitinating enzyme 31|ubiquitin specific proteinase 31|ubiquitin thioesterase 31|ubiquitin thiolesterase 31|ubiquitin-specific-processing protease 31', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23061406, end_position_on_the_genomic_accession=23149452, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    57479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57479, CurrentID=0, Status='live', Symbol='PRR12', Aliases=['KIAA1205'], description='proline rich 12', other_designations='proline-rich protein 12', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49591177, end_position_on_the_genomic_accession=49626439, orientation='plus', exon_count=14, OMIM=[616633], no_hdr0=''),
    57480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57480, CurrentID=0, Status='live', Symbol='PLEKHG1', Aliases=['ARHGEF41'], description='pleckstrin homology and RhoGEF domain containing G1', other_designations='pleckstrin homology domain-containing family G member 1|pleckstrin homology domain containing, family G (with RhoGef domain) member 1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150599885, end_position_on_the_genomic_accession=150843665, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    57481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57481, CurrentID=0, Status='live', Symbol='KIAA1210', Aliases=[], description='KIAA1210', other_designations='acrosomal protein KIAA1210', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119078635, end_position_on_the_genomic_accession=119151083, orientation='minus', exon_count=16, OMIM=[300995], no_hdr0=''),
    57482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57482, CurrentID=0, Status='live', Symbol='CRACD', Aliases=['CRAD', 'KIAA1211'], description='capping protein inhibiting regulator of actin dynamics', other_designations='capping protein-inhibiting regulator of actin dynamics|capping protein inhibiting regulator of actin dynamics|cancer-related regulator of actin dynamics', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56049098, end_position_on_the_genomic_accession=56330622, orientation='plus', exon_count=18, OMIM=[618327], no_hdr0=''),
    57484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57484, CurrentID=0, Status='live', Symbol='RNF150', Aliases=[], description='ring finger protein 150', other_designations='RING finger protein 150', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140859807, end_position_on_the_genomic_accession=141212858, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    57486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57486, CurrentID=0, Status='live', Symbol='NLN', Aliases=['AGTBP', 'EP24.16', 'MEP', 'MOP'], description='neurolysin', other_designations='neurolysin, mitochondrial|angiotensin binding protein|endopeptidase 24.16|microsomal endopeptidase|mitochondrial oligopeptidase M|neurolysin (metallopeptidase M3 family)|neurotensin endopeptidase', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65722205, end_position_on_the_genomic_accession=65829283, orientation='plus', exon_count=14, OMIM=[611530], no_hdr0=''),
    57488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57488, CurrentID=0, Status='live', Symbol='ESYT2', Aliases=['CHR2SYT', 'E-Syt2', 'FAM62B'], description='extended synaptotagmin 2', other_designations='extended synaptotagmin-2|chr2 synaptotagmin|extended synaptotagmin like protein 2|extended synaptotagmin protein 2|family with sequence similarity 62 (C2 domain containing), member B', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=158730997, end_position_on_the_genomic_accession=158829577, orientation='minus', exon_count=26, OMIM=[616691], no_hdr0=''),
    57489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57489, CurrentID=0, Status='live', Symbol='ODF2L', Aliases=[], description='outer dense fiber of sperm tails 2 like', other_designations='protein BCAP|basal body centriole-associated protein', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=86346837, end_position_on_the_genomic_accession=86396323, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    57491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57491, CurrentID=0, Status='live', Symbol='AHRR', Aliases=['AHH', 'AHHR', 'bHLHe77'], description='aryl-hydrocarbon receptor repressor', other_designations='aryl hydrocarbon receptor repressor|ahR repressor|aryl hydrocarbon hydroxylase regulator|class E basic helix-loop-helix protein 77|dioxin receptor repressor', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=321714, end_position_on_the_genomic_accession=438285, orientation='plus', exon_count=12, OMIM=[606517], no_hdr0=''),
    57492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57492, CurrentID=0, Status='live', Symbol='ARID1B', Aliases=['6A3-5', 'BAF250B', 'BRIGHT', 'CSS1', 'DAN15', 'ELD/OSA1', 'MRD12', 'OSA2', 'P250R'], description='AT-rich interaction domain 1B', other_designations='AT-rich interactive domain-containing protein 1B|ARID domain-containing protein 1B|AT rich interactive domain 1B (SWI1-like)|BRG1-associated factor 250b|BRG1-binding protein ELD/OSA1|ELD (eyelid)/OSA protein', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=156776026, end_position_on_the_genomic_accession=157210779, orientation='plus', exon_count=25, OMIM=[614556], no_hdr0=''),
    57493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57493, CurrentID=0, Status='live', Symbol='HEG1', Aliases=['HEG', 'MST112', 'MSTP112'], description='heart development protein with EGF like domains 1', other_designations='protein HEG homolog 1|heart of glass', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=124965710, end_position_on_the_genomic_accession=125055997, orientation='minus', exon_count=18, OMIM=[614182], no_hdr0=''),
    57494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57494, CurrentID=0, Status='live', Symbol='RIMKLB', Aliases=['FAM80B', 'NAAGS', 'NAAGS-I'], description='ribosomal modification protein rimK like family member B', other_designations='beta-citrylglutamate synthase B|N-acetyl-aspartyl-glutamate synthetase B|N-acetyl-aspartylglutamate synthetase B|N-acetylaspartyl-glutamate synthetase B|NAAG synthetase B|beta-citryl-glutamate synthase B|family with sequence similarity 80, member B|ribosomal protein S6 modification-like protein B', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8681600, end_position_on_the_genomic_accession=8783095, orientation='plus', exon_count=13, OMIM=[614054], no_hdr0=''),
    57495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57495, CurrentID=0, Status='live', Symbol='NWD2', Aliases=['KIAA1239'], description='NACHT and WD repeat domain containing 2', other_designations='NACHT and WD repeat domain-containing protein 2', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37244743, end_position_on_the_genomic_accession=37449463, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    57496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57496, CurrentID=0, Status='live', Symbol='MRTFB', Aliases=['MKL2', 'MRTF-B', 'NPD001'], description='myocardin related transcription factor B', other_designations='myocardin-related transcription factor B|CTA-276F8.1|MKL and myocardin family member 2|MKL/myocardin like 2|MKL/myocardin-like protein 2|MKL1/myocardin like 2|megakaryoblastic leukemia 2', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14071062, end_position_on_the_genomic_accession=14266779, orientation='plus', exon_count=25, OMIM=[609463], no_hdr0=''),
    57497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57497, CurrentID=0, Status='live', Symbol='LRFN2', Aliases=['FIGLER2', 'KIAA1246', 'SALM1'], description='leucine rich repeat and fibronectin type III domain containing 2', other_designations='leucine-rich repeat and fibronectin type-III domain-containing protein 2|fibronectin type III, immunoglobulin and leucine rich repeat domains 2|synaptic adhesion-like molecule 1', map_location='6p21.2-p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=40391589, end_position_on_the_genomic_accession=40587364, orientation='minus', exon_count=10, OMIM=[612808], no_hdr0=''),
    57498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57498, CurrentID=0, Status='live', Symbol='KIDINS220', Aliases=['ARMS', 'SINO'], description='kinase D interacting substrate 220', other_designations='kinase D-interacting substrate of 220 kDa|ankyrin repeat-rich membrane-spanning protein|kinase D-interacting substrate 220kDa', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=8721081, end_position_on_the_genomic_accession=8837613, orientation='minus', exon_count=35, OMIM=[615759], no_hdr0=''),
    57501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57501, CurrentID=0, Status='live', Symbol='CFAP92', Aliases=['FAP92', 'KIAA1257'], description='cilia and flagella associated protein 92 (putative)', other_designations='uncharacterized protein KIAA1257|putative cilia and flagella associated protein 92', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128909873, end_position_on_the_genomic_accession=129032431, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    57502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57502, CurrentID=0, Status='live', Symbol='NLGN4X', Aliases=['ASPGX2', 'AUTSX2', 'HLNX', 'HNL4X', 'NLGN4'], description='neuroligin 4 X-linked', other_designations='neuroligin-4, X-linked', map_location='Xp22.32-p22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=5890042, end_position_on_the_genomic_accession=6228878, orientation='minus', exon_count=13, OMIM=[300427], no_hdr0=''),
    57504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57504, CurrentID=0, Status='live', Symbol='MTA3', Aliases=[], description='metastasis associated 1 family member 3', other_designations='metastasis-associated protein MTA3|metastasis associated gene family, member 3', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42494110, end_position_on_the_genomic_accession=42756946, orientation='plus', exon_count=20, OMIM=[609050], no_hdr0=''),
    57505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57505, CurrentID=0, Status='live', Symbol='AARS2', Aliases=['AARSL', 'COXPD8', 'LKENP', 'MT-ALARS', 'MTALARS'], description='alanyl-tRNA synthetase 2, mitochondrial', other_designations='alanine--tRNA ligase, mitochondrial|alanine tRNA ligase 2, mitochondrial (putative)|alanyl-tRNA synthetase 2, mitochondrial (putative)|alanyl-tRNA synthetase like|probable alanyl-tRNA synthetase, mitochondrial', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44297850, end_position_on_the_genomic_accession=44313358, orientation='minus', exon_count=23, OMIM=[612035], no_hdr0=''),
    57506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57506, CurrentID=0, Status='live', Symbol='MAVS', Aliases=['CARDIF', 'IPS-1', 'IPS1', 'VISA'], description='mitochondrial antiviral signaling protein', other_designations='mitochondrial antiviral-signaling protein|CARD adapter inducing interferon beta|CARD adaptor inducing IFN-beta|IFN-B promoter stimulator 1|interferon beta promoter stimulator protein 1|putative NF-kappa-B-activating protein 031N|virus-induced signaling adaptor|virus-induced-signaling adapter', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3846834, end_position_on_the_genomic_accession=3876118, orientation='plus', exon_count=8, OMIM=[609676], no_hdr0=''),
    57507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57507, CurrentID=0, Status='live', Symbol='ZNF608', Aliases=['NY-REN-36'], description='zinc finger protein 608', other_designations='zinc finger protein 608|renal carcinoma antigen NY-REN-36', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=124636913, end_position_on_the_genomic_accession=124748824, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    57508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57508, CurrentID=0, Status='live', Symbol='INTS2', Aliases=['INT2', 'KIAA1287'], description='integrator complex subunit 2', other_designations='integrator complex subunit 2', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61865367, end_position_on_the_genomic_accession=61927982, orientation='minus', exon_count=27, OMIM=[611346], no_hdr0=''),
    57509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57509, CurrentID=0, Status='live', Symbol='MTUS1', Aliases=['ATBP', 'ATIP', 'ATIP3', 'ICIS', 'MP44', 'MTSG1'], description='microtubule associated scaffold protein 1', other_designations='microtubule-associated tumor suppressor 1|AT2 receptor-binding protein|AT2 receptor-interacting protein|AT2R binding protein|angiotensin-II type 2 receptor-interacting protein|erythroid differentiation-related|microtubule associated tumor suppressor 1|mitochondrial tumor suppressor gene 1|transcription factor MTSG1', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17643794, end_position_on_the_genomic_accession=17801521, orientation='minus', exon_count=27, OMIM=[609589], no_hdr0=''),
    57510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57510, CurrentID=0, Status='live', Symbol='XPO5', Aliases=['exp5'], description='exportin 5', other_designations='exportin-5|ran-binding protein 21', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43522334, end_position_on_the_genomic_accession=43576038, orientation='minus', exon_count=33, OMIM=[607845], no_hdr0=''),
    57511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57511, CurrentID=0, Status='live', Symbol='COG6', Aliases=['CDG2L', 'COD2', 'SHNS'], description='component of oligomeric golgi complex 6', other_designations='conserved oligomeric Golgi complex subunit 6|COG complex subunit 6|complexed with Dor1p 2|conserved oligomeric Golgi complex protein 6|testicular tissue protein Li 41', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=39655627, end_position_on_the_genomic_accession=39791666, orientation='plus', exon_count=22, OMIM=[606977], no_hdr0=''),
    57512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57512, CurrentID=0, Status='live', Symbol='GPR158', Aliases=[], description='G protein-coupled receptor 158', other_designations='probable G-protein coupled receptor 158', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=25174737, end_position_on_the_genomic_accession=25602229, orientation='plus', exon_count=13, OMIM=[614573], no_hdr0=''),
    57513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57513, CurrentID=0, Status='live', Symbol='CASKIN2', Aliases=['ANKS5B'], description='CASK interacting protein 2', other_designations='caskin-2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75500261, end_position_on_the_genomic_accession=75515537, orientation='minus', exon_count=21, OMIM=[612185], no_hdr0=''),
    57514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57514, CurrentID=0, Status='live', Symbol='ARHGAP31', Aliases=['AOS1', 'CDGAP'], description='Rho GTPase activating protein 31', other_designations='rho GTPase-activating protein 31|Cdc42 GTPase-activating protein', map_location='3q13.32-q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119294289, end_position_on_the_genomic_accession=119420714, orientation='plus', exon_count=12, OMIM=[610911], no_hdr0=''),
    57515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57515, CurrentID=0, Status='live', Symbol='SERINC1', Aliases=['TDE1L', 'TDE2', 'TMS-2', 'TMS2'], description='serine incorporator 1', other_designations='serine incorporator 1|tumor differentially expressed protein 2', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122443351, end_position_on_the_genomic_accession=122471807, orientation='minus', exon_count=10, OMIM=[614548], no_hdr0=''),
    57519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57519, CurrentID=0, Status='live', Symbol='STARD9', Aliases=['KIF16A'], description='StAR related lipid transfer domain containing 9', other_designations='stAR-related lipid transfer protein 9|START domain-containing protein 9|StAR-related lipid transfer (START) domain containing 9', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42575606, end_position_on_the_genomic_accession=42720998, orientation='plus', exon_count=36, OMIM=[614642], no_hdr0=''),
    57520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57520, CurrentID=0, Status='live', Symbol='HECW2', Aliases=['NDHSAL', 'NEDL2'], description='HECT, C2 and WW domain containing E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase HECW2|HECT-type E3 ubiquitin transferase HECW2|NEDD4-like E3 ubiquitin-protein ligase 2|NEDD4-related E3 ubiquitin ligase NEDL2', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196194072, end_position_on_the_genomic_accession=196593692, orientation='minus', exon_count=31, OMIM=[617245], no_hdr0=''),
    57521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57521, CurrentID=0, Status='live', Symbol='RPTOR', Aliases=['KOG1', 'Mip1'], description='regulatory associated protein of MTOR complex 1', other_designations='regulatory-associated protein of mTOR|p150 target of rapamycin (TOR)-scaffold protein containing WD-repeats|raptor', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80544838, end_position_on_the_genomic_accession=80966368, orientation='plus', exon_count=34, OMIM=[607130], no_hdr0=''),
    57522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57522, CurrentID=0, Status='live', Symbol='SRGAP1', Aliases=['ARHGAP13', 'NMTC2'], description='SLIT-ROBO Rho GTPase activating protein 1', other_designations='SLIT-ROBO Rho GTPase-activating protein 1|rho GTPase-activating protein 13', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=63843911, end_position_on_the_genomic_accession=64162217, orientation='plus', exon_count=25, OMIM=[606523], no_hdr0=''),
    57523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57523, CurrentID=0, Status='live', Symbol='NYNRIN', Aliases=['CGIN1', 'KIAA1305'], description='NYN domain and retroviral integrase containing', other_designations='protein NYNRIN|Cousin of GIN1|NYN domain and retroviral integrase catalytic domain-containing protein|protein cousin of GIN1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24399003, end_position_on_the_genomic_accession=24419283, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    57524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57524, CurrentID=0, Status='live', Symbol='CASKIN1', Aliases=['ANKS5A'], description='CASK interacting protein 1', other_designations='caskin-1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2177180, end_position_on_the_genomic_accession=2196605, orientation='minus', exon_count=20, OMIM=[612184], no_hdr0=''),
    57526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57526, CurrentID=0, Status='live', Symbol='PCDH19', Aliases=['DEE9', 'EFMR', 'EIEE9'], description='protocadherin 19', other_designations='protocadherin-19', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100291644, end_position_on_the_genomic_accession=100410273, orientation='minus', exon_count=6, OMIM=[300460], no_hdr0=''),
    57528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57528, CurrentID=0, Status='live', Symbol='KCTD16', Aliases=[], description='potassium channel tetramerization domain containing 16', other_designations='BTB/POZ domain-containing protein KCTD16|potassium channel tetramerisation domain containing 16|potassium channel tetramerization domain-containing protein 16', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=144170723, end_position_on_the_genomic_accession=144485686, orientation='plus', exon_count=8, OMIM=[613423], no_hdr0=''),
    57529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57529, CurrentID=0, Status='live', Symbol='RTL9', Aliases=['MAR9', 'MART9', 'RGAG1', 'SIRH10'], description='retrotransposon Gag like 9', other_designations='retrotransposon Gag-like protein 9|Sushi-Ichi retrotransposon homolog 10|mammalian retrotransposon-derived 9|retrotransposon gag domain containing 1|retrotransposon gag domain-containing protein 1|tumor antigen BJ-HCC-23|tumor antigen BJHCC23', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=110358101, end_position_on_the_genomic_accession=110456334, orientation='plus', exon_count=6, OMIM=[300965], no_hdr0=''),
    57530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57530, CurrentID=0, Status='live', Symbol='CGN', Aliases=[], description='cingulin', other_designations='cingulin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151510858, end_position_on_the_genomic_accession=151538692, orientation='plus', exon_count=22, OMIM=[609473], no_hdr0=''),
    57531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57531, CurrentID=0, Status='live', Symbol='HACE1', Aliases=['SPPRS'], description='HECT domain and ankyrin repeat containing E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase HACE1|HECT-type E3 ubiquitin transferase HACE1', map_location='6q16.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=104728094, end_position_on_the_genomic_accession=104859919, orientation='minus', exon_count=27, OMIM=[610876], no_hdr0=''),
    57532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57532, CurrentID=0, Status='live', Symbol='NUFIP2', Aliases=['182-FIP', '82-FIP', 'FIP-82', 'PIG1'], description='nuclear FMR1 interacting protein 2', other_designations='nuclear fragile X mental retardation-interacting protein 2|82 kDa FMRP-interacting protein|82-kD FMRP Interacting Protein|FMRP-interacting protein 2|Fragile X Mental Retardation Protein|NUFIP2, FMR1 interacting protein 2|cell proliferation-inducing gene 1 protein|nuclear fragile X mental retardation protein interacting protein 2|proliferation-inducing gene 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29255839, end_position_on_the_genomic_accession=29294148, orientation='minus', exon_count=5, OMIM=[609356], no_hdr0=''),
    57533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57533, CurrentID=0, Status='live', Symbol='TBC1D14', Aliases=[], description='TBC1 domain family member 14', other_designations='TBC1 domain family member 14', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6909444, end_position_on_the_genomic_accession=7033114, orientation='plus', exon_count=22, OMIM=[614855], no_hdr0=''),
    57534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57534, CurrentID=0, Status='live', Symbol='MIB1', Aliases=['DIP-1', 'DIP1', 'LVNC7', 'MIB', 'ZZANK2', 'ZZZ6'], description='MIB E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase MIB1|DAPK-interacting protein 1|RING-type E3 ubiquitin transferase MIB1|mindbomb E3 ubiquitin protein ligase 1|ubiquitin ligase mind bomb|zinc finger ZZ type with ankyrin repeat domain protein 2', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=21740792, end_position_on_the_genomic_accession=21870953, orientation='plus', exon_count=26, OMIM=[608677], no_hdr0=''),
    57535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57535, CurrentID=0, Status='live', Symbol='ELAPOR1', Aliases=['EIG121', 'KIAA1324'], description='endosome-lysosome associated apoptosis and autophagy regulator 1', other_designations='endosome/lysosome-associated apoptosis and autophagy regulator 1|estrogen-induced gene 121 protein|maba1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109114106, end_position_on_the_genomic_accession=109206781, orientation='plus', exon_count=24, OMIM=[611298], no_hdr0=''),
    57536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57536, CurrentID=0, Status='live', Symbol='KIAA1328', Aliases=[], description='KIAA1328', other_designations='protein hinderin|hinderin', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36828817, end_position_on_the_genomic_accession=37232172, orientation='plus', exon_count=24, OMIM=[616480], no_hdr0=''),
    57537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57537, CurrentID=0, Status='live', Symbol='SORCS2', Aliases=[], description='sortilin related VPS10 domain containing receptor 2', other_designations='VPS10 domain-containing receptor SorCS2|VPS10 domain receptor protein', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7192538, end_position_on_the_genomic_accession=7742828, orientation='plus', exon_count=29, OMIM=[606284], no_hdr0=''),
    57538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57538, CurrentID=0, Status='live', Symbol='ALPK3', Aliases=['CMH27', 'MAK', 'MIDORI'], description='alpha kinase 3', other_designations='alpha-protein kinase 3|muscle alpha-kinase|muscle alpha-protein kinase|myocyte induction differentiation originator', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84817356, end_position_on_the_genomic_accession=84873479, orientation='plus', exon_count=14, OMIM=[617608], no_hdr0=''),
    57539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57539, CurrentID=0, Status='live', Symbol='WDR35', Aliases=['CED2', 'FAP118', 'IFT121', 'IFTA1', 'SRTD7'], description='WD repeat domain 35', other_designations='WD repeat-containing protein 35|intraflagellar transport protein 121 homolog|naofen', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=19910260, end_position_on_the_genomic_accession=19990105, orientation='minus', exon_count=29, OMIM=[613602], no_hdr0=''),
    57540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57540, CurrentID=0, Status='live', Symbol='DISP3', Aliases=['PTCHD2'], description='dispatched RND transporter family member 3', other_designations='protein dispatched homolog 3|dispatched 3|dispatched homolog 3|patched domain containing 2|patched domain-containing protein 2', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11479155, end_position_on_the_genomic_accession=11537583, orientation='plus', exon_count=24, OMIM=[611251], no_hdr0=''),
    57541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57541, CurrentID=0, Status='live', Symbol='ZNF398', Aliases=['P51', 'P71', 'ZER6'], description='zinc finger protein 398', other_designations='zinc finger protein 398|zinc finger DNA binding protein ZER6|zinc finger DNA binding protein p52/p71|zinc finger-estrogen receptor interaction, clone 6', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149126408, end_position_on_the_genomic_accession=149183042, orientation='plus', exon_count=12, OMIM=[618593], no_hdr0=''),
    57542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57542, CurrentID=0, Status='live', Symbol='KLHL42', Aliases=['Ctb9', 'KLHDC5'], description='kelch like family member 42', other_designations='kelch-like protein 42|cullin-3-binding protein 9|kelch domain containing 5|kelch domain-containing protein 5', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27780233, end_position_on_the_genomic_accession=27803040, orientation='plus', exon_count=5, OMIM=[618919], no_hdr0=''),
    57544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57544, CurrentID=0, Status='live', Symbol='TXNDC16', Aliases=['ERp90', 'KIAA1344'], description='thioredoxin domain containing 16', other_designations='thioredoxin domain-containing protein 16', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52430594, end_position_on_the_genomic_accession=52552563, orientation='minus', exon_count=24, OMIM=[616179], no_hdr0=''),
    57545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57545, CurrentID=0, Status='live', Symbol='CC2D2A', Aliases=['COACH2', 'JBTS9', 'MKS6'], description='coiled-coil and C2 domain containing 2A', other_designations='coiled-coil and C2 domain-containing protein 2A', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15468660, end_position_on_the_genomic_accession=15601557, orientation='plus', exon_count=40, OMIM=[612013], no_hdr0=''),
    57546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57546, CurrentID=0, Status='live', Symbol='PDP2', Aliases=['PDPC 2', 'PPM2B', 'PPM2C2'], description='pyruvate dehyrogenase phosphatase catalytic subunit 2', other_designations='[Pyruvate dehydrogenase [acetyl-transferring]]-phosphatase 2, mitochondrial|protein phosphatase 2C, magnesium-dependent, catalytic subunit 2|protein phosphatase, Mg2+/Mn2+ dependent 2B|pyruvate dehydrogenase phosphatase isoenzyme 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66880515, end_position_on_the_genomic_accession=66891101, orientation='plus', exon_count=3, OMIM=[615499], no_hdr0=''),
    57547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57547, CurrentID=0, Status='live', Symbol='ZNF624', Aliases=[], description='zinc finger protein 624', other_designations='zinc finger protein 624', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16620734, end_position_on_the_genomic_accession=16655210, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    57549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57549, CurrentID=0, Status='live', Symbol='IGSF9', Aliases=['FP18798A', 'Nrt1', 'IGSF9'], description='immunoglobulin superfamily member 9', other_designations='protein turtle homolog A|immunoglobulin superfamily member 9A', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159927041, end_position_on_the_genomic_accession=159945661, orientation='minus', exon_count=22, OMIM=[609738], no_hdr0=''),
    57551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57551, CurrentID=0, Status='live', Symbol='TAOK1', Aliases=['KFC-B', 'MAP3K16', 'MARKK', 'PSK-2', 'PSK2', 'TAO1', 'hKFC-B', 'hTAOK1'], description='TAO kinase 1', other_designations='serine/threonine-protein kinase TAO1|MARK Kinase|STE20-like kinase PSK2|kinase from chicken homolog B|microtubule affinity regulating kinase kinase|prostate-derived STE20-like kinase 2|prostate-derived sterile 20-like kinase 2|serine/threonine protein kinase TAO1 homolog|thousand and one amino acid protein 1|thousand and one amino acid protein kinase 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29390363, end_position_on_the_genomic_accession=29551903, orientation='plus', exon_count=20, OMIM=[610266], no_hdr0=''),
    57552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57552, CurrentID=0, Status='live', Symbol='NCEH1', Aliases=['AADACL1', 'NCEH'], description='neutral cholesterol ester hydrolase 1', other_designations='neutral cholesterol ester hydrolase 1|acetylalkylglycerol acetylhydrolase|alkylacetylglycerol acetylhydrolase|arylacetamide deacetylase-like 1', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172630249, end_position_on_the_genomic_accession=172711067, orientation='minus', exon_count=5, OMIM=[613234], no_hdr0=''),
    57553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57553, CurrentID=0, Status='live', Symbol='MICAL3', Aliases=['MICAL-3'], description='microtubule associated monooxygenase, calponin and LIM domain containing 3', other_designations='[F-actin]-monooxygenase MICAL3|[F-actin]-methionine sulfoxide oxidase MICAL3|flavoprotein oxidoreductase MICAL3|molecule interacting with CasL protein 3|protein MICAL-3|protein-methionine sulfoxide oxidase MICAL3', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17787649, end_position_on_the_genomic_accession=18024561, orientation='minus', exon_count=37, OMIM=[608882], no_hdr0=''),
    57554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57554, CurrentID=0, Status='live', Symbol='LRRC7', Aliases=['DENSIN'], description='leucine rich repeat containing 7', other_designations='leucine-rich repeat-containing protein 7|densin-180', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=69567922, end_position_on_the_genomic_accession=70144364, orientation='plus', exon_count=31, OMIM=[614453], no_hdr0=''),
    57555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57555, CurrentID=0, Status='live', Symbol='NLGN2', Aliases=[], description='neuroligin 2', other_designations='neuroligin-2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7405492, end_position_on_the_genomic_accession=7419860, orientation='plus', exon_count=8, OMIM=[606479], no_hdr0=''),
    57556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57556, CurrentID=0, Status='live', Symbol='SEMA6A', Aliases=['HT018', 'SEMA1', 'SEMAQ', 'VIA', 'SEMA6A'], description='semaphorin 6A', other_designations='semaphorin-6A|SEMA6A-1|sema VIa|sema domain, transmembrane domain (TM), and cytoplasmic domain, (semaphorin) 6A|semaphorin 6A-1|semaphorin VIA', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=116443555, end_position_on_the_genomic_accession=116574823, orientation='minus', exon_count=23, OMIM=[605885], no_hdr0=''),
    57558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57558, CurrentID=0, Status='live', Symbol='USP35', Aliases=[], description='ubiquitin specific peptidase 35', other_designations='ubiquitin carboxyl-terminal hydrolase 35|deubiquitinating enzyme 35|ubiquitin specific protease 35|ubiquitin thioesterase 35|ubiquitin thiolesterase 35|ubiquitin-specific-processing protease 35', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78188815, end_position_on_the_genomic_accession=78226184, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    57559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57559, CurrentID=0, Status='live', Symbol='STAMBPL1', Aliases=['ALMalpha', 'AMSH-FP', 'AMSH-LP', 'bA399O19.2'], description='STAM binding protein like 1', other_designations='AMSH-like protease|associated molecule with the SH3 domain of STAM (AMSH) - Family Protein|associated molecule with the SH3 domain of STAM (AMSH) like protein', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88879368, end_position_on_the_genomic_accession=88923502, orientation='plus', exon_count=17, OMIM=[612352], no_hdr0=''),
    57560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57560, CurrentID=0, Status='live', Symbol='IFT80', Aliases=['ATD2', 'FAP167', 'SRTD2', 'WDR56'], description='intraflagellar transport 80', other_designations='intraflagellar transport protein 80 homolog|WD repeat domain 56|WD repeat-containing protein 56|intraflagellar transport 80 homolog', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160256986, end_position_on_the_genomic_accession=160399225, orientation='minus', exon_count=21, OMIM=[611177], no_hdr0=''),
    57561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57561, CurrentID=0, Status='live', Symbol='ARRDC3', Aliases=['TLIMP'], description='arrestin domain containing 3', other_designations='arrestin domain-containing protein 3|TBP-2-like inducible membrane protein|alpha-arrestin 3', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=91368631, end_position_on_the_genomic_accession=91383332, orientation='minus', exon_count=9, OMIM=[612464], no_hdr0=''),
    57562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57562, CurrentID=0, Status='live', Symbol='CEP126', Aliases=['KIAA1377'], description='centrosomal protein 126', other_designations='centrosomal protein of 126 kDa|centrosomal protein 126kDa', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=101915010, end_position_on_the_genomic_accession=102001062, orientation='plus', exon_count=12, OMIM=[614634], no_hdr0=''),
    57563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57563, CurrentID=0, Status='live', Symbol='KLHL8', Aliases=[], description='kelch like family member 8', other_designations='kelch-like protein 8|kelch-like 8', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87160103, end_position_on_the_genomic_accession=87220618, orientation='minus', exon_count=11, OMIM=[611967], no_hdr0=''),
    57565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57565, CurrentID=0, Status='live', Symbol='KLHL14', Aliases=[], description='kelch like family member 14', other_designations='kelch-like protein 14|kelch-like 14|printor|protein interactor of Torsin-1A', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32672673, end_position_on_the_genomic_accession=32773023, orientation='minus', exon_count=11, OMIM=[613772], no_hdr0=''),
    57567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57567, CurrentID=0, Status='live', Symbol='ZNF319', Aliases=['ZFP319'], description='zinc finger protein 319', other_designations='zinc finger protein 319', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57994676, end_position_on_the_genomic_accession=58000672, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    57568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57568, CurrentID=0, Status='live', Symbol='SIPA1L2', Aliases=['SPAL2', 'SPAR2'], description='signal induced proliferation associated 1 like 2', other_designations='signal-induced proliferation-associated 1-like protein 2|SIPA1-like protein 2|SPA-1-like 2|spine-associated RapGAP 2', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=232397965, end_position_on_the_genomic_accession=232630496, orientation='minus', exon_count=25, OMIM=[611609], no_hdr0=''),
    57569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57569, CurrentID=0, Status='live', Symbol='ARHGAP20', Aliases=['RARHOGAP'], description='Rho GTPase activating protein 20', other_designations='rho GTPase-activating protein 20|RA and RhoGAP domain containing protein|rho GTPase activating protein 20 variant 2|rho-type GTPase-activating protein 20', map_location='11q22.3-q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=110577035, end_position_on_the_genomic_accession=110713189, orientation='minus', exon_count=20, OMIM=[609568], no_hdr0=''),
    57570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57570, CurrentID=0, Status='live', Symbol='TRMT5', Aliases=['COXPD26', 'KIAA1393', 'TRM5'], description='tRNA methyltransferase 5', other_designations='tRNA (guanine(37)-N1)-methyltransferase|M1G-methyltransferase|TRM5 tRNA methyltransferase 5 homolog|tRNA (guanine-N(1)-)-methyltransferase|tRNA [GM37] methyltransferase|tRNA-N1G37 methyltransferase', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60971441, end_position_on_the_genomic_accession=60981690, orientation='minus', exon_count=5, OMIM=[611023], no_hdr0=''),
    57571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57571, CurrentID=0, Status='live', Symbol='CARNS1', Aliases=['ATPGD1'], description='carnosine synthase 1', other_designations='carnosine synthase 1|ATP-grasp domain containing 1|ATP-grasp domain-containing protein 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67415678, end_position_on_the_genomic_accession=67425607, orientation='plus', exon_count=10, OMIM=[613368], no_hdr0=''),
    57572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57572, CurrentID=0, Status='live', Symbol='DOCK6', Aliases=['AOS2', 'ZIR1'], description='dedicator of cytokinesis 6', other_designations='dedicator of cytokinesis protein 6', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11199295, end_position_on_the_genomic_accession=11262524, orientation='minus', exon_count=51, OMIM=[614194], no_hdr0=''),
    57573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57573, CurrentID=0, Status='live', Symbol='ZNF471', Aliases=['ERP1', 'Z1971', 'Zfp78'], description='zinc finger protein 471', other_designations='zinc finger protein 471|EZFIT-related protein 1', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56507855, end_position_on_the_genomic_accession=56530212, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    57574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57574, CurrentID=0, Status='live', Symbol='MARCHF4', Aliases=['MARCH-IV', 'MARCH4', 'RNF174'], description='membrane associated ring-CH-type finger 4', other_designations='E3 ubiquitin-protein ligase MARCHF4|E3 ubiquitin-protein ligase MARCH4|RING finger protein 174|RING-type E3 ubiquitin transferase MARCH4|RING-type E3 ubiquitin transferase MARCHF4|membrane associated ring finger 4|membrane-associated RING finger protein 4|membrane-associated RING-CH protein IV|membrane-associated ring finger (C3HC4) 4, E3 ubiquitin protein ligase', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216257865, end_position_on_the_genomic_accession=216372483, orientation='minus', exon_count=4, OMIM=[608208], no_hdr0=''),
    57575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57575, CurrentID=0, Status='live', Symbol='PCDH10', Aliases=['OL-PCDH', 'PCDH19'], description='protocadherin 10', other_designations='protocadherin-10', map_location='4q28.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=133149294, end_position_on_the_genomic_accession=133208606, orientation='plus', exon_count=6, OMIM=[608286], no_hdr0=''),
    57576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57576, CurrentID=0, Status='live', Symbol='KIF17', Aliases=['KIF17B', 'KIF3X', 'KLP-2', 'OSM-3'], description='kinesin family member 17', other_designations='kinesin-like protein KIF17|KIF17 variant protein|KIF3-related motor protein', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20664014, end_position_on_the_genomic_accession=20718007, orientation='minus', exon_count=15, OMIM=[605037], no_hdr0=''),
    57577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57577, CurrentID=0, Status='live', Symbol='CCDC191', Aliases=['KIAA1407'], description='coiled-coil domain containing 191', other_designations='coiled-coil domain-containing protein 191', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113964137, end_position_on_the_genomic_accession=114056613, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    57578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57578, CurrentID=0, Status='live', Symbol='UNC79', Aliases=['KIAA1409'], description='unc-79 homolog, NALCN channel complex subunit', other_designations='protein unc-79 homolog', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93333182, end_position_on_the_genomic_accession=93710473, orientation='plus', exon_count=60, OMIM=[616884], no_hdr0=''),
    57579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57579, CurrentID=0, Status='live', Symbol='FAM135A', Aliases=['KIAA1411'], description='family with sequence similarity 135 member A', other_designations='protein FAM135A', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=70413434, end_position_on_the_genomic_accession=70561174, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    57580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57580, CurrentID=0, Status='live', Symbol='PREX1', Aliases=['P-REX1'], description='phosphatidylinositol-3,4,5-trisphosphate dependent Rac exchange factor 1', other_designations='phosphatidylinositol 3,4,5-trisphosphate-dependent Rac exchanger 1 protein|PIP3 dependent Rac exchange factor 1|ptdIns(3,4,5)-dependent Rac exchanger 1', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=48624252, end_position_on_the_genomic_accession=48827999, orientation='minus', exon_count=40, OMIM=[606905], no_hdr0=''),
    57582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57582, CurrentID=0, Status='live', Symbol='KCNT1', Aliases=['DEE14', 'EIEE14', 'ENFL5', 'KCa4.1', 'SLACK', 'Slo2.2', 'bA100C15.2'], description='potassium sodium-activated channel subfamily T member 1', other_designations='potassium channel subfamily T member 1|Sequence like a calcium-activated K+ channel|potassium channel, sodium activated subfamily T, member 1|potassium channel, subfamily T, member 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135702185, end_position_on_the_genomic_accession=135795502, orientation='plus', exon_count=38, OMIM=[608167], no_hdr0=''),
    57583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57583, CurrentID=0, Status='live', Symbol='TMEM181', Aliases=['GPR178', 'KIAA1423'], description='transmembrane protein 181', other_designations='transmembrane protein 181|G protein-coupled receptor 178', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158536432, end_position_on_the_genomic_accession=158635433, orientation='plus', exon_count=20, OMIM=[613209], no_hdr0=''),
    57584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57584, CurrentID=0, Status='live', Symbol='ARHGAP21', Aliases=['ARHGAP10'], description='Rho GTPase activating protein 21', other_designations='rho GTPase-activating protein 21|Rho-GTPase activating protein 10|rho GTPase-activating protein 10|rho-type GTPase-activating protein 21', map_location='10p12.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=24583610, end_position_on_the_genomic_accession=24725421, orientation='minus', exon_count=33, OMIM=[609870], no_hdr0=''),
    57585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57585, CurrentID=0, Status='live', Symbol='CRAMP1', Aliases=['CRAMP1L', 'HN1L', 'TCE4'], description='cramped chromatin regulator homolog 1', other_designations='protein cramped-like|Crm, cramped-like|T-complex expressed gene 4|hematological and neurological expressed 1-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1612360, end_position_on_the_genomic_accession=1677908, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    57586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57586, CurrentID=0, Status='live', Symbol='SYT13', Aliases=[], description='synaptotagmin 13', other_designations='synaptotagmin-13|synaptotagmin XIII|sytXIII', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45240302, end_position_on_the_genomic_accession=45286341, orientation='minus', exon_count=8, OMIM=[607716], no_hdr0=''),
    57587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57587, CurrentID=0, Status='live', Symbol='CFAP97', Aliases=['KIAA1430', 'hmw'], description='cilia and flagella associated protein 97', other_designations='cilia- and flagella-associated protein 97', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185151723, end_position_on_the_genomic_accession=185205443, orientation='minus', exon_count=9, OMIM=[616047], no_hdr0=''),
    57589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57589, CurrentID=0, Status='live', Symbol='RIC1', Aliases=['CATIFA', 'CIP150', 'KIAA1432', 'bA207C16.1'], description='RIC1 homolog, RAB6A GEF complex partner 1', other_designations='guanine nucleotide exchange factor subunit RIC1|RAB6A GEF complex partner 1|RAB6A-GEF complex partner protein 1|connexin 43-interacting protein 150 kDa|connexin-43-interacting protein of 150 kDa|protein RIC1 homolog', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5629030, end_position_on_the_genomic_accession=5778633, orientation='plus', exon_count=28, OMIM=[610354], no_hdr0=''),
    57590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57590, CurrentID=0, Status='live', Symbol='WDFY1', Aliases=['FENS-1', 'FENS1', 'WDF1', 'ZFYVE17'], description='WD repeat and FYVE domain containing 1', other_designations='WD repeat and FYVE domain-containing protein 1|FYVE domain-containing protein localized to endosomes 1|WD40- and FYVE domain-containing protein 1|phosphoinositide-binding protein SR1|zinc finger FYVE domain-containing protein 17', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223875348, end_position_on_the_genomic_accession=223945335, orientation='minus', exon_count=12, OMIM=[618080], no_hdr0=''),
    57591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57591, CurrentID=0, Status='live', Symbol='MRTFA', Aliases=['BSAC', 'MAL', 'MKL', 'MKL1', 'MRTF-A'], description='myocardin related transcription factor A', other_designations='myocardin-related transcription factor A|MKL/myocardin-like protein 1|basic, SAP and coiled-coil domain|megakaryoblastic leukemia (translocation) 1|megakaryoblastic leukemia 1 protein|megakaryocytic acute leukemia protein', map_location='22q13.1-q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40410289, end_position_on_the_genomic_accession=40636719, orientation='minus', exon_count=16, OMIM=[606078], no_hdr0=''),
    57592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57592, CurrentID=0, Status='live', Symbol='ZNF687', Aliases=['PDB6'], description='zinc finger protein 687', other_designations='zinc finger protein 687', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151281522, end_position_on_the_genomic_accession=151292176, orientation='plus', exon_count=12, OMIM=[610568], no_hdr0=''),
    57593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57593, CurrentID=0, Status='live', Symbol='EBF4', Aliases=['COE4', 'O/E-4', 'OE-4'], description='EBF family member 4', other_designations='transcription factor COE4|early B cell factor 4|olf-1/EBF-like 4', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2692780, end_position_on_the_genomic_accession=2760108, orientation='plus', exon_count=19, OMIM=[609935], no_hdr0=''),
    57594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57594, CurrentID=0, Status='live', Symbol='HOMEZ', Aliases=['KIAA1443'], description='homeobox and leucine zipper encoding', other_designations='homeobox and leucine zipper protein Homez|homeodomain leucine zipper-containing factor', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23272422, end_position_on_the_genomic_accession=23286132, orientation='minus', exon_count=2, OMIM=[608119], no_hdr0=''),
    57595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57595, CurrentID=0, Status='live', Symbol='PDZD4', Aliases=['LNX5', 'LU1', 'PDZK4', 'PDZRN4L'], description='PDZ domain containing 4', other_designations='PDZ domain-containing protein 4|PDZ domain-containing RING finger protein 4-like protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153802166, end_position_on_the_genomic_accession=153830544, orientation='minus', exon_count=10, OMIM=[300634], no_hdr0=''),
    57596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57596, CurrentID=0, Status='live', Symbol='BEGAIN', Aliases=[], description='brain enriched guanylate kinase associated', other_designations='brain-enriched guanylate kinase-associated protein|brain-enriched guanylate kinase-associated homolog', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100537147, end_position_on_the_genomic_accession=100587417, orientation='minus', exon_count=14, OMIM=[618597], no_hdr0=''),
    57597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57597, CurrentID=0, Status='live', Symbol='BAHCC1', Aliases=['BAHD2'], description='BAH domain and coiled-coil containing 1', other_designations='BAH and coiled-coil domain-containing protein 1|BAH domain-containing protein 2|bromo adjacent homology domain-containing protein 2', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81395431, end_position_on_the_genomic_accession=81466331, orientation='plus', exon_count=30, OMIM=[617646], no_hdr0=''),
    57599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57599, CurrentID=0, Status='live', Symbol='WDR48', Aliases=['Bun62', 'P80', 'SPG60', 'UAF1'], description='WD repeat domain 48', other_designations='WD repeat-containing protein 48|USP1 associated factor 1|WD repeat endosomal protein|testicular tissue protein Li 224', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39052002, end_position_on_the_genomic_accession=39096666, orientation='plus', exon_count=22, OMIM=[612167], no_hdr0=''),
    57600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57600, CurrentID=0, Status='live', Symbol='FNIP2', Aliases=['FNIPL', 'MAPO1'], description='folliculin interacting protein 2', other_designations='folliculin-interacting protein 2|FNIP1-like protein|O6-methylguanine-induced apoptosis 1 protein', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158769026, end_position_on_the_genomic_accession=158908050, orientation='plus', exon_count=22, OMIM=[612768], no_hdr0=''),
    57602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57602, CurrentID=0, Status='live', Symbol='USP36', Aliases=['DUB1'], description='ubiquitin specific peptidase 36', other_designations='ubiquitin carboxyl-terminal hydrolase 36|deubiquitinating enzyme 36|ubiquitin specific protease 36|ubiquitin thioesterase 36|ubiquitin-specific-processing protease 36', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78787381, end_position_on_the_genomic_accession=78841439, orientation='minus', exon_count=28, OMIM=[612543], no_hdr0=''),
    57604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57604, CurrentID=0, Status='live', Symbol='TRMT9B', Aliases=['C8orf79', 'KIAA1456', 'TRM9L', 'hTRM9L'], description='tRNA methyltransferase 9B (putative)', other_designations='probable tRNA methyltransferase 9B|probable tRNA methyltransferase 9-like protein', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12945673, end_position_on_the_genomic_accession=13029777, orientation='plus', exon_count=12, OMIM=[615666], no_hdr0=''),
    57605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57605, CurrentID=0, Status='live', Symbol='PITPNM2', Aliases=['NIR-3', 'NIR3', 'RDGB2', 'RDGBA2'], description='phosphatidylinositol transfer protein membrane associated 2', other_designations='membrane-associated phosphatidylinositol transfer protein 2|PYK2 N-terminal domain-interacting receptor 3|retinal degeneration B alpha 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122983480, end_position_on_the_genomic_accession=123151090, orientation='minus', exon_count=31, OMIM=[608920], no_hdr0=''),
    57606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57606, CurrentID=0, Status='live', Symbol='SLAIN2', Aliases=['KIAA1458'], description='SLAIN motif family member 2', other_designations='SLAIN motif-containing protein 2', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48341475, end_position_on_the_genomic_accession=48426201, orientation='plus', exon_count=9, OMIM=[610492], no_hdr0=''),
    57608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57608, CurrentID=0, Status='live', Symbol='JCAD', Aliases=['KIAA1462'], description='junctional cadherin 5 associated', other_designations='junctional protein associated with coronary artery disease', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=30012803, end_position_on_the_genomic_accession=30115494, orientation='minus', exon_count=7, OMIM=[614398], no_hdr0=''),
    57609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57609, CurrentID=0, Status='live', Symbol='DIP2B', Aliases=[], description='disco interacting protein 2 homolog B', other_designations='disco-interacting protein 2 homolog B|DIP2 disco-interacting protein 2 homolog B', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50504985, end_position_on_the_genomic_accession=50748657, orientation='plus', exon_count=38, OMIM=[611379], no_hdr0=''),
    57610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57610, CurrentID=0, Status='live', Symbol='RANBP10', Aliases=[], description='RAN binding protein 10', other_designations='ran-binding protein 10', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67723068, end_position_on_the_genomic_accession=67806560, orientation='minus', exon_count=20, OMIM=[614031], no_hdr0=''),
    57611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57611, CurrentID=0, Status='live', Symbol='ISLR2', Aliases=['LINX'], description='immunoglobulin superfamily containing leucine rich repeat 2', other_designations='immunoglobulin superfamily containing leucine-rich repeat protein 2|leucine-rich repeat domain and immunoglobulin domain-containing axon extension protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74100314, end_position_on_the_genomic_accession=74141826, orientation='plus', exon_count=14, OMIM=[614179], no_hdr0=''),
    57613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57613, CurrentID=0, Status='live', Symbol='FAM234B', Aliases=['KIAA1467'], description='family with sequence similarity 234 member B', other_designations='protein FAM234B', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=13044381, end_position_on_the_genomic_accession=13083449, orientation='plus', exon_count=13, OMIM=[617838], no_hdr0=''),
    57614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57614, CurrentID=0, Status='live', Symbol='RELCH', Aliases=['HsT3308', 'HsT885', 'KIAA1468'], description='RAB11 binding and LisH domain, coiled-coil and HEAT repeat containing', other_designations='RAB11-binding protein RELCH|RAB11-binding protein containing LisH, coiled-coil, and HEAT repeats', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=62187255, end_position_on_the_genomic_accession=62310249, orientation='plus', exon_count=38, OMIM=[618001], no_hdr0=''),
    57615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57615, CurrentID=0, Status='live', Symbol='ZNF492', Aliases=['ZNF115'], description='zinc finger protein 492', other_designations='zinc finger protein 492|zinc finger protein 115 (Y20)', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22634324, end_position_on_the_genomic_accession=22667671, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    57616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57616, CurrentID=0, Status='live', Symbol='TSHZ3', Aliases=['TSH3', 'ZNF537'], description='teashirt zinc finger homeobox 3', other_designations='teashirt homolog 3|teashirt family zinc finger 3|zinc finger protein 537', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=31149876, end_position_on_the_genomic_accession=31349436, orientation='minus', exon_count=7, OMIM=[614119], no_hdr0=''),
    57617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57617, CurrentID=0, Status='live', Symbol='VPS18', Aliases=['PEP3'], description='VPS18 core subunit of CORVET and HOPS complexes', other_designations='vacuolar protein sorting-associated protein 18 homolog|VPS18, CORVET/HOPS core subunit|hVPS18|vacuolar protein sorting 18 homolog|vacuolar protein sorting protein 18', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40894410, end_position_on_the_genomic_accession=40903975, orientation='plus', exon_count=7, OMIM=[608551], no_hdr0=''),
    57619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57619, CurrentID=0, Status='live', Symbol='SHROOM3', Aliases=['APXL3', 'MSTP013', 'SHRM', 'ShrmL'], description='shroom family member 3', other_designations='protein Shroom3|F-actin-binding protein|shroom-related protein', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76435229, end_position_on_the_genomic_accession=76783253, orientation='plus', exon_count=11, OMIM=[604570], no_hdr0=''),
    57620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57620, CurrentID=0, Status='live', Symbol='STIM2', Aliases=[], description='stromal interaction molecule 2', other_designations='stromal interaction molecule 2', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=26860841, end_position_on_the_genomic_accession=27025381, orientation='plus', exon_count=14, OMIM=[610841], no_hdr0=''),
    57621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57621, CurrentID=0, Status='live', Symbol='ZBTB2', Aliases=['ZNF437'], description='zinc finger and BTB domain containing 2', other_designations='zinc finger and BTB domain-containing protein 2', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151364115, end_position_on_the_genomic_accession=151391705, orientation='minus', exon_count=6, OMIM=[616595], no_hdr0=''),
    57622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57622, CurrentID=0, Status='live', Symbol='LRFN1', Aliases=['SALM2'], description='leucine rich repeat and fibronectin type III domain containing 1', other_designations='leucine-rich repeat and fibronectin type III domain-containing protein 1|CTC-246B18.8|synaptic adhesion-like molecule 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39306566, end_position_on_the_genomic_accession=39320863, orientation='minus', exon_count=6, OMIM=[612807], no_hdr0=''),
    57623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57623, CurrentID=0, Status='live', Symbol='ZFAT', Aliases=['AITD31', 'ZNF406', 'ZFAT'], description='zinc finger and AT-hook domain containing', other_designations='zinc finger protein ZFAT|zinc finger gene in autoimmune thyroid disease|zinc finger protein 406|zinc-finger gene in AITD susceptibility region', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=134477788, end_position_on_the_genomic_accession=134713031, orientation='minus', exon_count=24, OMIM=[610931], no_hdr0=''),
    57624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57624, CurrentID=0, Status='live', Symbol='NYAP2', Aliases=['KIAA1486'], description='neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adaptor 2', other_designations='neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adapter 2', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=225399710, end_position_on_the_genomic_accession=225703654, orientation='plus', exon_count=8, OMIM=[615478], no_hdr0=''),
    57626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57626, CurrentID=0, Status='live', Symbol='KLHL1', Aliases=['MRP2'], description='kelch like family member 1', other_designations='kelch-like protein 1|Mayven-related protein 2', map_location='13q21.33', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=69700593, end_position_on_the_genomic_accession=70108452, orientation='minus', exon_count=13, OMIM=[605332], no_hdr0=''),
    57628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57628, CurrentID=0, Status='live', Symbol='DPP10', Aliases=['DPL2', 'DPPY', 'DPRP-3', 'DPRP3'], description='dipeptidyl peptidase like 10', other_designations='inactive dipeptidyl peptidase 10|DPP X|dipeptidyl peptidase 10|dipeptidyl peptidase IV-related protein 3|dipeptidyl peptidase X|dipeptidyl peptidase-like protein 2|dipeptidyl-peptidase 10 (inactive)|dipeptidyl-peptidase 10 (non-functional)', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=114442641, end_position_on_the_genomic_accession=115845780, orientation='plus', exon_count=33, OMIM=[608209], no_hdr0=''),
    57630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57630, CurrentID=0, Status='live', Symbol='SH3RF1', Aliases=['POSH', 'RNF142', 'SH3MD2'], description='SH3 domain containing ring finger 1', other_designations='E3 ubiquitin-protein ligase SH3RF1|RING-type E3 ubiquitin transferase SH3RF1|SH3 domain-containing RING finger protein 1|SH3 multiple domains 2|SH3 multiple domains protein 2|plenty of SH3 domains|plenty of SH3s|putative E3 ubiquitin-protein ligase SH3RF1|ring finger protein 142', map_location='4q32.3-q33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=169094259, end_position_on_the_genomic_accession=169270956, orientation='minus', exon_count=12, OMIM=[618642], no_hdr0=''),
    57631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57631, CurrentID=0, Status='live', Symbol='LRCH2', Aliases=['dA204F4.4'], description='leucine rich repeats and calponin homology domain containing 2', other_designations='leucine-rich repeat and calponin homology domain-containing protein 2|leucine-rich repeats and calponin homology (CH) domain containing 2', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=115110611, end_position_on_the_genomic_accession=115234096, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    57633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57633, CurrentID=0, Status='live', Symbol='LRRN1', Aliases=['FIGLER3', 'NLRR-1'], description='leucine rich repeat neuronal 1', other_designations='leucine-rich repeat neuronal protein 1|fibronectin type III, immunoglobulin and leucine rich repeat domains 3|neuronal leucine-rich repeat protein 1', map_location='3p26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=3799431, end_position_on_the_genomic_accession=3849834, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    57634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57634, CurrentID=0, Status='live', Symbol='EP400', Aliases=['CAGH32', 'P400', 'TNRC12'], description='E1A binding protein p400', other_designations='E1A-binding protein p400|CAG repeat protein 32|domino homolog|hDomino|hDomino(p400)|p400 SWI2/SNF2-related protein|p400 kDa SWI2/SNF2-related protein|trinucleotide repeat containing 12|trinucleotide repeat-containing gene 12 protein', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131949942, end_position_on_the_genomic_accession=132080460, orientation='plus', exon_count=53, OMIM=[606265], no_hdr0=''),
    57636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57636, CurrentID=0, Status='live', Symbol='ARHGAP23', Aliases=[], description='Rho GTPase activating protein 23', other_designations='rho GTPase-activating protein 23|rho-type GTPase-activating protein 23', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38419286, end_position_on_the_genomic_accession=38512389, orientation='plus', exon_count=31, OMIM=[610590], no_hdr0=''),
    57639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57639, CurrentID=0, Status='live', Symbol='CCDC146', Aliases=['MBO2'], description='coiled-coil domain containing 146', other_designations='coiled-coil domain-containing protein 146', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77122615, end_position_on_the_genomic_accession=77295204, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    57642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57642, CurrentID=0, Status='live', Symbol='COL20A1', Aliases=[], description='collagen type XX alpha 1 chain', other_designations='collagen alpha-1(XX) chain|collagen, type XX, alpha 1|collagen-like protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63293169, end_position_on_the_genomic_accession=63334847, orientation='plus', exon_count=38, OMIM=[619390], no_hdr0=''),
    57643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57643, CurrentID=0, Status='live', Symbol='ZSWIM5', Aliases=[], description='zinc finger SWIM-type containing 5', other_designations='zinc finger SWIM domain-containing protein 5|zinc finger, SWIM domain containing 5', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45016399, end_position_on_the_genomic_accession=45206605, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    57644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57644, CurrentID=0, Status='live', Symbol='MYH7B', Aliases=['MHC14', 'MYH14'], description='myosin heavy chain 7B', other_designations='myosin-7B|U937-associated antigen|antigen MLAA-21|myosin, heavy chain 7B, cardiac muscle, beta|myosin, heavy polypeptide 7B, cardiac muscle, beta|slow A MYH14', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34955868, end_position_on_the_genomic_accession=35002437, orientation='plus', exon_count=47, OMIM=[609928], no_hdr0=''),
    57645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57645, CurrentID=0, Status='live', Symbol='POGK', Aliases=['BASS2', 'KRBOX2', 'LST003'], description='pogo transposable element derived with KRAB domain', other_designations='pogo transposable element with KRAB domain|KRAB box domain containing 2', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=166839447, end_position_on_the_genomic_accession=166856359, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    57646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57646, CurrentID=0, Status='live', Symbol='USP28', Aliases=[], description='ubiquitin specific peptidase 28', other_designations='ubiquitin carboxyl-terminal hydrolase 28|deubiquitinating enzyme 28|ubiquitin carboxyl-terminal hydrolase 28 variant 1|ubiquitin thioesterase 28|ubiquitin thiolesterase 28|ubiquitin-specific-processing protease 28', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113797875, end_position_on_the_genomic_accession=113875572, orientation='minus', exon_count=28, OMIM=[610748], no_hdr0=''),
    57647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57647, CurrentID=0, Status='live', Symbol='DHX37', Aliases=['DDX37', 'Dhr1', 'NEDBAVC', 'SRXY11'], description='DEAH-box helicase 37', other_designations='probable ATP-dependent RNA helicase DHX37|DEAD/DEAH box helicase DDX37|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 37|DEAH (Asp-Glu-Ala-His) box polypeptide 37|DEAH box protein 37', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124946824, end_position_on_the_genomic_accession=124989131, orientation='minus', exon_count=28, OMIM=[617362], no_hdr0=''),
    57648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57648, CurrentID=0, Status='live', Symbol='KIAA1522', Aliases=[], description='KIAA1522', other_designations='uncharacterized protein KIAA1522', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32741830, end_position_on_the_genomic_accession=32774970, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    57649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57649, CurrentID=0, Status='live', Symbol='PHF12', Aliases=['PF1'], description='PHD finger protein 12', other_designations='PHD finger protein 12|PHD factor 1|PHD zinc finger transcription factor', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28905250, end_position_on_the_genomic_accession=28951518, orientation='minus', exon_count=16, OMIM=[618645], no_hdr0=''),
    57650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57650, CurrentID=0, Status='live', Symbol='CIP2A', Aliases=['KIAA1524', 'NOCIVA', 'p90'], description='cellular inhibitor of PP2A', other_designations='protein CIP2A|cancerous inhibitor of PP2A|cancerous inhibitor of protein phosphatase 2A|cell proliferation regulating inhibitor of protein phosphatase 2A|p90 autoantigen', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108545752, end_position_on_the_genomic_accession=108589456, orientation='minus', exon_count=22, OMIM=[610643], no_hdr0=''),
    57654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57654, CurrentID=0, Status='live', Symbol='UVSSA', Aliases=['KIAA1530', 'UVSS3'], description='UV stimulated scaffold protein A', other_designations='UV-stimulated scaffold protein A', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1341998, end_position_on_the_genomic_accession=1388049, orientation='plus', exon_count=27, OMIM=[614632], no_hdr0=''),
    57655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57655, CurrentID=0, Status='live', Symbol='GRAMD1A', Aliases=['KIAA1533'], description='GRAM domain containing 1A', other_designations='protein Aster-A|GRAM domain-containing protein 1A', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34994727, end_position_on_the_genomic_accession=35026471, orientation='plus', exon_count=27, OMIM=[], no_hdr0=''),
    57657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57657, CurrentID=0, Status='live', Symbol='HCN3', Aliases=[], description='hyperpolarization activated cyclic nucleotide gated potassium channel 3', other_designations='potassium/sodium hyperpolarization-activated cyclic nucleotide-gated channel 3', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155277427, end_position_on_the_genomic_accession=155289848, orientation='plus', exon_count=10, OMIM=[609973], no_hdr0=''),
    57658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57658, CurrentID=0, Status='live', Symbol='CALCOCO1', Aliases=['Cocoa', 'PP13275', 'calphoglin'], description='calcium binding and coiled-coil domain 1', other_designations='calcium-binding and coiled-coil domain-containing protein 1|coiled-coil coactivator protein|coiled-coil leucine zipper coactivator 1|inorganic pyrophosphatase activator|sarcoma antigen NY-SAR-3', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53708517, end_position_on_the_genomic_accession=53727520, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    57659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57659, CurrentID=0, Status='live', Symbol='ZBTB4', Aliases=['KAISO-L1', 'ZNF903'], description='zinc finger and BTB domain containing 4', other_designations='zinc finger and BTB domain-containing protein 4|KAISO-like zinc finger protein 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7459366, end_position_on_the_genomic_accession=7484249, orientation='minus', exon_count=8, OMIM=[612308], no_hdr0=''),
    57661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57661, CurrentID=0, Status='live', Symbol='PHRF1', Aliases=['PPP1R125', 'RNF221'], description='PHD and ring finger domains 1', other_designations='PHD and RING finger domain-containing protein 1|CTD-binding SR-like protein rA9|protein phosphatase 1, regulatory subunit 125', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=576446, end_position_on_the_genomic_accession=612222, orientation='plus', exon_count=18, OMIM=[611780], no_hdr0=''),
    57662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57662, CurrentID=0, Status='live', Symbol='CAMSAP3', Aliases=['KIAA1543', 'NEZHA', 'PPP1R80'], description='calmodulin regulated spectrin associated protein family member 3', other_designations='calmodulin-regulated spectrin-associated protein 3|protein phosphatase 1, regulatory subunit 80', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7595863, end_position_on_the_genomic_accession=7618304, orientation='plus', exon_count=19, OMIM=[612685], no_hdr0=''),
    57663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57663, CurrentID=0, Status='live', Symbol='USP29', Aliases=['HOM-TES-84/86'], description='ubiquitin specific peptidase 29', other_designations='ubiquitin carboxyl-terminal hydrolase 29|deubiquitinating enzyme 29|ubiquitin thioesterase 29|ubiquitin thiolesterase 29|ubiquitin-specific processing protease|ubiquitin-specific-processing protease 29', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57119087, end_position_on_the_genomic_accession=57131983, orientation='plus', exon_count=5, OMIM=[609546], no_hdr0=''),
    57664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57664, CurrentID=0, Status='live', Symbol='PLEKHA4', Aliases=['PEPP1'], description='pleckstrin homology domain containing A4', other_designations='pleckstrin homology domain-containing family A member 4|PH domain-containing family A member 4|phosphoinositol 3-phosphate-binding PH domain protein 1|pleckstrin homology domain containing, family A (phosphoinositide binding specific) member 4', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48837092, end_position_on_the_genomic_accession=48868622, orientation='minus', exon_count=21, OMIM=[607769], no_hdr0=''),
    57665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57665, CurrentID=0, Status='live', Symbol='RDH14', Aliases=['PAN2', 'SDR7C4'], description='retinol dehydrogenase 14', other_designations='retinol dehydrogenase 14|alcohol dehydrogenase PAN2|pancreas protein 2|retinol dehydrogenase 14 (all-trans and 9-cis)|retinol dehydrogenase 14 (all-trans/9-cis/11-cis)|short chain dehydrogenase/reductase family 7C member 4', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=18554723, end_position_on_the_genomic_accession=18560653, orientation='minus', exon_count=2, OMIM=[616796], no_hdr0=''),
    57666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57666, CurrentID=0, Status='live', Symbol='FBRSL1', Aliases=[], description='fibrosin like 1', other_designations='fibrosin-1-like protein|AUTS2-like protein|HBV X-transactivated gene 9 protein|HBV XAg-transactivated protein 9', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132490151, end_position_on_the_genomic_accession=132585188, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    57669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57669, CurrentID=0, Status='live', Symbol='EPB41L5', Aliases=['BE37', 'LULU', 'LULU1', 'YMO1', 'YRT'], description='erythrocyte membrane protein band 4.1 like 5', other_designations='band 4.1-like protein 5|yurt homolog', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120013032, end_position_on_the_genomic_accession=120179119, orientation='plus', exon_count=28, OMIM=[611730], no_hdr0=''),
    57670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57670, CurrentID=0, Status='live', Symbol='KIAA1549', Aliases=['RP86'], description='KIAA1549', other_designations='UPF0606 protein KIAA1549', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138831377, end_position_on_the_genomic_accession=138981626, orientation='minus', exon_count=21, OMIM=[613344], no_hdr0=''),
    57673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57673, CurrentID=0, Status='live', Symbol='BEND3', Aliases=['KIAA1553'], description='BEN domain containing 3', other_designations='BEN domain-containing protein 3', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107065182, end_position_on_the_genomic_accession=107115515, orientation='minus', exon_count=6, OMIM=[616374], no_hdr0=''),
    57674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57674, CurrentID=0, Status='live', Symbol='RNF213', Aliases=['ALO17', 'C17orf27', 'KIAA1618', 'MYMY2', 'MYSTR', 'NET57'], description='ring finger protein 213', other_designations='E3 ubiquitin-protein ligase RNF213|ALK lymphoma oligomerization partner on chromosome 17|RING-type E3 ubiquitin transferase RNF213|mysterin', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80260820, end_position_on_the_genomic_accession=80398794, orientation='plus', exon_count=72, OMIM=[613768], no_hdr0=''),
    57677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57677, CurrentID=0, Status='live', Symbol='ZFP14', Aliases=['ZNF531'], description='ZFP14 zinc finger protein', other_designations='zinc finger protein 14 homolog|zinc finger protein 531', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36334453, end_position_on_the_genomic_accession=36379201, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    57678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57678, CurrentID=0, Status='live', Symbol='GPAM', Aliases=['GPAT', 'GPAT1'], description='glycerol-3-phosphate acyltransferase, mitochondrial', other_designations='glycerol-3-phosphate acyltransferase 1, mitochondrial|GPAT-1', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112149865, end_position_on_the_genomic_accession=112216306, orientation='minus', exon_count=24, OMIM=[602395], no_hdr0=''),
    57679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57679, CurrentID=0, Status='live', Symbol='ALS2', Aliases=['ALS2CR6', 'ALSJ', 'IAHSP', 'PLSJ'], description='alsin Rho guanine nucleotide exchange factor ALS2', other_designations='alsin|ALS2, alsin Rho guanine nucleotide exchange factor|amyotrophic lateral sclerosis 2 (juvenile)|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 6 protein|amyotrophic lateral sclerosis 2 protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201700267, end_position_on_the_genomic_accession=201781153, orientation='minus', exon_count=37, OMIM=[606352], no_hdr0=''),
    57680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57680, CurrentID=0, Status='live', Symbol='CHD8', Aliases=['AUTS18', 'HELSNF1'], description='chromodomain helicase DNA binding protein 8', other_designations='chromodomain-helicase-DNA-binding protein 8|ATP-dependent helicase CHD8|axis duplication inhibitor|duplin|helicase with SNF2 domain 1', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21385199, end_position_on_the_genomic_accession=21456123, orientation='minus', exon_count=39, OMIM=[610528], no_hdr0=''),
    57683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57683, CurrentID=0, Status='live', Symbol='ZDBF2', Aliases=['Slx9'], description='zinc finger DBF-type containing 2', other_designations='DBF4-type zinc finger-containing protein 2', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206273572, end_position_on_the_genomic_accession=206314427, orientation='plus', exon_count=10, OMIM=[617059], no_hdr0=''),
    57684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57684, CurrentID=0, Status='live', Symbol='ZBTB26', Aliases=['ZNF481', 'bioref'], description='zinc finger and BTB domain containing 26', other_designations='zinc finger and BTB domain-containing protein 26|zinc finger protein 481|zinc finger protein 483|zinc finger protein Bioref', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122915566, end_position_on_the_genomic_accession=122931512, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    57685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57685, CurrentID=0, Status='live', Symbol='CACHD1', Aliases=[], description='cache domain containing 1', other_designations='VWFA and cache domain-containing protein 1|cache domain-containing protein 1|von Willebrand factor type A and cache domain containing 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=64470129, end_position_on_the_genomic_accession=64693058, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    57687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57687, CurrentID=0, Status='live', Symbol='VAT1L', Aliases=[], description='vesicle amine transport 1 like', other_designations='synaptic vesicle membrane protein VAT-1 homolog-like|vesicle amine transport protein 1 homolog (T. californica)-like|vesicle amine transport protein 1 homolog-like (T. californica)', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77788564, end_position_on_the_genomic_accession=77980107, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    57688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57688, CurrentID=0, Status='live', Symbol='ZSWIM6', Aliases=['AFND', 'NEDMAGA'], description='zinc finger SWIM-type containing 6', other_designations='zinc finger SWIM domain-containing protein 6|zinc finger, SWIM domain containing 6', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=61332258, end_position_on_the_genomic_accession=61546172, orientation='plus', exon_count=16, OMIM=[615951], no_hdr0=''),
    57689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57689, CurrentID=0, Status='live', Symbol='LRRC4C', Aliases=['NGL-1', 'NGL1'], description='leucine rich repeat containing 4C', other_designations='leucine-rich repeat-containing protein 4C|netrin-G1 ligand', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=40107066, end_position_on_the_genomic_accession=41460419, orientation='minus', exon_count=14, OMIM=[608817], no_hdr0=''),
    57690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57690, CurrentID=0, Status='live', Symbol='TNRC6C', Aliases=[], description='trinucleotide repeat containing adaptor 6C', other_designations='trinucleotide repeat-containing gene 6C protein|trinucleotide repeat containing 6C', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=77958853, end_position_on_the_genomic_accession=78108835, orientation='plus', exon_count=25, OMIM=[610741], no_hdr0=''),
    57691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57691, CurrentID=0, Status='live', Symbol='KIAA1586', Aliases=[], description='KIAA1586', other_designations='E3 SUMO-protein ligase KIAA1586', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=57046691, end_position_on_the_genomic_accession=57055739, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    57692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57692, CurrentID=0, Status='live', Symbol='MAGEE1', Aliases=['DAMAGE', 'HCA1'], description='MAGE family member E1', other_designations='melanoma-associated antigen E1|MAGE-E1 antigen|alpha-dystrobrevin-associated MAGE Protein|dystrobrevin-associated MAGE protein|hepatocellular carcinoma-associated HCA1|hepatocellular carcinoma-associated protein 1|melanoma antigen family E, 1|melanoma antigen family E1', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=76427710, end_position_on_the_genomic_accession=76431342, orientation='plus', exon_count=1, OMIM=[300759], no_hdr0=''),
    57693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57693, CurrentID=0, Status='live', Symbol='ZNF317', Aliases=[], description='zinc finger protein 317', other_designations='zinc finger protein 317|KRAB-containing zinc finger protein 317', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9140395, end_position_on_the_genomic_accession=9163419, orientation='plus', exon_count=8, OMIM=[613864], no_hdr0=''),
    57695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57695, CurrentID=0, Status='live', Symbol='USP37', Aliases=[], description='ubiquitin specific peptidase 37', other_designations='ubiquitin carboxyl-terminal hydrolase 37|deubiquitinating enzyme 37|tmp_locus_50|ubiquitin specific protease 37|ubiquitin thioesterase 37|ubiquitin thiolesterase 37|ubiquitin-specific-processing protease 37', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218450251, end_position_on_the_genomic_accession=218568393, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    57696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57696, CurrentID=0, Status='live', Symbol='DDX55', Aliases=[], description='DEAD-box helicase 55', other_designations='ATP-dependent RNA helicase DDX55|DEAD (Asp-Glu-Ala-Asp) box polypeptide 55|DEAD box protein 55|epididymis secretory sperm binding protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123602089, end_position_on_the_genomic_accession=123620943, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    57697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57697, CurrentID=0, Status='live', Symbol='FANCM', Aliases=['FAAP250', 'KIAA1596', 'POF15', 'SPGF28'], description='FA complementation group M', other_designations='Fanconi anemia group M protein|ATP-dependent RNA helicase FANCM|Fanconi anemia complementation group M|fanconi anemia-associated polypeptide of 250 kDa|protein Hef ortholog', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=45135930, end_position_on_the_genomic_accession=45200890, orientation='plus', exon_count=25, OMIM=[609644], no_hdr0=''),
    57698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57698, CurrentID=0, Status='live', Symbol='SHTN1', Aliases=['KIAA1598', 'shootin-1'], description='shootin 1', other_designations='shootin-1|shootin1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116881477, end_position_on_the_genomic_accession=117126586, orientation='minus', exon_count=21, OMIM=[611171], no_hdr0=''),
    57699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57699, CurrentID=0, Status='live', Symbol='CPNE5', Aliases=['COPN5', 'CPN5'], description='copine 5', other_designations='copine-5|copine V', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36740773, end_position_on_the_genomic_accession=36839998, orientation='minus', exon_count=32, OMIM=[604209], no_hdr0=''),
    57700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57700, CurrentID=0, Status='live', Symbol='FHIP2A', Aliases=['FAM160B1', 'KIAA1600', 'bA106M7.3'], description='FHF complex subunit HOOK interacting protein 2A', other_designations='FHF complex subunit HOOK interacting protein 2A|family with sequence similarity 160 member B1|protein FAM160B1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114821780, end_position_on_the_genomic_accession=114899832, orientation='plus', exon_count=18, OMIM=[617312], no_hdr0=''),
    57701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57701, CurrentID=0, Status='live', Symbol='NCKAP5L', Aliases=['Cep169', 'FP1193', 'KIAA1602'], description='NCK associated protein 5 like', other_designations='nck-associated protein 5-like|NCKAP5-like|centrosomal protein of 169 kDa', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49791139, end_position_on_the_genomic_accession=49828750, orientation='minus', exon_count=14, OMIM=[615104], no_hdr0=''),
    57703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57703, CurrentID=0, Status='live', Symbol='CWC22', Aliases=['EIF4GL', 'NCM', 'fSAPb'], description='CWC22 spliceosome associated protein homolog', other_designations='pre-mRNA-splicing factor CWC22 homolog|CWC22 homolog, spliceosome-associated protein|CWC22 spliceosome-associated protein|functional spliceosome-associated protein b|nucampholin homolog', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=179944876, end_position_on_the_genomic_accession=180007297, orientation='minus', exon_count=21, OMIM=[615186], no_hdr0=''),
    57704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57704, CurrentID=0, Status='live', Symbol='GBA2', Aliases=['AD035', 'NLGase', 'SPG46'], description='glucosylceramidase beta 2', other_designations='non-lysosomal glucosylceramidase|beta-glucocerebrosidase 2|bile acid beta-glucosidase GBA2|bile acid glucosyl transferase GBA2|cholesterol glucosyltransferase GBA2|cholesteryl-beta-glucosidase GBA2|glucosidase, beta (bile acid) 2|glucosylceramidase 2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35736862, end_position_on_the_genomic_accession=35749228, orientation='minus', exon_count=18, OMIM=[609471], no_hdr0=''),
    57705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57705, CurrentID=0, Status='live', Symbol='WDFY4', Aliases=['C10orf64'], description='WDFY family member 4', other_designations='WD repeat- and FYVE domain-containing protein 4|truncated WD repeat- and FYVE domain-containing protein 4', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=48684827, end_position_on_the_genomic_accession=48982956, orientation='plus', exon_count=68, OMIM=[613316], no_hdr0=''),
    57706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57706, CurrentID=0, Status='live', Symbol='DENND1A', Aliases=['FAM31A', 'KIAA1608'], description='DENN domain containing 1A', other_designations='DENN domain-containing protein 1A|DENN/MADD domain containing 1A|connecdenn 1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=123379658, end_position_on_the_genomic_accession=123930158, orientation='minus', exon_count=30, OMIM=[613633], no_hdr0=''),
    57707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57707, CurrentID=0, Status='live', Symbol='MEAK7', Aliases=['EAK7', 'KIAA1609', 'TLDC1', 'mEAK-7'], description='MTOR associated protein, eak-7 homolog', other_designations='MTOR-associated protein MEAK7|TBC/LysM-associated domain containing 1|TBC/LysM-associated domain-containing protein 1|TLD domain containing 1|TLD domain-containing protein 1|mammalian EAK-7', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84476355, end_position_on_the_genomic_accession=84504708, orientation='minus', exon_count=12, OMIM=[619331], no_hdr0=''),
    57708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57708, CurrentID=0, Status='live', Symbol='MIER1', Aliases=['ER1', 'MI-ER1'], description='MIER1 transcriptional regulator', other_designations='mesoderm induction early response protein 1|mesoderm induction early response 1 homolog|mesoderm induction early response 1, transcriptional regulator', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66924900, end_position_on_the_genomic_accession=66988619, orientation='plus', exon_count=21, OMIM=[616848], no_hdr0=''),
    57709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57709, CurrentID=0, Status='live', Symbol='SLC7A14', Aliases=['PPP1R142'], description='solute carrier family 7 member 14', other_designations='probable cationic amino acid transporter|protein phosphatase 1, regulatory subunit 142|solute carrier family 7 (cationic amino acid transporter, y+ system), member 14|solute carrier family 7 (orphan transporter), member 14', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170459548, end_position_on_the_genomic_accession=170586075, orientation='minus', exon_count=8, OMIM=[615720], no_hdr0=''),
    57710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57710, CurrentID=0, Status='live', Symbol='KIAA1614', Aliases=[], description='KIAA1614', other_designations='uncharacterized protein KIAA1614', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180912897, end_position_on_the_genomic_accession=180951614, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    57711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57711, CurrentID=0, Status='live', Symbol='ZNF529', Aliases=[], description='zinc finger protein 529', other_designations='zinc finger protein 529', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36534491, end_position_on_the_genomic_accession=36605411, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    57713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57713, CurrentID=0, Status='live', Symbol='SFMBT2', Aliases=[], description='Scm like with four mbt domains 2', other_designations='scm-like with four MBT domains protein 2|Scm-related gene containing four mbt domains 2|scm-like with 4 MBT domains protein 2', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7158624, end_position_on_the_genomic_accession=7411490, orientation='minus', exon_count=25, OMIM=[615392], no_hdr0=''),
    57715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57715, CurrentID=0, Status='live', Symbol='SEMA4G', Aliases=[], description='semaphorin 4G', other_designations='semaphorin-4G|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4G', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100969503, end_position_on_the_genomic_accession=100985618, orientation='plus', exon_count=17, OMIM=[618991], no_hdr0=''),
    57716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57716, CurrentID=0, Status='live', Symbol='PRX', Aliases=['CMT4F'], description='periaxin', other_designations='periaxin', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40393762, end_position_on_the_genomic_accession=40414718, orientation='minus', exon_count=9, OMIM=[605725], no_hdr0=''),
    57717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57717, CurrentID=0, Status='live', Symbol='PCDHB16', Aliases=['ME1', 'PCDH-BETA16', 'PCDH3X', 'PCDHB8a'], description='protocadherin beta 16', other_designations='protocadherin beta-16|cadherin ME1|protocadherin beta 8a|protocadherin-3x', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141182387, end_position_on_the_genomic_accession=141186226, orientation='plus', exon_count=1, OMIM=[606345], no_hdr0=''),
    57718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57718, CurrentID=0, Status='live', Symbol='PPP4R4', Aliases=['CFAP14', 'KIAA1622', 'PP4R4'], description='protein phosphatase 4 regulatory subunit 4', other_designations='serine/threonine-protein phosphatase 4 regulatory subunit 4|HEAT-like repeat-containing protein|cilia and flagella associated protein 14', map_location='14q32.12-q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94174322, end_position_on_the_genomic_accession=94279734, orientation='plus', exon_count=31, OMIM=[616790], no_hdr0=''),
    57719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57719, CurrentID=0, Status='live', Symbol='ANO8', Aliases=['KIAA1623', 'TMEM16H'], description='anoctamin 8', other_designations='anoctamin-8|transmembrane protein 16H', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17323223, end_position_on_the_genomic_accession=17334855, orientation='minus', exon_count=18, OMIM=[610216], no_hdr0=''),
    57720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57720, CurrentID=0, Status='live', Symbol='GPR107', Aliases=['GCDRP', 'LUSTR1', 'bA138E2.2'], description='G protein-coupled receptor 107', other_designations='protein GPR107|lung seven transmembrane receptor 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130053906, end_position_on_the_genomic_accession=130140164, orientation='plus', exon_count=20, OMIM=[618490], no_hdr0=''),
    57721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57721, CurrentID=0, Status='live', Symbol='METTL14', Aliases=['hMETTL14'], description='methyltransferase 14, N6-adenosine-methyltransferase subunit', other_designations='N6-adenosine-methyltransferase non-catalytic subunit|N6-adenosine-methyltransferase subunit METTL14|methyltransferase like 14|methyltransferase-like protein 14', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=118685375, end_position_on_the_genomic_accession=118715430, orientation='plus', exon_count=12, OMIM=[616504], no_hdr0=''),
    57722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57722, CurrentID=0, Status='live', Symbol='IGDCC4', Aliases=['DDM36', 'NOPE'], description='immunoglobulin superfamily DCC subclass member 4', other_designations='immunoglobulin superfamily DCC subclass member 4|likely ortholog of mouse neighbor of Punc E11|neighbor of Punc E11', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65381484, end_position_on_the_genomic_accession=65422947, orientation='minus', exon_count=22, OMIM=[616810], no_hdr0=''),
    57724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57724, CurrentID=0, Status='live', Symbol='EPG5', Aliases=['HEEW1', 'KIAA1632', 'VICIS'], description='ectopic P-granules autophagy protein 5 homolog', other_designations='ectopic P granules protein 5 homolog', map_location='18q12.3-q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=45800586, end_position_on_the_genomic_accession=45967339, orientation='minus', exon_count=47, OMIM=[615068], no_hdr0=''),
    57727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57727, CurrentID=0, Status='live', Symbol='NCOA5', Aliases=['CIA', 'bA465L10.6'], description='nuclear receptor coactivator 5', other_designations='nuclear receptor coactivator 5|NCoA-5|coactivator independent of AF-2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46060991, end_position_on_the_genomic_accession=46089962, orientation='minus', exon_count=8, OMIM=[616825], no_hdr0=''),
    57728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57728, CurrentID=0, Status='live', Symbol='WDR19', Aliases=['ATD5', 'CED4', 'DYF-2', 'FAP66', 'IFT144', 'NPHP13', 'ORF26', 'Oseg6', 'PWDMP', 'SRTD5'], description='WD repeat domain 19', other_designations='WD repeat-containing protein 19|WD repeat membrane protein PWDMP|intraflagellar transport 144 homolog', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39182473, end_position_on_the_genomic_accession=39285810, orientation='plus', exon_count=38, OMIM=[608151], no_hdr0=''),
    57730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57730, CurrentID=0, Status='live', Symbol='ANKRD36B', Aliases=['KIAA1641'], description='ankyrin repeat domain 36B', other_designations='ankyrin repeat domain-containing protein 36B|CLL-associated antigen KW-1|melanoma-associated antigen', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97492663, end_position_on_the_genomic_accession=97590337, orientation='minus', exon_count=47, OMIM=[], no_hdr0=''),
    57731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57731, CurrentID=0, Status='live', Symbol='SPTBN4', Aliases=['CMND', 'NEDHND', 'QV', 'SPNB4', 'SPTBN3'], description='spectrin beta, non-erythrocytic 4', other_designations='spectrin beta chain, non-erythrocytic 4|beta-IV spectrin|spectrin beta chain, brain 3|spectrin, non-erythroid beta chain 3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40467001, end_position_on_the_genomic_accession=40576464, orientation='plus', exon_count=40, OMIM=[606214], no_hdr0=''),
    57732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57732, CurrentID=0, Status='live', Symbol='ZFYVE28', Aliases=['LST2', 'LYST2', 'lst-2'], description='zinc finger FYVE-type containing 28', other_designations='lateral signaling target protein 2 homolog|hLst2|lateral signaling target-2 homolog|zinc finger FYVE domain-containing protein 28|zinc finger, FYVE domain containing 28', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2269585, end_position_on_the_genomic_accession=2418698, orientation='minus', exon_count=23, OMIM=[614176], no_hdr0=''),
    57733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57733, CurrentID=0, Status='live', Symbol='GBA3', Aliases=['CBG', 'CBGL1', 'GLUC', 'KLRP'], description='glucosylceramidase beta 3 (gene/pseudogene)', other_designations='cytosolic beta-glucosidase|cytosolic GCase|cytosolic beta-glucosidase-like protein 1|cytosolic glycosylceramidase|glucosidase beta acid 3|glucosidase, beta, acid 3 (cytosolic)|klotho-related protein', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=22692937, end_position_on_the_genomic_accession=22819569, orientation='plus', exon_count=6, OMIM=[606619], no_hdr0=''),
    57758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57758, CurrentID=0, Status='live', Symbol='SCUBE2', Aliases=['CEGB1', 'CEGF1', 'CEGP1', 'scube/You'], description='signal peptide, CUB domain and EGF like domain containing 2', other_designations='signal peptide, CUB and EGF-like domain-containing protein 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9019476, end_position_on_the_genomic_accession=9091599, orientation='minus', exon_count=25, OMIM=[611747], no_hdr0=''),
    57761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57761, CurrentID=0, Status='live', Symbol='TRIB3', Aliases=['C20orf97', 'NIPK', 'SINK', 'SKIP3', 'TRB3'], description='tribbles pseudokinase 3', other_designations='tribbles homolog 3|TRB-3|neuronal cell death inducible putative kinase|p65-interacting inhibitor of NF-kappa-B|p65-interacting inhibitor of NF-kappaB', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=380760, end_position_on_the_genomic_accession=397559, orientation='plus', exon_count=6, OMIM=[607898], no_hdr0=''),
    57763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57763, CurrentID=0, Status='live', Symbol='ANKRA2', Aliases=['ANKRA'], description='ankyrin repeat family A member 2', other_designations='ankyrin repeat family A protein 2|RFXANK-like protein 2|ankyrin repeat, family A (RFXANK-like), 2', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73552190, end_position_on_the_genomic_accession=73565639, orientation='minus', exon_count=9, OMIM=[605787], no_hdr0=''),
    57786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57786, CurrentID=0, Status='live', Symbol='RBAK', Aliases=['ZNF769'], description='RB associated KRAB zinc finger', other_designations='RB-associated KRAB zinc finger protein|RB-associated KRAB repressor|zinc finger protein 769', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5045860, end_position_on_the_genomic_accession=5069487, orientation='plus', exon_count=5, OMIM=[608191], no_hdr0=''),
    57787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57787, CurrentID=0, Status='live', Symbol='MARK4', Aliases=['MARK4LS', 'MARKL1', 'MARKL1L', 'PAR-1D', 'MARK4'], description='microtubule affinity regulating kinase 4', other_designations='MAP/microtubule affinity-regulating kinase 4|MAP/microtubule affinity-regulating kinase like 1|MARK4 serine/threonine protein kinase|epididymis secretory sperm binding protein', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45251271, end_position_on_the_genomic_accession=45305284, orientation='plus', exon_count=18, OMIM=[606495], no_hdr0=''),
    57794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57794, CurrentID=0, Status='live', Symbol='SUGP1', Aliases=['F23858', 'RBP', 'SF4'], description='SURP and G-patch domain containing 1', other_designations='SURP and G-patch domain-containing protein 1|RNA-binding protein RBP|splicing factor 4', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19276033, end_position_on_the_genomic_accession=19320509, orientation='minus', exon_count=14, OMIM=[607992], no_hdr0=''),
    57795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57795, CurrentID=0, Status='live', Symbol='BRINP2', Aliases=['DBCCR1L2', 'FAM5B'], description='BMP/retinoic acid inducible neural specific 2', other_designations='BMP/retinoic acid-inducible neural-specific protein 2|DBCCR1-like protein 2|DBCCR1-like2|bone morphogenetic protein/retinoic acid inducible neural-specific 2|bone morphogenic protein/retinoic acid inducible neural-specific 2|family with sequence similarity 5, member B|protein FAM5B', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=177170890, end_position_on_the_genomic_accession=177282422, orientation='plus', exon_count=11, OMIM=[619359], no_hdr0=''),
    57798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57798, CurrentID=0, Status='live', Symbol='GATAD1', Aliases=['CMD2B', 'ODAG', 'RG083M05.2'], description='GATA zinc finger domain containing 1', other_designations='GATA zinc finger domain-containing protein 1|ocular development-associated gene protein', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92447448, end_position_on_the_genomic_accession=92494631, orientation='plus', exon_count=11, OMIM=[614518], no_hdr0=''),
    57799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57799, CurrentID=0, Status='live', Symbol='RAB40C', Aliases=['RARL', 'RASL8C'], description='RAB40C, member RAS oncogene family', other_designations='ras-related protein Rab-40C|RAR (RAS like GTPASE) like|RAR like|RAS-like GTPase|RAS-like, family 8, member C|SOCS box-containing protein RAR3|rar-like protein|ras-like protein family member 8C', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=589357, end_position_on_the_genomic_accession=629268, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    57801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57801, CurrentID=0, Status='live', Symbol='HES4', Aliases=['bHLHb42'], description='hes family bHLH transcription factor 4', other_designations='transcription factor HES-4|bHLH factor Hes4|class B basic helix-loop-helix protein 42|hHES4|hairy and enhancer of split 4', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=998962, end_position_on_the_genomic_accession=1001052, orientation='minus', exon_count=4, OMIM=[608060], no_hdr0=''),
    57804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57804, CurrentID=0, Status='live', Symbol='POLD4', Aliases=['POLDS', 'p12'], description='DNA polymerase delta 4, accessory subunit', other_designations='DNA polymerase delta subunit 4|DNA polymerase delta smallest subunit p12|polymerase (DNA) delta 4, accessory subunit|polymerase (DNA-directed), delta 4, accessory subunit', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67350765, end_position_on_the_genomic_accession=67353596, orientation='minus', exon_count=4, OMIM=[611525], no_hdr0=''),
    57805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57805, CurrentID=0, Status='live', Symbol='CCAR2', Aliases=['DBC-1', 'DBC1', 'KIAA1967', 'NET35', 'p30 DBC', 'p30DBC'], description='cell cycle and apoptosis regulator 2', other_designations='cell cycle and apoptosis regulator protein 2|cell division cycle and apoptosis regulator protein 2|deleted in breast cancer 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22604740, end_position_on_the_genomic_accession=22621514, orientation='plus', exon_count=22, OMIM=[607359], no_hdr0=''),
    57817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57817, CurrentID=0, Status='live', Symbol='HAMP', Aliases=['HEPC', 'HFE2B', 'LEAP1', 'PLTR'], description='hepcidin antimicrobial peptide', other_designations='hepcidin|hepcidin preproprotein|liver-expressed antimicrobial peptide 1|putative liver tumor regressor', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35282528, end_position_on_the_genomic_accession=35285143, orientation='plus', exon_count=3, OMIM=[606464], no_hdr0=''),
    57818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57818, CurrentID=0, Status='live', Symbol='G6PC2', Aliases=['IGRP'], description='glucose-6-phosphatase catalytic subunit 2', other_designations='glucose-6-phosphatase 2|G-6-Pase 2|G6Pase 2|glucose-6-phosphatase, catalytic, 2|islet-specific G6CP-related protein|islet-specific glucose-6-phosphatase catalytic subunit-related protein|islet-specific glucose-6-phosphatase-related protein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=168901223, end_position_on_the_genomic_accession=168910000, orientation='plus', exon_count=5, OMIM=[608058], no_hdr0=''),
    57819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57819, CurrentID=0, Status='live', Symbol='LSM2', Aliases=['C6orf28', 'G7B', 'YBL026W', 'snRNP'], description='LSM2 homolog, U6 small nuclear RNA and mRNA degradation associated', other_designations='U6 snRNA-associated Sm-like protein LSm2|LSM2 U6 small nuclear RNA and mRNA degradation associated|LSM2 homolog, U6 small nuclear RNA associated|protein G7b|small nuclear ribonuclear protein D homolog|snRNP core Sm-like protein Sm-x5', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31797396, end_position_on_the_genomic_accession=31806966, orientation='minus', exon_count=5, OMIM=[607282], no_hdr0=''),
    57820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57820, CurrentID=0, Status='live', Symbol='CCNB1IP1', Aliases=['C14orf18', 'HEI10'], description='cyclin B1 interacting protein 1', other_designations='E3 ubiquitin-protein ligase CCNB1IP1|RING-type E3 ubiquitin transferase CCNB1IP1|cyclin B1 interacting protein 1, E3 ubiquitin protein ligase|epididymis secretory sperm binding protein|human enhancer of invasion 10', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20311370, end_position_on_the_genomic_accession=20333279, orientation='minus', exon_count=8, OMIM=[608249], no_hdr0=''),
    57821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57821, CurrentID=0, Status='live', Symbol='CCDC181', Aliases=['C1orf114'], description='coiled-coil domain containing 181', other_designations='coiled-coil domain-containing protein 181', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169394870, end_position_on_the_genomic_accession=169462221, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    57822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57822, CurrentID=0, Status='live', Symbol='GRHL3', Aliases=['SOM', 'TFCP2L4', 'VWS2'], description='grainyhead like transcription factor 3', other_designations='grainyhead-like protein 3 homolog|sister of mammalian grainyhead|transcription factor CP2-like 4|transcription factor hSOM1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24319333, end_position_on_the_genomic_accession=24364482, orientation='plus', exon_count=19, OMIM=[608317], no_hdr0=''),
    57823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57823, CurrentID=0, Status='live', Symbol='SLAMF7', Aliases=['19A', 'CD319', 'CRACC', 'CS1'], description='SLAM family member 7', other_designations='SLAM family member 7|19A24 protein|CD2 subset 1|CD2-like receptor activating cytotoxic cells|membrane protein FOAP-12|novel LY9 (lymphocyte antigen 9) like protein|protein 19A', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160739057, end_position_on_the_genomic_accession=160754821, orientation='plus', exon_count=7, OMIM=[606625], no_hdr0=''),
    57824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57824, CurrentID=0, Status='live', Symbol='HMHB1', Aliases=['HB-1', 'HB-1Y', 'HLA-HB1'], description='histocompatibility minor HB-1', other_designations='minor histocompatibility protein HB-1|minor histocompatibility antigen HB-1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=143812161, end_position_on_the_genomic_accession=143820716, orientation='plus', exon_count=2, OMIM=[609961], no_hdr0=''),
    57826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57826, CurrentID=0, Status='live', Symbol='RAP2C', Aliases=[], description='RAP2C, member of RAS oncogene family', other_designations='ras-related protein Rap-2c|small GTPase RAP2C', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=132203025, end_position_on_the_genomic_accession=132219471, orientation='minus', exon_count=8, OMIM=[301016], no_hdr0=''),
    57827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57827, CurrentID=0, Status='live', Symbol='C6orf47', Aliases=['D6S53E', 'G4', 'NG34'], description='chromosome 6 open reading frame 47', other_designations='uncharacterized protein C6orf47|protein G4', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31658298, end_position_on_the_genomic_accession=31660778, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    57828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57828, CurrentID=0, Status='live', Symbol='CATSPERG', Aliases=['C19orf15'], description='cation channel sperm associated auxiliary subunit gamma', other_designations='cation channel sperm-associated protein subunit gamma|catsper channel auxiliary subunit gamma', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38335830, end_position_on_the_genomic_accession=38370943, orientation='plus', exon_count=29, OMIM=[613452], no_hdr0=''),
    57829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57829, CurrentID=0, Status='live', Symbol='ZP4', Aliases=['ZBP', 'ZP1', 'ZPB', 'Zp-4'], description='zona pellucida glycoprotein 4', other_designations='zona pellucida sperm-binding protein 4|zona pellucida protein B', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=237882404, end_position_on_the_genomic_accession=237890922, orientation='minus', exon_count=12, OMIM=[613514], no_hdr0=''),
    57830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57830, CurrentID=0, Status='live', Symbol='KRTAP5-8', Aliases=['KRTAP5-2', 'KRTAP5.8', 'UHSKerB'], description='keratin associated protein 5-8', other_designations='keratin-associated protein 5-8|UHS KERB-like protein|UHS KerB|UHS keratin B|keratin, ultra high-sulfur matrix protein B|keratin, ultrahigh sulfur, B|keratin-associated protein 5.8|ultrahigh sulfur keratin-associated protein 5.8', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71538025, end_position_on_the_genomic_accession=71539209, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    57834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57834, CurrentID=0, Status='live', Symbol='CYP4F11', Aliases=['CYPIVF11'], description='cytochrome P450 family 4 subfamily F member 11', other_designations='cytochrome P450 4F11|3-hydroxy fatty acids omega-hydroxylase CYP4F11|cytochrome P450, family 4, subfamily F, polypeptide 11|cytochrome P450, subfamily IVF, polypeptide 11|docosahexaenoic acid omega-hydroxylase|long-chain fatty acid omega-monooxygenase|phylloquinone omega-hydroxylase CYP4F11', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15912377, end_position_on_the_genomic_accession=15934867, orientation='minus', exon_count=13, OMIM=[611517], no_hdr0=''),
    57835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57835, CurrentID=0, Status='live', Symbol='SLC4A5', Aliases=['NBC4', 'NBCe2'], description='solute carrier family 4 member 5', other_designations='electrogenic sodium bicarbonate cotransporter 4|solute carrier family 4 (sodium bicarbonate cotransporter), member 5', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74216242, end_position_on_the_genomic_accession=74343416, orientation='minus', exon_count=33, OMIM=[606757], no_hdr0=''),
    57862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57862, CurrentID=0, Status='live', Symbol='ZNF410', Aliases=['APA-1', 'APA1'], description='zinc finger protein 410', other_designations='zinc finger protein 410|another partner for ARF 1|clones 23667 and 23775 zinc finger protein|zinc finger protein APA-1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73886859, end_position_on_the_genomic_accession=73932521, orientation='plus', exon_count=15, OMIM=[619427], no_hdr0=''),
    57863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57863, CurrentID=0, Status='live', Symbol='CADM3', Aliases=['BIgR', 'IGSF4B', 'NECL1', 'Necl-1', 'TSLL1', 'synCAM3'], description='cell adhesion molecule 3', other_designations='cell adhesion molecule 3|TSLC1-like 1|brain immunoglobulin receptor|immunoglobulin superfamily member 4B|synaptic cell adhesion molecule 3', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159171592, end_position_on_the_genomic_accession=159203313, orientation='plus', exon_count=12, OMIM=[609743], no_hdr0=''),
    57864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57864, CurrentID=0, Status='live', Symbol='SLC46A2', Aliases=['Ly110', 'TSCOT'], description='solute carrier family 46 member 2', other_designations='thymic stromal cotransporter homolog|thymic stromal co-transporter', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112878920, end_position_on_the_genomic_accession=112895538, orientation='minus', exon_count=4, OMIM=[608956], no_hdr0=''),
    57876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=57876, CurrentID=0, Status='live', Symbol='MUC3B', Aliases=['MUC3', 'MUC3A'], description='mucin 3B, cell surface associated', other_designations='mucin-3B|MUC-3B|intestinal mucin MUC3B|intestinal mucin-3B', map_location='7q22', chromosome='7', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[605633], no_hdr0=''),
    58155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58155, CurrentID=0, Status='live', Symbol='PTBP2', Aliases=['PTBLP', 'brPTB', 'nPTB'], description='polypyrimidine tract binding protein 2', other_designations='polypyrimidine tract-binding protein 2|PTB-like protein|neural polypyrimidine tract binding protein|neurally-enriched homolog of PTB', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=96721766, end_position_on_the_genomic_accession=96823739, orientation='plus', exon_count=16, OMIM=[608449], no_hdr0=''),
    58157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58157, CurrentID=0, Status='live', Symbol='NGB', Aliases=[], description='neuroglobin', other_designations='neuroglobin', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77265483, end_position_on_the_genomic_accession=77271206, orientation='minus', exon_count=4, OMIM=[605304], no_hdr0=''),
    58158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58158, CurrentID=0, Status='live', Symbol='NEUROD4', Aliases=['ATH-3', 'ATH3', 'Atoh3', 'MATH-3', 'MATH3', 'bHLHa4'], description='neuronal differentiation 4', other_designations='neurogenic differentiation factor 4|class A basic helix-loop-helix protein 4|neurogenic differentiation 4|protein atonal homolog 3', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55019974, end_position_on_the_genomic_accession=55030017, orientation='plus', exon_count=2, OMIM=[611635], no_hdr0=''),
    58189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58189, CurrentID=0, Status='live', Symbol='WFDC1', Aliases=['PS20'], description='WAP four-disulfide core domain 1', other_designations='WAP four-disulfide core domain protein 1|WAP four-disulfide core domain 1 homolog|prostate stromal protein ps20|ps20 growth inhibitor', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84292233, end_position_on_the_genomic_accession=84329850, orientation='plus', exon_count=9, OMIM=[605322], no_hdr0=''),
    58190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58190, CurrentID=0, Status='live', Symbol='CTDSP1', Aliases=['NIF3', 'NLI-IF', 'NLIIF', 'SCP1'], description='CTD small phosphatase 1', other_designations='carboxy-terminal domain RNA polymerase II polypeptide A small phosphatase 1|CTD (carboxy-terminal domain, RNA polymerase II, polypeptide A) small phosphatase 1|NLI-interacting factor 3|nuclear LIM interactor-interacting factor 3|small C-terminal domain phosphatase 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218398233, end_position_on_the_genomic_accession=218405941, orientation='plus', exon_count=9, OMIM=[605323], no_hdr0=''),
    58191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58191, CurrentID=0, Status='live', Symbol='CXCL16', Aliases=['CXCLG16', 'SR-PSOX', 'SRPSOX'], description='C-X-C motif chemokine ligand 16', other_designations='C-X-C motif chemokine 16|CXC chemokine ligand 16|chemokine (C-X-C motif) ligand 16|scavenger receptor for phosphatidylserine and oxidized low density lipoprotein|small-inducible cytokine B16|transmembrane chemokine CXCL16', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4733533, end_position_on_the_genomic_accession=4739928, orientation='minus', exon_count=6, OMIM=[605398], no_hdr0=''),
    58472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58472, CurrentID=0, Status='live', Symbol='SQOR', Aliases=['CGI-44', 'PRO1975', 'SQR', 'SQRDL'], description='sulfide quinone oxidoreductase', other_designations='sulfide:quinone oxidoreductase, mitochondrial|sulfide dehydrogenase like|sulfide quinone reductase-like', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45631148, end_position_on_the_genomic_accession=45691281, orientation='plus', exon_count=12, OMIM=[617658], no_hdr0=''),
    58473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58473, CurrentID=0, Status='live', Symbol='PLEKHB1', Aliases=['KPL1', 'PHR1', 'PHRET1'], description='pleckstrin homology domain containing B1', other_designations='pleckstrin homology domain-containing family B member 1|PH domain containing, retinal 1|PH domain-containing family B member 1|PH domain-containing protein in retina 1|evectin-1|pleckstrin homology domain containing, family B (evectins) member 1|pleckstrin homology domain retinal protein 1', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73646581, end_position_on_the_genomic_accession=73662819, orientation='plus', exon_count=9, OMIM=[607651], no_hdr0=''),
    58475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58475, CurrentID=0, Status='live', Symbol='MS4A7', Aliases=['4SPAN2', 'CD20L4', 'CFFM4', 'MS4A8'], description='membrane spanning 4-domains A7', other_designations='membrane-spanning 4-domains subfamily A member 7|CD20 antigen-like 4|CD20/Fc-epsilon-RI-beta family member 4|four-span transmembrane protein 2|high affinity immunoglobulin epsilon receptor beta subunit', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60378532, end_position_on_the_genomic_accession=60395948, orientation='plus', exon_count=7, OMIM=[606502], no_hdr0=''),
    58476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58476, CurrentID=0, Status='live', Symbol='TP53INP2', Aliases=['C20orf110', 'DOR', 'PIG-U', 'PIGU', 'PINH', 'dJ1181N3.1'], description='tumor protein p53 inducible nuclear protein 2', other_designations='tumor protein p53-inducible nuclear protein 2|diabetes and obesity-regulated|p53-inducible protein U', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34704344, end_position_on_the_genomic_accession=34713439, orientation='plus', exon_count=6, OMIM=[617549], no_hdr0=''),
    58477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58477, CurrentID=0, Status='live', Symbol='SRPRB', Aliases=['APMCF1', 'SR-beta'], description='SRP receptor subunit beta', other_designations='signal recognition particle receptor subunit beta|SRP receptor beta subunit|signal recognition particle receptor, B subunit|signal recognition particle receptor, beta subunit', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133784023, end_position_on_the_genomic_accession=133828574, orientation='plus', exon_count=9, OMIM=[616883], no_hdr0=''),
    58478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58478, CurrentID=0, Status='live', Symbol='ENOPH1', Aliases=['E1', 'MASA', 'MST145', 'mtnC'], description='enolase-phosphatase 1', other_designations='enolase-phosphatase E1|2,3-diketo-5-methylthio-1-phosphopentane phosphatase|acireductone synthase', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82430590, end_position_on_the_genomic_accession=82461177, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    58480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58480, CurrentID=0, Status='live', Symbol='RHOU', Aliases=['ARHU', 'CDC42L1', 'G28K', 'WRCH1', 'hG28K'], description='ras homolog family member U', other_designations='rho-related GTP-binding protein RhoU|2310026M05Rik|CDC42-like GTPase 1|GTP-binding protein SB128|GTP-binding protein like 1|Ryu GTPase|ras homolog gene family, member U|ras-like gene family member U|rho GTPase-like protein ARHU|wnt-1 responsive Cdc42 homolog 1', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228644647, end_position_on_the_genomic_accession=228746669, orientation='plus', exon_count=4, OMIM=[606366], no_hdr0=''),
    58484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58484, CurrentID=0, Status='live', Symbol='NLRC4', Aliases=['AIFEC', 'CARD12', 'CLAN', 'CLAN1', 'CLANA', 'CLANB', 'CLANC', 'CLAND', 'CLR2.1', 'FCAS4', 'IPAF'], description='NLR family CARD domain containing 4', other_designations='NLR family CARD domain-containing protein 4|CARD, LRR, and NACHT-containing protein|CED-4-like protein Clan|ICE-protease activating factor|NOD-like receptor C4|caspase recruitment domain family, member 12|caspase recruitment domain-containing protein 12|nucleotide-binding oligomerization domain, leucine rich repeat and CARD domain containing 4', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32224449, end_position_on_the_genomic_accession=32265743, orientation='minus', exon_count=11, OMIM=[606831], no_hdr0=''),
    58485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58485, CurrentID=0, Status='live', Symbol='TRAPPC1', Aliases=['BET5', 'MUM2'], description='trafficking protein particle complex subunit 1', other_designations='trafficking protein particle complex subunit 1|BET5 homolog|MUM-2|melanoma ubiquitous mutated 2|multiple myeloma protein 2|trafficking protein particle complex 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7930345, end_position_on_the_genomic_accession=7931999, orientation='minus', exon_count=4, OMIM=[610969], no_hdr0=''),
    58486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58486, CurrentID=0, Status='live', Symbol='ZBED5', Aliases=['Buster1'], description='zinc finger BED-type containing 5', other_designations='zinc finger BED domain-containing protein 5|transposon-derived Buster1 transposase-like protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10852706, end_position_on_the_genomic_accession=10858053, orientation='minus', exon_count=3, OMIM=[615251], no_hdr0=''),
    58487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58487, CurrentID=0, Status='live', Symbol='CREBZF', Aliases=['SMILE', 'ZF'], description='CREB/ATF bZIP transcription factor', other_designations='CREB/ATF bZIP transcription factor|HCF-binding transcription factor Zhangfei|SHP-interacting leucine zipper protein|Zhangfei|host cell factor-binding transcription factor Zhangfei', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85657985, end_position_on_the_genomic_accession=85682863, orientation='minus', exon_count=8, OMIM=[606444], no_hdr0=''),
    58488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58488, CurrentID=0, Status='live', Symbol='PCTP', Aliases=['PC-TP', 'STARD2'], description='phosphatidylcholine transfer protein', other_designations='phosphatidylcholine transfer protein|START domain-containing protein 2|StAR-related lipid transfer (START) domain containing 2|stAR-related lipid transfer protein 2', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=55750979, end_position_on_the_genomic_accession=55845001, orientation='plus', exon_count=8, OMIM=[606055], no_hdr0=''),
    58489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58489, CurrentID=0, Status='live', Symbol='ABHD17C', Aliases=['FAM108C1'], description='abhydrolase domain containing 17C, depalmitoylase', other_designations='alpha/beta hydrolase domain-containing protein 17C|abhydrolase domain-containing protein 17C|abhydrolase domain-containing protein FAM108C1|family with sequence similarity 108, member C1|protein ABHD17C', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80695310, end_position_on_the_genomic_accession=80755621, orientation='plus', exon_count=3, OMIM=[617944], no_hdr0=''),
    58490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58490, CurrentID=0, Status='live', Symbol='RPRD1B', Aliases=['C20orf77', 'CREPT', 'K-H', 'Kub5-Hera', 'NET60', 'dJ1057B20.2'], description='regulation of nuclear pre-mRNA domain containing 1B', other_designations='regulation of nuclear pre-mRNA domain-containing protein 1B|Ku70-binding protein 5-Hera|cell-cycle related and expression-elevated protein in tumor', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38033462, end_position_on_the_genomic_accession=38092366, orientation='plus', exon_count=10, OMIM=[614694], no_hdr0=''),
    58491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58491, CurrentID=0, Status='live', Symbol='ZNF71', Aliases=['EZFIT'], description='zinc finger protein 71', other_designations='endothelial zinc finger protein induced by tumor necrosis factor alpha|Kruppel-related zinc finger protein', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56595302, end_position_on_the_genomic_accession=56624486, orientation='plus', exon_count=4, OMIM=[194545], no_hdr0=''),
    58492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58492, CurrentID=0, Status='live', Symbol='ZNF77', Aliases=['pT1'], description='zinc finger protein 77', other_designations='zinc finger protein 77|ZNFpT1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2933218, end_position_on_the_genomic_accession=2944971, orientation='minus', exon_count=4, OMIM=[194551], no_hdr0=''),
    58493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58493, CurrentID=0, Status='live', Symbol='INIP', Aliases=['C9orf80', 'HSPC043', 'MISE', 'SOSSC', 'SSBIP1', 'hSSBIP1'], description='INTS3 and NABP interacting protein', other_designations='SOSS complex subunit C|SSB-interacting protein 1|hSSB-interacting protein 1|minute INTS3/hSSB-associated element|sensor of single-strand DNA complex subunit C|sensor of ssDNA subunit C|single-stranded DNA-binding protein-interacting protein 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112683926, end_position_on_the_genomic_accession=112718117, orientation='minus', exon_count=7, OMIM=[613273], no_hdr0=''),
    58494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58494, CurrentID=0, Status='live', Symbol='JAM2', Aliases=['C21orf43', 'CD322', 'IBGC8', 'JAM-B', 'JAMB', 'PRO245', 'VE-JAM', 'VEJAM'], description='junctional adhesion molecule 2', other_designations='junctional adhesion molecule B|JAM-2|JAM-IT/VE-JAM|vascular endothelial junction-associated molecule', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=25607550, end_position_on_the_genomic_accession=25717562, orientation='plus', exon_count=14, OMIM=[606870], no_hdr0=''),
    58495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58495, CurrentID=0, Status='live', Symbol='OVOL2', Aliases=['CHED', 'CHED1', 'CHED2', 'EUROIMAGE566589', 'PPCD1', 'ZNF339'], description='ovo like zinc finger 2', other_designations='transcription factor Ovo-like 2|corneal endothelial dystrophy 1 (autosomal dominant)|zinc finger protein 339', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18024152, end_position_on_the_genomic_accession=18059188, orientation='minus', exon_count=5, OMIM=[616441], no_hdr0=''),
    58496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58496, CurrentID=0, Status='live', Symbol='LY6G5B', Aliases=['C6orf19', 'G5b'], description='lymphocyte antigen 6 family member G5B', other_designations='lymphocyte antigen 6 complex locus protein G5b|lymphocyte antigen 6 complex, locus G5B', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31670951, end_position_on_the_genomic_accession=31672450, orientation='plus', exon_count=3, OMIM=[610433], no_hdr0=''),
    58497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58497, CurrentID=0, Status='live', Symbol='PRUNE1', Aliases=['DRES-17', 'DRES17', 'H-PRUNE', 'HTCD37', 'NMIHBA', 'PRUNE'], description='prune exopolyphosphatase 1', other_designations='exopolyphosphatase PRUNE1|Drosophila-related expressed sequence 17|protein prune homolog 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151008405, end_position_on_the_genomic_accession=151035713, orientation='plus', exon_count=8, OMIM=[617413], no_hdr0=''),
    58498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58498, CurrentID=0, Status='live', Symbol='MYL7', Aliases=['MYL2A', 'MYLC2A'], description='myosin light chain 7', other_designations='myosin regulatory light chain 2, atrial isoform|MLC-2a|MLC2a|myosin light chain 2a|myosin regulatory light chain 7|myosin, light chain 7, regulatory|myosin, light polypeptide 7, regulatory', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44138864, end_position_on_the_genomic_accession=44141392, orientation='minus', exon_count=7, OMIM=[613993], no_hdr0=''),
    58499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58499, CurrentID=0, Status='live', Symbol='ZNF462', Aliases=['WSKA', 'ZFPIP', 'Zfp462'], description='zinc finger protein 462', other_designations='zinc finger protein 462|zinc finger PBX1-interacting protein', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=106860154, end_position_on_the_genomic_accession=107013634, orientation='plus', exon_count=18, OMIM=[617371], no_hdr0=''),
    58500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58500, CurrentID=0, Status='live', Symbol='ZNF250', Aliases=['ZFP647', 'ZNF647'], description='zinc finger protein 250', other_designations='zinc finger protein 250|zinc finger protein (clone 647)|zinc finger protein 647', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144876955, end_position_on_the_genomic_accession=144902177, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    58503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58503, CurrentID=0, Status='live', Symbol='OPRPN', Aliases=['BPLP', 'PRL1', 'PROL1', 'opiorphin'], description='opiorphin prepropeptide', other_designations='opiorphin prepropeptide|basic proline-rich lacrimal protein|basic proline-rich protein|proline rich, lacrimal 1|proline-rich 1|proline-rich protein 1', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70397940, end_position_on_the_genomic_accession=70410195, orientation='plus', exon_count=4, OMIM=[608936], no_hdr0=''),
    58504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58504, CurrentID=0, Status='live', Symbol='ARHGAP22', Aliases=['RhoGAP2', 'RhoGap22'], description='Rho GTPase activating protein 22', other_designations='rho GTPase-activating protein 22|rho-type GTPase-activating protein 22', map_location='10q11.22-q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=48429831, end_position_on_the_genomic_accession=48656265, orientation='minus', exon_count=22, OMIM=[610585], no_hdr0=''),
    58505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58505, CurrentID=0, Status='live', Symbol='OSTC', Aliases=['DC2'], description='oligosaccharyltransferase complex non-catalytic subunit', other_designations='oligosaccharyltransferase complex subunit OSTC|hydrophobic protein HSF-28|oligosaccharyltransferase complex subunit (non-catalytic)', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=108650599, end_position_on_the_genomic_accession=108667820, orientation='plus', exon_count=5, OMIM=[619023], no_hdr0=''),
    58506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58506, CurrentID=0, Status='live', Symbol='SCAF1', Aliases=['SRA1'], description='SR-related CTD associated factor 1', other_designations='splicing factor, arginine/serine-rich 19|SCAF|SR-related C-terminal domain-associated factor 1|SR-related and CTD-associated factor 1|SR-related-CTD-associated factor|serine arginine-rich pre-mRNA splicing factor SR-A1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49640481, end_position_on_the_genomic_accession=49658642, orientation='plus', exon_count=13, OMIM=[617264], no_hdr0=''),
    58508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58508, CurrentID=0, Status='live', Symbol='KMT2C', Aliases=['HALR', 'KLEFS2', 'MLL3'], description='lysine methyltransferase 2C', other_designations='histone-lysine N-methyltransferase 2C|ALR-like protein|histone-lysine N-methyltransferase MLL3|histone-lysine N-methyltransferase, H3 lysine-4 specific|homologous to ALR protein|lysine (K)-specific methyltransferase 2C|myeloid/lymphoid or mixed-lineage leukemia protein 3', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=152134925, end_position_on_the_genomic_accession=152436642, orientation='minus', exon_count=65, OMIM=[606833], no_hdr0=''),
    58509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58509, CurrentID=0, Status='live', Symbol='CACTIN', Aliases=['C19orf29', 'NY-REN-24', 'fSAPc'], description='cactin, spliceosome C complex subunit', other_designations='cactin|NY REN 24 antigen|functional spliceosome-associated protein c|renal carcinoma antigen NY-REN-24', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3610645, end_position_on_the_genomic_accession=3626810, orientation='minus', exon_count=11, OMIM=[618536], no_hdr0=''),
    58510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58510, CurrentID=0, Status='live', Symbol='PRODH2', Aliases=['HSPOX1', 'HYPDH'], description='proline dehydrogenase 2', other_designations='hydroxyproline dehydrogenase|kidney and liver proline oxidase 1|probable proline dehydrogenase 2|probable proline oxidase 2|proline dehydrogenase (oxidase) 2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35799988, end_position_on_the_genomic_accession=35812845, orientation='minus', exon_count=10, OMIM=[616377], no_hdr0=''),
    58511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58511, CurrentID=0, Status='live', Symbol='DNASE2B', Aliases=['DLAD'], description='deoxyribonuclease 2 beta', other_designations='deoxyribonuclease-2-beta|DNase II beta|DNase II-like acid DNase|DNase2-like acid DNase|deoxyribonuclease II beta|endonuclease DLAD|lysosomal DNase II', map_location='1p31.1-p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84398484, end_position_on_the_genomic_accession=84415895, orientation='plus', exon_count=6, OMIM=[608057], no_hdr0=''),
    58512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58512, CurrentID=0, Status='live', Symbol='DLGAP3', Aliases=['DAP3', 'SAPAP3'], description='DLG associated protein 3', other_designations='disks large-associated protein 3|DAP-3|PSD-95/SAP90-binding protein 3|SAP90/PSD-95-associated protein 3|discs large homolog associated protein 3', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34862120, end_position_on_the_genomic_accession=34929650, orientation='minus', exon_count=15, OMIM=[611413], no_hdr0=''),
    58513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58513, CurrentID=0, Status='live', Symbol='EPS15L1', Aliases=['EPS15R'], description='epidermal growth factor receptor pathway substrate 15 like 1', other_designations='epidermal growth factor receptor substrate 15-like 1|epidermal growth factor receptor substrate EPS15R|eps15-related protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16355244, end_position_on_the_genomic_accession=16472012, orientation='minus', exon_count=27, OMIM=[616826], no_hdr0=''),
    58515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58515, CurrentID=0, Status='live', Symbol='SELENOK', Aliases=['HSPC030', 'HSPC297', 'SELK'], description='selenoprotein K', other_designations='selenoprotein K', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53884417, end_position_on_the_genomic_accession=53891859, orientation='minus', exon_count=5, OMIM=[607916], no_hdr0=''),
    58516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58516, CurrentID=0, Status='live', Symbol='SINHCAF', Aliases=['C12orf14', 'FAM60A', 'L4', 'TERA'], description='SIN3-HDAC complex associated factor', other_designations='SIN3-HDAC complex-associated factor|family with sequence similarity 60 member A|protein FAM60A|tera protein homolog', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31280584, end_position_on_the_genomic_accession=31326218, orientation='minus', exon_count=10, OMIM=[615027], no_hdr0=''),
    58517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58517, CurrentID=0, Status='live', Symbol='RBM25', Aliases=['NET52', 'RED120', 'RNPC7', 'S164', 'Snu71', 'fSAP94'], description='RNA binding motif protein 25', other_designations='RNA-binding protein 25|Arg/Glu/Asp-rich protein, 120 kDa|RNA-binding region (RNP1, RRM) containing 7|RNA-binding region-containing protein 7|U1 small nuclear ribonucleoprotein 1SNRP homolog|arg/Glu/Asp-rich protein of 120 kDa|functional spliceosome-associated protein 94', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73058532, end_position_on_the_genomic_accession=73123899, orientation='plus', exon_count=21, OMIM=[612427], no_hdr0=''),
    58524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58524, CurrentID=0, Status='live', Symbol='DMRT3', Aliases=['DMRTA3'], description='doublesex and mab-3 related transcription factor 3', other_designations='doublesex- and mab-3-related transcription factor 3|DMRT-like family A3|testis-specific protein', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=976655, end_position_on_the_genomic_accession=991732, orientation='plus', exon_count=2, OMIM=[614754], no_hdr0=''),
    58525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58525, CurrentID=0, Status='live', Symbol='WIZ', Aliases=['ZNF803'], description='WIZ zinc finger', other_designations='protein Wiz|widely interspaced zinc finger motifs|widely-interspaced zinc finger-containing protein|zinc finger protein 803', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15419978, end_position_on_the_genomic_accession=15449956, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    58526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58526, CurrentID=0, Status='live', Symbol='MID1IP1', Aliases=['G12-like', 'MIG12', 'S14R', 'STRAIT11499', 'THRSPL'], description='MID1 interacting protein 1', other_designations='mid1-interacting protein 1|MID1 interacting G12-like protein|MID1 interacting protein 1 (gastrulation specific G12-like)|gastrulation specific G12 homolog|spot 14-R|spot 14-related protein', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=38801459, end_position_on_the_genomic_accession=38806532, orientation='plus', exon_count=3, OMIM=[300961], no_hdr0=''),
    58527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58527, CurrentID=0, Status='live', Symbol='ABRACL', Aliases=['C6orf115', 'Costars', 'HSPC280', 'PRO2013'], description='ABRA C-terminal like', other_designations='costars family protein ABRACL|ABRA C-terminal-like protein', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=139028745, end_position_on_the_genomic_accession=139043302, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    58528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58528, CurrentID=0, Status='live', Symbol='RRAGD', Aliases=['RAGD', 'bA11D8.2.1'], description='Ras related GTP binding D', other_designations='ras-related GTP-binding protein D|Rag D protein', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89363509, end_position_on_the_genomic_accession=89412273, orientation='minus', exon_count=8, OMIM=[608268], no_hdr0=''),
    58529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58529, CurrentID=0, Status='live', Symbol='MYOZ1', Aliases=['CS-2', 'FATZ', 'MYOZ'], description='myozenin 1', other_designations='myozenin-1|calsarcin-2|filamin-, actinin- and telethonin-binding protein', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73631612, end_position_on_the_genomic_accession=73641474, orientation='minus', exon_count=6, OMIM=[605603], no_hdr0=''),
    58530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58530, CurrentID=0, Status='live', Symbol='LY6G6D', Aliases=['C6orf23', 'G6D', 'LY6-D', 'MEGT1', 'NG25'], description='lymphocyte antigen 6 family member G6D', other_designations='lymphocyte antigen 6 complex locus protein G6d|lymphocyte antigen 6 complex, locus G6D|lymphocyte antigen-6 G6D|megakaryocyte-enhanced gene transcript 1 protein|protein Ly6-D', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31715348, end_position_on_the_genomic_accession=31717919, orientation='plus', exon_count=3, OMIM=[606038], no_hdr0=''),
    58531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58531, CurrentID=0, Status='live', Symbol='PRM3', Aliases=[], description='protamine 3', other_designations='protamine-3|gene 4|sperm protamine P3', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11273199, end_position_on_the_genomic_accession=11273629, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    58533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58533, CurrentID=0, Status='live', Symbol='SNX6', Aliases=['MSTP010', 'TFAF2'], description='sorting nexin 6', other_designations='sorting nexin-6|TRAF4-associated factor 2|tumor necrosis factor receptor-associated factor 4(TRAF4)-associated factor 2', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34561093, end_position_on_the_genomic_accession=34630148, orientation='minus', exon_count=14, OMIM=[606098], no_hdr0=''),
    58538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58538, CurrentID=0, Status='live', Symbol='MPP4', Aliases=['ALS2CR5', 'DLG6'], description='membrane palmitoylated protein 4', other_designations='MAGUK p55 subfamily member 4|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 5 protein|discs large homolog 6|membrane protein, palmitoylated 4 (MAGUK p55 subfamily member 4)', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201644874, end_position_on_the_genomic_accession=201700263, orientation='minus', exon_count=22, OMIM=[606575], no_hdr0=''),
    58985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58985, CurrentID=0, Status='live', Symbol='IL22RA1', Aliases=['CRF2-9', 'IL22R', 'IL22R1'], description='interleukin 22 receptor subunit alpha 1', other_designations='interleukin-22 receptor subunit alpha-1|IL-22 receptor subunit alpha-1|IL-22R-alpha-1|IL-22RA1|cytokine receptor class-II member 9|cytokine receptor family 2 member 9|interleukin 22 receptor, alpha 1|zcytoR11', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24119771, end_position_on_the_genomic_accession=24143179, orientation='minus', exon_count=8, OMIM=[605457], no_hdr0=''),
    58986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=58986, CurrentID=0, Status='live', Symbol='PGAP6', Aliases=['GPI-PLA2', 'M83', 'TMEM6', 'TMEM8', 'TMEM8A'], description='post-glycosylphosphatidylinositol attachment to proteins 6', other_designations='post-GPI attachment to proteins factor 6|GPI processing phospholipase A2|five-span transmembrane protein M83|transmembrane protein 6|transmembrane protein 8 (five membrane-spanning domains)|transmembrane protein 8A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=370788, end_position_on_the_genomic_accession=381978, orientation='minus', exon_count=12, OMIM=[619342], no_hdr0=''),
    59067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59067, CurrentID=0, Status='live', Symbol='IL21', Aliases=['CVID11', 'IL-21', 'Za11'], description='interleukin 21', other_designations='interleukin-21', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122610108, end_position_on_the_genomic_accession=122621066, orientation='minus', exon_count=5, OMIM=[605384], no_hdr0=''),
    59082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59082, CurrentID=0, Status='live', Symbol='CARD18', Aliases=['ICEBERG', 'UNQ5804', 'pseudo-ICE'], description='caspase recruitment domain family member 18', other_designations='caspase recruitment domain-containing protein 18|ICEBERG caspase-1 inhibitor|caspase-1 inhibitor Iceberg', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=105137714, end_position_on_the_genomic_accession=105139769, orientation='minus', exon_count=3, OMIM=[605354], no_hdr0=''),
    59084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59084, CurrentID=0, Status='live', Symbol='ENPP5', Aliases=['NPP-5', 'NPP5'], description='ectonucleotide pyrophosphatase/phosphodiesterase family member 5', other_designations='ectonucleotide pyrophosphatase/phosphodiesterase family member 5|E-NPP 5|ectonucleotide pyrophosphatase/phosphodiesterase 5 (putative)', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46159182, end_position_on_the_genomic_accession=46171006, orientation='minus', exon_count=5, OMIM=[617001], no_hdr0=''),
    59269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59269, CurrentID=0, Status='live', Symbol='HIVEP3', Aliases=['KBP-1', 'KBP1', 'KRC', 'SHN3', 'Schnurri-3', 'ZAS3', 'ZNF40C'], description='HIVEP zinc finger 3', other_designations='transcription factor HIVEP3|ZAS family, member 3|human immunodeficiency virus type I enhancer binding protein 3|kappa-B and V(D)J recombination signal sequences-binding protein|kappa-binding protein 1|zinc finger protein ZAS3', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=41506365, end_position_on_the_genomic_accession=42035934, orientation='minus', exon_count=17, OMIM=[606649], no_hdr0=''),
    59271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59271, CurrentID=0, Status='live', Symbol='EVA1C', Aliases=['B18', 'B19', 'C21orf63', 'C21orf64', 'FAM176C', 'PRED34', 'SUE21'], description='eva-1 homolog C', other_designations='protein eva-1 homolog C|family with sequence similarity 176, member C|protein FAM176C', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32411692, end_position_on_the_genomic_accession=32515387, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    59272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59272, CurrentID=0, Status='live', Symbol='ACE2', Aliases=['ACEH'], description='angiotensin converting enzyme 2', other_designations='angiotensin-converting enzyme 2|ACE-related carboxypeptidase|angiotensin I converting enzyme (peptidyl-dipeptidase A) 2|angiotensin I converting enzyme 2|angiotensin-converting enzyme homolog|angiotensin-converting enzyme-related carboxypeptidase|metalloprotease MPROT15|peptidyl-dipeptidase A|truncated angiotensin converting enzyme 2', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15518197, end_position_on_the_genomic_accession=15607211, orientation='minus', exon_count=22, OMIM=[300335], no_hdr0=''),
    59274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59274, CurrentID=0, Status='live', Symbol='TLNRD1', Aliases=['MESDC1'], description='talin rod domain containing 1', other_designations='talin rod domain-containing protein 1|mesoderm development candidate 1', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=81000923, end_position_on_the_genomic_accession=81005788, orientation='plus', exon_count=1, OMIM=[615466], no_hdr0=''),
    59277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59277, CurrentID=0, Status='live', Symbol='NTN4', Aliases=['PRO3091'], description='netrin 4', other_designations='netrin-4|beta-netrin|hepar-derived netrin-like protein', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95657807, end_position_on_the_genomic_accession=95791155, orientation='minus', exon_count=12, OMIM=[610401], no_hdr0=''),
    59283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59283, CurrentID=0, Status='live', Symbol='CACNG8', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 8', other_designations='voltage-dependent calcium channel gamma-8 subunit|TARP gamma-8|calcium channel, voltage-dependent, gamma subunit 8|neuronal voltage-gated calcium channel gamma-8 subunit|transmembrane AMPAR regulatory protein gamma-8', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53962937, end_position_on_the_genomic_accession=53990215, orientation='plus', exon_count=4, OMIM=[606900], no_hdr0=''),
    59284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59284, CurrentID=0, Status='live', Symbol='CACNG7', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 7', other_designations='voltage-dependent calcium channel gamma-7 subunit|TARP gamma-7|calcium channel, voltage-dependent, gamma subunit 7|neuronal voltage-gated calcium channel gamma-7 subunit|transmembrane AMPAR regulatory protein gamma-7', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53909278, end_position_on_the_genomic_accession=53943950, orientation='plus', exon_count=6, OMIM=[606899], no_hdr0=''),
    59285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59285, CurrentID=0, Status='live', Symbol='CACNG6', Aliases=[], description='calcium voltage-gated channel auxiliary subunit gamma 6', other_designations='voltage-dependent calcium channel gamma-6 subunit|calcium channel, voltage-dependent, gamma subunit 6|neuronal voltage-gated calcium channel gamma-6 subunit', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53991149, end_position_on_the_genomic_accession=54012666, orientation='plus', exon_count=6, OMIM=[606898], no_hdr0=''),
    59286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59286, CurrentID=0, Status='live', Symbol='UBL5', Aliases=['HUB1'], description='ubiquitin like 5', other_designations='ubiquitin-like protein 5|beacon|testicular tissue protein Li 217', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9827918, end_position_on_the_genomic_accession=9830115, orientation='plus', exon_count=5, OMIM=[606849], no_hdr0=''),
    59307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59307, CurrentID=0, Status='live', Symbol='SIGIRR', Aliases=['IL-1R8', 'TIR8'], description='single Ig and TIR domain containing', other_designations='single Ig IL-1-related receptor|single Ig IL-1R-related molecule|single immunoglobulin and toll-interleukin 1 receptor (TIR) domain|single immunoglobulin domain IL1R1 related|single immunoglobulin domain-containing IL1R-related protein|toll/interleukin-1 receptor 8', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=405716, end_position_on_the_genomic_accession=417454, orientation='minus', exon_count=11, OMIM=[605478], no_hdr0=''),
    59335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59335, CurrentID=0, Status='live', Symbol='PRDM12', Aliases=['HSAN8', 'PFM9'], description='PR/SET domain 12', other_designations='PR domain zinc finger protein 12|PR domain containing 12', map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130664594, end_position_on_the_genomic_accession=130682983, orientation='plus', exon_count=5, OMIM=[616458], no_hdr0=''),
    59336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59336, CurrentID=0, Status='live', Symbol='PRDM13', Aliases=['MU-MB-20.220', 'PFM10'], description='PR/SET domain 13', other_designations='PR domain zinc finger protein 13|PR domain 13|PR domain containing 13|PR-domain containing protein 13', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99606833, end_position_on_the_genomic_accession=99615562, orientation='plus', exon_count=4, OMIM=[616741], no_hdr0=''),
    59338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59338, CurrentID=0, Status='live', Symbol='PLEKHA1', Aliases=['TAPP1'], description='pleckstrin homology domain containing A1', other_designations='pleckstrin homology domain-containing family A member 1|pleckstrin homology domain containing, family A (phosphoinositide binding specific) member 1|tandem PH domain-containing protein 1', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122374675, end_position_on_the_genomic_accession=122442600, orientation='plus', exon_count=22, OMIM=[607772], no_hdr0=''),
    59339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59339, CurrentID=0, Status='live', Symbol='PLEKHA2', Aliases=['TAPP2'], description='pleckstrin homology domain containing A2', other_designations='pleckstrin homology domain-containing family A member 2|PH domain-containing family A member 2|TAPP-2|pleckstrin homology domain containing, family A (phosphoinositide binding specific) member 2|tandem PH Domain containing protein-2|tandem PH domain-containing protein 2', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38901346, end_position_on_the_genomic_accession=38973912, orientation='plus', exon_count=14, OMIM=[607773], no_hdr0=''),
    59340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59340, CurrentID=0, Status='live', Symbol='HRH4', Aliases=['AXOR35', 'BG26', 'GPCR105', 'GPRv53', 'H4', 'H4R', 'HH4R'], description='histamine receptor H4', other_designations='histamine H4 receptor|G-protein coupled receptor 105|SP9144|pfi-013', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=24460637, end_position_on_the_genomic_accession=24479974, orientation='plus', exon_count=3, OMIM=[606792], no_hdr0=''),
    59341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59341, CurrentID=0, Status='live', Symbol='TRPV4', Aliases=['BCYM3', 'CMT2C', 'HMSN2C', 'OTRPC4', 'SMAL', 'SPSMA', 'SSQTL1', 'TRP12', 'VRL2', 'VROAC'], description='transient receptor potential cation channel subfamily V member 4', other_designations='transient receptor potential cation channel subfamily V member 4|OSM9-like transient receptor potential channel 4|osm-9-like TRP channel 4|osmosensitive transient receptor potential channel 4|transient receptor potential protein 12|vanilloid receptor-like channel 2|vanilloid receptor-related osmotically activated channel', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109783087, end_position_on_the_genomic_accession=109833398, orientation='minus', exon_count=19, OMIM=[605427], no_hdr0=''),
    59342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59342, CurrentID=0, Status='live', Symbol='SCPEP1', Aliases=['HSCP1', 'RISC'], description='serine carboxypeptidase 1', other_designations='retinoid-inducible serine carboxypeptidase|serine carboxypeptidase 1 precursor protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56978129, end_position_on_the_genomic_accession=57006768, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    59343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59343, CurrentID=0, Status='live', Symbol='SENP2', Aliases=['AXAM2', 'SMT3IP2'], description='SUMO specific peptidase 2', other_designations='sentrin-specific protease 2|SMT3-specific isopeptidase 2|SUMO1/sentrin/SMT3 specific peptidase 2|SUMO1/sentrin/SMT3 specific protease 2|sentrin (SUMO1) specific peptidase 2|sentrin/SUMO-specific protease SENP2', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185586295, end_position_on_the_genomic_accession=185633551, orientation='plus', exon_count=17, OMIM=[608261], no_hdr0=''),
    59344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59344, CurrentID=0, Status='live', Symbol='ALOXE3', Aliases=['ARCI3', 'E-LOX', 'eLOX-3', 'eLOX3'], description='arachidonate lipoxygenase 3', other_designations='hydroperoxide isomerase ALOXE3|Epidermal lipoxygenase-3|e-LOX-3|epidermal LOX-3|epidermal lipoxygenase|epidermis-type lipoxygenase 3|hydroperoxy dehydratase ALOXE3|hydroperoxy icosatetraenoate dehydratase|hydroperoxy icosatetraenoate isomerase', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8095900, end_position_on_the_genomic_accession=8118916, orientation='minus', exon_count=19, OMIM=[607206], no_hdr0=''),
    59345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59345, CurrentID=0, Status='live', Symbol='GNB4', Aliases=['CMTD1F'], description='G protein subunit beta 4', other_designations='guanine nucleotide-binding protein subunit beta-4|G protein beta-4 subunit|guanine nucleotide binding protein (G protein), beta polypeptide 4|transducin beta chain 4', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179396088, end_position_on_the_genomic_accession=179451470, orientation='minus', exon_count=12, OMIM=[610863], no_hdr0=''),
    59348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59348, CurrentID=0, Status='live', Symbol='ZNF350', Aliases=['ZBRK1', 'ZFQR'], description='zinc finger protein 350', other_designations='zinc finger protein 350|KRAB zinc finger protein ZFQR|zinc finger and BRCA1-interacting protein with a KRAB domain 1|zinc finger protein ZBRK1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51964340, end_position_on_the_genomic_accession=51986856, orientation='minus', exon_count=9, OMIM=[605422], no_hdr0=''),
    59349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59349, CurrentID=0, Status='live', Symbol='KLHL12', Aliases=['C3IP1', 'DKIR'], description='kelch like family member 12', other_designations='kelch-like protein 12|CUL3-interacting protein 1|DKIR homolog|kelch-like protein C3IP1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202891116, end_position_on_the_genomic_accession=202928628, orientation='minus', exon_count=14, OMIM=[614522], no_hdr0=''),
    59350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59350, CurrentID=0, Status='live', Symbol='RXFP1', Aliases=['LGR7', 'RXFPR1'], description='relaxin family peptide receptor 1', other_designations='relaxin receptor 1|leucine-rich repeat-containing G protein-coupled receptor 7|relaxin/insulin like family peptide receptor 1', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158521711, end_position_on_the_genomic_accession=158653372, orientation='plus', exon_count=23, OMIM=[606654], no_hdr0=''),
    59351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59351, CurrentID=0, Status='live', Symbol='PBOV1', Aliases=['UC28', 'UROC28', 'dJ171N11.2'], description='prostate and breast cancer overexpressed 1', other_designations='prostate and breast cancer overexpressed gene 1 protein', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138215986, end_position_on_the_genomic_accession=138218491, orientation='minus', exon_count=1, OMIM=[605669], no_hdr0=''),
    59352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59352, CurrentID=0, Status='live', Symbol='LGR6', Aliases=['GPCR', 'VTS20631'], description='leucine rich repeat containing G protein-coupled receptor 6', other_designations='leucine-rich repeat-containing G-protein coupled receptor 6|gonadotropin receptor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202193799, end_position_on_the_genomic_accession=202319761, orientation='plus', exon_count=27, OMIM=[606653], no_hdr0=''),
    59353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=59353, CurrentID=0, Status='live', Symbol='TMEM35A', Aliases=['NACHO', 'TMEM35', 'TUF-1'], description='transmembrane protein 35A', other_designations='novel acetylcholine receptor chaperone|nAChR regulator|nicotinic acetylcholine receptor regulator|transmembrane protein 35', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101078879, end_position_on_the_genomic_accession=101096367, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    60312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60312, CurrentID=0, Status='live', Symbol='AFAP1', Aliases=['AFAP', 'AFAP-11010', 'AFAP1'], description='actin filament associated protein 1', other_designations='actin filament-associated protein 1|110 kDa actin filament-associated protein|actin filament-associated protein, 110 kDa', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7758713, end_position_on_the_genomic_accession=7939861, orientation='minus', exon_count=21, OMIM=[608252], no_hdr0=''),
    60313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60313, CurrentID=0, Status='live', Symbol='GPBP1L1', Aliases=['SP192'], description='GC-rich promoter binding protein 1 like 1', other_designations='vasculin-like protein 1', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45627304, end_position_on_the_genomic_accession=45688110, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    60314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60314, CurrentID=0, Status='live', Symbol='MYG1', Aliases=['C12orf10', 'Gamm1', 'MST024', 'MSTP024', 'MYG'], description='MYG1 exonuclease', other_designations='MYG1 exonuclease|UPF0160 protein MYG1, mitochondrial|melanocyte proliferating gene 1|melanocyte related', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53299695, end_position_on_the_genomic_accession=53307177, orientation='plus', exon_count=7, OMIM=[611366], no_hdr0=''),
    60343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60343, CurrentID=0, Status='live', Symbol='FAM3A', Aliases=['2.19', 'DLD', 'DXS560S', 'XAP-7'], description='FAM3 metabolism regulating signaling molecule A', other_designations='protein FAM3A|cytokine-like protein 2-19|family with sequence similarity 3 member A', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154506164, end_position_on_the_genomic_accession=154516257, orientation='minus', exon_count=9, OMIM=[300492], no_hdr0=''),
    60370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60370, CurrentID=0, Status='live', Symbol='AVPI1', Aliases=['PP5395', 'VIP32', 'VIT32'], description='arginine vasopressin induced 1', other_designations='arginine vasopressin-induced protein 1|AVP-induced protein 1|vasopressin-induced transcript', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97677422, end_position_on_the_genomic_accession=97687432, orientation='minus', exon_count=3, OMIM=[618537], no_hdr0=''),
    60385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60385, CurrentID=0, Status='live', Symbol='TSKS', Aliases=['PPP1R161', 'STK22S11', 'TSSKS', 'TSKS'], description='testis specific serine kinase substrate', other_designations='testis-specific serine kinase substrate|STK22 substrate 1|protein phosphatase 1, regulatory subunit 161|testis specific serine/threonine kinase substrate|testis-specific kinase substrate', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49739753, end_position_on_the_genomic_accession=49763328, orientation='minus', exon_count=11, OMIM=[608253], no_hdr0=''),
    60386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60386, CurrentID=0, Status='live', Symbol='SLC25A19', Aliases=['DNC', 'MCPHA', 'MUP1', 'THMD3', 'THMD4', 'TPC'], description='solute carrier family 25 member 19', other_designations='mitochondrial thiamine pyrophosphate carrier|mitochondrial uncoupling protein 1|solute carrier family 25 (mitochondrial deoxynucleotide carrier), member 19|solute carrier family 25 (mitochondrial thiamine pyrophosphate carrier), member 19', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75272980, end_position_on_the_genomic_accession=75289958, orientation='minus', exon_count=11, OMIM=[606521], no_hdr0=''),
    60401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60401, CurrentID=0, Status='live', Symbol='EDA2R', Aliases=['EDA-A2R', 'EDAA2R', 'TNFRSF27', 'XEDAR'], description='ectodysplasin A2 receptor', other_designations='tumor necrosis factor receptor superfamily member 27|EDA-A2 receptor|X-linked ectodysplasin-A2 receptor|tumor necrosis factor receptor superfamily member XEDAR', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=66594384, end_position_on_the_genomic_accession=66639303, orientation='minus', exon_count=9, OMIM=[300276], no_hdr0=''),
    60412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60412, CurrentID=0, Status='live', Symbol='EXOC4', Aliases=['SEC8', 'SEC8L1', 'Sec8p'], description='exocyst complex component 4', other_designations='exocyst complex component 4|SEC8-like 1|exocyst complex component Sec8', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=133253075, end_position_on_the_genomic_accession=134067137, orientation='plus', exon_count=23, OMIM=[608185], no_hdr0=''),
    60436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60436, CurrentID=0, Status='live', Symbol='TGIF2', Aliases=[], description='TGFB induced factor homeobox 2', other_designations="homeobox protein TGIF2|5'-TG-3' interacting factor 2|TGF(beta)-induced transcription factor 2|TGFB-induced factor 2 (TALE family homeobox)|transcription growth factor-beta-induced factor 2", map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36573464, end_position_on_the_genomic_accession=36593950, orientation='plus', exon_count=5, OMIM=[607294], no_hdr0=''),
    60437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60437, CurrentID=0, Status='live', Symbol='CDH26', Aliases=['VR20'], description='cadherin 26', other_designations='cadherin-like protein 26|cadherin-like 26|cadherin-like protein VR20', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59957764, end_position_on_the_genomic_accession=60037971, orientation='plus', exon_count=23, OMIM=[617685], no_hdr0=''),
    60468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60468, CurrentID=0, Status='live', Symbol='BACH2', Aliases=['BTBD25', 'IMD60'], description='BTB domain and CNC homolog 2', other_designations='transcription regulator protein BACH2|BTB and CNC homolog 2|BTB and CNC homology 1, basic leucine zipper transcription factor 2', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89926528, end_position_on_the_genomic_accession=90296843, orientation='minus', exon_count=14, OMIM=[605394], no_hdr0=''),
    60481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60481, CurrentID=0, Status='live', Symbol='ELOVL5', Aliases=['HELO1', 'SCA38', 'dJ483K16.1'], description='ELOVL fatty acid elongase 5', other_designations='elongation of very long chain fatty acids protein 5|3-keto acyl-CoA synthase ELOVL5|ELOVL FA elongase 5|ELOVL family member 5, elongation of long chain fatty acids (FEN1/Elo2, SUR4/Elo3-like, yeast)|fatty acid elongase 1|homolog of yeast long chain polyunsaturated fatty acid elongation enzyme 2|spinocerebellar ataxia 38|very long chain 3-ketoacyl-CoA synthase 5|very long chain 3-oxoacyl-CoA synthase 5', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53267404, end_position_on_the_genomic_accession=53348950, orientation='minus', exon_count=10, OMIM=[611805], no_hdr0=''),
    60482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60482, CurrentID=0, Status='live', Symbol='SLC5A7', Aliases=['CHT', 'CHT1', 'CMS20', 'HMN7A'], description='solute carrier family 5 member 7', other_designations='high affinity choline transporter 1|high affinity choline transporter; hemicholinium-3-sensitive choline transporter|solute carrier family 5 (sodium/choline cotransporter), member 7', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=107986524, end_position_on_the_genomic_accession=108014497, orientation='plus', exon_count=10, OMIM=[608761], no_hdr0=''),
    60484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60484, CurrentID=0, Status='live', Symbol='HAPLN2', Aliases=['BRAL1'], description='hyaluronan and proteoglycan link protein 2', other_designations='hyaluronan and proteoglycan link protein 2|brain link protein-1', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156601504, end_position_on_the_genomic_accession=156626608, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    60485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60485, CurrentID=0, Status='live', Symbol='SAV1', Aliases=['SAV', 'WW45', 'WWP4'], description='salvador family WW domain containing protein 1', other_designations='protein salvador homolog 1|1700040G09Rik|45 kDa WW domain protein|WW domain-containing adaptor 45|hWW45|salvador homolog 1', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50633104, end_position_on_the_genomic_accession=50668306, orientation='minus', exon_count=6, OMIM=[607203], no_hdr0=''),
    60487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60487, CurrentID=0, Status='live', Symbol='TRMT11', Aliases=['C6orf75', 'MDS024', 'TRM11-1', 'TRMT11'], description='tRNA methyltransferase 11 homolog', other_designations="tRNA (guanine(10)-N2)-methyltransferase homolog|tRNA guanosine-2'-O-methyltransferase TRM11 homolog", map_location='6q22.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125986453, end_position_on_the_genomic_accession=126079728, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    60488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60488, CurrentID=0, Status='live', Symbol='MRPS35', Aliases=['HDCMD11P', 'MDS023', 'MRP-S28', 'MRPS28'], description='mitochondrial ribosomal protein S35', other_designations='28S ribosomal protein S35, mitochondrial|28S ribosomal protein S28, mitochondrial|MRP-S35|S28mt|S35mt|mitochondrial ribosomal protein S28|mitochondrial small ribosomal subunit protein mS35', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27710773, end_position_on_the_genomic_accession=27756295, orientation='plus', exon_count=9, OMIM=[611995], no_hdr0=''),
    60489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60489, CurrentID=0, Status='live', Symbol='APOBEC3G', Aliases=['A3G', 'ARCD', 'ARP-9', 'ARP9', 'CEM-15', 'CEM15', 'MDS019', 'bK150C2.7', 'dJ494G10.1'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3G', other_designations='DNA dC->dU-editing enzyme APOBEC-3G|APOBEC-related cytidine deaminase|APOBEC-related protein 9|DNA dC->dU editing enzyme|apolipoprotein B editing enzyme catalytic polypeptide-like 3G|apolipoprotein B mRNA editing enzyme cytidine deaminase|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3G|apolipoprotein B mRNA-editing enzyme catalytic polypeptide 3G|deoxycytidine deaminase|phorbolin-like protein MDS019', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39077005, end_position_on_the_genomic_accession=39087743, orientation='plus', exon_count=7, OMIM=[607113], no_hdr0=''),
    60490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60490, CurrentID=0, Status='live', Symbol='PPCDC', Aliases=['MDS018', 'PPC-DC', 'coaC'], description='phosphopantothenoylcysteine decarboxylase', other_designations='phosphopantothenoylcysteine decarboxylase', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75023544, end_position_on_the_genomic_accession=75060180, orientation='plus', exon_count=10, OMIM=[609854], no_hdr0=''),
    60491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60491, CurrentID=0, Status='live', Symbol='NIF3L1', Aliases=['ALS2CR1', 'CALS-7', 'MDS015'], description='NGG1 interacting factor 3 like 1', other_designations='NIF3-like protein 1|GTP cyclohydrolase I|NIF3 (Ngg1 interacting factor 3, S.pombe homolog)-like 1|NIF3 NGG1 interacting factor 3-like 1|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 1|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 1 protein|putative GTP cyclohydrolase 1 type 2 NIF3L1', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200889327, end_position_on_the_genomic_accession=200903932, orientation='plus', exon_count=8, OMIM=[605778], no_hdr0=''),
    60492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60492, CurrentID=0, Status='live', Symbol='CCDC90B', Aliases=['MDS011', 'MDS025'], description='coiled-coil domain containing 90B', other_designations='coiled-coil domain-containing protein 90B, mitochondrial', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=83259081, end_position_on_the_genomic_accession=83286367, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    60493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60493, CurrentID=0, Status='live', Symbol='FASTKD5', Aliases=['dJ1187M17.5'], description='FAST kinase domains 5', other_designations='FAST kinase domain-containing protein 5, mitochondrial', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3146519, end_position_on_the_genomic_accession=3159865, orientation='minus', exon_count=2, OMIM=[614272], no_hdr0=''),
    60494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60494, CurrentID=0, Status='live', Symbol='CCDC81', Aliases=[], description='coiled-coil domain containing 81', other_designations='coiled-coil domain-containing protein 81', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=86374736, end_position_on_the_genomic_accession=86424908, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    60495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60495, CurrentID=0, Status='live', Symbol='HPSE2', Aliases=['HPA2', 'HPR2', 'UFS', 'UFS1'], description='heparanase 2 (inactive)', other_designations='inactive heparanase-2|heparanase 3|heparanase-like protein', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=98457077, end_position_on_the_genomic_accession=99235875, orientation='minus', exon_count=18, OMIM=[613469], no_hdr0=''),
    60496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60496, CurrentID=0, Status='live', Symbol='AASDHPPT', Aliases=['AASD-PPT', 'ACPS', 'CGI-80', 'LYS2', 'LYS5'], description='aminoadipate-semialdehyde dehydrogenase-phosphopantetheinyl transferase', other_designations="L-aminoadipate-semialdehyde dehydrogenase-phosphopantetheinyl transferase|4'-phosphopantetheinyl transferase|LYS5 ortholog|alpha-aminoadipic semialdehyde dehydrogenase-phosphopantetheinyl transferase|holo ACP synthase|holo-[acyl-carrier-protein] synthase", map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=106077605, end_position_on_the_genomic_accession=106098695, orientation='plus', exon_count=7, OMIM=[607756], no_hdr0=''),
    60506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60506, CurrentID=0, Status='live', Symbol='NYX', Aliases=['CLRP', 'CSNB1', 'CSNB1A', 'CSNB4', 'NBM1'], description='nyctalopin', other_designations='nyctalopin|leucine-rich repeat protein', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41447343, end_position_on_the_genomic_accession=41475652, orientation='plus', exon_count=2, OMIM=[300278], no_hdr0=''),
    60509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60509, CurrentID=0, Status='live', Symbol='AGBL5', Aliases=['CCP5', 'RP75'], description='AGBL carboxypeptidase 5', other_designations='cytosolic carboxypeptidase-like protein 5|ATP/GTP binding protein like 5|cytosolic carboxypeptidase 5', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27051423, end_position_on_the_genomic_accession=27070620, orientation='plus', exon_count=18, OMIM=[615900], no_hdr0=''),
    60526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60526, CurrentID=0, Status='live', Symbol='LDAH', Aliases=['C2orf43', 'hLDAH'], description='lipid droplet associated hydrolase', other_designations='lipid droplet-associated hydrolase|UPF0554 protein C2orf43|lipid droplet-associated serine hydrolase', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20682489, end_position_on_the_genomic_accession=20823139, orientation='minus', exon_count=10, OMIM=[613570], no_hdr0=''),
    60528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60528, CurrentID=0, Status='live', Symbol='ELAC2', Aliases=['COXPD17', 'ELC2', 'HPC2'], description='elaC ribonuclease Z 2', other_designations='zinc phosphodiesterase ELAC protein 2|RNase Z 2|elaC homolog 2|elaC homolog protein 2|elaC-like protein 2|heredity prostate cancer protein 2|putative prostate cancer susceptibility protein HPC2/ELAC2|ribonuclease Z 2|tRNA 3 endonuclease 2|tRNase Z (long form)|tRNase Z 2', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=12991612, end_position_on_the_genomic_accession=13018027, orientation='minus', exon_count=25, OMIM=[605367], no_hdr0=''),
    60529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60529, CurrentID=0, Status='live', Symbol='ALX4', Aliases=['CRS5', 'FND2'], description='ALX homeobox 4', other_designations='homeobox protein aristaless-like 4|aristaless-like homeobox 4|homeodomain transcription factor ALX4', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44260440, end_position_on_the_genomic_accession=44310139, orientation='minus', exon_count=4, OMIM=[605420], no_hdr0=''),
    60558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60558, CurrentID=0, Status='live', Symbol='GUF1', Aliases=['DEE40', 'EF-4', 'EF4', 'EIEE40'], description='GTP binding elongation factor GUF1', other_designations='translation factor GUF1, mitochondrial|GTP-binding protein GUF1 homolog|GTPase of unknown function 1|GUF1 homolog, GTPase|elongation factor 4 homolog|ribosomal back-translocase', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=44678420, end_position_on_the_genomic_accession=44700928, orientation='plus', exon_count=17, OMIM=[617064], no_hdr0=''),
    60559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60559, CurrentID=0, Status='live', Symbol='SPCS3', Aliases=['PRO3567', 'SPC22', 'SPC22/23', 'SPC23', 'SPC3', 'YLR066W'], description='signal peptidase complex subunit 3', other_designations='signal peptidase complex subunit 3|SPase 22 kDa subunit|SPase 22/23 kDa subunit|microsomal signal peptidase 22/23 kDa subunit|microsomal signal peptidase 23 kDa subunit|signal peptidase complex subunit 3 homolog', map_location='4q34.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=176319966, end_position_on_the_genomic_accession=176332245, orientation='plus', exon_count=5, OMIM=[618854], no_hdr0=''),
    60560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60560, CurrentID=0, Status='live', Symbol='NAA35', Aliases=['EGAP', 'MAK10', 'MAK10P', 'bA379P1.1'], description='N-alpha-acetyltransferase 35, NatC auxiliary subunit', other_designations='N-alpha-acetyltransferase 35, NatC auxiliary subunit|MAK10 homolog, amino-acid N-acetyltransferase subunit|corneal wound healing-related protein|embryonic growth-associated protein homolog|protein MAK10 homolog', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=85941142, end_position_on_the_genomic_accession=86026355, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    60561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60561, CurrentID=0, Status='live', Symbol='RINT1', Aliases=['ILFS3', 'RINT-1'], description='RAD50 interactor 1', other_designations='RAD50-interacting protein 1', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105532170, end_position_on_the_genomic_accession=105567678, orientation='plus', exon_count=16, OMIM=[610089], no_hdr0=''),
    60592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60592, CurrentID=0, Status='live', Symbol='SCOC', Aliases=['HRIHFB2072O', 'UNC-69', 'SCOC'], description='short coiled-coil protein', other_designations='short coiled-coil protein', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140257308, end_position_on_the_genomic_accession=140385728, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    60598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60598, CurrentID=0, Status='live', Symbol='KCNK15', Aliases=['K2p15.1', 'KCNK11', 'KCNK14', 'KT3.3', 'TASK-5', 'TASK5', 'dJ781B1.1'], description='potassium two pore domain channel subfamily K member 15', other_designations='potassium channel subfamily K member 15|TWIK-related acid-sensitive K(+) channel 5|TWIK-related acid-sensitive K+ 5|acid-sensitive potassium channel protein TASK-5|potassium channel, subfamily K, member 14|potassium channel, two pore domain subfamily K, member 15|two pore K(+) channel KT3.3|two pore potassium channel KT3.3', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44745605, end_position_on_the_genomic_accession=44752313, orientation='plus', exon_count=3, OMIM=[607368], no_hdr0=''),
    60625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60625, CurrentID=0, Status='live', Symbol='DHX35', Aliases=['C20orf15', 'DDX35', 'KAIA0875'], description='DEAH-box helicase 35', other_designations='probable ATP-dependent RNA helicase DHX35|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 35|DEAH (Asp-Glu-Ala-His) box polypeptide 35|DEAH-box protein 35', map_location='20q11.23-q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38962344, end_position_on_the_genomic_accession=39039723, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    60626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60626, CurrentID=0, Status='live', Symbol='RIC8A', Aliases=['RIC8'], description='RIC8 guanine nucleotide exchange factor A', other_designations='synembryn-A|resistance to inhibitors of cholinesterase 8 homolog A', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=207708, end_position_on_the_genomic_accession=215113, orientation='plus', exon_count=10, OMIM=[609146], no_hdr0=''),
    60672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60672, CurrentID=0, Status='live', Symbol='MIIP', Aliases=['IIP45'], description='migration and invasion inhibitory protein', other_designations='migration and invasion-inhibitory protein|IGFBP2-binding protein|invasion-inhibitory protein 45', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12019466, end_position_on_the_genomic_accession=12032045, orientation='plus', exon_count=12, OMIM=[608772], no_hdr0=''),
    60673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60673, CurrentID=0, Status='live', Symbol='ATG101', Aliases=['C12orf44'], description='autophagy related 101', other_designations='autophagy-related protein 101|Atg13-interacting protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52069923, end_position_on_the_genomic_accession=52077495, orientation='plus', exon_count=5, OMIM=[615089], no_hdr0=''),
    60675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60675, CurrentID=0, Status='live', Symbol='PROK2', Aliases=['BV8', 'HH4', 'KAL4', 'MIT1', 'PK2'], description='prokineticin 2', other_designations='prokineticin-2|protein Bv8 homolog', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=71771655, end_position_on_the_genomic_accession=71785148, orientation='minus', exon_count=5, OMIM=[607002], no_hdr0=''),
    60676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60676, CurrentID=0, Status='live', Symbol='PAPPA2', Aliases=['PAPP-A2', 'PAPP-E', 'PAPPE', 'PLAC3'], description='pappalysin 2', other_designations='pappalysin-2|placenta-specific 3|pregnancy-associated plasma preproprotein-A2|pregnancy-associated plasma protein E1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=176463159, end_position_on_the_genomic_accession=176845601, orientation='plus', exon_count=29, OMIM=[], no_hdr0=''),
    60677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60677, CurrentID=0, Status='live', Symbol='CELF6', Aliases=['BRUNOL6'], description='CUGBP Elav-like family member 6', other_designations='CUGBP Elav-like family member 6|Bruno -like 6, RNA binding protein|CELF-6|CUG-BP- and ETR-3-like factor 6|RNA-binding protein BRUNOL-6|bruno-like 6, RNA binding protein|bruno-like protein 6', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72284727, end_position_on_the_genomic_accession=72320157, orientation='minus', exon_count=14, OMIM=[612681], no_hdr0=''),
    60678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60678, CurrentID=0, Status='live', Symbol='EEFSEC', Aliases=['EFSEC', 'SELB'], description='eukaryotic elongation factor, selenocysteine-tRNA specific', other_designations='selenocysteine-specific elongation factor|elongation factor for selenoprotein translation|elongation factor sec|selenocysteine (Sec)-specific eukaryotic elongation factor', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128153453, end_position_on_the_genomic_accession=128426193, orientation='plus', exon_count=12, OMIM=[607695], no_hdr0=''),
    60680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60680, CurrentID=0, Status='live', Symbol='CELF5', Aliases=['BRUNOL-5', 'BRUNOL5', 'CELF-5'], description='CUGBP Elav-like family member 5', other_designations='CUGBP Elav-like family member 5|CUG-BP and ETR-3 like factor 5|RNA-binding protein BRUNOL-5|bruno-like 5 RNA binding protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3224661, end_position_on_the_genomic_accession=3297076, orientation='plus', exon_count=17, OMIM=[612680], no_hdr0=''),
    60681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60681, CurrentID=0, Status='live', Symbol='FKBP10', Aliases=['BRKS1', 'FKBP65', 'OI11', 'OI6', 'PPIASE', 'hFKBP65'], description='FKBP prolyl isomerase 10', other_designations='peptidyl-prolyl cis-trans isomerase FKBP10|65 kDa FK506-binding protein|65 kDa FKBP|FK506 binding protein 10, 65 kDa|FK506-binding protein 10|FKBP-10|FKBP-65|PPIase FKBP10|immunophilin FKBP65|rotamase', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41812938, end_position_on_the_genomic_accession=41823215, orientation='plus', exon_count=11, OMIM=[607063], no_hdr0=''),
    60682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60682, CurrentID=0, Status='live', Symbol='SMAP1', Aliases=['SMAP-1'], description='small ArfGAP 1', other_designations='stromal membrane-associated protein 1|stromal membrane-associated GTPase-activating protein 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=70667883, end_position_on_the_genomic_accession=70862015, orientation='plus', exon_count=16, OMIM=[611372], no_hdr0=''),
    60684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60684, CurrentID=0, Status='live', Symbol='TRAPPC11', Aliases=['C4orf41', 'FOIGR', 'GRY', 'LGMD2S', 'LGMDR18'], description='trafficking protein particle complex subunit 11', other_designations='trafficking protein particle complex subunit 11|foie gras homolog|gryzun homolog|trafficking protein particle complex 11', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183659277, end_position_on_the_genomic_accession=183713592, orientation='plus', exon_count=32, OMIM=[614138], no_hdr0=''),
    60685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60685, CurrentID=0, Status='live', Symbol='ZFAND3', Aliases=['TEX27'], description='zinc finger AN1-type containing 3', other_designations='AN1-type zinc finger protein 3|testis expressed sequence 27|testis-expressed protein 27|zinc finger, AN1-type domain 3', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37819727, end_position_on_the_genomic_accession=38154624, orientation='plus', exon_count=7, OMIM=[607455], no_hdr0=''),
    60686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=60686, CurrentID=0, Status='live', Symbol='C14orf93', Aliases=['RTFC'], description='chromosome 14 open reading frame 93', other_designations='uncharacterized protein C14orf93|regulator of thyroid function and cancer', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22985894, end_position_on_the_genomic_accession=23010144, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    63027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63027, CurrentID=0, Status='live', Symbol='SLC22A23', Aliases=['C6orf85'], description='solute carrier family 22 member 23', other_designations='solute carrier family 22 member 23|ion transporter protein', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3268973, end_position_on_the_genomic_accession=3457050, orientation='minus', exon_count=21, OMIM=[611697], no_hdr0=''),
    63035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63035, CurrentID=0, Status='live', Symbol='BCORL1', Aliases=['BCoR-L1', 'CXorf10', 'SHUVER'], description='BCL6 corepressor like 1', other_designations='BCL-6 corepressor-like protein 1|BCoR-like protein 1', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=129980285, end_position_on_the_genomic_accession=130058081, orientation='plus', exon_count=20, OMIM=[300688], no_hdr0=''),
    63036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63036, CurrentID=0, Status='live', Symbol='CELA2A', Aliases=['AOMS4', 'ELA2A', 'PE-1'], description='chymotrypsin like elastase 2A', other_designations='chymotrypsin-like elastase family member 2A|chymotrypsin like elastase family member 2A|elastase 2A|pancreatic elastase 2|pancreatic elastase IIA', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15456732, end_position_on_the_genomic_accession=15472091, orientation='plus', exon_count=8, OMIM=[609443], no_hdr0=''),
    63826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63826, CurrentID=0, Status='live', Symbol='SRR', Aliases=['ILV1', 'ISO1'], description='serine racemase', other_designations='serine racemase|D-serine ammonia-lyase|D-serine dehydratase|L-serine ammonia-lyase|L-serine dehydratase', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2303371, end_position_on_the_genomic_accession=2325267, orientation='plus', exon_count=11, OMIM=[606477], no_hdr0=''),
    63827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63827, CurrentID=0, Status='live', Symbol='BCAN', Aliases=['BEHAB', 'CSPG7'], description='brevican', other_designations='brevican core protein|brain-enriched hyaluronan-binding protein|chondroitin sulfate proteoglycan 7|chondroitin sulfate proteoglycan BEHAB', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156642117, end_position_on_the_genomic_accession=156659528, orientation='plus', exon_count=15, OMIM=[600347], no_hdr0=''),
    63874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63874, CurrentID=0, Status='live', Symbol='ABHD4', Aliases=['ABH4'], description='abhydrolase domain containing 4, N-acyl phospholipase B', other_designations='(Lyso)-N-acylphosphatidylethanolamine lipase|abhydrolase domain-containing protein 4|alpha/beta hydrolase domain-containing protein 4|alpha/beta-hydrolase 4|lyso-N-acylphosphatidylethanolamine lipase|protein ABHD4', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22598298, end_position_on_the_genomic_accession=22612963, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    63875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63875, CurrentID=0, Status='live', Symbol='MRPL17', Aliases=['L17mt', 'LIP2', 'MRP-L17', 'MRP-L26', 'RPL17L', 'RPML26'], description='mitochondrial ribosomal protein L17', other_designations='39S ribosomal protein L17, mitochondrial|LYST-interacting protein 2|LYST-interacting protein LIP2|mitochondrial large ribosomal subunit protein bL17m', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6680385, end_position_on_the_genomic_accession=6683340, orientation='minus', exon_count=3, OMIM=[611830], no_hdr0=''),
    63876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63876, CurrentID=0, Status='live', Symbol='PKNOX2', Aliases=['PREP2'], description='PBX/knotted 1 homeobox 2', other_designations='homeobox protein PKNOX2|PBX/knotted homeobox 2|homeobox protein PREP-2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125164751, end_position_on_the_genomic_accession=125433389, orientation='plus', exon_count=17, OMIM=[613066], no_hdr0=''),
    63877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63877, CurrentID=0, Status='live', Symbol='FAM204A', Aliases=['C10orf84', 'bA319I23.1'], description='family with sequence similarity 204 member A', other_designations='protein FAM204A', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=118297925, end_position_on_the_genomic_accession=118342325, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    63891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63891, CurrentID=0, Status='live', Symbol='RNF123', Aliases=['FP1477', 'KPC1'], description='ring finger protein 123', other_designations='E3 ubiquitin-protein ligase RNF123|Kip1 ubiquitination-promoting complex subunit 1|RING-type E3 ubiquitin transferase RNF123|kip1 ubiquitination-promoting complex protein 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49688753, end_position_on_the_genomic_accession=49721529, orientation='plus', exon_count=41, OMIM=[614472], no_hdr0=''),
    63892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63892, CurrentID=0, Status='live', Symbol='THADA', Aliases=['ARMC13', 'GITA'], description='THADA armadillo repeat containing', other_designations='thyroid adenoma-associated protein|death receptor-interacting protein|gene inducing thyroid adenomas protein', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43230851, end_position_on_the_genomic_accession=43596046, orientation='minus', exon_count=41, OMIM=[611800], no_hdr0=''),
    63893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63893, CurrentID=0, Status='live', Symbol='UBE2O', Aliases=['E2-230K'], description='ubiquitin conjugating enzyme E2 O', other_designations='(E3-independent) E2 ubiquitin-conjugating enzyme|E2/E3 hybrid ubiquitin-protein ligase UBE2O|ubiquitin carrier protein O|ubiquitin conjugating enzyme E2O|ubiquitin-conjugating enzyme E2 of 230 kDa|ubiquitin-conjugating enzyme E2-230K|ubiquitin-protein ligase O', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76389456, end_position_on_the_genomic_accession=76453234, orientation='minus', exon_count=19, OMIM=[617649], no_hdr0=''),
    63894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63894, CurrentID=0, Status='live', Symbol='VIPAS39', Aliases=['C14orf133', 'SPE-39', 'SPE39', 'VIPAR', 'VPS16B', 'hSPE-39'], description='VPS33B interacting protein, apical-basolateral polarity regulator, spe-39 homolog', other_designations='spermatogenesis-defective protein 39 homolog|VPS33B-interacting protein involved in polarity and apical protein restriction', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77426675, end_position_on_the_genomic_accession=77457727, orientation='minus', exon_count=22, OMIM=[613401], no_hdr0=''),
    63895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63895, CurrentID=0, Status='live', Symbol='PIEZO2', Aliases=['C18orf30', 'C18orf58', 'DA3', 'DA5', 'DAIPT', 'FAM38B', 'FAM38B2', 'HsT748', 'HsT771', 'MWKS'], description='piezo type mechanosensitive ion channel component 2', other_designations='piezo-type mechanosensitive ion channel component 2|PIEZO2 variant 16|family with sequence similarity 38, member A pseudogene|family with sequence similarity 38, member B2|piezo-type mechanosensitive ion channel component 1 pseudogene|protein PIEZO2', map_location='18p11.22-p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=10670237, end_position_on_the_genomic_accession=11149585, orientation='minus', exon_count=57, OMIM=[613629], no_hdr0=''),
    63897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63897, CurrentID=0, Status='live', Symbol='HEATR6', Aliases=['ABC1'], description='HEAT repeat containing 6', other_designations='HEAT repeat-containing protein 6|amplified in breast cancer 1|amplified in breast cancer protein 1', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60041008, end_position_on_the_genomic_accession=60078921, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    63898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63898, CurrentID=0, Status='live', Symbol='SH2D4A', Aliases=['PPP1R38', 'SH2A'], description='SH2 domain containing 4A', other_designations='SH2 domain-containing protein 4A|protein SH(2)A|protein phosphatase 1 regulatory subunit 38', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=19313693, end_position_on_the_genomic_accession=19396218, orientation='plus', exon_count=11, OMIM=[614968], no_hdr0=''),
    63899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63899, CurrentID=0, Status='live', Symbol='NSUN3', Aliases=['COXPD48', 'MST077', 'MSTP077'], description='NOP2/Sun RNA methyltransferase 3', other_designations='tRNA (cytosine(34)-C(5))-methyltransferase, mitochondrial|NOL1/NOP2/Sun domain family member 3|NOP2/Sun RNA methyltransferase family member 3|putative methyltransferase NSUN3', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=94063061, end_position_on_the_genomic_accession=94131832, orientation='plus', exon_count=7, OMIM=[617491], no_hdr0=''),
    63901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63901, CurrentID=0, Status='live', Symbol='FAM111A', Aliases=['GCLEB', 'KCS2'], description='FAM111 trypsin like peptidase A', other_designations='serine protease FAM111A|family with sequence similarity 111 member A|protein FAM111A', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59142856, end_position_on_the_genomic_accession=59155039, orientation='plus', exon_count=5, OMIM=[615292], no_hdr0=''),
    63904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63904, CurrentID=0, Status='live', Symbol='DUSP21', Aliases=['LMWDSP21'], description='dual specificity phosphatase 21', other_designations='dual specificity protein phosphatase 21|BJ-HCC-26 tumor antigen|LMW-DSP21|low molecular weight dual specificity phosphatase 21', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=44844021, end_position_on_the_genomic_accession=44844888, orientation='plus', exon_count=1, OMIM=[300678], no_hdr0=''),
    63905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63905, CurrentID=0, Status='live', Symbol='MANBAL', Aliases=[], description='mannosidase beta like', other_designations='protein MANBAL|mannosidase beta A like|mannosidase, beta A, lysosomal-like', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37289655, end_position_on_the_genomic_accession=37317260, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    63906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63906, CurrentID=0, Status='live', Symbol='GPATCH3', Aliases=['GPATC3'], description='G-patch domain containing 3', other_designations='G patch domain-containing protein 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26890488, end_position_on_the_genomic_accession=26900467, orientation='minus', exon_count=7, OMIM=[617486], no_hdr0=''),
    63908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63908, CurrentID=0, Status='live', Symbol='NAPB', Aliases=['SNAP-BETA', 'SNAPB'], description='NSF attachment protein beta', other_designations='beta-soluble NSF attachment protein|N-ethylmaleimide-sensitive factor attachment protein, beta', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23374522, end_position_on_the_genomic_accession=23421498, orientation='minus', exon_count=13, OMIM=[611270], no_hdr0=''),
    63910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63910, CurrentID=0, Status='live', Symbol='SLC17A9', Aliases=['C20orf59', 'POROK8', 'VNUT'], description='solute carrier family 17 member 9', other_designations='solute carrier family 17 member 9|solute carrier family 17 (vesicular nucleotide transporter), member 9|vesicular nucleotide transporter SLC17A9', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62952690, end_position_on_the_genomic_accession=62969585, orientation='plus', exon_count=14, OMIM=[612107], no_hdr0=''),
    63915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63915, CurrentID=0, Status='live', Symbol='BLOC1S5', Aliases=['BLOS5', 'HPS11', 'MU', 'MUTED'], description='biogenesis of lysosomal organelles complex 1 subunit 5', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 5|BLOC-1 subunit 5|biogenesis of lysosomal organelles complex-1, subunit 5, muted|muted homolog|protein Muted homolog', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=8013567, end_position_on_the_genomic_accession=8064414, orientation='minus', exon_count=6, OMIM=[607289], no_hdr0=''),
    63916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63916, CurrentID=0, Status='live', Symbol='ELMO2', Aliases=['CED-12', 'CED12', 'Ced-12A', 'ELMO-2', 'VMPI'], description='engulfment and cell motility 2', other_designations='engulfment and cell motility protein 2|PH domain protein CED12A|ced-12 homolog 2|protein ced-12 homolog A', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46366050, end_position_on_the_genomic_accession=46407051, orientation='minus', exon_count=22, OMIM=[606421], no_hdr0=''),
    63917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63917, CurrentID=0, Status='live', Symbol='GALNT11', Aliases=['GALNAC-T11', 'GALNACT11'], description='polypeptide N-acetylgalactosaminyltransferase 11', other_designations='polypeptide N-acetylgalactosaminyltransferase 11|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 11|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 11 (GalNAc-T11)|polypeptide GalNAc transferase 11|pp-GaNTase 11|protein-UDP acetylgalactosaminyltransferase 11', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=152025674, end_position_on_the_genomic_accession=152122345, orientation='plus', exon_count=22, OMIM=[615130], no_hdr0=''),
    63920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63920, CurrentID=0, Status='live', Symbol='ZBED8', Aliases=['Buster3', 'C5orf54'], description='zinc finger BED-type containing 8', other_designations='protein ZBED8|transposon-derived Buster3 transposase-like protein|zinc finger BED domain-containing protein 8', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160393148, end_position_on_the_genomic_accession=160400054, orientation='minus', exon_count=3, OMIM=[615253], no_hdr0=''),
    63922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63922, CurrentID=0, Status='live', Symbol='CHTF18', Aliases=['C16orf41', 'C321D2.2', 'C321D2.3', 'C321D2.4', 'CHL12', 'Ctf18', 'RUVBL'], description='chromosome transmission fidelity factor 18', other_designations='chromosome transmission fidelity protein 18 homolog|CTF18, chromosome transmission fidelity factor 18 homolog|homolog of yeast CHL12|some homology with holliday junction DNA helicase RUVB like', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=788620, end_position_on_the_genomic_accession=798074, orientation='plus', exon_count=21, OMIM=[613201], no_hdr0=''),
    63923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63923, CurrentID=0, Status='live', Symbol='TNN', Aliases=['TN-W', 'TNW'], description='tenascin N', other_designations='tenascin-N|TN-N|tenascin-W', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=175067833, end_position_on_the_genomic_accession=175148075, orientation='plus', exon_count=20, OMIM=[617472], no_hdr0=''),
    63924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63924, CurrentID=0, Status='live', Symbol='CIDEC', Aliases=['CIDE-3', 'CIDE3', 'FPLD5', 'FSP27'], description='cell death inducing DFFA like effector c', other_designations='cell death activator CIDE-3|fat specific protein 27', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9866710, end_position_on_the_genomic_accession=9880253, orientation='minus', exon_count=9, OMIM=[612120], no_hdr0=''),
    63925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63925, CurrentID=0, Status='live', Symbol='ZNF335', Aliases=['MCPH10', 'NIF-1', 'NIF1', 'NIF2'], description='zinc finger protein 335', other_designations='zinc finger protein 335|NRC-interacting factor 1|zinc-finger/leucine-zipper co-transducer NIF1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45948653, end_position_on_the_genomic_accession=45972910, orientation='minus', exon_count=27, OMIM=[610827], no_hdr0=''),
    63926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63926, CurrentID=0, Status='live', Symbol='ANKEF1', Aliases=['ANKRD5'], description='ankyrin repeat and EF-hand domain containing 1', other_designations='ankyrin repeat and EF-hand domain-containing protein 1|ankyrin repeat domain-containing protein 5', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=10034987, end_position_on_the_genomic_accession=10058303, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    63928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63928, CurrentID=0, Status='live', Symbol='CHP2', Aliases=[], description='calcineurin like EF-hand protein 2', other_designations='calcineurin B homologous protein 2|hepatocellular carcinoma antigen gene 520|hepatocellular carcinoma-associated antigen 520', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23755026, end_position_on_the_genomic_accession=23758935, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    63929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63929, CurrentID=0, Status='live', Symbol='XPNPEP3', Aliases=['APP3', 'ICP55', 'NPHPL1'], description='X-prolyl aminopeptidase 3', other_designations='xaa-Pro aminopeptidase 3|Intermediate Cleaving Peptidase 55|X-Pro aminopeptidase 3|X-prolyl aminopeptidase 3, mitochondrial|probable Xaa-Pro aminopeptidase 3', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40857148, end_position_on_the_genomic_accession=40932815, orientation='plus', exon_count=12, OMIM=[613553], no_hdr0=''),
    63931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63931, CurrentID=0, Status='live', Symbol='MRPS14', Aliases=['COXPD38', 'DJ262D12.2', 'HSMRPS14', 'MRP-S14', 'S14mt'], description='mitochondrial ribosomal protein S14', other_designations='28S ribosomal protein S14, mitochondrial|mitochondrial 28S ribosomal protein S14|mitochondrial small ribosomal subunit protein uS14m', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=175012958, end_position_on_the_genomic_accession=175023425, orientation='minus', exon_count=3, OMIM=[611978], no_hdr0=''),
    63932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63932, CurrentID=0, Status='live', Symbol='STEEP1', Aliases=['CXorf56', 'MRX107', 'STEEP'], description='STING1 ER exit protein 1', other_designations='STING ER exit protein|UPF0428 protein CXorf56', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119538149, end_position_on_the_genomic_accession=119565409, orientation='minus', exon_count=7, OMIM=[301012], no_hdr0=''),
    63933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63933, CurrentID=0, Status='live', Symbol='MCUR1', Aliases=['C6orf79', 'CCDC90A', 'FMP32'], description='mitochondrial calcium uniporter regulator 1', other_designations='mitochondrial calcium uniporter regulator 1|MCU regulator 1|coiled-coil domain containing 90A|coiled-coil domain-containing protein 90A, mitochondrial|epididymis secretory sperm binding protein', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13786557, end_position_on_the_genomic_accession=13814994, orientation='minus', exon_count=10, OMIM=[616952], no_hdr0=''),
    63934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63934, CurrentID=0, Status='live', Symbol='ZNF667', Aliases=['MIPU1'], description='zinc finger protein 667', other_designations='zinc finger protein 667|myocardial ischemic preconditioning upregulated 1 ortholog', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56438512, end_position_on_the_genomic_accession=56478065, orientation='minus', exon_count=14, OMIM=[611024], no_hdr0=''),
    63935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63935, CurrentID=0, Status='live', Symbol='PCIF1', Aliases=['C20orf67', 'CAPAM', 'PPP1R121', 'hCAPAM', 'hPCIF1'], description='phosphorylated CTD interacting factor 1', other_designations="mRNA (2'-O-methyladenosine-N(6)-)-methyltransferase|PDX-1 C terminus-interacting factor 1|PDX1 C-terminal inhibiting factor 1|cap-specific adenosine methyltransferase|protein phosphatase 1, regulatory subunit 121", map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45934674, end_position_on_the_genomic_accession=45948023, orientation='plus', exon_count=18, OMIM=[618626], no_hdr0=''),
    63939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63939, CurrentID=0, Status='live', Symbol='FAM217B', Aliases=['C20orf177', 'dJ551D2.5'], description='family with sequence similarity 217 member B', other_designations='protein FAM217B|uncharacterized protein C20orf177', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59933769, end_position_on_the_genomic_accession=59948680, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    63940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63940, CurrentID=0, Status='live', Symbol='GPSM3', Aliases=['AGS4', 'C6orf9', 'G18', 'G18.1a', 'G18.1b', 'G18.2', 'NG1'], description='G protein signaling modulator 3', other_designations='G-protein-signaling modulator 3|G-protein signaling modulator 3 (AGS3-like, C. elegans)|G-protein signalling modulator 3 (AGS3-like, C. elegans)|activator of G-protein signaling 4', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32190766, end_position_on_the_genomic_accession=32195523, orientation='minus', exon_count=8, OMIM=[618558], no_hdr0=''),
    63941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63941, CurrentID=0, Status='live', Symbol='NECAB3', Aliases=['APBA2BP', 'EFCBP3', 'NIP1', 'STIP3', 'SYTIP2', 'XB51', 'dJ63M2.4', 'dJ63M2.5'], description='N-terminal EF-hand calcium binding protein 3', other_designations='N-terminal EF-hand calcium-binding protein 3|EF-hand calcium binding protein 3|Nek2-interacting protein 1|X11L-binding protein 51|amyloid beta (A4) precursor protein-binding, family A, member 2 binding protein|amyloid beta A4 protein-binding family A member 2-binding protein|neuronal calcium-binding protein 3|neuronal calcium-binding protein NECAB3|synaptotagmin interacting protein 2|synaptotagmin interacting protein STIP3', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33657087, end_position_on_the_genomic_accession=33674428, orientation='minus', exon_count=16, OMIM=[612478], no_hdr0=''),
    63943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63943, CurrentID=0, Status='live', Symbol='FKBPL', Aliases=['DIR1', 'NG7', 'WISP39'], description='FKBP prolyl isomerase like', other_designations='FK506-binding protein-like|FK506 binding protein like|WAF-1/CIP1 stabilizing protein 39|peptidyl-prolyl cis-trans isomerase', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32128707, end_position_on_the_genomic_accession=32130288, orientation='minus', exon_count=2, OMIM=[617076], no_hdr0=''),
    63946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63946, CurrentID=0, Status='live', Symbol='DMRTC2', Aliases=[], description='DMRT like family C2', other_designations='doublesex- and mab-3-related transcription factor C2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41844743, end_position_on_the_genomic_accession=41852333, orientation='plus', exon_count=12, OMIM=[614806], no_hdr0=''),
    63947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63947, CurrentID=0, Status='live', Symbol='DMRTC1', Aliases=[], description='DMRT like family C1', other_designations='doublesex- and mab-3-related transcription factor C1|doublesex-mab-3', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72872025, end_position_on_the_genomic_accession=72943837, orientation='minus', exon_count=7, OMIM=[300878], no_hdr0=''),
    63948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63948, CurrentID=0, Status='live', Symbol='DMRTB1', Aliases=[], description='DMRT like family B with proline rich C-terminal 1', other_designations='doublesex- and mab-3-related transcription factor B1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53459399, end_position_on_the_genomic_accession=53467488, orientation='plus', exon_count=4, OMIM=[614805], no_hdr0=''),
    63950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63950, CurrentID=0, Status='live', Symbol='DMRTA2', Aliases=[], description='DMRT like family A2', other_designations='doublesex- and mab-3-related transcription factor A2|doublesex- and mab-3-related transcription factor 5', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=50417550, end_position_on_the_genomic_accession=50423443, orientation='minus', exon_count=3, OMIM=[614804], no_hdr0=''),
    63951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63951, CurrentID=0, Status='live', Symbol='DMRTA1', Aliases=['DMO', 'DMRT4'], description='DMRT like family A1', other_designations='doublesex- and mab-3-related transcription factor A1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=22446824, end_position_on_the_genomic_accession=22455740, orientation='plus', exon_count=2, OMIM=[614803], no_hdr0=''),
    63967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63967, CurrentID=0, Status='live', Symbol='CLSPN', Aliases=[], description='claspin', other_designations='claspin|claspin homolog', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35720213, end_position_on_the_genomic_accession=35769985, orientation='minus', exon_count=26, OMIM=[605434], no_hdr0=''),
    63970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63970, CurrentID=0, Status='live', Symbol='TP53AIP1', Aliases=['P53AIP1'], description='tumor protein p53 regulated apoptosis inducing protein 1', other_designations='p53-regulated apoptosis-inducing protein 1', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=128934731, end_position_on_the_genomic_accession=128944233, orientation='minus', exon_count=7, OMIM=[605426], no_hdr0=''),
    63971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63971, CurrentID=0, Status='live', Symbol='KIF13A', Aliases=['RBKIN', 'bA500C11.2'], description='kinesin family member 13A', other_designations='kinesin-like protein KIF13A|homolog of mouse KIF13A mannose-6-phosphate receptor transporter|kinesin-like protein RBKIN', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17759126, end_position_on_the_genomic_accession=17987635, orientation='minus', exon_count=45, OMIM=[605433], no_hdr0=''),
    63973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63973, CurrentID=0, Status='live', Symbol='NEUROG2', Aliases=['Atoh4', 'Math4A', 'NGN2', 'bHLHa8', 'ngn-2'], description='neurogenin 2', other_designations='neurogenin-2|class A basic helix-loop-helix protein 8|protein atonal homolog 4', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112513516, end_position_on_the_genomic_accession=112516180, orientation='minus', exon_count=2, OMIM=[606624], no_hdr0=''),
    63974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63974, CurrentID=0, Status='live', Symbol='NEUROD6', Aliases=['Atoh2', 'MATH2', 'Math-2', 'NEX1M', 'Nex1', 'bHLHa2'], description='neuronal differentiation 6', other_designations='neurogenic differentiation factor 6|brain my051 protein|class A basic helix-loop-helix protein 2|protein atonal homolog 2', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31337465, end_position_on_the_genomic_accession=31340726, orientation='minus', exon_count=2, OMIM=[611513], no_hdr0=''),
    63976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63976, CurrentID=0, Status='live', Symbol='PRDM16', Aliases=['CMD1LL', 'KMT8F', 'LVNC8', 'MEL1', 'PFM13'], description='PR/SET domain 16', other_designations='histone-lysine N-methyltransferase PRDM16|MDS1/EVI1-like gene 1|PR domain 16|PR domain containing 16|PR domain zinc finger protein 16|transcription factor MEL1', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3069203, end_position_on_the_genomic_accession=3438621, orientation='plus', exon_count=17, OMIM=[605557], no_hdr0=''),
    63977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63977, CurrentID=0, Status='live', Symbol='PRDM15', Aliases=['C21orf83', 'PFM15', 'ZNF298'], description='PR/SET domain 15', other_designations='PR domain zinc finger protein 15|PR domain 15|PR domain containing 15|zinc finger protein 298', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=41798225, end_position_on_the_genomic_accession=41879396, orientation='minus', exon_count=37, OMIM=[617692], no_hdr0=''),
    63978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63978, CurrentID=0, Status='live', Symbol='PRDM14', Aliases=['PFM11'], description='PR/SET domain 14', other_designations='PR domain zinc finger protein 14|PR domain 14|PR domain-containing 14|PR domain-containing protein 14', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=70051613, end_position_on_the_genomic_accession=70071252, orientation='minus', exon_count=9, OMIM=[611781], no_hdr0=''),
    63979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63979, CurrentID=0, Status='live', Symbol='FIGNL1', Aliases=[], description='fidgetin like 1', other_designations='fidgetin-like protein 1', map_location='7p12.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=50437320, end_position_on_the_genomic_accession=50450400, orientation='minus', exon_count=5, OMIM=[615383], no_hdr0=''),
    63982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=63982, CurrentID=0, Status='live', Symbol='ANO3', Aliases=['C11orf25', 'DYT23', 'DYT24', 'GENX-3947', 'TMEM16C'], description='anoctamin 3', other_designations='anoctamin-3|dystonia 23|transmembrane protein 16C (eight membrane-spanning domains)', map_location='11p14.3-p14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=26188808, end_position_on_the_genomic_accession=26667907, orientation='plus', exon_count=33, OMIM=[610110], no_hdr0=''),
    64005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64005, CurrentID=0, Status='live', Symbol='MYO1G', Aliases=['HA2', 'HLA-HA2', 'MHAG'], description='myosin IG', other_designations='unconventional myosin-Ig|minor histocompatibility antigen HA-2|myosin-Ig', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44962662, end_position_on_the_genomic_accession=44979105, orientation='minus', exon_count=22, OMIM=[600642], no_hdr0=''),
    64061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64061, CurrentID=0, Status='live', Symbol='TSPYL2', Aliases=['CDA1', 'CINAP', 'CTCL', 'DENTT', 'HRIHFB2216', 'NP79', 'SE204', 'TSPX'], description='TSPY like 2', other_designations='testis-specific Y-encoded-like protein 2|CASK-interacting nucleosome assembly protein|CTCL tumor antigen se20-4|CTCL-associated antigen se20-4|TSPY-like protein 2|cell division autoantigen 1|cutaneous T-cell lymphoma-associated antigen se20-4|cutaneous T-cell lymphoma-associated tumor antigen se20-4|differentially expressed nucleolar TGF-beta1 target|differentially-expressed nucleolar TGF-beta1 target protein|nuclear protein of 79 kDa|testis-specific protein Y encoded-like 2', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53082367, end_position_on_the_genomic_accession=53088540, orientation='plus', exon_count=6, OMIM=[300564], no_hdr0=''),
    64062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64062, CurrentID=0, Status='live', Symbol='RBM26', Aliases=['ARRS2', 'C13orf10', 'PPP1R132', 'PRO1777', 'SE70-2', 'ZC3H17'], description='RNA binding motif protein 26', other_designations='RNA-binding protein 26|CTCL tumor antigen se70-2|acidic rich RS domain containing 2|cutaneous T-cell lymphoma tumor antigen se70-2|protein phosphatase 1, regulatory 132', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=79311827, end_position_on_the_genomic_accession=79406255, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    64063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64063, CurrentID=0, Status='live', Symbol='PRSS22', Aliases=['BSSP-4', 'SP001LA', 'hBSSP-4'], description='serine protease 22', other_designations='brain-specific serine protease 4|prosemin|protease, serine 22|protease, serine S1 family member 22|serine protease 26|tryptase epsilon', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2852729, end_position_on_the_genomic_accession=2858630, orientation='minus', exon_count=7, OMIM=[609343], no_hdr0=''),
    64064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64064, CurrentID=0, Status='live', Symbol='OXCT2', Aliases=['FKSG25', 'SCOTT'], description='3-oxoacid CoA-transferase 2', other_designations='succinyl-CoA:3-ketoacid coenzyme A transferase 2, mitochondrial|3-oxoacid CoA-transferase 2A|testis-specific succinyl CoA:3-oxoacid CoA-transferase', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39769523, end_position_on_the_genomic_accession=39771348, orientation='minus', exon_count=1, OMIM=[610289], no_hdr0=''),
    64065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64065, CurrentID=0, Status='live', Symbol='PERP', Aliases=['EKVP7', 'KCP1', 'KRTCAP1', 'OLMS2', 'PIGPC1', 'THW', 'dJ496H19.1'], description='p53 apoptosis effector related to PMP22', other_designations='p53 apoptosis effector related to PMP-22|1110017A08Rik|KCP-1|PERP, TP53 apoptosis effector|keratinocyte-associated protein 1|keratinocytes associated protein 1|p53-induced protein PIGPC1|transmembrane protein THW', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138088505, end_position_on_the_genomic_accession=138107419, orientation='minus', exon_count=4, OMIM=[609301], no_hdr0=''),
    64066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64066, CurrentID=0, Status='live', Symbol='MMP27', Aliases=['MMP-27'], description='matrix metallopeptidase 27', other_designations='matrix metalloproteinase-27|matrix metalloprotease 27', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102690943, end_position_on_the_genomic_accession=102705785, orientation='minus', exon_count=10, OMIM=[618101], no_hdr0=''),
    64067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64067, CurrentID=0, Status='live', Symbol='NPAS3', Aliases=['MOP6', 'PASD6', 'bHLHe12'], description='neuronal PAS domain protein 3', other_designations='neuronal PAS domain-containing protein 3|PAS domain-containing protein 6|basic-helix-loop-helix-PAS protein MOP6|class E basic helix-loop-helix protein 12|member of PAS protein 6|neuronal PAS3', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=32934785, end_position_on_the_genomic_accession=33804176, orientation='plus', exon_count=18, OMIM=[609430], no_hdr0=''),
    64072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64072, CurrentID=0, Status='live', Symbol='CDH23', Aliases=['CDHR23', 'PITA5', 'USH1D'], description='cadherin related 23', other_designations='cadherin-23|cadherin-like 23|cadherin-related family member 23|otocadherin', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71396920, end_position_on_the_genomic_accession=71815947, orientation='plus', exon_count=71, OMIM=[605516], no_hdr0=''),
    64073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64073, CurrentID=0, Status='live', Symbol='C19orf33', Aliases=['H2RSP', 'IMUP', 'IMUP-1', 'IMUP-2'], description='chromosome 19 open reading frame 33', other_designations='immortalization up-regulated protein|HAI-2 related small protein|hepatocyte growth factor activator inhibitor type 2-related small protein|immortalization-upregulated protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38304251, end_position_on_the_genomic_accession=38305006, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    64077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64077, CurrentID=0, Status='live', Symbol='LHPP', Aliases=['HDHD2B'], description='phospholysine phosphohistidine inorganic pyrophosphate phosphatase', other_designations='phospholysine phosphohistidine inorganic pyrophosphate phosphatase|hLHPP', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124461823, end_position_on_the_genomic_accession=124614141, orientation='plus', exon_count=15, OMIM=[617231], no_hdr0=''),
    64078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64078, CurrentID=0, Status='live', Symbol='SLC28A3', Aliases=['CNT3'], description='solute carrier family 28 member 3', other_designations='solute carrier family 28 member 3|concentrative Na(+)-nucleoside cotransporter 3|concentrative Na+-nucleoside cotransporter|solute carrier family 28 (concentrative nucleoside transporter), member 3|solute carrier family 28 (sodium-coupled nucleoside transporter), member 3', map_location='9q21.32-q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=84273123, end_position_on_the_genomic_accession=84368727, orientation='minus', exon_count=22, OMIM=[608269], no_hdr0=''),
    64080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64080, CurrentID=0, Status='live', Symbol='RBKS', Aliases=['RBSK', 'RK'], description='ribokinase', other_designations='ribokinase', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27781379, end_position_on_the_genomic_accession=27890387, orientation='minus', exon_count=9, OMIM=[611132], no_hdr0=''),
    64081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64081, CurrentID=0, Status='live', Symbol='PBLD', Aliases=['HEL-S-306', 'MAWBP', 'MAWDBP'], description='phenazine biosynthesis like protein domain containing', other_designations='phenazine biosynthesis-like domain-containing protein|MAWD-binding protein|epididymis secretory protein Li 306|epididymis secretory sperm binding protein', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68282660, end_position_on_the_genomic_accession=68332958, orientation='minus', exon_count=10, OMIM=[612189], no_hdr0=''),
    64083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64083, CurrentID=0, Status='live', Symbol='GOLPH3', Aliases=['GOPP1', 'GPP34', 'MIDAS', 'Vps74'], description='golgi phosphoprotein 3', other_designations='Golgi phosphoprotein 3|coat protein GPP34|coat-protein|golgi peripheral membrane protein 1, 34 kDa|golgi protein|golgi-associated protein|mitochondrial DNA absence factor', map_location='5p13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=32124711, end_position_on_the_genomic_accession=32174319, orientation='minus', exon_count=6, OMIM=[612207], no_hdr0=''),
    64084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64084, CurrentID=0, Status='live', Symbol='CLSTN2', Aliases=['ALC-GAMMA', 'CDHR13', 'CS2', 'CSTN2', 'alcagamma'], description='calsyntenin 2', other_designations='calsyntenin-2|alcadein gamma|cadherin-related family member 13', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139935185, end_position_on_the_genomic_accession=140577397, orientation='plus', exon_count=18, OMIM=[611323], no_hdr0=''),
    64087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64087, CurrentID=0, Status='live', Symbol='MCCC2', Aliases=['MCCB', 'MCCCbeta'], description='methylcrotonyl-CoA carboxylase subunit 2', other_designations='methylcrotonoyl-CoA carboxylase beta chain, mitochondrial|3-methylcrotonyl-CoA carboxylase 2|3-methylcrotonyl-CoA carboxylase non-biotin-containing subunit|3-methylcrotonyl-CoA:carbon dioxide ligase subunit beta|MCCase subunit beta|biotin carboxylase|methylcrotonoyl-CoA carboxylase 2 (beta)|methylcrotonoyl-Coenzyme A carboxylase 2 (beta)|non-biotin containing subunit of 3-methylcrotonyl-CoA carboxylase|testicular secretory protein Li 29', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=71587340, end_position_on_the_genomic_accession=71658706, orientation='plus', exon_count=19, OMIM=[609014], no_hdr0=''),
    64089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64089, CurrentID=0, Status='live', Symbol='SNX16', Aliases=[], description='sorting nexin 16', other_designations='sorting nexin-16', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81799583, end_position_on_the_genomic_accession=81842326, orientation='minus', exon_count=10, OMIM=[614903], no_hdr0=''),
    64090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64090, CurrentID=0, Status='live', Symbol='GAL3ST2', Aliases=['GAL3ST-2', 'GP3ST'], description='galactose-3-O-sulfotransferase 2', other_designations="galactose-3-O-sulfotransferase 2|beta-galactose-3-O-sulfotransferase 2|gal 3-O-sulphotransferase|gal-beta-1, 3-GalNAc 3'-sulfotransferase 2|galbeta1-3GalNAc 3'-sulfotransferase 2|glycoprotein beta-Gal 3'-sulfotransferase 2", map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241776822, end_position_on_the_genomic_accession=241804287, orientation='plus', exon_count=4, OMIM=[608237], no_hdr0=''),
    64091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64091, CurrentID=0, Status='live', Symbol='POPDC2', Aliases=['POP2'], description='popeye domain containing 2', other_designations='popeye domain-containing protein 2|popeye protein 2', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119642056, end_position_on_the_genomic_accession=119660589, orientation='minus', exon_count=5, OMIM=[605823], no_hdr0=''),
    64092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64092, CurrentID=0, Status='live', Symbol='SAMSN1', Aliases=['HACS1', 'NASH1', 'SASH2', 'SH3D6B', 'SLy2'], description='SAM domain, SH3 domain and nuclear localization signals 1', other_designations='SAM domain-containing protein SAMSN-1|SAM and SH3 domain containing 2|SAM domain, SH3 domain and nuclear localisation signals, 1|SAM domain, SH3 domain and nuclear localization signals protein 1|SH3-SAM adaptor protein|Src homology domain 3 (SH3)-containing adapter protein SH3 lymphocyte protein 2|hematopoietic adapter-containing SH3 and sterile I+/--motif (SAM) domains 1|hematopoietic adapter-containing SH3 and sterile alpha-motif (SAM) domains 1|hematopoietic adaptor containing SH3 and SAM domains 1|nuclear localization signals, SAM and SH3 domain containing 1', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14485228, end_position_on_the_genomic_accession=14583402, orientation='minus', exon_count=14, OMIM=[607978], no_hdr0=''),
    64093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64093, CurrentID=0, Status='live', Symbol='SMOC1', Aliases=['OAS'], description='SPARC related modular calcium binding 1', other_designations='SPARC-related modular calcium-binding protein 1|secreted modular calcium-binding protein 1', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69879388, end_position_on_the_genomic_accession=70032366, orientation='plus', exon_count=12, OMIM=[608488], no_hdr0=''),
    64094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64094, CurrentID=0, Status='live', Symbol='SMOC2', Aliases=['DTDP1', 'MST117', 'MSTP117', 'MSTP140', 'SMAP2', 'bA270C4A.1', 'bA37D8.1', 'dJ421D16.1'], description='SPARC related modular calcium binding 2', other_designations='SPARC-related modular calcium-binding protein 2|SMAP-2|SMOC-2|secreted modular calcium-binding protein 2|smooth muscle associated protein 2|thyroglobulin type-1 repeat containing protein', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=168441153, end_position_on_the_genomic_accession=168667992, orientation='plus', exon_count=14, OMIM=[607223], no_hdr0=''),
    64096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64096, CurrentID=0, Status='live', Symbol='GFRA4', Aliases=[], description='GDNF family receptor alpha 4', other_designations='GDNF family receptor alpha-4|GDNF receptor alpha-4|GDNFR-alpha-4|GFR receptor alpha 4|GFR-alpha-4|persephin receptor', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3659248, end_position_on_the_genomic_accession=3663399, orientation='minus', exon_count=6, OMIM=[618679], no_hdr0=''),
    64097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64097, CurrentID=0, Status='live', Symbol='EPB41L4A', Aliases=['EPB41L4', 'NBL4'], description='erythrocyte membrane protein band 4.1 like 4A', other_designations='band 4.1-like protein 4A|erythrocyte protein band 4.1-like 4', map_location='5q22.1-q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=112141829, end_position_on_the_genomic_accession=112419277, orientation='minus', exon_count=26, OMIM=[612141], no_hdr0=''),
    64098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64098, CurrentID=0, Status='live', Symbol='PARVG', Aliases=[], description='parvin gamma', other_designations='gamma-parvin', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44170228, end_position_on_the_genomic_accession=44208469, orientation='plus', exon_count=17, OMIM=[608122], no_hdr0=''),
    64100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64100, CurrentID=0, Status='live', Symbol='ELSPBP1', Aliases=['E12', 'EDDM12', 'EL149', 'HE12'], description='epididymal sperm binding protein 1', other_designations='epididymal sperm-binding protein 1|epididymal protein 12|epididymal secretory protein 12|epididymis luminal secretory protein 149|epididymis secretory sperm binding protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47994632, end_position_on_the_genomic_accession=48025154, orientation='plus', exon_count=8, OMIM=[607443], no_hdr0=''),
    64101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64101, CurrentID=0, Status='live', Symbol='LRRC4', Aliases=['NAG14', 'NGL-2'], description='leucine rich repeat containing 4', other_designations='leucine-rich repeat-containing protein 4|brain tumor associated protein LRRC4|brain tumor-associated protein BAG|nasopharyngeal carcinoma-associated gene 14 protein|netrin-G2 ligand', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128027071, end_position_on_the_genomic_accession=128032107, orientation='minus', exon_count=3, OMIM=[610486], no_hdr0=''),
    64102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64102, CurrentID=0, Status='live', Symbol='TNMD', Aliases=['BRICD4', 'CHM1L', 'TEM'], description='tenomodulin', other_designations='tenomodulin|BRICHOS domain containing 4|chondromodulin-1-like protein|chondromodulin-I-like protein|chondromodulin-IB|hChM1L|hTeM|myodulin|tendin', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100584936, end_position_on_the_genomic_accession=100599885, orientation='plus', exon_count=7, OMIM=[300459], no_hdr0=''),
    64105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64105, CurrentID=0, Status='live', Symbol='CENPK', Aliases=['AF5alpha', 'CENP-K', 'FKSG14', 'P33', 'Solt'], description='centromere protein K', other_designations='centromere protein K|SoxLZ/Sox6-binding protein Solt|interphase centromere complex protein 37|leucine zipper protein FKSG14|protein AF-5alpha', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65488919, end_position_on_the_genomic_accession=65563194, orientation='minus', exon_count=19, OMIM=[611502], no_hdr0=''),
    64106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64106, CurrentID=0, Status='live', Symbol='NPFFR1', Aliases=['GPR147', 'NPFF1', 'NPFF1R1', 'OT7T022'], description='neuropeptide FF receptor 1', other_designations='neuropeptide FF receptor 1|G-protein coupled receptor 147|RFamide-related peptide receptor OT7T022|neuropeptide FF 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70247329, end_position_on_the_genomic_accession=70284004, orientation='minus', exon_count=4, OMIM=[607448], no_hdr0=''),
    64108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64108, CurrentID=0, Status='live', Symbol='RTP4', Aliases=['IFRG28', 'Z3CXXC4'], description='receptor transporter protein 4', other_designations='receptor-transporting protein 4|28 kDa interferon-responsive protein|28kD interferon responsive protein|3CxxC-type zinc finger protein 4|receptor (chemosensory) transporter protein 4|zinc finger, 3CxxC-type 4', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187368385, end_position_on_the_genomic_accession=187372076, orientation='plus', exon_count=2, OMIM=[609350], no_hdr0=''),
    64109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64109, CurrentID=0, Status='live', Symbol='CRLF2', Aliases=['CRL2Y', 'TSLPR', 'CRLF2'], description='cytokine receptor like factor 2', other_designations='cytokine receptor-like factor 2|IL-XR|TSLP receptor|cytokine receptor CRL2 precusor|thymic stromal lymphopoietin protein receptor|thymic stromal-derived lymphopoietin receptor', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1190437, end_position_on_the_genomic_accession=1212762, orientation='minus', exon_count=9, OMIM=[300357, 400023], no_hdr0=''),
    64110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64110, CurrentID=0, Status='live', Symbol='MAGEF1', Aliases=['MAGE-F1'], description='MAGE family member F1', other_designations='melanoma-associated antigen F1|MAGE-F1 antigen|melanoma antigen family F, 1|melanoma antigen family F1', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184710364, end_position_on_the_genomic_accession=184712064, orientation='minus', exon_count=1, OMIM=[609267], no_hdr0=''),
    64111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64111, CurrentID=0, Status='live', Symbol='NPVF', Aliases=['C7orf9', 'RFRP'], description='neuropeptide VF precursor', other_designations='pro-FMRFamide-related neuropeptide VF|FMRFamide-related peptide|FMRFamide-related peptides|RFamide-related peptide|neuropeptide NPVF', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=25224570, end_position_on_the_genomic_accession=25228486, orientation='minus', exon_count=3, OMIM=[616984], no_hdr0=''),
    64112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64112, CurrentID=0, Status='live', Symbol='MOAP1', Aliases=['MAP-1', 'PNMA4'], description='modulator of apoptosis 1', other_designations='modulator of apoptosis 1|MAP1|paraneoplastic Ma antigen family member 4|paraneoplastic antigen Ma4|paraneoplastic antigen like 4', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93182199, end_position_on_the_genomic_accession=93184897, orientation='minus', exon_count=3, OMIM=[609485], no_hdr0=''),
    64114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64114, CurrentID=0, Status='live', Symbol='TMBIM1', Aliases=['LFG3', 'MST100', 'MSTP100', 'PP1201', 'RECS1'], description='transmembrane BAX inhibitor motif containing 1', other_designations='protein lifeguard 3|transmembrane BAX inhibitor motif-containing protein 1', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218274192, end_position_on_the_genomic_accession=218292577, orientation='minus', exon_count=17, OMIM=[610364], no_hdr0=''),
    64115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64115, CurrentID=0, Status='live', Symbol='VSIR', Aliases=['B7-H5', 'B7H5', 'C10orf54', 'DD1alpha', 'Dies1', 'GI24', 'PD-1H', 'PP2135', 'SISP1', 'VISTA'], description='V-set immunoregulatory receptor', other_designations='V-type immunoglobulin domain-containing suppressor of T-cell activation|Death Domain1alpha|PDCD1 homolog|V-domain Ig suppressor of T cell activation|V-set domain-containing immunoregulatory receptor|platelet receptor GI24|sisp-1|stress-induced secreted protein-1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71747556, end_position_on_the_genomic_accession=71773520, orientation='minus', exon_count=7, OMIM=[615608], no_hdr0=''),
    64116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64116, CurrentID=0, Status='live', Symbol='SLC39A8', Aliases=['BIGM103', 'CDG2N', 'LZT-Hs6', 'PP3105', 'ZIP8'], description='solute carrier family 39 member 8', other_designations='metal cation symporter ZIP8|BCG induced integral membrane protein BIGM103|BCG-induced integral membrane protein in monocyte clone 103 protein|LIV-1 subfamily of ZIP zinc transporter 6|ZIP-8|Zrt- and Irt-like protein 8|solute carrier family 39 (metal ion transporter), member 8|zinc transporter ZIP8', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102251041, end_position_on_the_genomic_accession=102345482, orientation='minus', exon_count=16, OMIM=[608732], no_hdr0=''),
    64118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64118, CurrentID=0, Status='live', Symbol='DUS1L', Aliases=['DUS1', 'PP3111'], description='dihydrouridine synthase 1 like', other_designations='tRNA-dihydrouridine(16/17) synthase [NAD(P)(+)]-like', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82057506, end_position_on_the_genomic_accession=82065815, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    64121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64121, CurrentID=0, Status='live', Symbol='RRAGC', Aliases=['GTR2', 'RAGC', 'TIB929'], description='Ras related GTP binding C', other_designations='ras-related GTP-binding protein C|GTPase-interacting protein 2|Rag C protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38838198, end_position_on_the_genomic_accession=38859772, orientation='minus', exon_count=7, OMIM=[608267], no_hdr0=''),
    64122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64122, CurrentID=0, Status='live', Symbol='FN3K', Aliases=[], description='fructosamine 3 kinase', other_designations='fructosamine-3-kinase|protein-psicosamine 3-kinase FN3K|protein-ribulosamine 3-kinase FN3K', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82735615, end_position_on_the_genomic_accession=82751196, orientation='plus', exon_count=7, OMIM=[608425], no_hdr0=''),
    64123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64123, CurrentID=0, Status='live', Symbol='ADGRL4', Aliases=['ELTD1', 'ETL', 'KPG_003'], description='adhesion G protein-coupled receptor L4', other_designations='adhesion G protein-coupled receptor L4|EGF, latrophilin and seven transmembrane domain containing 1|EGF, latrophilin and seven transmembrane domain-containing protein 1|EGF-TM7-latrophilin-related protein', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=78889764, end_position_on_the_genomic_accession=79006730, orientation='minus', exon_count=15, OMIM=[616419], no_hdr0=''),
    64127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64127, CurrentID=0, Status='live', Symbol='NOD2', Aliases=['ACUG', 'BLAU', 'BLAUS', 'CARD15', 'CD', 'CLR16.3', 'IBD1', 'NLRC2B', 'PSORAS1', 'YAOS', 'NOD2'], description='nucleotide binding oligomerization domain containing 2', other_designations='nucleotide-binding oligomerization domain-containing protein 2|NLR family, CARD domain containing 2|NOD-like receptor C2|caspase recruitment domain family, member 15|caspase recruitment domain protein 15|caspase recruitment domain-containing protein 15|inflammatory bowel disease protein 1|nucleotide-binding oligomerization domain 2|nucleotide-binding oligomerization domain, leucine rich repeat and CARD domain containing 2', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50693587, end_position_on_the_genomic_accession=50733077, orientation='plus', exon_count=18, OMIM=[605956], no_hdr0=''),
    64129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64129, CurrentID=0, Status='live', Symbol='TINAGL1', Aliases=['ARG1', 'LCN7', 'LIECG3', 'TINAGRP'], description='tubulointerstitial nephritis antigen like 1', other_designations='tubulointerstitial nephritis antigen-like|OLRG-2|P3ECSL|TIN Ag-related protein|TIN-Ag-RP|TINAG-like 1|androgen-regulated gene 1|glucocorticoid-inducible protein 5|lipocalin 7|oxidized-LDL responsive gene 2|tubulointerstitial nephritis antigen-related protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31576384, end_position_on_the_genomic_accession=31587686, orientation='plus', exon_count=13, OMIM=[616064], no_hdr0=''),
    64130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64130, CurrentID=0, Status='live', Symbol='LIN7B', Aliases=['LIN-7B', 'MALS-2', 'MALS2', 'VELI2'], description='lin-7 homolog B, crumbs cell polarity complex component', other_designations='protein lin-7 homolog B|hLin7B|hVeli2|mammalian lin-seven protein 2|veli-2|vertebrate lin-7 homolog 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49114339, end_position_on_the_genomic_accession=49118464, orientation='plus', exon_count=6, OMIM=[612331], no_hdr0=''),
    64131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64131, CurrentID=0, Status='live', Symbol='XYLT1', Aliases=['DBQD2', 'PXYLT1', 'XT-I', 'XT1', 'XTI', 'XYLTI', 'xylT-I'], description='xylosyltransferase 1', other_designations='xylosyltransferase 1|beta-D-xylosyltransferase 1|peptide O-xylosyltransferase 1|xylosyltransferase I|xylosyltransferase iota', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=17101769, end_position_on_the_genomic_accession=17470960, orientation='minus', exon_count=14, OMIM=[608124], no_hdr0=''),
    64132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64132, CurrentID=0, Status='live', Symbol='XYLT2', Aliases=['PXYLT2', 'SOS', 'XT-II', 'XT2', 'xylT-II'], description='xylosyltransferase 2', other_designations='xylosyltransferase 2|UDP-D-xylose:proteoglycan core protein beta-D-xylosyltransferase|peptide O-xylosyltransferase 1|protein xylosyltransferase 2|xylosyltransferase II', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50346126, end_position_on_the_genomic_accession=50361185, orientation='plus', exon_count=12, OMIM=[608125], no_hdr0=''),
    64135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64135, CurrentID=0, Status='live', Symbol='IFIH1', Aliases=['AGS7', 'Hlcd', 'IDDM19', 'MDA-5', 'MDA5', 'RLR-2', 'SGMRT1'], description='interferon induced with helicase C domain 1', other_designations='interferon-induced helicase C domain-containing protein 1|CADM-140 autoantigen|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide|RIG-I-like receptor 2|RNA helicase-DEAD box protein 116|clinically amyopathic dermatomyositis autoantigen 140 kDa|helicard|helicase with 2 CARD domains|melanoma differentiation-associated gene 5|melanoma differentiation-associated protein 5|murabutide down-regulated protein', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=162267074, end_position_on_the_genomic_accession=162318684, orientation='minus', exon_count=16, OMIM=[606951], no_hdr0=''),
    64137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64137, CurrentID=0, Status='live', Symbol='ABCG4', Aliases=['WHITE2'], description='ATP binding cassette subfamily G member 4', other_designations='ATP-binding cassette sub-family G member 4|ATP-binding cassette, sub-family G (WHITE), member 4|putative ABC transporter', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119149052, end_position_on_the_genomic_accession=119162666, orientation='plus', exon_count=17, OMIM=[607784], no_hdr0=''),
    64145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64145, CurrentID=0, Status='live', Symbol='RBSN', Aliases=['Rabenosyn-5', 'ZFYVE20'], description='rabenosyn, RAB effector', other_designations='rabenosyn-5|110 kDa protein|FYVE finger-containing Rab5 effector protein rabenosyn-5|RAB effector RBSN|zinc finger, FYVE domain containing 20', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15070069, end_position_on_the_genomic_accession=15099163, orientation='minus', exon_count=16, OMIM=[609511], no_hdr0=''),
    64146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64146, CurrentID=0, Status='live', Symbol='PDF', Aliases=[], description='peptide deformylase, mitochondrial', other_designations='peptide deformylase, mitochondrial|peptide deformylase-like protein|polypeptide deformylase', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69326913, end_position_on_the_genomic_accession=69330588, orientation='minus', exon_count=2, OMIM=[618720], no_hdr0=''),
    64147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64147, CurrentID=0, Status='live', Symbol='KIF9', Aliases=[], description='kinesin family member 9', other_designations='kinesin-like protein KIF9|kinesin protein 9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=47227998, end_position_on_the_genomic_accession=47282847, orientation='minus', exon_count=24, OMIM=[607910], no_hdr0=''),
    64149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64149, CurrentID=0, Status='live', Symbol='C17orf75', Aliases=['NJMU-R1', 'SRI2'], description='chromosome 17 open reading frame 75', other_designations='protein Njmu-R1|sensitization to ricin complex subunit 2|spermatogenesis-related protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32328441, end_position_on_the_genomic_accession=32350049, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    64151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64151, CurrentID=0, Status='live', Symbol='NCAPG', Aliases=['CAPG', 'CHCG', 'NY-MEL-3', 'YCG1'], description='non-SMC condensin I complex subunit G', other_designations='condensin complex subunit 3|XCAP-G homolog|chromosome condensation protein G|chromosome-associated protein G|condensin subunit CAP-G|melanoma antigen NY-MEL-3', map_location='4p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17810942, end_position_on_the_genomic_accession=17844865, orientation='plus', exon_count=21, OMIM=[606280], no_hdr0=''),
    64167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64167, CurrentID=0, Status='live', Symbol='ERAP2', Aliases=['L-RAP', 'LRAP'], description='endoplasmic reticulum aminopeptidase 2', other_designations='endoplasmic reticulum aminopeptidase 2|leukocyte-derived arginine aminopeptidase', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=96875939, end_position_on_the_genomic_accession=96919716, orientation='plus', exon_count=19, OMIM=[609497], no_hdr0=''),
    64168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64168, CurrentID=0, Status='live', Symbol='NECAB1', Aliases=['EFCBP1', 'STIP-1'], description='N-terminal EF-hand calcium binding protein 1', other_designations='N-terminal EF-hand calcium-binding protein 1|EF-hand calcium-binding protein 1|neuronal calcium binding protein|neuronal calcium-binding protein 1|synaptotagmin interacting protein 1', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90791768, end_position_on_the_genomic_accession=90959393, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    64170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64170, CurrentID=0, Status='live', Symbol='CARD9', Aliases=['CANDF2', 'hCARD9'], description='caspase recruitment domain family member 9', other_designations='caspase recruitment domain-containing protein 9', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136363956, end_position_on_the_genomic_accession=136373669, orientation='minus', exon_count=13, OMIM=[607212], no_hdr0=''),
    64172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64172, CurrentID=0, Status='live', Symbol='OSGEPL1', Aliases=['OSGEPL', 'Qri7'], description='O-sialoglycoprotein endopeptidase like 1', other_designations='probable tRNA N6-adenosine threonylcarbamoyltransferase, mitochondrial|N6-L-threonylcarbamoyladenine synthase|O-sialoglycoprotein endopeptidase-like protein 1|probable O-sialoglycoprotein endopeptidase 2|probable tRNA threonylcarbamoyladenosine biosynthesis protein OSGEPL1|putative sialoglycoprotease type 2|t(6)A synthase|t(6)A37 threonylcarbamoyladenosine biosynthesis protein OSGEPL1|tRNA threonylcarbamoyladenosine biosynthesis protein OSGEPL1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189746660, end_position_on_the_genomic_accession=189763351, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    64174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64174, CurrentID=0, Status='live', Symbol='DPEP2', Aliases=['MBD2'], description='dipeptidase 2', other_designations='dipeptidase 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67987390, end_position_on_the_genomic_accession=68000644, orientation='minus', exon_count=13, OMIM=[609925], no_hdr0=''),
    64175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64175, CurrentID=0, Status='live', Symbol='P3H1', Aliases=['GROS1', 'LEPRE1', 'OI8'], description='prolyl 3-hydroxylase 1', other_designations='prolyl 3-hydroxylase 1|growth suppressor 1|leprecan|leucine proline-enriched proteoglycan (leprecan) 1|leucine- and proline-enriched proteoglycan 1|procollagen-proline 3-dioxygenase', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42746374, end_position_on_the_genomic_accession=42767028, orientation='minus', exon_count=16, OMIM=[610339], no_hdr0=''),
    64180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64180, CurrentID=0, Status='live', Symbol='DPEP3', Aliases=['MBD3'], description='dipeptidase 3', other_designations='dipeptidase 3|membrane-bound dipeptidase 3|metallopeptidase (family M19)|testis secretory sperm-binding protein Li 211a', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67975663, end_position_on_the_genomic_accession=67980499, orientation='minus', exon_count=10, OMIM=[609926], no_hdr0=''),
    64184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64184, CurrentID=0, Status='live', Symbol='EDDM3B', Aliases=['EP3B', 'FAM12B', 'HE3-BETA', 'HE3B', 'RAM2'], description='epididymal protein 3B', other_designations='epididymal secretory protein E3-beta|family with sequence similarity 12, member B (epididymal)|human epididymis-specific 3 beta|human epididymis-specific protein 3-beta|ribonuclease A M2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20768404, end_position_on_the_genomic_accession=20770948, orientation='plus', exon_count=2, OMIM=[611582], no_hdr0=''),
    64207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64207, CurrentID=0, Status='live', Symbol='IRF2BPL', Aliases=['C14orf4', 'EAP1', 'NEDAMSS'], description='interferon regulatory factor 2 binding protein like', other_designations='probable E3 ubiquitin-protein ligase IRF2BPL|enhanced at puberty 1|enhanced at puberty protein 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77024543, end_position_on_the_genomic_accession=77028708, orientation='minus', exon_count=1, OMIM=[611720], no_hdr0=''),
    64208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64208, CurrentID=0, Status='live', Symbol='POPDC3', Aliases=['LGMDR26', 'POP3', 'bA355M14.1'], description='popeye domain containing 3', other_designations='popeye domain-containing protein 3|popeye protein 3', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=105157900, end_position_on_the_genomic_accession=105180014, orientation='minus', exon_count=7, OMIM=[605824], no_hdr0=''),
    64210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64210, CurrentID=0, Status='live', Symbol='MMS19', Aliases=['CIAO4', 'MET18L', 'hMMS19', 'MMS19'], description='MMS19 homolog, cytosolic iron-sulfur assembly component', other_designations='MMS19 nucleotide excision repair protein homolog|MET18 homolog|MMS19 cytosolic iron-sulfur assembly component|MMS19 nucleotide excision repair homolog|MMS19-like (MET18 homolog, S. cerevisiae)|MMS19-like protein|homolog of yeast MMS19', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97458324, end_position_on_the_genomic_accession=97498794, orientation='minus', exon_count=33, OMIM=[614777], no_hdr0=''),
    64211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64211, CurrentID=0, Status='live', Symbol='LHX5', Aliases=[], description='LIM homeobox 5', other_designations='LIM/homeobox protein Lhx5|LIM homeobox protein 5', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113462033, end_position_on_the_genomic_accession=113471871, orientation='minus', exon_count=5, OMIM=[605992], no_hdr0=''),
    64215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64215, CurrentID=0, Status='live', Symbol='DNAJC1', Aliases=['DNAJL1', 'ERdj1', 'HTJ1', 'MTJ1'], description='DnaJ heat shock protein family (Hsp40) member C1', other_designations='dnaJ homolog subfamily C member 1|DnaJ (Hsp40) homolog, subfamily C, member 1|DnaJ-like protein|dnaJ protein homolog MTJ1', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=21756548, end_position_on_the_genomic_accession=22003763, orientation='minus', exon_count=14, OMIM=[611207], no_hdr0=''),
    64216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64216, CurrentID=0, Status='live', Symbol='TFB2M', Aliases=['Hkp1', 'mtTFB2'], description='transcription factor B2, mitochondrial', other_designations="dimethyladenosine transferase 2, mitochondrial|HCV NS5A-transactivated protein 5|S-adenosylmethionine-6-N', N'-adenosyl(rRNA) dimethyltransferase 2|h-mtTFB|h-mtTFB2|hTFB2M|hepatitis C virus NS5A-transactivated protein 5|mitochondrial 12S rRNA dimethylase 2|mitochondrial transcription factor B2", map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=246540561, end_position_on_the_genomic_accession=246566261, orientation='minus', exon_count=8, OMIM=[607055], no_hdr0=''),
    64218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64218, CurrentID=0, Status='live', Symbol='SEMA4A', Aliases=['CORD10', 'RP35', 'SEMAB', 'SEMB'], description='semaphorin 4A', other_designations='semaphorin-4A|sema B|sema domain, immunoglobulin domain (Ig), transmembrane domain (TM) and short cytoplasmic domain, (semaphorin) 4A|semaphorin-B', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156149672, end_position_on_the_genomic_accession=156177746, orientation='plus', exon_count=18, OMIM=[607292], no_hdr0=''),
    64219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64219, CurrentID=0, Status='live', Symbol='PJA1', Aliases=['PRAJA1', 'RNF70'], description='praja ring finger ubiquitin ligase 1', other_designations='E3 ubiquitin-protein ligase Praja-1|RING finger protein 70|RING-type E3 ubiquitin transferase Praja-1|praja 1|praja ring finger 1, E3 ubiquitin protein ligase', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=69160746, end_position_on_the_genomic_accession=69165453, orientation='minus', exon_count=3, OMIM=[300420], no_hdr0=''),
    64220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64220, CurrentID=0, Status='live', Symbol='STRA6', Aliases=['MCOPCB8', 'MCOPS9', 'PP14296'], description='signaling receptor and transporter of retinol STRA6', other_designations='receptor for retinol uptake STRA6|RBP receptor|retinol binding protein 4 receptor|retinol-binding protein receptor STRA6|stimulated by retinoic acid 6 homolog|stimulated by retinoic acid gene 6 homolog|stimulated by retinoic acid gene 6 protein homolog', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74179466, end_position_on_the_genomic_accession=74212267, orientation='minus', exon_count=26, OMIM=[610745], no_hdr0=''),
    64221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64221, CurrentID=0, Status='live', Symbol='ROBO3', Aliases=['HGPPS', 'HGPPS1', 'HGPS', 'RBIG1', 'RIG1'], description='roundabout guidance receptor 3', other_designations='roundabout homolog 3|retinoblastoma inhibiting gene 1|roundabout, axon guidance receptor, homolog 3|roundabout-like protein 3', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124865432, end_position_on_the_genomic_accession=124881471, orientation='plus', exon_count=29, OMIM=[608630], no_hdr0=''),
    64222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64222, CurrentID=0, Status='live', Symbol='TOR3A', Aliases=['ADIR', 'ADIR2'], description='torsin family 3 member A', other_designations='torsin-3A|ATP-dependant interferon response protein 1|ATP-dependant interferon responsive|ATP-dependent interferon-responsive protein|epididymis secretory sperm binding protein', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179082070, end_position_on_the_genomic_accession=179095996, orientation='plus', exon_count=6, OMIM=[607555], no_hdr0=''),
    64223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64223, CurrentID=0, Status='live', Symbol='MLST8', Aliases=['GBL', 'GbetaL', 'LST8', 'POP3', 'WAT1'], description='MTOR associated protein, LST8 homolog', other_designations='target of rapamycin complex subunit LST8|TORC subunit LST8|gable|mammalian lethal with SEC13 protein 8|protein GbetaL', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2204628, end_position_on_the_genomic_accession=2209453, orientation='plus', exon_count=11, OMIM=[612190], no_hdr0=''),
    64224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64224, CurrentID=0, Status='live', Symbol='HERPUD2', Aliases=[], description='HERPUD family member 2', other_designations='homocysteine-responsive endoplasmic reticulum-resident ubiquitin-like domain member 2 protein|homocysteine-inducible, endoplasmic reticulum stress-inducible, ubiquitin-like domain member 2', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=35632659, end_position_on_the_genomic_accession=35695811, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    64225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64225, CurrentID=0, Status='live', Symbol='ATL2', Aliases=['ARL3IP2', 'ARL6IP2', 'aip-2', 'atlastin2'], description='atlastin GTPase 2', other_designations='atlastin-2|ADP-ribosylation factor-like protein 6-interacting protein 2|ARL-6-interacting protein 2', map_location='2p22.2-p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38293954, end_position_on_the_genomic_accession=38378584, orientation='minus', exon_count=16, OMIM=[609368], no_hdr0=''),
    64231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64231, CurrentID=0, Status='live', Symbol='MS4A6A', Aliases=['4SPAN3', '4SPAN3.2', 'CD20L3', 'CDA01', 'MS4A6', 'MST090', 'MSTP090'], description='membrane spanning 4-domains A6A', other_designations='membrane-spanning 4-domains subfamily A member 6A|CD20 antigen-like 3|CD20-like precusor|HAIRB-iso|MS4A6A-polymorph|four-span transmembrane protein 3|four-span transmembrane protein 3.1|four-span transmembrane protein 3.2|membrane-spanning 4-domains, subfamily A, member 6A', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60171607, end_position_on_the_genomic_accession=60184666, orientation='minus', exon_count=12, OMIM=[606548], no_hdr0=''),
    64232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64232, CurrentID=0, Status='live', Symbol='MS4A5', Aliases=['CD20-L2', 'CD20L2', 'TETM4'], description='membrane spanning 4-domains A5', other_designations='membrane-spanning 4-domains subfamily A member 5|CD20 antigen-like 2|testis-expressed transmembrane protein 4|testis-expressed transmembrane-4 protein', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60429572, end_position_on_the_genomic_accession=60447792, orientation='plus', exon_count=5, OMIM=[606499], no_hdr0=''),
    64236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64236, CurrentID=0, Status='live', Symbol='PDLIM2', Aliases=['MYSTIQUE', 'SLIM'], description='PDZ and LIM domain 2', other_designations='PDZ and LIM domain protein 2', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22578741, end_position_on_the_genomic_accession=22598026, orientation='plus', exon_count=11, OMIM=[609722], no_hdr0=''),
    64240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64240, CurrentID=0, Status='live', Symbol='ABCG5', Aliases=['STSL', 'STSL2'], description='ATP binding cassette subfamily G member 5', other_designations='ATP-binding cassette sub-family G member 5|ATP-binding cassette, sub-family G (WHITE), member 5|sterolin 1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43806154, end_position_on_the_genomic_accession=43838840, orientation='minus', exon_count=15, OMIM=[605459], no_hdr0=''),
    64241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64241, CurrentID=0, Status='live', Symbol='ABCG8', Aliases=['GBD4', 'STSL', 'STSL1'], description='ATP binding cassette subfamily G member 8', other_designations='ATP-binding cassette sub-family G member 8|ATP-binding cassette, sub-family G (WHITE), member 8|sterolin 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43831942, end_position_on_the_genomic_accession=43882988, orientation='plus', exon_count=15, OMIM=[605460], no_hdr0=''),
    64282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64282, CurrentID=0, Status='live', Symbol='TENT4B', Aliases=['PAPD5', 'TRF4-2', 'TUT3'], description='terminal nucleotidyltransferase 4B', other_designations='terminal nucleotidyltransferase 4B|PAP associated domain containing 5|PAP-associated domain-containing protein 5|TUTase 3|non-canonical poly(A) RNA polymerase PAPD5|poly(A) RNA polymerase D5, non-canonical|terminal guanylyltransferase|terminal nucleotidyltransferase 4A|terminal uridylyltransferase 3|topoisomerase-related function protein 4-2', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50152911, end_position_on_the_genomic_accession=50235310, orientation='plus', exon_count=13, OMIM=[605540], no_hdr0=''),
    64283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64283, CurrentID=0, Status='live', Symbol='ARHGEF28', Aliases=['RGNEF', 'RIP2', 'p190RHOGEF'], description='Rho guanine nucleotide exchange factor 28', other_designations='rho guanine nucleotide exchange factor 28|190 kDa guanine nucleotide exchange factor|Rho guanine nucleotide exchange factor (GEF) 28|Rho interacting protein 2|rho-guanine nucleotide exchange factor', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73626179, end_position_on_the_genomic_accession=73941993, orientation='plus', exon_count=40, OMIM=[612790], no_hdr0=''),
    64284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64284, CurrentID=0, Status='live', Symbol='RAB17', Aliases=[], description='RAB17, member RAS oncogene family', other_designations='ras-related protein Rab-17', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237574322, end_position_on_the_genomic_accession=237591121, orientation='minus', exon_count=6, OMIM=[602206], no_hdr0=''),
    64285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64285, CurrentID=0, Status='live', Symbol='RHBDF1', Aliases=['C16orf8', 'Dist1', 'EGFR-RS', 'gene-89', 'gene-90', 'hDist1'], description='rhomboid 5 homolog 1', other_designations='inactive rhomboid protein 1|epidermal growth factor receptor, related sequence|epidermal growth factor receptor-related protein|iRhom1|p100hRho|rhomboid family 1|rhomboid family member 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58059, end_position_on_the_genomic_accession=76355, orientation='minus', exon_count=19, OMIM=[614403], no_hdr0=''),
    64288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64288, CurrentID=0, Status='live', Symbol='ZSCAN31', Aliases=['ZNF20-Lp', 'ZNF310P', 'ZNF323'], description='zinc finger and SCAN domain containing 31', other_designations='zinc finger and SCAN domain-containing protein 31|zinc finger protein 323', map_location='6p22.3-p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28324737, end_position_on_the_genomic_accession=28359157, orientation='minus', exon_count=14, OMIM=[610794], no_hdr0=''),
    64318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64318, CurrentID=0, Status='live', Symbol='NOC3L', Aliases=['AD24', 'C10orf117', 'FAD24'], description='NOC3 like DNA replication regulator', other_designations='nucleolar complex protein 3 homolog|NOC3 protein homolog|NOC3L DNA replication regulator|factor for adipocyte differentiation 24|nucleolar complex associated 3 homolog|nucleolar complex-associated protein 3-like protein', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=94314907, end_position_on_the_genomic_accession=94362959, orientation='minus', exon_count=23, OMIM=[610769], no_hdr0=''),
    64319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64319, CurrentID=0, Status='live', Symbol='FBRS', Aliases=['FBS', 'FBS1'], description='fibrosin', other_designations='probable fibrosin-1|fibrogenic lymphokine|fibrosin 1|probable fibrosin-1 long transcript protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30658431, end_position_on_the_genomic_accession=30670810, orientation='plus', exon_count=18, OMIM=[608601], no_hdr0=''),
    64320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64320, CurrentID=0, Status='live', Symbol='RNF25', Aliases=['AO7'], description='ring finger protein 25', other_designations='E3 ubiquitin-protein ligase RNF25|RING-type E3 ubiquitin transferase RNF25|ring finger protein AO7', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218663874, end_position_on_the_genomic_accession=218672002, orientation='minus', exon_count=10, OMIM=[616014], no_hdr0=''),
    64321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64321, CurrentID=0, Status='live', Symbol='SOX17', Aliases=['VUR3'], description='SRY-box transcription factor 17', other_designations='transcription factor SOX-17|SRY (sex determining region Y)-box 17|SRY-box 17|SRY-related HMG-box transcription factor SOX17', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=54457935, end_position_on_the_genomic_accession=54460892, orientation='plus', exon_count=2, OMIM=[610928], no_hdr0=''),
    64324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64324, CurrentID=0, Status='live', Symbol='NSD1', Aliases=['ARA267', 'KMT3B', 'SOTOS', 'SOTOS1', 'STO'], description='nuclear receptor binding SET domain protein 1', other_designations='histone-lysine N-methyltransferase, H3 lysine-36 specific|H3-K36-HMTase|H4-K20-HMTase|NR-binding SET domain-containing protein|androgen receptor coactivator 267 kDa protein|androgen receptor-associated coregulator 267|androgen receptor-associated protein of 267 kDa|histone-lysine N-methyltransferase, H3 lysine-36 and H4 lysine-20 specific|lysine N-methyltransferase 3B|nuclear receptor SET domain-containing protein 1|nuclear receptor-binding SET domain-containing protein 1|truncated nuclear receptor binding SET domain protein 1', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177131835, end_position_on_the_genomic_accession=177300213, orientation='plus', exon_count=31, OMIM=[606681], no_hdr0=''),
    64326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64326, CurrentID=0, Status='live', Symbol='COP1', Aliases=['CFAP78', 'FAP78', 'RFWD2', 'RNF200'], description='COP1 E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase COP1|E3 ubiquitin-protein ligase RFWD2|RING finger protein 200|RING-type E3 ubiquitin transferase RFWD2|constitutive photomorphogenesis protein 1 homolog|constitutive photomorphogenic protein 1|putative ubiquitin ligase COP1|ring finger and WD repeat domain 2, E3 ubiquitin protein ligase', map_location='1q25.1-q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=175944831, end_position_on_the_genomic_accession=176209087, orientation='minus', exon_count=23, OMIM=[608067], no_hdr0=''),
    64327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64327, CurrentID=0, Status='live', Symbol='LMBR1', Aliases=['ACHP', 'C7orf2', 'DIF14', 'LSS', 'PPD2', 'THYP', 'TPT', 'ZRS'], description='limb development membrane protein 1', other_designations='limb region 1 protein homolog|differentiation-related gene 14 protein|limb region 1 homolog', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=156669012, end_position_on_the_genomic_accession=156893183, orientation='minus', exon_count=25, OMIM=[605522], no_hdr0=''),
    64328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64328, CurrentID=0, Status='live', Symbol='XPO4', Aliases=['exp4'], description='exportin 4', other_designations='exportin-4', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20777329, end_position_on_the_genomic_accession=20902774, orientation='minus', exon_count=29, OMIM=[611449], no_hdr0=''),
    64332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64332, CurrentID=0, Status='live', Symbol='NFKBIZ', Aliases=['IKBZ', 'INAP', 'MAIL'], description='NFKB inhibitor zeta', other_designations='NF-kappa-B inhibitor zeta|I-kappa-B-zeta|IL-1 inducible nuclear ankyrin-repeat protein|Ikappa B-zeta variant 3|IkappaB-zeta|ikB-zeta|ikappaBzeta|molecule possessing ankyrin repeats induced by lipopolysaccharide|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor, zeta', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101827990, end_position_on_the_genomic_accession=101861022, orientation='plus', exon_count=14, OMIM=[608004], no_hdr0=''),
    64333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64333, CurrentID=0, Status='live', Symbol='ARHGAP9', Aliases=['10C', 'RGL1'], description='Rho GTPase activating protein 9', other_designations='rho GTPase-activating protein 9|rho-type GTPase-activating protein 9', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57472262, end_position_on_the_genomic_accession=57488824, orientation='minus', exon_count=22, OMIM=[610576], no_hdr0=''),
    64342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64342, CurrentID=0, Status='live', Symbol='HS1BP3', Aliases=['ETM2', 'HS1-BP3'], description='HCLS1 binding protein 3', other_designations='HCLS1-binding protein 3|HS1-binding protein 3|HSP1BP-3', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20552934, end_position_on_the_genomic_accession=20651661, orientation='minus', exon_count=11, OMIM=[609359], no_hdr0=''),
    64343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64343, CurrentID=0, Status='live', Symbol='AZI2', Aliases=['AZ2', 'NAP1', 'TILP'], description='5-azacytidine induced 2', other_designations='5-azacytidine-induced protein 2|5-azacytidine induced gene 2|NAK-associated protein 1|NF-kappa-B-activating kinase-associated protein 1', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=28321047, end_position_on_the_genomic_accession=28349278, orientation='minus', exon_count=11, OMIM=[609916], no_hdr0=''),
    64344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64344, CurrentID=0, Status='live', Symbol='HIF3A', Aliases=['HIF-3A', 'HIF3-alpha-1', 'IPAS', 'MOP7', 'PASD7', 'bHLHe17'], description='hypoxia inducible factor 3 subunit alpha', other_designations='hypoxia-inducible factor 3-alpha|PAS domain-containing protein 7|basic-helix-loop-helix-PAS protein MOP7|class E basic helix-loop-helix protein 17|hypoxia inducible factor 3 alpha subunit|inhibitory PAS domain protein|member of PAS protein 7', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46297042, end_position_on_the_genomic_accession=46343433, orientation='plus', exon_count=18, OMIM=[609976], no_hdr0=''),
    64359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64359, CurrentID=0, Status='live', Symbol='NXN', Aliases=['NRX', 'RRS2', 'TRG-4'], description='nucleoredoxin', other_designations='nucleoredoxin|nucleoredoxin 1', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=799310, end_position_on_the_genomic_accession=979776, orientation='minus', exon_count=11, OMIM=[612895], no_hdr0=''),
    64374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64374, CurrentID=0, Status='live', Symbol='SIL1', Aliases=['BAP', 'MSS', 'ULG5'], description='SIL1 nucleotide exchange factor', other_designations='nucleotide exchange factor SIL1|BiP-associated protein|SIL1 homolog, endoplasmic reticulum chaperone|SIL1-like protein endoplasmic reticulum chaperone', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=138946724, end_position_on_the_genomic_accession=139198368, orientation='minus', exon_count=13, OMIM=[608005], no_hdr0=''),
    64375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64375, CurrentID=0, Status='live', Symbol='IKZF4', Aliases=['EOS', 'ZNFN1A4'], description='IKAROS family zinc finger 4', other_designations='zinc finger protein Eos|ikaros family zinc finger protein 4|zinc finger protein, subfamily 1A, 4 (Eos)|zinc finger transcription factor Eos', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56007504, end_position_on_the_genomic_accession=56038435, orientation='plus', exon_count=14, OMIM=[606239], no_hdr0=''),
    64376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64376, CurrentID=0, Status='live', Symbol='IKZF5', Aliases=['PEGASUS', 'THC7', 'ZNFN1A5'], description='IKAROS family zinc finger 5', other_designations='zinc finger protein Pegasus|zinc finger protein, subfamily 1A, 5 (Pegasus)|zinc finger transcription factor Pegasus', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122990806, end_position_on_the_genomic_accession=123008826, orientation='minus', exon_count=7, OMIM=[606238], no_hdr0=''),
    64377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64377, CurrentID=0, Status='live', Symbol='CHST8', Aliases=['GALNAC4ST1', 'GalNAc4ST', 'PSS3'], description='carbohydrate sulfotransferase 8', other_designations='carbohydrate sulfotransferase 8|GALNAC-4-ST1|GalNAc-4-O-sulfotransferase 1|N-acetylgalactosamine-4-O-sulfotransferase 1|carbohydrate (N-acetylgalactosamine 4-0) sulfotransferase 8|galNAc4ST-1', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33621953, end_position_on_the_genomic_accession=33773509, orientation='plus', exon_count=9, OMIM=[610190], no_hdr0=''),
    64386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64386, CurrentID=0, Status='live', Symbol='MMP25', Aliases=['MMP-25', 'MMP20', 'MMP20A', 'MMPL1', 'MT-MMP 6', 'MT-MMP6', 'MT6-MMP', 'MT6MMP', 'MTMMP6'], description='matrix metallopeptidase 25', other_designations='matrix metalloproteinase-25|leukolysin|matrix metallopeptidase-like 1|matrix metalloproteinase 20|matrix metalloproteinase-like 1|membrane-type 6 matrix metalloproteinase|membrane-type matrix metalloproteinase 6', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3045963, end_position_on_the_genomic_accession=3060729, orientation='plus', exon_count=14, OMIM=[608482], no_hdr0=''),
    64388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64388, CurrentID=0, Status='live', Symbol='GREM2', Aliases=['CKTSF1B2', 'DAND3', 'PRDC', 'STHAG9'], description='gremlin 2, DAN family BMP antagonist', other_designations='gremlin-2|DAN domain family member 3|cysteine knot superfamily 1, BMP antagonist 2|gremlin 2, cysteine knot superfamily, homolog|protein related to DAN and cerberus', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=240489573, end_position_on_the_genomic_accession=240612372, orientation='minus', exon_count=4, OMIM=[608832], no_hdr0=''),
    64393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64393, CurrentID=0, Status='live', Symbol='ZMAT3', Aliases=['PAG608', 'WIG-1', 'WIG1'], description='zinc finger matrin-type 3', other_designations='zinc finger matrin-type protein 3|WIG-1/PAG608 protein|p53 target zinc finger protein|p53-activated gene 608 protein|zinc finger protein WIG1', map_location='3q26.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=179017223, end_position_on_the_genomic_accession=179072513, orientation='minus', exon_count=9, OMIM=[606452], no_hdr0=''),
    64395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64395, CurrentID=0, Status='live', Symbol='GMCL1', Aliases=['BTBD13', 'GCL', 'GCL1', 'SPATA29'], description='germ cell-less 1, spermatogenesis associated', other_designations='germ cell-less protein-like 1|germ cell-less homolog 1|germ cell-less, spermatogenesis associated 1|spermatogenesis associated 29|spermatogenesis-associated protein 29', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69829660, end_position_on_the_genomic_accession=69881389, orientation='plus', exon_count=16, OMIM=[618627], no_hdr0=''),
    64396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64396, CurrentID=0, Status='live', Symbol='GMCL2', Aliases=['GCL', 'GMCL1L', 'GMCL1P1'], description='germ cell-less 2, spermatogenesis associated', other_designations='germ cell-less protein-like 2|germ cell-less protein-like 1-like|germ cell-less related|germ cell-less, spermatogenesis associated 2|putative germ cell-less protein-like 1-like', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178184505, end_position_on_the_genomic_accession=178187371, orientation='minus', exon_count=1, OMIM=[618629], no_hdr0=''),
    64397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64397, CurrentID=0, Status='live', Symbol='ZNF106', Aliases=['SH3BP3', 'ZFP106', 'ZNF474'], description='zinc finger protein 106', other_designations='zinc finger protein 106|SH3-domain binding protein 3|zinc finger protein 474', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42412823, end_position_on_the_genomic_accession=42491141, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    64398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64398, CurrentID=0, Status='live', Symbol='PALS1', Aliases=['MPP5'], description='protein associated with LIN7 1, MAGUK family member', other_designations='protein PALS1|MAGUK p55 subfamily member 5|membrane palmitoylated protein 5|membrane protein, palmitoylated 5 (MAGUK p55 subfamily member 5)|protein associated with Lin-7 1|protein associated with lin seven 1|stardust', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67241395, end_position_on_the_genomic_accession=67336061, orientation='plus', exon_count=18, OMIM=[606958], no_hdr0=''),
    64399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64399, CurrentID=0, Status='live', Symbol='HHIP', Aliases=['HIP'], description='hedgehog interacting protein', other_designations='hedgehog-interacting protein', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=144646154, end_position_on_the_genomic_accession=144745271, orientation='plus', exon_count=14, OMIM=[606178], no_hdr0=''),
    64400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64400, CurrentID=0, Status='live', Symbol='AKTIP', Aliases=['FT1', 'FTS'], description='AKT interacting protein', other_designations='AKT-interacting protein|fused toes homolog', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53491040, end_position_on_the_genomic_accession=53504411, orientation='minus', exon_count=11, OMIM=[608483], no_hdr0=''),
    64403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64403, CurrentID=0, Status='live', Symbol='CDH24', Aliases=['CDH11L'], description='cadherin 24', other_designations='cadherin-24|cadherin 24, type 2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23047067, end_position_on_the_genomic_accession=23057619, orientation='minus', exon_count=14, OMIM=[618599], no_hdr0=''),
    64405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64405, CurrentID=0, Status='live', Symbol='CDH22', Aliases=['C20orf25', 'dJ998H6.1'], description='cadherin 22', other_designations='cadherin-22|PB-cadherin|cadherin 22, type 2|cadherin-like 22|ortholog of rat PB-cadherin|pituitary and brain cadherin', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46173733, end_position_on_the_genomic_accession=46308498, orientation='minus', exon_count=14, OMIM=[609920], no_hdr0=''),
    64407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64407, CurrentID=0, Status='live', Symbol='RGS18', Aliases=['RGS13'], description='regulator of G protein signaling 18', other_designations='regulator of G-protein signaling 18|regulator of G-protein signalling 13|regulator of G-protein signalling 18', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=192158462, end_position_on_the_genomic_accession=192187172, orientation='plus', exon_count=6, OMIM=[607192], no_hdr0=''),
    64409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64409, CurrentID=0, Status='live', Symbol='GALNT17', Aliases=['GALNACT17', 'GALNT16', 'GALNT20', 'GALNTL3', 'GalNAc-T17', 'GalNAc-T19', 'GalNAc-T5L', 'WBSCR17'], description='polypeptide N-acetylgalactosaminyltransferase 17', other_designations='polypeptide N-acetylgalactosaminyltransferase 17|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase-like 3|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase-like protein 3|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 16|Williams-Beuren syndrome chromosome region 17|galNAc-T-like protein 3|polypeptide GalNAc transferase 3|polypeptide GalNAc transferase-like protein 3|polypeptide N-acetylgalactosaminyltransferase WBSCR17|polypeptide N-acetylgalactosaminyltransferase-like 3|pp-GaNTase-like protein 3|pp-GalNAc-transferase 20|ppGalNAc-T17|protein-UDP acetylgalactosaminyltransferase-like protein 3|putative polypeptide N-acetylgalactosaminyltransferase-like protein 3|williams-Beuren syndrome chromosomal region 17 protein', map_location='7q11.22', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=71132144, end_position_on_the_genomic_accession=71713599, orientation='plus', exon_count=14, OMIM=[615137], no_hdr0=''),
    64410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64410, CurrentID=0, Status='live', Symbol='KLHL25', Aliases=['ENC-2', 'ENC2'], description='kelch like family member 25', other_designations='kelch-like protein 25|BTB/POZ KELCH domain protein|ectoderm-neural cortex protein 2|ectodermal-neural cortex 2|kelch-like 25', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=85759326, end_position_on_the_genomic_accession=85794925, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    64411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64411, CurrentID=0, Status='live', Symbol='ARAP3', Aliases=['CENTD3', 'DRAG1'], description='ArfGAP with RhoGAP domain, ankyrin repeat and PH domain 3', other_designations='arf-GAP with Rho-GAP domain, ANK repeat and PH domain-containing protein 3|ARF-GAP, RHO-GAP, ankyrin repeat and plekstrin homology domains-containing protein 3|Arf and Rho GAP adapter protein 3|PtdIns(3,4,5)P3-binding protein|centaurin-delta-3|phosphoinositide binding protein', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141653401, end_position_on_the_genomic_accession=141682230, orientation='minus', exon_count=35, OMIM=[606647], no_hdr0=''),
    64412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64412, CurrentID=0, Status='live', Symbol='GZF1', Aliases=['JLSM', 'ZBTB23', 'ZNF336'], description='GDNF inducible zinc finger protein 1', other_designations='GDNF-inducible zinc finger protein 1|zinc finger and BTB domain-containing protein 23|zinc finger protein 336', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23361585, end_position_on_the_genomic_accession=23375399, orientation='plus', exon_count=11, OMIM=[613842], no_hdr0=''),
    64417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64417, CurrentID=0, Status='live', Symbol='TMEM267', Aliases=['C5orf28'], description='transmembrane protein 267', other_designations='transmembrane protein 267|transmembrane protein C5orf28', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43444252, end_position_on_the_genomic_accession=43484658, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    64418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64418, CurrentID=0, Status='live', Symbol='TMEM168', Aliases=[], description='transmembrane protein 168', other_designations='transmembrane protein 168', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=112762377, end_position_on_the_genomic_accession=112790403, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    64419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64419, CurrentID=0, Status='live', Symbol='MTMR14', Aliases=['C3orf29'], description='myotubularin related protein 14', other_designations='myotubularin-related protein 14|HCV NS5A-transactivated protein 4 splice variant A-binding protein 1|NS5ATP4ABP1|egg-derived tyrosine phosphatase homolog|jumpy', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9649465, end_position_on_the_genomic_accession=9702393, orientation='plus', exon_count=21, OMIM=[611089], no_hdr0=''),
    64420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64420, CurrentID=0, Status='live', Symbol='SUSD1', Aliases=[], description='sushi domain containing 1', other_designations='sushi domain-containing protein 1', map_location='9q31.3-q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112040783, end_position_on_the_genomic_accession=112175515, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    64421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64421, CurrentID=0, Status='live', Symbol='DCLRE1C', Aliases=['A-SCID', 'DCLREC1C', 'RS-SCID', 'SCIDA', 'SNM1C'], description='DNA cross-link repair 1C', other_designations='protein artemis|DNA cross-link repair 1C (PSO2 homolog, S. cerevisiae)|SNM1 homolog C|SNM1-like protein|severe combined immunodeficiency, type a (Athabascan)', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14897359, end_position_on_the_genomic_accession=14954432, orientation='minus', exon_count=20, OMIM=[605988], no_hdr0=''),
    64422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64422, CurrentID=0, Status='live', Symbol='ATG3', Aliases=['APG3', 'APG3-LIKE', 'APG3L', 'PC3-96'], description='autophagy related 3', other_designations='ubiquitin-like-conjugating enzyme ATG3|2610016C12Rik|APG3 autophagy 3-like|ATG3 autophagy related 3 homolog|autophagy-related protein 3|hApg3', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112532510, end_position_on_the_genomic_accession=112561962, orientation='minus', exon_count=12, OMIM=[609606], no_hdr0=''),
    64423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64423, CurrentID=0, Status='live', Symbol='INF2', Aliases=['C14orf151', 'C14orf173', 'CMTDIE', 'FSGS5', 'pp9484'], description='inverted formin 2', other_designations='inverted formin-2|HBEAG-binding protein 2 binding protein C|HBEBP2-binding protein C|inverted formin, FH2 and WH2 domain containing', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104689618, end_position_on_the_genomic_accession=104722535, orientation='plus', exon_count=23, OMIM=[610982], no_hdr0=''),
    64425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64425, CurrentID=0, Status='live', Symbol='POLR1E', Aliases=['A49', 'PAF53', 'PRAF1', 'RPA49'], description='RNA polymerase I subunit E', other_designations='DNA-directed RNA polymerase I subunit RPA49|DNA-directed RNA polymerase I subunit E|RNA polymerase I subunit A49|RNA polymerase I-associated factor 53|polymerase (RNA) I associated factor 1|polymerase (RNA) I polypeptide E, 53kDa|polymerase (RNA) I subunit E', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37485948, end_position_on_the_genomic_accession=37503697, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    64426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64426, CurrentID=0, Status='live', Symbol='SUDS3', Aliases=['SAP45', 'SDS3'], description='SDS3 homolog, SIN3A corepressor complex component', other_designations='sin3 histone deacetylase corepressor complex component SDS3|45 kDa Sin3-associated polypeptide|sin3A-associated protein, 45kDa|suppressor of defective silencing 3 protein homolog', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118373189, end_position_on_the_genomic_accession=118418033, orientation='plus', exon_count=18, OMIM=[608250], no_hdr0=''),
    64427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64427, CurrentID=0, Status='live', Symbol='TTC31', Aliases=[], description='tetratricopeptide repeat domain 31', other_designations='tetratricopeptide repeat protein 31|TPR repeat protein 31', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74483078, end_position_on_the_genomic_accession=74494559, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    64428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64428, CurrentID=0, Status='live', Symbol='CIAO3', Aliases=['HPRN', 'IOP1', 'LET1L', 'NAR1', 'NARFL', 'PRN'], description='cytosolic iron-sulfur assembly component 3', other_designations='cytosolic iron-sulfur assembly component 3|LET1 like/JFP15|cytosolic Fe-S cluster assembly factor NARFL|iron-only hydrogenase-like protein 1|nuclear prelamin A recognition factor like|protein related to Narf', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=729765, end_position_on_the_genomic_accession=740997, orientation='minus', exon_count=12, OMIM=[611118], no_hdr0=''),
    64429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64429, CurrentID=0, Status='live', Symbol='ZDHHC6', Aliases=['DHHC-6', 'DHHC6', 'ZNF376'], description='zinc finger DHHC-type palmitoyltransferase 6', other_designations='palmitoyltransferase ZDHHC6|stearoyltransferase ZDHHC6|transmembrane protein H4|zinc finger DHHC domain-containing protein 6|zinc finger DHHC-type containing 6|zinc finger protein 376', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112424411, end_position_on_the_genomic_accession=112447572, orientation='minus', exon_count=15, OMIM=[618715], no_hdr0=''),
    64430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64430, CurrentID=0, Status='live', Symbol='PCNX4', Aliases=['C14orf135', 'FBP2', 'PCNXL4'], description='pecanex 4', other_designations='pecanex-like protein 4|HCV F protein-binding protein 2|HCV F-interacting protein|hepatitis C virus F protein-binding protein 2|pecanex homolog 4|pecanex homolog protein 4|pecanex-like 4|pecanex-like protein C14orf135', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60091911, end_position_on_the_genomic_accession=60148221, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    64431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64431, CurrentID=0, Status='live', Symbol='ACTR6', Aliases=['ARP6', 'CDA12', 'HSPC281', 'MSTP136', 'hARP6', 'hARPX'], description='actin related protein 6', other_designations='actin-related protein 6|ARP6 actin related protein 6 homolog', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100200815, end_position_on_the_genomic_accession=100224424, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    64432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64432, CurrentID=0, Status='live', Symbol='MRPS25', Aliases=['COXPD50', 'MRP-S25', 'RPMS25'], description='mitochondrial ribosomal protein S25', other_designations='28S ribosomal protein S25, mitochondrial|S25mt|mitochondrial 28S ribosomal protein S25|mitochondrial small ribosomal subunit protein mS25', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15042251, end_position_on_the_genomic_accession=15065315, orientation='minus', exon_count=5, OMIM=[611987], no_hdr0=''),
    64434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64434, CurrentID=0, Status='live', Symbol='NOM1', Aliases=['C7orf3', 'PPP1R113', 'SGD1'], description='nucleolar protein with MIF4G domain 1', other_designations='nucleolar MIF4G domain-containing protein 1|SGD1 homolog|protein phosphatase 1, regulatory subunit 113', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=156949712, end_position_on_the_genomic_accession=156973176, orientation='plus', exon_count=11, OMIM=[611269], no_hdr0=''),
    64446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64446, CurrentID=0, Status='live', Symbol='DNAI2', Aliases=['CILD9', 'DIC2'], description='dynein axonemal intermediate chain 2', other_designations='dynein axonemal intermediate chain 2|dynein intermediate chain 2, axonemal|dynein, axonemal, intermediate polypeptide 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74274229, end_position_on_the_genomic_accession=74314884, orientation='plus', exon_count=17, OMIM=[605483], no_hdr0=''),
    64478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64478, CurrentID=0, Status='live', Symbol='CSMD1', Aliases=['PPP1R24'], description='CUB and Sushi multiple domains 1', other_designations='CUB and sushi domain-containing protein 1|protein phosphatase 1, regulatory subunit 24', map_location='8p23.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=2935353, end_position_on_the_genomic_accession=4995035, orientation='minus', exon_count=73, OMIM=[608397], no_hdr0=''),
    64499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64499, CurrentID=0, Status='live', Symbol='TPSB2', Aliases=['TPS2', 'tryptaseB', 'tryptaseC'], description='tryptase beta 2', other_designations='tryptase beta-2|mast cell tryptase beta II|mast cell tryptase beta III|testicular tissue protein Li 163', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1228336, end_position_on_the_genomic_accession=1230184, orientation='minus', exon_count=6, OMIM=[191081], no_hdr0=''),
    64506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64506, CurrentID=0, Status='live', Symbol='CPEB1', Aliases=['CPE-BP1', 'CPEB', 'CPEB-1', 'h-CPEB', 'hCPEB-1'], description='cytoplasmic polyadenylation element binding protein 1', other_designations='cytoplasmic polyadenylation element-binding protein 1|CPE-binding protein 1', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82543201, end_position_on_the_genomic_accession=82648795, orientation='minus', exon_count=23, OMIM=[607342], no_hdr0=''),
    64518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64518, CurrentID=0, Status='live', Symbol='TEKT3', Aliases=[], description='tektin 3', other_designations='tektin-3|testicular microtubules-related protein', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15303811, end_position_on_the_genomic_accession=15343682, orientation='minus', exon_count=13, OMIM=[612683], no_hdr0=''),
    64577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64577, CurrentID=0, Status='live', Symbol='ALDH8A1', Aliases=['ALDH12', 'DJ352A20.2'], description='aldehyde dehydrogenase 8 family member A1', other_designations='2-aminomuconic semialdehyde dehydrogenase|aldehyde dehydrogenase 12|aldehyde dehydrogenase family protein', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=134917393, end_position_on_the_genomic_accession=134950101, orientation='minus', exon_count=7, OMIM=[606467], no_hdr0=''),
    64579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64579, CurrentID=0, Status='live', Symbol='NDST4', Aliases=['N-HSST', 'N-HSST 4', 'NDST-4', 'NHSST4'], description='N-deacetylase and N-sulfotransferase 4', other_designations='bifunctional heparan sulfate N-deacetylase/N-sulfotransferase 4|N-deacetylase/N-sulfotransferase (heparan glucosaminyl) 4|N-deacetylase/N-sulfotransferase 4|N-heparan sulfate sulfotransferase 4|glucosaminyl N-deacetylase/N-sulfotransferase 4', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=114824122, end_position_on_the_genomic_accession=115114133, orientation='minus', exon_count=14, OMIM=[615039], no_hdr0=''),
    64581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64581, CurrentID=0, Status='live', Symbol='CLEC7A', Aliases=['BGR', 'CANDF4', 'CD369', 'CLECSF12', 'DECTIN1', 'SCARE2'], description='C-type lectin domain containing 7A', other_designations='C-type lectin domain family 7 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 12|C-type lectin superfamily member 12|DC-associated C-type lectin 1|beta-glucan receptor|dectin-1|dendritic cell-associated C-type lectin-1|lectin-like receptor 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10116777, end_position_on_the_genomic_accession=10130264, orientation='minus', exon_count=8, OMIM=[606264], no_hdr0=''),
    64582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64582, CurrentID=0, Status='live', Symbol='GPR135', Aliases=['HUMNPIIY20'], description='G protein-coupled receptor 135', other_designations='G-protein coupled receptor 135|probable G-protein coupled receptor 135', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59452773, end_position_on_the_genomic_accession=59465636, orientation='minus', exon_count=6, OMIM=[607970], no_hdr0=''),
    64591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64591, CurrentID=0, Status='live', Symbol='TSPY2', Aliases=['TSPYQ1'], description='testis specific protein Y-linked 2', other_designations='testis-specific Y-encoded protein 2|testis-specific Y-encoded protein Q1', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=6246223, end_position_on_the_genomic_accession=6249020, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    64598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64598, CurrentID=0, Status='live', Symbol='MOSPD3', Aliases=['CDS3', 'NET30'], description='motile sperm domain containing 3', other_designations='motile sperm domain-containing protein 3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100612162, end_position_on_the_genomic_accession=100615377, orientation='plus', exon_count=8, OMIM=[609125], no_hdr0=''),
    64599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64599, CurrentID=0, Status='live', Symbol='GIGYF1', Aliases=['GYF1', 'PERQ1'], description='GRB10 interacting GYF protein 1', other_designations='GRB10-interacting GYF protein 1|PERQ amino acid-rich with GYF domain-containing protein 1|postmeiotic segregation increased 2-like 12', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100679507, end_position_on_the_genomic_accession=100694250, orientation='minus', exon_count=27, OMIM=[612064], no_hdr0=''),
    64600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64600, CurrentID=0, Status='live', Symbol='PLA2G2F', Aliases=['GIIFsPLA2', 'sPLA2-IIF'], description='phospholipase A2 group IIF', other_designations='group IIF secretory phospholipase A2|GIIF sPLA2|phosphatidylcholine 2-acylhydrolase 2F', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20139323, end_position_on_the_genomic_accession=20150386, orientation='plus', exon_count=5, OMIM=[616793], no_hdr0=''),
    64601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64601, CurrentID=0, Status='live', Symbol='VPS16', Aliases=['DYT30', 'hVPS16'], description='VPS16 core subunit of CORVET and HOPS complexes', other_designations='vacuolar protein sorting-associated protein 16 homolog|VPS16, CORVET/HOPS core subunit|vacuolar protein sorting 16 homolog|vacuolar protein sorting protein 16', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2840745, end_position_on_the_genomic_accession=2866732, orientation='plus', exon_count=24, OMIM=[608550], no_hdr0=''),
    64641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64641, CurrentID=0, Status='live', Symbol='EBF2', Aliases=['COE2', 'EBF-2', 'O/E-3', 'OE-3'], description='EBF transcription factor 2', other_designations='transcription factor COE2|Collier, Olf and EBF 2|Collier, Olf and EBF transcription factor 2|OLF-1/EBF-LIKE 3|early B cell factor 2|metencephalon-mesencephalnon-olfactory transcription factor 1', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=25841725, end_position_on_the_genomic_accession=26045413, orientation='minus', exon_count=16, OMIM=[609934], no_hdr0=''),
    64645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64645, CurrentID=0, Status='live', Symbol='MFSD14A', Aliases=['HIAT1'], description='major facilitator superfamily domain containing 14A', other_designations='hippocampus abundant transcript 1 protein|hippocampus abundant gene transcript 1|putative tetracycline transporter-like protein|tetracycline transporter-like protein', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100038078, end_position_on_the_genomic_accession=100083377, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    64648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64648, CurrentID=0, Status='live', Symbol='SPANXD', Aliases=['CT11.3', 'CT11.4', 'SPANX-C', 'SPANX-D', 'SPANX-E', 'SPANXC', 'SPANXE', 'dJ171K16.1'], description='SPANX family member D', other_designations='sperm protein associated with the nucleus on the X chromosome D|Cancer/testis antigen 11.3|Cancer/testis-associated protein CTp11|Nuclear-associated protein SPAN-Xc|SPANX family, member E|Sperm protein associated with the nucleus on the X chromosome C|cancer/testis antigen 11.4|cancer/testis antigen family 11, member 4|nuclear-associated protein SPAN-Xd|nuclear-associated protein SPAN-Xe|sperm protein associated with the nucleus, X chromosome, family member D|sperm protein associated with the nucleus, X chromosome, family member E', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141697411, end_position_on_the_genomic_accession=141698739, orientation='minus', exon_count=2, OMIM=[300670, 300671], no_hdr0=''),
    64651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64651, CurrentID=0, Status='live', Symbol='CSRNP1', Aliases=['AXUD1', 'CSRNP-1', 'FAM130B', 'TAIP-3', 'URAX1'], description='cysteine and serine rich nuclear protein 1', other_designations='cysteine/serine-rich nuclear protein 1|AXIN1 up-regulated 1|TGF-beta-induced apoptosis protein 3|axin-1 up-regulated gene 1 protein', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39141855, end_position_on_the_genomic_accession=39154641, orientation='minus', exon_count=8, OMIM=[606458], no_hdr0=''),
    64663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64663, CurrentID=0, Status='live', Symbol='SPANXC', Aliases=['CT11.3', 'CTp11', 'SPANX-C', 'SPANX-E', 'SPANXE'], description='SPANX family member C', other_designations='sperm protein associated with the nucleus on the X chromosome C|Nuclear-associated protein SPAN-Xe|SPAN-Xc protein|Sperm protein associated with the nucleus on the X chromosome E|cancer-testis-associated protein CTp11|cancer/testis antigen 11.3|cancer/testis antigen family 11, member 3|cancer/testis-associated protein of 11 kD|nuclear-associated protein SPAN-Xc|sperm protein associated with the nucleus, X chromosome, family member C', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141241463, end_position_on_the_genomic_accession=141242517, orientation='minus', exon_count=2, OMIM=[300330], no_hdr0=''),
    64682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64682, CurrentID=0, Status='live', Symbol='ANAPC1', Aliases=['APC1', 'MCPR', 'TSG24'], description='anaphase promoting complex subunit 1', other_designations='anaphase-promoting complex subunit 1|anaphase-promoting complex 1 (meiotic checkpoint regulator)|cyclosome subunit 1|mitotic checkpoint regulator|testis-specific gene 24 protein', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=111766150, end_position_on_the_genomic_accession=111884196, orientation='minus', exon_count=50, OMIM=[608473], no_hdr0=''),
    64689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64689, CurrentID=0, Status='live', Symbol='GORASP1', Aliases=['GOLPH5', 'GRASP65', 'P65'], description='golgi reassembly stacking protein 1', other_designations='Golgi reassembly-stacking protein 1|Golgi peripheral membrane protein p65|Golgi phosphoprotein 5|Golgi reassembly and stacking protein 1|golgi reassembly stacking protein 1, 65kDa|golgi reassembly-stacking protein of 65 kDa', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39096599, end_position_on_the_genomic_accession=39107843, orientation='minus', exon_count=11, OMIM=[606867], no_hdr0=''),
    64693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64693, CurrentID=0, Status='live', Symbol='CTAGE1', Aliases=['CT21.1', 'CT21.2', 'CTAGE', 'CTAGE-1', 'CTAGE-2'], description='cutaneous T cell lymphoma-associated antigen 1', other_designations='cTAGE family member 2|cancer/testis antigen 21.2|cancer/testis antigen family 21, member 1|cancer/testis antigen family 21, member 2|cutaneous T-cell lymphoma-associated antigen 2|protein cTAGE-2', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=22413599, end_position_on_the_genomic_accession=22417915, orientation='minus', exon_count=1, OMIM=[608856], no_hdr0=''),
    64699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64699, CurrentID=0, Status='live', Symbol='TMPRSS3', Aliases=['DFNB10', 'DFNB8', 'ECHOS1', 'TADG12'], description='transmembrane serine protease 3', other_designations='transmembrane protease serine 3|serine protease TADG-12|transmembrane protease, serine 3|tumor-associated differentially-expressed gene 12 protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42371890, end_position_on_the_genomic_accession=42396052, orientation='minus', exon_count=13, OMIM=[605511], no_hdr0=''),
    64708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64708, CurrentID=0, Status='live', Symbol='COPS7B', Aliases=['CSN7B', 'SGN7b'], description='COP9 signalosome subunit 7B', other_designations='COP9 signalosome complex subunit 7b|COP9 constitutive photomorphogenic homolog subunit 7B|JAB1-containing signalosome subunit 7b|signalosome subunit 7b', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231781671, end_position_on_the_genomic_accession=231809253, orientation='plus', exon_count=11, OMIM=[616010], no_hdr0=''),
    64710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64710, CurrentID=0, Status='live', Symbol='NUCKS1', Aliases=['JC7', 'NUCKS'], description='nuclear casein kinase and cyclin dependent kinase substrate 1', other_designations='nuclear ubiquitous casein and cyclin-dependent kinase substrate 1|P1|nuclear ubiquitous casein kinase and cyclin-dependent kinase substrate|potential LAG1 interactor', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205712822, end_position_on_the_genomic_accession=205750220, orientation='minus', exon_count=7, OMIM=[611912], no_hdr0=''),
    64711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64711, CurrentID=0, Status='live', Symbol='HS3ST6', Aliases=['3-OST-6', '3OST6', 'HAE8', 'HS3ST5'], description='heparan sulfate-glucosamine 3-sulfotransferase 6', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 6|heparan sulfate (glucosamine) 3-O-sulfotransferase 5|heparan sulfate (glucosamine) 3-O-sulfotransferase 6|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 6|heparan sulphate D-glucosaminyl 3-O-sulfotransferase-3B like', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1911475, end_position_on_the_genomic_accession=1921428, orientation='minus', exon_count=4, OMIM=[619210], no_hdr0=''),
    64714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64714, CurrentID=0, Status='live', Symbol='PDIA2', Aliases=['PDA2', 'PDI', 'PDIP', 'PDIR'], description='protein disulfide isomerase family A member 2', other_designations='protein disulfide-isomerase A2|Rho GDP dissociation inhibitor gamma|pancreas-specific protein disulfide isomerase|pancreatic protein disulfide isomerase|protein disulfide isomerase, pancreatic|protein disulfide isomerase-associated 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=283164, end_position_on_the_genomic_accession=287215, orientation='plus', exon_count=11, OMIM=[608012], no_hdr0=''),
    64718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64718, CurrentID=0, Status='live', Symbol='UNKL', Aliases=['C16orf28', 'ZC3H5L', 'ZC3HDC5L'], description='unk like zinc finger', other_designations='putative E3 ubiquitin-protein ligase UNKL|RING finger protein unkempt-like|unkempt family zinc finger-like|unkempt homolog-like|zinc finger CCCH domain-containing protein 5-like', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1363205, end_position_on_the_genomic_accession=1414749, orientation='minus', exon_count=21, OMIM=[617463], no_hdr0=''),
    64743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64743, CurrentID=0, Status='live', Symbol='WDR13', Aliases=['MG21'], description='WD repeat domain 13', other_designations='WD repeat-containing protein 13', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48590053, end_position_on_the_genomic_accession=48608869, orientation='plus', exon_count=10, OMIM=[300512], no_hdr0=''),
    64744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64744, CurrentID=0, Status='live', Symbol='SMAP2', Aliases=['SMAP1L'], description='small ArfGAP2', other_designations='stromal membrane-associated protein 2|stromal membrane-associated GTPase-activating protein 2', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40373672, end_position_on_the_genomic_accession=40423326, orientation='plus', exon_count=15, OMIM=[616916], no_hdr0=''),
    64745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64745, CurrentID=0, Status='live', Symbol='METTL17', Aliases=['METT11D1'], description='methyltransferase like 17', other_designations='methyltransferase-like protein 17, mitochondrial|false p73 target gene protein|methyltransferase 11 domain containing 1|methyltransferase 11 domain-containing protein 1|protein RSM22 homolog, mitochondrial', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20989980, end_position_on_the_genomic_accession=20997035, orientation='plus', exon_count=14, OMIM=[616091], no_hdr0=''),
    64746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64746, CurrentID=0, Status='live', Symbol='ACBD3', Aliases=['GCP60', 'GOCAP1', 'GOLPH1', 'PAP7'], description='acyl-CoA binding domain containing 3', other_designations='Golgi resident protein GCP60|PBR- and PKA-associated protein 7|PKA (RIalpha)-associated protein|acyl-Coenzyme A binding domain containing 3|golgi complex associated protein 1, 60kDa|golgi phosphoprotein 1|peripheral benzodiazepine receptor-associated protein PAP7', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226144679, end_position_on_the_genomic_accession=226186741, orientation='minus', exon_count=8, OMIM=[606809], no_hdr0=''),
    64747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64747, CurrentID=0, Status='live', Symbol='MFSD1', Aliases=['Minerva', 'SMAP4'], description='major facilitator superfamily domain containing 1', other_designations='major facilitator superfamily domain-containing protein 1|smooth muscle cell-associated protein 4', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158801264, end_position_on_the_genomic_accession=158829717, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    64748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64748, CurrentID=0, Status='live', Symbol='PLPPR2', Aliases=['LPPR2', 'PRG4'], description='phospholipid phosphatase related 2', other_designations='phospholipid phosphatase-related protein type 2|lipid phosphate phosphatase-related protein type 2|plasticity related gene 4|plasticity-related gene 4 protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11355431, end_position_on_the_genomic_accession=11365698, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    64750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64750, CurrentID=0, Status='live', Symbol='SMURF2', Aliases=[], description='SMAD specific E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase SMURF2|E3 ubiquitin ligase SMURF2|HECT-type E3 ubiquitin transferase SMURF2|SMAD ubiquitination regulatory factor 2|hSMURF2', map_location='17q23.3-q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64542282, end_position_on_the_genomic_accession=64662307, orientation='minus', exon_count=19, OMIM=[605532], no_hdr0=''),
    64753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64753, CurrentID=0, Status='live', Symbol='CCDC136', Aliases=['NAG6'], description='coiled-coil domain containing 136', other_designations='coiled-coil domain-containing protein 136|nasopharyngeal carcinoma-associated gene 6 protein', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128790762, end_position_on_the_genomic_accession=128822130, orientation='plus', exon_count=24, OMIM=[611902], no_hdr0=''),
    64754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64754, CurrentID=0, Status='live', Symbol='SMYD3', Aliases=['KMT3E', 'ZMYND1', 'ZNFN3A1', 'bA74P14.1'], description='SET and MYND domain containing 3', other_designations='histone-lysine N-methyltransferase SMYD3|SET and MYND domain-containing protein 3|zinc finger MYND domain-containing protein 1|zinc finger protein, subfamily 3A (MYND domain containing), 1|zinc finger, MYND domain containing 1', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=245749342, end_position_on_the_genomic_accession=246507279, orientation='minus', exon_count=30, OMIM=[608783], no_hdr0=''),
    64755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64755, CurrentID=0, Status='live', Symbol='RUSF1', Aliases=['C16orf58', 'RUS'], description='RUS family member 1', other_designations='RUS family member 1|RUS1 family protein C16orf58|RUS1 homolog|UPF0420 protein C16orf58|root UVB sensitivity', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31489475, end_position_on_the_genomic_accession=31508391, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    64756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64756, CurrentID=0, Status='live', Symbol='ATPAF1', Aliases=['ATP11', 'ATP11p'], description='ATP synthase mitochondrial F1 complex assembly factor 1', other_designations='ATP synthase mitochondrial F1 complex assembly factor 1|homolog of yeast ATP11', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46632737, end_position_on_the_genomic_accession=46668557, orientation='minus', exon_count=11, OMIM=[608917], no_hdr0=''),
    64757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64757, CurrentID=0, Status='live', Symbol='MTARC1', Aliases=['MARC1', 'MOSC1'], description='mitochondrial amidoxime reducing component 1', other_designations='mitochondrial amidoxime-reducing component 1|MOCO sulphurase C-terminal domain containing 1|MOSC domain-containing protein 1, mitochondrial|moco sulfurase C-terminal domain-containing protein 1|molybdenum cofactor sulfurase C-terminal domain-containing protein 1', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220786697, end_position_on_the_genomic_accession=220819659, orientation='plus', exon_count=11, OMIM=[614126], no_hdr0=''),
    64759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64759, CurrentID=0, Status='live', Symbol='TNS3', Aliases=['TEM6', 'TENS1'], description='tensin 3', other_designations='tensin-3|tensin-like SH2 domain containing 1|tensin-like SH2 domain-containing protein 1|thyroid specific PTB domain protein|tumor endothelial marker 6', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=47275154, end_position_on_the_genomic_accession=47582553, orientation='minus', exon_count=41, OMIM=[606825], no_hdr0=''),
    64760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64760, CurrentID=0, Status='live', Symbol='FHIP2B', Aliases=['FAM160B2', 'RAI16'], description='FHF complex subunit HOOK interacting protein 2B', other_designations='FHF complex subunit HOOK interacting protein 2B|protein FAM160B2|family with sequence similarity 160 member B2|retinoic acid induced 16|retinoic acid-induced protein 16', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22089150, end_position_on_the_genomic_accession=22104911, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    64761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64761, CurrentID=0, Status='live', Symbol='PARP12', Aliases=['ARTD12', 'MST109', 'MSTP109', 'ZC3H1', 'ZC3HDC1'], description='poly(ADP-ribose) polymerase family member 12', other_designations='protein mono-ADP-ribosyltransferase PARP12|ADP-ribosyltransferase diphtheria toxin-like 12|poly [ADP-ribose] polymerase 12|zinc finger CCCH type domain containing 1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140023744, end_position_on_the_genomic_accession=140063718, orientation='minus', exon_count=14, OMIM=[612481], no_hdr0=''),
    64762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64762, CurrentID=0, Status='live', Symbol='GAREM1', Aliases=['C18orf11', 'FAM59A', 'GAREM', 'Gm944'], description='GRB2 associated regulator of MAPK1 subtype 1', other_designations='GRB2-associated and regulator of MAPK protein 1|GRB2 associated regulator of MAPK1 1|GRB2 associated, regulator of MAPK1|GRB2-associated and regulator of MAPK1|Grb2-associated and regulator of Erk/MAPK|family with sequence similarity 59, member A|protein FAM59A', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32263521, end_position_on_the_genomic_accession=32470882, orientation='minus', exon_count=9, OMIM=[617998], no_hdr0=''),
    64763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64763, CurrentID=0, Status='live', Symbol='ZNF574', Aliases=['FP972'], description='zinc finger protein 574', other_designations='zinc finger protein 574', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42068477, end_position_on_the_genomic_accession=42081561, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    64764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64764, CurrentID=0, Status='live', Symbol='CREB3L2', Aliases=['BBF2H7'], description='cAMP responsive element binding protein 3 like 2', other_designations='cyclic AMP-responsive element-binding protein 3-like protein 2|B-ZIB transcription factor|BBF2 human homolog on chromosome 7|FUS/BBF2H7 protein|TCAG_1951439|basic transcription factor 2|cAMP-responsive element-binding protein 3-like protein 2', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=137874979, end_position_on_the_genomic_accession=138002086, orientation='minus', exon_count=14, OMIM=[608834], no_hdr0=''),
    64766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64766, CurrentID=0, Status='live', Symbol='S100PBP', Aliases=['S100PBPR'], description='S100P binding protein', other_designations='S100P-binding protein|S100P binding protein 1', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32816767, end_position_on_the_genomic_accession=32858879, orientation='plus', exon_count=16, OMIM=[611889], no_hdr0=''),
    64768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64768, CurrentID=0, Status='live', Symbol='IPPK', Aliases=['C9orf12', 'INSP5K2', 'IP5K', 'IPK1', 'bA476B13.1'], description='inositol-pentakisphosphate 2-kinase', other_designations='inositol-pentakisphosphate 2-kinase|IPK1 homolog|inositol 1,3,4,5,6-pentakisphosphate 2-kinase|ins(1,3,4,5,6)P5 2-kinase|insP5 2-kinase', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92613183, end_position_on_the_genomic_accession=92670259, orientation='minus', exon_count=14, OMIM=[619043], no_hdr0=''),
    64769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64769, CurrentID=0, Status='live', Symbol='MEAF6', Aliases=['C1orf149', 'CENP-28', 'EAF6', 'NY-SAR-91'], description='MYST/Esa1 associated factor 6', other_designations='chromatin modification-related protein MEAF6|Esa1p-associated factor 6 homolog|centromere protein 28|protein EAF6 homolog|sarcoma antigen NY-SAR-91', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37489993, end_position_on_the_genomic_accession=37514766, orientation='minus', exon_count=10, OMIM=[611001], no_hdr0=''),
    64770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64770, CurrentID=0, Status='live', Symbol='CCDC14', Aliases=[], description='coiled-coil domain containing 14', other_designations='coiled-coil domain-containing protein 14', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123887383, end_position_on_the_genomic_accession=123961412, orientation='minus', exon_count=16, OMIM=[617147], no_hdr0=''),
    64771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64771, CurrentID=0, Status='live', Symbol='ILRUN', Aliases=['C6orf106', 'FP852', 'dJ391O22.4'], description='inflammation and lipid regulator with UBA-like and NBR1-like domains', other_designations='protein ILRUN|inflammation and lipid regulator with UBA-like and NBR1-like domains protein|uncharacterized protein C6orf106', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34587288, end_position_on_the_genomic_accession=34696767, orientation='minus', exon_count=7, OMIM=[612217], no_hdr0=''),
    64772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64772, CurrentID=0, Status='live', Symbol='ENGASE', Aliases=[], description='endo-beta-N-acetylglucosaminidase', other_designations='cytosolic endo-beta-N-acetylglucosaminidase|Di-N-acetylchitobiosyl beta-N-acetylglucosaminidase|Mannosyl-glycoprotein endo-beta-N-acetylglucosaminidase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79074812, end_position_on_the_genomic_accession=79088599, orientation='plus', exon_count=14, OMIM=[611898], no_hdr0=''),
    64773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64773, CurrentID=0, Status='live', Symbol='PCED1A', Aliases=['C20orf81', 'FAM113A', 'bA12M19.1'], description='PC-esterase domain containing 1A', other_designations='PC-esterase domain-containing protein 1A|family with sequence similarity 113, member A|sarcoma antigen NY-SAR-23', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2835314, end_position_on_the_genomic_accession=2841243, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    64776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64776, CurrentID=0, Status='live', Symbol='C11orf1', Aliases=[], description='chromosome 11 open reading frame 1', other_designations='UPF0686 protein C11orf1', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111879478, end_position_on_the_genomic_accession=111885975, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    64777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64777, CurrentID=0, Status='live', Symbol='RMND5B', Aliases=['GID2', 'GID2B'], description='required for meiotic nuclear division 5 homolog B', other_designations='E3 ubiquitin-protein transferase RMND5B|GID complex subunit 2 homolog B|protein RMD5 homolog B', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178130532, end_position_on_the_genomic_accession=178150568, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    64778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64778, CurrentID=0, Status='live', Symbol='FNDC3B', Aliases=['FAD104', 'PRO4979', 'YVTM2421'], description='fibronectin type III domain containing 3B', other_designations='fibronectin type III domain-containing protein 3B|HCV NS5A-binding protein 37|factor for adipocyte differentiation 104', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172039578, end_position_on_the_genomic_accession=172401669, orientation='plus', exon_count=30, OMIM=[611909], no_hdr0=''),
    64779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64779, CurrentID=0, Status='live', Symbol='MTHFSD', Aliases=[], description='methenyltetrahydrofolate synthetase domain containing', other_designations='methenyltetrahydrofolate synthase domain-containing protein|methenyltetrahydrofolate synthetase domain-containing protein', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=86530178, end_position_on_the_genomic_accession=86555840, orientation='minus', exon_count=13, OMIM=[616820], no_hdr0=''),
    64780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64780, CurrentID=0, Status='live', Symbol='MICAL1', Aliases=['MICAL', 'MICAL-1', 'NICAL'], description='microtubule associated monooxygenase, calponin and LIM domain containing 1', other_designations='[F-actin]-monooxygenase MICAL1|NEDD9-interacting protein with calponin homology and LIM domains|[F-actin]-methionine sulfoxide oxidase MICAL1|molecule interacting with CasL protein 1|protein-methionine sulfoxide oxidase MICAL1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109444062, end_position_on_the_genomic_accession=109465968, orientation='minus', exon_count=26, OMIM=[607129], no_hdr0=''),
    64781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64781, CurrentID=0, Status='live', Symbol='CERK', Aliases=['LK4', 'dA59H18.2', 'dA59H18.3', 'hCERK'], description='ceramide kinase', other_designations='ceramide kinase|acylsphingosine kinase|lipid kinase 4|lipid kinase LK4', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46684410, end_position_on_the_genomic_accession=46738252, orientation='minus', exon_count=14, OMIM=[610307], no_hdr0=''),
    64782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64782, CurrentID=0, Status='live', Symbol='AEN', Aliases=['ISG20L1', 'pp12744'], description='apoptosis enhancing nuclease', other_designations='apoptosis-enhancing nuclease|interferon stimulated exonuclease gene 20kDa-like 1|interferon-stimulated 20 kDa exonuclease-like 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88604601, end_position_on_the_genomic_accession=88632281, orientation='plus', exon_count=8, OMIM=[610177], no_hdr0=''),
    64783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64783, CurrentID=0, Status='live', Symbol='RBM15', Aliases=['OTT', 'OTT1', 'SPEN'], description='RNA binding motif protein 15', other_designations='RNA-binding protein 15|one twenty two protein|one twenty-two|one-twenty two protein 1|putative RNA-binding protein 15', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110339377, end_position_on_the_genomic_accession=110346677, orientation='plus', exon_count=3, OMIM=[606077], no_hdr0=''),
    64784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64784, CurrentID=0, Status='live', Symbol='CRTC3', Aliases=['TORC-3', 'TORC3'], description='CREB regulated transcription coactivator 3', other_designations='CREB-regulated transcription coactivator 3|transducer of regulated CREB protein 3|transducer of regulated cAMP response element-binding protein (CREB) 3', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90529915, end_position_on_the_genomic_accession=90645345, orientation='plus', exon_count=17, OMIM=[608986], no_hdr0=''),
    64785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64785, CurrentID=0, Status='live', Symbol='GINS3', Aliases=['PSF3'], description='GINS complex subunit 3', other_designations='DNA replication complex GINS protein PSF3|GINS complex subunit 3 (Psf3 homolog)', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58392471, end_position_on_the_genomic_accession=58406147, orientation='plus', exon_count=4, OMIM=[610610], no_hdr0=''),
    64786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64786, CurrentID=0, Status='live', Symbol='TBC1D15', Aliases=['RAB7-GAP'], description='TBC1 domain family member 15', other_designations='TBC1 domain family member 15|GAP for RAB7|GTPase-activating protein RAB7|Tre-2-budding uninhibited by benzimidazole-cell division cycle 16 domain, domain family member 15|Tre2/Bub2/Cdc16 domain family member 15', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71839759, end_position_on_the_genomic_accession=71924313, orientation='plus', exon_count=30, OMIM=[612662], no_hdr0=''),
    64787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64787, CurrentID=0, Status='live', Symbol='EPS8L2', Aliases=['DFNB106', 'EPS8R2'], description='EPS8 like 2', other_designations='epidermal growth factor receptor kinase substrate 8-like protein 2|EPS8-related protein 2|epidermal growth factor receptor pathway substrate 8-related protein 2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=706202, end_position_on_the_genomic_accession=727727, orientation='plus', exon_count=22, OMIM=[614988], no_hdr0=''),
    64788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64788, CurrentID=0, Status='live', Symbol='LMF1', Aliases=['C16orf26', 'HMFN1876', 'JFP11', 'TMEM112', 'TMEM112A'], description='lipase maturation factor 1', other_designations='lipase maturation factor 1|transmembrane protein 112', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=853634, end_position_on_the_genomic_accession=981613, orientation='minus', exon_count=15, OMIM=[611761], no_hdr0=''),
    64789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64789, CurrentID=0, Status='live', Symbol='EXO5', Aliases=['C1orf176', 'DEM1', 'Exo V', 'hExo5'], description='exonuclease 5', other_designations='exonuclease V|defects in morphology 1 homolog|defects in morphology protein 1 homolog|probable exonuclease V', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40508741, end_position_on_the_genomic_accession=40516050, orientation='plus', exon_count=4, OMIM=[618601], no_hdr0=''),
    64792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64792, CurrentID=0, Status='live', Symbol='IFT22', Aliases=['FAP9', 'RABL5'], description='intraflagellar transport 22', other_designations='intraflagellar transport protein 22 homolog|RAB, member RAS oncogene family-like 5|RAB, member of RAS oncogene family-like 5|intraflagellar transport 22 homolog|rab-like protein 5', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101310914, end_position_on_the_genomic_accession=101321823, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    64793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64793, CurrentID=0, Status='live', Symbol='CEP85', Aliases=['CCDC21'], description='centrosomal protein 85', other_designations='centrosomal protein of 85 kDa|centrosomal protein 85kDa|coiled-coil domain-containing protein 21', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26234179, end_position_on_the_genomic_accession=26278808, orientation='plus', exon_count=18, OMIM=[618898], no_hdr0=''),
    64794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64794, CurrentID=0, Status='live', Symbol='DDX31', Aliases=['PPP1R25'], description='DEAD-box helicase 31', other_designations='probable ATP-dependent RNA helicase DDX31|DEAD (Asp-Glu-Ala-Asp) box polypeptide 31|DEAD box protein 31|DEAD/DEXH helicase DDX31|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 31|G2 helicase|helicain|protein phosphatase 1, regulatory subunit 25', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132592997, end_position_on_the_genomic_accession=132670401, orientation='minus', exon_count=26, OMIM=[616533], no_hdr0=''),
    64795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64795, CurrentID=0, Status='live', Symbol='RMND5A', Aliases=['CTLH', 'GID2', 'GID2A', 'RMD5', 'p44CTLH'], description='required for meiotic nuclear division 5 homolog A', other_designations='E3 ubiquitin-protein transferase RMND5A|44-kD protein coding for CTLH motif|C-terminal to LisH motif, 44 kDa|GID complex subunit 2 homolog A|protein RMD5 homolog A', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86720291, end_position_on_the_genomic_accession=86778041, orientation='plus', exon_count=9, OMIM=[618964], no_hdr0=''),
    64798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64798, CurrentID=0, Status='live', Symbol='DEPTOR', Aliases=['DEP.6', 'DEPDC6'], description='DEP domain containing MTOR interacting protein', other_designations='DEP domain-containing mTOR-interacting protein|DEP domain containing 6|DEP domain-containing protein 6', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119873722, end_position_on_the_genomic_accession=120050918, orientation='plus', exon_count=9, OMIM=[612974], no_hdr0=''),
    64799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64799, CurrentID=0, Status='live', Symbol='IQCH', Aliases=['NYDSP5'], description='IQ motif containing H', other_designations='IQ domain-containing protein H|testis development protein NYD-SP5', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67254786, end_position_on_the_genomic_accession=67501804, orientation='plus', exon_count=25, OMIM=[612523], no_hdr0=''),
    64800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64800, CurrentID=0, Status='live', Symbol='EFCAB6', Aliases=['DJBP', 'HSCBCIP1', 'dJ185D5.1'], description='EF-hand calcium binding domain 6', other_designations='EF-hand calcium-binding domain-containing protein 6|CAP-binding protein complex-interacting protein 1|DJ-1-binding protein|epididymis secretory sperm binding protein', map_location='22q13.2-q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43528549, end_position_on_the_genomic_accession=43812977, orientation='minus', exon_count=41, OMIM=[], no_hdr0=''),
    64801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64801, CurrentID=0, Status='live', Symbol='ARV1', Aliases=['DEE38', 'EIEE38'], description='ARV1 homolog, fatty acid homeostasis modulator', other_designations='protein ARV1', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230979082, end_position_on_the_genomic_accession=231000733, orientation='plus', exon_count=8, OMIM=[611647], no_hdr0=''),
    64802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64802, CurrentID=0, Status='live', Symbol='NMNAT1', Aliases=['LCA9', 'NMNAT', 'PNAT1', 'SHILCA'], description='nicotinamide nucleotide adenylyltransferase 1', other_designations='nicotinamide/nicotinic acid mononucleotide adenylyltransferase 1|NMN adenylyltransferase 1|NMN/NaMN adenylyltransferase 1|NaMN adenylyltransferase 1|nicotinamide mononucleotide adenylyltransferase 1|nicotinate-nucleotide adenylyltransferase 1|pyridine nucleotide adenylyltransferase 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9942923, end_position_on_the_genomic_accession=9996884, orientation='plus', exon_count=9, OMIM=[608700], no_hdr0=''),
    64805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64805, CurrentID=0, Status='live', Symbol='P2RY12', Aliases=['ADPG-R', 'BDPLT8', 'HORK3', 'P2T(AC)', 'P2Y(12)R', 'P2Y(AC)', 'P2Y(ADP)', 'P2Y(cyc)', 'P2Y12', 'SP1999'], description='purinergic receptor P2Y12', other_designations='P2Y purinoceptor 12|ADP-glucose receptor|G-protein coupled receptor SP1999|Gi-coupled ADP receptor HORK3|P2Y12 platelet ADP receptor|purinergic receptor P2RY12|purinergic receptor P2Y, G-protein coupled, 12|putative G-protein coupled receptor', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151336843, end_position_on_the_genomic_accession=151384753, orientation='minus', exon_count=3, OMIM=[600515], no_hdr0=''),
    64806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64806, CurrentID=0, Status='live', Symbol='IL25', Aliases=['IL17E'], description='interleukin 25', other_designations='interleukin-25|interleukin-17E', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23372809, end_position_on_the_genomic_accession=23376403, orientation='plus', exon_count=2, OMIM=[605658], no_hdr0=''),
    64816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64816, CurrentID=0, Status='live', Symbol='CYP3A43', Aliases=[], description='cytochrome P450 family 3 subfamily A member 43', other_designations='cytochrome P450 3A43|cytochrome P450, family 3, subfamily A, polypeptide 43|cytochrome P450, subfamily IIIA, polypeptide 43', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99827626, end_position_on_the_genomic_accession=99867138, orientation='plus', exon_count=15, OMIM=[606534], no_hdr0=''),
    64834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64834, CurrentID=0, Status='live', Symbol='ELOVL1', Aliases=['CGI-88', 'IKSHD', 'Ssc1'], description='ELOVL fatty acid elongase 1', other_designations='elongation of very long chain fatty acids protein 1|3-keto acyl-CoA synthase ELOVL1|ELOVL FA elongase 1|elongation of very long chain fatty acids (FEN1/Elo2, SUR4/Elo3, yeast)-like 1|very long chain 3-ketoacyl-CoA synthase 1|very long chain 3-oxoacyl-CoA synthase 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43363401, end_position_on_the_genomic_accession=43368011, orientation='minus', exon_count=9, OMIM=[611813], no_hdr0=''),
    64837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64837, CurrentID=0, Status='live', Symbol='KLC2', Aliases=[], description='kinesin light chain 2', other_designations='kinesin light chain 2|KLC 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66257288, end_position_on_the_genomic_accession=66267860, orientation='plus', exon_count=17, OMIM=[611729], no_hdr0=''),
    64838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64838, CurrentID=0, Status='live', Symbol='FNDC4', Aliases=['FRCP1'], description='fibronectin type III domain containing 4', other_designations='fibronectin type III domain-containing protein 4|fibronectin type III repeat-containing protein 1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27491883, end_position_on_the_genomic_accession=27495502, orientation='minus', exon_count=7, OMIM=[611905], no_hdr0=''),
    64839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64839, CurrentID=0, Status='live', Symbol='FBXL17', Aliases=['FBXO13', 'Fbl17', 'Fbx13'], description='F-box and leucine rich repeat protein 17', other_designations='F-box/LRR-repeat protein 17|F-box only protein 13', map_location='5q21.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=107859035, end_position_on_the_genomic_accession=108382098, orientation='minus', exon_count=18, OMIM=[609083], no_hdr0=''),
    64840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64840, CurrentID=0, Status='live', Symbol='PORCN', Aliases=['DHOF', 'FODH', 'MG61', 'PORC', 'PPN'], description='porcupine O-acyltransferase', other_designations='protein-serine O-palmitoleoyltransferase porcupine|porcupine homolog|probable protein-cysteine N-palmitoyltransferase porcupine', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48508992, end_position_on_the_genomic_accession=48520814, orientation='plus', exon_count=15, OMIM=[300651], no_hdr0=''),
    64841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64841, CurrentID=0, Status='live', Symbol='GNPNAT1', Aliases=['GNA1', 'GNPNAT', 'Gpnat1'], description='glucosamine-phosphate N-acetyltransferase 1', other_designations='glucosamine 6-phosphate N-acetyltransferase|phosphoglucosamine acetylase|phosphoglucosamine transacetylase', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52775193, end_position_on_the_genomic_accession=52791607, orientation='minus', exon_count=8, OMIM=[616510], no_hdr0=''),
    64843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64843, CurrentID=0, Status='live', Symbol='ISL2', Aliases=[], description='ISL LIM homeobox 2', other_designations='insulin gene enhancer protein ISL-2|ISL2 transcription factor, LIM/homeodomain, (islet-2)|islet-2', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76336773, end_position_on_the_genomic_accession=76342475, orientation='plus', exon_count=6, OMIM=[609481], no_hdr0=''),
    64844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64844, CurrentID=0, Status='live', Symbol='MARCHF7', Aliases=['AXO', 'AXOT', 'MARCH-VII', 'MARCH7', 'RNF177'], description='membrane associated ring-CH-type finger 7', other_designations='E3 ubiquitin-protein ligase MARCHF7|E3 ubiquitin-protein ligase MARCH7|RING finger protein 177|RING-type E3 ubiquitin transferase MARCH7|RING-type E3 ubiquitin transferase MARCHF7|axotrophin|membrane associated ring finger 7|membrane-associated RING finger protein 7|membrane-associated RING-CH protein VII|membrane-associated ring finger (C3HC4) 7, E3 ubiquitin protein ligase', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159712494, end_position_on_the_genomic_accession=159771027, orientation='plus', exon_count=16, OMIM=[613334], no_hdr0=''),
    64847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64847, CurrentID=0, Status='live', Symbol='SPATA20', Aliases=['HEL-S-98', 'SSP411', 'Tisp78'], description='spermatogenesis associated 20', other_designations='spermatogenesis-associated protein 20|epididymis secretory protein Li 98|sperm protein SSP411|sperm-specific protein 411|transcript increased in spermiogenesis 78', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50547174, end_position_on_the_genomic_accession=50555852, orientation='plus', exon_count=17, OMIM=[613939], no_hdr0=''),
    64848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64848, CurrentID=0, Status='live', Symbol='YTHDC2', Aliases=['CAHL', 'hYTHDC2'], description='YTH domain containing 2', other_designations="3'-5' RNA helicase YTHDC2|CsA-associated helicase-like protein|probable ATP-dependent RNA helicase YTHDC2", map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=113513683, end_position_on_the_genomic_accession=113595284, orientation='plus', exon_count=32, OMIM=[616530], no_hdr0=''),
    64849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64849, CurrentID=0, Status='live', Symbol='SLC13A3', Aliases=['ARLIAK', 'NADC3', 'SDCT2'], description='solute carrier family 13 member 3', other_designations='solute carrier family 13 member 3|Na(+)/dicarboxylate cotransporter 3|hNaDC3|naDC-3|sodium-dependent high affinity dicarboxylate transporter 3', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46557828, end_position_on_the_genomic_accession=46684485, orientation='minus', exon_count=15, OMIM=[606411], no_hdr0=''),
    64850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64850, CurrentID=0, Status='live', Symbol='ETNPPL', Aliases=['AGXT2L1'], description='ethanolamine-phosphate phospho-lyase', other_designations='ethanolamine-phosphate phospho-lyase|alanine--glyoxylate aminotransferase 2-like 1', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=108742053, end_position_on_the_genomic_accession=108763053, orientation='minus', exon_count=13, OMIM=[614682], no_hdr0=''),
    64852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64852, CurrentID=0, Status='live', Symbol='TUT1', Aliases=['PAPD2', 'RBM21', 'STARPAP', 'TENT1', 'TUTase', 'URLC6'], description='terminal uridylyl transferase 1, U6 snRNA-specific', other_designations='speckle targeted PIP5K1A-regulated poly(A) polymerase|PAP-associated domain-containing 2|RNA uridylyltransferase|RNA-binding motif protein 21|RNA-binding protein 21|TUTase 6|U6 snRNA-specific terminal uridylyltransferase 1|U6-TUTase|nuclear speckle targeted phosphatidylinositol 4-phosphate 5-kinase type I-alpha regulated-poly(A) polymerase|nuclear speckle-targeted PIPK1A-regulated-poly(A) polymerase|poly(A) polymerase associated domain containing 2|star-PAP|up-regulated in lung cancer 6', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62575052, end_position_on_the_genomic_accession=62591523, orientation='minus', exon_count=9, OMIM=[610641], no_hdr0=''),
    64853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64853, CurrentID=0, Status='live', Symbol='AIDA', Aliases=['C1orf80'], description='axin interactor, dorsalization associated', other_designations='axin interactor, dorsalization-associated protein|axin interaction partner and dorsalization antagonist', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222668013, end_position_on_the_genomic_accession=222712895, orientation='minus', exon_count=10, OMIM=[612375], no_hdr0=''),
    64854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64854, CurrentID=0, Status='live', Symbol='USP46', Aliases=[], description='ubiquitin specific peptidase 46', other_designations='ubiquitin carboxyl-terminal hydrolase 46|deubiquitinating enzyme 46|ubiquitin thioesterase 46|ubiquitin thiolesterase 46|ubiquitin-specific-processing protease 46', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52590960, end_position_on_the_genomic_accession=52659301, orientation='minus', exon_count=11, OMIM=[612849], no_hdr0=''),
    64855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64855, CurrentID=0, Status='live', Symbol='NIBAN2', Aliases=['C9orf88', 'FAM129B', 'MEG-3', 'MINERVA', 'OC58', 'bA356B19.6'], description='niban apoptosis regulator 2', other_designations='protein Niban 2|family with sequence similarity 129 member B|melanoma invasion by ERK|niban-like protein 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127505339, end_position_on_the_genomic_accession=127579031, orientation='minus', exon_count=17, OMIM=[614045], no_hdr0=''),
    64856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64856, CurrentID=0, Status='live', Symbol='VWA1', Aliases=['HMNMYO', 'WARP'], description='von Willebrand factor A domain containing 1', other_designations='von Willebrand factor A domain-containing protein 1|von Willebrand factor A domain-related protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1435690, end_position_on_the_genomic_accession=1442882, orientation='plus', exon_count=3, OMIM=[611901], no_hdr0=''),
    64857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64857, CurrentID=0, Status='live', Symbol='PLEKHG2', Aliases=['ARHGEF42', 'CLG', 'CTB-60E11.4', 'LDAMD'], description='pleckstrin homology and RhoGEF domain containing G2', other_designations='pleckstrin homology domain-containing family G member 2|PH domain-containing family G member 2|common-site lymphoma/leukemia guanine nucleotide exchange factor|pleckstrin homology domain containing, family G (with RhoGef domain) member 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39412582, end_position_on_the_genomic_accession=39428415, orientation='plus', exon_count=20, OMIM=[611893], no_hdr0=''),
    64858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64858, CurrentID=0, Status='live', Symbol='DCLRE1B', Aliases=['APOLLO', 'SNM1B', 'SNMIB'], description='DNA cross-link repair 1B', other_designations="5' exonuclease Apollo|DNA cross-link repair 1B (PSO2 homolog, S. cerevisiae)|PSO2 homolog|SNM1 homolog B", map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113904619, end_position_on_the_genomic_accession=113914086, orientation='plus', exon_count=5, OMIM=[609683], no_hdr0=''),
    64859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64859, CurrentID=0, Status='live', Symbol='NABP1', Aliases=['OBFC2A', 'SOSS-B2', 'SSB2'], description='nucleic acid binding protein 1', other_designations='SOSS complex subunit B2|oligonucleotide/oligosaccharide-binding fold containing 2A|oligonucleotide/oligosaccharide-binding fold-containing protein 2A|sensor of single-strand DNA complex subunit B2|sensor of ssDNA subunit B2|single-stranded DNA-binding protein 2', map_location='2q32.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=191678136, end_position_on_the_genomic_accession=191686943, orientation='plus', exon_count=7, OMIM=[612103], no_hdr0=''),
    64860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64860, CurrentID=0, Status='live', Symbol='ARMCX5', Aliases=['GASP5'], description='armadillo repeat containing X-linked 5', other_designations='armadillo repeat-containing X-linked protein 5', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102599206, end_position_on_the_genomic_accession=102604159, orientation='plus', exon_count=6, OMIM=[301047], no_hdr0=''),
    64863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64863, CurrentID=0, Status='live', Symbol='METTL4', Aliases=['HsT661'], description='methyltransferase 4, N6-adenosine', other_designations="N(6)-adenine-specific methyltransferase METTL4|N(6)-adenine-specific DNA methyltransferase METTL4|methyltransferase like 4|methyltransferase-like protein 4|snRNA (2'-O-methyladenosine-N(6)-)-methyltransferase METTL4", map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=2537530, end_position_on_the_genomic_accession=2571505, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    64864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64864, CurrentID=0, Status='live', Symbol='RFX7', Aliases=['RFXDC2'], description='regulatory factor X7', other_designations='DNA-binding protein RFX7|regulatory factor X domain containing 2|regulatory factor X domain-containing protein 2|regulatory factor X, 7', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=56087280, end_position_on_the_genomic_accession=56247654, orientation='minus', exon_count=14, OMIM=[612660], no_hdr0=''),
    64866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64866, CurrentID=0, Status='live', Symbol='CDCP1', Aliases=['CD318', 'SIMA135', 'TRASK'], description='CUB domain containing protein 1', other_designations='CUB domain-containing protein 1|membrane glycoprotein gp140|subtractive immunization M plus HEp3-associated 135 kDa protein|transmembrane and associated with src kinases', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45082277, end_position_on_the_genomic_accession=45146410, orientation='minus', exon_count=9, OMIM=[611735], no_hdr0=''),
    64881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64881, CurrentID=0, Status='live', Symbol='PCDH20', Aliases=['PCDH13'], description='protocadherin 20', other_designations='protocadherin-20|protocadherin 13', map_location='13q21.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=61409685, end_position_on_the_genomic_accession=61415522, orientation='minus', exon_count=2, OMIM=[614449], no_hdr0=''),
    64895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64895, CurrentID=0, Status='live', Symbol='PAPOLG', Aliases=[], description='poly(A) polymerase gamma', other_designations="poly(A) polymerase gamma|PAP-gamma|SRP RNA 3' adenylating enzyme/pap2|SRP RNA 3'-adenylating enzyme|SRP RNA-adenylating enzyme|neo-PAP|neo-poly(A) polymerase|nuclear poly(A) polymerase gamma|polynucleotide adenylyltransferase gamma|signal recognition particle RNA-adenylating enzyme", map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=60756248, end_position_on_the_genomic_accession=60802086, orientation='plus', exon_count=22, OMIM=[616865], no_hdr0=''),
    64897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64897, CurrentID=0, Status='live', Symbol='C12orf43', Aliases=['Custos'], description='chromosome 12 open reading frame 43', other_designations='protein CUSTOS|uncharacterized protein C12orf43', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121000486, end_position_on_the_genomic_accession=121016487, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    64900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64900, CurrentID=0, Status='live', Symbol='LPIN3', Aliases=['LIPN3L', 'SMP2', 'dJ620E11.2'], description='lipin 3', other_designations='phosphatidate phosphatase LPIN3', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41340779, end_position_on_the_genomic_accession=41360583, orientation='plus', exon_count=23, OMIM=[605520], no_hdr0=''),
    64901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64901, CurrentID=0, Status='live', Symbol='RANBP17', Aliases=[], description='RAN binding protein 17', other_designations='ran-binding protein 17', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170862018, end_position_on_the_genomic_accession=171300015, orientation='plus', exon_count=37, OMIM=[606141], no_hdr0=''),
    64902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64902, CurrentID=0, Status='live', Symbol='AGXT2', Aliases=['AGT2', 'BAIBA', 'DAIBAT'], description='alanine--glyoxylate aminotransferase 2', other_designations='alanine--glyoxylate aminotransferase 2, mitochondrial|(R)-3-amino-2-methylpropionate--pyruvate transaminase|beta-ALAAT II|beta-alanine-pyruvate aminotransferase', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34998099, end_position_on_the_genomic_accession=35048188, orientation='minus', exon_count=14, OMIM=[612471], no_hdr0=''),
    64919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64919, CurrentID=0, Status='live', Symbol='BCL11B', Aliases=['ATL1', 'ATL1-alpha', 'ATL1-beta', 'ATL1-delta', 'ATL1-gamma', 'CTIP-2', 'CTIP2', 'IDDFSTA', 'IMD49', 'RIT1', 'ZNF856B', 'hRIT1-alpha'], description='BAF chromatin remodeling complex subunit BCL11B', other_designations='B-cell lymphoma/leukemia 11B|B cell CLL/lymphoma 11B|B-cell CLL/lymphoma 11B (zinc finger protein)|B-cell CLL/lymphoma 11B/T-cell receptor delta constant region fusion protein|B-cell lymphoma/leukaemia 11B|BCL-11B|BCL11B, BAF complex component|BCL11B/TRDC fusion|COUP-TF-interacting protein 2|hRit1|radiation-induced tumor suppressor gene 1 protein|zinc finger protein hRit1 alpha', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99169287, end_position_on_the_genomic_accession=99272197, orientation='minus', exon_count=4, OMIM=[606558], no_hdr0=''),
    64921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64921, CurrentID=0, Status='live', Symbol='CASD1', Aliases=['C7orf12', 'NBLA04196', 'SOAT'], description='CAS1 domain containing 1', other_designations='N-acetylneuraminate 9-O-acetyltransferase|CAS1 domain-containing protein 1|O-acetyltransferase|WUGSC:H_GS542D18.2|sialate O-acetyltransferase', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=94509809, end_position_on_the_genomic_accession=94633465, orientation='plus', exon_count=21, OMIM=[611686], no_hdr0=''),
    64922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64922, CurrentID=0, Status='live', Symbol='LRRC19', Aliases=[], description='leucine rich repeat containing 19', other_designations='leucine-rich repeat-containing protein 19', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=26993136, end_position_on_the_genomic_accession=27005672, orientation='minus', exon_count=5, OMIM=[619068], no_hdr0=''),
    64924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64924, CurrentID=0, Status='live', Symbol='SLC30A5', Aliases=['ZNT5', 'ZNTL1', 'ZTL1', 'ZnT-5'], description='solute carrier family 30 member 5', other_designations='zinc transporter 5|solute carrier family 30 (zinc transporter), member 5|zinc transporter ZTL1|znT-like transporter 1', map_location='5q13.1-q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69093993, end_position_on_the_genomic_accession=69131069, orientation='plus', exon_count=16, OMIM=[607819], no_hdr0=''),
    64925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64925, CurrentID=0, Status='live', Symbol='CCDC71', Aliases=[], description='coiled-coil domain containing 71', other_designations='coiled-coil domain-containing protein 71|2600016J21Rik', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49162535, end_position_on_the_genomic_accession=49166331, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    64926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64926, CurrentID=0, Status='live', Symbol='RASAL3', Aliases=[], description='RAS protein activator like 3', other_designations='RAS protein activator like-3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15451624, end_position_on_the_genomic_accession=15464571, orientation='minus', exon_count=18, OMIM=[616561], no_hdr0=''),
    64927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64927, CurrentID=0, Status='live', Symbol='TTC23', Aliases=['HCC-8'], description='tetratricopeptide repeat domain 23', other_designations='tetratricopeptide repeat protein 23|TPR repeat protein 23|cervical cancer proto-oncogene 8 protein', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99136323, end_position_on_the_genomic_accession=99251226, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    64928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64928, CurrentID=0, Status='live', Symbol='MRPL14', Aliases=['L14mt', 'L32mt', 'MRP-L14', 'MRP-L32', 'MRPL32', 'RMPL32', 'RPML32'], description='mitochondrial ribosomal protein L14', other_designations='39S ribosomal protein L14, mitochondrial|39S ribosomal protein L32, mitochondrial|mitochondrial large ribosomal subunit protein uL14m', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44113451, end_position_on_the_genomic_accession=44127452, orientation='minus', exon_count=6, OMIM=[611827], no_hdr0=''),
    64943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64943, CurrentID=0, Status='live', Symbol='NT5DC2', Aliases=[], description="5'-nucleotidase domain containing 2", other_designations="5'-nucleotidase domain-containing protein 2", map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52524381, end_position_on_the_genomic_accession=52535027, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    64946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64946, CurrentID=0, Status='live', Symbol='CENPH', Aliases=[], description='centromere protein H', other_designations='centromere protein H|CENP-H|interphase centromere complex protein 35|kinetochore protein CENP-H', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69189583, end_position_on_the_genomic_accession=69210357, orientation='plus', exon_count=9, OMIM=[605607], no_hdr0=''),
    64949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64949, CurrentID=0, Status='live', Symbol='MRPS26', Aliases=['C20orf193', 'GI008', 'MRP-S13', 'MRP-S26', 'MRPS13', 'NY-BR-87', 'RPMS13', 'dJ534B8.3'], description='mitochondrial ribosomal protein S26', other_designations='28S ribosomal protein S26, mitochondrial|28S ribosomal protein S13, mitochondrial|S13mt|S26mt|mitochondrial small ribosomal subunit protein mS26|serologically defined breast cancer antigen NY-BR-87', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3046052, end_position_on_the_genomic_accession=3048250, orientation='plus', exon_count=4, OMIM=[611988], no_hdr0=''),
    64951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64951, CurrentID=0, Status='live', Symbol='MRPS24', Aliases=['HSPC335', 'MRP-S24', 'S24mt', 'bMRP-47', 'bMRP47'], description='mitochondrial ribosomal protein S24', other_designations='28S ribosomal protein S24, mitochondrial|mitochondrial 28S ribosomal protein S24|mitochondrial small ribosomal subunit protein uS3m', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43866558, end_position_on_the_genomic_accession=43869517, orientation='minus', exon_count=4, OMIM=[611986], no_hdr0=''),
    64960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64960, CurrentID=0, Status='live', Symbol='MRPS15', Aliases=['DC37', 'MPR-S15', 'RPMS15', 'S15mt'], description='mitochondrial ribosomal protein S15', other_designations='28S ribosomal protein S15, mitochondrial|MRP-S15|mitochondrial small ribosomal subunit protein uS15m', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36455718, end_position_on_the_genomic_accession=36464384, orientation='minus', exon_count=8, OMIM=[611979], no_hdr0=''),
    64963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64963, CurrentID=0, Status='live', Symbol='MRPS11', Aliases=['HCC-2', 'MRP-S11', 'S11mt'], description='mitochondrial ribosomal protein S11', other_designations='28S ribosomal protein S11, mitochondrial|cervical cancer proto-oncogene 2 protein|mitochondrial small ribosomal subunit protein uS11m', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88467708, end_position_on_the_genomic_accession=88480776, orientation='plus', exon_count=7, OMIM=[611977], no_hdr0=''),
    64965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64965, CurrentID=0, Status='live', Symbol='MRPS9', Aliases=['MRP-S9', 'RPMS9', 'S9mt'], description='mitochondrial ribosomal protein S9', other_designations='28S ribosomal protein S9, mitochondrial|mitochondrial small ribosomal subunit protein uS9m', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105037469, end_position_on_the_genomic_accession=105099960, orientation='plus', exon_count=12, OMIM=[611975], no_hdr0=''),
    64968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64968, CurrentID=0, Status='live', Symbol='MRPS6', Aliases=['C21orf101', 'MRP-S6', 'RPMS6', 'S6mt'], description='mitochondrial ribosomal protein S6', other_designations='28S ribosomal protein S6, mitochondrial|mitochondrial small ribosomal subunit protein bS6m', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34073578, end_position_on_the_genomic_accession=34143030, orientation='plus', exon_count=3, OMIM=[611973], no_hdr0=''),
    64969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64969, CurrentID=0, Status='live', Symbol='MRPS5', Aliases=['MRP-S5', 'S5mt'], description='mitochondrial ribosomal protein S5', other_designations='28S ribosomal protein S5, mitochondrial|mitochondrial 28S ribosomal protein S5|mitochondrial small ribosomal subunit protein uS5m', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95085369, end_position_on_the_genomic_accession=95122003, orientation='minus', exon_count=12, OMIM=[611972], no_hdr0=''),
    64975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64975, CurrentID=0, Status='live', Symbol='MRPL41', Aliases=['BMRP', 'MRP-L27', 'MRPL27', 'PIG3', 'RPML27'], description='mitochondrial ribosomal protein L41', other_designations='39S ribosomal protein L41, mitochondrial|39S ribosomal protein L27 homolog|L41mt|MRP-L27 homolog|MRP-L41|bcl-2-interacting mitochondrial ribosomal protein L41|cell proliferation-inducing gene 3 protein|mitochondrial large ribosomal subunit protein mL41|proliferation-inducing gene 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137551879, end_position_on_the_genomic_accession=137552555, orientation='plus', exon_count=2, OMIM=[611846], no_hdr0=''),
    64976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64976, CurrentID=0, Status='live', Symbol='MRPL40', Aliases=['L40mt', 'MRP-L22', 'MRP-L40', 'MRPL22', 'NLVCF', 'URIM'], description='mitochondrial ribosomal protein L40', other_designations='39S ribosomal protein L40, mitochondrial|mitochondrial large ribosomal subunit protein mL40|nuclear localization signal-containing protein deleted in velocardiofacial syndrome|up-regulated in metastasis', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19432545, end_position_on_the_genomic_accession=19436075, orientation='plus', exon_count=4, OMIM=[605089], no_hdr0=''),
    64978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64978, CurrentID=0, Status='live', Symbol='MRPL38', Aliases=['HSPC262', 'L38MT', 'MRP-L3', 'MRP-L38', 'RPML3'], description='mitochondrial ribosomal protein L38', other_designations='39S ribosomal protein L38, mitochondrial|mitochondrial large ribosomal subunit protein mL38', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75898644, end_position_on_the_genomic_accession=75904884, orientation='minus', exon_count=9, OMIM=[611844], no_hdr0=''),
    64979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64979, CurrentID=0, Status='live', Symbol='MRPL36', Aliases=['BRIP1', 'L36mt', 'MRP-L36', 'PRPL36', 'RPMJ'], description='mitochondrial ribosomal protein L36', other_designations='39S ribosomal protein L36, mitochondrial|BRCA1-interacting protein 1|mitochondrial large ribosomal subunit protein bL36m|putative BRCA1-interacting protein', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1798385, end_position_on_the_genomic_accession=1801432, orientation='minus', exon_count=5, OMIM=[611842], no_hdr0=''),
    64981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64981, CurrentID=0, Status='live', Symbol='MRPL34', Aliases=['L34mt'], description='mitochondrial ribosomal protein L34', other_designations='39S ribosomal protein L34, mitochondrial|MRP-L34|mitochondrial large ribosomal subunit protein bL34m', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17302865, end_position_on_the_genomic_accession=17306843, orientation='plus', exon_count=4, OMIM=[611840], no_hdr0=''),
    64983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=64983, CurrentID=0, Status='live', Symbol='MRPL32', Aliases=['HSPC283', 'L32mt', 'MRP-L32', 'bMRP-59b'], description='mitochondrial ribosomal protein L32', other_designations='39S ribosomal protein L32, mitochondrial|mitochondrial large ribosomal subunit protein bL32m', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=42932376, end_position_on_the_genomic_accession=42937857, orientation='plus', exon_count=4, OMIM=[611839], no_hdr0=''),
    65003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65003, CurrentID=0, Status='live', Symbol='MRPL11', Aliases=['CGI-113', 'L11MT', 'MRP-L11'], description='mitochondrial ribosomal protein L11', other_designations='39S ribosomal protein L11, mitochondrial|mitochondrial large ribosomal subunit protein uL11m', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66435075, end_position_on_the_genomic_accession=66438860, orientation='minus', exon_count=6, OMIM=[611826], no_hdr0=''),
    65005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65005, CurrentID=0, Status='live', Symbol='MRPL9', Aliases=['L9mt'], description='mitochondrial ribosomal protein L9', other_designations='39S ribosomal protein L9, mitochondrial|mitochondrial large ribosomal subunit protein bL9m', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151759647, end_position_on_the_genomic_accession=151763496, orientation='minus', exon_count=7, OMIM=[611824], no_hdr0=''),
    65008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65008, CurrentID=0, Status='live', Symbol='MRPL1', Aliases=['BM022', 'L1MT', 'MRP-L1'], description='mitochondrial ribosomal protein L1', other_designations='39S ribosomal protein L1, mitochondrial|mitochondrial large ribosomal subunit protein uL1m', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=77862680, end_position_on_the_genomic_accession=77952790, orientation='plus', exon_count=10, OMIM=[611821], no_hdr0=''),
    65009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65009, CurrentID=0, Status='live', Symbol='NDRG4', Aliases=['BDM1', 'SMAP-8', 'SMAP8'], description='NDRG family member 4', other_designations='protein NDRG4|N-myc downstream-regulated gene 4 protein|brain development-related molecule 1|smooth muscle-associated protein 8|vascular smooth muscle cell-associated protein 8', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58463704, end_position_on_the_genomic_accession=58515403, orientation='plus', exon_count=24, OMIM=[614463], no_hdr0=''),
    65010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65010, CurrentID=0, Status='live', Symbol='SLC26A6', Aliases=[], description='solute carrier family 26 member 6', other_designations='solute carrier family 26 member 6|anion exchange transporter|anion transporter 1|pendrin L1|solute carrier family 26 (anion exchanger), member 6|sulfate anion transporter', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48625723, end_position_on_the_genomic_accession=48635461, orientation='minus', exon_count=21, OMIM=[610068], no_hdr0=''),
    65018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65018, CurrentID=0, Status='live', Symbol='PINK1', Aliases=['BRPK', 'PARK6'], description='PTEN induced kinase 1', other_designations='serine/threonine-protein kinase PINK1, mitochondrial|PTEN induced putative kinase 1|PTEN-induced putative kinase protein 1|protein kinase BRPK', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20633458, end_position_on_the_genomic_accession=20651511, orientation='plus', exon_count=8, OMIM=[608309], no_hdr0=''),
    65055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65055, CurrentID=0, Status='live', Symbol='REEP1', Aliases=['C2orf23', 'HMN5B', 'SPG31', 'Yip2a'], description='receptor accessory protein 1', other_designations='receptor expression-enhancing protein 1|spastic paraplegia 31 protein', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86213993, end_position_on_the_genomic_accession=86338083, orientation='minus', exon_count=13, OMIM=[609139], no_hdr0=''),
    65056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65056, CurrentID=0, Status='live', Symbol='GPBP1', Aliases=['GPBP', 'SSH6', 'VASCULIN'], description='GC-rich promoter binding protein 1', other_designations='vasculin|vascular wall-linked protein', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=57174059, end_position_on_the_genomic_accession=57264679, orientation='plus', exon_count=14, OMIM=[608412], no_hdr0=''),
    65057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65057, CurrentID=0, Status='live', Symbol='ACD', Aliases=['PIP1', 'PTOP', 'TINT1', 'TPP1'], description='ACD shelterin complex subunit and telomerase recruitment factor', other_designations='adrenocortical dysplasia protein homolog|POT1 and TIN2-interacting protein|TIN2 interacting protein 1|adrenocortical dysplasia homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67657512, end_position_on_the_genomic_accession=67660832, orientation='minus', exon_count=12, OMIM=[609377], no_hdr0=''),
    65059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65059, CurrentID=0, Status='live', Symbol='RAPH1', Aliases=['ALS2CR18', 'ALS2CR9', 'LPD', 'PREL-2', 'PREL2', 'RMO1', 'RalGDS/AF-6'], description='Ras association (RalGDS/AF-6) and pleckstrin homology domains 1', other_designations='ras-associated and pleckstrin homology domains-containing protein 1|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 18|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 9|lamellipodin|proline-rich EVH1 ligand 2', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203433682, end_position_on_the_genomic_accession=203535322, orientation='minus', exon_count=19, OMIM=[609035], no_hdr0=''),
    65061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65061, CurrentID=0, Status='live', Symbol='CDK15', Aliases=['ALS2CR7', 'PFTAIRE2', 'PFTK2'], description='cyclin dependent kinase 15', other_designations='cyclin-dependent kinase 15|PFTAIRE protein kinase 2|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 7|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 7 protein|cell division protein kinase 15|serine/threonine protein kinase|serine/threonine-protein kinase ALS2CR7|serine/threonine-protein kinase PFTAIRE-2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201790324, end_position_on_the_genomic_accession=201895550, orientation='plus', exon_count=23, OMIM=[616147], no_hdr0=''),
    65062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65062, CurrentID=0, Status='live', Symbol='TMEM237', Aliases=['ALS2CR4', 'JBTS14'], description='transmembrane protein 237', other_designations='transmembrane protein 237|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 4|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 4 protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201620186, end_position_on_the_genomic_accession=201643503, orientation='minus', exon_count=14, OMIM=[614423], no_hdr0=''),
    65065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65065, CurrentID=0, Status='live', Symbol='NBEAL1', Aliases=['A530083I02Rik', 'ALS2CR16', 'ALS2CR17'], description='neurobeachin like 1', other_designations='neurobeachin-like protein 1|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 16|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 17|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 16 protein|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 17 protein|beach', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=203013784, end_position_on_the_genomic_accession=203225194, orientation='plus', exon_count=61, OMIM=[609816], no_hdr0=''),
    65078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65078, CurrentID=0, Status='live', Symbol='RTN4R', Aliases=['NGR', 'NOGOR'], description='reticulon 4 receptor', other_designations='reticulon-4 receptor|Nogo-66 receptor|UNQ330/PRO526|nogo receptor', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20241415, end_position_on_the_genomic_accession=20268318, orientation='minus', exon_count=2, OMIM=[605566], no_hdr0=''),
    65080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65080, CurrentID=0, Status='live', Symbol='MRPL44', Aliases=['COXPD16', 'L44MT', 'MRP-L44'], description='mitochondrial ribosomal protein L44', other_designations='39S ribosomal protein L44, mitochondrial|mitochondrial large ribosomal subunit protein mL44', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223950846, end_position_on_the_genomic_accession=223967714, orientation='plus', exon_count=5, OMIM=[611849], no_hdr0=''),
    65082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65082, CurrentID=0, Status='live', Symbol='VPS33A', Aliases=['MPSPS'], description='VPS33A core subunit of CORVET and HOPS complexes', other_designations='vacuolar protein sorting-associated protein 33A|VPS33A, CORVET/HOPS core subunit|vacuolar protein sorting 33 homolog A|vacuolar protein sorting 33A', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122229564, end_position_on_the_genomic_accession=122266494, orientation='minus', exon_count=14, OMIM=[610034], no_hdr0=''),
    65083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65083, CurrentID=0, Status='live', Symbol='NOL6', Aliases=['NRAP', 'UTP22', 'bA311H10.1'], description='nucleolar protein 6', other_designations='nucleolar protein 6|nucleolar RNA-associated protein|nucleolar protein 6 (RNA-associated)|nucleolar protein family 6 (RNA-associated)', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33460811, end_position_on_the_genomic_accession=33473924, orientation='minus', exon_count=26, OMIM=[611532], no_hdr0=''),
    65084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65084, CurrentID=0, Status='live', Symbol='TMEM135', Aliases=['PMP52'], description='transmembrane protein 135', other_designations='transmembrane protein 135|peroxisomal membrane protein 52', map_location='11q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=87037934, end_position_on_the_genomic_accession=87328824, orientation='plus', exon_count=17, OMIM=[616360], no_hdr0=''),
    65094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65094, CurrentID=0, Status='live', Symbol='JMJD4', Aliases=[], description='jumonji domain containing 4', other_designations='2-oxoglutarate and iron-dependent oxygenase JMJD4|2-oxoglutarate- and Fe(II)-dependent oxygenase|C4 lysyl hydroxylase|jmjC domain-containing protein 4|jumonji domain-containing protein 4|lysyl-hydroxylase JMJD4', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=227731191, end_position_on_the_genomic_accession=227735499, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    65095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65095, CurrentID=0, Status='live', Symbol='KRI1', Aliases=[], description='KRI1 homolog', other_designations='protein KRI1 homolog', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10553085, end_position_on_the_genomic_accession=10566031, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    65108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65108, CurrentID=0, Status='live', Symbol='MARCKSL1', Aliases=['F52', 'MACMARCKS', 'MLP', 'MLP1', 'MRP'], description='MARCKS like 1', other_designations='MARCKS-related protein|MARCKS-like protein 1|mac-MARCKS|macrophage myristoylated alanine-rich C kinase substrate', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32333839, end_position_on_the_genomic_accession=32336233, orientation='minus', exon_count=2, OMIM=[602940], no_hdr0=''),
    65109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65109, CurrentID=0, Status='live', Symbol='UPF3B', Aliases=['HUPF3B', 'MRX62', 'MRX82', 'MRXS14', 'RENT3BP1', 'UPF3BP2', 'UPF3BP3', 'UPF3X', 'Upf3p-X', 'UPF3B'], description='UPF3B regulator of nonsense mediated mRNA decay', other_designations='regulator of nonsense transcripts 3B|UPF3 regulator of nonsense transcripts homolog B|UPF3B pseudogene 1|UPF3B pseudogene 2|UPF3B pseudogene 3|mental retardation, X-linked 62|nonfunctional UPF3B regulator of nonsense mediated mRNA decay|nonsense mRNA reducing factor 3B|up-frameshift suppressor 3 homolog B|up-frameshift suppressor 3 homolog on chromosome X', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119805311, end_position_on_the_genomic_accession=119853028, orientation='minus', exon_count=16, OMIM=[300298], no_hdr0=''),
    65110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65110, CurrentID=0, Status='live', Symbol='UPF3A', Aliases=['HUPF3A', 'RENT3A', 'UPF3'], description='UPF3A regulator of nonsense mediated mRNA decay', other_designations='regulator of nonsense transcripts 3A|UPF3 regulator of nonsense transcripts homolog A|hUpf3|nonsense mRNA reducing factor 3A|up-frameshift suppressor 3 homolog A', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=114281598, end_position_on_the_genomic_accession=114305817, orientation='plus', exon_count=14, OMIM=[605530], no_hdr0=''),
    65117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65117, CurrentID=0, Status='live', Symbol='RSRC2', Aliases=[], description='arginine and serine rich coiled-coil 2', other_designations='arginine/serine-rich coiled-coil protein 2|arginine/serine-rich coiled-coil 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122503454, end_position_on_the_genomic_accession=122526999, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    65121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65121, CurrentID=0, Status='live', Symbol='PRAMEF1', Aliases=[], description='PRAME family member 1', other_designations='PRAME family member 1', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12791397, end_position_on_the_genomic_accession=12796628, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    65122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65122, CurrentID=0, Status='live', Symbol='PRAMEF2', Aliases=['DJ845O24.3'], description='PRAME family member 2', other_designations='PRAME family member 2', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12857086, end_position_on_the_genomic_accession=12861909, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    65123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65123, CurrentID=0, Status='live', Symbol='INTS3', Aliases=['C1orf193', 'C1orf60', 'INT3', 'SOSS-A', 'SOSSA'], description='integrator complex subunit 3', other_designations='integrator complex subunit 3|SOSS complex subunit A|sensor of single-strand DNA complex subunit A|sensor of ssDNA subunit A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153728050, end_position_on_the_genomic_accession=153774808, orientation='plus', exon_count=30, OMIM=[611347], no_hdr0=''),
    65124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65124, CurrentID=0, Status='live', Symbol='SOWAHC', Aliases=['ANKRD57', 'C2orf26'], description='sosondowah ankyrin repeat domain family member C', other_designations='ankyrin repeat domain-containing protein SOWAHC|ankyrin repeat domain 57|ankyrin repeat domain-containing protein 57|protein sosondowah homolog C', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109614364, end_position_on_the_genomic_accession=109618990, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    65125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65125, CurrentID=0, Status='live', Symbol='WNK1', Aliases=['HSAN2', 'HSN2', 'KDP', 'PPP1R167', 'PRKWNK1', 'PSK', 'p65'], description='WNK lysine deficient protein kinase 1', other_designations='serine/threonine-protein kinase WNK1|erythrocyte 65 kDa protein|prostate-derived sterile 20-like kinase|protein kinase with no lysine 1|protein phosphatase 1, regulatory subunit 167|serine/threonine-protein kinase WNK1 1|serine/threonine-protein kinase WNK1 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=752579, end_position_on_the_genomic_accession=911452, orientation='plus', exon_count=31, OMIM=[605232], no_hdr0=''),
    65217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65217, CurrentID=0, Status='live', Symbol='PCDH15', Aliases=['CDHR15', 'DFNB23', 'USH1F'], description='protocadherin related 15', other_designations='protocadherin-15|cadherin-related family member 15', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=53802771, end_position_on_the_genomic_accession=55629182, orientation='minus', exon_count=48, OMIM=[605514], no_hdr0=''),
    65220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65220, CurrentID=0, Status='live', Symbol='NADK', Aliases=['dJ283E3.1'], description='NAD kinase', other_designations='NAD kinase|poly(P)/ATP NAD kinase', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1751232, end_position_on_the_genomic_accession=1780509, orientation='minus', exon_count=19, OMIM=[611616], no_hdr0=''),
    65243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65243, CurrentID=0, Status='live', Symbol='ZFP69B', Aliases=['ZKSCAN23B', 'ZNF643', 'ZSCAN54B'], description='ZFP69 zinc finger protein B', other_designations='zinc finger protein 69 homolog B|novel zinc finger protein|zinc finger protein 643|zinc finger protein ZFP69B', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40450064, end_position_on_the_genomic_accession=40466765, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    65244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65244, CurrentID=0, Status='live', Symbol='SPATS2', Aliases=['Nbla00526', 'P59SCR', 'SCR59', 'SPATA10'], description='spermatogenesis associated serine rich 2', other_designations='spermatogenesis-associated serine-rich protein 2|putative protein product of Nbla00526|serine-rich spermatocytes and round spermatid 59 kDa protein|serine-rich spermatocytes and round spermatid protein', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49366909, end_position_on_the_genomic_accession=49527441, orientation='plus', exon_count=16, OMIM=[611667], no_hdr0=''),
    65249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65249, CurrentID=0, Status='live', Symbol='ZSWIM4', Aliases=[], description='zinc finger SWIM-type containing 4', other_designations='zinc finger SWIM domain-containing protein 4', map_location='19p13.13-p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13795424, end_position_on_the_genomic_accession=13832254, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    65250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65250, CurrentID=0, Status='live', Symbol='CPLANE1', Aliases=['C5orf42', 'Hug', 'JBTS17', 'OFD6'], description='ciliogenesis and planar polarity effector 1', other_designations='ciliogenesis and planar polarity effector 1|protein JBTS17|transmembrane protein ENSP00000382582', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=37063928, end_position_on_the_genomic_accession=37249499, orientation='minus', exon_count=60, OMIM=[614571], no_hdr0=''),
    65251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65251, CurrentID=0, Status='live', Symbol='ZNF649', Aliases=[], description='zinc finger protein 649', other_designations='zinc finger protein 649', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51889235, end_position_on_the_genomic_accession=51905017, orientation='minus', exon_count=5, OMIM=[611903], no_hdr0=''),
    65258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65258, CurrentID=0, Status='live', Symbol='MPPE1', Aliases=['Cdc1', 'PGAP5'], description='metallophosphoesterase 1', other_designations='metallophosphoesterase 1|metallo phosphoesterase|post-GPI attachment to proteins 5|post-GPI attachment to proteins factor 5', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=11882622, end_position_on_the_genomic_accession=11908661, orientation='minus', exon_count=17, OMIM=[611900], no_hdr0=''),
    65260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65260, CurrentID=0, Status='live', Symbol='COA7', Aliases=['C1orf163', 'RESA1', 'SCAN3', 'SELRC1'], description='cytochrome c oxidase assembly factor 7', other_designations='cytochrome c oxidase assembly factor 7|Sel1 repeat containing 1|beta-lactamase hcp-like protein|cytochrome c oxidase assembly factor 7 (putative)|epididymis secretory sperm binding protein|hcp beta-lactamase-like protein C1orf163|respiratory chain assembly 1|respiratory chain assembly factor 1|sel1 repeat-containing protein 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52684449, end_position_on_the_genomic_accession=52698347, orientation='minus', exon_count=3, OMIM=[615623], no_hdr0=''),
    65263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65263, CurrentID=0, Status='live', Symbol='PYCR3', Aliases=['PYCRL'], description='pyrroline-5-carboxylate reductase 3', other_designations='pyrroline-5-carboxylate reductase 3|P5C reductase 3|P5CR 3|pyrroline-5-carboxylate reductase-like', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143603210, end_position_on_the_genomic_accession=143609575, orientation='minus', exon_count=7, OMIM=[616408], no_hdr0=''),
    65264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65264, CurrentID=0, Status='live', Symbol='UBE2Z', Aliases=['HOYS7', 'USE1'], description='ubiquitin conjugating enzyme E2 Z', other_designations='ubiquitin-conjugating enzyme E2 Z|E2 ubiquitin-conjugating enzyme Z|UBA6-specific enzyme E2|uba6-specific E2 conjugating enzyme 1|ubiquitin carrier protein Z|ubiquitin conjugating enzyme E2Z|ubiquitin-protein ligase Z', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48908407, end_position_on_the_genomic_accession=48929056, orientation='plus', exon_count=7, OMIM=[611362], no_hdr0=''),
    65265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65265, CurrentID=0, Status='live', Symbol='C8orf33', Aliases=[], description='chromosome 8 open reading frame 33', other_designations='UPF0488 protein C8orf33', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=145052467, end_position_on_the_genomic_accession=145065864, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    65266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65266, CurrentID=0, Status='live', Symbol='WNK4', Aliases=['PHA2B', 'PRKWNK4'], description='WNK lysine deficient protein kinase 4', other_designations='serine/threonine-protein kinase WNK4|protein kinase lysine-deficient 4|protein kinase with no lysine 4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42779701, end_position_on_the_genomic_accession=42797066, orientation='plus', exon_count=18, OMIM=[601844], no_hdr0=''),
    65267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65267, CurrentID=0, Status='live', Symbol='WNK3', Aliases=['PRKWNK3'], description='WNK lysine deficient protein kinase 3', other_designations='serine/threonine-protein kinase WNK3|protein kinase with no lysine 3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54192823, end_position_on_the_genomic_accession=54358695, orientation='minus', exon_count=25, OMIM=[300358], no_hdr0=''),
    65268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65268, CurrentID=0, Status='live', Symbol='WNK2', Aliases=['NY-CO-43', 'P/OKcl.13', 'PRKWNK2', 'SDCCAG43'], description='WNK lysine deficient protein kinase 2', other_designations='serine/threonine-protein kinase WNK2|antigen NY-CO-43|mitogen-activated protein kinase kinase kinase|protein kinase lysine-deficient 2|protein kinase with no lysine 2|serologically defined colon cancer antigen 43', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93184139, end_position_on_the_genomic_accession=93327581, orientation='plus', exon_count=38, OMIM=[606249], no_hdr0=''),
    65975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65975, CurrentID=0, Status='live', Symbol='STK33', Aliases=[], description='serine/threonine kinase 33', other_designations='serine/threonine-protein kinase 33', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8335029, end_position_on_the_genomic_accession=8594228, orientation='minus', exon_count=25, OMIM=[607670], no_hdr0=''),
    65977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65977, CurrentID=0, Status='live', Symbol='PLEKHA3', Aliases=['FAPP1'], description='pleckstrin homology domain containing A3', other_designations='pleckstrin homology domain-containing family A member 3|FAPP-1|PH domain-containing family A member 3|four-phosphate-adaptor protein 1|phosphatidylinositol-four-phosphate adapter protein 1|phosphoinositol 4-phosphate adapter protein 1|pleckstrin homology domain containing, family A (phosphoinositide binding specific) member 3', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178480454, end_position_on_the_genomic_accession=178516463, orientation='plus', exon_count=9, OMIM=[607774], no_hdr0=''),
    65979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65979, CurrentID=0, Status='live', Symbol='PHACTR4', Aliases=['PPP1R124'], description='phosphatase and actin regulator 4', other_designations='phosphatase and actin regulator 4|protein phosphatase 1, regulatory subunit 124', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28369740, end_position_on_the_genomic_accession=28500364, orientation='plus', exon_count=17, OMIM=[608726], no_hdr0=''),
    65980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65980, CurrentID=0, Status='live', Symbol='BRD9', Aliases=['LAVS3040', 'PRO9856'], description='bromodomain containing 9', other_designations='bromodomain-containing protein 9|rhabdomyosarcoma antigen MU-RMS-40.8|sarcoma antigen NY-SAR-29', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=863735, end_position_on_the_genomic_accession=892803, orientation='minus', exon_count=23, OMIM=[618465], no_hdr0=''),
    65981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65981, CurrentID=0, Status='live', Symbol='CAPRIN2', Aliases=['C1QDC1', 'EEG-1', 'EEG1', 'RNG140'], description='caprin family member 2', other_designations='caprin-2|C1q domain-containing protein 1|RNA granule protein 140|cytoplasmic activation/proliferation-associated protein 2|gastric cancer multidrug resistance-associated protein', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=30709552, end_position_on_the_genomic_accession=30754951, orientation='minus', exon_count=22, OMIM=[610375], no_hdr0=''),
    65982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65982, CurrentID=0, Status='live', Symbol='ZSCAN18', Aliases=['ZNF447'], description='zinc finger and SCAN domain containing 18', other_designations='zinc finger and SCAN domain-containing protein 18|zinc finger protein 447', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58083834, end_position_on_the_genomic_accession=58118433, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    65983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65983, CurrentID=0, Status='live', Symbol='GRAMD2B', Aliases=['GRAMD3', 'NS3TP2'], description='GRAM domain containing 2B', other_designations='GRAM domain-containing protein 2B|GRAM domain containing 3|GRAM domain-containing protein 3|HCV NS3-transactivated protein 2|hepatitis C virus nonstructural protein 3-transactivating protein 2', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126360120, end_position_on_the_genomic_accession=126494377, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    65985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65985, CurrentID=0, Status='live', Symbol='AACS', Aliases=['ACSF1', 'SUR-5'], description='acetoacetyl-CoA synthetase', other_designations='acetoacetyl-CoA synthetase|acetoacetate-CoA ligase|acyl-CoA synthetase family member 1|homolog of C. elegans supressor of ras 5 (sur-5)|protein sur-5 homolog', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=125065435, end_position_on_the_genomic_accession=125143327, orientation='plus', exon_count=19, OMIM=[614364], no_hdr0=''),
    65986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65986, CurrentID=0, Status='live', Symbol='ZBTB10', Aliases=['RINZF'], description='zinc finger and BTB domain containing 10', other_designations='zinc finger and BTB domain-containing protein 10|zinc finger protein RIN ZF|zinc finger protein RINZF', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=80485593, end_position_on_the_genomic_accession=80526265, orientation='plus', exon_count=7, OMIM=[618576], no_hdr0=''),
    65987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65987, CurrentID=0, Status='live', Symbol='KCTD14', Aliases=[], description='potassium channel tetramerization domain containing 14', other_designations='BTB/POZ domain-containing protein KCTD14|potassium channel tetramerisation domain containing 14', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78015715, end_position_on_the_genomic_accession=78046191, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    65988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65988, CurrentID=0, Status='live', Symbol='ZNF747', Aliases=[], description='zinc finger protein 747', other_designations='KRAB domain-containing protein ZNF747', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30530367, end_position_on_the_genomic_accession=30534858, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    65989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65989, CurrentID=0, Status='live', Symbol='DLK2', Aliases=['DLK-2', 'EGFL9'], description='delta like non-canonical Notch ligand 2', other_designations='protein delta homolog 2|EGF-like protein 9|EGF-like-domain, multiple 9|delta-like 2 homolog|epidermal growth factor-like protein 9', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43450352, end_position_on_the_genomic_accession=43456632, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    65990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65990, CurrentID=0, Status='live', Symbol='ANTKMT', Aliases=['ANT-KMT', 'C16orf24', 'FAM173A'], description='adenine nucleotide translocase lysine methyltransferase', other_designations='adenine nucleotide translocase lysine N-methyltransferase|family with sequence similarity 173 member A|protein FAM173A|protein N-lysine methyltransferase FAM173A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=720581, end_position_on_the_genomic_accession=722590, orientation='plus', exon_count=5, OMIM=[618566], no_hdr0=''),
    65991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65991, CurrentID=0, Status='live', Symbol='FUNDC2', Aliases=['DC44', 'HCBP6', 'HCC3', 'PD03104'], description='FUN14 domain containing 2', other_designations='FUN14 domain-containing protein 2|HCC-3|cervical cancer oncogene 3|cervical cancer proto-oncogene 3 protein|hepatitis C virus core-binding protein 6', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155026844, end_position_on_the_genomic_accession=155060304, orientation='plus', exon_count=5, OMIM=[301042], no_hdr0=''),
    65992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65992, CurrentID=0, Status='live', Symbol='DDRGK1', Aliases=['C20orf116', 'SEMDSH', 'UFBP1', 'dJ1187M17.3'], description='DDRGK domain containing 1', other_designations='DDRGK domain-containing protein 1|Dashurin|UFM1-binding and PCI domain-containing protein 1|UFM1-binding protein 1 containing a PCI domain', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3190350, end_position_on_the_genomic_accession=3204682, orientation='minus', exon_count=9, OMIM=[616177], no_hdr0=''),
    65993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65993, CurrentID=0, Status='live', Symbol='MRPS34', Aliases=['COXPD32', 'MRP-S12', 'MRP-S34', 'MRPS12'], description='mitochondrial ribosomal protein S34', other_designations='28S ribosomal protein S34, mitochondrial|S34mt|mitochondrial 28S ribosomal protein S34|mitochondrial small ribosomal subunit protein mS34', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1771895, end_position_on_the_genomic_accession=1773134, orientation='minus', exon_count=3, OMIM=[611994], no_hdr0=''),
    65997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65997, CurrentID=0, Status='live', Symbol='RASL11B', Aliases=[], description='RAS like family 11 member B', other_designations='ras-like protein family member 11B', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52862317, end_position_on_the_genomic_accession=52866835, orientation='plus', exon_count=4, OMIM=[612404], no_hdr0=''),
    65998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65998, CurrentID=0, Status='live', Symbol='ZFTA', Aliases=['C11orf95'], description='zinc finger translocation associated', other_designations='zinc finger translocation-associated protein|uncharacterized protein C11orf95', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63759892, end_position_on_the_genomic_accession=63768775, orientation='minus', exon_count=5, OMIM=[615699], no_hdr0=''),
    65999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=65999, CurrentID=0, Status='live', Symbol='LRRC61', Aliases=['HSPC295'], description='leucine rich repeat containing 61', other_designations='leucine-rich repeat-containing protein 61', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150309499, end_position_on_the_genomic_accession=150338156, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    66000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66000, CurrentID=0, Status='live', Symbol='TMEM108', Aliases=['CT124', 'RTLN'], description='transmembrane protein 108', other_designations='transmembrane protein 108|cancer/testis antigen 124|retrolinkin', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=133038391, end_position_on_the_genomic_accession=133397775, orientation='plus', exon_count=7, OMIM=[617361], no_hdr0=''),
    66002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66002, CurrentID=0, Status='live', Symbol='CYP4F12', Aliases=['CYPIVF12', 'F22329_1'], description='cytochrome P450 family 4 subfamily F member 12', other_designations='cytochrome P450 4F12|cytochrome P450, family 4, subfamily F, polypeptide 12|cytochrome P450, subfamily IVF, polypeptide 12', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15673023, end_position_on_the_genomic_accession=15698819, orientation='plus', exon_count=13, OMIM=[611485], no_hdr0=''),
    66004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66004, CurrentID=0, Status='live', Symbol='LYNX1', Aliases=[], description='Ly6/neurotoxin 1', other_designations='ly-6/neurotoxin-like protein 1|Ly-6 neurotoxin-like protein 1|endogenous prototoxin LYNX1|testicular tissue protein Li 112', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142771197, end_position_on_the_genomic_accession=142777872, orientation='minus', exon_count=7, OMIM=[606110], no_hdr0=''),
    66005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66005, CurrentID=0, Status='live', Symbol='CHID1', Aliases=['GL008', 'SI-CLP', 'SICLP'], description='chitinase domain containing 1', other_designations='chitinase domain-containing protein 1|stabilin-1 interacting chitinase-like protein', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=867859, end_position_on_the_genomic_accession=914845, orientation='minus', exon_count=19, OMIM=[615692], no_hdr0=''),
    66008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66008, CurrentID=0, Status='live', Symbol='TRAK2', Aliases=['ALS2CR3', 'CALS-C', 'GRIF-1', 'GRIF1', 'MILT2', 'OIP98'], description='trafficking kinesin protein 2', other_designations='trafficking kinesin-binding protein 2|O-linked N-acetylglucosamine transferase interacting protein 98|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 3|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 3 protein|gamma-aminobutyric acid(A) receptor-interacting factor|milton homolog 2|trafficking protein, kinesin binding 2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201377207, end_position_on_the_genomic_accession=201451577, orientation='minus', exon_count=17, OMIM=[607334], no_hdr0=''),
    66035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66035, CurrentID=0, Status='live', Symbol='SLC2A11', Aliases=['GLUT10', 'GLUT11'], description='solute carrier family 2 member 11', other_designations='solute carrier family 2, facilitated glucose transporter member 11|facilitative glucose transporter GLUT11|glucose transporter protein 10|glucose transporter protein 11|glucose transporter type 10|glucose transporter type 11|glucose transporter-like protein XI|solute carrier family 2 (facilitated glucose transporter), member 11', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23856934, end_position_on_the_genomic_accession=23886312, orientation='plus', exon_count=14, OMIM=[610367], no_hdr0=''),
    66036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66036, CurrentID=0, Status='live', Symbol='MTMR9', Aliases=['C8orf9', 'LIP-STYX', 'MTMR8'], description='myotubularin related protein 9', other_designations='myotubularin-related protein 9|inactive phosphatidylinositol 3-phosphatase 9|myotubularin related protein 8', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11284416, end_position_on_the_genomic_accession=11328146, orientation='plus', exon_count=13, OMIM=[606260], no_hdr0=''),
    66037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=66037, CurrentID=0, Status='live', Symbol='BOLL', Aliases=['BOULE'], description='boule homolog, RNA binding protein', other_designations='protein boule-like|bol, boule-like|boule-like RNA binding protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197726890, end_position_on_the_genomic_accession=197786312, orientation='minus', exon_count=15, OMIM=[606165], no_hdr0=''),
    78986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78986, CurrentID=0, Status='live', Symbol='DUSP26', Aliases=['DSP-4', 'DUSP24', 'LDP-4', 'LDP4', 'MKP-8', 'MKP8', 'NATA1', 'NEAP', 'SKRP3'], description='dual specificity phosphatase 26', other_designations='dual specificity protein phosphatase 26|MAP kinase phosphatase 8|Novel amplified gene in thyroid anaplastic cancer|dual specificity phosphatase 26 (putative)|dual specificity phosphatase SKRP3|low-molecular-mass dual-specificity phosphatase 4|mitogen-activated protein kinase phosphatase 8|neuroendocrine-associated phosphatase', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=33591330, end_position_on_the_genomic_accession=33600023, orientation='minus', exon_count=4, OMIM=[618368], no_hdr0=''),
    78987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78987, CurrentID=0, Status='live', Symbol='CRELD1', Aliases=['AVSD2', 'CIRRIN'], description='cysteine rich with EGF like domains 1', other_designations='protein disulfide isomerase CRELD1', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9933788, end_position_on_the_genomic_accession=9945406, orientation='plus', exon_count=11, OMIM=[607170], no_hdr0=''),
    78988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78988, CurrentID=0, Status='live', Symbol='MRPL57', Aliases=['MRP63', 'bMRP63'], description='mitochondrial ribosomal protein L57', other_designations='ribosomal protein 63, mitochondrial|hMRP63|mitochondrial large ribosomal subunit protein mL63|mitochondrial ribosomal protein 63|mitochondrial ribosomal protein bMRP63', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21176649, end_position_on_the_genomic_accession=21179084, orientation='plus', exon_count=2, OMIM=[611997], no_hdr0=''),
    78989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78989, CurrentID=0, Status='live', Symbol='COLEC11', Aliases=['3MC2', 'CL-11', 'CL-K1-I', 'CL-K1-II', 'CL-K1-IIa', 'CL-K1-IIb', 'CLK1'], description='collectin subfamily member 11', other_designations='collectin-11|Collectin K1|collectin kidney protein 1|collectin sub-family member 11', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3595112, end_position_on_the_genomic_accession=3644644, orientation='plus', exon_count=12, OMIM=[612502], no_hdr0=''),
    78990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78990, CurrentID=0, Status='live', Symbol='OTUB2', Aliases=['C14orf137', 'OTB2', 'OTU2'], description='OTU deubiquitinase, ubiquitin aldehyde binding 2', other_designations='ubiquitin thioesterase OTUB2|OTU domain, ubiquitin aldehyde binding 2|OTU domain-containing ubiquitin aldehyde-binding protein 2|deubiquitinating enzyme OTUB2|otubain-2|ubiquitin-specific protease otubain 2|ubiquitin-specific-processing protease OTUB2', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94026340, end_position_on_the_genomic_accession=94048930, orientation='plus', exon_count=6, OMIM=[608338], no_hdr0=''),
    78991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78991, CurrentID=0, Status='live', Symbol='PCYOX1L', Aliases=[], description='prenylcysteine oxidase 1 like', other_designations='prenylcysteine oxidase-like', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149358046, end_position_on_the_genomic_accession=149369653, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    78992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78992, CurrentID=0, Status='live', Symbol='YIPF2', Aliases=['FinGER2'], description='Yip1 domain family member 2', other_designations='protein YIPF2|YIP1 family member 2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10922185, end_position_on_the_genomic_accession=10928688, orientation='minus', exon_count=8, OMIM=[617522], no_hdr0=''),
    78994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78994, CurrentID=0, Status='live', Symbol='PRR14', Aliases=[], description='proline rich 14', other_designations='proline-rich protein 14', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30650778, end_position_on_the_genomic_accession=30656413, orientation='plus', exon_count=13, OMIM=[617423], no_hdr0=''),
    78995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78995, CurrentID=0, Status='live', Symbol='HROB', Aliases=['C17orf53', 'MCM8IP'], description='homologous recombination factor with OB-fold', other_designations='homologous recombination OB-fold protein|MCM8-9-Interacting Protein)|homologous recombincation factor with OB-fold|uncharacterized protein C17orf53', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44141930, end_position_on_the_genomic_accession=44162477, orientation='plus', exon_count=11, OMIM=[618611], no_hdr0=''),
    78996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78996, CurrentID=0, Status='live', Symbol='CYREN', Aliases=['C7orf49', 'MRI', 'MRI-2'], description='cell cycle regulator of NHEJ', other_designations='cell cycle regulator of non-homologous end joining|modulator of retrovirus infection homolog', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135092303, end_position_on_the_genomic_accession=135170821, orientation='minus', exon_count=7, OMIM=[616980], no_hdr0=''),
    78997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78997, CurrentID=0, Status='live', Symbol='GDAP1L1', Aliases=['dJ881L22.1', 'dJ995J12.1.1'], description='ganglioside induced differentiation associated protein 1 like 1', other_designations='ganglioside-induced differentiation-associated protein 1-like 1|GDAP1-L1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44247099, end_position_on_the_genomic_accession=44280947, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    78999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=78999, CurrentID=0, Status='live', Symbol='LRFN4', Aliases=['FIGLER6', 'SALM3', 'SALM3.'], description='leucine rich repeat and fibronectin type III domain containing 4', other_designations='leucine-rich repeat and fibronectin type-III domain-containing protein 4|fibronectin type III, immunoglobulin and leucine rich repeat domains 6', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66857064, end_position_on_the_genomic_accession=66860475, orientation='plus', exon_count=3, OMIM=[612810], no_hdr0=''),
    79000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79000, CurrentID=0, Status='live', Symbol='AUNIP', Aliases=['AIBP', 'C1orf135'], description='aurora kinase A and ninein interacting protein', other_designations='aurora kinase A and ninein-interacting protein|aurora A-binding protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25831906, end_position_on_the_genomic_accession=25859457, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79001, CurrentID=0, Status='live', Symbol='VKORC1', Aliases=['EDTP308', 'MST134', 'MST576', 'VKCFD2', 'VKOR'], description='vitamin K epoxide reductase complex subunit 1', other_designations='vitamin K epoxide reductase complex subunit 1|phylloquinone epoxide reductase|vitamin K dependent clotting factors deficiency 2|vitamin K1 2,3-epoxide reductase subunit 1|vitamin K1 epoxide reductase (warfarin-sensitive)', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31090854, end_position_on_the_genomic_accession=31094797, orientation='minus', exon_count=4, OMIM=[608547], no_hdr0=''),
    79002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79002, CurrentID=0, Status='live', Symbol='TRIR', Aliases=['C19orf43', 'TERCIR', 'fSAP18'], description='telomerase RNA component interacting RNase', other_designations='telomerase RNA component interacting RNase|My029 protein|exoribonuclease TRIR|uncharacterized protein C19orf43', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12730640, end_position_on_the_genomic_accession=12734684, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    79003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79003, CurrentID=0, Status='live', Symbol='MIS12', Aliases=['2510025F08Rik', 'KNTC2AP', 'MTW1', 'hMis12'], description='MIS12 kinetochore complex component', other_designations='protein MIS12 homolog|MIS12 homolog|MIS12, MIND kinetochore complex component, homolog|homolog of yeast Mis12', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5486374, end_position_on_the_genomic_accession=5490814, orientation='plus', exon_count=5, OMIM=[609178], no_hdr0=''),
    79004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79004, CurrentID=0, Status='live', Symbol='CUEDC2', Aliases=['C10orf66', 'bA18I14.5'], description='CUE domain containing 2', other_designations='CUE domain-containing protein 2', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102423249, end_position_on_the_genomic_accession=102432574, orientation='minus', exon_count=9, OMIM=[614142], no_hdr0=''),
    79005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79005, CurrentID=0, Status='live', Symbol='SCNM1', Aliases=[], description='sodium channel modifier 1', other_designations='sodium channel modifier 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151166144, end_position_on_the_genomic_accession=151170296, orientation='plus', exon_count=7, OMIM=[608095], no_hdr0=''),
    79006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79006, CurrentID=0, Status='live', Symbol='METRN', Aliases=['C16orf23', 'c380A1.2'], description='meteorin, glial cell differentiation regulator', other_designations='meteorin', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=715118, end_position_on_the_genomic_accession=719655, orientation='plus', exon_count=4, OMIM=[610998], no_hdr0=''),
    79007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79007, CurrentID=0, Status='live', Symbol='DBNDD1', Aliases=[], description='dysbindin domain containing 1', other_designations='dysbindin domain-containing protein 1|dysbindin (dystrobrevin binding protein 1) domain containing 1', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=90004871, end_position_on_the_genomic_accession=90019890, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    79008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79008, CurrentID=0, Status='live', Symbol='SLX1B', Aliases=['GIYD2'], description='SLX1 homolog B, structure-specific endonuclease subunit', other_designations='structure-specific endonuclease subunit SLX1|GIY-YIG domain-containing protein 1|SLX1 structure-specific endonuclease subunit homolog B', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29454501, end_position_on_the_genomic_accession=29458219, orientation='plus', exon_count=6, OMIM=[615823], no_hdr0=''),
    79009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79009, CurrentID=0, Status='live', Symbol='DDX50', Aliases=['GU2', 'GUB', 'RH-II/GuB', 'mcdrh'], description='DExD-box helicase 50', other_designations='ATP-dependent RNA helicase DDX50|DEAD (Asp-Glu-Ala-Asp) box polypeptide 50|DEAD box protein 50|DEAD-box helicase 50|RNA helicase II/Gu beta|gu-beta|malignant cell derived RNA helicase|nucleolar protein GU2', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68898817, end_position_on_the_genomic_accession=68956312, orientation='plus', exon_count=20, OMIM=[610373], no_hdr0=''),
    79012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79012, CurrentID=0, Status='live', Symbol='CAMKV', Aliases=['1G5', 'VACAMKL'], description='CaM kinase like vesicle associated', other_designations='caM kinase-like vesicle-associated protein|testis tissue sperm-binding protein Li 52e|vesicle-associated calmodulin-binding protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49857989, end_position_on_the_genomic_accession=49869906, orientation='minus', exon_count=11, OMIM=[614993], no_hdr0=''),
    79016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79016, CurrentID=0, Status='live', Symbol='DDA1', Aliases=['C19orf58', 'PCIA1'], description='DET1 and DDB1 associated 1', other_designations='DET1- and DDB1-associated protein 1|cross-immune reaction antigen PCIA1|placenta cross-immune reaction antigen 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17309563, end_position_on_the_genomic_accession=17323301, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79017, CurrentID=0, Status='live', Symbol='GGCT', Aliases=['C7orf24', 'CRF21', 'GCTG', 'GGC'], description='gamma-glutamylcyclotransferase', other_designations='gamma-glutamylcyclotransferase|cytochrome c-releasing factor 21|gamma -glutamyl cyclotransferase', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30496621, end_position_on_the_genomic_accession=30504829, orientation='minus', exon_count=5, OMIM=[137170], no_hdr0=''),
    79018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79018, CurrentID=0, Status='live', Symbol='GID4', Aliases=['C17orf39', 'VID2', 'VID24'], description='GID complex subunit 4 homolog', other_designations='glucose-induced degradation protein 4 homolog|GID complex subunit 4, VID24 homolog|vacuolar import and degradation 24|vacuolar import and degradation protein 24 homolog', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18039408, end_position_on_the_genomic_accession=18068405, orientation='plus', exon_count=8, OMIM=[617699], no_hdr0=''),
    79019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79019, CurrentID=0, Status='live', Symbol='CENPM', Aliases=['C22orf18', 'CENP-M', 'PANE1'], description='centromere protein M', other_designations='centromere protein M|interphase centromere complex protein 39|proliferation-associated nuclear element protein 1', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41927747, end_position_on_the_genomic_accession=41947152, orientation='minus', exon_count=9, OMIM=[610152], no_hdr0=''),
    79020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79020, CurrentID=0, Status='live', Symbol='C7orf25', Aliases=[], description='chromosome 7 open reading frame 25', other_designations='UPF0415 protein C7orf25', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=42909273, end_position_on_the_genomic_accession=42914356, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79022, CurrentID=0, Status='live', Symbol='TMEM106C', Aliases=[], description='transmembrane protein 106C', other_designations='transmembrane protein 106C|endoplasmic reticulum membrane protein overexpressed in cancer', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47963596, end_position_on_the_genomic_accession=47968878, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    79023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79023, CurrentID=0, Status='live', Symbol='NUP37', Aliases=['MCPH24', 'p37'], description='nucleoporin 37', other_designations='nucleoporin Nup37|nucleoporin 37kDa|nup107-160 subcomplex subunit Nup37', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=102073103, end_position_on_the_genomic_accession=102120131, orientation='minus', exon_count=11, OMIM=[609264], no_hdr0=''),
    79024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79024, CurrentID=0, Status='live', Symbol='SMIM2', Aliases=['C13orf44'], description='small integral membrane protein 2', other_designations='small integral membrane protein 2', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=44143150, end_position_on_the_genomic_accession=44161257, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    79025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79025, CurrentID=0, Status='live', Symbol='FNDC11', Aliases=['C20orf195'], description='fibronectin type III domain containing 11', other_designations='fibronectin type III domain-containing protein 11', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63553020, end_position_on_the_genomic_accession=63556712, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79026, CurrentID=0, Status='live', Symbol='AHNAK', Aliases=['AHNAKRS', 'PM227'], description='AHNAK nucleoprotein', other_designations='neuroblast differentiation-associated protein AHNAK|AHNAK-related|desmoyokin', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62433544, end_position_on_the_genomic_accession=62546806, orientation='minus', exon_count=9, OMIM=[103390], no_hdr0=''),
    79027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79027, CurrentID=0, Status='live', Symbol='ZNF655', Aliases=['VIK', 'VIK-1'], description='zinc finger protein 655', other_designations='zinc finger protein 655|vav-1 interacting Kruppel-like protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99558544, end_position_on_the_genomic_accession=99576453, orientation='plus', exon_count=8, OMIM=[617891], no_hdr0=''),
    79029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79029, CurrentID=0, Status='live', Symbol='SPATA5L1', Aliases=[], description='spermatogenesis associated 5 like 1', other_designations='spermatogenesis-associated protein 5-like protein 1', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45402336, end_position_on_the_genomic_accession=45421415, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    79031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79031, CurrentID=0, Status='live', Symbol='PDCL3', Aliases=['HTPHLP', 'PHLP2A', 'PHLP3', 'VIAF', 'VIAF1'], description='phosducin like 3', other_designations='phosducin-like protein 3|IAP-associated factor VIAF1|VIAF-1|phPL3|viral IAP-associated factor 1', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=100562993, end_position_on_the_genomic_accession=100577472, orientation='plus', exon_count=7, OMIM=[611678], no_hdr0=''),
    79033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79033, CurrentID=0, Status='live', Symbol='ERI3', Aliases=['PINT1', 'PRNPIP'], description='ERI1 exoribonuclease family member 3', other_designations='ERI1 exoribonuclease 3|enhanced RNAi three prime mRNA exonuclease homolog 3|prion interactor 1|prion protein-interacting protein', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44221070, end_position_on_the_genomic_accession=44355298, orientation='minus', exon_count=10, OMIM=[609917], no_hdr0=''),
    79034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79034, CurrentID=0, Status='live', Symbol='C7orf26', Aliases=[], description='chromosome 7 open reading frame 26', other_designations='uncharacterized protein C7orf26', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6590021, end_position_on_the_genomic_accession=6608726, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    79035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79035, CurrentID=0, Status='live', Symbol='NABP2', Aliases=['OBFC2B', 'SOSS-B1', 'SSB1', 'hSSB1'], description='nucleic acid binding protein 2', other_designations='SOSS complex subunit B1|LP3587|oligonucleotide/oligosaccharide-binding fold containing 2B|oligonucleotide/oligosaccharide-binding fold-containing protein 2B|sensor of single-strand DNA complex subunit B1|sensor of ssDNA subunit B1|single strand DNA-binding protein 1|single-stranded DNA-binding protein 1', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56222012, end_position_on_the_genomic_accession=56229858, orientation='plus', exon_count=9, OMIM=[612104], no_hdr0=''),
    79036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79036, CurrentID=0, Status='live', Symbol='KXD1', Aliases=['BORCS4', 'C10orf50', 'C19orf50', 'KXDL', 'MST096', 'MSTP096'], description='KxDL motif containing 1', other_designations='kxDL motif-containing protein 1|BLOC-1 related complex subunit 4|UPF0459 protein C19orf50', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18557762, end_position_on_the_genomic_accession=18569381, orientation='plus', exon_count=8, OMIM=[615178], no_hdr0=''),
    79037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79037, CurrentID=0, Status='live', Symbol='PVRIG', Aliases=['C7orf15', 'CD112R'], description='PVR related immunoglobulin domain containing', other_designations='transmembrane protein PVRIG|CD112 receptor|nectin-2 receptor|poliovirus receptor related immunoglobulin domain containing|poliovirus receptor-related immunoglobulin domain-containing protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100218625, end_position_on_the_genomic_accession=100221490, orientation='plus', exon_count=7, OMIM=[617012], no_hdr0=''),
    79038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79038, CurrentID=0, Status='live', Symbol='ZFYVE21', Aliases=['HCVP7TP1', 'ZF21'], description='zinc finger FYVE-type containing 21', other_designations='zinc finger FYVE domain-containing protein 21|FYVE domain containing 21|HCV p7-transactivated protein 1|zinc finger, FYVE domain containing 21', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103715810, end_position_on_the_genomic_accession=103733664, orientation='plus', exon_count=8, OMIM=[613504], no_hdr0=''),
    79039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79039, CurrentID=0, Status='live', Symbol='DDX54', Aliases=['DP97'], description='DEAD-box helicase 54', other_designations='ATP-dependent RNA helicase DDX54|ATP-dependent RNA helicase DP97|DEAD (Asp-Glu-Ala-Asp) box polypeptide 54|DEAD box RNA helicase 97 kDa|DEAD box helicase 97 KDa|DEAD box protein 54', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113157173, end_position_on_the_genomic_accession=113185478, orientation='minus', exon_count=20, OMIM=[611665], no_hdr0=''),
    79041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79041, CurrentID=0, Status='live', Symbol='TMEM38A', Aliases=['TRIC-A', 'TRICA'], description='transmembrane protein 38A', other_designations='trimeric intracellular cation channel type A', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16661139, end_position_on_the_genomic_accession=16690023, orientation='plus', exon_count=6, OMIM=[611235], no_hdr0=''),
    79042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79042, CurrentID=0, Status='live', Symbol='TSEN34', Aliases=['LENG5', 'PCH2C', 'SEN34', 'SEN34L'], description='tRNA splicing endonuclease subunit 34', other_designations='tRNA-splicing endonuclease subunit Sen34|CTD-3093M3.1|TSEN34 tRNA splicing endonuclease subunit|leukocyte receptor cluster (LRC) member 5|leukocyte receptor cluster member 5|tRNA-intron endonuclease Sen34', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54189970, end_position_on_the_genomic_accession=54194532, orientation='plus', exon_count=7, OMIM=[608754], no_hdr0=''),
    79047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79047, CurrentID=0, Status='live', Symbol='KCTD15', Aliases=[], description='potassium channel tetramerization domain containing 15', other_designations='BTB/POZ domain-containing protein KCTD15|potassium channel tetramerisation domain containing 15|potassium channel tetramerization domain-containing protein 15', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33795540, end_position_on_the_genomic_accession=33815761, orientation='plus', exon_count=11, OMIM=[615240], no_hdr0=''),
    79048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79048, CurrentID=0, Status='live', Symbol='SECISBP2', Aliases=['SBP2'], description='SECIS binding protein 2', other_designations='selenocysteine insertion sequence-binding protein 2|Sec insertion sequence-binding protein 2', map_location='9q22.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=89318500, end_position_on_the_genomic_accession=89367117, orientation='plus', exon_count=22, OMIM=[607693], no_hdr0=''),
    79050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79050, CurrentID=0, Status='live', Symbol='NOC4L', Aliases=['NET49', 'NOC4', 'UTP19'], description='nucleolar complex associated 4 homolog', other_designations='nucleolar complex protein 4 homolog|NOC4 protein homolog|NOC4-like protein|nucleolar complex-associated protein 4-like protein', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132144421, end_position_on_the_genomic_accession=132152468, orientation='plus', exon_count=15, OMIM=[612819], no_hdr0=''),
    79053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79053, CurrentID=0, Status='live', Symbol='ALG8', Aliases=['CDG1H', 'PCLD3'], description='ALG8 alpha-1,3-glucosyltransferase', other_designations='probable dolichyl pyrophosphate Glc1Man9GlcNAc2 alpha-1,3-glucosyltransferase|HUSSY-02|asparagine-linked glycosylation 8 alpha-13-glucosyltransferase-like protein|asparagine-linked glycosylation 8 homolog (S. cerevisiae, alpha-1,3-glucosyltransferase)|asparagine-linked glycosylation 8 homolog (yeast, alpha-1,3-glucosyltransferase)|asparagine-linked glycosylation 8, alpha-1,3-glucosyltransferase homolog|asparagine-linked glycosylation protein 8 homolog|dol-P-Glc:Glc(1)Man(9)GlcNAc(2)-PP-dolichyl alpha-1,3-glucosyltransferase|dolichyl pyrophosphate Glc1Man9GlcNAc2 alpha-1,3-glucosyltransferase|dolichyl-P-Glc:Glc(1)Man(9)GlcNAc(2)-PP-dolichol alpha- 1->3-glucosyltransferase|dolichyl-P-Glc:Glc1Man9GlcNAc2-PP-dolichyl glucosyltransferase|dolichyl-P-glucose:Glc1Man9GlcNAc2-PP-dolichyl-alpha-1,3-glucosyltransferase', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78100946, end_position_on_the_genomic_accession=78139643, orientation='minus', exon_count=14, OMIM=[608103], no_hdr0=''),
    79054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79054, CurrentID=0, Status='live', Symbol='TRPM8', Aliases=['LTRPC6', 'LTrpC-6', 'TRPP8', 'trp-p8'], description='transient receptor potential cation channel subfamily M member 8', other_designations='transient receptor potential cation channel subfamily M member 8|TRPM8 cationic channel|transient receptor potential p8|transient receptor potential subfamily M member 8', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233917342, end_position_on_the_genomic_accession=234019522, orientation='plus', exon_count=28, OMIM=[606678], no_hdr0=''),
    79056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79056, CurrentID=0, Status='live', Symbol='PRRG4', Aliases=['PRGP4', 'TMG4'], description='proline rich and Gla domain 4', other_designations='transmembrane gamma-carboxyglutamic acid protein 4|proline rich Gla (G-carboxyglutamic acid) 4 (transmembrane)|proline-rich Gla protein 4|proline-rich gamma-carboxyglutamic acid protein 4', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32829756, end_position_on_the_genomic_accession=32858120, orientation='plus', exon_count=6, OMIM=[611690], no_hdr0=''),
    79057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79057, CurrentID=0, Status='live', Symbol='PRRG3', Aliases=['PRGP3', 'TMG3'], description='proline rich and Gla domain 3', other_designations='transmembrane gamma-carboxyglutamic acid protein 3|proline rich Gla (G-carboxyglutamic acid) 3 (transmembrane)|proline-rich Gla protein 3|proline-rich gamma-carboxyglutamic acid protein 3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151694606, end_position_on_the_genomic_accession=151705924, orientation='plus', exon_count=7, OMIM=[300685], no_hdr0=''),
    79058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79058, CurrentID=0, Status='live', Symbol='ASPSCR1', Aliases=['ASPCR1', 'ASPL', 'ASPS', 'RCC17', 'TUG', 'UBXD9', 'UBXN9'], description='ASPSCR1 tether for SLC2A4, UBX domain containing', other_designations='tether containing UBX domain for GLUT4|ASPSCR1, UBX domain containing tether for SLC2A4|UBX domain protein 9|UBX domain-containing protein 9|alveolar soft part sarcoma chromosomal region candidate gene 1 protein|alveolar soft part sarcoma chromosome region, candidate 1|alveolar soft part sarcoma locus|renal cell carcinoma gene on chromosome 17|renal cell carcinoma, papillary, 17|renal papillary cell carcinoma protein 17', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81977550, end_position_on_the_genomic_accession=82017669, orientation='plus', exon_count=19, OMIM=[606236], no_hdr0=''),
    79064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79064, CurrentID=0, Status='live', Symbol='TMEM223', Aliases=[], description='transmembrane protein 223', other_designations='transmembrane protein 223', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62789971, end_position_on_the_genomic_accession=62792006, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79065, CurrentID=0, Status='live', Symbol='ATG9A', Aliases=['APG9L1', 'MGD3208', 'mATG9'], description='autophagy related 9A', other_designations='autophagy-related protein 9A|APG9 autophagy 9-like 1|APG9-like 1|ATG9 autophagy related 9 homolog A|autophagy 9-like 1 protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219219380, end_position_on_the_genomic_accession=219229636, orientation='minus', exon_count=16, OMIM=[612204], no_hdr0=''),
    79066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79066, CurrentID=0, Status='live', Symbol='METTL16', Aliases=['METT10D'], description='methyltransferase 16, N6-methyladenosine', other_designations='RNA N6-adenosine-methyltransferase METTL16|N6-adenosine-methyltransferase METTL16|U6 small nuclear RNA (adenine-(43)-N(6))-methyltransferase|U6 snRNA methyltransferase|methyltransferase 10 domain containing|methyltransferase 10 domain-containing protein|methyltransferase like 16|methyltransferase-like protein 16|putative methyltransferase METT10D', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2416049, end_position_on_the_genomic_accession=2511901, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    79068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79068, CurrentID=0, Status='live', Symbol='FTO', Aliases=['ALKBH9', 'BMIQ14', 'GDFD'], description='FTO alpha-ketoglutarate dependent dioxygenase', other_designations="alpha-ketoglutarate-dependent dioxygenase FTO|AlkB homolog 9|U6 small nuclear RNA (2'-O-methyladenosine-N(6)-)-demethylase FTO|U6 small nuclear RNA N(6)-methyladenosine-demethylase FTO|fat mass and obesity associated|fat mass and obesity-associated protein|m6A(m)-demethylase FTO|mRNA (2'-O-methyladenosine-N(6)-)-demethylase FTO|mRNA N(6)-methyladenosine demethylase FTO|tRNA N1-methyl adenine demethylase FTO", map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53703963, end_position_on_the_genomic_accession=54121941, orientation='plus', exon_count=16, OMIM=[610966], no_hdr0=''),
    79070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79070, CurrentID=0, Status='live', Symbol='POGLUT2', Aliases=['EP58', 'ERp58', 'KDEL1', 'KDELC1'], description='protein O-glucosyltransferase 2', other_designations='protein O-glucosyltransferase 2|ER protein 58|KDEL (Lys-Asp-Glu-Leu) containing 1|KDEL motif containing 1|KDEL motif-containing protein 1|endoplasmic reticulum resident protein 58|protein O-xylosyltransferase POGLUT2', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102784281, end_position_on_the_genomic_accession=102799009, orientation='minus', exon_count=11, OMIM=[611613], no_hdr0=''),
    79071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79071, CurrentID=0, Status='live', Symbol='ELOVL6', Aliases=['FACE', 'FAE', 'LCE'], description='ELOVL fatty acid elongase 6', other_designations='elongation of very long chain fatty acids protein 6|3-keto acyl-CoA synthase ELOVL6|ELOVL FA elongase 6|ELOVL family member 6, elongation of long chain fatty acids (FEN1/Elo2, SUR4/Elo3-like, yeast)|fatty acid elongase 2|fatty acyl-CoA elongase|hELO2|long-chain fatty-acyl elongase|very long chain 3-ketoacyl-CoA synthase 6|very long chain 3-oxoacyl-CoA synthase 6', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=110045846, end_position_on_the_genomic_accession=110199199, orientation='minus', exon_count=6, OMIM=[611546], no_hdr0=''),
    79072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79072, CurrentID=0, Status='live', Symbol='FASTKD3', Aliases=[], description='FAST kinase domains 3', other_designations='FAST kinase domain-containing protein 3, mitochondrial', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=7859159, end_position_on_the_genomic_accession=7869037, orientation='minus', exon_count=7, OMIM=[617530], no_hdr0=''),
    79073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79073, CurrentID=0, Status='live', Symbol='TMEM109', Aliases=[], description='transmembrane protein 109', other_designations='transmembrane protein 109|mg23|mitsugumin-23', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60914158, end_position_on_the_genomic_accession=60923443, orientation='plus', exon_count=4, OMIM=[619168], no_hdr0=''),
    79074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79074, CurrentID=0, Status='live', Symbol='C2orf49', Aliases=['asw'], description='chromosome 2 open reading frame 49', other_designations='ashwin', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=105337365, end_position_on_the_genomic_accession=105359940, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    79075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79075, CurrentID=0, Status='live', Symbol='DSCC1', Aliases=['DCC1'], description='DNA replication and sister chromatid cohesion 1', other_designations='sister chromatid cohesion protein DCC1|defective in sister chromatid cohesion 1 homolog|defective in sister chromatid cohesion protein 1 homolog', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119833960, end_position_on_the_genomic_accession=119855920, orientation='minus', exon_count=9, OMIM=[613203], no_hdr0=''),
    79077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79077, CurrentID=0, Status='live', Symbol='DCTPP1', Aliases=['CDA03', 'RS21C6', 'XTP3TPA'], description='dCTP pyrophosphatase 1', other_designations='dCTP pyrophosphatase 1|XTP3-transactivated gene A protein|XTP3-transactivated protein A|dCTPase 1|deoxycytidine-triphosphatase 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30423615, end_position_on_the_genomic_accession=30430030, orientation='minus', exon_count=4, OMIM=[615840], no_hdr0=''),
    79078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79078, CurrentID=0, Status='live', Symbol='C1orf50', Aliases=[], description='chromosome 1 open reading frame 50', other_designations='uncharacterized protein C1orf50', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42767249, end_position_on_the_genomic_accession=42779491, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79080, CurrentID=0, Status='live', Symbol='CCDC86', Aliases=[], description='coiled-coil domain containing 86', other_designations='coiled-coil domain-containing protein 86|cyclon|cytokine-induced protein with coiled-coil domain', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60842113, end_position_on_the_genomic_accession=60851081, orientation='plus', exon_count=4, OMIM=[611293], no_hdr0=''),
    79081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79081, CurrentID=0, Status='live', Symbol='LBHD1', Aliases=['C11orf48'], description='LBH domain containing 1', other_designations='LBH domain-containing protein 1', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62662817, end_position_on_the_genomic_accession=62672267, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79083, CurrentID=0, Status='live', Symbol='MLPH', Aliases=['SLAC2-A'], description='melanophilin', other_designations='melanophilin|exophilin-3|slp homolog lacking C2 domains a|synaptotagmin-like protein 2a', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237486410, end_position_on_the_genomic_accession=237555322, orientation='plus', exon_count=20, OMIM=[606526], no_hdr0=''),
    79084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79084, CurrentID=0, Status='live', Symbol='WDR77', Aliases=['HKMT1069', 'MEP-50', 'MEP50', 'Nbla10071', 'p44', 'p44/Mep50'], description='WD repeat domain 77', other_designations='methylosome protein 50|WD repeat-containing protein 77|androgen receptor cofactor p44|testis tissue sperm-binding protein Li 44a', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111439890, end_position_on_the_genomic_accession=111449256, orientation='minus', exon_count=10, OMIM=[611734], no_hdr0=''),
    79085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79085, CurrentID=0, Status='live', Symbol='SLC25A23', Aliases=['APC2', 'MCSC2', 'SCaMC-3'], description='solute carrier family 25 member 23', other_designations='calcium-binding mitochondrial carrier protein SCaMC-3|mitochondrial ATP-Mg/Pi carrier protein 2|mitochondrial Ca(2+)-dependent solute carrier protein 2|mitochondrial Ca2+-dependent solute carrier protein 2|short calcium-binding mitochondrial carrier 3|small calcium-binding mitochondrial carrier protein 3|solute carrier family 25 (mitochondrial carrier; phosphate carrier), member 23', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6436081, end_position_on_the_genomic_accession=6459792, orientation='minus', exon_count=14, OMIM=[608746], no_hdr0=''),
    79086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79086, CurrentID=0, Status='live', Symbol='SMIM7', Aliases=['C19orf42'], description='small integral membrane protein 7', other_designations='small integral membrane protein 7|UPF0608 protein C19orf42', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16630741, end_position_on_the_genomic_accession=16660144, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79087, CurrentID=0, Status='live', Symbol='ALG12', Aliases=['CDG1G', 'ECM39', 'PP14673', 'hALG12'], description='ALG12 alpha-1,6-mannosyltransferase', other_designations='dol-P-Man:Man(7)GlcNAc(2)-PP-Dol alpha-1,6-mannosyltransferase|asparagine-linked glycosylation 12 homolog (S. cerevisiae, alpha-1,6-mannosyltransferase)|asparagine-linked glycosylation 12 homolog (yeast, alpha-1,6-mannosyltransferase)|asparagine-linked glycosylation 12, alpha-1,6-mannosyltransferase homolog|asparagine-linked glycosylation protein 12 homolog|dol-P-Man dependent alpha-1,6-mannosyltransferase|dolichyl-P-Man:Man(7)GlcNAc(2)-PP-dolichol alpha-1,6-mannosyltransferase|dolichyl-P-Man:Man(7)GlcNAc(2)-PP-dolichyl-alpha-1,6-mannosyltransferase|dolichyl-P-mannose:Man-7-GlcNAc-2-PP-dolichyl-alpha-6-mannosyltransferase|mannosyltransferase ALG12 homolog|membrane protein SB87', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49860163, end_position_on_the_genomic_accession=49918469, orientation='minus', exon_count=12, OMIM=[607144], no_hdr0=''),
    79088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79088, CurrentID=0, Status='live', Symbol='ZNF426', Aliases=['K-RBP'], description='zinc finger protein 426', other_designations='zinc finger protein 426|CTC-543D15.7|KSHV RTA binding protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9523223, end_position_on_the_genomic_accession=9538865, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79089, CurrentID=0, Status='live', Symbol='TMUB2', Aliases=['FP2653'], description='transmembrane and ubiquitin like domain containing 2', other_designations='transmembrane and ubiquitin-like domain-containing protein 2', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44186972, end_position_on_the_genomic_accession=44191929, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79090, CurrentID=0, Status='live', Symbol='TRAPPC6A', Aliases=['TRS33'], description='trafficking protein particle complex subunit 6A', other_designations='trafficking protein particle complex subunit 6A|TRAPP complex subunit 6A|trafficking protein particle complex 6A', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45162933, end_position_on_the_genomic_accession=45179266, orientation='minus', exon_count=6, OMIM=[610396], no_hdr0=''),
    79091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79091, CurrentID=0, Status='live', Symbol='METTL22', Aliases=['C16orf68'], description='methyltransferase 22, Kin17 lysine', other_designations='methyltransferase-like protein 22|LP8272|methyltransferase like 22', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8621670, end_position_on_the_genomic_accession=8673565, orientation='plus', exon_count=18, OMIM=[615261], no_hdr0=''),
    79092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79092, CurrentID=0, Status='live', Symbol='CARD14', Aliases=['BIMP2', 'CARMA2', 'PRP', 'PSORS2', 'PSS1'], description='caspase recruitment domain family member 14', other_designations='caspase recruitment domain-containing protein 14|CARD-containing MAGUK protein 2|bcl10-interacting maguk protein 2', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80169992, end_position_on_the_genomic_accession=80209331, orientation='plus', exon_count=26, OMIM=[607211], no_hdr0=''),
    79094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79094, CurrentID=0, Status='live', Symbol='CHAC1', Aliases=[], description='ChaC glutathione specific gamma-glutamylcyclotransferase 1', other_designations='glutathione-specific gamma-glutamylcyclotransferase 1|ChaC, cation transport regulator homolog 1|ChaC, cation transport regulator-like 1|blocks Notch protein|botch|gamma-GCG 1|gamma-GCT acting on glutathione homolog 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40942137, end_position_on_the_genomic_accession=40956518, orientation='plus', exon_count=4, OMIM=[614587], no_hdr0=''),
    79095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79095, CurrentID=0, Status='live', Symbol='BBLN', Aliases=['C9orf16', 'EST00098'], description='bublin coiled coil protein', other_designations='bublin coiled-coil protein|UPF0184 protein C9orf16', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128159425, end_position_on_the_genomic_accession=128163926, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    79096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79096, CurrentID=0, Status='live', Symbol='C11orf49', Aliases=[], description='chromosome 11 open reading frame 49', other_designations='UPF0705 protein C11orf49', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46936524, end_position_on_the_genomic_accession=47164385, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    79097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79097, CurrentID=0, Status='live', Symbol='TRIM48', Aliases=['RNF101'], description='tripartite motif containing 48', other_designations='tripartite motif-containing protein 48|RING finger protein 101', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55262155, end_position_on_the_genomic_accession=55271114, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79098, CurrentID=0, Status='live', Symbol='C1orf116', Aliases=['SARG'], description='chromosome 1 open reading frame 116', other_designations='specifically androgen-regulated gene protein|specifically androgen-regulated protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=207018521, end_position_on_the_genomic_accession=207032761, orientation='minus', exon_count=5, OMIM=[611680], no_hdr0=''),
    79101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79101, CurrentID=0, Status='live', Symbol='TAF1D', Aliases=['JOSD3', 'RAFI41', 'TAF(I)41', 'TAFI41'], description='TATA-box binding protein associated factor, RNA polymerase I subunit D', other_designations='TATA box-binding protein-associated factor RNA polymerase I subunit D|Josephin domain containing 3|RNA polymerase I-specific TBP-associated factor 41 kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase I, D, 41kDa|TATA box-binding protein-associated factor 1D|TATA-box binding protein associated factor, RNA polymerase I, D|TBP-associated factor 1D|transcription initiation factor SL1/TIF-IB subunit D', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93730194, end_position_on_the_genomic_accession=93741495, orientation='minus', exon_count=14, OMIM=[612823], no_hdr0=''),
    79102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79102, CurrentID=0, Status='live', Symbol='RNF26', Aliases=[], description='ring finger protein 26', other_designations='E3 ubiquitin-protein ligase RNF26|ring finger protein with leucine zipper', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119334527, end_position_on_the_genomic_accession=119337309, orientation='plus', exon_count=1, OMIM=[606130], no_hdr0=''),
    79109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79109, CurrentID=0, Status='live', Symbol='MAPKAP1', Aliases=['JC310', 'MIP1', 'SIN1', 'SIN1b', 'SIN1g'], description='MAPK associated protein 1', other_designations='target of rapamycin complex 2 subunit MAPKAP1|MEKK2-interacting protein 1|SAPK-interacting protein 1|TORC2 subunit MAPKAP1|mSIN1|mitogen-activated protein kinase 2-associated protein 1|mitogen-activated protein kinase associated protein 1|ras inhibitor MGC2745|stress-activated map kinase interacting protein 1|stress-activated protein kinase-interacting 1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=125437394, end_position_on_the_genomic_accession=125707208, orientation='minus', exon_count=13, OMIM=[610558], no_hdr0=''),
    79132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79132, CurrentID=0, Status='live', Symbol='DHX58', Aliases=['D11LGP2', 'D11lgp2e', 'LGP2', 'RLR-3'], description='DExH-box helicase 58', other_designations='probable ATP-dependent RNA helicase DHX58|DEXH (Asp-Glu-X-His) box polypeptide 58|RIG-I-like receptor 3|RIG-I-like receptor LGP2|RLR|RNA helicase LGP2|ortholog of mouse D11lgp2|probable ATP-dependent helicase LGP2|protein D11Lgp2 homolog', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42101404, end_position_on_the_genomic_accession=42112721, orientation='minus', exon_count=14, OMIM=[608588], no_hdr0=''),
    79133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79133, CurrentID=0, Status='live', Symbol='NDUFAF5', Aliases=['C20orf7', 'MC1DN16', 'bA526K24.2', 'dJ842G6.1'], description='NADH:ubiquinone oxidoreductase complex assembly factor 5', other_designations='arginine-hydroxylase NDUFAF5, mitochondrial|NADH dehydrogenase (ubiquinone) complex I, assembly factor 5|NADH dehydrogenase [ubiquinone] 1 alpha subcomplex assembly factor 5|probable methyltransferase C20orf7, mitochondrial|putative methyltransferase NDUFAF5', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13785026, end_position_on_the_genomic_accession=13821580, orientation='plus', exon_count=14, OMIM=[612360], no_hdr0=''),
    79134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79134, CurrentID=0, Status='live', Symbol='TMEM185B', Aliases=['FAM11B'], description='transmembrane protein 185B', other_designations='transmembrane protein 185B|ee3_2|family with sequence similarity 11, member B|putative transmembrane protein 185B|transmembrane protein 185B (pseudogene)', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120217479, end_position_on_the_genomic_accession=120223400, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79135, CurrentID=0, Status='live', Symbol='APOO', Aliases=['FAM121B', 'MIC26', 'MICOS26', 'Mic23', 'My025'], description='apolipoprotein O', other_designations='MICOS complex subunit MIC26|MICOS complex subunit MIC23|brain my025|family with sequence similarity 121B|mitochondrial contact site and cristae organizing system subunit 26', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23833348, end_position_on_the_genomic_accession=23907938, orientation='minus', exon_count=11, OMIM=[300753], no_hdr0=''),
    79137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79137, CurrentID=0, Status='live', Symbol='RETREG2', Aliases=['C2orf17', 'FAM134A', 'MAG-2'], description='reticulophagy regulator family member 2', other_designations='reticulophagy regulator 2|family with sequence similarity 134 member A|metastasis associated gene-2|protein FAM134A', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219178227, end_position_on_the_genomic_accession=219185475, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    79139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79139, CurrentID=0, Status='live', Symbol='DERL1', Aliases=['DER-1', 'DER1', 'derlin-1'], description='derlin 1', other_designations='derlin-1|DERtrin-1|Der1-like domain family, member 1|degradation in endoplasmic reticulum protein 1', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123013170, end_position_on_the_genomic_accession=123042302, orientation='minus', exon_count=9, OMIM=[608813], no_hdr0=''),
    79140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79140, CurrentID=0, Status='live', Symbol='CCDC28B', Aliases=[], description='coiled-coil domain containing 28B', other_designations='coiled-coil domain-containing protein 28B', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32200595, end_position_on_the_genomic_accession=32205387, orientation='plus', exon_count=6, OMIM=[610162], no_hdr0=''),
    79142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79142, CurrentID=0, Status='live', Symbol='PHF23', Aliases=['hJUNE-1b'], description='PHD finger protein 23', other_designations='PHD finger protein 23|PDH-containing protein JUNE-1|PHD finger protein 23a', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7235032, end_position_on_the_genomic_accession=7239656, orientation='minus', exon_count=9, OMIM=[612910], no_hdr0=''),
    79143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79143, CurrentID=0, Status='live', Symbol='MBOAT7', Aliases=['BB1', 'LENG4', 'LPIAT', 'LPLAT', 'LRC4', 'MBOA7', 'MRT57', 'OACT7', 'hMBOA-7'], description='membrane bound O-acyltransferase domain containing 7', other_designations='lysophospholipid acyltransferase 7|1-acylglycerophosphatidylinositol O-acyltransferase|LPLAT 7|bladder and breast carcinoma-overexpressed gene 1 protein|h-mboa-7|leukocyte receptor cluster (LRC) member 4|lyso-PI acyltransferase|lysophosphatidylinositol acyltransferase|malignant cell expression-enhanced gene/tumor progression-enhanced', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54173414, end_position_on_the_genomic_accession=54189632, orientation='minus', exon_count=9, OMIM=[606048], no_hdr0=''),
    79144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79144, CurrentID=0, Status='live', Symbol='PPDPF', Aliases=['C20orf149', 'dJ697K14.9', 'exdpf'], description='pancreatic progenitor cell differentiation and proliferation factor', other_designations='pancreatic progenitor cell differentiation and proliferation factor|exocrine differentiation and proliferation factor|pancreatic progenitor cell differentiation and proliferation factor homolog', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63520741, end_position_on_the_genomic_accession=63522206, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    79145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79145, CurrentID=0, Status='live', Symbol='CHCHD7', Aliases=['COX23'], description='coiled-coil-helix-coiled-coil-helix domain containing 7', other_designations='coiled-coil-helix-coiled-coil-helix domain-containing protein 7|COX23 cytochrome c oxidase assembly homolog', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56211789, end_position_on_the_genomic_accession=56218809, orientation='plus', exon_count=6, OMIM=[611238], no_hdr0=''),
    79147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79147, CurrentID=0, Status='live', Symbol='FKRP', Aliases=['FKTR', 'LGMD2I', 'LGMDR9', 'MDC1C', 'MDDGA5', 'MDDGB5', 'MDDGC5'], description='fukutin related protein', other_designations='fukutin-related protein|ribitol-5-phosphate transferase', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46746015, end_position_on_the_genomic_accession=46758575, orientation='plus', exon_count=5, OMIM=[606596], no_hdr0=''),
    79148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79148, CurrentID=0, Status='live', Symbol='MMP28', Aliases=['EPILYSIN', 'MM28', 'MMP-25', 'MMP-28', 'MMP25'], description='matrix metallopeptidase 28', other_designations='matrix metalloproteinase-28|matrix metalloprotease MMP25', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35756249, end_position_on_the_genomic_accession=35795707, orientation='minus', exon_count=14, OMIM=[608417], no_hdr0=''),
    79149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79149, CurrentID=0, Status='live', Symbol='ZSCAN5A', Aliases=['ZNF495', 'ZSCAN5'], description='zinc finger and SCAN domain containing 5A', other_designations='zinc finger and SCAN domain-containing protein 5A|zinc finger and SCAN domain containing 5|zinc finger protein 495', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56221303, end_position_on_the_genomic_accession=56368278, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    79152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79152, CurrentID=0, Status='live', Symbol='FA2H', Aliases=['FAAH', 'FAH1', 'FAXDC1', 'SCS7', 'SPG35'], description='fatty acid 2-hydroxylase', other_designations='fatty acid 2-hydroxylase|fatty acid alpha-hydroxylase|fatty acid hydroxylase domain containing 1|fatty acid hydroxylase domain-containing protein 1|spastic paraplegia 35 (autosomal recessive)', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74712955, end_position_on_the_genomic_accession=74774831, orientation='minus', exon_count=8, OMIM=[611026], no_hdr0=''),
    79153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79153, CurrentID=0, Status='live', Symbol='GDPD3', Aliases=['GDE7'], description='glycerophosphodiester phosphodiesterase domain containing 3', other_designations='lysophospholipase D GDPD3|glycerophosphodiester phosphodiesterase 7|glycerophosphodiester phosphodiesterase domain-containing protein 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30104810, end_position_on_the_genomic_accession=30113537, orientation='minus', exon_count=10, OMIM=[616318], no_hdr0=''),
    79154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79154, CurrentID=0, Status='live', Symbol='DHRS11', Aliases=['ARPG836', 'SDR24C1', 'spDHRS11'], description='dehydrogenase/reductase 11', other_designations='dehydrogenase/reductase SDR family member 11|17-beta-hydroxysteroid dehydrogenase|3-beta-hydroxysteroid 3-dehydrogenase|dehydrogenase/reductase (SDR family) member 11|estradiol 17-beta-dehydrogenase|short-chain dehydrogenase/reductase family 24C member 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36591846, end_position_on_the_genomic_accession=36600804, orientation='plus', exon_count=7, OMIM=[616159], no_hdr0=''),
    79155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79155, CurrentID=0, Status='live', Symbol='TNIP2', Aliases=['ABIN2', 'FLIP1', 'KLIP'], description='TNFAIP3 interacting protein 2', other_designations='TNFAIP3-interacting protein 2|A20-binding inhibitor of NF-kappaB activation-2|fetal liver LKB1-interacting protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2741648, end_position_on_the_genomic_accession=2756336, orientation='minus', exon_count=6, OMIM=[610669], no_hdr0=''),
    79156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79156, CurrentID=0, Status='live', Symbol='PLEKHF1', Aliases=['APPD', 'LAPF', 'PHAFIN1', 'ZFYVE15'], description='pleckstrin homology and FYVE domain containing 1', other_designations='pleckstrin homology domain-containing family F member 1|PH and FYVE domain-containing protein 1|PH domain-containing family F member 1|apoptosis-inducing protein D|lysosome-associated apoptosis-inducing protein containing PH and FYVE domains|phafin 1|pleckstrin homology domain containing, family F (with FYVE domain) member 1|zinc finger FYVE domain-containing protein 15', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29665422, end_position_on_the_genomic_accession=29675477, orientation='plus', exon_count=2, OMIM=[615200], no_hdr0=''),
    79157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79157, CurrentID=0, Status='live', Symbol='MFSD11', Aliases=['ET'], description='major facilitator superfamily domain containing 11', other_designations='UNC93-like protein MFSD11|major facilitator superfamily domain-containing protein 11|protein ET', map_location='17q25.1-q25.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76736634, end_position_on_the_genomic_accession=76803805, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    79158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79158, CurrentID=0, Status='live', Symbol='GNPTAB', Aliases=['GNPTA', 'ICD'], description='N-acetylglucosamine-1-phosphate transferase subunits alpha and beta', other_designations='N-acetylglucosamine-1-phosphotransferase subunits alpha/beta|GlcNAc phosphotransferase|N-acetylglucosamine-1-phosphate transferase alpha and beta subunits|UDP-N-acetylglucosamine-1-phosphotransferase subunits alpha/beta|UDP-N-acetylglucosamine-lysosomal-enzyme N-acetylglucosamine|glcNAc-1-phosphotransferase subunits alpha/beta|glucosamine (UDP-N-acetyl)-lysosomal-enzyme N-acetylglucosamine phosphotransferase|stealth protein GNPTAB', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101745499, end_position_on_the_genomic_accession=101830959, orientation='minus', exon_count=23, OMIM=[607840], no_hdr0=''),
    79159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79159, CurrentID=0, Status='live', Symbol='NOL12', Aliases=['Nop25', 'dJ37E16.7'], description='nucleolar protein 12', other_designations='nucleolar protein 12', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37686343, end_position_on_the_genomic_accession=37693474, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79161, CurrentID=0, Status='live', Symbol='TMEM243', Aliases=['C7orf23', 'MM-TRAG', 'MMTRAG'], description='transmembrane protein 243', other_designations='transmembrane protein 243|MDR1 and mitochondrial taxol resistance associated|MDR1- and mitochondrial taxol resistance-associated protein|transmembrane protein 243, mitochondrial|transmembrane protein C7orf23', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87196160, end_position_on_the_genomic_accession=87220587, orientation='minus', exon_count=5, OMIM=[616993], no_hdr0=''),
    79165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79165, CurrentID=0, Status='live', Symbol='LENG1', Aliases=[], description='leukocyte receptor cluster member 1', other_designations='leukocyte receptor cluster member 1|leukocyte receptor cluster (LRC) member 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54155161, end_position_on_the_genomic_accession=54159721, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79168, CurrentID=0, Status='live', Symbol='LILRA6', Aliases=['CD85b', 'ILT-8', 'ILT5', 'ILT8', 'LILRB3', 'LILRB6'], description='leukocyte immunoglobulin like receptor A6', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 6|immunoglobulin-like transcript 5|immunoglobulin-like transcript 8|leucocyte Ig-like receptor A6|leukocyte Ig-like receptor|leukocyte immunoglobulin like receptor B3|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 6|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 6', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54236590, end_position_on_the_genomic_accession=54242790, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    79169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79169, CurrentID=0, Status='live', Symbol='C1orf35', Aliases=['MMTAG2'], description='chromosome 1 open reading frame 35', other_designations='multiple myeloma tumor-associated protein 2|multiple myeloma transforming 2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228100731, end_position_on_the_genomic_accession=228103325, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    79170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79170, CurrentID=0, Status='live', Symbol='PRR15L', Aliases=['ATAD4'], description='proline rich 15 like', other_designations='proline-rich protein 15-like protein|ATPase family, AAA domain containing 4|testicular tissue protein Li 157', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47951967, end_position_on_the_genomic_accession=47957905, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79171, CurrentID=0, Status='live', Symbol='RBM42', Aliases=[], description='RNA binding motif protein 42', other_designations='RNA-binding protein 42', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35629036, end_position_on_the_genomic_accession=35637685, orientation='plus', exon_count=10, OMIM=[613232], no_hdr0=''),
    79172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79172, CurrentID=0, Status='live', Symbol='CENPO', Aliases=['CENP-O', 'ICEN-36', 'MCM21R'], description='centromere protein O', other_designations='centromere protein O|centromeric protein O|interphase centromere complex protein 36', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24793339, end_position_on_the_genomic_accession=24822376, orientation='plus', exon_count=8, OMIM=[611504], no_hdr0=''),
    79173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79173, CurrentID=0, Status='live', Symbol='BRME1', Aliases=['C19orf57', 'MEIOK21'], description='break repair meiotic recombinase recruitment factor 1', other_designations='break repair meiotic recombinase recruitment factor 1|BRCA2 and MEILB2-associating protein 1|meiosis-specific 4930432K21RIK|pre-T/NK cell associated protein (3B3)|uncharacterized protein C19orf57', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13882348, end_position_on_the_genomic_accession=13906127, orientation='minus', exon_count=12, OMIM=[619276], no_hdr0=''),
    79174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79174, CurrentID=0, Status='live', Symbol='CRELD2', Aliases=[], description='cysteine rich with EGF like domains 2', other_designations='protein disulfide isomerase CRELD2|cysteine-rich with EGF-like domain protein 2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49918634, end_position_on_the_genomic_accession=49927540, orientation='plus', exon_count=12, OMIM=[607171], no_hdr0=''),
    79175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79175, CurrentID=0, Status='live', Symbol='ZNF343', Aliases=['dJ734P14.5'], description='zinc finger protein 343', other_designations='zinc finger protein 343', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2481817, end_position_on_the_genomic_accession=2524522, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    79176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79176, CurrentID=0, Status='live', Symbol='FBXL15', Aliases=['FBXO37', 'Fbl15', 'JET', 'PSD'], description='F-box and leucine rich repeat protein 15', other_designations='F-box/LRR-repeat protein 15|F-box only protein 37|pleckstrin and Sec7 domain protein', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102419222, end_position_on_the_genomic_accession=102423138, orientation='plus', exon_count=7, OMIM=[610287], no_hdr0=''),
    79177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79177, CurrentID=0, Status='live', Symbol='ZNF576', Aliases=[], description='zinc finger protein 576', other_designations='zinc finger protein 576', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43596392, end_position_on_the_genomic_accession=43601157, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    79178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79178, CurrentID=0, Status='live', Symbol='THTPA', Aliases=['THTPSE', 'THTPA'], description='thiamine triphosphatase', other_designations='thiamine-triphosphatase', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23511760, end_position_on_the_genomic_accession=23560271, orientation='plus', exon_count=7, OMIM=[611612], no_hdr0=''),
    79180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79180, CurrentID=0, Status='live', Symbol='EFHD2', Aliases=['SWS1'], description='EF-hand domain family member D2', other_designations='EF-hand domain-containing protein D2|EF hand domain containing 2|swiprosin 1|testicular tissue protein Li 62', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15409888, end_position_on_the_genomic_accession=15430339, orientation='plus', exon_count=4, OMIM=[616450], no_hdr0=''),
    79183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79183, CurrentID=0, Status='live', Symbol='TTPAL', Aliases=['C20orf121'], description='alpha tocopherol transfer protein like', other_designations='alpha-tocopherol transfer protein-like|tocopherol (alpha) transfer protein-like', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44475870, end_position_on_the_genomic_accession=44494603, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    79184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79184, CurrentID=0, Status='live', Symbol='BRCC3', Aliases=['BRCC36', 'C6.1A', 'CXorf53'], description='BRCA1/BRCA2-containing complex subunit 3', other_designations='lys-63-specific deubiquitinase BRCC36|BRCA1-A complex subunit BRCC36|BRCA1/BRCA2-containing complex subunit 36|BRISC complex subunit BRCC36', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155071403, end_position_on_the_genomic_accession=155126766, orientation='plus', exon_count=12, OMIM=[300617], no_hdr0=''),
    79187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79187, CurrentID=0, Status='live', Symbol='FSD1', Aliases=['GLFND', 'MIR1'], description='fibronectin type III and SPRY domain containing 1', other_designations='fibronectin type III and SPRY domain-containing protein 1|MID1-related protein 1|fibronectin type 3 and SPRY (spla, ryanodine) domain containing (with coiled-coil motif) 1|fibronectin type 3 and SPRY domain containing 1|microtubule-associated protein GLFND|midline 1-related protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4304598, end_position_on_the_genomic_accession=4323836, orientation='plus', exon_count=13, OMIM=[609828], no_hdr0=''),
    79188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79188, CurrentID=0, Status='live', Symbol='TMEM43', Aliases=['ARVC5', 'ARVD5', 'EDMD7', 'LUMA'], description='transmembrane protein 43', other_designations='transmembrane protein 43', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14125006, end_position_on_the_genomic_accession=14143680, orientation='plus', exon_count=13, OMIM=[612048], no_hdr0=''),
    79190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79190, CurrentID=0, Status='live', Symbol='IRX6', Aliases=['IRX-3', 'IRX7', 'IRXB3'], description='iroquois homeobox 6', other_designations='iroquois-class homeodomain protein IRX-6|homeodomain protein IRXB3|iroquois homeobox protein 6|iroquois homeobox protein 7', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55323760, end_position_on_the_genomic_accession=55330760, orientation='plus', exon_count=6, OMIM=[606196], no_hdr0=''),
    79191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79191, CurrentID=0, Status='live', Symbol='IRX3', Aliases=['IRX-1', 'IRXB1'], description='iroquois homeobox 3', other_designations='iroquois-class homeodomain protein IRX-3|homeodomain protein IRXB1|iroquois homeobox protein 3|iroquois-class homeodomain protein IRX-1', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=54283304, end_position_on_the_genomic_accession=54286787, orientation='minus', exon_count=4, OMIM=[612985], no_hdr0=''),
    79192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79192, CurrentID=0, Status='live', Symbol='IRX1', Aliases=['IRX-5', 'IRXA1'], description='iroquois homeobox 1', other_designations='iroquois-class homeodomain protein IRX-1|homeodomain protein IRXA1|iroquois homeobox protein 1', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=3595832, end_position_on_the_genomic_accession=3601403, orientation='plus', exon_count=4, OMIM=[606197], no_hdr0=''),
    79228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79228, CurrentID=0, Status='live', Symbol='THOC6', Aliases=['WDR58', 'fSAP35'], description='THO complex 6', other_designations='THO complex subunit 6 homolog|WD repeat domain 58|WD repeat-containing protein 58|functional spliceosome-associated protein 35', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3024035, end_position_on_the_genomic_accession=3027750, orientation='plus', exon_count=13, OMIM=[615403], no_hdr0=''),
    79230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79230, CurrentID=0, Status='live', Symbol='ZNF557', Aliases=[], description='zinc finger protein 557', other_designations='zinc finger protein 557|CTB-25J19.9', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7069703, end_position_on_the_genomic_accession=7087968, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    79258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79258, CurrentID=0, Status='live', Symbol='MMEL1', Aliases=['MMEL2', 'NEP2', 'NEPII', 'NL1', 'NL2', 'SEP'], description='membrane metalloendopeptidase like 1', other_designations='membrane metallo-endopeptidase-like 1|NEP2(m)|membrane metallo-endopeptidase-like 2|neprilysin II|neprilysin-2|soluble secreted endopeptidase|zinc metallopeptidase', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2590639, end_position_on_the_genomic_accession=2633042, orientation='minus', exon_count=26, OMIM=[618104], no_hdr0=''),
    79269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79269, CurrentID=0, Status='live', Symbol='DCAF10', Aliases=['WDR32'], description='DDB1 and CUL4 associated factor 10', other_designations='DDB1- and CUL4-associated factor 10|WD repeat domain 32|WD repeat-containing protein 32', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37800554, end_position_on_the_genomic_accession=37867664, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    79290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79290, CurrentID=0, Status='live', Symbol='OR13A1', Aliases=[], description='olfactory receptor family 13 subfamily A member 1', other_designations='olfactory receptor 13A1|olfactory receptor OR10-3|seven transmembrane helix receptor', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45302595, end_position_on_the_genomic_accession=45315608, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79295, CurrentID=0, Status='live', Symbol='OR5H6', Aliases=['OR3-11'], description='olfactory receptor family 5 subfamily H member 6', other_designations='olfactory receptor 5H6|olfactory receptor OR3-11', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98264244, end_position_on_the_genomic_accession=98265356, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79296, CurrentID=0, Status='live', Symbol='OR52E1', Aliases=['OR52E1P'], description='olfactory receptor family 52 subfamily E member 1 (gene/pseudogene)', other_designations='olfactory receptor 52E1|olfactory receptor, family 52, subfamily E, member 1 pseudogene|seven transmembrane helix receptor', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5069572, end_position_on_the_genomic_accession=5070497, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79310, CurrentID=0, Status='live', Symbol='OR5H2', Aliases=['OR3-10'], description='olfactory receptor family 5 subfamily H member 2', other_designations='olfactory receptor 5H2|olfactory receptor OR3-10', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98282505, end_position_on_the_genomic_accession=98284070, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79317, CurrentID=0, Status='live', Symbol='OR4K5', Aliases=['OR14-16'], description='olfactory receptor family 4 subfamily K member 5', other_designations='olfactory receptor 4K5|olfactory receptor OR14-16', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19920607, end_position_on_the_genomic_accession=19921578, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79324, CurrentID=0, Status='live', Symbol='OR51G1', Aliases=['OR11-29', 'OR51G3P'], description='olfactory receptor family 51 subfamily G member 1', other_designations='olfactory receptor 51G1|olfactory receptor 51G3|olfactory receptor OR11-29', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4923374, end_position_on_the_genomic_accession=4924339, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79334, CurrentID=0, Status='live', Symbol='OR11H2', Aliases=['C14orf15', 'OR11H13P', 'OR11H8P', 'OR11H2'], description='olfactory receptor family 11 subfamily H member 2', other_designations='olfactory receptor 11H2|olfactory receptor OR14-1|seven transmembrane helix receptor', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19712936, end_position_on_the_genomic_accession=19713883, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79339, CurrentID=0, Status='live', Symbol='OR51B4', Aliases=["HOR5'Beta1"], description='olfactory receptor family 51 subfamily B member 4', other_designations="olfactory receptor 51B4|odorant receptor HOR5'beta1", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5301014, end_position_on_the_genomic_accession=5301946, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79345, CurrentID=0, Status='live', Symbol='OR51B2', Aliases=["HOR5'Beta3", 'OR51B1P'], description='olfactory receptor family 51 subfamily B member 2', other_designations="olfactory receptor 51B2|odorant receptor HOR5'beta3|olfactory receptor 51B1", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5323359, end_position_on_the_genomic_accession=5324297, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79346, CurrentID=0, Status='live', Symbol='OR4C5', Aliases=['OR4C5PQ', 'OR4C5'], description='olfactory receptor family 4 subfamily C member 5', other_designations='olfactory receptor 4C5|olfactory receptor OR11-99|olfactory receptor, family 4, subfamily C, member 5 pseudogene|seven transmembrane helix receptor', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48365485, end_position_on_the_genomic_accession=48366465, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79363, CurrentID=0, Status='live', Symbol='CPLANE2', Aliases=['C1orf89', 'RSG1'], description='ciliogenesis and planar polarity effector 2', other_designations='ciliogenesis and planar polarity effector 2|REM2 and RAB like small GTPase 1|REM2- and Rab-like small GTPase 1|Rem/Rab-Similar GTPase 1|miro domain-containing protein C1orf89', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16231692, end_position_on_the_genomic_accession=16237445, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79364, CurrentID=0, Status='live', Symbol='ZXDC', Aliases=['ZXDL'], description='ZXD family zinc finger C', other_designations='zinc finger protein ZXDC|SERH2790|ZXD-like zinc finger protein', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126437348, end_position_on_the_genomic_accession=126475938, orientation='minus', exon_count=10, OMIM=[615746], no_hdr0=''),
    79365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79365, CurrentID=0, Status='live', Symbol='BHLHE41', Aliases=['BHLHB3', 'DEC2', 'FNSS1', 'SHARP1', 'hDEC2'], description='basic helix-loop-helix family member e41', other_designations='class E basic helix-loop-helix protein 41|basic helix-loop-helix domain containing, class B, 3|differentially expressed in chondrocytes protein 2|enhancer-of-split and hairy-related protein 1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=26120030, end_position_on_the_genomic_accession=26125037, orientation='minus', exon_count=5, OMIM=[606200], no_hdr0=''),
    79366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79366, CurrentID=0, Status='live', Symbol='HMGN5', Aliases=['NBP-45', 'NSBP1'], description='high mobility group nucleosome binding domain 5', other_designations='high mobility group nucleosome-binding domain-containing protein 5|nucleosomal binding protein 1|nucleosome-binding protein 1', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=81113699, end_position_on_the_genomic_accession=81201913, orientation='minus', exon_count=7, OMIM=[300385], no_hdr0=''),
    79368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79368, CurrentID=0, Status='live', Symbol='FCRL2', Aliases=['CD307b', 'FCRH2', 'IFGP4', 'IRTA4', 'SPAP1', 'SPAP1A', 'SPAP1B', 'SPAP1C'], description='Fc receptor like 2', other_designations='Fc receptor-like protein 2|IFGP family protein 4|SH2 domain containing phosphatase anchor protein 1|fc receptor homolog 2|immune receptor translocation-associated protein 4|immunoglobulin receptor translocation-associated protein 4|immunoglobulin superfamily Fc receptor, gp42', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157745733, end_position_on_the_genomic_accession=157777472, orientation='minus', exon_count=13, OMIM=[606509], no_hdr0=''),
    79369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79369, CurrentID=0, Status='live', Symbol='B3GNT4', Aliases=['B3GN-T4', 'beta3Gn-T4'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 4', other_designations='N-acetyllactosaminide beta-1,3-N-acetylglucosaminyltransferase 4|BGnT-4|beta-1,3-Gn-T4|beta-1,3-N-acetylglucosaminyltransferase 4|beta-1,3-N-acetylglucosaminyltransferase bGn-T4', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122203709, end_position_on_the_genomic_accession=122208952, orientation='plus', exon_count=3, OMIM=[605864], no_hdr0=''),
    79370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79370, CurrentID=0, Status='live', Symbol='BCL2L14', Aliases=['BCLG'], description='BCL2 like 14', other_designations='apoptosis facilitator Bcl-2-like protein 14|BCL2-like 14 (apoptosis facilitator)|apoptosis regulator BCL-G|bcl2-L-14|testicular tissue protein Li 26', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12049849, end_position_on_the_genomic_accession=12099695, orientation='plus', exon_count=12, OMIM=[606126], no_hdr0=''),
    79400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79400, CurrentID=0, Status='live', Symbol='NOX5', Aliases=[], description='NADPH oxidase 5', other_designations='NADPH oxidase 5|NADPH oxidase, EF-hand calcium binding domain 5', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68930525, end_position_on_the_genomic_accession=69062762, orientation='plus', exon_count=18, OMIM=[606572], no_hdr0=''),
    79411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79411, CurrentID=0, Status='live', Symbol='GLB1L', Aliases=[], description='galactosidase beta 1 like', other_designations='beta-galactosidase-1-like protein|testicular tissue protein Li 74', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219236598, end_position_on_the_genomic_accession=219245444, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    79412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79412, CurrentID=0, Status='live', Symbol='KREMEN2', Aliases=['KRM2'], description='kringle containing transmembrane protein 2', other_designations='kremen protein 2|dickkopf receptor 2|kringle domain-containing transmembrane protein 2|kringle-containing protein marking the eye and the nose', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2964275, end_position_on_the_genomic_accession=2968380, orientation='plus', exon_count=9, OMIM=[609899], no_hdr0=''),
    79413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79413, CurrentID=0, Status='live', Symbol='ZBED2', Aliases=[], description='zinc finger BED-type containing 2', other_designations='zinc finger BED domain-containing protein 2|zinc finger, BED domain containing 2', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111592900, end_position_on_the_genomic_accession=111595346, orientation='minus', exon_count=2, OMIM=[615246], no_hdr0=''),
    79414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79414, CurrentID=0, Status='live', Symbol='LRFN3', Aliases=['FIGLER1', 'SALM4'], description='leucine rich repeat and fibronectin type III domain containing 3', other_designations='leucine-rich repeat and fibronectin type-III domain-containing protein 3|fibronectin type III, immunoglobulin and leucine rich repeat domains 1|synaptic adhesion-like molecule 4', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35936374, end_position_on_the_genomic_accession=35946624, orientation='plus', exon_count=3, OMIM=[612809], no_hdr0=''),
    79415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79415, CurrentID=0, Status='live', Symbol='CYBC1', Aliases=['C17orf62', 'CGD5', 'Eros'], description='cytochrome b-245 chaperone 1', other_designations='cytochrome b-245 chaperone 1|essential for reactive oxygen species protein|uncharacterized protein C17orf62', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82442586, end_position_on_the_genomic_accession=82450821, orientation='minus', exon_count=9, OMIM=[618334], no_hdr0=''),
    79441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79441, CurrentID=0, Status='live', Symbol='HAUS3', Aliases=['C4orf15', 'IT1', 'dgt3'], description='HAUS augmin like complex subunit 3', other_designations='HAUS augmin-like complex subunit 3', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2228349, end_position_on_the_genomic_accession=2242121, orientation='minus', exon_count=6, OMIM=[613430], no_hdr0=''),
    79442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79442, CurrentID=0, Status='live', Symbol='LRRC2', Aliases=[], description='leucine rich repeat containing 2', other_designations='leucine-rich repeat-containing protein 2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46515385, end_position_on_the_genomic_accession=46580099, orientation='minus', exon_count=10, OMIM=[607180], no_hdr0=''),
    79443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79443, CurrentID=0, Status='live', Symbol='FYCO1', Aliases=['CATC2', 'CTRCT18', 'RUFY3', 'ZFYVE7'], description='FYVE and coiled-coil domain autophagy adaptor 1', other_designations='FYVE and coiled-coil domain-containing protein 1|FYVE and coiled-coil domain containing 1|RUN and FYVE domain containing 3|zinc finger FYVE domain-containing protein 7', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=45917903, end_position_on_the_genomic_accession=45995824, orientation='minus', exon_count=23, OMIM=[607182], no_hdr0=''),
    79444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79444, CurrentID=0, Status='live', Symbol='BIRC7', Aliases=['KIAP', 'LIVIN', 'ML-IAP', 'MLIAP', 'RNF50'], description='baculoviral IAP repeat containing 7', other_designations='baculoviral IAP repeat-containing protein 7|RING finger protein 50|RING-type E3 ubiquitin transferase BIRC7|kidney inhibitor of apoptosis protein|livin inhibitor of apoptosis|melanoma inhibitor of apoptosis protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63235905, end_position_on_the_genomic_accession=63240495, orientation='plus', exon_count=7, OMIM=[605737], no_hdr0=''),
    79446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79446, CurrentID=0, Status='live', Symbol='WDR25', Aliases=['C14orf67'], description='WD repeat domain 25', other_designations='WD repeat-containing protein 25|epididymis secretory sperm binding protein', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100376485, end_position_on_the_genomic_accession=100530303, orientation='plus', exon_count=8, OMIM=[618059], no_hdr0=''),
    79447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79447, CurrentID=0, Status='live', Symbol='PAGR1', Aliases=['C16orf53', 'GAS', 'PA1'], description='PAXIP1 associated glutamate rich protein 1', other_designations='PAXIP1-associated glutamate-rich protein 1|PAXIP1-associated protein 1|PTIP-associated 1 protein|PTIP-associated protein 1|glutamate-rich coactivator associated with SRC1|glutamate-rich coactivator interacting with SRC1|glutamate-rich coactivator interacting with SRC1/NCOA1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29816152, end_position_on_the_genomic_accession=29822489, orientation='plus', exon_count=3, OMIM=[612033], no_hdr0=''),
    79465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79465, CurrentID=0, Status='live', Symbol='ULBP3', Aliases=['N2DL-3', 'NKG2DL3', 'RAET1N'], description='UL16 binding protein 3', other_designations='UL16-binding protein 3|ALCAN-gamma|NKG2D ligand 3|retinoic acid early transcript 1N', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150061053, end_position_on_the_genomic_accession=150069121, orientation='minus', exon_count=5, OMIM=[605699], no_hdr0=''),
    79470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79470, CurrentID=0, Status='live', Symbol='OR51J1', Aliases=["HOR5'Beta8P", 'OR51J2', 'OR51J1'], description='olfactory receptor family 51 subfamily J member 1', other_designations="olfactory receptor 51J1|odorant receptor HOR5'beta8|olfactory receptor 51J2|olfactory receptor, family 51, subfamily J, member 1 pseudogene|olfactory receptor, family 51, subfamily J, member 2", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5402397, end_position_on_the_genomic_accession=5403771, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79473, CurrentID=0, Status='live', Symbol='OR52N1', Aliases=['OR11-61'], description='olfactory receptor family 52 subfamily N member 1', other_designations='olfactory receptor 52N1|olfactory receptor OR11-61', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5786471, end_position_on_the_genomic_accession=5791265, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79482, CurrentID=0, Status='live', Symbol='OR5AL1', Aliases=['OR5AL1P'], description='olfactory receptor family 5 subfamily AL member 1 (gene/pseudogene)', other_designations='olfactory receptor 5AL1|Olfactory receptor 5AL1|olfactory receptor OR11-184|olfactory receptor, family 5, subfamily AL, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56412597, end_position_on_the_genomic_accession=56413781, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    79490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79490, CurrentID=0, Status='live', Symbol='OR10G6', Aliases=['OR10G6PQ', 'OR10G6'], description='olfactory receptor family 10 subfamily G member 6', other_designations='olfactory receptor 10G6|olfactory receptor OR11-280|seven transmembrane helix receptor', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123994163, end_position_on_the_genomic_accession=123995161, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79501, CurrentID=0, Status='live', Symbol='OR4F5', Aliases=[], description='olfactory receptor family 4 subfamily F member 5', other_designations='olfactory receptor 4F5', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=65419, end_position_on_the_genomic_accession=71585, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    79541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79541, CurrentID=0, Status='live', Symbol='OR2A4', Aliases=['OR2A10'], description='olfactory receptor family 2 subfamily A member 4', other_designations='olfactory receptor 2A4|olfactory receptor 2A10|olfactory receptor OR6-37|olfactory receptor, family 2, subfamily A, member 10', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131699644, end_position_on_the_genomic_accession=131701401, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    79544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79544, CurrentID=0, Status='live', Symbol='OR4K1', Aliases=['OR14-19'], description='olfactory receptor family 4 subfamily K member 1', other_designations='olfactory receptor 4K1|olfactory receptor OR14-19', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19920263, end_position_on_the_genomic_accession=19936757, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    79549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79549, CurrentID=0, Status='live', Symbol='OR6J1', Aliases=['OR6J1P', 'OR6J2'], description='olfactory receptor family 6 subfamily J member 1', other_designations='olfactory receptor 6J1|Olfactory receptor 6J1|olfactory receptor 6J2|olfactory receptor, family 6, subfamily J, member 1 pseudogene|olfactory receptor, family 6, subfamily J, member 2|seven transmembrane helix receptor', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22630929, end_position_on_the_genomic_accession=22644352, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79567, CurrentID=0, Status='live', Symbol='RIPOR1', Aliases=['FAM65A'], description='RHO family interacting cell polarization regulator 1', other_designations='rho family-interacting cell polarization regulator 1|family with sequence similarity 65 member A|protein FAM65A', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67518423, end_position_on_the_genomic_accession=67546786, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    79568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79568, CurrentID=0, Status='live', Symbol='MAIP1', Aliases=['C2orf47'], description='matrix AAA peptidase interacting protein 1', other_designations='m-AAA protease-interacting protein 1, mitochondrial', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=199955317, end_position_on_the_genomic_accession=199964117, orientation='plus', exon_count=7, OMIM=[617267], no_hdr0=''),
    79570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79570, CurrentID=0, Status='live', Symbol='NKAIN1', Aliases=['FAM77C'], description='sodium/potassium transporting ATPase interacting 1', other_designations='sodium/potassium-transporting ATPase subunit beta-1-interacting protein 1|Na(+)/K(+)-transporting ATPase subunit beta-1-interacting protein 1|Na+/K+ transporting ATPase interacting 1|family with sequence similarity 77, member C', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31179270, end_position_on_the_genomic_accession=31239887, orientation='minus', exon_count=7, OMIM=[612871], no_hdr0=''),
    79571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79571, CurrentID=0, Status='live', Symbol='GCC1', Aliases=['GCC1P', 'GCC88'], description='GRIP and coiled-coil domain containing 1', other_designations='GRIP and coiled-coil domain-containing protein 1|golgi coiled-coil 1|golgi coiled-coil protein 1|peripheral membrane Golgi protein', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127580628, end_position_on_the_genomic_accession=127585596, orientation='minus', exon_count=2, OMIM=[607418], no_hdr0=''),
    79572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79572, CurrentID=0, Status='live', Symbol='ATP13A3', Aliases=['AFURS1'], description='ATPase 13A3', other_designations='polyamine-transporting ATPase 13A3|probable cation-transporting ATPase 13A3|ATPase family homolog up-regulated in senescence cells 1|ATPase type 13A3|putrescine transporting ATPase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194402674, end_position_on_the_genomic_accession=194487006, orientation='minus', exon_count=36, OMIM=[610232], no_hdr0=''),
    79573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79573, CurrentID=0, Status='live', Symbol='TTC13', Aliases=[], description='tetratricopeptide repeat domain 13', other_designations='tetratricopeptide repeat protein 13|TPR repeat protein 13|epididymis secretory sperm binding protein', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230906243, end_position_on_the_genomic_accession=230978872, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    79574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79574, CurrentID=0, Status='live', Symbol='EPS8L3', Aliases=['EPS8R3', 'HYPT5'], description='EPS8 like 3', other_designations='epidermal growth factor receptor kinase substrate 8-like protein 3|EPS8-like protein 3|EPS8-related protein 3|epidermal growth factor receptor pathway substrate 8-related protein 3', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109750080, end_position_on_the_genomic_accession=109763976, orientation='minus', exon_count=20, OMIM=[614989], no_hdr0=''),
    79575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79575, CurrentID=0, Status='live', Symbol='ABHD8', Aliases=[], description='abhydrolase domain containing 8', other_designations='protein ABHD8|abhydrolase domain-containing protein 8|alpha/beta hydrolase domain-containing protein 8', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17292131, end_position_on_the_genomic_accession=17303425, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79576, CurrentID=0, Status='live', Symbol='NKAP', Aliases=['MRXSHD'], description='NFKB activating protein', other_designations='NF-kappa-B-activating protein|NF-kappaB activating protein', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119920672, end_position_on_the_genomic_accession=119943751, orientation='minus', exon_count=10, OMIM=[300766], no_hdr0=''),
    79577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79577, CurrentID=0, Status='live', Symbol='CDC73', Aliases=['C1orf28', 'FIHP', 'HPTJT', 'HRPT1', 'HRPT2', 'HYX'], description='cell division cycle 73', other_designations='parafibromin|Familial isolated hyperparathyroidism|Paf1/RNA polymerase II complex component|cell division cycle 73 Paf1/RNA polymerase II complex component-like protein|cell division cycle 73, Paf1/RNA polymerase II complex component, homolog|cell division cycle protein 73 homolog|hyperparathyroidism 2 protein', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=193122031, end_position_on_the_genomic_accession=193254815, orientation='plus', exon_count=18, OMIM=[607393], no_hdr0=''),
    79581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79581, CurrentID=0, Status='live', Symbol='SLC52A2', Aliases=['BVVLS2', 'D15Ertd747e', 'GPCR41', 'GPR172A', 'PAR1', 'RFT3', 'RFVT2', 'hRFT3'], description='solute carrier family 52 member 2', other_designations='solute carrier family 52, riboflavin transporter, member 2|G protein-coupled receptor 172A|PERV-A receptor 1|porcine endogenous retrovirus A receptor 1|putative G-protein coupled receptor GPCR41|riboflavin transporter 3|solute carrier family 52 (riboflavin transporter), member 2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144358547, end_position_on_the_genomic_accession=144361272, orientation='plus', exon_count=7, OMIM=[607882], no_hdr0=''),
    79582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79582, CurrentID=0, Status='live', Symbol='SPAG16', Aliases=['PF20', 'WDR29'], description='sperm associated antigen 16', other_designations='sperm-associated antigen 16 protein|WD repeat domain 29|pf20 protein homolog|sperm-associated WD repeat protein', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=213284369, end_position_on_the_genomic_accession=214410501, orientation='plus', exon_count=34, OMIM=[612173], no_hdr0=''),
    79583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79583, CurrentID=0, Status='live', Symbol='TMEM231', Aliases=['ALYE870', 'JBTS20', 'MKS11', 'PRO1886'], description='transmembrane protein 231', other_designations='transmembrane protein 231', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75536741, end_position_on_the_genomic_accession=75556286, orientation='minus', exon_count=7, OMIM=[614949], no_hdr0=''),
    79585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79585, CurrentID=0, Status='live', Symbol='CORO7', Aliases=['0610011B16Rik', 'CRN7', 'POD1'], description='coronin 7', other_designations='coronin-7|70 kDa WD repeat tumor rejection antigen homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4354542, end_position_on_the_genomic_accession=4416596, orientation='minus', exon_count=29, OMIM=[611668], no_hdr0=''),
    79586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79586, CurrentID=0, Status='live', Symbol='CHPF', Aliases=['CHSY2', 'CSS2'], description='chondroitin polymerizing factor', other_designations='chondroitin sulfate synthase 2|N-acetylgalactosaminyl-proteoglycan 3-beta-glucuronosyltransferase II|N-acetylgalactosaminyltransferase 2|chondroitin glucuronyltransferase 2|glucuronosyl-N-acetylgalactosaminyl-proteoglycan 4-beta-N-acetylgalactosaminyltransferase II', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219538949, end_position_on_the_genomic_accession=219543809, orientation='minus', exon_count=5, OMIM=[610405], no_hdr0=''),
    79587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79587, CurrentID=0, Status='live', Symbol='CARS2', Aliases=['COXPD27', 'cysRS'], description='cysteinyl-tRNA synthetase 2, mitochondrial', other_designations='probable cysteine--tRNA ligase, mitochondrial|cysteine tRNA ligase 2, mitochondrial (putative)|cysteinyl-tRNA synthetase 2, mitochondrial (putative)', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=110641410, end_position_on_the_genomic_accession=110713601, orientation='minus', exon_count=24, OMIM=[612800], no_hdr0=''),
    79589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79589, CurrentID=0, Status='live', Symbol='RNF128', Aliases=['GRAIL'], description='ring finger protein 128', other_designations='E3 ubiquitin-protein ligase RNF128|RING-type E3 ubiquitin transferase RNF128|gene related to anergy in lymphocytes protein|ring finger protein 128, E3 ubiquitin protein ligase', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106693838, end_position_on_the_genomic_accession=106797016, orientation='plus', exon_count=8, OMIM=[300439], no_hdr0=''),
    79590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79590, CurrentID=0, Status='live', Symbol='MRPL24', Aliases=['L24mt', 'MRP-L18', 'MRP-L24'], description='mitochondrial ribosomal protein L24', other_designations='39S ribosomal protein L24, mitochondrial|mitochondrial large ribosomal subunit protein uL24m', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156737303, end_position_on_the_genomic_accession=156741267, orientation='minus', exon_count=7, OMIM=[611836], no_hdr0=''),
    79591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79591, CurrentID=0, Status='live', Symbol='ARMH3', Aliases=['C10orf76'], description='armadillo like helical domain containing 3', other_designations='armadillo-like helical domain-containing protein 3|UPF0668 protein C10orf76', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101845599, end_position_on_the_genomic_accession=102056237, orientation='minus', exon_count=33, OMIM=[], no_hdr0=''),
    79594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79594, CurrentID=0, Status='live', Symbol='MUL1', Aliases=['C1orf166', 'GIDE', 'MAPL', 'MULAN', 'RNF218'], description='mitochondrial E3 ubiquitin protein ligase 1', other_designations='mitochondrial ubiquitin ligase activator of NFKB 1|E3 SUMO-protein ligase MUL1|E3 ubiquitin ligase|E3 ubiquitin-protein ligase MUL1|RING-type E3 ubiquitin transferase NFKB 1|growth inhibition and death E3 ligase|mitochondria-anchored protein ligase|mitochondrial E3 ubiquitin ligase 1|mitochondrial ubiquitin ligase activator of NF-kB|mitochondrial-anchored protein ligase|protein Hades|putative NF-kappa-B-activating protein 266|ring finger protein 218', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20499448, end_position_on_the_genomic_accession=20508483, orientation='minus', exon_count=4, OMIM=[612037], no_hdr0=''),
    79595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79595, CurrentID=0, Status='live', Symbol='SAP130', Aliases=[], description='Sin3A associated protein 130', other_designations='histone deacetylase complex subunit SAP130|130 kDa Sin3-associated polypeptide|Sin3-associated polypeptide p130|Sin3A associated protein 130kDa', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127941218, end_position_on_the_genomic_accession=128028059, orientation='minus', exon_count=22, OMIM=[609697], no_hdr0=''),
    79596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79596, CurrentID=0, Status='live', Symbol='OBI1', Aliases=['C13orf7', 'RNF219'], description='ORC ubiquitin ligase 1', other_designations='ORC ubiquitin ligase 1|ring finger protein 219', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=78614286, end_position_on_the_genomic_accession=78659165, orientation='minus', exon_count=7, OMIM=[615906], no_hdr0=''),
    79598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79598, CurrentID=0, Status='live', Symbol='CEP97', Aliases=['2810403B08Rik', 'LRRIQ2'], description='centrosomal protein 97', other_designations='centrosomal protein of 97 kDa|leucine-rich repeat and IQ domain-containing protein 2|leucine-rich repeats and IQ motif containing 2', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101723931, end_position_on_the_genomic_accession=101770562, orientation='plus', exon_count=11, OMIM=[615864], no_hdr0=''),
    79600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79600, CurrentID=0, Status='live', Symbol='TCTN1', Aliases=['JBTS13', 'TECT1'], description='tectonic family member 1', other_designations='tectonic-1', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110614068, end_position_on_the_genomic_accession=110649430, orientation='plus', exon_count=19, OMIM=[609863], no_hdr0=''),
    79602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79602, CurrentID=0, Status='live', Symbol='ADIPOR2', Aliases=['ACDCR2', 'PAQR2'], description='adiponectin receptor 2', other_designations='adiponectin receptor protein 2|progestin and adipoQ receptor family member 2|progestin and adipoQ receptor family member II', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1691059, end_position_on_the_genomic_accession=1788674, orientation='plus', exon_count=11, OMIM=[607946], no_hdr0=''),
    79603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79603, CurrentID=0, Status='live', Symbol='CERS4', Aliases=['LASS4', 'Trh1'], description='ceramide synthase 4', other_designations='ceramide synthase 4|LAG1 homolog, ceramide synthase 4|LAG1 longevity assurance homolog 4|sphingosine N-acyltransferase CERS4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8209329, end_position_on_the_genomic_accession=8262433, orientation='plus', exon_count=17, OMIM=[615334], no_hdr0=''),
    79605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79605, CurrentID=0, Status='live', Symbol='PGBD5', Aliases=[], description='piggyBac transposable element derived 5', other_designations='piggyBac transposable element-derived protein 5|piggyBac domain related protein 5|piggyBac transposase 5', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230314490, end_position_on_the_genomic_accession=230426332, orientation='minus', exon_count=7, OMIM=[616791], no_hdr0=''),
    79607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79607, CurrentID=0, Status='live', Symbol='FAM118B', Aliases=[], description='family with sequence similarity 118 member B', other_designations='protein FAM118B', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126211414, end_position_on_the_genomic_accession=126264540, orientation='plus', exon_count=9, OMIM=[616587], no_hdr0=''),
    79608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79608, CurrentID=0, Status='live', Symbol='RIC3', Aliases=['AYST720', 'PRO1385'], description='RIC3 acetylcholine receptor chaperone', other_designations='protein RIC-3|resistance to inhibitors of cholinesterase 3-like protein|resistant to inhibitor of cholinesterase 3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=8092965, end_position_on_the_genomic_accession=8169040, orientation='minus', exon_count=11, OMIM=[610509], no_hdr0=''),
    79609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79609, CurrentID=0, Status='live', Symbol='VCPKMT', Aliases=['C14orf138', 'METTL21D', 'VCP-KMT'], description='valosin containing protein lysine methyltransferase', other_designations='protein-lysine methyltransferase METTL21D|VCP lysine methyltransferase|methyltransferase like 21D|methyltransferase-like protein 21D|valosin containing protein lysine (K) methyltransferase', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50100456, end_position_on_the_genomic_accession=50116572, orientation='minus', exon_count=9, OMIM=[615260], no_hdr0=''),
    79611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79611, CurrentID=0, Status='live', Symbol='ACSS3', Aliases=[], description='acyl-CoA synthetase short chain family member 3', other_designations='acyl-CoA synthetase short-chain family member 3, mitochondrial|AMP-binding enzyme, 33217|acetate--CoA ligase 3|propionate--CoA ligase', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=81078037, end_position_on_the_genomic_accession=81261210, orientation='plus', exon_count=19, OMIM=[614356], no_hdr0=''),
    79612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79612, CurrentID=0, Status='live', Symbol='NAA16', Aliases=['NARG1L'], description='N-alpha-acetyltransferase 16, NatA auxiliary subunit', other_designations='N-alpha-acetyltransferase 16, NatA auxiliary subunit|NARG1-like protein|NMDA receptor-regulated 1-like protein', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41311239, end_position_on_the_genomic_accession=41377031, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    79613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79613, CurrentID=0, Status='live', Symbol='TANGO6', Aliases=['TMCO7'], description='transport and golgi organization 6 homolog', other_designations='transport and Golgi organization protein 6 homolog|transmembrane and coiled-coil domain-containing protein 7|transmembrane and coiled-coil domains 7', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68843531, end_position_on_the_genomic_accession=69085182, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    79616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79616, CurrentID=0, Status='live', Symbol='CCNJL', Aliases=[], description='cyclin J like', other_designations='cyclin-J-like protein', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160249083, end_position_on_the_genomic_accession=160339570, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    79618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79618, CurrentID=0, Status='live', Symbol='HMBOX1', Aliases=['HNF1LA', 'HOT1', 'PBHNF', 'TAH1'], description='homeobox containing 1', other_designations='homeobox-containing protein 1|homeobox telomere-binding protein 1|homeobox-containing protein PBHNF|telomere-associated homeobox-containing protein 1', map_location='8p21.1-p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28890394, end_position_on_the_genomic_accession=29064945, orientation='plus', exon_count=22, OMIM=[618610], no_hdr0=''),
    79621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79621, CurrentID=0, Status='live', Symbol='RNASEH2B', Aliases=['AGS2', 'DLEU8'], description='ribonuclease H2 subunit B', other_designations='ribonuclease H2 subunit B|Aicardi-Goutieres syndrome 2 protein|RNase H2 subunit B|deleted in lymphocytic leukemia 8|ribonuclease HI subunit B', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=50909678, end_position_on_the_genomic_accession=50970462, orientation='plus', exon_count=17, OMIM=[610326], no_hdr0=''),
    79622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79622, CurrentID=0, Status='live', Symbol='SNRNP25', Aliases=['C16orf33'], description='small nuclear ribonucleoprotein U11/U12 subunit 25', other_designations='U11/U12 small nuclear ribonucleoprotein 25 kDa protein|U11/U12 snRNP 25 kDa protein|U11/U12 snRNP 25K|minus-99 protein|small nuclear ribonucleoprotein 25kDa (U11/U12)|small nuclear ribonucleoprotein, U11/U12 25kDa subunit', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53828, end_position_on_the_genomic_accession=57669, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79623, CurrentID=0, Status='live', Symbol='GALNT14', Aliases=['GALNT15', 'GalNac-T10', 'GalNac-T14'], description='polypeptide N-acetylgalactosaminyltransferase 14', other_designations='polypeptide N-acetylgalactosaminyltransferase 14|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 14|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase T10|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 14 (GalNAc-T14)|polypeptide GalNAc transferase 14|polypeptide N-acetylgalactosaminyltransferase 15|pp-GaNTase 14|protein-UDP acetylgalactosaminyltransferase 14', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=30888518, end_position_on_the_genomic_accession=31138440, orientation='minus', exon_count=22, OMIM=[608225], no_hdr0=''),
    79624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79624, CurrentID=0, Status='live', Symbol='ARMT1', Aliases=['C6orf211'], description='acidic residue methyltransferase 1', other_designations='damage-control phosphatase ARMT1|UPF0364 protein C6orf211|protein-glutamate O-methyltransferase|sugar phosphate phosphatase ARMT1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151452466, end_position_on_the_genomic_accession=151470101, orientation='plus', exon_count=5, OMIM=[616332], no_hdr0=''),
    79625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79625, CurrentID=0, Status='live', Symbol='NDNF', Aliases=['C4orf31', 'HH25', 'NORD'], description='neuron derived neurotrophic factor', other_designations='protein NDNF|fibronectin type-III domain-containing protein C4orf31', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121029293, end_position_on_the_genomic_accession=121072535, orientation='minus', exon_count=5, OMIM=[616506], no_hdr0=''),
    79626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79626, CurrentID=0, Status='live', Symbol='TNFAIP8L2', Aliases=['TIPE2'], description='TNF alpha induced protein 8 like 2', other_designations='tumor necrosis factor alpha-induced protein 8-like protein 2|TNF alpha-induced protein 8-like protein 2|TNFAIP8-like protein 2|inflammation factor 20|inflammation factor protein 20|tumor necrosis factor, alpha induced protein 8 like 2|tumor necrosis factor, alpha-induced protein 8-like protein 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151156649, end_position_on_the_genomic_accession=151159749, orientation='plus', exon_count=2, OMIM=[612112], no_hdr0=''),
    79627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79627, CurrentID=0, Status='live', Symbol='OGFRL1', Aliases=['dJ331H24.1'], description='opioid growth factor receptor like 1', other_designations='opioid growth factor receptor-like protein 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=71288296, end_position_on_the_genomic_accession=71309059, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    79628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79628, CurrentID=0, Status='live', Symbol='SH3TC2', Aliases=['CMT4C', 'MNMN'], description='SH3 domain and tetratricopeptide repeats 2', other_designations='SH3 domain and tetratricopeptide repeat-containing protein 2|SH3 domain and tetratricopeptide repeats-containing protein 2', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148982150, end_position_on_the_genomic_accession=149063062, orientation='minus', exon_count=17, OMIM=[608206], no_hdr0=''),
    79629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79629, CurrentID=0, Status='live', Symbol='OCEL1', Aliases=['FWP009', 'S863-9'], description='occludin/ELL domain containing 1', other_designations='occludin/ELL domain-containing protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17226226, end_position_on_the_genomic_accession=17229219, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79630, CurrentID=0, Status='live', Symbol='C1orf54', Aliases=[], description='chromosome 1 open reading frame 54', other_designations='uncharacterized protein C1orf54', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150270317, end_position_on_the_genomic_accession=150280927, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    79631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79631, CurrentID=0, Status='live', Symbol='EFL1', Aliases=['EFTUD1', 'FAM42A', 'HsT19294', 'RIA1', 'SDS2'], description='elongation factor like GTPase 1', other_designations='elongation factor-like GTPase 1|elongation factor Tu GTP binding domain containing 1|elongation factor Tu GTP-binding domain-containing protein 1|elongation factor-like 1|ribosome assembly 1 homolog', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82130223, end_position_on_the_genomic_accession=82262734, orientation='minus', exon_count=22, OMIM=[617538], no_hdr0=''),
    79632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79632, CurrentID=0, Status='live', Symbol='FAM184A', Aliases=['C6orf60'], description='family with sequence similarity 184 member A', other_designations='protein FAM184A', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=118959763, end_position_on_the_genomic_accession=119149128, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    79633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79633, CurrentID=0, Status='live', Symbol='FAT4', Aliases=['CDHF14', 'CDHR11', 'FAT-J', 'FATJ', 'HKLLS2', 'NBLA00548', 'VMLDS2'], description='FAT atypical cadherin 4', other_designations='protocadherin Fat 4|FAT tumor suppressor homolog 4|cadherin family member 14|cadherin-related family member 11|fat-like cadherin protein FAT-J|putative protein product of Nbla00548', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=125314918, end_position_on_the_genomic_accession=125492932, orientation='plus', exon_count=18, OMIM=[612411], no_hdr0=''),
    79634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79634, CurrentID=0, Status='live', Symbol='SCRN3', Aliases=['SES3'], description='secernin 3', other_designations='secernin-3', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174395730, end_position_on_the_genomic_accession=174430074, orientation='plus', exon_count=8, OMIM=[614967], no_hdr0=''),
    79635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79635, CurrentID=0, Status='live', Symbol='CCDC121', Aliases=[], description='coiled-coil domain containing 121', other_designations='coiled-coil domain-containing protein 121', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27625638, end_position_on_the_genomic_accession=27629012, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79637, CurrentID=0, Status='live', Symbol='ARMC7', Aliases=[], description='armadillo repeat containing 7', other_designations='armadillo repeat-containing protein 7', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75109969, end_position_on_the_genomic_accession=75130272, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    79639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79639, CurrentID=0, Status='live', Symbol='TMEM53', Aliases=['NET4'], description='transmembrane protein 53', other_designations='transmembrane protein 53|novel DUF829 domain-containing protein', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44653247, end_position_on_the_genomic_accession=44674481, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79641, CurrentID=0, Status='live', Symbol='ROGDI', Aliases=['KTZS'], description='rogdi atypical leucine zipper', other_designations='protein rogdi homolog|leucine zipper domain protein|rogdi homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4796967, end_position_on_the_genomic_accession=4802860, orientation='minus', exon_count=11, OMIM=[614574], no_hdr0=''),
    79642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79642, CurrentID=0, Status='live', Symbol='ARSJ', Aliases=['ASJ'], description='arylsulfatase family member J', other_designations='arylsulfatase J', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=113899929, end_position_on_the_genomic_accession=113980464, orientation='minus', exon_count=8, OMIM=[610010], no_hdr0=''),
    79643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79643, CurrentID=0, Status='live', Symbol='CHMP6', Aliases=['VPS20'], description='charged multivesicular body protein 6', other_designations='charged multivesicular body protein 6|chromatin-modifying protein 6|hVps20|vacuolar protein sorting-associated protein 20', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80991841, end_position_on_the_genomic_accession=81000133, orientation='plus', exon_count=8, OMIM=[610901], no_hdr0=''),
    79644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79644, CurrentID=0, Status='live', Symbol='SRD5A3', Aliases=['CDG1P', 'CDG1Q', 'KRIZI', 'SRD5A2L', 'SRD5A2L1'], description='steroid 5 alpha-reductase 3', other_designations='polyprenol reductase|3-oxo-5-alpha-steroid 4-dehydrogenase (NADP(+))|3-oxo-5-alpha-steroid 4-dehydrogenase 3|S5AR 3|SR type 3|probable polyprenol reductase', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55346228, end_position_on_the_genomic_accession=55373100, orientation='plus', exon_count=6, OMIM=[611715], no_hdr0=''),
    79645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79645, CurrentID=0, Status='live', Symbol='EFCAB1', Aliases=[], description='EF-hand calcium binding domain 1', other_designations='EF-hand calcium-binding domain-containing protein 1|calaxin', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=48709593, end_position_on_the_genomic_accession=48735843, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    79646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79646, CurrentID=0, Status='live', Symbol='PANK3', Aliases=[], description='pantothenate kinase 3', other_designations='pantothenate kinase 3|hPanK3|pantothenic acid kinase 3', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=168548495, end_position_on_the_genomic_accession=168579368, orientation='minus', exon_count=7, OMIM=[606161], no_hdr0=''),
    79647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79647, CurrentID=0, Status='live', Symbol='AKIRIN1', Aliases=['C1orf108', 'STRF2'], description='akirin 1', other_designations='akirin-1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38991276, end_position_on_the_genomic_accession=39006059, orientation='plus', exon_count=5, OMIM=[615164], no_hdr0=''),
    79648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79648, CurrentID=0, Status='live', Symbol='MCPH1', Aliases=['BRIT1', 'MCT'], description='microcephalin 1', other_designations='microcephalin|BRCT-repeat inhibitor of TERT expression 1|truncated microcephalin', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6406615, end_position_on_the_genomic_accession=6648508, orientation='plus', exon_count=23, OMIM=[607117], no_hdr0=''),
    79649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79649, CurrentID=0, Status='live', Symbol='MAP7D3', Aliases=['MDP3'], description='MAP7 domain containing 3', other_designations='MAP7 domain-containing protein 3', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136213220, end_position_on_the_genomic_accession=136256482, orientation='minus', exon_count=22, OMIM=[300930], no_hdr0=''),
    79650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79650, CurrentID=0, Status='live', Symbol='USB1', Aliases=['C16orf57', 'HVSL1', 'Mpn1', 'PN', 'hUsb1'], description='U6 snRNA biogenesis phosphodiesterase 1', other_designations='U6 snRNA phosphodiesterase|HVSL motif containing 1|U six biogenesis 1|U6 snRNA biogenesis 1|UPF0406 protein C16orf57|mutated in poikiloderma with neutropenia protein 1|putative U6 snRNA phosphodiesterase', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57999603, end_position_on_the_genomic_accession=58021618, orientation='plus', exon_count=9, OMIM=[613276], no_hdr0=''),
    79651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79651, CurrentID=0, Status='live', Symbol='RHBDF2', Aliases=['RHBDL5', 'RHBDL6', 'TEC', 'TOC', 'TOCG', 'iRhom2'], description='rhomboid 5 homolog 2', other_designations='inactive rhomboid protein 2|rhomboid family member 2|rhomboid veinlet-like protein 5|rhomboid veinlet-like protein 6', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76470893, end_position_on_the_genomic_accession=76501440, orientation='minus', exon_count=21, OMIM=[614404], no_hdr0=''),
    79652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79652, CurrentID=0, Status='live', Symbol='TMEM204', Aliases=['C16orf30', 'CLP24'], description='transmembrane protein 204', other_designations='transmembrane protein 204|claudin-like protein 24|claudin-like protein of 24 kDa', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1528678, end_position_on_the_genomic_accession=1555568, orientation='plus', exon_count=4, OMIM=[611002], no_hdr0=''),
    79654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79654, CurrentID=0, Status='live', Symbol='HECTD3', Aliases=[], description='HECT domain E3 ubiquitin protein ligase 3', other_designations='E3 ubiquitin-protein ligase HECTD3|HECT domain containing E3 ubiquitin protein ligase 3|HECT-type E3 ubiquitin transferase HECTD3', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45002547, end_position_on_the_genomic_accession=45011324, orientation='minus', exon_count=21, OMIM=[618638], no_hdr0=''),
    79656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79656, CurrentID=0, Status='live', Symbol='BEND5', Aliases=['C1orf165'], description='BEN domain containing 5', other_designations='BEN domain-containing protein 5', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=48727519, end_position_on_the_genomic_accession=48777489, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    79657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79657, CurrentID=0, Status='live', Symbol='RPAP3', Aliases=['Tah1', 'hSpagh'], description='RNA polymerase II associated protein 3', other_designations='RNA polymerase II-associated protein 3', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47661249, end_position_on_the_genomic_accession=47706030, orientation='minus', exon_count=17, OMIM=[611477], no_hdr0=''),
    79658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79658, CurrentID=0, Status='live', Symbol='ARHGAP10', Aliases=['GRAF2', 'PS-GAP', 'PSGAP'], description='Rho GTPase activating protein 10', other_designations='rho GTPase-activating protein 10|GTPase regulator associated with focal adhesion kinase 2|graf-related protein 2|rho-type GTPase-activating protein 10', map_location='4q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=147732063, end_position_on_the_genomic_accession=148072781, orientation='plus', exon_count=24, OMIM=[609746], no_hdr0=''),
    79659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79659, CurrentID=0, Status='live', Symbol='DYNC2H1', Aliases=['ATD3', 'DHC1b', 'DHC2', 'DNCH2', 'DYH1B', 'SRPS2B', 'SRTD3', 'hdhc11'], description='dynein cytoplasmic 2 heavy chain 1', other_designations='cytoplasmic dynein 2 heavy chain 1|dynein cytoplasmic heavy chain 2|dynein heavy chain 11|dynein heavy chain, isotype 1B|dynein, cytoplasmic, heavy polypeptide 2', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=103109426, end_position_on_the_genomic_accession=103479863, orientation='plus', exon_count=90, OMIM=[603297], no_hdr0=''),
    79660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79660, CurrentID=0, Status='live', Symbol='PPP1R3B', Aliases=['GL', 'PPP1R4', 'PTG'], description='protein phosphatase 1 regulatory subunit 3B', other_designations='protein phosphatase 1 regulatory subunit 3B|PP1 subunit R4|hepatic glycogen-targeting protein phosphatase 1 regulatory subunit GL|hepatic glycogen-targeting subunit, G(L)|protein phosphatase 1 regulatory subunit 4|protein phosphatase 1, regulatory (inhibitor) subunit 3B', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=9136255, end_position_on_the_genomic_accession=9151586, orientation='minus', exon_count=3, OMIM=[610541], no_hdr0=''),
    79661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79661, CurrentID=0, Status='live', Symbol='NEIL1', Aliases=['FPG1', 'NEI1', 'hFPG1'], description='nei like DNA glycosylase 1', other_designations='endonuclease 8-like 1|DNA endonuclease eight-like glycosylase 1|DNA glycosylase/AP lyase Neil1|DNA-(apurinic or apyrimidinic site) lyase Neil1|NEH1|endonuclease VIII|endonuclease VIII-like 1|nei endonuclease VIII-like 1|nei homolog 1|nei-like protein 1', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75346638, end_position_on_the_genomic_accession=75357115, orientation='plus', exon_count=11, OMIM=[608844], no_hdr0=''),
    79663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79663, CurrentID=0, Status='live', Symbol='HSPBAP1', Aliases=['PASS1'], description='HSPB1 associated protein 1', other_designations='HSPB1-associated protein 1|27 kDa heat shock protein-associated protein 1|HSPB (heat shock 27kDa) associated protein 1|protein associating with small stress protein PASS1', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122739997, end_position_on_the_genomic_accession=122793831, orientation='minus', exon_count=13, OMIM=[608263], no_hdr0=''),
    79664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79664, CurrentID=0, Status='live', Symbol='ICE2', Aliases=['BRCC1', 'NARG2'], description='interactor of little elongation complex ELL subunit 2', other_designations='little elongation complex subunit 2|NMDA receptor regulated 2|NMDA receptor-regulated gene 2|NMDA receptor-regulated protein 2|breast cancer cell 1|interactor of little elongator complex ELL subunit 2', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=60419609, end_position_on_the_genomic_accession=60479142, orientation='minus', exon_count=20, OMIM=[610835], no_hdr0=''),
    79665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79665, CurrentID=0, Status='live', Symbol='DHX40', Aliases=['ARG147', 'DDX40', 'PAD'], description='DEAH-box helicase 40', other_designations='probable ATP-dependent RNA helicase DHX40|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 40 (RNA helicase)|DEAH (Asp-Glu-Ala-His) box polypeptide 40|DEAH box protein 40', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59565563, end_position_on_the_genomic_accession=59608345, orientation='plus', exon_count=18, OMIM=[607570], no_hdr0=''),
    79666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79666, CurrentID=0, Status='live', Symbol='PLEKHF2', Aliases=['EAPF', 'PHAFIN2', 'ZFYVE18'], description='pleckstrin homology and FYVE domain containing 2', other_designations='pleckstrin homology domain-containing family F member 2|PH and FYVE domain-containing protein 2|PH domain-containing family F member 2|endoplasmic reticulum-associated apoptosis-involved protein containing PH and FYVE domains|pleckstrin homology domain containing, family F (with FYVE domain) member 2|zinc finger FYVE domain-containing protein 18', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=95133785, end_position_on_the_genomic_accession=95156685, orientation='plus', exon_count=2, OMIM=[615208], no_hdr0=''),
    79668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79668, CurrentID=0, Status='live', Symbol='PARP8', Aliases=['ARTD16', 'pART16'], description='poly(ADP-ribose) polymerase family member 8', other_designations='protein mono-ADP-ribosyltransferase PARP8|ADP-ribosyltransferase diphtheria toxin-like 16', map_location='5q11.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=50665831, end_position_on_the_genomic_accession=50846522, orientation='plus', exon_count=32, OMIM=[], no_hdr0=''),
    79669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79669, CurrentID=0, Status='live', Symbol='C3orf52', Aliases=['TTMP'], description='chromosome 3 open reading frame 52', other_designations='TPA-induced transmembrane protein|TPA induced trans-membrane protein|novel endoplasmic reticulum transmembrane protein', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112086349, end_position_on_the_genomic_accession=112136379, orientation='plus', exon_count=8, OMIM=[611956], no_hdr0=''),
    79670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79670, CurrentID=0, Status='live', Symbol='TUT7', Aliases=['PAPD6', 'TENT3B', 'ZCCHC6'], description='terminal uridylyl transferase 7', other_designations='terminal uridylyltransferase 7|PAP associated domain containing 6|TUTase 7|zinc finger CCHC domain-containing protein 6|zinc finger CCHC-type containing 6|zinc finger, CCHC domain containing 6', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=86287733, end_position_on_the_genomic_accession=86354497, orientation='minus', exon_count=32, OMIM=[613467], no_hdr0=''),
    79671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79671, CurrentID=0, Status='live', Symbol='NLRX1', Aliases=['CLR11.3', 'DLNB26', 'NOD26', 'NOD5', 'NOD9'], description='NLR family member X1', other_designations='NLR family member X1|NOD-like receptor X1|caterpiller protein 11.3|nucleotide-binding oligomerization domain protein 26|nucleotide-binding oligomerization domain protein 5|nucleotide-binding oligomerization domain protein 9|nucleotide-binding oligomerization domain, leucine rich repeat containing X1', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119168334, end_position_on_the_genomic_accession=119184016, orientation='plus', exon_count=13, OMIM=[611947], no_hdr0=''),
    79672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79672, CurrentID=0, Status='live', Symbol='FN3KRP', Aliases=['FN3KL'], description='fructosamine 3 kinase related protein', other_designations='ketosamine-3-kinase|FN3K-related protein|protein-psicosamine 3-kinase FN3KRP|testis secretory sperm-binding protein Li 211a', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82716706, end_position_on_the_genomic_accession=82728017, orientation='plus', exon_count=8, OMIM=[611683], no_hdr0=''),
    79673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79673, CurrentID=0, Status='live', Symbol='ZNF329', Aliases=[], description='zinc finger protein 329', other_designations='zinc finger protein 329', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58126248, end_position_on_the_genomic_accession=58155169, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79674, CurrentID=0, Status='live', Symbol='VEPH1', Aliases=['MELT', 'VEPH'], description='ventricular zone expressed PH domain containing 1', other_designations='ventricular zone-expressed PH domain-containing protein homolog 1|protein melted|ventricular zone expressed PH domain homolog 1', map_location='3q25.31-q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=157259742, end_position_on_the_genomic_accession=157503777, orientation='minus', exon_count=19, OMIM=[609594], no_hdr0=''),
    79675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79675, CurrentID=0, Status='live', Symbol='FASTKD1', Aliases=[], description='FAST kinase domains 1', other_designations='FAST kinase domain-containing protein 1, mitochondrial', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169527880, end_position_on_the_genomic_accession=169573916, orientation='minus', exon_count=15, OMIM=[617529], no_hdr0=''),
    79676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79676, CurrentID=0, Status='live', Symbol='OGFOD2', Aliases=[], description='2-oxoglutarate and iron dependent oxygenase domain containing 2', other_designations='2-oxoglutarate and iron-dependent oxygenase domain-containing protein 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122974726, end_position_on_the_genomic_accession=122980042, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    79677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79677, CurrentID=0, Status='live', Symbol='SMC6', Aliases=['SMC-6L1', 'hSMC6', 'SMC6'], description='structural maintenance of chromosomes 6', other_designations='structural maintenance of chromosomes protein 6|SMC protein 6|SMC6 structural maintenance of chromosomes 6-like 1', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17663812, end_position_on_the_genomic_accession=17753833, orientation='minus', exon_count=30, OMIM=[609387], no_hdr0=''),
    79679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79679, CurrentID=0, Status='live', Symbol='VTCN1', Aliases=['B7-H4', 'B7H4', 'B7S1', 'B7X', 'B7h.5', 'PRO1291', 'VCTN1'], description='V-set domain containing T cell activation inhibitor 1', other_designations='V-set domain-containing T-cell activation inhibitor 1|B7 family member, H4|B7 homolog 4|B7 superfamily member 1|T cell costimulatory molecule B7x|immune costimulatory protein B7-H4', map_location='1p13.1-p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117143587, end_position_on_the_genomic_accession=117210985, orientation='minus', exon_count=9, OMIM=[608162], no_hdr0=''),
    79680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79680, CurrentID=0, Status='live', Symbol='RTL10', Aliases=['BOP', 'C22orf29'], description='retrotransposon Gag like 10', other_designations='protein Bop|BH3-only protein|retrotransposon Gag-like protein 10', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19846146, end_position_on_the_genomic_accession=19854874, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    79682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79682, CurrentID=0, Status='live', Symbol='CENPU', Aliases=['CENP5050', 'KLIP1', 'MLF1IP', 'PBIP1', 'CENPU'], description='centromere protein U', other_designations='centromere protein U|KSHV latent nuclear antigen interacting protein 1|MLF1 interacting protein|centromere protein of 50 kDa|interphase centromere complex protein 24|polo-box-interacting protein 1', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184694085, end_position_on_the_genomic_accession=184734096, orientation='minus', exon_count=14, OMIM=[611511], no_hdr0=''),
    79683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79683, CurrentID=0, Status='live', Symbol='ZDHHC14', Aliases=['NEW1CP'], description='zinc finger DHHC-type palmitoyltransferase 14', other_designations='palmitoyltransferase ZDHHC14|DHHC domain-containing cysteine-rich protein 14|DHHC-14|NEW1 domain-containing protein|probable palmitoyltransferase ZDHHC14|zinc finger DHHC domain-containing protein 14|zinc finger DHHC-type containing 14|zinc finger, DHHC domain containing 14', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=157381190, end_position_on_the_genomic_accession=157678157, orientation='plus', exon_count=16, OMIM=[619295], no_hdr0=''),
    79684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79684, CurrentID=0, Status='live', Symbol='MSANTD2', Aliases=['C11orf61'], description='Myb/SANT DNA binding domain containing 2', other_designations='myb/SANT-like DNA-binding domain-containing protein 2|Myb/SANT-like DNA-binding domain containing 2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124766492, end_position_on_the_genomic_accession=124800972, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79685, CurrentID=0, Status='live', Symbol='SAP30L', Aliases=['NS4ATP2'], description='SAP30 like', other_designations='histone deacetylase complex subunit SAP30L|HCV non-structural protein 4A-transactivated protein 2|Sin3A associated protein p30-like|sin3 corepressor complex subunit SAP30L|sin3-associated protein p30-like', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=154445969, end_position_on_the_genomic_accession=154461053, orientation='plus', exon_count=5, OMIM=[610398], no_hdr0=''),
    79689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79689, CurrentID=0, Status='live', Symbol='STEAP4', Aliases=['STAMP2', 'SchLAH', 'TIARP', 'TNFAIP9'], description='STEAP4 metalloreductase', other_designations='metalloreductase STEAP4|STEAP family member 4|seven chromosome locus associated with HCC|six transmembrane prostate protein 2|six-transmembrane epithelial antigen of prostate 4|sixTransMembrane protein of prostate 2|tumor necrosis factor, alpha-induced protein 9|tumor necrosis-alpha-induced adipose-related protein', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=88270892, end_position_on_the_genomic_accession=88306894, orientation='minus', exon_count=6, OMIM=[611098], no_hdr0=''),
    79690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79690, CurrentID=0, Status='live', Symbol='GAL3ST4', Aliases=['GAL3ST-4'], description='galactose-3-O-sulfotransferase 4', other_designations="galactose-3-O-sulfotransferase 4|beta-galactose-3-O-sulfotransferase 4|gal-beta-1,3-GalNAc 3'-sulfotransferase", map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100159244, end_position_on_the_genomic_accession=100168617, orientation='minus', exon_count=4, OMIM=[608235], no_hdr0=''),
    79691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79691, CurrentID=0, Status='live', Symbol='QTRT2', Aliases=['QTRTD1'], description='queuine tRNA-ribosyltransferase accessory subunit 2', other_designations='queuine tRNA-ribosyltransferase accessory subunit 2|queuine tRNA-ribosyltransferase domain containing 1', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=114056737, end_position_on_the_genomic_accession=114088422, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    79692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79692, CurrentID=0, Status='live', Symbol='ZNF322', Aliases=['HCG12A', 'ZNF388', 'ZNF489', 'ZNF322'], description='zinc finger protein 322', other_designations='zinc finger protein 322|HLA complex group 12|zinc finger protein 322A|zinc finger protein 388|zinc finger protein 489', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=26634383, end_position_on_the_genomic_accession=26659746, orientation='minus', exon_count=5, OMIM=[610847], no_hdr0=''),
    79693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79693, CurrentID=0, Status='live', Symbol='YRDC', Aliases=['DRIP3', 'IRIP', 'SUA5'], description='yrdC N6-threonylcarbamoyltransferase domain containing', other_designations='yrdC domain-containing protein, mitochondrial|dopamine receptor interacting protein 3|hIRIP|ischemia/reperfusion inducible protein|ischemia/reperfusion-inducible protein homolog|yrdC N(6)-threonylcarbamoyltransferase domain containing|yrdC domain containing', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37802945, end_position_on_the_genomic_accession=37808208, orientation='minus', exon_count=5, OMIM=[612276], no_hdr0=''),
    79694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79694, CurrentID=0, Status='live', Symbol='MANEA', Aliases=['ENDO', 'hEndo'], description='mannosidase endo-alpha', other_designations='glycoprotein endo-alpha-1,2-mannosidase|alpha 1,2-endomannosidase|endo-alpha mannosidase|endomannosidase|mandaselin', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=95577535, end_position_on_the_genomic_accession=95609452, orientation='plus', exon_count=6, OMIM=[612327], no_hdr0=''),
    79695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79695, CurrentID=0, Status='live', Symbol='GALNT12', Aliases=['CRCS1', 'GalNAc-T12'], description='polypeptide N-acetylgalactosaminyltransferase 12', other_designations='polypeptide N-acetylgalactosaminyltransferase 12|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 12|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 12 (GalNAc-T12)|colorectal cancer, susceptibility to 1|polypeptide GalNAc transferase 12|pp-GaNTase 12|protein-UDP acetylgalactosaminyltransferase 12', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98807670, end_position_on_the_genomic_accession=98850081, orientation='plus', exon_count=13, OMIM=[610290], no_hdr0=''),
    79696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79696, CurrentID=0, Status='live', Symbol='ZC2HC1C', Aliases=['C14orf140', 'FAM164C'], description='zinc finger C2HC-type containing 1C', other_designations='zinc finger C2HC domain-containing protein 1C|family with sequence similarity 164, member C|protein FAM164C', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75069628, end_position_on_the_genomic_accession=75079988, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79697, CurrentID=0, Status='live', Symbol='RIOX1', Aliases=['C14orf169', 'JMJD9', 'MAPJD', 'NO66', 'ROX', 'URLC2', 'hsNO66'], description='ribosomal oxygenase 1', other_designations='ribosomal oxygenase 1|60S ribosomal protein L8 histidine hydroxylase|MYC-associated protein with JmjC domain|bifunctional lysine-specific demethylase and histidyl-hydroxylase NO66|histone lysine demethylase NO66|lysine-specific demethylase NO66|nucleolar protein 66|ribosomal oxygenase NO66|up-regulated in lung cancer 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73490933, end_position_on_the_genomic_accession=73493394, orientation='plus', exon_count=1, OMIM=[611919], no_hdr0=''),
    79698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79698, CurrentID=0, Status='live', Symbol='ZMAT4', Aliases=[], description='zinc finger matrin-type 4', other_designations='zinc finger matrin-type protein 4', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=40522766, end_position_on_the_genomic_accession=40897828, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    79699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79699, CurrentID=0, Status='live', Symbol='ZYG11B', Aliases=['ZYG11'], description='zyg-11 family member B, cell cycle regulator', other_designations='protein zyg-11 homolog B|zyg-11 homolog B', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52726453, end_position_on_the_genomic_accession=52827336, orientation='plus', exon_count=16, OMIM=[618673], no_hdr0=''),
    79701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79701, CurrentID=0, Status='live', Symbol='OGFOD3', Aliases=['C17orf101'], description='2-oxoglutarate and iron dependent oxygenase domain containing 3', other_designations='2-oxoglutarate and iron-dependent oxygenase domain-containing protein 3|PKHD domain-containing transmembrane protein C17orf101', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82389210, end_position_on_the_genomic_accession=82418637, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    79703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79703, CurrentID=0, Status='live', Symbol='C11orf80', Aliases=['HYDM4', 'TOP6BL', 'TOPOVIBL'], description='chromosome 11 open reading frame 80', other_designations='type 2 DNA topoisomerase 6 subunit B-like|type 2 DNA topoisomerase VI subunit B-like', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66744736, end_position_on_the_genomic_accession=66843516, orientation='plus', exon_count=17, OMIM=[616109], no_hdr0=''),
    79705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79705, CurrentID=0, Status='live', Symbol='LRRK1', Aliases=['RIPK6', 'Roco1'], description='leucine rich repeat kinase 1', other_designations='leucine-rich repeat serine/threonine-protein kinase 1', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=100919017, end_position_on_the_genomic_accession=101078257, orientation='plus', exon_count=37, OMIM=[610986], no_hdr0=''),
    79706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79706, CurrentID=0, Status='live', Symbol='PRKRIP1', Aliases=['C114', 'KRBOX3'], description='PRKR interacting protein 1', other_designations='PRKR-interacting protein 1|KRAB box domain containing 3|PRKR interacting protein 1 (IL11 inducible)|likely ortholog of mouse C114 dsRNA-binding protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102396363, end_position_on_the_genomic_accession=102426666, orientation='plus', exon_count=6, OMIM=[617458], no_hdr0=''),
    79707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79707, CurrentID=0, Status='live', Symbol='NOL9', Aliases=['Grc3', 'NET6'], description='nucleolar protein 9', other_designations="polynucleotide 5'-hydroxyl-kinase NOL9|polynucleotide 5'-kinase", map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6521347, end_position_on_the_genomic_accession=6554535, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    79709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79709, CurrentID=0, Status='live', Symbol='COLGALT1', Aliases=['BSVD3', 'ColGalT 1', 'GLT25D1'], description='collagen beta(1-O)galactosyltransferase 1', other_designations='procollagen galactosyltransferase 1|glycosyltransferase 25 domain containing 1|glycosyltransferase 25 family member 1|hydroxylysine galactosyltransferase 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17555649, end_position_on_the_genomic_accession=17583159, orientation='plus', exon_count=16, OMIM=[617531], no_hdr0=''),
    79710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79710, CurrentID=0, Status='live', Symbol='MORC4', Aliases=['ZCW4', 'ZCWCC2', 'dJ75H8.2'], description='MORC family CW-type zinc finger 4', other_designations='MORC family CW-type zinc finger protein 4|zinc finger CW-type coiled-coil domain protein 2|zinc finger CW-type domain protein 4|zinc finger, CW type with coiled-coil domain 2', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106940300, end_position_on_the_genomic_accession=107000244, orientation='minus', exon_count=17, OMIM=[300970], no_hdr0=''),
    79711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79711, CurrentID=0, Status='live', Symbol='IPO4', Aliases=['Imp4'], description='importin 4', other_designations='importin-4|imp4b|importin-4b|ran-binding protein 4|ranBP4', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24180219, end_position_on_the_genomic_accession=24188816, orientation='minus', exon_count=30, OMIM=[], no_hdr0=''),
    79712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79712, CurrentID=0, Status='live', Symbol='GTDC1', Aliases=['Hmat-Xa', 'mat-Xa'], description='glycosyltransferase like domain containing 1', other_designations='glycosyltransferase-like domain-containing protein 1|glycosyltransferase-like 1|mannosyltransferase candidate|mannosyltransferase-like protein Xa', map_location='2q22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=143938068, end_position_on_the_genomic_accession=144333069, orientation='minus', exon_count=37, OMIM=[610165], no_hdr0=''),
    79713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79713, CurrentID=0, Status='live', Symbol='IGFLR1', Aliases=['TMEM149'], description='IGF like family receptor 1', other_designations='IGF-like family receptor 1|transmembrane protein 149', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35738801, end_position_on_the_genomic_accession=35742452, orientation='minus', exon_count=5, OMIM=[614143], no_hdr0=''),
    79714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79714, CurrentID=0, Status='live', Symbol='CCDC51', Aliases=['MITOK'], description='coiled-coil domain containing 51', other_designations='mitochondrial potassium channel|coiled-coil domain-containing protein 51', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48432170, end_position_on_the_genomic_accession=48446652, orientation='minus', exon_count=6, OMIM=[618585], no_hdr0=''),
    79716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79716, CurrentID=0, Status='live', Symbol='NPEPL1', Aliases=['bA261P9.2'], description='aminopeptidase like 1', other_designations='probable aminopeptidase NPEPL1', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58689131, end_position_on_the_genomic_accession=58715844, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    79717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79717, CurrentID=0, Status='live', Symbol='PPCS', Aliases=['CMD2C'], description='phosphopantothenoylcysteine synthetase', other_designations='phosphopantothenate--cysteine ligase|PPC synthetase', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42456341, end_position_on_the_genomic_accession=42473417, orientation='plus', exon_count=5, OMIM=[609853], no_hdr0=''),
    79718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79718, CurrentID=0, Status='live', Symbol='TBL1XR1', Aliases=['C21', 'DC42', 'IRA1', 'MRD41', 'TBLR1'], description='TBL1X receptor 1', other_designations='F-box-like/WD repeat-containing protein TBL1XR1|TBL1-related protein 1|nuclear receptor co-repressor/HDAC3 complex subunit|nuclear receptor corepressor/HDAC3 complex subunit TBLR1|transducin beta like 1 X-linked receptor 1', map_location='3q26.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=177019344, end_position_on_the_genomic_accession=177197482, orientation='minus', exon_count=22, OMIM=[608628], no_hdr0=''),
    79719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79719, CurrentID=0, Status='live', Symbol='AAGAB', Aliases=['KPPP1', 'PPKP1', 'PPKP1A', 'p34'], description='alpha and gamma adaptin binding protein', other_designations='alpha- and gamma-adaptin-binding protein p34', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67200667, end_position_on_the_genomic_accession=67255198, orientation='minus', exon_count=13, OMIM=[614888], no_hdr0=''),
    79720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79720, CurrentID=0, Status='live', Symbol='VPS37B', Aliases=[], description='VPS37B subunit of ESCRT-I', other_designations='vacuolar protein sorting-associated protein 37B|ESCRT-I complex subunit VPS37B|VPS37B, ESCRT-I subunit|hVps37B|vacuolar protein sorting 37 homolog B|vacuolar protein sorting 37B', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122865330, end_position_on_the_genomic_accession=122896143, orientation='minus', exon_count=9, OMIM=[610037], no_hdr0=''),
    79722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79722, CurrentID=0, Status='live', Symbol='ANKRD55', Aliases=[], description='ankyrin repeat domain 55', other_designations='ankyrin repeat domain-containing protein 55', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=56099680, end_position_on_the_genomic_accession=56233330, orientation='minus', exon_count=14, OMIM=[615189], no_hdr0=''),
    79723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79723, CurrentID=0, Status='live', Symbol='SUV39H2', Aliases=['KMT1B'], description='suppressor of variegation 3-9 homolog 2', other_designations='histone-lysine N-methyltransferase SUV39H2|H3-K9-HMTase 2|histone H3-K9 methyltransferase 2|lysine N-methyltransferase 1B|su(var)3-9 homolog 2', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14878866, end_position_on_the_genomic_accession=14904315, orientation='plus', exon_count=8, OMIM=[606503], no_hdr0=''),
    79724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79724, CurrentID=0, Status='live', Symbol='ZNF768', Aliases=[], description='zinc finger protein 768', other_designations='zinc finger protein 768', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30524004, end_position_on_the_genomic_accession=30532367, orientation='minus', exon_count=4, OMIM=[618032], no_hdr0=''),
    79725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79725, CurrentID=0, Status='live', Symbol='THAP9', Aliases=['hTh9'], description='THAP domain containing 9', other_designations='DNA transposase THAP9|THAP domain-containing protein 9', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82900684, end_position_on_the_genomic_accession=82920283, orientation='plus', exon_count=8, OMIM=[612537], no_hdr0=''),
    79726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79726, CurrentID=0, Status='live', Symbol='WDR59', Aliases=['CDW12', 'FP977', 'p90-120'], description='WD repeat domain 59', other_designations='GATOR complex protein WDR59|CDw12 antigen|WD repeat-containing protein 59', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74871362, end_position_on_the_genomic_accession=74985123, orientation='minus', exon_count=28, OMIM=[617418], no_hdr0=''),
    79727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79727, CurrentID=0, Status='live', Symbol='LIN28A', Aliases=['CSDD1', 'LIN-28', 'LIN28', 'ZCCHC1', 'lin-28A'], description='lin-28 homolog A', other_designations='protein lin-28 homolog A|RNA-binding protein LIN-28|zinc finger CCHC domain-containing protein 1|zinc finger, CCHC domain containing 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26410778, end_position_on_the_genomic_accession=26429728, orientation='plus', exon_count=5, OMIM=[611043], no_hdr0=''),
    79728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79728, CurrentID=0, Status='live', Symbol='PALB2', Aliases=['FANCN', 'PNCA3'], description='partner and localizer of BRCA2', other_designations='partner and localizer of BRCA2|mutant partner and localizer of BRCA2|truncated partner and localizer of BRCA2', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23603162, end_position_on_the_genomic_accession=23641337, orientation='minus', exon_count=14, OMIM=[610355], no_hdr0=''),
    79729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79729, CurrentID=0, Status='live', Symbol='SH3D21', Aliases=['C1orf113'], description='SH3 domain containing 21', other_designations='SH3 domain-containing protein 21|SH3 domain-containing protein C1orf113', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36306348, end_position_on_the_genomic_accession=36329221, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    79730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79730, CurrentID=0, Status='live', Symbol='NSUN7', Aliases=[], description='NOP2/Sun RNA methyltransferase family member 7', other_designations='putative methyltransferase NSUN7|NOL1/NOP2/Sun domain family member 7|NOP2/Sun domain family, member 7', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=40749874, end_position_on_the_genomic_accession=40815729, orientation='plus', exon_count=14, OMIM=[617185], no_hdr0=''),
    79731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79731, CurrentID=0, Status='live', Symbol='NARS2', Aliases=['DFNB94', 'SLM5', 'asnRS'], description='asparaginyl-tRNA synthetase 2, mitochondrial', other_designations='probable asparagine--tRNA ligase, mitochondrial|asparagine tRNA ligase 2, mitochondrial (putative)|asparaginyl-tRNA synthetase 2, mitochondrial (putative)|deafness, autosomal recessive 94|probable asparaginyl-tRNA synthetase, mitochondrial', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78435968, end_position_on_the_genomic_accession=78574864, orientation='minus', exon_count=17, OMIM=[612803], no_hdr0=''),
    79733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79733, CurrentID=0, Status='live', Symbol='E2F8', Aliases=['E2F-8'], description='E2F transcription factor 8', other_designations='transcription factor E2F8|E2F family member 8', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=19224063, end_position_on_the_genomic_accession=19241655, orientation='minus', exon_count=14, OMIM=[612047], no_hdr0=''),
    79734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79734, CurrentID=0, Status='live', Symbol='KCTD17', Aliases=[], description='potassium channel tetramerization domain containing 17', other_designations='BTB/POZ domain-containing protein KCTD17', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37051725, end_position_on_the_genomic_accession=37063390, orientation='plus', exon_count=8, OMIM=[616386], no_hdr0=''),
    79735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79735, CurrentID=0, Status='live', Symbol='TBC1D17', Aliases=[], description='TBC1 domain family member 17', other_designations='TBC1 domain family member 17', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49877531, end_position_on_the_genomic_accession=49888750, orientation='plus', exon_count=18, OMIM=[616659], no_hdr0=''),
    79736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79736, CurrentID=0, Status='live', Symbol='TEFM', Aliases=['C17orf42'], description='transcription elongation factor, mitochondrial', other_designations='transcription elongation factor, mitochondrial|transcription elongation factor of mitochondria', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30898983, end_position_on_the_genomic_accession=30907629, orientation='minus', exon_count=4, OMIM=[616422], no_hdr0=''),
    79738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79738, CurrentID=0, Status='live', Symbol='BBS10', Aliases=['C12orf58'], description='Bardet-Biedl syndrome 10', other_designations='Bardet-Biedl syndrome 10 protein', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76344474, end_position_on_the_genomic_accession=76348415, orientation='minus', exon_count=2, OMIM=[610148], no_hdr0=''),
    79739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79739, CurrentID=0, Status='live', Symbol='TTLL7', Aliases=[], description='tubulin tyrosine ligase like 7', other_designations='tubulin polyglutamylase TTLL7|testis development protein NYD-SP30|tubulin tyrosine ligase-like family, member 7|tubulin--tyrosine ligase-like protein 7', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=83865021, end_position_on_the_genomic_accession=83999141, orientation='minus', exon_count=26, OMIM=[618813], no_hdr0=''),
    79740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79740, CurrentID=0, Status='live', Symbol='ZBBX', Aliases=[], description='zinc finger B-box domain containing', other_designations='zinc finger B-box domain-containing protein 1', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=167178399, end_position_on_the_genomic_accession=167407886, orientation='minus', exon_count=34, OMIM=[], no_hdr0=''),
    79741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79741, CurrentID=0, Status='live', Symbol='CCDC7', Aliases=['BIOT2', 'BioT2-A', 'BioT2-B', 'BioT2-C', 'C10orf68'], description='coiled-coil domain containing 7', other_designations='coiled-coil domain-containing protein 7|uncharacterized protein C10orf68|epididymis secretory sperm binding protein', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=32446129, end_position_on_the_genomic_accession=32882864, orientation='plus', exon_count=59, OMIM=[], no_hdr0=''),
    79742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79742, CurrentID=0, Status='live', Symbol='DIPK2B', Aliases=['4930578C19Rik', 'CXorf36', 'DIA1R', 'EPQL1862', 'PRO3743', 'bA435K1.1'], description='divergent protein kinase domain 2B', other_designations='divergent protein kinase domain 2B|UPF0672 protein CXorf36|deleted in autism-1 related protein|deleted in autism-related protein 1|hCG1981635', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=45148373, end_position_on_the_genomic_accession=45200876, orientation='minus', exon_count=6, OMIM=[300959], no_hdr0=''),
    79744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79744, CurrentID=0, Status='live', Symbol='ZNF419', Aliases=['ZAPHIRA', 'ZNF419'], description='zinc finger protein 419', other_designations='zinc finger protein 419|zinc finger protein 419A', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57487720, end_position_on_the_genomic_accession=57496098, orientation='plus', exon_count=6, OMIM=[617410], no_hdr0=''),
    79745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79745, CurrentID=0, Status='live', Symbol='CLIP4', Aliases=['RSNL2'], description='CAP-Gly domain containing linker protein family member 4', other_designations='CAP-Gly domain-containing linker protein 4|CAP-GLY domain containing linker protein family, member 4|restin-like protein 2', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=29097681, end_position_on_the_genomic_accession=29183808, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    79746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79746, CurrentID=0, Status='live', Symbol='ECHDC3', Aliases=[], description='enoyl-CoA hydratase domain containing 3', other_designations='enoyl-CoA hydratase domain-containing protein 3, mitochondrial|enoyl Coenzyme A hydratase domain containing 3|testis tissue sperm-binding protein Li 76m', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=11742382, end_position_on_the_genomic_accession=11764070, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    79747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79747, CurrentID=0, Status='live', Symbol='ADGB', Aliases=['C6orf103', 'CAPN16'], description='androglobin', other_designations='androglobin|calpain-7-like protein', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=146598972, end_position_on_the_genomic_accession=146815462, orientation='plus', exon_count=36, OMIM=[614630], no_hdr0=''),
    79748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79748, CurrentID=0, Status='live', Symbol='LMAN1L', Aliases=['ERGIC-53L', 'ERGL'], description='lectin, mannose binding 1 like', other_designations='protein ERGIC-53-like|ERGIC53-like protein|LMAN1-like protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74812835, end_position_on_the_genomic_accession=74825754, orientation='plus', exon_count=14, OMIM=[609548], no_hdr0=''),
    79750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79750, CurrentID=0, Status='live', Symbol='ZNF385D', Aliases=['ZNF659'], description='zinc finger protein 385D', other_designations='zinc finger protein 385D|zinc finger protein 659', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=21412218, end_position_on_the_genomic_accession=22372641, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    79751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79751, CurrentID=0, Status='live', Symbol='SLC25A22', Aliases=['DEE3', 'EIEE3', 'GC-1', 'GC1', 'NET44'], description='solute carrier family 25 member 22', other_designations='mitochondrial glutamate carrier 1|glutamate/H(+) symporter 1|solute carrier family 25 (mitochondrial carrier: glutamate), member 22', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=790475, end_position_on_the_genomic_accession=798281, orientation='minus', exon_count=15, OMIM=[609302], no_hdr0=''),
    79752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79752, CurrentID=0, Status='live', Symbol='ZFAND1', Aliases=[], description='zinc finger AN1-type containing 1', other_designations='AN1-type zinc finger protein 1|zinc finger AN1-type-containing protein 1|zinc finger, AN1-type domain 1', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81701331, end_position_on_the_genomic_accession=81721304, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    79753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79753, CurrentID=0, Status='live', Symbol='SNIP1', Aliases=['PML1', 'PMRED'], description='Smad nuclear interacting protein 1', other_designations='smad nuclear-interacting protein 1|FHA domain-containing protein SNIP1|PML1 homolog', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37534449, end_position_on_the_genomic_accession=37554293, orientation='minus', exon_count=4, OMIM=[608241], no_hdr0=''),
    79754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79754, CurrentID=0, Status='live', Symbol='ASB13', Aliases=[], description='ankyrin repeat and SOCS box containing 13', other_designations='ankyrin repeat and SOCS box protein 13|ankyrin repeat domain-containing SOCS box protein Asb-13', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5638867, end_position_on_the_genomic_accession=5666595, orientation='minus', exon_count=7, OMIM=[615055], no_hdr0=''),
    79755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79755, CurrentID=0, Status='live', Symbol='ZNF750', Aliases=['ZFP750'], description='zinc finger protein 750', other_designations='zinc finger protein 750|protein ZNF750', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82829434, end_position_on_the_genomic_accession=82840022, orientation='minus', exon_count=3, OMIM=[610226], no_hdr0=''),
    79758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79758, CurrentID=0, Status='live', Symbol='DHRS12', Aliases=['SDR40C1'], description='dehydrogenase/reductase 12', other_designations='dehydrogenase/reductase SDR family member 12|dehydrogenase/reductase (SDR family) member 12|short-chain dehydrogenase/reductase family 40C member 1', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51767993, end_position_on_the_genomic_accession=51804163, orientation='minus', exon_count=14, OMIM=[616163], no_hdr0=''),
    79759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79759, CurrentID=0, Status='live', Symbol='ZNF668', Aliases=[], description='zinc finger protein 668', other_designations='zinc finger protein 668', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31060847, end_position_on_the_genomic_accession=31074240, orientation='minus', exon_count=6, OMIM=[617103], no_hdr0=''),
    79760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79760, CurrentID=0, Status='live', Symbol='GEMIN7', Aliases=['SIP3'], description='gem nuclear organelle associated protein 7', other_designations='gem-associated protein 7|gemin-7', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45075627, end_position_on_the_genomic_accession=45091518, orientation='plus', exon_count=5, OMIM=[607419], no_hdr0=''),
    79762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79762, CurrentID=0, Status='live', Symbol='C1orf115', Aliases=['RDD1'], description='chromosome 1 open reading frame 115', other_designations='uncharacterized protein C1orf115|Required for Drug-induced Death 1', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=220690363, end_position_on_the_genomic_accession=220699153, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    79763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79763, CurrentID=0, Status='live', Symbol='ISOC2', Aliases=[], description='isochorismatase domain containing 2', other_designations='isochorismatase domain-containing protein 2|isochorismatase domain-containing protein 2, mitochondrial', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55452985, end_position_on_the_genomic_accession=55461642, orientation='minus', exon_count=6, OMIM=[612928], no_hdr0=''),
    79767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79767, CurrentID=0, Status='live', Symbol='ELMO3', Aliases=['CED-12', 'CED12', 'ELMO-3'], description='engulfment and cell motility 3', other_designations='engulfment and cell motility protein 3|ced-12 homolog 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67199131, end_position_on_the_genomic_accession=67204029, orientation='plus', exon_count=20, OMIM=[606422], no_hdr0=''),
    79768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79768, CurrentID=0, Status='live', Symbol='KATNBL1', Aliases=['C15orf29'], description='katanin regulatory subunit B1 like 1', other_designations='KATNB1-like protein 1|katanin p80 subunit B-like 1', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34140674, end_position_on_the_genomic_accession=34210096, orientation='minus', exon_count=14, OMIM=[616235], no_hdr0=''),
    79770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79770, CurrentID=0, Status='live', Symbol='TXNDC15', Aliases=['BUG', 'C5orf14', 'UNQ335'], description='thioredoxin domain containing 15', other_designations='thioredoxin domain-containing protein 15|2310047H23Rik|disulfide isomerase', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134873770, end_position_on_the_genomic_accession=134901635, orientation='plus', exon_count=5, OMIM=[617778], no_hdr0=''),
    79772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79772, CurrentID=0, Status='live', Symbol='MCTP1', Aliases=[], description='multiple C2 and transmembrane domain containing 1', other_designations='multiple C2 and transmembrane domain-containing protein 1|multiple C2 domains, transmembrane 1|multiple C2-domains with two transmembrane regions 1', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=94703690, end_position_on_the_genomic_accession=95285094, orientation='minus', exon_count=31, OMIM=[616296], no_hdr0=''),
    79774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79774, CurrentID=0, Status='live', Symbol='GRTP1', Aliases=['TBC1D6'], description='growth hormone regulated TBC protein 1', other_designations='growth hormone-regulated TBC protein 1|TBC1 domain family member 6', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113323252, end_position_on_the_genomic_accession=113364158, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    79776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79776, CurrentID=0, Status='live', Symbol='ZFHX4', Aliases=['ZFH4', 'ZHF4'], description='zinc finger homeobox 4', other_designations='zinc finger homeobox protein 4|zinc-finger homeodomain protein 4', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=76681219, end_position_on_the_genomic_accession=76867285, orientation='plus', exon_count=15, OMIM=[606940], no_hdr0=''),
    79777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79777, CurrentID=0, Status='live', Symbol='ACBD4', Aliases=['HMFT0700'], description='acyl-CoA binding domain containing 4', other_designations='acyl-CoA-binding domain-containing protein 4|acyl-Coenzyme A binding domain containing 4', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45132600, end_position_on_the_genomic_accession=45144181, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    79778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79778, CurrentID=0, Status='live', Symbol='MICALL2', Aliases=['JRAB', 'MICAL-L2'], description='MICAL like 2', other_designations='MICAL-like protein 2|junctional Rab13-binding protein|molecule interacting with CasL-like 2', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1433639, end_position_on_the_genomic_accession=1459497, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    79780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79780, CurrentID=0, Status='live', Symbol='CCDC82', Aliases=['HSPC048'], description='coiled-coil domain containing 82', other_designations='coiled-coil domain-containing protein 82', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=96352765, end_position_on_the_genomic_accession=96389924, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    79781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79781, CurrentID=0, Status='live', Symbol='IQCA1', Aliases=['4930465P12Rik', 'DRC11', 'IQCA'], description='IQ motif containing with AAA domain 1', other_designations='dynein regulatory complex protein 11|IQ and AAA domain-containing protein 1|dynein regulatory complex subunit 11', map_location='2q37.2-q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=236324147, end_position_on_the_genomic_accession=236507476, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    79782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79782, CurrentID=0, Status='live', Symbol='LRRC31', Aliases=['HEL-S-293'], description='leucine rich repeat containing 31', other_designations='leucine-rich repeat-containing protein 31|epididymis secretory protein Li 293|epididymis secretory sperm binding protein', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169839172, end_position_on_the_genomic_accession=169869935, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    79783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79783, CurrentID=0, Status='live', Symbol='SUGCT', Aliases=['C7orf10', 'DERP13', 'GA3', 'ORF19'], description='succinyl-CoA:glutarate-CoA transferase', other_designations='succinate--hydroxymethylglutarate CoA-transferase|Russel-Silver syndrome candidate|dermal papilla-derived protein 13|succinylCoA:glutarate-CoA transferase', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=40134887, end_position_on_the_genomic_accession=40860763, orientation='plus', exon_count=21, OMIM=[609187], no_hdr0=''),
    79784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79784, CurrentID=0, Status='live', Symbol='MYH14', Aliases=['DFNA4', 'DFNA4A', 'FP17425', 'MHC16', 'MYH17', 'NMHC II-C', 'NMHC-II-C', 'PNMHH', 'myosin'], description='myosin heavy chain 14', other_designations='myosin-14|MYH14 variant protein|myosin heavy chain, non-muscle IIc|myosin, heavy chain 14, non-muscle|myosin, heavy polypeptide 14|non-muscle myosin heavy chain IIc|nonmuscle myosin heavy chain II-C', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50188186, end_position_on_the_genomic_accession=50310540, orientation='plus', exon_count=46, OMIM=[608568], no_hdr0=''),
    79785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79785, CurrentID=0, Status='live', Symbol='RERGL', Aliases=[], description='RERG like', other_designations='ras-related and estrogen-regulated growth inhibitor-like protein|RERG/RAS-like', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=18080869, end_position_on_the_genomic_accession=18090193, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    79786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79786, CurrentID=0, Status='live', Symbol='KLHL36', Aliases=['C16orf44'], description='kelch like family member 36', other_designations='kelch-like protein 36|kelch-like 36', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84648511, end_position_on_the_genomic_accession=84667686, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79788, CurrentID=0, Status='live', Symbol='ZNF665', Aliases=['ZFP160L'], description='zinc finger protein 665', other_designations='zinc finger protein 665', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53162424, end_position_on_the_genomic_accession=53193404, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79789, CurrentID=0, Status='live', Symbol='CLMN', Aliases=[], description='calmin', other_designations='calmin|calmin (calponin-like, transmembrane)|calponin-like transmembrane domain protein', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95181940, end_position_on_the_genomic_accession=95319908, orientation='minus', exon_count=17, OMIM=[611121], no_hdr0=''),
    79791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79791, CurrentID=0, Status='live', Symbol='FBXO31', Aliases=['FBX14', 'FBXO14', 'Fbx31', 'MRT45', 'pp2386'], description='F-box protein 31', other_designations='F-box only protein 31|SCF ubiquitin ligase specificity factor|putative breast cancer tumor-suppressor', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87326987, end_position_on_the_genomic_accession=87392121, orientation='minus', exon_count=11, OMIM=[609102], no_hdr0=''),
    79792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79792, CurrentID=0, Status='live', Symbol='GSDMD', Aliases=['DF5L', 'DFNA5L', 'FKSG10C1', 'GSDMD'], description='gasdermin D', other_designations='gasdermin-D|gasdermin domain containing 1|gasdermin domain-containing protein 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143553387, end_position_on_the_genomic_accession=143563062, orientation='plus', exon_count=13, OMIM=[617042], no_hdr0=''),
    79794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79794, CurrentID=0, Status='live', Symbol='SPRING1', Aliases=['C12orf49', 'LUR1', 'POST1', 'SPRING'], description='SREBF pathway regulator in golgi 1', other_designations='SREBP regulating gene protein|UPF0454 protein C12orf49|partner of site-1 protease', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=116710171, end_position_on_the_genomic_accession=116738069, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79796, CurrentID=0, Status='live', Symbol='ALG9', Aliases=['CDG1L', 'DIBD1', 'GIKANIS', 'LOH11CR1J'], description='ALG9 alpha-1,2-mannosyltransferase', other_designations='alpha-1,2-mannosyltransferase ALG9|asparagine-linked glycosylation 9 alpha-12-mannosyltransferase-like protein|asparagine-linked glycosylation 9 homolog (S. cerevisiae, alpha- 1,2-mannosyltransferase)|asparagine-linked glycosylation 9 homolog (yeast, alpha- 1,2-mannosyltransferase)|asparagine-linked glycosylation 9, alpha-1,2-mannosyltransferase homolog|asparagine-linked glycosylation protein 9 homolog|disrupted in bipolar affective disorder 1|disrupted in bipolar disorder protein 1|dol-P-Man dependent alpha-1,2-mannosyltransferase|dol-P-Man:Man(6)GlcNAc(2)-PP-Dol alpha-1,2-mannosyltransferase|dol-P-Man:Man(8)GlcNAc(2)-PP-Dol alpha-1,2-mannosyltransferase|dolichyl-P-Man:Man(6)GlcNAc(2)-PP-dolichol alpha-1,2-mannosyltransferase|dolichyl-P-Man:Man(8)GlcNAc(2)-PP-dolichol alpha-1,2-mannosyltransferase|loss of heterozygosity, 11, chromosomal region 1 gene J product', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111776096, end_position_on_the_genomic_accession=111871581, orientation='minus', exon_count=22, OMIM=[606941], no_hdr0=''),
    79797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79797, CurrentID=0, Status='live', Symbol='ZNF408', Aliases=['EVR6', 'RP72'], description='zinc finger protein 408', other_designations='zinc finger protein 408|PR domain zinc finger protein 17', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46701031, end_position_on_the_genomic_accession=46705912, orientation='plus', exon_count=5, OMIM=[616454], no_hdr0=''),
    79798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79798, CurrentID=0, Status='live', Symbol='ARMC5', Aliases=['AIMAH2'], description='armadillo repeat containing 5', other_designations='armadillo repeat-containing protein 5', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31458273, end_position_on_the_genomic_accession=31467167, orientation='plus', exon_count=8, OMIM=[615549], no_hdr0=''),
    79799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79799, CurrentID=0, Status='live', Symbol='UGT2A3', Aliases=[], description='UDP glucuronosyltransferase family 2 member A3', other_designations='UDP-glucuronosyltransferase 2A3|UDP glucuronosyltransferase 2 family, polypeptide A3|UDPGT 2A3', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68928460, end_position_on_the_genomic_accession=68951804, orientation='minus', exon_count=7, OMIM=[616382], no_hdr0=''),
    79800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79800, CurrentID=0, Status='live', Symbol='CARF', Aliases=['ALS2CR8', 'NYD-SP24'], description='calcium responsive transcription factor', other_designations='calcium-responsive transcription factor|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 8|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 8 protein|calcium-response factor|testis development protein NYD-SP24', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202912248, end_position_on_the_genomic_accession=202988263, orientation='plus', exon_count=24, OMIM=[607586], no_hdr0=''),
    79801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79801, CurrentID=0, Status='live', Symbol='SHCBP1', Aliases=['PAL'], description='SHC binding and spindle associated 1', other_designations='SHC SH2 domain-binding protein 1|Protein expressed in Activated Lymphocytes', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46578591, end_position_on_the_genomic_accession=46621379, orientation='minus', exon_count=15, OMIM=[611027], no_hdr0=''),
    79802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79802, CurrentID=0, Status='live', Symbol='HHIPL2', Aliases=['KIAA1822L'], description='HHIP like 2', other_designations='HHIP-like protein 2|hedgehog interacting protein-like 2', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222501521, end_position_on_the_genomic_accession=222548104, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    79803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79803, CurrentID=0, Status='live', Symbol='HPS6', Aliases=['BLOC2S3'], description='HPS6 biogenesis of lysosomal organelles complex 2 subunit 3', other_designations='Hermansky-Pudlak syndrome 6 protein|Hermansky-Pudlak syndrome-6 protein (HPS6)|ruby-eye protein homolog', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102065349, end_position_on_the_genomic_accession=102068036, orientation='plus', exon_count=1, OMIM=[607522], no_hdr0=''),
    79805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79805, CurrentID=0, Status='live', Symbol='VASH2', Aliases=[], description='vasohibin 2', other_designations='tubulinyl-Tyr carboxypeptidase 2|testicular tissue protein Li 222|vasohibin-like protein', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212950541, end_position_on_the_genomic_accession=212991585, orientation='plus', exon_count=8, OMIM=[610471], no_hdr0=''),
    79807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79807, CurrentID=0, Status='live', Symbol='GSTCD', Aliases=[], description='glutathione S-transferase C-terminal domain containing', other_designations='glutathione S-transferase C-terminal domain-containing protein', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105708778, end_position_on_the_genomic_accession=105847726, orientation='plus', exon_count=14, OMIM=[615912], no_hdr0=''),
    79809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79809, CurrentID=0, Status='live', Symbol='TTC21B', Aliases=['ATD4', 'FAP60', 'FLA17', 'IFT139', 'IFT139B', 'JBTS11', 'NPHP12', 'Nbla10696', 'SRTD4', 'THM1'], description='tetratricopeptide repeat domain 21B', other_designations='tetratricopeptide repeat protein 21B|TPR repeat protein 21B|intraflagellar transport 139 homolog|putative protein product of Nbla10696', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165873362, end_position_on_the_genomic_accession=165953781, orientation='minus', exon_count=33, OMIM=[612014], no_hdr0=''),
    79810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79810, CurrentID=0, Status='live', Symbol='PTCD2', Aliases=[], description='pentatricopeptide repeat domain 2', other_designations='pentatricopeptide repeat-containing protein 2, mitochondrial|CTC-365E16.1', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72320373, end_position_on_the_genomic_accession=72368395, orientation='plus', exon_count=12, OMIM=[615484], no_hdr0=''),
    79811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79811, CurrentID=0, Status='live', Symbol='SLTM', Aliases=['Met'], description='SAFB like transcription modulator', other_designations='SAFB-like transcription modulator|modulator of estrogen-induced transcription', map_location='15q22.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=58879050, end_position_on_the_genomic_accession=58934313, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    79812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79812, CurrentID=0, Status='live', Symbol='MMRN2', Aliases=['EMILIN-3', 'EMILIN3', 'ENDOGLYX-1'], description='multimerin 2', other_designations='multimerin-2|EMILIN-like protein EndoGlyx-1|elastin microfibril interface located protein 3|elastin microfibril interfacer 3|endoGlyx-1 p125/p140 subunit', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86935540, end_position_on_the_genomic_accession=86957615, orientation='minus', exon_count=7, OMIM=[608925], no_hdr0=''),
    79813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79813, CurrentID=0, Status='live', Symbol='EHMT1', Aliases=['EHMT1-IT1', 'EUHMTASE1', 'Eu-HMTase1', 'FP13812', 'GLP', 'GLP1', 'KLEFS1', 'KMT1D'], description='euchromatic histone lysine methyltransferase 1', other_designations='histone-lysine N-methyltransferase EHMT1|EHMT1 intronic transcript 1|G9a-like protein 1|H3-K9-HMTase 5|euchromatic histone-lysine N-methyltransferase 1|histone H3-K9 methyltransferase 5|histone-lysine N-methyltransferase, H3 lysine-9 specific 5|lysine N-methyltransferase 1D', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137619001, end_position_on_the_genomic_accession=137836127, orientation='plus', exon_count=38, OMIM=[607001], no_hdr0=''),
    79814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79814, CurrentID=0, Status='live', Symbol='AGMAT', Aliases=[], description='agmatinase', other_designations='agmatinase, mitochondrial|AUH|agmatine ureohydrolase (agmatinase)', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15571699, end_position_on_the_genomic_accession=15585051, orientation='minus', exon_count=7, OMIM=[617887], no_hdr0=''),
    79815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79815, CurrentID=0, Status='live', Symbol='NIPAL2', Aliases=['NPAL2', 'SLC57A4'], description='NIPA like domain containing 2', other_designations='NIPA-like protein 2', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98189826, end_position_on_the_genomic_accession=98294235, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    79816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79816, CurrentID=0, Status='live', Symbol='TLE6', Aliases=['GRG6', 'PREMBL'], description='TLE family member 6, subcortical maternal complex member', other_designations='transducin-like enhancer protein 6|transducin like enhancer of split 6|transducin-like enhancer of split 6 (E(sp1) homolog, Drosophila)', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2977410, end_position_on_the_genomic_accession=2995184, orientation='plus', exon_count=21, OMIM=[612399], no_hdr0=''),
    79817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79817, CurrentID=0, Status='live', Symbol='MOB3B', Aliases=['C9orf35', 'MOB1D', 'MOBKL2B'], description='MOB kinase activator 3B', other_designations='MOB kinase activator 3B|MOB kinase activator-like 2B|MOB1, Mps One Binder kinase activator-like 2B|mob1 homolog 2b|monopolar spindle 1 binding, MOB1, domain containing|mps one binder kinase activator-like 2B', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27325209, end_position_on_the_genomic_accession=27529814, orientation='minus', exon_count=4, OMIM=[617652], no_hdr0=''),
    79818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79818, CurrentID=0, Status='live', Symbol='ZNF552', Aliases=[], description='zinc finger protein 552', other_designations='zinc finger protein 552', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57807082, end_position_on_the_genomic_accession=57815989, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    79819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79819, CurrentID=0, Status='live', Symbol='DNAI4', Aliases=['DIC4', 'WDR78'], description='dynein axonemal intermediate chain 4', other_designations='dynein axonemal intermediate chain 4|dynein intermediate chain 4, axonemal|WD repeat domain 78|WD repeat-containing protein 78', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66812885, end_position_on_the_genomic_accession=66924856, orientation='minus', exon_count=19, OMIM=[619156], no_hdr0=''),
    79820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79820, CurrentID=0, Status='live', Symbol='CATSPERB', Aliases=['C14orf161', 'CatSper(beta)'], description='cation channel sperm associated auxiliary subunit beta', other_designations='cation channel sperm-associated protein subunit beta|catSper-beta|cation channel, sperm associated beta|catsper channel auxiliary subunit beta', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91580698, end_position_on_the_genomic_accession=91732086, orientation='minus', exon_count=27, OMIM=[611169], no_hdr0=''),
    79822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79822, CurrentID=0, Status='live', Symbol='ARHGAP28', Aliases=[], description='Rho GTPase activating protein 28', other_designations='rho GTPase-activating protein 28|rho-type GTPase-activating protein 28', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=6729716, end_position_on_the_genomic_accession=6915716, orientation='plus', exon_count=20, OMIM=[610592], no_hdr0=''),
    79823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79823, CurrentID=0, Status='live', Symbol='CAMKMT', Aliases=['C2orf34', 'CLNMT', 'CaM KMT', 'Cam', 'KMT'], description='calmodulin-lysine N-methyltransferase', other_designations='calmodulin-lysine N-methyltransferase', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=44361714, end_position_on_the_genomic_accession=44772592, orientation='plus', exon_count=27, OMIM=[609559], no_hdr0=''),
    79825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79825, CurrentID=0, Status='live', Symbol='EFCC1', Aliases=['C3orf73', 'CCDC48'], description='EF-hand and coiled-coil domain containing 1', other_designations='EF-hand and coiled-coil domain-containing protein 1|EF-hand domain-containing protein ENSP00000381169|coiled-coil domain containing 48|coiled-coil domain-containing protein 48', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129001304, end_position_on_the_genomic_accession=129040742, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    79827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79827, CurrentID=0, Status='live', Symbol='CLMP', Aliases=['ACAM', 'ASAM', 'CSBM', 'CSBS'], description='CXADR like membrane protein', other_designations='CXADR-like membrane protein|CAR-like membrane protein|adipocyte-specific adhesion molecule|coxsackie- and adenovirus receptor-like membrane protein', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123069872, end_position_on_the_genomic_accession=123195248, orientation='minus', exon_count=7, OMIM=[611693], no_hdr0=''),
    79828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79828, CurrentID=0, Status='live', Symbol='METTL8', Aliases=['TIP'], description='methyltransferase 8, methylcytidine', other_designations='mRNA N(3)-methylcytidine methyltransferase METTL8|methyltransferase like 8|methyltransferase-like protein 8|tension-induced/inhibited protein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171315746, end_position_on_the_genomic_accession=171434797, orientation='minus', exon_count=13, OMIM=[609525], no_hdr0=''),
    79829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79829, CurrentID=0, Status='live', Symbol='NAA40', Aliases=['NAT11', 'NatD', 'PATT1', 'hNatD'], description='N-alpha-acetyltransferase 40, NatD catalytic subunit', other_designations='N-alpha-acetyltransferase 40|N(alpha)-acetyltransferase 40, NatD catalytic subunit, homolog|N-acetyltransferase 11 (GCN5-related, putative)|N-alpha acetyl transferase 40|N-alpha-acetyltransferase D|natD catalytic subunit|protein acetyltransferase 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63938973, end_position_on_the_genomic_accession=63957322, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    79830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79830, CurrentID=0, Status='live', Symbol='ZMYM1', Aliases=['MYM'], description='zinc finger MYM-type containing 1', other_designations='zinc finger MYM-type protein 1|zinc finger, MYM domain containing 1|zinc finger, MYM-type 1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35059786, end_position_on_the_genomic_accession=35116458, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    79831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79831, CurrentID=0, Status='live', Symbol='KDM8', Aliases=['JMJD5'], description='lysine demethylase 8', other_designations='bifunctional peptidase and arginyl-hydroxylase JMJD5|JmjC arginyl-hydroxylase|L-arginine (3R)-hydroxylase KDM8|arginyl C3-hydroxylase KDM8|jmjC domain-containing protein 5|jumonji C domain-containing protein 5|jumonji domain containing 5|jumonji domain-containing protein 5|lysine (K)-specific demethylase 8|lysine-specific demethylase 8', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27203486, end_position_on_the_genomic_accession=27222305, orientation='plus', exon_count=10, OMIM=[611917], no_hdr0=''),
    79832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79832, CurrentID=0, Status='live', Symbol='QSER1', Aliases=[], description='glutamine and serine rich 1', other_designations='glutamine and serine-rich protein 1', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32892811, end_position_on_the_genomic_accession=32980270, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    79833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79833, CurrentID=0, Status='live', Symbol='GEMIN6', Aliases=[], description='gem nuclear organelle associated protein 6', other_designations='gem-associated protein 6|SIP2|gemin-6', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38778210, end_position_on_the_genomic_accession=38785002, orientation='plus', exon_count=3, OMIM=[607006], no_hdr0=''),
    79834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79834, CurrentID=0, Status='live', Symbol='PEAK1', Aliases=['SGK269'], description='pseudopodium enriched atypical kinase 1', other_designations='inactive tyrosine-protein kinase PEAK1|NKF3 kinase family member|sugen kinase 269|tyrosine-protein kinase SgK269', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=77100829, end_position_on_the_genomic_accession=77420699, orientation='minus', exon_count=24, OMIM=[614248], no_hdr0=''),
    79836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79836, CurrentID=0, Status='live', Symbol='LONRF3', Aliases=['RNF127'], description='LON peptidase N-terminal domain and ring finger 3', other_designations='LON peptidase N-terminal domain and RING finger protein 3|ring finger protein 127', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=118974614, end_position_on_the_genomic_accession=119022925, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    79837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79837, CurrentID=0, Status='live', Symbol='PIP4K2C', Aliases=['PIP5K2C'], description='phosphatidylinositol-5-phosphate 4-kinase type 2 gamma', other_designations='phosphatidylinositol 5-phosphate 4-kinase type-2 gamma|PI(5)P 4-kinase type II gamma|PIP4KII-gamma|phosphatidylinositol 4-phosphate 5-kinase|phosphatidylinositol 5-phosphate 4-kinase type II gamma|phosphatidylinositol-4-phosphate 5-kinase, type II, gamma', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57591188, end_position_on_the_genomic_accession=57603418, orientation='plus', exon_count=12, OMIM=[617104], no_hdr0=''),
    79838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79838, CurrentID=0, Status='live', Symbol='TMC5', Aliases=[], description='transmembrane channel like 5', other_designations='transmembrane channel-like protein 5', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19410539, end_position_on_the_genomic_accession=19499113, orientation='plus', exon_count=24, OMIM=[617197], no_hdr0=''),
    79839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79839, CurrentID=0, Status='live', Symbol='CCDC102B', Aliases=['ACY1L', 'AN', 'C18orf14', 'HsT1731'], description='coiled-coil domain containing 102B', other_designations='coiled-coil domain-containing protein 102B', map_location='18q22.1-q22.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=68715216, end_position_on_the_genomic_accession=69214350, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    79840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79840, CurrentID=0, Status='live', Symbol='NHEJ1', Aliases=['XLF'], description='non-homologous end joining factor 1', other_designations='non-homologous end-joining factor 1|XRCC4-like factor|nonhomologous end-joining factor 1|protein cernunnos', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219069357, end_position_on_the_genomic_accession=219160815, orientation='minus', exon_count=10, OMIM=[611290], no_hdr0=''),
    79841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79841, CurrentID=0, Status='live', Symbol='AGBL2', Aliases=['CCP2'], description='AGBL carboxypeptidase 2', other_designations='cytosolic carboxypeptidase 2|ATP/GTP binding protein like 2|cytoplasmic carboxypeptidase 2|testis tissue sperm-binding protein Li 96mP', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47659168, end_position_on_the_genomic_accession=47715382, orientation='minus', exon_count=24, OMIM=[617345], no_hdr0=''),
    79842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79842, CurrentID=0, Status='live', Symbol='ZBTB3', Aliases=[], description='zinc finger and BTB domain containing 3', other_designations='zinc finger and BTB domain-containing protein 3', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62750963, end_position_on_the_genomic_accession=62754160, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79843, CurrentID=0, Status='live', Symbol='FAM124B', Aliases=[], description='family with sequence similarity 124 member B', other_designations='protein FAM124B|family with sequence similarity 124B', map_location='2q36.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=224378698, end_position_on_the_genomic_accession=224402107, orientation='minus', exon_count=3, OMIM=[618403], no_hdr0=''),
    79844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79844, CurrentID=0, Status='live', Symbol='ZDHHC11', Aliases=['ZNF399'], description='zinc finger DHHC-type containing 11', other_designations='palmitoyltransferase ZDHHC11|DHHC-11|probable palmitoyltransferase ZDHHC11|zinc finger DHHC domain-containing protein 11|zinc finger protein 399|zinc finger, DHHC domain containing 11', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=795605, end_position_on_the_genomic_accession=863634, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    79845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79845, CurrentID=0, Status='live', Symbol='RNF122', Aliases=[], description='ring finger protein 122', other_designations='RING finger protein 122', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=33547754, end_position_on_the_genomic_accession=33567128, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    79846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79846, CurrentID=0, Status='live', Symbol='CFAP69', Aliases=['C7orf63', 'FAP69', 'SPGF24'], description='cilia and flagella associated protein 69', other_designations='cilia- and flagella-associated protein 69', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90245174, end_position_on_the_genomic_accession=90320964, orientation='plus', exon_count=34, OMIM=[617949], no_hdr0=''),
    79847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79847, CurrentID=0, Status='live', Symbol='MFSD13A', Aliases=['C10orf77', 'TMEM180', 'bA18I14.8'], description='major facilitator superfamily domain containing 13A', other_designations='transmembrane protein 180', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102460896, end_position_on_the_genomic_accession=102480197, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    79848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79848, CurrentID=0, Status='live', Symbol='CSPP1', Aliases=['CSPP', 'CSPP-L', 'JBTS21'], description='centrosome and spindle pole associated protein 1', other_designations='centrosome and spindle pole-associated protein 1', map_location='8q13.1-q13.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=67062417, end_position_on_the_genomic_accession=67198003, orientation='plus', exon_count=35, OMIM=[611654], no_hdr0=''),
    79849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79849, CurrentID=0, Status='live', Symbol='PDZD3', Aliases=['IKEPP', 'NHERF4', 'PDZK2'], description='PDZ domain containing 3', other_designations='Na(+)/H(+) exchange regulatory cofactor NHE-RF4|NHERF-4|PDZ domain containing 2|PDZ domain-containing protein 2|PDZ domain-containing protein 3|intestinal and kidney enriched PDZ protein|na/Pi cotransporter C-terminal-associated protein 2|naPi-Cap2|natrium-phosphate cotransporter IIa C-terminal-associated protein 2|sodium-hydrogen exchanger regulatory factor 4', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119185457, end_position_on_the_genomic_accession=119190218, orientation='plus', exon_count=10, OMIM=[607146], no_hdr0=''),
    79850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79850, CurrentID=0, Status='live', Symbol='TLCD3A', Aliases=['CT120', 'FAM57A'], description='TLC domain containing 3A', other_designations='TLC domain-containing protein 3A|family with sequence similarity 57 member A|membrane protein expressed in epithelial-like lung adenocarcinoma|protein FAM57A', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=732596, end_position_on_the_genomic_accession=742968, orientation='plus', exon_count=5, OMIM=[611627], no_hdr0=''),
    79852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79852, CurrentID=0, Status='live', Symbol='EPHX3', Aliases=['ABHD9', 'EH3'], description='epoxide hydrolase 3', other_designations='epoxide hydrolase 3|abhydrolase domain containing 9|abhydrolase domain-containing protein 9', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15226919, end_position_on_the_genomic_accession=15233453, orientation='minus', exon_count=9, OMIM=[617400], no_hdr0=''),
    79853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79853, CurrentID=0, Status='live', Symbol='TM4SF20', Aliases=['PRO994', 'SLI5', 'TCCE518'], description='transmembrane 4 L six family member 20', other_designations='transmembrane 4 L6 family member 20', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227362038, end_position_on_the_genomic_accession=227379306, orientation='minus', exon_count=5, OMIM=[615404], no_hdr0=''),
    79856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79856, CurrentID=0, Status='live', Symbol='SNX22', Aliases=[], description='sorting nexin 22', other_designations='sorting nexin-22', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64151698, end_position_on_the_genomic_accession=64157481, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    79858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79858, CurrentID=0, Status='live', Symbol='NEK11', Aliases=[], description='NIMA related kinase 11', other_designations='serine/threonine-protein kinase Nek11|NIMA (never in mitosis gene a)- related kinase 11', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=131026851, end_position_on_the_genomic_accession=131350465, orientation='plus', exon_count=31, OMIM=[609779], no_hdr0=''),
    79861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79861, CurrentID=0, Status='live', Symbol='TUBAL3', Aliases=[], description='tubulin alpha like 3', other_designations='tubulin alpha chain-like 3', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5393101, end_position_on_the_genomic_accession=5404828, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79862, CurrentID=0, Status='live', Symbol='ZNF669', Aliases=[], description='zinc finger protein 669', other_designations='zinc finger protein 669', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247099962, end_position_on_the_genomic_accession=247104356, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    79863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79863, CurrentID=0, Status='live', Symbol='RBFA', Aliases=['C18orf22', 'HsT169'], description='ribosome binding factor A', other_designations='putative ribosome-binding factor A, mitochondrial|ribosome binding factor A (putative)', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=80034434, end_position_on_the_genomic_accession=80050651, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    79864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79864, CurrentID=0, Status='live', Symbol='JHY', Aliases=['C11orf63'], description='junctional cadherin complex regulator', other_designations='jhy protein homolog|juvenile hydrocephalus|uncharacterized protein C11orf63', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=122882759, end_position_on_the_genomic_accession=122963862, orientation='plus', exon_count=10, OMIM=[617594], no_hdr0=''),
    79865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79865, CurrentID=0, Status='live', Symbol='TREML2', Aliases=['C6orf76', 'TLT-2', 'TLT2', 'dJ238O23.1'], description='triggering receptor expressed on myeloid cells like 2', other_designations='trem-like transcript 2 protein|triggering receptor expressed on myeloid cells-like protein 2', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41189749, end_position_on_the_genomic_accession=41201233, orientation='minus', exon_count=5, OMIM=[609715], no_hdr0=''),
    79866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79866, CurrentID=0, Status='live', Symbol='BORA', Aliases=['C13orf34'], description='BORA aurora kinase A activator', other_designations='protein aurora borealis', map_location='13q21.33', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=72727923, end_position_on_the_genomic_accession=72756196, orientation='plus', exon_count=12, OMIM=[610510], no_hdr0=''),
    79867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79867, CurrentID=0, Status='live', Symbol='TCTN2', Aliases=['C12orf38', 'JBTS24', 'MKS8', 'TECT2'], description='tectonic family member 2', other_designations='tectonic-2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123671108, end_position_on_the_genomic_accession=123708405, orientation='plus', exon_count=18, OMIM=[613846], no_hdr0=''),
    79868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79868, CurrentID=0, Status='live', Symbol='ALG13', Aliases=['CDG1S', 'CXorf45', 'DEE36', 'EIEE36', 'GLT28D1', 'MDS031', 'TDRD13', 'YGL047W'], description='ALG13 UDP-N-acetylglucosaminyltransferase subunit', other_designations='putative bifunctional UDP-N-acetylglucosamine transferase and deubiquitinase ALG13|N-acetylglucosaminyldiphosphodolichol N-acetylglucosaminyltransferase|UDP-N-acetylglucosamine transferase subunit ALG13 homolog|asparagine-linked glycosylation 13 homolog|glycosyltransferase 28 domain-containing protein 1|hematopoietic stem/progenitor cells protein MDS031|tudor domain containing 13', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111680741, end_position_on_the_genomic_accession=111764164, orientation='plus', exon_count=36, OMIM=[300776], no_hdr0=''),
    79869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79869, CurrentID=0, Status='live', Symbol='CPSF7', Aliases=['CFIm59'], description='cleavage and polyadenylation specific factor 7', other_designations='cleavage and polyadenylation specificity factor subunit 7|CPSF 59 kDa subunit|cleavage and polyadenylation specificity factor 59 kDa subunit|cleavage factor Im complex 59 kDa subunit|pre-mRNA cleavage factor I, 59 kDa subunit|pre-mRNA cleavage factor Im 59 kDa subunit', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61402651, end_position_on_the_genomic_accession=61429975, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    79870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79870, CurrentID=0, Status='live', Symbol='BAALC', Aliases=[], description='BAALC binder of MAP3K1 and KLF4', other_designations='brain and acute leukemia cytoplasmic protein|BAALC, MAP3K1 and KLF4 binding|BAALC, MEKK1 and KLF4 binding|brain and acute leukemia, cytoplasmic', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103140725, end_position_on_the_genomic_accession=103230305, orientation='plus', exon_count=5, OMIM=[606602], no_hdr0=''),
    79871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79871, CurrentID=0, Status='live', Symbol='RPAP2', Aliases=['C1orf82', 'Rtr1'], description='RNA polymerase II associated protein 2', other_designations='putative RNA polymerase II subunit B1 CTD phosphatase RPAP2', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92299050, end_position_on_the_genomic_accession=92402056, orientation='plus', exon_count=17, OMIM=[611476], no_hdr0=''),
    79872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79872, CurrentID=0, Status='live', Symbol='CBLL1', Aliases=['HAKAI', 'RNF188'], description='Cbl proto-oncogene like 1', other_designations='E3 ubiquitin-protein ligase Hakai|Cas-Br-M (murine) ecotropic retroviral transforming sequence-like 1|Cbl proto-oncogene like 1, E3 ubiquitin protein ligase|Cbl proto-oncogene, E3 ubiquitin protein ligase-like 1|E-cadherin binding protein E7|RING finger protein 188|RING-type E3 ubiquitin transferase Hakai|c-Cbl-like protein 1|casitas B-lineage lymphoma-transforming sequence-like protein 1', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107743836, end_position_on_the_genomic_accession=107764997, orientation='plus', exon_count=10, OMIM=[606872], no_hdr0=''),
    79873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79873, CurrentID=0, Status='live', Symbol='NUDT18', Aliases=['MTH3'], description='nudix hydrolase 18', other_designations='8-oxo-dGDP phosphatase NUDT18|2-hydroxy-dADP phosphatase|7,8-dihydro-8-oxoguanine phosphatase|mutT homolog 3|mutT human homolog 3|nucleoside diphosphate-linked moiety X motif 18|nudix (nucleoside diphosphate linked moiety X)-type motif 18|nudix motif 18', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22106872, end_position_on_the_genomic_accession=22110355, orientation='minus', exon_count=4, OMIM=[615791], no_hdr0=''),
    79874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79874, CurrentID=0, Status='live', Symbol='RABEP2', Aliases=['FRA'], description='rabaptin, RAB GTPase binding effector protein 2', other_designations='rab GTPase-binding effector protein 2|Rabaptin-5 beta|rabaptin-5beta', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28904421, end_position_on_the_genomic_accession=28925238, orientation='minus', exon_count=13, OMIM=[611869], no_hdr0=''),
    79875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79875, CurrentID=0, Status='live', Symbol='THSD4', Aliases=['ADAMTSL-6', 'ADAMTSL6', 'FVSY9334', 'PRO34005'], description='thrombospondin type 1 domain containing 4', other_designations='thrombospondin type-1 domain-containing protein 4|A disintegrin and metalloproteinase with thrombospondin motifs-like protein 6|ADAMTS-like protein 6|thrombospondin, type I, domain containing 4', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=71096894, end_position_on_the_genomic_accession=71783383, orientation='plus', exon_count=25, OMIM=[614476], no_hdr0=''),
    79876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79876, CurrentID=0, Status='live', Symbol='UBA5', Aliases=['DEE44', 'EIEE44', 'SCAR24', 'THIFP1', 'UBE1DC1'], description='ubiquitin like modifier activating enzyme 5', other_designations='ubiquitin-like modifier-activating enzyme 5|UBA5, ubiquitin-activating enzyme E1 homolog|UFM1-activating enzyme|ubiquitin-activating enzyme 5|ubiquitin-activating enzyme E1 domain-containing protein 1|ubiquitin-activating enzyme E1-domain containing 1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132654430, end_position_on_the_genomic_accession=132679794, orientation='plus', exon_count=13, OMIM=[610552], no_hdr0=''),
    79877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79877, CurrentID=0, Status='live', Symbol='DCAKD', Aliases=[], description='dephospho-CoA kinase domain containing', other_designations='dephospho-CoA kinase domain-containing protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45023338, end_position_on_the_genomic_accession=45061131, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    79879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79879, CurrentID=0, Status='live', Symbol='CCDC134', Aliases=[], description='coiled-coil domain containing 134', other_designations='coiled-coil domain-containing protein 134', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41800679, end_position_on_the_genomic_accession=41832164, orientation='plus', exon_count=8, OMIM=[618788], no_hdr0=''),
    79882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79882, CurrentID=0, Status='live', Symbol='ZC3H14', Aliases=['MRT56', 'MSUT-2', 'NY-REN-37', 'SUT2', 'UKp68'], description='zinc finger CCCH-type containing 14', other_designations='zinc finger CCCH domain-containing protein 14|mammalian suppressor of tau pathology-2|nuclear protein UKp68|renal carcinoma antigen NY-REN-37', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88562982, end_position_on_the_genomic_accession=88627596, orientation='plus', exon_count=20, OMIM=[613279], no_hdr0=''),
    79883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79883, CurrentID=0, Status='live', Symbol='PODNL1', Aliases=['SLRR5B'], description='podocan like 1', other_designations='podocan-like protein 1', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13931187, end_position_on_the_genomic_accession=13953383, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    79884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79884, CurrentID=0, Status='live', Symbol='MAP9', Aliases=['ASAP'], description='microtubule associated protein 9', other_designations='microtubule-associated protein 9|aster-associated protein', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=155342658, end_position_on_the_genomic_accession=155376970, orientation='minus', exon_count=14, OMIM=[610070], no_hdr0=''),
    79885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79885, CurrentID=0, Status='live', Symbol='HDAC11', Aliases=['HD11'], description='histone deacetylase 11', other_designations='histone deacetylase 11', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=13478903, end_position_on_the_genomic_accession=13506416, orientation='plus', exon_count=14, OMIM=[607226], no_hdr0=''),
    79886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79886, CurrentID=0, Status='live', Symbol='CAAP1', Aliases=['C9orf82', 'CAAP'], description='caspase activity and apoptosis inhibitor 1', other_designations='caspase activity and apoptosis inhibitor 1|conserved anti-apoptotic protein', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=26840685, end_position_on_the_genomic_accession=26892808, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    79887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79887, CurrentID=0, Status='live', Symbol='PLBD1', Aliases=[], description='phospholipase B domain containing 1', other_designations='phospholipase B-like 1|LAMA-like protein 1|PLB homolog 1|lamina ancestor homolog 1|phospholipase B domain-containing protein 1|putative phospholipase B-like 1', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14503661, end_position_on_the_genomic_accession=14567883, orientation='minus', exon_count=11, OMIM=[618486], no_hdr0=''),
    79888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79888, CurrentID=0, Status='live', Symbol='LPCAT1', Aliases=['AGPAT10', 'AGPAT9', 'AYTL2', 'LPCAT-1', 'PFAAP3', 'lpcat', 'lysoPAFAT'], description='lysophosphatidylcholine acyltransferase 1', other_designations='lysophosphatidylcholine acyltransferase 1|1-acylglycerol-3-phosphate O-acyltransferase|1-acylglycerophosphocholine O-acyltransferase|1-alkenylglycerophosphocholine O-acyltransferase|1-alkylglycerophosphocholine O-acetyltransferase|LPC acyltransferase 1|acetyl-CoA:lyso-PAF acetyltransferase|acetyl-CoA:lyso-platelet-activating factor acetyltransferase|acyltransferase-like 2|lyso-PAF acetyltransferase|lysoPC acyltransferase 1|phosphonoformate immuno-associated protein 3', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1461427, end_position_on_the_genomic_accession=1523960, orientation='minus', exon_count=18, OMIM=[610472], no_hdr0=''),
    79890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79890, CurrentID=0, Status='live', Symbol='RIN3', Aliases=[], description='Ras and Rab interactor 3', other_designations='ras and Rab interactor 3|RAB5 interacting protein 3|ras interaction/interference protein 3', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92513773, end_position_on_the_genomic_accession=92688994, orientation='plus', exon_count=15, OMIM=[610223], no_hdr0=''),
    79891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79891, CurrentID=0, Status='live', Symbol='ZNF671', Aliases=[], description='zinc finger protein 671', other_designations='zinc finger protein 671', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57719747, end_position_on_the_genomic_accession=57727637, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79892, CurrentID=0, Status='live', Symbol='MCMBP', Aliases=['C10orf119', 'MCM-BP'], description='minichromosome maintenance complex binding protein', other_designations='mini-chromosome maintenance complex-binding protein|MCM-binding protein', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119829440, end_position_on_the_genomic_accession=119873628, orientation='minus', exon_count=17, OMIM=[610909], no_hdr0=''),
    79893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79893, CurrentID=0, Status='live', Symbol='GGNBP2', Aliases=['DIF-3', 'DIF3', 'LCRG1', 'LZK1', 'ZFP403', 'ZNF403'], description='gametogenetin binding protein 2', other_designations='gametogenetin-binding protein 2|C3HC4-type zinc finger protein|laryngeal carcinoma related gene 1|laryngeal carcinoma-related protein 1|zinc finger protein 403', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36544913, end_position_on_the_genomic_accession=36589848, orientation='plus', exon_count=14, OMIM=[612275], no_hdr0=''),
    79894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79894, CurrentID=0, Status='live', Symbol='ZNF672', Aliases=[], description='zinc finger protein 672', other_designations='zinc finger protein 672', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248838219, end_position_on_the_genomic_accession=248849517, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    79895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79895, CurrentID=0, Status='live', Symbol='ATP8B4', Aliases=['ATPIM'], description='ATPase phospholipid transporting 8B4 (putative)', other_designations='probable phospholipid-transporting ATPase IM|ATPase, class I, type 8B, member 4|P4-ATPase flippase complex alpha subunit ATP8B4|potential phospholipid-transporting ATPase IM', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49858238, end_position_on_the_genomic_accession=50181851, orientation='minus', exon_count=49, OMIM=[609123], no_hdr0=''),
    79896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79896, CurrentID=0, Status='live', Symbol='THNSL1', Aliases=['TSH1'], description='threonine synthase like 1', other_designations='threonine synthase-like 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=24952319, end_position_on_the_genomic_accession=25026664, orientation='plus', exon_count=5, OMIM=[611260], no_hdr0=''),
    79897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79897, CurrentID=0, Status='live', Symbol='RPP21', Aliases=['C6orf135', 'CAT60'], description='ribonuclease P/MRP subunit p21', other_designations='ribonuclease P protein subunit p21|RNaseP protein p21|ribonuclease P/MRP 21kDa subunit|ribonucleoprotein V', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30345156, end_position_on_the_genomic_accession=30346857, orientation='plus', exon_count=5, OMIM=[612524], no_hdr0=''),
    79898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79898, CurrentID=0, Status='live', Symbol='ZNF613', Aliases=[], description='zinc finger protein 613', other_designations='zinc finger protein 613', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51927147, end_position_on_the_genomic_accession=51946621, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    79899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79899, CurrentID=0, Status='live', Symbol='PRR5L', Aliases=['PROTOR2'], description='proline rich 5 like', other_designations='proline-rich protein 5-like|Protein observed with Rictor-2|protor-2', map_location='11p13-p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36296288, end_position_on_the_genomic_accession=36465204, orientation='plus', exon_count=11, OMIM=[611728], no_hdr0=''),
    79901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79901, CurrentID=0, Status='live', Symbol='CYBRD1', Aliases=['CYB561A2', 'DCYTB', 'FRRS3'], description='cytochrome b reductase 1', other_designations='plasma membrane ascorbate-dependent reductase CYBRD1|cytochrome b561 family, member A2|duodenal cytochrome b|ferric-chelate reductase 3', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171522233, end_position_on_the_genomic_accession=171558129, orientation='plus', exon_count=5, OMIM=[605745], no_hdr0=''),
    79902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79902, CurrentID=0, Status='live', Symbol='NUP85', Aliases=['FROUNT', 'NPHS17', 'Nup75'], description='nucleoporin 85', other_designations='nuclear pore complex protein Nup85|nucleoporin 85kDa|nucleoporin Nup75|nucleoporin Nup85', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75205557, end_position_on_the_genomic_accession=75235758, orientation='plus', exon_count=23, OMIM=[170285], no_hdr0=''),
    79903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79903, CurrentID=0, Status='live', Symbol='NAA60', Aliases=['HAT4', 'NAT15', 'NatF', 'hNaa60'], description='N-alpha-acetyltransferase 60, NatF catalytic subunit', other_designations='N-alpha-acetyltransferase 60|N-acetyltransferase 15 (GCN5-related, putative)|N-alpha-acetyltransferase F|epididymis secretory sperm binding protein|histone acetyltransferase type B protein 4', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3443611, end_position_on_the_genomic_accession=3486963, orientation='plus', exon_count=9, OMIM=[614246], no_hdr0=''),
    79905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79905, CurrentID=0, Status='live', Symbol='TMC7', Aliases=[], description='transmembrane channel like 7', other_designations='transmembrane channel-like protein 7', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18983934, end_position_on_the_genomic_accession=19063942, orientation='plus', exon_count=17, OMIM=[617198], no_hdr0=''),
    79906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79906, CurrentID=0, Status='live', Symbol='MORN1', Aliases=[], description='MORN repeat containing 1', other_designations='MORN repeat-containing protein 1', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2321253, end_position_on_the_genomic_accession=2391554, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    79908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79908, CurrentID=0, Status='live', Symbol='BTNL8', Aliases=['BTN9.2'], description='butyrophilin like 8', other_designations='butyrophilin-like protein 8|B7-H5 costimulatory molecule', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180899097, end_position_on_the_genomic_accession=180952166, orientation='plus', exon_count=12, OMIM=[615606], no_hdr0=''),
    79912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79912, CurrentID=0, Status='live', Symbol='PYROXD1', Aliases=['MFM8'], description='pyridine nucleotide-disulphide oxidoreductase domain 1', other_designations='pyridine nucleotide-disulfide oxidoreductase domain-containing protein 1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21437630, end_position_on_the_genomic_accession=21471250, orientation='plus', exon_count=14, OMIM=[617220], no_hdr0=''),
    79913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79913, CurrentID=0, Status='live', Symbol='ACTR5', Aliases=['Arp5', 'INO80M'], description='actin related protein 5', other_designations='actin-related protein 5|ARP5 actin related protein 5 homolog|INO80 complex subunit M|hARP5|sarcoma antigen NY-SAR-16', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38748460, end_position_on_the_genomic_accession=38772520, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    79915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79915, CurrentID=0, Status='live', Symbol='ATAD5', Aliases=['C17orf41', 'ELG1', 'FRAG1'], description='ATPase family AAA domain containing 5', other_designations='ATPase family AAA domain-containing protein 5|chromosome fragility associated gene 1|chromosome fragility-associated gene 1 protein|enhanced level of genomic instability 1 homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30830830, end_position_on_the_genomic_accession=30895869, orientation='plus', exon_count=23, OMIM=[609534], no_hdr0=''),
    79917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79917, CurrentID=0, Status='live', Symbol='MAGIX', Aliases=['JM10', 'PDZX'], description='MAGI family member, X-linked', other_designations='PDZ domain-containing protein MAGIX|PDZ domain containing, X chromosome', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49162843, end_position_on_the_genomic_accession=49168157, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79918, CurrentID=0, Status='live', Symbol='SETD6', Aliases=[], description='SET domain containing 6, protein lysine methyltransferase', other_designations='N-lysine methyltransferase SETD6|SET domain-containing protein 6', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58515479, end_position_on_the_genomic_accession=58523842, orientation='plus', exon_count=8, OMIM=[616424], no_hdr0=''),
    79919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79919, CurrentID=0, Status='live', Symbol='MAB21L4', Aliases=['C2orf54'], description='mab-21 like 4', other_designations='protein mab-21-like 4|uncharacterized protein C2orf54', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240886048, end_position_on_the_genomic_accession=240896889, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    79921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79921, CurrentID=0, Status='live', Symbol='TCEAL4', Aliases=['NPD017', 'WEX7'], description='transcription elongation factor A like 4', other_designations='transcription elongation factor A protein-like 4|TCEA-like protein 4|epididymis secretory sperm binding protein|transcription elongation factor A (SII)-like 4|transcription elongation factor S-II protein-like 4', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103576231, end_position_on_the_genomic_accession=103587729, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    79922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79922, CurrentID=0, Status='live', Symbol='MRM1', Aliases=[], description='mitochondrial rRNA methyltransferase 1', other_designations="rRNA methyltransferase 1, mitochondrial|16S rRNA (guanosine(1145)-2'-O)-methyltransferase|16S rRNA [Gm1145] 2'-O-methyltransferase|CTB-75G16.3|mitochondrial large ribosomal RNA ribose methylase|mitochondrial rRNA methyltransferase 1 homolog", map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36601583, end_position_on_the_genomic_accession=36634698, orientation='plus', exon_count=9, OMIM=[618099], no_hdr0=''),
    79923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79923, CurrentID=0, Status='live', Symbol='NANOG', Aliases=[], description='Nanog homeobox', other_designations='homeobox protein NANOG|homeobox transcription factor Nanog|homeobox transcription factor Nanog-delta 48', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7789402, end_position_on_the_genomic_accession=7799146, orientation='plus', exon_count=4, OMIM=[607937], no_hdr0=''),
    79924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79924, CurrentID=0, Status='live', Symbol='ADM2', Aliases=['AM2', 'dJ579N16.4'], description='adrenomedullin 2', other_designations='protein ADM2|intermedin', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50481543, end_position_on_the_genomic_accession=50486437, orientation='plus', exon_count=2, OMIM=[608682], no_hdr0=''),
    79925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79925, CurrentID=0, Status='live', Symbol='SPEF2', Aliases=['CT122', 'KPL2', 'SPGF43'], description='sperm flagellar 2', other_designations='sperm flagellar protein 2|cancer/testis antigen 122|testis tissue sperm-binding protein Li 47a', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=35617367, end_position_on_the_genomic_accession=35814611, orientation='plus', exon_count=45, OMIM=[610172], no_hdr0=''),
    79927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79927, CurrentID=0, Status='live', Symbol='FAM110D', Aliases=['GRRP1'], description='family with sequence similarity 110 member D', other_designations='protein FAM110D|glycine/arginine-rich protein 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26159079, end_position_on_the_genomic_accession=26163962, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    79929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79929, CurrentID=0, Status='live', Symbol='MAP6D1', Aliases=['MAPO6D1', 'SL21'], description='MAP6 domain containing 1', other_designations='MAP6 domain-containing protein 1|21 kDa STOP-like protein|STOP-Like protein 21 kD', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183815884, end_position_on_the_genomic_accession=183825602, orientation='minus', exon_count=3, OMIM=[610593], no_hdr0=''),
    79930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79930, CurrentID=0, Status='live', Symbol='DOK3', Aliases=['DOKL'], description='docking protein 3', other_designations='docking protein 3|Dok-like protein|downstream of tyrosine kinase 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177501904, end_position_on_the_genomic_accession=177511100, orientation='minus', exon_count=9, OMIM=[611435], no_hdr0=''),
    79931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79931, CurrentID=0, Status='live', Symbol='TNIP3', Aliases=['ABIN-3', 'LIND'], description='TNFAIP3 interacting protein 3', other_designations='TNFAIP3-interacting protein 3|A20-binding inhibitor of NF-kappa-B activation 3|ABIN-3 beta|Listeria induced|TNFAIP3-interacting protein 3 beta|TNIP3 beta|listeria-induced gene protein', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121131408, end_position_on_the_genomic_accession=121227609, orientation='minus', exon_count=20, OMIM=[608019], no_hdr0=''),
    79932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79932, CurrentID=0, Status='live', Symbol='KIAA0319L', Aliases=['AAVR', 'AAVRL'], description='KIAA0319 like', other_designations='dyslexia-associated protein KIAA0319-like protein|AAV receptor like|adeno-associated virus receptor|polycystic kidney disease 1-related', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35433490, end_position_on_the_genomic_accession=35557603, orientation='minus', exon_count=26, OMIM=[613535], no_hdr0=''),
    79933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79933, CurrentID=0, Status='live', Symbol='SYNPO2L', Aliases=[], description='synaptopodin 2 like', other_designations='synaptopodin 2-like protein', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73644881, end_position_on_the_genomic_accession=73656029, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    79934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79934, CurrentID=0, Status='live', Symbol='COQ8B', Aliases=['ADCK4', 'NPHS9'], description='coenzyme Q8B', other_designations='atypical kinase COQ8B, mitochondrial|aarF domain containing kinase 4|aarF domain-containing protein kinase 4|coenzyme Q protein 8B', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40691530, end_position_on_the_genomic_accession=40716886, orientation='minus', exon_count=16, OMIM=[615567], no_hdr0=''),
    79935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79935, CurrentID=0, Status='live', Symbol='CCNP', Aliases=['CNTD2'], description='cyclin P', other_designations='cyclin-P|cyclin N-terminal domain containing 2|cyclin N-terminal domain-containing protein 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40222208, end_position_on_the_genomic_accession=40227111, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    79937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79937, CurrentID=0, Status='live', Symbol='CNTNAP3', Aliases=['CASPR3A', 'CNTNAP3'], description='contactin associated protein family member 3', other_designations='contactin-associated protein-like 3|cell recognition molecule Caspr3|contactin associated protein like 3', map_location='9p12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=39064710, end_position_on_the_genomic_accession=39288167, orientation='minus', exon_count=24, OMIM=[610517], no_hdr0=''),
    79939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79939, CurrentID=0, Status='live', Symbol='SLC35E1', Aliases=[], description='solute carrier family 35 member E1', other_designations='solute carrier family 35 member E1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16549837, end_position_on_the_genomic_accession=16572415, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    79943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79943, CurrentID=0, Status='live', Symbol='ZNF696', Aliases=[], description='zinc finger protein 696', other_designations='zinc finger protein 696', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143291417, end_position_on_the_genomic_accession=143299952, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    79944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79944, CurrentID=0, Status='live', Symbol='L2HGDH', Aliases=['C14orf160', 'L2HGA'], description='L-2-hydroxyglutarate dehydrogenase', other_designations='L-2-hydroxyglutarate dehydrogenase, mitochondrial|2-hydroxyglutarate dehydrogenase|L-alpha-hydroxyglutarate dehydrogenase|alpha-hydroxyglutarate oxidoreductase|alpha-ketoglutarate reductase|duranin', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50242434, end_position_on_the_genomic_accession=50312229, orientation='minus', exon_count=15, OMIM=[609584], no_hdr0=''),
    79946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79946, CurrentID=0, Status='live', Symbol='C10orf95', Aliases=[], description='chromosome 10 open reading frame 95', other_designations='uncharacterized protein C10orf95', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102449837, end_position_on_the_genomic_accession=102451543, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    79947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79947, CurrentID=0, Status='live', Symbol='DHDDS', Aliases=['CIT', 'CPT', 'DEDSM', 'DS', 'HDS', 'RP59', 'hCIT'], description='dehydrodolichyl diphosphate synthase subunit', other_designations='dehydrodolichyl diphosphate synthase complex subunit DHDDS|cis-IPTase|cis-isoprenyltransferase|cis-prenyl transferase|cis-prenyltransferase subunit hCIT|dedol-PP synthase|dehydrodolichyl diphosphate syntase complex subunit DHDDS|epididymis tissue protein Li 189m', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26432321, end_position_on_the_genomic_accession=26471306, orientation='plus', exon_count=9, OMIM=[608172], no_hdr0=''),
    79948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79948, CurrentID=0, Status='live', Symbol='PLPPR3', Aliases=['LPPR3', 'LPR3', 'PRG-2', 'PRG2'], description='phospholipid phosphatase related 3', other_designations='phospholipid phosphatase-related protein type 3|PAP-2-like protein 2|lipid phosphate phosphatase-related protein type 3|plasticity-related gene 2 protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=810966, end_position_on_the_genomic_accession=824244, orientation='minus', exon_count=9, OMIM=[610391], no_hdr0=''),
    79949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79949, CurrentID=0, Status='live', Symbol='PLEKHS1', Aliases=['C10orf81', 'HEL185'], description='pleckstrin homology domain containing S1', other_designations='pleckstrin homology domain-containing family S member 1|PH domain-containing family S member 1|PH domain-containing protein C10orf81|epididymis luminal protein 185|epididymis secretory sperm binding protein', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113751262, end_position_on_the_genomic_accession=113783429, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    79953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79953, CurrentID=0, Status='live', Symbol='SYNDIG1', Aliases=['C20orf39', 'DSPC2', 'IFITMD5', 'TMEM90B'], description='synapse differentiation inducing 1', other_designations='synapse differentiation-inducing gene protein 1|dispanin subfamily C member 2|interferon induced transmembrane protein domain containing 5|synapse differentiation induced gene 1|transmembrane protein 90B', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=24469629, end_position_on_the_genomic_accession=24666616, orientation='plus', exon_count=12, OMIM=[614311], no_hdr0=''),
    79954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79954, CurrentID=0, Status='live', Symbol='NOL10', Aliases=['PQBP5'], description='nucleolar protein 10', other_designations='nucleolar protein 10|H_NH0074G24.1|polyglutamine binding protein 5', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10570754, end_position_on_the_genomic_accession=10689975, orientation='minus', exon_count=24, OMIM=[616197], no_hdr0=''),
    79955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79955, CurrentID=0, Status='live', Symbol='PDZD7', Aliases=['DFNB57', 'PDZK7'], description='PDZ domain containing 7', other_designations='PDZ domain-containing protein 7|deafness, autosomal recessive 57', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101007679, end_position_on_the_genomic_accession=101031145, orientation='minus', exon_count=20, OMIM=[612971], no_hdr0=''),
    79956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79956, CurrentID=0, Status='live', Symbol='ERMP1', Aliases=['FXNA', 'KIAA1815', 'bA207C16.3'], description='endoplasmic reticulum metallopeptidase 1', other_designations='endoplasmic reticulum metallopeptidase 1|Felix-ina|aminopeptidase Fxna', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5764061, end_position_on_the_genomic_accession=5867091, orientation='minus', exon_count=20, OMIM=[611156], no_hdr0=''),
    79957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79957, CurrentID=0, Status='live', Symbol='PAQR6', Aliases=['PRdelta'], description='progestin and adipoQ receptor family member 6', other_designations='membrane progestin receptor delta|mPR delta|membrane progesterone P4 receptor delta|membrane progesterone receptor delta|progesterone and adipoQ receptor family member 6|progestin and adipoQ receptor family member VI variant 3|progestin and adipoQ receptor family member VI variant 4|progestin and adipoQ receptor family member VI variant 5', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156243320, end_position_on_the_genomic_accession=156248522, orientation='minus', exon_count=9, OMIM=[614579], no_hdr0=''),
    79958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79958, CurrentID=0, Status='live', Symbol='DENND1C', Aliases=['FAM31C'], description='DENN domain containing 1C', other_designations='DENN domain-containing protein 1C|DENN/MADD domain containing 1C|connecdenn 3|family with sequence similarity 31, member C', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6467204, end_position_on_the_genomic_accession=6481798, orientation='minus', exon_count=23, OMIM=[613634], no_hdr0=''),
    79959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79959, CurrentID=0, Status='live', Symbol='CEP76', Aliases=['C18orf9', 'HsT1705'], description='centrosomal protein 76', other_designations='centrosomal protein of 76 kDa|centrosomal protein 76kDa', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12661956, end_position_on_the_genomic_accession=12702777, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    79960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79960, CurrentID=0, Status='live', Symbol='JADE1', Aliases=['PHF17'], description='jade family PHD finger 1', other_designations='protein Jade-1|PHD finger protein 17|PHD protein Jade-1|gene for apoptosis and differentiation in epithelia|jade family PHD finger protein 1', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=128809687, end_position_on_the_genomic_accession=128875224, orientation='plus', exon_count=16, OMIM=[610514], no_hdr0=''),
    79961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79961, CurrentID=0, Status='live', Symbol='DENND2D', Aliases=[], description='DENN domain containing 2D', other_designations='DENN domain-containing protein 2D|DENN/MADD domain containing 2D|RP5-1180E21.2', map_location='1p13.3-p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111185969, end_position_on_the_genomic_accession=111204791, orientation='minus', exon_count=20, OMIM=[615111], no_hdr0=''),
    79962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79962, CurrentID=0, Status='live', Symbol='DNAJC22', Aliases=['wus'], description='DnaJ heat shock protein family (Hsp40) member C22', other_designations='dnaJ homolog subfamily C member 22|DnaJ (Hsp40) homolog, subfamily C, member 22|wurst homolog', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49346888, end_position_on_the_genomic_accession=49353690, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    79966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79966, CurrentID=0, Status='live', Symbol='SCD5', Aliases=['ACOD4', 'DFNA79', 'FADS4', 'HSCD5', 'SCD2', 'SCD4'], description='stearoyl-CoA desaturase 5', other_designations='stearoyl-CoA desaturase 5|acyl-CoA-desaturase 4|stearoyl-CoA 9-desaturase|stearoyl-CoA desaturase 2|stearoyl-CoA desaturase 4', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82629539, end_position_on_the_genomic_accession=82798796, orientation='minus', exon_count=6, OMIM=[608370], no_hdr0=''),
    79968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79968, CurrentID=0, Status='live', Symbol='WDR76', Aliases=['CDW14'], description='WD repeat domain 76', other_designations='WD repeat-containing protein 76', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43826977, end_position_on_the_genomic_accession=43868419, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    79969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79969, CurrentID=0, Status='live', Symbol='ATAT1', Aliases=['C6orf134', 'MEC17', 'Nbla00487', 'TAT', 'alpha-TAT', 'alpha-TAT1'], description='alpha tubulin acetyltransferase 1', other_designations='alpha-tubulin N-acetyltransferase 1|acetyltransferase mec-17 homolog', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30626874, end_position_on_the_genomic_accession=30646821, orientation='plus', exon_count=14, OMIM=[615556], no_hdr0=''),
    79971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79971, CurrentID=0, Status='live', Symbol='WLS', Aliases=['C1orf139', 'EVI', 'GPR177', 'MRP', 'mig-14'], description='Wnt ligand secretion mediator', other_designations='protein wntless homolog|G protein-coupled receptor 177|integral membrane protein GPR177|protein evenness interrupted homolog|putative NF-kappa-B-activating protein 373|putative NFkB activating protein 373|wntless Wnt ligand secretion mediator', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=68098459, end_position_on_the_genomic_accession=68233018, orientation='minus', exon_count=14, OMIM=[611514], no_hdr0=''),
    79973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79973, CurrentID=0, Status='live', Symbol='ZNF442', Aliases=[], description='zinc finger protein 442', other_designations='zinc finger protein 442', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12345944, end_position_on_the_genomic_accession=12372636, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    79974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79974, CurrentID=0, Status='live', Symbol='CPED1', Aliases=['C7orf58'], description='cadherin like and PC-esterase domain containing 1', other_designations='cadherin-like and PC-esterase domain-containing protein 1', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=120988711, end_position_on_the_genomic_accession=121297447, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    79977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79977, CurrentID=0, Status='live', Symbol='GRHL2', Aliases=['BOM', 'DFNA28', 'ECTDS', 'PPCD4', 'TFCP2L3'], description='grainyhead like transcription factor 2', other_designations='grainyhead-like protein 2 homolog|brother of mammalian grainyhead|brother-of-MGR|grainyhead-like 2|transcription factor CP2-like 3', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=101492439, end_position_on_the_genomic_accession=101678104, orientation='plus', exon_count=18, OMIM=[608576], no_hdr0=''),
    79979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79979, CurrentID=0, Status='live', Symbol='TRMT2B', Aliases=['CXorf34', 'dJ341D10.3'], description='tRNA methyltransferase 2 homolog B', other_designations='tRNA (uracil(54)-C(5))-methyltransferase homolog|TRM2 homolog|TRM2 tRNA methyltransferase 2 homolog B|tRNA (uracil-5-)-methyltransferase homolog', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100973359, end_position_on_the_genomic_accession=101052118, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    79980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79980, CurrentID=0, Status='live', Symbol='DSN1', Aliases=['C20orf172', 'KNL3', 'MIS13', 'dJ469A13.2', 'hKNL-3'], description='DSN1 component of MIS12 kinetochore complex', other_designations='kinetochore-associated protein DSN1 homolog|DSN1 homolog, MIS12 kinetochore complex component|DSN1, MIND kinetochore complex component, homolog|DSN1, MIS12 kinetochore complex component|kinetochore null 3 homolog', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36751795, end_position_on_the_genomic_accession=36773815, orientation='minus', exon_count=12, OMIM=[609175], no_hdr0=''),
    79981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79981, CurrentID=0, Status='live', Symbol='FRMD1', Aliases=['bA164L23.1'], description='FERM domain containing 1', other_designations='FERM domain-containing protein 1', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=168053095, end_position_on_the_genomic_accession=168093007, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    79982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79982, CurrentID=0, Status='live', Symbol='DNAJB14', Aliases=['EGNR9427', 'PRO34683'], description='DnaJ heat shock protein family (Hsp40) member B14', other_designations='dnaJ homolog subfamily B member 14|DnaJ (Hsp40) homolog, subfamily B, member 14', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99896248, end_position_on_the_genomic_accession=99946713, orientation='minus', exon_count=13, OMIM=[617487], no_hdr0=''),
    79983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79983, CurrentID=0, Status='live', Symbol='POF1B', Aliases=['POF', 'POF2B'], description='POF1B actin binding protein', other_designations='protein POF1B|premature ovarian failure protein 1B|premature ovarian failure, 1B', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=85277396, end_position_on_the_genomic_accession=85379709, orientation='minus', exon_count=17, OMIM=[300603], no_hdr0=''),
    79987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79987, CurrentID=0, Status='live', Symbol='SVEP1', Aliases=['C9orf13', 'CCP22', 'POLYDOM', 'SEL-OB', 'SELOB'], description='sushi, von Willebrand factor type A, EGF and pentraxin domain containing 1', other_designations='sushi, von Willebrand factor type A, EGF and pentraxin domain-containing protein 1|CCP module-containing protein 22|selectin-like osteoblast-derived protein|selectin-like protein|serologically defined breast cancer antigen NY-BR-38', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110365248, end_position_on_the_genomic_accession=110579741, orientation='minus', exon_count=48, OMIM=[611691], no_hdr0=''),
    79989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79989, CurrentID=0, Status='live', Symbol='TTC26', Aliases=['DYF13', 'IFT56', 'dyf-13'], description='tetratricopeptide repeat domain 26', other_designations='intraflagellar transport protein 56|TPR repeat protein 26|tetratricopeptide repeat protein 26', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139133778, end_position_on_the_genomic_accession=139191986, orientation='plus', exon_count=19, OMIM=[617453], no_hdr0=''),
    79990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79990, CurrentID=0, Status='live', Symbol='PLEKHH3', Aliases=[], description='pleckstrin homology, MyTH4 and FERM domain containing H3', other_designations='pleckstrin homology domain-containing family H member 3|PH domain-containing family H member 3|pleckstrin homology domain containing, family H (with MyTH4 domain) member 3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42667914, end_position_on_the_genomic_accession=42677045, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    79991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79991, CurrentID=0, Status='live', Symbol='STN1', Aliases=['AAF-44', 'AAF44', 'OBFC1', 'RPA-32', 'bA541N10.2'], description='STN1 subunit of CST complex', other_designations='CST complex subunit STN1|STN1, CST complex subunit|alpha accessory factor 44|oligonucleotide/oligosaccharide binding fold containing 1|oligonucleotide/oligosaccharide-binding fold-containing protein 1|replication protein A 32 kDa subunit|suppressor of cdc thirteen homolog', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103877569, end_position_on_the_genomic_accession=103918184, orientation='minus', exon_count=10, OMIM=[613128], no_hdr0=''),
    79993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79993, CurrentID=0, Status='live', Symbol='ELOVL7', Aliases=[], description='ELOVL fatty acid elongase 7', other_designations='elongation of very long chain fatty acids protein 7|3-keto acyl-CoA synthase ELOVL7|ELOVL FA elongase 7|ELOVL family member 7, elongation of long chain fatty acids|very long chain 3-ketoacyl-CoA synthase 7|very long chain 3-oxoacyl-CoA synthase 7', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=60751791, end_position_on_the_genomic_accession=60844292, orientation='minus', exon_count=15, OMIM=[614451], no_hdr0=''),
    79998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=79998, CurrentID=0, Status='live', Symbol='ANKRD53', Aliases=[], description='ankyrin repeat domain 53', other_designations='ankyrin repeat domain-containing protein 53', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70978445, end_position_on_the_genomic_accession=70986677, orientation='plus', exon_count=7, OMIM=[617009], no_hdr0=''),
    80000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80000, CurrentID=0, Status='live', Symbol='GREB1L', Aliases=['C18orf6', 'DFNA80', 'KIAA1772', 'RHDA3'], description='GREB1 like retinoic acid receptor coactivator', other_designations='GREB1-like protein|growth regulation by estrogen in breast cancer 1 like|growth regulation by estrogen in breast cancer 1-like protein|growth regulation by estrogen in breast cancer-like', map_location='18q11.1-q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=21242225, end_position_on_the_genomic_accession=21528503, orientation='plus', exon_count=34, OMIM=[617782], no_hdr0=''),
    80003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80003, CurrentID=0, Status='live', Symbol='PCNX2', Aliases=['PCNXL2'], description='pecanex 2', other_designations='pecanex-like protein 2|pecanex homolog 2', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=232983435, end_position_on_the_genomic_accession=233295730, orientation='minus', exon_count=38, OMIM=[617656], no_hdr0=''),
    80004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80004, CurrentID=0, Status='live', Symbol='ESRP2', Aliases=['RBM35B'], description='epithelial splicing regulatory protein 2', other_designations='epithelial splicing regulatory protein 2|RNA binding motif protein 35A|RNA-binding motif protein 35B|RNA-binding protein 35B', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68225968, end_position_on_the_genomic_accession=68236175, orientation='minus', exon_count=15, OMIM=[612960], no_hdr0=''),
    80005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80005, CurrentID=0, Status='live', Symbol='DOCK5', Aliases=[], description='dedicator of cytokinesis 5', other_designations='dedicator of cytokinesis protein 5', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=25184689, end_position_on_the_genomic_accession=25415711, orientation='plus', exon_count=53, OMIM=[616904], no_hdr0=''),
    80006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80006, CurrentID=0, Status='live', Symbol='TRAPPC13', Aliases=['C5orf44', 'SHLD3'], description='trafficking protein particle complex subunit 13', other_designations='trafficking protein particle complex subunit 13|REV7-interacting novel NHEJ regulator 1|Trs65-related|UPF0533 protein C5orf44|trafficking protein particle complex 13', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65625027, end_position_on_the_genomic_accession=65666233, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    80007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80007, CurrentID=0, Status='live', Symbol='C10orf88', Aliases=['PAAT'], description='chromosome 10 open reading frame 88', other_designations='ATPase PAAT|protein associated with ABC transporters|uncharacterized protein C10orf88', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122930901, end_position_on_the_genomic_accession=122954353, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    80008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80008, CurrentID=0, Status='live', Symbol='TMEM156', Aliases=[], description='transmembrane protein 156', other_designations='transmembrane protein 156', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38966009, end_position_on_the_genomic_accession=39032668, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    80010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80010, CurrentID=0, Status='live', Symbol='RMI1', Aliases=['BLAP75', 'C9orf76', 'FAAP75'], description='RecQ mediated genome instability 1', other_designations='recQ-mediated genome instability protein 1|BLM-associated polypeptide, 75 kDa|BLM-associated protein 75 kDa|RMI1, RecQ mediated genome instability 1, homolog|homolog of yeast RecQ-mediated genome instability 1 (RMI1)', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83980359, end_position_on_the_genomic_accession=84004074, orientation='plus', exon_count=6, OMIM=[610404], no_hdr0=''),
    80011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80011, CurrentID=0, Status='live', Symbol='PSME3IP1', Aliases=['C16orf94', 'CDA018', 'CDA10', 'FAM192A', 'NIP30', 'PIP30'], description='proteasome activator subunit 3 interacting protein 1', other_designations='PSME3-interacting protein|NEFA-interacting nuclear protein NIP30|PA28G interacting protein 30kDa|PA28G-interacting protein|PSME3 interacting protein 30kDa|family with sequence similarity 192 member A|protein FAM192A', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57152466, end_position_on_the_genomic_accession=57186116, orientation='minus', exon_count=15, OMIM=[617766], no_hdr0=''),
    80012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80012, CurrentID=0, Status='live', Symbol='PHC3', Aliases=['EDR3', 'HPH3'], description='polyhomeotic homolog 3', other_designations='polyhomeotic-like protein 3|early development regulator 3|early development regulatory protein 3|homolog of polyhomeotic 3|polyhomeotic like 3', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170087580, end_position_on_the_genomic_accession=170181752, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    80013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80013, CurrentID=0, Status='live', Symbol='MINDY3', Aliases=['C10orf97', 'CARP', 'DERP5', 'FAM188A', 'MST126', 'MSTP126', 'my042'], description='MINDY lysine 48 deubiquitinase 3', other_designations='ubiquitin carboxyl-terminal hydrolase MINDY-3|CARD-containing protein|MINDY deubiquitinase 3|caspase recruitment domain containing pro-apoptotic protein|dermal papilla-derived protein 5|deubiquitinating enzyme MINDY-3|family with sequence similarity 188 member A|protein FAM188A|ubiquitin carboxyl-terminal hydrolase FAM188A', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15778169, end_position_on_the_genomic_accession=15860510, orientation='minus', exon_count=19, OMIM=[611649], no_hdr0=''),
    80014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80014, CurrentID=0, Status='live', Symbol='WWC2', Aliases=['BOMB'], description='WW and C2 domain containing 2', other_designations='protein WWC2|BH3-only member B protein|WW, C2 and coiled-coil domain containing 2', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183098640, end_position_on_the_genomic_accession=183320777, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    80017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80017, CurrentID=0, Status='live', Symbol='DGLUCY', Aliases=['C14orf159'], description='D-glutamate cyclase', other_designations='D-glutamate cyclase, mitochondrial|UPF0317 protein C14orf159, mitochondrial', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91060333, end_position_on_the_genomic_accession=91225632, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    80018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80018, CurrentID=0, Status='live', Symbol='NAA25', Aliases=['C12orf30', 'MDM20', 'NAP1'], description='N-alpha-acetyltransferase 25, NatB auxiliary subunit', other_designations='N-alpha-acetyltransferase 25, NatB auxiliary subunit|N-terminal acetyltransferase B complex subunit NAA25|mitochondrial distribution and morphology 20|natB complex subunit MDM20', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112026689, end_position_on_the_genomic_accession=112108804, orientation='minus', exon_count=25, OMIM=[612755], no_hdr0=''),
    80019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80019, CurrentID=0, Status='live', Symbol='UBTD1', Aliases=[], description='ubiquitin domain containing 1', other_designations='ubiquitin domain-containing protein 1', map_location='10q24.1-q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97498924, end_position_on_the_genomic_accession=97571206, orientation='plus', exon_count=3, OMIM=[616388], no_hdr0=''),
    80020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80020, CurrentID=0, Status='live', Symbol='FOXRED2', Aliases=['ERFAD'], description='FAD dependent oxidoreductase domain containing 2', other_designations='FAD-dependent oxidoreductase domain-containing protein 2|ER flavoprotein associated with degradation|endoplasmic reticulum flavoprotein associated with degradation', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36487190, end_position_on_the_genomic_accession=36507040, orientation='minus', exon_count=9, OMIM=[613777], no_hdr0=''),
    80021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80021, CurrentID=0, Status='live', Symbol='TMEM62', Aliases=[], description='transmembrane protein 62', other_designations='transmembrane protein 62', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43133115, end_position_on_the_genomic_accession=43185147, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    80022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80022, CurrentID=0, Status='live', Symbol='MYO15B', Aliases=['MYO15BP'], description='myosin XVB', other_designations='myosin XVB|myosin XVB pseudogene|unconventional myosin XVBP pseudogene', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75587545, end_position_on_the_genomic_accession=75626851, orientation='plus', exon_count=70, OMIM=[], no_hdr0=''),
    80023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80023, CurrentID=0, Status='live', Symbol='NRSN2', Aliases=['C20orf98', 'dJ1103G7.6'], description='neurensin 2', other_designations='neurensin-2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=346775, end_position_on_the_genomic_accession=359705, orientation='plus', exon_count=11, OMIM=[610666], no_hdr0=''),
    80024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80024, CurrentID=0, Status='live', Symbol='SLC8B1', Aliases=['NCKX6', 'NCLX', 'SLC24A6'], description='solute carrier family 8 member B1', other_designations='mitochondrial sodium/calcium exchanger protein|Na(+)/K(+)/Ca(2+)-exchange protein 6|sodium/calcium exchanger protein, mitochondrial|sodium/potassium/calcium exchanger 6, mitochondrial|solute carrier family 24 (sodium/lithium/calcium exchanger), member 6|solute carrier family 24 (sodium/potassium/calcium exchanger), member 6|solute carrier family 24 member 6|solute carrier family 8 (sodium/lithium/calcium exchanger), member B1', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113298771, end_position_on_the_genomic_accession=113335116, orientation='minus', exon_count=17, OMIM=[609841], no_hdr0=''),
    80025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80025, CurrentID=0, Status='live', Symbol='PANK2', Aliases=['C20orf48', 'HARP', 'HSS', 'NBIA1', 'PKAN'], description='pantothenate kinase 2', other_designations='pantothenate kinase 2, mitochondrial|Hallervorden-Spatz syndrome|pantothenate kinase-associated neurodegeneration|pantothenic acid kinase 2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3888781, end_position_on_the_genomic_accession=3929887, orientation='plus', exon_count=10, OMIM=[606157], no_hdr0=''),
    80028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80028, CurrentID=0, Status='live', Symbol='FBXL18', Aliases=['Fbl18'], description='F-box and leucine rich repeat protein 18', other_designations='F-box/LRR-repeat protein 18', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5454425, end_position_on_the_genomic_accession=5513809, orientation='minus', exon_count=7, OMIM=[609084], no_hdr0=''),
    80031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80031, CurrentID=0, Status='live', Symbol='SEMA6D', Aliases=[], description='semaphorin 6D', other_designations='semaphorin-6D|sema domain, transmembrane domain (TM), and cytoplasmic domain, (semaphorin) 6D', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=47184089, end_position_on_the_genomic_accession=47774228, orientation='plus', exon_count=26, OMIM=[609295], no_hdr0=''),
    80032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80032, CurrentID=0, Status='live', Symbol='ZNF556', Aliases=[], description='zinc finger protein 556', other_designations='zinc finger protein 556', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2867335, end_position_on_the_genomic_accession=2883445, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    80034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80034, CurrentID=0, Status='live', Symbol='CSRNP3', Aliases=['FAM130A2', 'PPP1R73', 'TAIP-2', 'TAIP2'], description='cysteine and serine rich nuclear protein 3', other_designations='cysteine/serine-rich nuclear protein 3|TGF-beta induced apoptosis protein 2|family with sequence similarity 130, member A2|protein phosphatase 1, regulatory subunit 73', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=165469680, end_position_on_the_genomic_accession=165689407, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    80036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80036, CurrentID=0, Status='live', Symbol='TRPM3', Aliases=['GON-2', 'LTRPC3', 'MLSN2'], description='transient receptor potential cation channel subfamily M member 3', other_designations='transient receptor potential cation channel subfamily M member 3|long transient receptor potential channel 3|melastatin-2', map_location='9q21.12-q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=70529060, end_position_on_the_genomic_accession=71446971, orientation='minus', exon_count=30, OMIM=[608961], no_hdr0=''),
    80045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80045, CurrentID=0, Status='live', Symbol='GPR157', Aliases=[], description='G protein-coupled receptor 157', other_designations='G-protein coupled receptor 157|probable G-protein coupled receptor 157', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9100305, end_position_on_the_genomic_accession=9129124, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    80055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80055, CurrentID=0, Status='live', Symbol='PGAP1', Aliases=['Bst1', 'ISPD3024', 'MRT42', 'NEDDSBA', 'SPG67'], description='post-GPI attachment to proteins inositol deacylase 1', other_designations='GPI inositol-deacylase|post-GPI attachment to proteins 1|post-GPI attachment to proteins factor 1', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196833004, end_position_on_the_genomic_accession=196926995, orientation='minus', exon_count=31, OMIM=[611655], no_hdr0=''),
    80059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80059, CurrentID=0, Status='live', Symbol='LRRTM4', Aliases=[], description='leucine rich repeat transmembrane neuronal 4', other_designations='leucine-rich repeat transmembrane neuronal protein 4', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=76747685, end_position_on_the_genomic_accession=77522376, orientation='minus', exon_count=4, OMIM=[610870], no_hdr0=''),
    80063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80063, CurrentID=0, Status='live', Symbol='ATF7IP2', Aliases=['MCAF2'], description='activating transcription factor 7 interacting protein 2', other_designations='activating transcription factor 7-interacting protein 2|ATF7-interacting protein 2|MBD1-containing chromatin associated factor 2', map_location='16p13.2-p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10386061, end_position_on_the_genomic_accession=10483643, orientation='plus', exon_count=18, OMIM=[613645], no_hdr0=''),
    80067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80067, CurrentID=0, Status='live', Symbol='DCAF17', Aliases=['C20orf37', 'C2orf37'], description='DDB1 and CUL4 associated factor 17', other_designations='DDB1- and CUL4-associated factor 17', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171434166, end_position_on_the_genomic_accession=171491029, orientation='plus', exon_count=18, OMIM=[612515], no_hdr0=''),
    80070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80070, CurrentID=0, Status='live', Symbol='ADAMTS20', Aliases=['ADAM-TS20', 'ADAMTS-20', 'GON-1'], description='ADAM metallopeptidase with thrombospondin type 1 motif 20', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 20|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 20', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=43352843, end_position_on_the_genomic_accession=43552203, orientation='minus', exon_count=40, OMIM=[611681], no_hdr0=''),
    80071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80071, CurrentID=0, Status='live', Symbol='CCDC15', Aliases=[], description='coiled-coil domain containing 15', other_designations='coiled-coil domain-containing protein 15', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124954121, end_position_on_the_genomic_accession=125041489, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    80086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80086, CurrentID=0, Status='live', Symbol='TUBA4B', Aliases=['TUBA4'], description='tubulin alpha 4b', other_designations='putative tubulin-like protein alpha-4B|tubulin, alpha 4|tubulin, alpha 4b (pseudogene)', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219253243, end_position_on_the_genomic_accession=219272197, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    80095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80095, CurrentID=0, Status='live', Symbol='ZNF606', Aliases=['ZNF328'], description='zinc finger protein 606', other_designations='zinc finger protein 606|zinc finger protein 328', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57977053, end_position_on_the_genomic_accession=58003346, orientation='minus', exon_count=7, OMIM=[613905], no_hdr0=''),
    80097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80097, CurrentID=0, Status='live', Symbol='MZT2B', Aliases=['FAM128B', 'MOZART2B'], description='mitotic spindle organizing protein 2B', other_designations='mitotic-spindle organizing protein 2B|family with sequence similarity 128, member B|mitotic-spindle organizing protein associated with a ring of gamma-tubulin 2B', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130182262, end_position_on_the_genomic_accession=130190727, orientation='plus', exon_count=4, OMIM=[613450], no_hdr0=''),
    80108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80108, CurrentID=0, Status='live', Symbol='ZFP2', Aliases=['ZNF751', 'zfp-2'], description='ZFP2 zinc finger protein', other_designations='zinc finger protein 2 homolog|zinc finger protein 751', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178895913, end_position_on_the_genomic_accession=178933212, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    80110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80110, CurrentID=0, Status='live', Symbol='ZNF614', Aliases=[], description='zinc finger protein 614', other_designations='zinc finger protein 614', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52013324, end_position_on_the_genomic_accession=52028379, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    80114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80114, CurrentID=0, Status='live', Symbol='BICC1', Aliases=['BICC', 'CYSRD'], description='BicC family RNA binding protein 1', other_designations='protein bicaudal C homolog 1|FGFR2-BICC1 fusion kinase protein|bicaudal C homolog 1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=58512872, end_position_on_the_genomic_accession=58831435, orientation='plus', exon_count=29, OMIM=[614295], no_hdr0=''),
    80115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80115, CurrentID=0, Status='live', Symbol='BAIAP2L2', Aliases=[], description='BAR/IMD domain containing adaptor protein 2 like 2', other_designations='brain-specific angiogenesis inhibitor 1-associated protein 2-like protein 2|BAI1 associated protein 2 like 2|BAI1-associated protein 2-like protein 2|pinkbar|planar intestinal- and kidney-specific BAR domain protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38084889, end_position_on_the_genomic_accession=38110944, orientation='minus', exon_count=19, OMIM=[617536], no_hdr0=''),
    80117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80117, CurrentID=0, Status='live', Symbol='ARL14', Aliases=['ARF7'], description='ADP ribosylation factor like GTPase 14', other_designations='ADP-ribosylation factor-like protein 14|ADP-ribosylation factor 7|ADP-ribosylation factor-like 14', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160677160, end_position_on_the_genomic_accession=160678448, orientation='plus', exon_count=1, OMIM=[614439], no_hdr0=''),
    80119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80119, CurrentID=0, Status='live', Symbol='PIF1', Aliases=['C15orf20', 'PIF'], description="PIF1 5'-to-3' DNA helicase", other_designations="ATP-dependent DNA helicase PIF1|DNA repair and recombination helicase PIF1|PIF1 5'-to-3' DNA helicase homolog|PIF1/RRM3 DNA helicase-like protein|petite integration frequency 1", map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64815632, end_position_on_the_genomic_accession=64827173, orientation='minus', exon_count=15, OMIM=[610953], no_hdr0=''),
    80122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80122, CurrentID=0, Status='live', Symbol='MAP3K19', Aliases=['RCK', 'YSK4'], description='mitogen-activated protein kinase kinase kinase 19', other_designations='mitogen-activated protein kinase kinase kinase 19|SPS1/STE20-related protein kinase YSK4|YSK4 Sps1/Ste20-related kinase homolog|regulated in COPD kinase|regulated in COPD, protein kinase|yeast Sps1/Ste20-related kinase 4', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=134963875, end_position_on_the_genomic_accession=135047468, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    80124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80124, CurrentID=0, Status='live', Symbol='VCPIP1', Aliases=['DUBA3', 'VCIP135'], description='valosin containing protein interacting protein 1', other_designations='deubiquitinating protein VCPIP1|VCP/p47 complex-interacting 135-kDa protein|deubiquitinating protein VCIP135|valosin-containing protein p97/p47 complex-interacting protein 1|valosin-containing protein p97/p47 complex-interacting protein p135', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66628487, end_position_on_the_genomic_accession=66667231, orientation='minus', exon_count=3, OMIM=[611745], no_hdr0=''),
    80125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80125, CurrentID=0, Status='live', Symbol='CCDC33', Aliases=['CT61', 'HP11097'], description='coiled-coil domain containing 33', other_designations='coiled-coil domain-containing protein 33|cancer/testis antigen 61|hypothetical protein HP11097', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74216640, end_position_on_the_genomic_accession=74336472, orientation='plus', exon_count=31, OMIM=[618525], no_hdr0=''),
    80127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80127, CurrentID=0, Status='live', Symbol='BBOF1', Aliases=['C14orf45', 'CCDC176', 'FBB10'], description='basal body orientation factor 1', other_designations='basal body-orientation factor 1|coiled-coil domain containing 176|coiled-coil domain-containing protein 176', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74019349, end_position_on_the_genomic_accession=74078351, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    80128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80128, CurrentID=0, Status='live', Symbol='TRIM46', Aliases=['GENEY', 'TRIFIC'], description='tripartite motif containing 46', other_designations='tripartite motif-containing protein 46|gene Y protein|tripartite, fibronectin type-III and C-terminal SPRY motif protein', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155173381, end_position_on_the_genomic_accession=155184971, orientation='plus', exon_count=16, OMIM=[600986], no_hdr0=''),
    80129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80129, CurrentID=0, Status='live', Symbol='CCDC170', Aliases=['C6orf97', 'bA282P11.1'], description='coiled-coil domain containing 170', other_designations='coiled-coil domain-containing protein 170', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=151494017, end_position_on_the_genomic_accession=151621193, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    80131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80131, CurrentID=0, Status='live', Symbol='LRRC8E', Aliases=[], description='leucine rich repeat containing 8 VRAC subunit E', other_designations='volume-regulated anion channel subunit LRRC8E|leucine rich repeat containing 8 family member E|leucine-rich repeat-containing protein 8E', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7888510, end_position_on_the_genomic_accession=7902016, orientation='plus', exon_count=5, OMIM=[612891], no_hdr0=''),
    80133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80133, CurrentID=0, Status='live', Symbol='MROH9', Aliases=['ARMC11', 'C1orf129'], description='maestro heat like repeat family member 9', other_designations='maestro heat-like repeat-containing protein family member 9|armadillo repeat containing 11', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=170935471, end_position_on_the_genomic_accession=171066341, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    80135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80135, CurrentID=0, Status='live', Symbol='RPF1', Aliases=['BXDC5'], description='ribosome production factor 1 homolog', other_designations='ribosome production factor 1|2310066N05Rik|RNA processing factor 1 (RPF1)|brix domain containing 5|brix domain-containing protein 5|ribosome biogenesis protein RPF1', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84479266, end_position_on_the_genomic_accession=84498352, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    80139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80139, CurrentID=0, Status='live', Symbol='ZNF703', Aliases=['NLZ1', 'ZEPPO1', 'ZNF503L', 'ZPO1'], description='zinc finger protein 703', other_designations='zinc finger protein 703|zinc finger elbow-related proline domain protein 1', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37695782, end_position_on_the_genomic_accession=37700019, orientation='plus', exon_count=2, OMIM=[617045], no_hdr0=''),
    80142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80142, CurrentID=0, Status='live', Symbol='PTGES2', Aliases=['C9orf15', 'GBF-1', 'GBF1', 'PGES2', 'mPGES-2'], description='prostaglandin E synthase 2', other_designations='prostaglandin E synthase 2|GATE-binding factor 1|gamma-interferon-activated transcriptional element-binding factor 1|mPGE synthase-2|membrane-associated prostaglandin E synthase 2|microsomal prostaglandin E synthase-2|prostaglandin-H(2) E-isomerase', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128120693, end_position_on_the_genomic_accession=128128440, orientation='minus', exon_count=10, OMIM=[608152], no_hdr0=''),
    80143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80143, CurrentID=0, Status='live', Symbol='SIKE1', Aliases=['SIKE'], description='suppressor of IKBKE 1', other_designations='suppressor of IKBKE 1|suppressor of IKK epsilon', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114769479, end_position_on_the_genomic_accession=114780685, orientation='minus', exon_count=5, OMIM=[611656], no_hdr0=''),
    80144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80144, CurrentID=0, Status='live', Symbol='FRAS1', Aliases=['FRASRS1'], description='Fraser extracellular matrix complex subunit 1', other_designations='extracellular matrix organizing protein FRAS1|Fraser syndrome 1|extracellular matrix protein FRAS1|fraser syndrome 1 protein', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=78057323, end_position_on_the_genomic_accession=78544269, orientation='plus', exon_count=74, OMIM=[607830], no_hdr0=''),
    80145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80145, CurrentID=0, Status='live', Symbol='THOC7', Aliases=['NIF3L1BP1', 'fSAP24', 'hTREX30'], description='THO complex 7', other_designations='THO complex subunit 7 homolog|NIF3L1-binding protein 1|Ngg1 interacting factor 3 like 1 binding protein 1|THO complex 7 homolog|functional spliceosome-associated protein 24|ngg1-interacting factor 3-like protein 1-binding protein 1', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=63833870, end_position_on_the_genomic_accession=63864478, orientation='minus', exon_count=9, OMIM=[611965], no_hdr0=''),
    80146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80146, CurrentID=0, Status='live', Symbol='UXS1', Aliases=['SDR6E1', 'UGD'], description='UDP-glucuronate decarboxylase 1', other_designations='UDP-glucuronic acid decarboxylase 1|UXS-1|short chain dehydrogenase/reductase family 6E, member 12', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=106093303, end_position_on_the_genomic_accession=106194336, orientation='minus', exon_count=19, OMIM=[609749], no_hdr0=''),
    80148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80148, CurrentID=0, Status='live', Symbol='SLC66A2', Aliases=['PQLC1'], description='solute carrier family 66 member 2', other_designations='solute carrier family 66 member 2|PQ loop repeat containing 1|PQ-loop repeat-containing protein 1', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79902420, end_position_on_the_genomic_accession=79951665, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    80149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80149, CurrentID=0, Status='live', Symbol='ZC3H12A', Aliases=['MCPIP', 'MCPIP-1', 'MCPIP1', 'Reg1', 'dJ423B22.1'], description='zinc finger CCCH-type containing 12A', other_designations='endoribonuclease ZC3H12A|MCP-1 treatment-induced protein|MCP-induced protein 1|bifunctional endoribonuclease and deubiquitinase ZC3H12A|monocyte chemotactic protein-induced protein 1|regnase-1|ribonuclease ZC3H12A|zinc finger CCCH domain-containing protein 12A', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37474518, end_position_on_the_genomic_accession=37484377, orientation='plus', exon_count=6, OMIM=[610562], no_hdr0=''),
    80150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80150, CurrentID=0, Status='live', Symbol='ASRGL1', Aliases=['ALP', 'ALP1', 'CRASH'], description='asparaginase and isoaspartyl peptidase 1', other_designations='isoaspartyl peptidase/L-asparaginase|L-asparaginase|L-asparagine amidohydrolase|asparaginase like 1|asparaginase-like 1 protein|asparaginase-like protein 1|beta-aspartyl-peptidase|isoaspartyl dipeptidase|testis secretory sperm-binding protein Li 242mP', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62337430, end_position_on_the_genomic_accession=62401401, orientation='plus', exon_count=10, OMIM=[609212], no_hdr0=''),
    80152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80152, CurrentID=0, Status='live', Symbol='CENPT', Aliases=['C16orf56', 'CENP-T', 'SSMGA'], description='centromere protein T', other_designations='centromere protein T|interphase centromere complex protein 22', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67828157, end_position_on_the_genomic_accession=67847693, orientation='minus', exon_count=17, OMIM=[611510], no_hdr0=''),
    80153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80153, CurrentID=0, Status='live', Symbol='EDC3', Aliases=['LSM16', 'MRT50', 'YJDC', 'YJEFN2', 'hYjeF_N2-15q23'], description='enhancer of mRNA decapping 3', other_designations='enhancer of mRNA-decapping protein 3|LSM16 homolog (EDC3, S. cerevisiae)|enhancer of mRNA decapping 3 homolog|yjeF N-terminal domain-containing protein 2|yjeF domain containing|yjeF domain-containing protein 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74630558, end_position_on_the_genomic_accession=74696434, orientation='minus', exon_count=12, OMIM=[609842], no_hdr0=''),
    80155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80155, CurrentID=0, Status='live', Symbol='NAA15', Aliases=['Ga19', 'MRD50', 'NARG1', 'NAT1P', 'NATH', 'TBDN', 'TBDN100'], description='N-alpha-acetyltransferase 15, NatA auxiliary subunit', other_designations='N-alpha-acetyltransferase 15, NatA auxiliary subunit|N-terminal acetyltransferase|NMDA receptor regulated 1|NMDA receptor-regulated protein 1|gastric cancer antigen Ga19|protein tubedown-1|transcriptional coactivator tubedown-100|tubedown-1', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139301499, end_position_on_the_genomic_accession=139391384, orientation='plus', exon_count=20, OMIM=[608000], no_hdr0=''),
    80157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80157, CurrentID=0, Status='live', Symbol='CWH43', Aliases=['CWH43-C', 'PGAP2IP'], description='cell wall biogenesis 43 C-terminal homolog', other_designations='PGAP2-interacting protein|cell wall biogenesis protein 43 C-terminal homolog', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48986247, end_position_on_the_genomic_accession=49062079, orientation='plus', exon_count=18, OMIM=[618561], no_hdr0=''),
    80162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80162, CurrentID=0, Status='live', Symbol='PGGHG', Aliases=['ATHL1'], description='protein-glucosylgalactosylhydroxylysine glucosidase', other_designations='protein-glucosylgalactosylhydroxylysine glucosidase|ATH1, acid trehalase-like 1|acid trehalase-like protein 1|testicular tissue protein Li 25', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=287760, end_position_on_the_genomic_accession=296107, orientation='plus', exon_count=18, OMIM=[617032], no_hdr0=''),
    80164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80164, CurrentID=0, Status='live', Symbol='PRR36', Aliases=[], description='proline rich 36', other_designations='proline-rich protein 36', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7868719, end_position_on_the_genomic_accession=7874390, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    80167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80167, CurrentID=0, Status='live', Symbol='ABHD18', Aliases=['C4orf29'], description='abhydrolase domain containing 18', other_designations='protein ABHD18|abhydrolase domain-containing protein 18|alpha/beta hydrolase domain-containing protein 18', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127965261, end_position_on_the_genomic_accession=128039953, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    80168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80168, CurrentID=0, Status='live', Symbol='MOGAT2', Aliases=['DGAT2L5', 'DGAT2L5.', 'MGAT2', 'hDC5'], description='monoacylglycerol O-acyltransferase 2', other_designations='2-acylglycerol O-acyltransferase 2|acyl-CoA:monoacylglycerol acyltransferase 2|diacylglycerol O-acyltransferase candidate 5|diacylglycerol acyltransferase 2-like protein 5', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75717819, end_position_on_the_genomic_accession=75732953, orientation='plus', exon_count=8, OMIM=[610270], no_hdr0=''),
    80169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80169, CurrentID=0, Status='live', Symbol='CTC1', Aliases=['AAF-132', 'AAF132', 'C17orf68', 'CRMCC', 'tmp494178'], description='CST telomere replication complex component 1', other_designations='CST complex subunit CTC1|CST telomere maintenance complex component 1|CTS telomere maintenance complex component 1|HBV DNAPTP1-transactivated protein B|alpha accessory factor 132|conserved telomere capping protein 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8224815, end_position_on_the_genomic_accession=8248079, orientation='minus', exon_count=23, OMIM=[613129], no_hdr0=''),
    80173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80173, CurrentID=0, Status='live', Symbol='IFT74', Aliases=['CCDC2', 'CMG-1', 'CMG1'], description='intraflagellar transport 74', other_designations='intraflagellar transport protein 74 homolog|capillary morphogenesis gene 1 protein|capillary morphogenesis protein 1|coiled-coil domain containing 2|coiled-coil domain-containing protein 2|intraflagellar transport 74 homolog', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=26947110, end_position_on_the_genomic_accession=27066134, orientation='plus', exon_count=25, OMIM=[608040], no_hdr0=''),
    80174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80174, CurrentID=0, Status='live', Symbol='DBF4B', Aliases=['ASKL1', 'CHIFB', 'DRF1', 'ZDBF1B'], description='DBF4 zinc finger B', other_designations='protein DBF4 homolog B|ASK-like protein 1|DBF4 homolog B|Dbf4-related factor 1|activator of S-phase kinase-like protein 1|chiffon homolog B|zinc finger, DBF-type containing 1B', map_location='17q21', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44708581, end_position_on_the_genomic_accession=44752732, orientation='plus', exon_count=15, OMIM=[611661], no_hdr0=''),
    80176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80176, CurrentID=0, Status='live', Symbol='SPSB1', Aliases=['SSB-1', 'SSB1'], description='splA/ryanodine receptor domain and SOCS box containing 1', other_designations='SPRY domain-containing SOCS box protein 1|SPRY domain-containing SOCS box protein SSB-1|novel SPRY domain containing protein', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9292894, end_position_on_the_genomic_accession=9369532, orientation='plus', exon_count=3, OMIM=[611657], no_hdr0=''),
    80177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80177, CurrentID=0, Status='live', Symbol='MYCT1', Aliases=['MTLC'], description='MYC target 1', other_designations='myc target protein 1|myc target in myeloid cells 1|myc target in myeloid cells protein 1', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=152697896, end_position_on_the_genomic_accession=152747175, orientation='plus', exon_count=6, OMIM=[616805], no_hdr0=''),
    80178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80178, CurrentID=0, Status='live', Symbol='TEDC2', Aliases=['C16orf59'], description='tubulin epsilon and delta complex 2', other_designations='tubulin epsilon and delta complex protein 2|uncharacterized protein C16orf59', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2460109, end_position_on_the_genomic_accession=2464963, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    80179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80179, CurrentID=0, Status='live', Symbol='MYO19', Aliases=['MYOHD1'], description='myosin XIX', other_designations='unconventional myosin-XIX|myosin head domain containing 1|myosin head domain-containing protein 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36495636, end_position_on_the_genomic_accession=36535338, orientation='minus', exon_count=31, OMIM=[617379], no_hdr0=''),
    80183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80183, CurrentID=0, Status='live', Symbol='RUBCNL', Aliases=['C13orf18', 'KIAA0226L', 'PACER'], description='rubicon like autophagy enhancer', other_designations='protein associated with UVRAG as autophagy enhancer|KIAA0226 like|RUN and cysteine rich domain containing beclin 1 interacting protein like|protein RUBCNL-like|protein Rubicon-like|rubicon like autophagy regulator', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46334681, end_position_on_the_genomic_accession=46390042, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    80184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80184, CurrentID=0, Status='live', Symbol='CEP290', Aliases=['3H11Ag', 'BBS14', 'CT87', 'JBTS5', 'LCA10', 'MKS4', 'NPHP6', 'POC3', 'SLSN6', 'rd16'], description='centrosomal protein 290', other_designations='centrosomal protein of 290 kDa|Bardet-Biedl syndrome 14 protein|CTCL tumor antigen se2-2|Meckel syndrome, type 4|POC3 centriolar protein homolog|cancer/testis antigen 87|centrosomal protein 290kDa|monoclonal antibody 3H11 antigen|nephrocytsin-6|prostate cancer antigen T21|tumor antigen se2-2', map_location='12q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=88049013, end_position_on_the_genomic_accession=88142216, orientation='minus', exon_count=60, OMIM=[610142], no_hdr0=''),
    80185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80185, CurrentID=0, Status='live', Symbol='TTI2', Aliases=['C8orf41', 'MRT39'], description='TELO2 interacting protein 2', other_designations='TELO2-interacting protein 2|Tel2 interacting protein 2 homolog', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=33498722, end_position_on_the_genomic_accession=33513135, orientation='minus', exon_count=8, OMIM=[614426], no_hdr0=''),
    80194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80194, CurrentID=0, Status='live', Symbol='TMEM134', Aliases=[], description='transmembrane protein 134', other_designations='transmembrane protein 134', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67461710, end_position_on_the_genomic_accession=67469272, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    80195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80195, CurrentID=0, Status='live', Symbol='TMEM254', Aliases=['C10orf57', 'bA369J21.6'], description='transmembrane protein 254', other_designations='transmembrane protein 254|transmembrane protein C10orf57', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80078665, end_position_on_the_genomic_accession=80092552, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    80196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80196, CurrentID=0, Status='live', Symbol='RNF34', Aliases=['CARP-1', 'CARP1', 'RFI', 'RIF', 'RIFF', 'hRFI'], description='ring finger protein 34', other_designations='E3 ubiquitin-protein ligase RNF34|FYVE-RING finger protein MOMO|RING finger protein RIFF|RING-type E3 ubiquitin transferase RNF34|caspase regulator CARP1|caspases-8 and -10-associated RING finger protein 1|human RING finger homologous to inhibitor of apoptosis protein|ring finger protein 34, E3 ubiquitin protein ligase', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121400096, end_position_on_the_genomic_accession=121424352, orientation='plus', exon_count=9, OMIM=[608299], no_hdr0=''),
    80198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80198, CurrentID=0, Status='live', Symbol='MUS81', Aliases=['SLX3'], description='MUS81 structure-specific endonuclease subunit', other_designations='crossover junction endonuclease MUS81|MUS81 endonuclease homolog|SLX3 structure-specific endonuclease subunit homolog', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65860244, end_position_on_the_genomic_accession=65867653, orientation='plus', exon_count=18, OMIM=[606591], no_hdr0=''),
    80199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80199, CurrentID=0, Status='live', Symbol='FUZ', Aliases=['CPLANE3', 'FY', 'NTD'], description='fuzzy planar cell polarity protein', other_designations='protein fuzzy homolog|ciliogenesis and planar polarity effector 3|fuzzy homolog', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49806866, end_position_on_the_genomic_accession=49817376, orientation='minus', exon_count=18, OMIM=[610622], no_hdr0=''),
    80201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80201, CurrentID=0, Status='live', Symbol='HKDC1', Aliases=[], description='hexokinase domain containing 1', other_designations='hexokinase HKDC1|hexokinase domain-containing protein 1|putative hexokinase HKDC1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69220303, end_position_on_the_genomic_accession=69267552, orientation='plus', exon_count=20, OMIM=[617221], no_hdr0=''),
    80204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80204, CurrentID=0, Status='live', Symbol='FBXO11', Aliases=['FBX11', 'IDDFBA', 'PRMT9', 'UBR6', 'UG063H01', 'VIT1'], description='F-box protein 11', other_designations='F-box only protein 11|protein arginine N-methyltransferase 9|ubiquitin protein ligase E3 component n-recognin 6|vitiligo-associated protein 1|vitiligo-associated protein VIT-1', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47806920, end_position_on_the_genomic_accession=47906498, orientation='minus', exon_count=25, OMIM=[607871], no_hdr0=''),
    80205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80205, CurrentID=0, Status='live', Symbol='CHD9', Aliases=['AD013', 'CHD-9', 'CReMM', 'KISH2', 'PRIC320'], description='chromodomain helicase DNA binding protein 9', other_designations='chromodomain-helicase-DNA-binding protein 9|ATP-dependent helicase CHD9|PPAR-alpha-interacting complex protein 320 kDa|PPAR{gamma}-interacting cofactor 320 kDa|chromatin remodeling factor CHROM1|chromatin-related mesenchymal modulator|ciprofibrate bound protein p240|kismet homolog 2|peroxisomal proliferator-activated receptor A-interacting complex 320 kDa protein|proteinx0008', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=53054982, end_position_on_the_genomic_accession=53327502, orientation='plus', exon_count=55, OMIM=[616936], no_hdr0=''),
    80206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80206, CurrentID=0, Status='live', Symbol='FHOD3', Aliases=['CMH28', 'FHOS2', 'Formactin2'], description='formin homology 2 domain containing 3', other_designations='FH1/FH2 domain-containing protein 3|formactin-2|formin homolog overexpressed in spleen 2', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=36297713, end_position_on_the_genomic_accession=36780220, orientation='plus', exon_count=33, OMIM=[609691], no_hdr0=''),
    80207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80207, CurrentID=0, Status='live', Symbol='OPA3', Aliases=['MGA3'], description='outer mitochondrial membrane lipid metabolism regulator OPA3', other_designations="optic atrophy 3 protein|3-methylglutaconic aciduria type III|OPA3 outer mitochondrial membrane lipid metabolism regulator|Optic atrophy 3 (Iraqi-Jewish 'optic atrophy plus')|optic atrophy 3 (autosomal recessive, with chorea and spastic paraplegia)", map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45527427, end_position_on_the_genomic_accession=45584802, orientation='minus', exon_count=4, OMIM=[606580], no_hdr0=''),
    80208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80208, CurrentID=0, Status='live', Symbol='SPG11', Aliases=['ALS5', 'CMT2X', 'KIAA1840'], description='SPG11 vesicle trafficking associated, spatacsin', other_designations='spatacsin|SPG11, spatacsin vesicle trafficking associated|amyotrophic lateral sclerosis 5|colorectal carcinoma-associated protein|spastic paraplegia 11 (autosomal recessive)|spastic paraplegia 11 protein', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44562696, end_position_on_the_genomic_accession=44663678, orientation='minus', exon_count=41, OMIM=[610844], no_hdr0=''),
    80209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80209, CurrentID=0, Status='live', Symbol='PROSER1', Aliases=['C13orf23'], description='proline and serine rich 1', other_designations='proline and serine-rich protein 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=39009865, end_position_on_the_genomic_accession=39038089, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    80210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80210, CurrentID=0, Status='live', Symbol='ARMC9', Aliases=['ARM', 'JBTS30', 'KU-MEL-1', 'NS21'], description='armadillo repeat containing 9', other_designations='lisH domain-containing protein ARMC9|armadillo repeat-containing protein 9|armadillo/beta-catenin-like repeats|melanoma/melanocyte specific protein KU-MEL-1|melanoma/melanocyte-specific tumor antigen KU-MEL-1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231198628, end_position_on_the_genomic_accession=231394991, orientation='plus', exon_count=34, OMIM=[617612], no_hdr0=''),
    80212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80212, CurrentID=0, Status='live', Symbol='CCDC92', Aliases=[], description='coiled-coil domain containing 92', other_designations='coiled-coil domain-containing protein 92|limkain beta 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123935626, end_position_on_the_genomic_accession=123972831, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    80213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80213, CurrentID=0, Status='live', Symbol='TM2D3', Aliases=['BLP2'], description='TM2 domain containing 3', other_designations='TM2 domain-containing protein 3|BBP-like protein 2|almondex homolog|beta-amyloid-binding protein-like protein 2', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101632977, end_position_on_the_genomic_accession=101652381, orientation='minus', exon_count=7, OMIM=[610014], no_hdr0=''),
    80216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80216, CurrentID=0, Status='live', Symbol='ALPK1', Aliases=['8430410J10Rik', 'LAK', 'ROSAH'], description='alpha kinase 1', other_designations='alpha-protein kinase 1|chromosome 4 kinase|lymphocyte alpha-kinase|lymphocyte alpha-protein kinase', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112297369, end_position_on_the_genomic_accession=112442621, orientation='plus', exon_count=16, OMIM=[607347], no_hdr0=''),
    80217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80217, CurrentID=0, Status='live', Symbol='CFAP43', Aliases=['C10orf79', 'HYDNP1', 'SPGF19', 'WDR96', 'bA373N18.2'], description='cilia and flagella associated protein 43', other_designations='cilia- and flagella-associated protein 43|WD repeat domain 96|WD repeat-containing protein 96|WD repeat-containing protein C10orf79', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104129888, end_position_on_the_genomic_accession=104232364, orientation='minus', exon_count=38, OMIM=[617558], no_hdr0=''),
    80218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80218, CurrentID=0, Status='live', Symbol='NAA50', Aliases=['MAK3', 'NAT13', 'NAT13P', 'NAT5', 'NAT5P', 'SAN', 'hNaa50p'], description='N-alpha-acetyltransferase 50, NatE catalytic subunit', other_designations='N-alpha-acetyltransferase 50|N-acetyltransferase 13 (GCN5-related)|N-acetyltransferase 5|N-acetyltransferase san homolog|N-epsilon-acetyltransferase 50|natE catalytic subunit', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113716458, end_position_on_the_genomic_accession=113746249, orientation='minus', exon_count=5, OMIM=[610834], no_hdr0=''),
    80219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80219, CurrentID=0, Status='live', Symbol='COQ10B', Aliases=[], description='coenzyme Q10B', other_designations='coenzyme Q-binding protein COQ10 homolog B, mitochondrial|coenzyme Q10 homolog B', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197453552, end_position_on_the_genomic_accession=197475310, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    80221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80221, CurrentID=0, Status='live', Symbol='ACSF2', Aliases=['ACSMW', 'AVYV493'], description='acyl-CoA synthetase family member 2', other_designations='medium-chain acyl-CoA ligase ACSF2, mitochondrial|PPARG binding, long chain fatty acid acyl Co-A ligase like|acyl-CoA synthetase family member 2, mitochondrial', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50426218, end_position_on_the_genomic_accession=50474845, orientation='plus', exon_count=20, OMIM=[610465], no_hdr0=''),
    80222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80222, CurrentID=0, Status='live', Symbol='TARS2', Aliases=['COXPD21', 'TARSL1', 'thrRS'], description='threonyl-tRNA synthetase 2, mitochondrial', other_designations='threonine--tRNA ligase, mitochondrial|threonyl-tRNA synthetase 2, mitochondrial (putative)|threonyl-tRNA synthetase-like 1', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150487411, end_position_on_the_genomic_accession=150507609, orientation='plus', exon_count=18, OMIM=[612805], no_hdr0=''),
    80223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80223, CurrentID=0, Status='live', Symbol='RAB11FIP1', Aliases=['NOEL1A', 'RCP', 'rab11-FIP1'], description='RAB11 family interacting protein 1', other_designations='rab11 family-interacting protein 1|RAB11 coupling protein|RAB11 family interacting protein 1 (class I)|Rab effector protein|Rab-interacting recycling protein', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37858618, end_position_on_the_genomic_accession=37899497, orientation='minus', exon_count=6, OMIM=[608737], no_hdr0=''),
    80224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80224, CurrentID=0, Status='live', Symbol='NUBPL', Aliases=['C14orf127', 'IND1', 'MC1DN21', 'huInd1'], description='nucleotide binding protein like', other_designations='iron-sulfur protein NUBPL|IND1 homolog|iron-sulfur protein required for NADH dehydrogenase', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31561399, end_position_on_the_genomic_accession=31861293, orientation='plus', exon_count=18, OMIM=[613621], no_hdr0=''),
    80227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80227, CurrentID=0, Status='live', Symbol='PAAF1', Aliases=['PAAF', 'Rpn14', 'WDR71'], description='proteasomal ATPase associated factor 1', other_designations='proteasomal ATPase-associated factor 1|WD repeat domain 71|WD repeat-containing protein 71', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73876699, end_position_on_the_genomic_accession=73931114, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    80228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80228, CurrentID=0, Status='live', Symbol='ORAI2', Aliases=['C7orf19', 'CBCIP2', 'MEM142B', 'TMEM142B'], description='ORAI calcium release-activated calcium modulator 2', other_designations='protein orai-2|CAP-binding protein complex interacting protein 2|H_NH0514P08.8|putative protein ORAI2-2|transmembrane protein 142B', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102433575, end_position_on_the_genomic_accession=102456825, orientation='plus', exon_count=4, OMIM=[610929], no_hdr0=''),
    80230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80230, CurrentID=0, Status='live', Symbol='RUFY1', Aliases=['RABIP4', 'ZFYVE12'], description='RUN and FYVE domain containing 1', other_designations='RUN and FYVE domain-containing protein 1|FYVE-finger protein EIP1|la-binding protein 1|rab4-interacting protein|zinc finger FYVE domain-containing protein 12', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179550551, end_position_on_the_genomic_accession=179610012, orientation='plus', exon_count=24, OMIM=[610327], no_hdr0=''),
    80231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80231, CurrentID=0, Status='live', Symbol='TASL', Aliases=['CXorf21'], description='TLR adaptor interacting with endolysosomal SLC15A4', other_designations='TLR adapter interacting with SLC15A4 on the lysosome|5430427O19Rik|TLR adaptor interacting with SLC15A4 on the lysosome|protein CXorf21|uncharacterized protein CXorf21', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30558809, end_position_on_the_genomic_accession=30577766, orientation='minus', exon_count=3, OMIM=[301049], no_hdr0=''),
    80232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80232, CurrentID=0, Status='live', Symbol='WDR26', Aliases=['CDW2', 'GID7', 'MIP2', 'SKDEAS'], description='WD repeat domain 26', other_designations='WD repeat-containing protein 26|CUL4- and DDB1-associated WDR protein 2|GID complex subunit 7 homolog|myocardial ischemic preconditioning upregulated protein 2', map_location='1q42.11-q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224385146, end_position_on_the_genomic_accession=224434797, orientation='minus', exon_count=14, OMIM=[617424], no_hdr0=''),
    80233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80233, CurrentID=0, Status='live', Symbol='FAAP100', Aliases=['C17orf70'], description='FA core complex associated protein 100', other_designations='Fanconi anemia core complex-associated protein 100|Fanconi anemia associated protein 100 kDa subunit|Fanconi anemia core complex 100 kDa subunit|Fanconi anemia core complex associated protein 100|Fanconi anemia-associated protein, 100kDa|fanconi anemia-associated protein of 100 kDa', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81539891, end_position_on_the_genomic_accession=81552399, orientation='minus', exon_count=10, OMIM=[611301], no_hdr0=''),
    80235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80235, CurrentID=0, Status='live', Symbol='PIGZ', Aliases=['GPI-MT-IV', 'PIG-Z', 'SMP3'], description='phosphatidylinositol glycan anchor biosynthesis class Z', other_designations='GPI mannosyltransferase 4|GPI mannosyltransferase IV|SMP3 mannosyltransferase|dol-P-Man dependent GPI mannosyltransferase|phosphatidylinositol glycan, class Z|phosphatidylinositol-glycan biosynthesis class Z protein', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196946356, end_position_on_the_genomic_accession=196969411, orientation='minus', exon_count=6, OMIM=[611671], no_hdr0=''),
    80237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80237, CurrentID=0, Status='live', Symbol='ELL3', Aliases=[], description='elongation factor for RNA polymerase II 3', other_designations='RNA polymerase II elongation factor ELL3|elongation factor RNA polymerase II-like 3', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43772620, end_position_on_the_genomic_accession=43776966, orientation='minus', exon_count=11, OMIM=[609885], no_hdr0=''),
    80243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80243, CurrentID=0, Status='live', Symbol='PREX2', Aliases=['DEP.2', 'DEPDC2', 'P-REX2', 'PPP1R129'], description='phosphatidylinositol-3,4,5-trisphosphate dependent Rac exchange factor 2', other_designations='phosphatidylinositol 3,4,5-trisphosphate-dependent Rac exchanger 2 protein|DEP domain-containing protein 2|PtdIns(3,4,5)-dependent Rac exchanger 2|protein phosphatase 1, regulatory subunit 129', map_location='8q13.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=67951918, end_position_on_the_genomic_accession=68237032, orientation='plus', exon_count=41, OMIM=[612139], no_hdr0=''),
    80254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80254, CurrentID=0, Status='live', Symbol='CEP63', Aliases=['SCKL6'], description='centrosomal protein 63', other_designations='centrosomal protein of 63 kDa|centrosomal protein 63kDa|centrosome protein CEP63', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134485724, end_position_on_the_genomic_accession=134783169, orientation='plus', exon_count=25, OMIM=[614724], no_hdr0=''),
    80255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80255, CurrentID=0, Status='live', Symbol='SLC35F5', Aliases=[], description='solute carrier family 35 member F5', other_designations='solute carrier family 35 member F5|HCV NS5A-transactivated protein 3|hepatitis C virus NS5A-transactivated protein 3', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113702677, end_position_on_the_genomic_accession=113756642, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    80256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80256, CurrentID=0, Status='live', Symbol='FAM214B', Aliases=['KIAA1539'], description='family with sequence similarity 214 member B', other_designations='protein FAM214B', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35104117, end_position_on_the_genomic_accession=35116341, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    80258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80258, CurrentID=0, Status='live', Symbol='EFHC2', Aliases=['MRX74', 'dJ1158H2.1'], description='EF-hand domain containing 2', other_designations='EF-hand domain-containing family member C2|EF-hand domain (C-terminal) containing 2|mental retardation, X-linked 74', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=44146254, end_position_on_the_genomic_accession=44343672, orientation='minus', exon_count=18, OMIM=[300817], no_hdr0=''),
    80262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80262, CurrentID=0, Status='live', Symbol='PHAF1', Aliases=['C16orf6', 'C16orf70', 'LIN10', 'lin-10'], description='phagosome assembly factor 1', other_designations='phagosome assembly factor 1|UPF0183 protein C16orf70', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67109881, end_position_on_the_genomic_accession=67148544, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    80263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80263, CurrentID=0, Status='live', Symbol='TRIM45', Aliases=['RNF99'], description='tripartite motif containing 45', other_designations='tripartite motif-containing protein 45|ring finger protein 99', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117107711, end_position_on_the_genomic_accession=117121789, orientation='minus', exon_count=8, OMIM=[609318], no_hdr0=''),
    80264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80264, CurrentID=0, Status='live', Symbol='ZNF430', Aliases=[], description='zinc finger protein 430', other_designations='zinc finger protein 430', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21020657, end_position_on_the_genomic_accession=21060050, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    80267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80267, CurrentID=0, Status='live', Symbol='EDEM3', Aliases=['C1orf22'], description='ER degradation enhancing alpha-mannosidase like protein 3', other_designations='ER degradation-enhancing alpha-mannosidase-like protein 3|ER degradation enhancer, mannosidase alpha-like 3|ER degradation-enhancing -mannosidase-like protein 3|ER degradation-enhancing alpha-mannosidase-like 3|alpha-1,2-mannosidase EDEM3', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=184690237, end_position_on_the_genomic_accession=184754907, orientation='minus', exon_count=21, OMIM=[610214], no_hdr0=''),
    80270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80270, CurrentID=0, Status='live', Symbol='HSD3B7', Aliases=['CBAS1', 'PFIC4', 'SDR11E3'], description='hydroxy-delta-5-steroid dehydrogenase, 3 beta- and steroid delta-isomerase 7', other_designations='3 beta-hydroxysteroid dehydrogenase type 7|3 beta-hydroxy-delta 5-C27-steroid oxidoreductase|3 beta-hydroxysteroid dehydrogenase type VII|3-beta-HSD VII|3-beta-hydroxy-Delta(5)-C27 steroid oxidoreductase|C(27)-3BETA-HSD|c(27) 3-beta-HSD|cholest-5-ene-3-beta,7-alpha-diol 3-beta-dehydrogenase|short chain dehydrogenase/reductase family 11E, member 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30985189, end_position_on_the_genomic_accession=30989152, orientation='plus', exon_count=7, OMIM=[607764], no_hdr0=''),
    80271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80271, CurrentID=0, Status='live', Symbol='ITPKC', Aliases=['IP3-3KC', 'IP3KC'], description='inositol-trisphosphate 3-kinase C', other_designations='inositol-trisphosphate 3-kinase C|IP3 3-kinase C|IP3K C|InsP 3 kinase C|inositol 1,4,5-trisphosphate 3-kinase C|insP 3-kinase C', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40717112, end_position_on_the_genomic_accession=40740860, orientation='plus', exon_count=7, OMIM=[606476], no_hdr0=''),
    80273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80273, CurrentID=0, Status='live', Symbol='GRPEL1', Aliases=['GrpE', 'HMGE', 'mt-GrpE#1'], description='GrpE like 1, mitochondrial', other_designations='grpE protein homolog 1, mitochondrial|GrpE-like protein cochaperone', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7058895, end_position_on_the_genomic_accession=7068064, orientation='minus', exon_count=4, OMIM=[606173], no_hdr0=''),
    80274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80274, CurrentID=0, Status='live', Symbol='SCUBE1', Aliases=[], description='signal peptide, CUB domain and EGF like domain containing 1', other_designations='signal peptide, CUB and EGF-like domain-containing protein 1|signal peptide, CUB domain, EGF-like 1|signal peptide-CUB domain-EGF-related 1', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43197280, end_position_on_the_genomic_accession=43343372, orientation='minus', exon_count=22, OMIM=[611746], no_hdr0=''),
    80279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80279, CurrentID=0, Status='live', Symbol='CDK5RAP3', Aliases=['C53', 'HSF-27', 'IC53', 'LZAP', 'MST016', 'OK/SW-cl.114', 'PP1553'], description='CDK5 regulatory subunit associated protein 3', other_designations='CDK5 regulatory subunit-associated protein 3|CDK5 regulatory subunit associated protein IC53-2|LXXLL/leucine-zipper-containing ARF-binding protein|LXXLL/leucine-zipper-containing ARFbinding protein|ischemic heart CDK5 activator-binding protein C53', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47967904, end_position_on_the_genomic_accession=47981781, orientation='plus', exon_count=16, OMIM=[608202], no_hdr0=''),
    80298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80298, CurrentID=0, Status='live', Symbol='MTERF2', Aliases=['MTERFD3', 'mTERFL'], description='mitochondrial transcription termination factor 2', other_designations='transcription termination factor 2, mitochondrial|MTERF domain containing 3|mTERF domain-containing protein 3, mitochondrial|mTERF-like|mitochondrial transcription termination factor-like protein', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106972856, end_position_on_the_genomic_accession=106987166, orientation='minus', exon_count=4, OMIM=[616929], no_hdr0=''),
    80301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80301, CurrentID=0, Status='live', Symbol='PLEKHO2', Aliases=['PLEKHQ1', 'PP1628', 'pp9099'], description='pleckstrin homology domain containing O2', other_designations='pleckstrin homology domain-containing family O member 2|PH domain-containing family O member 2|PH domain-containing family Q member 1|PH domain-containing protein|pleckstrin homology domain-containing family Q member 1', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64841915, end_position_on_the_genomic_accession=64868002, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    80303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80303, CurrentID=0, Status='live', Symbol='EFHD1', Aliases=['MST133', 'MSTP133', 'PP3051', 'SWS2'], description='EF-hand domain family member D1', other_designations='EF-hand domain-containing protein D1|EF-hand domain-containing protein 1|swiprosin-2', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232606057, end_position_on_the_genomic_accession=232682776, orientation='plus', exon_count=6, OMIM=[611617], no_hdr0=''),
    80304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80304, CurrentID=0, Status='live', Symbol='WDCP', Aliases=['C2orf44', 'MMAP', 'PP384'], description='WD repeat and coiled coil containing', other_designations='WD repeat and coiled-coil-containing protein|WD repeat and coiled-coil-containing protein C2orf44|WD repeat-containing protein C2orf44', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24029347, end_position_on_the_genomic_accession=24047391, orientation='minus', exon_count=4, OMIM=[616234], no_hdr0=''),
    80305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80305, CurrentID=0, Status='live', Symbol='TRABD', Aliases=['LP6054', 'PP2447'], description='TraB domain containing', other_designations='traB domain-containing protein', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50185889, end_position_on_the_genomic_accession=50199599, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    80306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80306, CurrentID=0, Status='live', Symbol='MED28', Aliases=['1500003D12Rik', 'EG1', 'magicin'], description='mediator complex subunit 28', other_designations='mediator of RNA polymerase II transcription subunit 28|endothelial-derived gene 1|endothelial-derived protein 1|mediator of RNA polymerase II transcription, subunit 28 homolog|merlin and Grb2-interacting cytoskeletal protein|tumor angiogenesis marker EG-1', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17614641, end_position_on_the_genomic_accession=17634105, orientation='plus', exon_count=4, OMIM=[610311], no_hdr0=''),
    80308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80308, CurrentID=0, Status='live', Symbol='FLAD1', Aliases=['FAD1', 'FADS', 'LSMFLAD', 'PP591'], description='flavin adenine dinucleotide synthetase 1', other_designations='FAD synthase|FAD pyrophosphorylase|FAD-synthetase|FMN adenylyltransferase|Fad1, flavin adenine dinucleotide synthetase, homolog', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154983344, end_position_on_the_genomic_accession=154993111, orientation='plus', exon_count=7, OMIM=[610595], no_hdr0=''),
    80309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80309, CurrentID=0, Status='live', Symbol='SPHKAP', Aliases=['SKIP'], description='SPHK1 interactor, AKAP domain containing', other_designations='A-kinase anchor protein SPHKAP|SPHK1 (sphingosine kinase type 1) interacting protein|SPHK1-interactor and AKAP domain-containing protein|sphingosine kinase type 1-interacting protein', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227979954, end_position_on_the_genomic_accession=228181999, orientation='minus', exon_count=14, OMIM=[611646], no_hdr0=''),
    80310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80310, CurrentID=0, Status='live', Symbol='PDGFD', Aliases=['IEGF', 'MSTP036', 'SCDGF-B', 'SCDGFB'], description='platelet derived growth factor D', other_designations='platelet-derived growth factor D|PDGF-D|iris-expressed growth factor|spinal cord-derived growth factor B', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=103907189, end_position_on_the_genomic_accession=104164147, orientation='minus', exon_count=7, OMIM=[609673], no_hdr0=''),
    80311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80311, CurrentID=0, Status='live', Symbol='KLHL15', Aliases=['HEL-S-305'], description='kelch like family member 15', other_designations='kelch-like protein 15|epididymis secretory protein Li 305|epididymis secretory sperm binding protein|kelch-like 15', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23983720, end_position_on_the_genomic_accession=24027186, orientation='minus', exon_count=4, OMIM=[300980], no_hdr0=''),
    80312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80312, CurrentID=0, Status='live', Symbol='TET1', Aliases=['CXXC6', 'LCX', 'bA119F7.1'], description='tet methylcytosine dioxygenase 1', other_designations='methylcytosine dioxygenase TET1|CXXC finger 6|CXXC zinc finger 6|CXXC-type zinc finger protein 6|TET1 splice variant VP_DE4|TET1 splice variant VP_DE456|leukemia-associated protein with a CXXC domain|ten-eleven translocation 1 gene protein|ten-eleven translocation-1|tet oncogene 1', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68560337, end_position_on_the_genomic_accession=68700794, orientation='plus', exon_count=20, OMIM=[607790], no_hdr0=''),
    80313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80313, CurrentID=0, Status='live', Symbol='LRRC27', Aliases=[], description='leucine rich repeat containing 27', other_designations='leucine-rich repeat-containing protein 27|testicular tissue protein Li 108', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132330063, end_position_on_the_genomic_accession=132381508, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    80314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80314, CurrentID=0, Status='live', Symbol='EPC1', Aliases=['Epl1'], description='enhancer of polycomb homolog 1', other_designations='enhancer of polycomb homolog 1', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=32267751, end_position_on_the_genomic_accession=32378769, orientation='minus', exon_count=19, OMIM=[610999], no_hdr0=''),
    80315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80315, CurrentID=0, Status='live', Symbol='CPEB4', Aliases=['CPE-BP4', 'hCPEB-4'], description='cytoplasmic polyadenylation element binding protein 4', other_designations='cytoplasmic polyadenylation element-binding protein 4|CPE-binding protein 4', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173888328, end_position_on_the_genomic_accession=173961980, orientation='plus', exon_count=12, OMIM=[610607], no_hdr0=''),
    80316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80316, CurrentID=0, Status='live', Symbol='PPP1R2C', Aliases=['I-4', 'PPP1R2P9'], description='PPP1R2C family member C', other_designations='protein phosphatase inhibitor 2 family member C|PPP1R2 family member B|protein phosphatase 1 regulatory inhibitor subunit 2 pseudogene 9|protein phosphatase 1 regulatory inhibitor subunit 2-like 9|putative type-1 protein phosphatase inhibitor 4|type 1 protein phosphatase inhibitor|type-1 protein phosphatase inhibitor 4', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=42777366, end_position_on_the_genomic_accession=42778163, orientation='minus', exon_count=1, OMIM=[301017], no_hdr0=''),
    80317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80317, CurrentID=0, Status='live', Symbol='ZKSCAN3', Aliases=['ZF47', 'ZFP306', 'ZNF306', 'ZNF309', 'ZSCAN13', 'ZSCAN35', 'Zfp47', 'dJ874C20.1', 'dJ874C20.1.', 'zfp-47'], description='zinc finger with KRAB and SCAN domains 3', other_designations='zinc finger protein with KRAB and SCAN domains 3|zinc finger and SCAN domain-containing protein 13|zinc finger protein 306|zinc finger protein 309|zinc finger protein 47 homolog|zinc finger protein zfp47', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28349913, end_position_on_the_genomic_accession=28369174, orientation='plus', exon_count=8, OMIM=[612791], no_hdr0=''),
    80318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80318, CurrentID=0, Status='live', Symbol='GKAP1', Aliases=['FKSG21', 'GKAP42'], description='G kinase anchoring protein 1', other_designations='G kinase-anchoring protein 1|cGMP-dependent protein kinase anchoring protein 42kDa|cGMP-dependent protein kinase-anchoring protein of 42 kDa|protein kinase anchoring protein GKAP42', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83739421, end_position_on_the_genomic_accession=83817769, orientation='minus', exon_count=16, OMIM=[611356], no_hdr0=''),
    80319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80319, CurrentID=0, Status='live', Symbol='CXXC4', Aliases=['IDAX'], description='CXXC finger protein 4', other_designations='CXXC-type zinc finger protein 4|CXXC finger 4|Dvl-binding protein IDAX (inhibition of the Dvl and Axin complex)|inhibition of the Dvl and axin complex protein', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=104468308, end_position_on_the_genomic_accession=104494967, orientation='minus', exon_count=4, OMIM=[611645], no_hdr0=''),
    80320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80320, CurrentID=0, Status='live', Symbol='SP6', Aliases=['EPFN', 'EPIPROFIN', 'KLF14'], description='Sp6 transcription factor', other_designations='transcription factor Sp6|Kruppel-like factor 14|krueppel-like factor 14', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47844908, end_position_on_the_genomic_accession=47876312, orientation='minus', exon_count=4, OMIM=[608613], no_hdr0=''),
    80321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80321, CurrentID=0, Status='live', Symbol='CEP70', Aliases=['BITE'], description='centrosomal protein 70', other_designations='centrosomal protein of 70 kDa|centrosomal protein 70kDa|p10-binding protein|testicular tissue protein Li 36', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138494339, end_position_on_the_genomic_accession=138594318, orientation='minus', exon_count=24, OMIM=[614310], no_hdr0=''),
    80323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80323, CurrentID=0, Status='live', Symbol='CCDC68', Aliases=['SE57-1'], description='coiled-coil domain containing 68', other_designations='coiled-coil domain-containing protein 68|CTCL tumor antigen se57-1|CTCL-associated antigen se57-1|cutaneous T-cell lymphoma associated antigen|cutaneous T-cell lymphoma-associated antigen se57-1', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54901509, end_position_on_the_genomic_accession=54959539, orientation='minus', exon_count=15, OMIM=[616909], no_hdr0=''),
    80324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80324, CurrentID=0, Status='live', Symbol='PUS1', Aliases=['MLASA1'], description='pseudouridine synthase 1', other_designations='tRNA pseudouridine synthase A|mitochondrial tRNA pseudouridine synthase A|pseudouridylate synthase 1|tRNA pseudouridine synthase A, mitochondrial|tRNA pseudouridine(38-40) synthase|tRNA pseudouridylate synthase I|tRNA uridine isomerase I', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131929268, end_position_on_the_genomic_accession=131945896, orientation='plus', exon_count=10, OMIM=[608109], no_hdr0=''),
    80325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80325, CurrentID=0, Status='live', Symbol='ABTB1', Aliases=['BPOZ', 'BTB3', 'BTBD21', 'EF1ABP', 'PP2259'], description='ankyrin repeat and BTB domain containing 1', other_designations='ankyrin repeat and BTB/POZ domain-containing protein 1|ankyrin repeat and BTB (POZ) domain containing 1|elongation factor 1A-binding protein', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127672928, end_position_on_the_genomic_accession=127680926, orientation='plus', exon_count=13, OMIM=[608308], no_hdr0=''),
    80326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80326, CurrentID=0, Status='live', Symbol='WNT10A', Aliases=['OODD', 'SSPS', 'STHAG4'], description='Wnt family member 10A', other_designations='protein Wnt-10a|wingless-type MMTV integration site family, member 10A', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218874116, end_position_on_the_genomic_accession=218893931, orientation='plus', exon_count=6, OMIM=[606268], no_hdr0=''),
    80328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80328, CurrentID=0, Status='live', Symbol='ULBP2', Aliases=['ALCAN-alpha', 'N2DL2', 'NKG2DL2', 'RAET1H', 'RAET1L'], description='UL16 binding protein 2', other_designations='UL16-binding protein 2|NKG2D ligand 2|retinoic acid early transcript 1H|retinoic acid early transcript 1L', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149941947, end_position_on_the_genomic_accession=149949235, orientation='plus', exon_count=5, OMIM=[605698], no_hdr0=''),
    80329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80329, CurrentID=0, Status='live', Symbol='ULBP1', Aliases=['N2DL-1', 'NKG2DL1', 'RAET1I'], description='UL16 binding protein 1', other_designations='UL16-binding protein 1|NKG2D ligand 1|alcan-beta|retinoic acid early transcript 1I', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149963943, end_position_on_the_genomic_accession=149973715, orientation='plus', exon_count=5, OMIM=[605697], no_hdr0=''),
    80331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80331, CurrentID=0, Status='live', Symbol='DNAJC5', Aliases=['CLN4', 'CLN4B', 'CSPA', 'NCL', 'mir-941-2', 'mir-941-3', 'mir-941-4', 'mir-941-5', 'DNAJC5'], description='DnaJ heat shock protein family (Hsp40) member C5', other_designations='dnaJ homolog subfamily C member 5|DnaJ (Hsp40) homolog, subfamily C, member 5|ceroid-lipofuscinosis neuronal protein 4|cysteine string protein alpha', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63895126, end_position_on_the_genomic_accession=63936026, orientation='plus', exon_count=8, OMIM=[611203], no_hdr0=''),
    80332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80332, CurrentID=0, Status='live', Symbol='ADAM33', Aliases=['C20orf153', 'DJ964F7.1'], description='ADAM metallopeptidase domain 33', other_designations='disintegrin and metalloproteinase domain-containing protein 33|ADAM 33|a disintegrin and metalloprotease 33|a disintegrin and metalloproteinase domain 33|disintegrin and reprolysin metalloproteinase family protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3667973, end_position_on_the_genomic_accession=3682108, orientation='minus', exon_count=22, OMIM=[607114], no_hdr0=''),
    80333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80333, CurrentID=0, Status='live', Symbol='KCNIP4', Aliases=['CALP', 'KCHIP4'], description='potassium voltage-gated channel interacting protein 4', other_designations='Kv channel-interacting protein 4|Kv channel interacting protein 4|a-type potassium channel modulatory protein 4|calsenilin-like protein', map_location='4p15.31-p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=20728520, end_position_on_the_genomic_accession=21948772, orientation='minus', exon_count=14, OMIM=[608182], no_hdr0=''),
    80335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80335, CurrentID=0, Status='live', Symbol='WDR82', Aliases=['MST107', 'MSTP107', 'PRO2730', 'PRO34047', 'SWD2', 'TMEM113A', 'WDR82'], description='WD repeat domain 82', other_designations='WD repeat-containing protein 82|transmembrane protein 113', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52254424, end_position_on_the_genomic_accession=52278649, orientation='minus', exon_count=9, OMIM=[611059], no_hdr0=''),
    80336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80336, CurrentID=0, Status='live', Symbol='PABPC1L', Aliases=['C20orf119', 'EPAB1', 'dJ1069P2.3', 'PABPC1L'], description='poly(A) binding protein cytoplasmic 1 like', other_designations='polyadenylate-binding protein 1-like|embryonic poly(A) binding protein', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44910060, end_position_on_the_genomic_accession=44939316, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    80339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80339, CurrentID=0, Status='live', Symbol='PNPLA3', Aliases=['ADPN', 'C22orf20', 'iPLA(2)epsilon'], description='patatin like phospholipase domain containing 3', other_designations='1-acylglycerol-3-phosphate O-acyltransferase PNPLA3|acylglycerol O-acyltransferase|acylglycerol transacylase|adiponutrin|calcium-independent phospholipase A2-epsilon|iPLA2-epsilon|iPLA2epsilon|lysophosphatidic acid acyltransferase|patatin-like phospholipase domain-containing protein 3', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43923805, end_position_on_the_genomic_accession=43947582, orientation='plus', exon_count=9, OMIM=[609567], no_hdr0=''),
    80341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80341, CurrentID=0, Status='live', Symbol='BPIFB2', Aliases=['BPIL1', 'C20orf184', 'LPLUNC2', 'RYSR', 'dJ726C3.2'], description='BPI fold containing family B member 2', other_designations='BPI fold-containing family B member 2|BPI-like 1|bactericidal/permeability-increasing protein-like 1|long palate, lung and nasal epithelium carcinoma-associated protein 2', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33007704, end_position_on_the_genomic_accession=33023703, orientation='plus', exon_count=16, OMIM=[614108], no_hdr0=''),
    80342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80342, CurrentID=0, Status='live', Symbol='TRAF3IP3', Aliases=['T3JAM'], description='TRAF3 interacting protein 3', other_designations='TRAF3-interacting JNK-activating modulator|TRAF3 interacting Jun N terminal kinase (JNK) activating modulator', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209756053, end_position_on_the_genomic_accession=209782317, orientation='plus', exon_count=20, OMIM=[608255], no_hdr0=''),
    80343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80343, CurrentID=0, Status='live', Symbol='SEL1L2', Aliases=['C20orf50', 'sel-1L2'], description='SEL1L2 adaptor subunit of ERAD E3 ligase', other_designations='protein sel-1 homolog 2|SEL1L2, ERAD E3 ligase adaptor subunit|sel-1 suppressor of lin-12-like 2|suppressor of lin-12-like protein 2', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13848586, end_position_on_the_genomic_accession=13995333, orientation='minus', exon_count=26, OMIM=[614289], no_hdr0=''),
    80344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80344, CurrentID=0, Status='live', Symbol='DCAF11', Aliases=['GL014', 'PRO2389', 'WDR23'], description='DDB1 and CUL4 associated factor 11', other_designations='DDB1- and CUL4-associated factor 11|WD repeat domain 23|WD repeat-containing protein 23', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24114777, end_position_on_the_genomic_accession=24125242, orientation='plus', exon_count=15, OMIM=[613317], no_hdr0=''),
    80345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80345, CurrentID=0, Status='live', Symbol='ZSCAN16', Aliases=['ZNF392', 'ZNF435', 'dJ265C24.3'], description='zinc finger and SCAN domain containing 16', other_designations='zinc finger and SCAN domain-containing protein 16|zinc finger protein 392|zinc finger protein 435', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28123753, end_position_on_the_genomic_accession=28130082, orientation='plus', exon_count=4, OMIM=[618544], no_hdr0=''),
    80346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80346, CurrentID=0, Status='live', Symbol='REEP4', Aliases=['C8orf20', 'PP432', 'Yip2c'], description='receptor accessory protein 4', other_designations='receptor expression-enhancing protein 4', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22138020, end_position_on_the_genomic_accession=22141907, orientation='minus', exon_count=8, OMIM=[609349], no_hdr0=''),
    80347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80347, CurrentID=0, Status='live', Symbol='COASY', Aliases=['DPCK', 'NBIA6', 'NBP', 'PCH12', 'PPAT', 'UKR1', 'pOV-2'], description='Coenzyme A synthase', other_designations='bifunctional coenzyme A synthase|CoA synthase|bifunctional phosphopantetheine adenylyl transferase/dephospho CoA kinase|nucleotide binding protein|phosphopantetheine adenylyltransferase / dephosphocoenzyme A kinase', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42562148, end_position_on_the_genomic_accession=42566277, orientation='plus', exon_count=9, OMIM=[609855], no_hdr0=''),
    80349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80349, CurrentID=0, Status='live', Symbol='WDR61', Aliases=['REC14', 'SKI8'], description='WD repeat domain 61', other_designations='WD repeat-containing protein 61|SKI8 homolog|meiotic recombination REC14 protein homolog|recombination protein REC14', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78283233, end_position_on_the_genomic_accession=78299703, orientation='minus', exon_count=11, OMIM=[609540], no_hdr0=''),
    80351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80351, CurrentID=0, Status='live', Symbol='TNKS2', Aliases=['ARTD6', 'PARP-5b', 'PARP-5c', 'PARP5B', 'PARP5C', 'TANK2', 'TNKL', 'pART6'], description='tankyrase 2', other_designations='poly [ADP-ribose] polymerase tankyrase-2|ADP-ribosyltransferase diphtheria toxin-like 6|TNKS-2|TRF1-interacting ankyrin-related ADP-ribose polymerase 2|poly [ADP-ribose] polymerase 5B|protein poly-ADP-ribosyltransferase tankyrase-2|tankyrase II|tankyrase, TRF1-interacting ankyrin-related ADP-ribose polymerase 2|tankyrase-like protein|tankyrase-related protein', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91798426, end_position_on_the_genomic_accession=91865475, orientation='plus', exon_count=31, OMIM=[607128], no_hdr0=''),
    80352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80352, CurrentID=0, Status='live', Symbol='RNF39', Aliases=['FAP216', 'HZF', 'HZFW', 'LIRF'], description='ring finger protein 39', other_designations='RING finger protein 39|LTP (long-term potentiation) induced RING finger protein|protein HZFw', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30070266, end_position_on_the_genomic_accession=30080625, orientation='minus', exon_count=4, OMIM=[607524], no_hdr0=''),
    80380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80380, CurrentID=0, Status='live', Symbol='PDCD1LG2', Aliases=['B7DC', 'Btdc', 'CD273', 'PD-L2', 'PDCD1L2', 'PDL2', 'bA574F11.2'], description='programmed cell death 1 ligand 2', other_designations='programmed cell death 1 ligand 2|B7 dendritic cell molecule|B7-DC|PD-1-ligand 2|PDCD1 ligand 2|butyrophilin B7-DC|programmed death ligand 2', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5510438, end_position_on_the_genomic_accession=5571282, orientation='plus', exon_count=7, OMIM=[605723], no_hdr0=''),
    80381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80381, CurrentID=0, Status='live', Symbol='CD276', Aliases=['4Ig-B7-H3', 'B7-H3', 'B7H3', 'B7RP-2'], description='CD276 molecule', other_designations='CD276 antigen|B7 homolog 3|costimulatory molecule', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73683966, end_position_on_the_genomic_accession=73714518, orientation='plus', exon_count=12, OMIM=[605715], no_hdr0=''),
    80700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80700, CurrentID=0, Status='live', Symbol='UBXN6', Aliases=['UBXD1', 'UBXDC2'], description='UBX domain protein 6', other_designations='UBX domain-containing protein 6|CTB-50L17.16|UBX domain containing 1|UBX domain-containing 2|UBX domain-containing protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4445006, end_position_on_the_genomic_accession=4458759, orientation='minus', exon_count=14, OMIM=[611946], no_hdr0=''),
    80704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80704, CurrentID=0, Status='live', Symbol='SLC19A3', Aliases=['BBGD', 'THMD2', 'THTR2', 'thTr-2'], description='solute carrier family 19 member 3', other_designations='thiamine transporter 2|solute carrier family 19 (thiamine transporter), member 3', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227683763, end_position_on_the_genomic_accession=227718030, orientation='minus', exon_count=10, OMIM=[606152], no_hdr0=''),
    80705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80705, CurrentID=0, Status='live', Symbol='TSGA10', Aliases=['CEP4L', 'CT79', 'SPGF26'], description='testis specific 10', other_designations='testis-specific gene 10 protein|cancer/testis antigen 79|testis development protein NYD-SP7|testis-specific 10 protein', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98997261, end_position_on_the_genomic_accession=99154966, orientation='minus', exon_count=32, OMIM=[607166], no_hdr0=''),
    80709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80709, CurrentID=0, Status='live', Symbol='AKNA', Aliases=[], description='AT-hook transcription factor', other_designations='microtubule organization protein AKNA|AKNA transcript F2|AT-hook transcription factor AKNA|AT-hook-containing transcription factor', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114334149, end_position_on_the_genomic_accession=114398498, orientation='minus', exon_count=28, OMIM=[605729], no_hdr0=''),
    80712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80712, CurrentID=0, Status='live', Symbol='ESX1', Aliases=['ESX1L', 'ESXR1'], description='ESX homeobox 1', other_designations='homeobox protein ESX1|ESX1-related protein|extraembryonic, spermatogenesis, homeobox 1 homolog', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104250038, end_position_on_the_genomic_accession=104254933, orientation='minus', exon_count=4, OMIM=[300154], no_hdr0=''),
    80714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80714, CurrentID=0, Status='live', Symbol='PBX4', Aliases=[], description='PBX homeobox 4', other_designations='pre-B-cell leukemia transcription factor 4|homeobox protein PBX4|pre-B-cell leukemia homeobox 4', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19561713, end_position_on_the_genomic_accession=19618690, orientation='minus', exon_count=11, OMIM=[608127], no_hdr0=''),
    80723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80723, CurrentID=0, Status='live', Symbol='SLC35G2', Aliases=['TMEM22'], description='solute carrier family 35 member G2', other_designations='solute carrier family 35 member G2|transmembrane protein 22', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=136819126, end_position_on_the_genomic_accession=136855892, orientation='plus', exon_count=7, OMIM=[617812], no_hdr0=''),
    80724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80724, CurrentID=0, Status='live', Symbol='ACAD10', Aliases=[], description='acyl-CoA dehydrogenase family member 10', other_designations='acyl-CoA dehydrogenase family member 10|ACAD-10|acyl-Coenzyme A dehydrogenase family, member 10', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111686053, end_position_on_the_genomic_accession=111757099, orientation='plus', exon_count=22, OMIM=[611181], no_hdr0=''),
    80725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80725, CurrentID=0, Status='live', Symbol='SRCIN1', Aliases=['P140', 'SNIP'], description='SRC kinase signaling inhibitor 1', other_designations='SRC kinase signaling inhibitor 1|P130Cas-associated protein|SNAP-25-interacting protein|SNAP25-interacting protein|p140Cap', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38530015, end_position_on_the_genomic_accession=38607166, orientation='minus', exon_count=27, OMIM=[610786], no_hdr0=''),
    80726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80726, CurrentID=0, Status='live', Symbol='IQCN', Aliases=['KIAA1683'], description='IQ motif containing N', other_designations='IQ domain-containing protein N', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18257098, end_position_on_the_genomic_accession=18274452, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    80727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80727, CurrentID=0, Status='live', Symbol='TTYH3', Aliases=[], description='tweety family member 3', other_designations='protein tweety homolog 3|hTTY3|tweety homolog 3', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2631986, end_position_on_the_genomic_accession=2664802, orientation='plus', exon_count=14, OMIM=[608919], no_hdr0=''),
    80728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80728, CurrentID=0, Status='live', Symbol='ARHGAP39', Aliases=['CrGAP', 'Vilse'], description='Rho GTPase activating protein 39', other_designations='rho GTPase-activating protein 39|RhoGAP93B homolog|crossGAP homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144529179, end_position_on_the_genomic_accession=144700520, orientation='minus', exon_count=16, OMIM=[615880], no_hdr0=''),
    80731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80731, CurrentID=0, Status='live', Symbol='THSD7B', Aliases=[], description='thrombospondin type 1 domain containing 7B', other_designations='thrombospondin type-1 domain-containing protein 7B|thrombospondin, type I, domain containing 7B', map_location='2q22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=136765545, end_position_on_the_genomic_accession=137677718, orientation='plus', exon_count=29, OMIM=[], no_hdr0=''),
    80736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80736, CurrentID=0, Status='live', Symbol='SLC44A4', Aliases=['C6orf29', 'CTL4', 'DFNA72', 'NG22', 'TPPT', 'hTPPT1'], description='solute carrier family 44 member 4', other_designations='choline transporter-like protein 4|testicular tissue protein Li 48|thiamine pyrophosphate transporter 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31863192, end_position_on_the_genomic_accession=31878997, orientation='minus', exon_count=22, OMIM=[606107], no_hdr0=''),
    80737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80737, CurrentID=0, Status='live', Symbol='VWA7', Aliases=['C6orf27', 'G7c', 'NG37'], description='von Willebrand factor A domain containing 7', other_designations='von Willebrand factor A domain-containing protein 7|protein G7c', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31765590, end_position_on_the_genomic_accession=31777328, orientation='minus', exon_count=17, OMIM=[609693], no_hdr0=''),
    80739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80739, CurrentID=0, Status='live', Symbol='MPIG6B', Aliases=['C6orf25', 'G6b', 'G6b-B', 'NG31', 'THAMY'], description='megakaryocyte and platelet inhibitory receptor G6b', other_designations='megakaryocyte and platelet inhibitory receptor G6b|immunoglobulin receptor|protein G6b', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31720557, end_position_on_the_genomic_accession=31726714, orientation='plus', exon_count=7, OMIM=[606520], no_hdr0=''),
    80740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80740, CurrentID=0, Status='live', Symbol='LY6G6C', Aliases=['C6orf24', 'G6c', 'NG24'], description='lymphocyte antigen 6 family member G6C', other_designations='lymphocyte antigen 6 complex locus protein G6c|lymphocyte antigen 6 complex, locus G6C|lymphocyte antigen-6 G6C', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31718648, end_position_on_the_genomic_accession=31721746, orientation='minus', exon_count=3, OMIM=[610435], no_hdr0=''),
    80741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80741, CurrentID=0, Status='live', Symbol='LY6G5C', Aliases=['C6orf20', 'G5CA', 'LY6G5CB', 'NG33', 'LY6G5C'], description='lymphocyte antigen 6 family member G5C', other_designations='lymphocyte antigen 6 complex locus protein G5c|lymphocyte antigen 6 complex, locus G5C|lymphocyte antigen-6 G5C', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31676684, end_position_on_the_genomic_accession=31680373, orientation='minus', exon_count=3, OMIM=[610434], no_hdr0=''),
    80742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80742, CurrentID=0, Status='live', Symbol='PRR3', Aliases=['CAT56'], description='proline rich 3', other_designations='proline-rich protein 3|MHC class I region proline-rich protein CAT56|proline-rich polypeptide 3', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30556709, end_position_on_the_genomic_accession=30563723, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    80745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80745, CurrentID=0, Status='live', Symbol='THUMPD2', Aliases=['C2orf8'], description='THUMP domain containing 2', other_designations='THUMP domain-containing protein 2|SAM-dependent methyltransferase|epididymis secretory sperm binding protein', map_location='2p22-p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=39736060, end_position_on_the_genomic_accession=39779276, orientation='minus', exon_count=13, OMIM=[611751], no_hdr0=''),
    80746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80746, CurrentID=0, Status='live', Symbol='TSEN2', Aliases=['PCH2B', 'SEN2', 'SEN2L'], description='tRNA splicing endonuclease subunit 2', other_designations='tRNA-splicing endonuclease subunit Sen2|TSEN2 tRNA splicing endonuclease subunit|hsSen2|tRNA-intron endonuclease Sen2', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12484456, end_position_on_the_genomic_accession=12539624, orientation='plus', exon_count=21, OMIM=[608753], no_hdr0=''),
    80755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80755, CurrentID=0, Status='live', Symbol='AARSD1', Aliases=['AlaXp'], description='alanyl-tRNA synthetase domain containing 1', other_designations='alanyl-tRNA editing protein Aarsd1|alanyl-tRNA synthetase domain-containing protein 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42950526, end_position_on_the_genomic_accession=42964454, orientation='minus', exon_count=12, OMIM=[613212], no_hdr0=''),
    80757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80757, CurrentID=0, Status='live', Symbol='TMEM121', Aliases=['TMEM121A', 'hole'], description='transmembrane protein 121', other_designations='transmembrane protein 121|transmembrane protein 121A', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105526583, end_position_on_the_genomic_accession=105530202, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    80758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80758, CurrentID=0, Status='live', Symbol='PRR7', Aliases=[], description='proline rich 7, synaptic', other_designations='proline-rich protein 7|synaptic proline-rich membrane protein', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177445995, end_position_on_the_genomic_accession=177456286, orientation='plus', exon_count=7, OMIM=[618306], no_hdr0=''),
    80759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80759, CurrentID=0, Status='live', Symbol='KHDC1', Aliases=['C6orf147', 'C6orf148', 'Em:AC019205.8L', 'NDG1', 'bA257K9.4', 'KHDC1'], description='KH domain containing 1', other_designations='KH homology domain-containing protein 1|KH homology domain containing 1|Putative KHDC1-like protein', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73241314, end_position_on_the_genomic_accession=73310365, orientation='minus', exon_count=9, OMIM=[611688], no_hdr0=''),
    80760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80760, CurrentID=0, Status='live', Symbol='ITIH5', Aliases=['ITI-HC5', 'PP14776'], description='inter-alpha-trypsin inhibitor heavy chain 5', other_designations='inter-alpha-trypsin inhibitor heavy chain H5|ITI heavy chain H5|inter-alpha (globulin) inhibitor H5|inter-alpha-trypsin inhibitor heavy chain family member 5', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7559270, end_position_on_the_genomic_accession=7666968, orientation='minus', exon_count=17, OMIM=[609783], no_hdr0=''),
    80762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80762, CurrentID=0, Status='live', Symbol='NDFIP1', Aliases=['N4WBP5'], description='Nedd4 family interacting protein 1', other_designations='NEDD4 family-interacting protein 1|Nedd4 WW domain-binding protein 5|breast cancer-associated protein SGA-1M|putative MAPK-activating protein PM13|putative NF-kappa-B-activating protein 164|putative NFKB and MAPK-activating protein', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=142108779, end_position_on_the_genomic_accession=142154440, orientation='plus', exon_count=8, OMIM=[612050], no_hdr0=''),
    80763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80763, CurrentID=0, Status='live', Symbol='SPX', Aliases=['C12orf39'], description='spexin hormone', other_designations='spexin|NPQ|neuropeptide Q', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=21526296, end_position_on_the_genomic_accession=21532947, orientation='plus', exon_count=7, OMIM=[619246], no_hdr0=''),
    80764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80764, CurrentID=0, Status='live', Symbol='THAP7', Aliases=[], description='THAP domain containing 7', other_designations='THAP domain-containing protein 7', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20999104, end_position_on_the_genomic_accession=21002118, orientation='minus', exon_count=4, OMIM=[609518], no_hdr0=''),
    80765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80765, CurrentID=0, Status='live', Symbol='STARD5', Aliases=[], description='StAR related lipid transfer domain containing 5', other_designations='stAR-related lipid transfer protein 5|START domain containing 5|START domain-containing protein 5|StAR-related lipid transfer (START) domain containing 5', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=81309053, end_position_on_the_genomic_accession=81324141, orientation='minus', exon_count=6, OMIM=[607050], no_hdr0=''),
    80772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80772, CurrentID=0, Status='live', Symbol='CPTP', Aliases=['GLTPD1'], description='ceramide-1-phosphate transfer protein', other_designations='ceramide-1-phosphate transfer protein|GLTP domain-containing protein 1|glycolipid transfer protein domain containing 1|glycolipid transfer protein domain-containing protein 1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1324757, end_position_on_the_genomic_accession=1328896, orientation='plus', exon_count=4, OMIM=[615467], no_hdr0=''),
    80774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80774, CurrentID=0, Status='live', Symbol='LIMD2', Aliases=[], description='LIM domain containing 2', other_designations='LIM domain-containing protein 2|testicular tissue protein Li 106', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63695888, end_position_on_the_genomic_accession=63701227, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    80775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80775, CurrentID=0, Status='live', Symbol='TMEM177', Aliases=[], description='transmembrane protein 177', other_designations='transmembrane protein 177', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119679170, end_position_on_the_genomic_accession=119723618, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    80776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80776, CurrentID=0, Status='live', Symbol='B9D2', Aliases=['ICIS-1', 'JBTS34', 'MKS10', 'MKSR-2', 'MKSR2'], description='B9 domain containing 2', other_designations='B9 domain-containing protein 2|B9 protein domain 2|MKS1-related protein 2|involved in cIlia stability-1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41354417, end_position_on_the_genomic_accession=41364534, orientation='minus', exon_count=5, OMIM=[611951], no_hdr0=''),
    80777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80777, CurrentID=0, Status='live', Symbol='CYB5B', Aliases=['CYB5-M', 'CYPB5M', 'OMB5'], description='cytochrome b5 type B', other_designations='cytochrome b5 type B|cytochrome b5 type B (outer mitochondrial membrane)|outer mitochondrial membrane cytochrome b5|type 2 cyt-b5', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69424619, end_position_on_the_genomic_accession=69466264, orientation='plus', exon_count=5, OMIM=[611964], no_hdr0=''),
    80778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80778, CurrentID=0, Status='live', Symbol='ZNF34', Aliases=['KOX32'], description='zinc finger protein 34', other_designations='zinc finger protein 34|zinc finger protein 34 (KOX 32)|zinc finger protein KOX32', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144772224, end_position_on_the_genomic_accession=144787317, orientation='minus', exon_count=10, OMIM=[194526], no_hdr0=''),
    80781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80781, CurrentID=0, Status='live', Symbol='COL18A1', Aliases=['GLCC', 'KNO', 'KNO1', 'KS'], description='collagen type XVIII alpha 1 chain', other_designations='collagen alpha-1(XVIII) chain|antiangiogenic agent|collagen, type XVIII, alpha 1|endostatin|multi-functional protein MFP', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=45405165, end_position_on_the_genomic_accession=45513720, orientation='plus', exon_count=43, OMIM=[120328], no_hdr0=''),
    80789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80789, CurrentID=0, Status='live', Symbol='INTS5', Aliases=['INT5', 'KIAA1698'], description='integrator complex subunit 5', other_designations='integrator complex subunit 5', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62646848, end_position_on_the_genomic_accession=62653302, orientation='minus', exon_count=2, OMIM=[611349], no_hdr0=''),
    80790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80790, CurrentID=0, Status='live', Symbol='CMIP', Aliases=['TCMIP'], description='c-Maf inducing protein', other_designations='C-Maf-inducing protein|tc-Mip', map_location='16q23.2-q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81444808, end_position_on_the_genomic_accession=81711762, orientation='plus', exon_count=27, OMIM=[610112], no_hdr0=''),
    80816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80816, CurrentID=0, Status='live', Symbol='ASXL3', Aliases=['BRPS', 'KIAA1713'], description='ASXL transcriptional regulator 3', other_designations='putative Polycomb group protein ASXL3|additional sex combs like 3, transcriptional regulator|additional sex combs like transcriptional regulator 3|additional sex combs-like protein 3', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=33578219, end_position_on_the_genomic_accession=33751195, orientation='plus', exon_count=17, OMIM=[615115], no_hdr0=''),
    80817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80817, CurrentID=0, Status='live', Symbol='CEP44', Aliases=['KIAA1712', 'PS1TP3'], description='centrosomal protein 44', other_designations='centrosomal protein of 44 kDa|HBV PreS1-transactivated protein 3|centrosomal protein 44kDa', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=174283677, end_position_on_the_genomic_accession=174334355, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    80818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80818, CurrentID=0, Status='live', Symbol='ZNF436', Aliases=['ZNF', 'Zfp46'], description='zinc finger protein 436', other_designations='zinc finger protein 436|DNA-binding protein', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23359448, end_position_on_the_genomic_accession=23369836, orientation='minus', exon_count=4, OMIM=[611703], no_hdr0=''),
    80820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80820, CurrentID=0, Status='live', Symbol='EEPD1', Aliases=['HSPC107'], description='endonuclease/exonuclease/phosphatase family domain containing 1', other_designations='endonuclease/exonuclease/phosphatase family domain-containing protein 1', map_location='7p14.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=36153252, end_position_on_the_genomic_accession=36301538, orientation='plus', exon_count=10, OMIM=[617192], no_hdr0=''),
    80821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80821, CurrentID=0, Status='live', Symbol='DDHD1', Aliases=['PA-PLA1', 'PAPLA1', 'SPG28', 'iPLA1alpha'], description='DDHD domain containing 1', other_designations='phospholipase DDHD1|intracellular phospholipase A1 alpha|phosphatidic acid-preferring phospholipase A1 homolog|phosphatidic acid-preferring phospholipase A1-like protein|spastic paraplegia 28 (autosomal recessive)', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=53036755, end_position_on_the_genomic_accession=53153323, orientation='minus', exon_count=15, OMIM=[614603], no_hdr0=''),
    80823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80823, CurrentID=0, Status='live', Symbol='BHLHB9', Aliases=['GASP3', 'p60TRP'], description='basic helix-loop-helix family member b9', other_designations='protein BHLHb9|basic helix-loop-helix domain containing, class B, 9|p60-like protein|p60-transcription-regulator-protein|transcription regulator of 60 kDa', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102720743, end_position_on_the_genomic_accession=102753540, orientation='plus', exon_count=5, OMIM=[300921], no_hdr0=''),
    80824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80824, CurrentID=0, Status='live', Symbol='DUSP16', Aliases=['MKP-7', 'MKP7'], description='dual specificity phosphatase 16', other_designations='dual specificity protein phosphatase 16|MAP kinase phosphatase 7|MAPK phosphatase-7|mitogen-activated protein kinase phosphatase 7', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12473282, end_position_on_the_genomic_accession=12562863, orientation='minus', exon_count=9, OMIM=[607175], no_hdr0=''),
    80829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80829, CurrentID=0, Status='live', Symbol='ZFP91', Aliases=['DMS-8', 'DSM-8', 'DSM8', 'FKSG11', 'PZF', 'ZFP-91', 'ZNF757'], description='ZFP91 zinc finger protein, atypical E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase ZFP91|RING-type E3 ubiquitin transferase ZFP91|drug resistance-associated sequence in melanoma 8|penta zinc finger protein|zinc finger protein 757|zinc finger protein 91 homolog|zinc finger protein homologous to Zfp91 in mouse', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58579063, end_position_on_the_genomic_accession=58621550, orientation='plus', exon_count=11, OMIM=[619289], no_hdr0=''),
    80830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80830, CurrentID=0, Status='live', Symbol='APOL6', Aliases=['APOL-VI', 'APOLVI'], description='apolipoprotein L6', other_designations='apolipoprotein L6|apolipoprotein L, 6|apolipoprotein L-VI', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35648316, end_position_on_the_genomic_accession=35668406, orientation='plus', exon_count=4, OMIM=[607256], no_hdr0=''),
    80831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80831, CurrentID=0, Status='live', Symbol='APOL5', Aliases=['APOL-V', 'APOLV'], description='apolipoprotein L5', other_designations='apolipoprotein L5|apolipoprotein L, 5|apolipoprotein L-V', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35708424, end_position_on_the_genomic_accession=35730325, orientation='plus', exon_count=7, OMIM=[607255], no_hdr0=''),
    80832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80832, CurrentID=0, Status='live', Symbol='APOL4', Aliases=['APOL-IV', 'APOLIV'], description='apolipoprotein L4', other_designations='apolipoprotein L4|apolipoprotein L, 4|apolipoprotein L-IV', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36189128, end_position_on_the_genomic_accession=36204833, orientation='minus', exon_count=8, OMIM=[607254], no_hdr0=''),
    80833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80833, CurrentID=0, Status='live', Symbol='APOL3', Aliases=['APOLIII', 'CG121', 'CG12_1', 'apoL-III'], description='apolipoprotein L3', other_designations='apolipoprotein L3|TNF-inducible protein CG12-1|apolipoprotein L, 3|apolipoprotein L-III splice variant alpha|apolipoprotein L-III splice variant beta', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36140323, end_position_on_the_genomic_accession=36166177, orientation='minus', exon_count=12, OMIM=[607253], no_hdr0=''),
    80834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80834, CurrentID=0, Status='live', Symbol='TAS1R2', Aliases=['GPR71', 'T1R2', 'TR2'], description='taste 1 receptor member 2', other_designations='taste receptor type 1 member 2|G-protein coupled receptor 71|sweet taste receptor T1R2|taste receptor, type 1, member 2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18839599, end_position_on_the_genomic_accession=18859660, orientation='minus', exon_count=6, OMIM=[606226], no_hdr0=''),
    80835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80835, CurrentID=0, Status='live', Symbol='TAS1R1', Aliases=['GM148', 'GPR70', 'T1R1', 'TR1'], description='taste 1 receptor member 1', other_designations='taste receptor type 1 member 1|G-protein coupled receptor 70|seven transmembrane helix receptor|taste receptor, type 1, member 1', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6555307, end_position_on_the_genomic_accession=6579755, orientation='plus', exon_count=7, OMIM=[606225], no_hdr0=''),
    80851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80851, CurrentID=0, Status='live', Symbol='SH3BP5L', Aliases=[], description='SH3 binding domain protein 5 like', other_designations='SH3 domain-binding protein 5-like|SH3BP-5-like', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248810446, end_position_on_the_genomic_accession=248825915, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    80852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80852, CurrentID=0, Status='live', Symbol='GRIP2', Aliases=[], description='glutamate receptor interacting protein 2', other_designations='glutamate receptor-interacting protein 2', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14485105, end_position_on_the_genomic_accession=14602996, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    80853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80853, CurrentID=0, Status='live', Symbol='KDM7A', Aliases=['JHDM1D'], description='lysine demethylase 7A', other_designations='lysine-specific demethylase 7A|histone lysine demethylase JHDM1D|jmjC domain-containing histone demethylation protein 1D|jumonji C domain containing histone demethylase 1 homolog D|lysine (K)-specific demethylase 7A|lysine-specific demethylase 7', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140084746, end_position_on_the_genomic_accession=140176983, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    80854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80854, CurrentID=0, Status='live', Symbol='SETD7', Aliases=['KMT7', 'SET7', 'SET7/9', 'SET9'], description='SET domain containing 7, histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase SETD7|H3-K4-HMTase SETD7|SET domain containing 7, lysine methyltransferase|SET domain containing lysine methyltransferase 7|SET domain-containing protein 7|histone H3-K4 methyltransferase SETD7|histone H3-lysine 4-specific methyltransferase|lysine N-methyltransferase 7', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139492974, end_position_on_the_genomic_accession=139556219, orientation='minus', exon_count=10, OMIM=[606594], no_hdr0=''),
    80856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80856, CurrentID=0, Status='live', Symbol='LNPK', Aliases=['KIAA1715', 'LNP', 'LNP1', 'NEDEHCC', 'Ul', 'ulnaless'], description='lunapark, ER junction formation factor', other_designations='endoplasmic reticulum junction formation protein lunapark|2310011O18Rik|4921514L11Rik|ER junction formation factor lunapark|limb and neural patterns|protein lunapark', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=175923862, end_position_on_the_genomic_accession=176002901, orientation='minus', exon_count=19, OMIM=[610236], no_hdr0=''),
    80863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80863, CurrentID=0, Status='live', Symbol='PRRT1', Aliases=['C6orf31', 'DSPD1', 'IFITMD7', 'NG5', 'SynDIG4'], description='proline rich transmembrane protein 1', other_designations='proline-rich transmembrane protein 1|dispanin subfamily D member 1|interferon induced transmembrane protein domain containing 7|synapse differentiation-induced protein 4', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32148328, end_position_on_the_genomic_accession=32153626, orientation='minus', exon_count=6, OMIM=[618297], no_hdr0=''),
    80864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80864, CurrentID=0, Status='live', Symbol='EGFL8', Aliases=['C6orf8', 'NG3'], description='EGF like domain multiple 8', other_designations='epidermal growth factor-like protein 8|EGF-like protein 8|VE-statin-2|vascular endothelial statin-2', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=32164595, end_position_on_the_genomic_accession=32168281, orientation='plus', exon_count=9, OMIM=[609897], no_hdr0=''),
    80895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80895, CurrentID=0, Status='live', Symbol='ILKAP', Aliases=['ILKAP23', 'PP2C-DELTA', 'PP2CD', 'PPM1O', 'ILKAP'], description='ILK associated serine/threonine phosphatase', other_designations='integrin-linked kinase-associated serine/threonine phosphatase 2C|integrin-linked kinase associated phosphatase|protein phosphatase 2c, delta isozyme|protein phosphatase, Mg2+/Mn2+ dependent 1O', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238170401, end_position_on_the_genomic_accession=238203702, orientation='minus', exon_count=12, OMIM=[618909], no_hdr0=''),
    80896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80896, CurrentID=0, Status='live', Symbol='NPL', Aliases=['C112', 'C1orf13', 'NAL1', 'NPL'], description='N-acetylneuraminate pyruvate lyase', other_designations='N-acetylneuraminate lyase|N-acetylneuraminate pyruvate lyase (dihydrodipicolinate synthase)|N-acetylneuraminic acid aldolase|NALase|dihydrodipicolinate synthetase homolog 1|sialate-pyruvate lyase|sialic acid aldolase', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182789773, end_position_on_the_genomic_accession=182830384, orientation='plus', exon_count=13, OMIM=[611412], no_hdr0=''),
    80975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=80975, CurrentID=0, Status='live', Symbol='TMPRSS5', Aliases=['SPINESIN'], description='transmembrane serine protease 5', other_designations='transmembrane protease serine 5|transmembrane protease, serine 5', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113687548, end_position_on_the_genomic_accession=113709811, orientation='minus', exon_count=12, OMIM=[606751], no_hdr0=''),
    81025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81025, CurrentID=0, Status='live', Symbol='GJA9', Aliases=['CX58', 'CX59', 'GJA10'], description='gap junction protein alpha 9', other_designations='gap junction alpha-9 protein|connexin 59|connexin-58|gap junction alpha 10|gap junction protein, alpha 9, 59kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=38874069, end_position_on_the_genomic_accession=38881587, orientation='minus', exon_count=2, OMIM=[611923], no_hdr0=''),
    81027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81027, CurrentID=0, Status='live', Symbol='TUBB1', Aliases=[], description='tubulin beta 1 class VI', other_designations='tubulin beta-1 chain|tubulin, beta 1', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59016026, end_position_on_the_genomic_accession=59026654, orientation='plus', exon_count=5, OMIM=[612901], no_hdr0=''),
    81029 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81029, CurrentID=0, Status='live', Symbol='WNT5B', Aliases=[], description='Wnt family member 5B', other_designations='protein Wnt-5b|WNT-5B protein|wingless-type MMTV integration site family, member 5B', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1529856, end_position_on_the_genomic_accession=1647213, orientation='plus', exon_count=13, OMIM=[606361], no_hdr0=''),
    81030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81030, CurrentID=0, Status='live', Symbol='ZBP1', Aliases=['C20orf183', 'DAI', 'DLM-1', 'DLM1'], description='Z-DNA binding protein 1', other_designations='Z-DNA-binding protein 1|DNA-dependent activator of IRFs|tumor stroma and activated macrophage protein DLM-1', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57603852, end_position_on_the_genomic_accession=57620480, orientation='minus', exon_count=13, OMIM=[606750], no_hdr0=''),
    81031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81031, CurrentID=0, Status='live', Symbol='SLC2A10', Aliases=['ATORS', 'ATS', 'GLUT10'], description='solute carrier family 2 member 10', other_designations='solute carrier family 2, facilitated glucose transporter member 10|GLUT-10|glucose transporter type 10|solute carrier family 2 (facilitated glucose transporter), member 10', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46708358, end_position_on_the_genomic_accession=46736347, orientation='plus', exon_count=8, OMIM=[606145], no_hdr0=''),
    81033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81033, CurrentID=0, Status='live', Symbol='KCNH6', Aliases=['ERG-2', 'ERG2', 'HERG2', 'Kv11.2', 'hERG-2'], description='potassium voltage-gated channel subfamily H member 6', other_designations='potassium voltage-gated channel subfamily H member 6|eag-related gene member 2|ether-a-go-go-related protein 2|potassium channel, voltage gated eag related subfamily H, member 6|potassium voltage-gated channel, subfamily H (eag-related), member 6|voltage-gated potassium channel subunit Kv11.2', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63523334, end_position_on_the_genomic_accession=63548992, orientation='plus', exon_count=16, OMIM=[608168], no_hdr0=''),
    81034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81034, CurrentID=0, Status='live', Symbol='SLC25A32', Aliases=['GLYB', 'MFT', 'MFTC', 'RREI'], description='solute carrier family 25 member 32', other_designations='mitochondrial folate transporter/carrier|Glycine auxotroph B, complementation of hamster|glycine B complementing|solute carrier family 25 (mitochondrial folate carrier), member 32', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103398638, end_position_on_the_genomic_accession=103415107, orientation='minus', exon_count=8, OMIM=[138480], no_hdr0=''),
    81035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81035, CurrentID=0, Status='live', Symbol='COLEC12', Aliases=['CLP1', 'NSR2', 'SCARA4', 'SRCL'], description='collectin subfamily member 12', other_designations='collectin-12|collectin placenta protein 1|collectin sub-family member 12|hCL-P1|nurse cell scavenger receptor 2|scavenger receptor class A, member 4|scavenger receptor with C-type lectin', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=316737, end_position_on_the_genomic_accession=500701, orientation='minus', exon_count=10, OMIM=[607621], no_hdr0=''),
    81037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81037, CurrentID=0, Status='live', Symbol='CLPTM1L', Aliases=['CRR9'], description='CLPTM1 like', other_designations='cleft lip and palate transmembrane protein 1-like protein|CLPTM1-like protein|cisplatin resistance related protein CRR9p|cisplatin resistance-related protein 9', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1317752, end_position_on_the_genomic_accession=1345099, orientation='minus', exon_count=17, OMIM=[612585], no_hdr0=''),
    81050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81050, CurrentID=0, Status='live', Symbol='OR5AC2', Aliases=['HSA1'], description='olfactory receptor family 5 subfamily AC member 2', other_designations='olfactory receptor 5AC2', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98087173, end_position_on_the_genomic_accession=98088102, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81061, CurrentID=0, Status='live', Symbol='OR11H1', Aliases=['OR11H12', 'OR22-1'], description='olfactory receptor family 11 subfamily H member 1', other_designations='olfactory receptor 11H1|olfactory receptor OR22-1|seven transmembrane helix receptor', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=15528192, end_position_on_the_genomic_accession=15529139, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81099, CurrentID=0, Status='live', Symbol='OR4F17', Aliases=['OR4F11P', 'OR4F18', 'OR4F19', 'OR4F5'], description='olfactory receptor family 4 subfamily F member 17', other_designations='olfactory receptor 4F17|olfactory receptor 4F11|olfactory receptor 4F18|olfactory receptor 4F19|olfactory receptor, family 4, subfamily F, member 11 pseudogene|olfactory receptor, family 4, subfamily F, member 19', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=107104, end_position_on_the_genomic_accession=113156, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    81127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81127, CurrentID=0, Status='live', Symbol='OR4K15', Aliases=['OR14-20Q', 'OR4K15'], description='olfactory receptor family 4 subfamily K member 15', other_designations='olfactory receptor 4K15|olfactory receptor OR14-20', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19975591, end_position_on_the_genomic_accession=19976565, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81168, CurrentID=0, Status='live', Symbol='OR8J3', Aliases=['OR11-173'], description='olfactory receptor family 8 subfamily J member 3', other_designations='olfactory receptor 8J3|olfactory receptor OR11-173', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56134721, end_position_on_the_genomic_accession=56140201, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    81282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81282, CurrentID=0, Status='live', Symbol='OR51G2', Aliases=['OR11-28'], description='olfactory receptor family 51 subfamily G member 2', other_designations='olfactory receptor 51G2|olfactory receptor OR11-28', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4912588, end_position_on_the_genomic_accession=4919350, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    81285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81285, CurrentID=0, Status='live', Symbol='OR51E2', Aliases=['HPRAJ', 'OR51E3P', 'OR52A2', 'PSGR'], description='olfactory receptor family 51 subfamily E member 2', other_designations='olfactory receptor 51E2|olfactory receptor OR11-16|olfactory receptor, family 51, subfamily E, member 3 pseudogene|olfactory receptor, family 52, subfamily A, member 2|prostate-specific G-protein coupled receptor', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4680171, end_position_on_the_genomic_accession=4697853, orientation='minus', exon_count=2, OMIM=[611268], no_hdr0=''),
    81300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81300, CurrentID=0, Status='live', Symbol='OR4P4', Aliases=['OR4P3P'], description='olfactory receptor family 4 subfamily P member 4', other_designations='olfactory receptor 4P4|olfactory receptor 4P3|olfactory receptor, family 4, subfamily P, member 3 pseudogene', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55638358, end_position_on_the_genomic_accession=55639296, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81309, CurrentID=0, Status='live', Symbol='OR4C15', Aliases=['OR11-127', 'OR11-134'], description='olfactory receptor family 4 subfamily C member 15', other_designations='olfactory receptor 4C15|olfactory receptor OR11-127|olfactory receptor OR11-134', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55554469, end_position_on_the_genomic_accession=55555419, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81318, CurrentID=0, Status='live', Symbol='OR4A5', Aliases=['OR11-111'], description='olfactory receptor family 4 subfamily A member 5', other_designations='olfactory receptor 4A5|olfactory receptor OR11-111|seven transmembrane helix receptor', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=54706832, end_position_on_the_genomic_accession=54707902, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81327, CurrentID=0, Status='live', Symbol='OR4A16', Aliases=['OR11-117Q', 'OR4A16'], description='olfactory receptor family 4 subfamily A member 16', other_designations='olfactory receptor 4A16|olfactory receptor OR11-117', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55343201, end_position_on_the_genomic_accession=55344187, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81328, CurrentID=0, Status='live', Symbol='OR4A15', Aliases=['OR11-118'], description='olfactory receptor family 4 subfamily A member 15', other_designations='olfactory receptor 4A15|olfactory receptor OR11-118', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55367884, end_position_on_the_genomic_accession=55368918, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81341, CurrentID=0, Status='live', Symbol='OR10W1', Aliases=['OR10W1PQ', 'OR11-236', 'UNQ6469', 'OR10W1'], description='olfactory receptor family 10 subfamily W member 1', other_designations='olfactory receptor 10W1|olfactory receptor OR11-236|olfactory receptor, family 10, subfamily W, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58266792, end_position_on_the_genomic_accession=58268260, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81392, CurrentID=0, Status='live', Symbol='OR2AE1', Aliases=['OR2AE2'], description='olfactory receptor family 2 subfamily AE member 1', other_designations='olfactory receptor 2AE1|olfactory receptor 2AE2|olfactory receptor, family 2, subfamily AE, member 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99876062, end_position_on_the_genomic_accession=99877033, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81399, CurrentID=0, Status='live', Symbol='OR4F16', Aliases=['OR1-1', 'OR7-21'], description='olfactory receptor family 4 subfamily F member 16', other_designations='olfactory receptor 4F3/4F16/4F29|olfactory receptor OR1-1|olfactory receptor OR4F16|olfactory receptor OR7-21', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=683910, end_position_on_the_genomic_accession=720115, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    81442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81442, CurrentID=0, Status='live', Symbol='OR6N2', Aliases=['OR1-23'], description='olfactory receptor family 6 subfamily N member 2', other_designations='olfactory receptor 6N2|olfactory receptor OR1-23', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158774222, end_position_on_the_genomic_accession=158781204, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    81448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81448, CurrentID=0, Status='live', Symbol='OR6K2', Aliases=['OR1-17'], description='olfactory receptor family 6 subfamily K member 2', other_designations='olfactory receptor 6K2|olfactory receptor OR1-17', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158699678, end_position_on_the_genomic_accession=158700652, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81458, CurrentID=0, Status='live', Symbol='OR2T7', Aliases=['OR2T7P', 'OST723'], description='olfactory receptor family 2 subfamily T member 7', other_designations='olfactory receptor 2T7|olfactory receptor OR1-44|olfactory receptor, family 2, subfamily T, member 7 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248436359, end_position_on_the_genomic_accession=248444316, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    81466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81466, CurrentID=0, Status='live', Symbol='OR2L5', Aliases=['OR2L11P', 'OR2L5'], description='olfactory receptor family 2 subfamily L member 5', other_designations='olfactory receptor 2L5|olfactory receptor 2L11|olfactory receptor OR1-53|olfactory receptor, family 2, subfamily L, member 11|olfactory receptor, family 2, subfamily L, member 5 pseudogene|seven transmembrane helix receptor', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248013660, end_position_on_the_genomic_accession=248024276, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    81469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81469, CurrentID=0, Status='live', Symbol='OR2G3', Aliases=['OR1-33'], description='olfactory receptor family 2 subfamily G member 3', other_designations='olfactory receptor 2G3|olfactory receptor OR1-33', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247605586, end_position_on_the_genomic_accession=247606515, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81470, CurrentID=0, Status='live', Symbol='OR2G2', Aliases=['OR1-32'], description='olfactory receptor family 2 subfamily G member 2', other_designations='olfactory receptor 2G2|olfactory receptor OR1-32|olfactory receptor, family 2, subfamily G, member 2 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247588360, end_position_on_the_genomic_accession=247589313, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81472, CurrentID=0, Status='live', Symbol='OR2C3', Aliases=['OR2C4', 'OR2C5P', 'OST742'], description='olfactory receptor family 2 subfamily C member 3', other_designations='olfactory receptor 2C3|olfactory receptor 2C4|olfactory receptor 2C5|olfactory receptor OR1-30|olfactory receptor, family 2, subfamily C, member 4|olfactory receptor, family 2, subfamily C, member 5 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247524677, end_position_on_the_genomic_accession=247536440, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    81488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81488, CurrentID=0, Status='live', Symbol='POLR2M', Aliases=['GCOM1', 'GRINL1A', 'Gdown', 'Gdown1'], description='RNA polymerase II subunit M', other_designations='protein GRINL1A|GRINL1A downstream protein Gdown4|glutamate receptor, ionotropic, N-methyl D-aspartate-like 1A|polymerase (RNA) II (DNA directed) polypeptide M|polymerase (RNA) II subunit M', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=57706714, end_position_on_the_genomic_accession=57717557, orientation='plus', exon_count=4, OMIM=[606485], no_hdr0=''),
    81490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81490, CurrentID=0, Status='live', Symbol='PTDSS2', Aliases=['PSS2'], description='phosphatidylserine synthase 2', other_designations='phosphatidylserine synthase 2|PSS-2|ptdSer synthase 2|serine-exchange enzyme II', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=448215, end_position_on_the_genomic_accession=491399, orientation='plus', exon_count=16, OMIM=[612793], no_hdr0=''),
    81491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81491, CurrentID=0, Status='live', Symbol='GPR63', Aliases=['PSP24(beta)', 'PSP24B'], description='G protein-coupled receptor 63', other_designations='probable G-protein coupled receptor 63|PSP24-2|PSP24-beta|brain expressed G-protein-coupled receptor PSP24 beta', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96794125, end_position_on_the_genomic_accession=96837477, orientation='minus', exon_count=7, OMIM=[606915], no_hdr0=''),
    81492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81492, CurrentID=0, Status='live', Symbol='RSPH6A', Aliases=['RSHL1', 'RSP4', 'RSP6', 'RSPH4B'], description='radial spoke head 6 homolog A', other_designations='radial spoke head protein 6 homolog A|ortholog of mouse radial spokehead-like 1|radial spoke head-like protein 1|radial spokehead-like 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45795713, end_position_on_the_genomic_accession=45815342, orientation='minus', exon_count=6, OMIM=[607548], no_hdr0=''),
    81493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81493, CurrentID=0, Status='live', Symbol='SYNC', Aliases=['SYNC1OILIN', 'SYNC'], description='syncoilin, intermediate filament protein', other_designations='syncoilin|intermediate filament protein syncoilin|syncoilin intermediate filament 1|syncoilin-1', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32679906, end_position_on_the_genomic_accession=32703596, orientation='minus', exon_count=8, OMIM=[611750], no_hdr0=''),
    81494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81494, CurrentID=0, Status='live', Symbol='CFHR5', Aliases=['CFHL5D', 'FHR-5', 'FHR5', 'CFHR5'], description='complement factor H related 5', other_designations='complement factor H-related protein 5|factor H-related protein 5', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196975022, end_position_on_the_genomic_accession=197009725, orientation='plus', exon_count=11, OMIM=[608593], no_hdr0=''),
    81501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81501, CurrentID=0, Status='live', Symbol='DCSTAMP', Aliases=['FIND', 'TM7SF4', 'hDC-STAMP'], description='dendrocyte expressed seven transmembrane protein', other_designations='dendritic cell-specific transmembrane protein|DC-specific transmembrane protein|Dendritic cells (DC)-specific transmembrane protein|IL-4-induced protein|IL-Four (IL-4) induced|IL-Four INDuced|IL-four-induced protein|transmembrane 7 superfamily member 4', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=104339087, end_position_on_the_genomic_accession=104356874, orientation='plus', exon_count=6, OMIM=[605933], no_hdr0=''),
    81502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81502, CurrentID=0, Status='live', Symbol='HM13', Aliases=['H13', 'IMP1', 'IMPAS', 'IMPAS-1', 'MSTP086', 'PSENL3', 'PSL3', 'SPP', 'SPPL1'], description='histocompatibility minor 13', other_designations='minor histocompatibility antigen H13|intramembrane protease 1|minor histocompatibility antigen 13|presenilin-like protein 3|signal peptide peptidase beta|signal peptide peptidase like 1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31514442, end_position_on_the_genomic_accession=31569543, orientation='plus', exon_count=13, OMIM=[607106], no_hdr0=''),
    81532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81532, CurrentID=0, Status='live', Symbol='MOB2', Aliases=['HCCA2'], description='MOB kinase activator 2', other_designations='MOB kinase activator 2|MOB2 Mps One Binder homolog|Mps one binder kinase activator-like 2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1469448, end_position_on_the_genomic_accession=1486779, orientation='minus', exon_count=5, OMIM=[611969], no_hdr0=''),
    81533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81533, CurrentID=0, Status='live', Symbol='ITFG1', Aliases=['2310047C21Rik', 'CDA08', 'LNKN-1', 'TIP'], description='integrin alpha FG-GAP repeat containing 1', other_designations='T-cell immunomodulatory protein|LINKIN|integrin-alpha FG-GAP repeat-containing protein 1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=47154391, end_position_on_the_genomic_accession=47461246, orientation='minus', exon_count=19, OMIM=[611803], no_hdr0=''),
    81537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81537, CurrentID=0, Status='live', Symbol='SGPP1', Aliases=['SPP-1', 'SPPase1'], description='sphingosine-1-phosphate phosphatase 1', other_designations='sphingosine-1-phosphate phosphatase 1|hSPP1|hSPPase1|sphingosine-1-phosphatase 1|sphingosine-1-phosphate phosphohydrolase 1|spp1', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63684216, end_position_on_the_genomic_accession=63728108, orientation='minus', exon_count=4, OMIM=[612826], no_hdr0=''),
    81539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81539, CurrentID=0, Status='live', Symbol='SLC38A1', Aliases=['ATA1', 'NAT2', 'SAT1', 'SNAT1'], description='solute carrier family 38 member 1', other_designations='sodium-coupled neutral amino acid transporter 1|N-system amino acid transporter 2|amino acid transporter A1|amino acid transporter system A1|system A amino acid transporter 1|system N amino acid transporter 1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=46183063, end_position_on_the_genomic_accession=46269149, orientation='minus', exon_count=22, OMIM=[608490], no_hdr0=''),
    81542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81542, CurrentID=0, Status='live', Symbol='TMX1', Aliases=['PDIA11', 'TMX', 'TXNDC', 'TXNDC1'], description='thioredoxin related transmembrane protein 1', other_designations='thioredoxin-related transmembrane protein 1|protein disulfide isomerase family A, member 11|thioredoxin domain containing 1|thioredoxin domain-containing protein 1|transmembrane Trx-related protein', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=51240247, end_position_on_the_genomic_accession=51257655, orientation='plus', exon_count=8, OMIM=[610527], no_hdr0=''),
    81543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81543, CurrentID=0, Status='live', Symbol='LRRC3', Aliases=['C21orf102', 'C21orf30DN', 'LRRC3'], description='leucine rich repeat containing 3', other_designations='leucine-rich repeat-containing protein 3|LRRC3 downstream neighbor (non-protein coding)|intronless long ORF, AL117578', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44455510, end_position_on_the_genomic_accession=44462196, orientation='plus', exon_count=2, OMIM=[617620], no_hdr0=''),
    81544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81544, CurrentID=0, Status='live', Symbol='GDPD5', Aliases=['GDE2', 'PP1665'], description='glycerophosphodiester phosphodiesterase domain containing 5', other_designations='glycerophosphodiester phosphodiesterase domain-containing protein 5|glycerophosphocholine phosphodiesterase GDPD5|glycerophosphodiester phosphodiesterase 2|phosphoinositide phospholipase C GDPD5', map_location='11q13.4-q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75434640, end_position_on_the_genomic_accession=75525941, orientation='minus', exon_count=25, OMIM=[609632], no_hdr0=''),
    81545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81545, CurrentID=0, Status='live', Symbol='FBXO38', Aliases=['Fbx38', 'HMN2D', 'MOKA', 'SP329'], description='F-box protein 38', other_designations='F-box only protein 38|modulator of KLF7 activity homolog', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148383957, end_position_on_the_genomic_accession=148442836, orientation='plus', exon_count=25, OMIM=[608533], no_hdr0=''),
    81550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81550, CurrentID=0, Status='live', Symbol='TDRD3', Aliases=[], description='tudor domain containing 3', other_designations='tudor domain-containing protein 3', map_location='13q21.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=60396457, end_position_on_the_genomic_accession=60573879, orientation='plus', exon_count=17, OMIM=[614392], no_hdr0=''),
    81551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81551, CurrentID=0, Status='live', Symbol='STMN4', Aliases=['RB3'], description='stathmin 4', other_designations='stathmin-4|stathmin-like 4|stathmin-like protein B3|stathmin-like-protein RB3', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27235308, end_position_on_the_genomic_accession=27258865, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    81552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81552, CurrentID=0, Status='live', Symbol='VOPP1', Aliases=['ECOP', 'GASP', 'WBP1L2'], description='VOPP1 WW domain binding protein', other_designations='vesicular, overexpressed in cancer, prosurvival protein 1|EGFR-coamplified and overexpressed protein|Glioblastoma-amplified secreted protein|VOPP1, WBP1/VOPP1 family member|hypothetical protein DKFZp564K0822|putative NF-kappa-B-activating protein 055N', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55434406, end_position_on_the_genomic_accession=55572502, orientation='minus', exon_count=15, OMIM=[611915], no_hdr0=''),
    81553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81553, CurrentID=0, Status='live', Symbol='CYRIA', Aliases=['CYRI-A', 'FAM49A'], description='CYFIP related Rac1 interactor A', other_designations='CYFIP-related Rac1 interactor A|family with sequence similarity 49 member A|protein FAM49A', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=16549459, end_position_on_the_genomic_accession=16665834, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    81554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81554, CurrentID=0, Status='live', Symbol='RCC1L', Aliases=['WBSCR16'], description='RCC1 like', other_designations='RCC1-like G exchanging factor-like protein|Williams-Beuren syndrome chromosomal region 16 protein|Williams-Beuren syndrome chromosome region 16', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75027119, end_position_on_the_genomic_accession=75073802, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    81555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81555, CurrentID=0, Status='live', Symbol='YIPF5', Aliases=['FinGER5', 'MEDS2', 'SB140', 'SMAP-5', 'SMAP5', 'YIP1A'], description='Yip1 domain family member 5', other_designations='protein YIPF5|YIP1 family member 5|YPT-interacting protein 1 A|five-pass transmembrane protein localizing in the Golgi apparatus and the endoplasmic reticulum 5|golgi membrane protein SB140|smooth muscle cell associated protein 5', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=144158162, end_position_on_the_genomic_accession=144170659, orientation='minus', exon_count=6, OMIM=[611483], no_hdr0=''),
    81556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81556, CurrentID=0, Status='live', Symbol='INTS14', Aliases=['C15orf44', 'VWA9'], description='integrator complex subunit 14', other_designations='integrator complex subunit 14|UPF0464 protein C15orf44|von Willebrand factor A domain containing 9|von Willebrand factor A domain-containing protein 9', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65578757, end_position_on_the_genomic_accession=65611131, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    81557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81557, CurrentID=0, Status='live', Symbol='MAGED4B', Aliases=[], description='MAGE family member D4B', other_designations='melanoma-associated antigen D4|MAGE-D4 antigen|MAGE-E1 antigen|melanoma antigen family D, 4B|melanoma antigen family D4B', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52061827, end_position_on_the_genomic_accession=52069272, orientation='minus', exon_count=14, OMIM=[300765], no_hdr0=''),
    81558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81558, CurrentID=0, Status='live', Symbol='FAM117A', Aliases=[], description='family with sequence similarity 117 member A', other_designations='protein FAM117A|C/EBP-induced protein', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49710329, end_position_on_the_genomic_accession=49764131, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    81559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81559, CurrentID=0, Status='live', Symbol='TRIM11', Aliases=['BIA1', 'RNF92'], description='tripartite motif containing 11', other_designations='E3 ubiquitin-protein ligase TRIM11|RING finger protein 92|RING-type E3 ubiquitin transferase TRIM11|tripartite motif-containing protein 11', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228393672, end_position_on_the_genomic_accession=228406835, orientation='minus', exon_count=6, OMIM=[607868], no_hdr0=''),
    81562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81562, CurrentID=0, Status='live', Symbol='LMAN2L', Aliases=['MRT52', 'VIPL'], description='lectin, mannose binding 2 like', other_designations='VIP36-like protein|LMAN2-like protein', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96705929, end_position_on_the_genomic_accession=96740072, orientation='minus', exon_count=10, OMIM=[609552], no_hdr0=''),
    81563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81563, CurrentID=0, Status='live', Symbol='C1orf21', Aliases=['PIG13'], description='chromosome 1 open reading frame 21', other_designations='uncharacterized protein C1orf21|cell proliferation-inducing gene 13 protein|proliferation-inducing protein 13', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=184387029, end_position_on_the_genomic_accession=184629019, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    81565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81565, CurrentID=0, Status='live', Symbol='NDEL1', Aliases=['EOPA', 'MITAP1', 'NDE1L1', 'NDE2', 'NUDEL'], description='nudE neurodevelopment protein 1 like 1', other_designations='nuclear distribution protein nudE-like 1|endooligopeptidase A|mitosin-associated protein 1|mitosin-associated protein MITAP1|nudE nuclear distribution E homolog-like 1|nudE nuclear distribution gene E homolog-like 1|protein Nudel', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8435884, end_position_on_the_genomic_accession=8472744, orientation='plus', exon_count=13, OMIM=[607538], no_hdr0=''),
    81566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81566, CurrentID=0, Status='live', Symbol='CSRNP2', Aliases=['C12orf2', 'C12orf22', 'FAM130A1', 'PPP1R72', 'TAIP-12'], description='cysteine and serine rich nuclear protein 2', other_designations='cysteine/serine-rich nuclear protein 2|CSRNP-2|TGF-beta-induced apoptosis protein 12|family with sequence similarity 130, member A1|protein phosphatase 1, regulatory subunit 72', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51061205, end_position_on_the_genomic_accession=51083597, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    81567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81567, CurrentID=0, Status='live', Symbol='TXNDC5', Aliases=['ENDOPDI', 'ERP46', 'HCC-2', 'HCC2', 'PDIA15', 'STRF8', 'UNQ364'], description='thioredoxin domain containing 5', other_designations='thioredoxin domain-containing protein 5|ER protein 46|endoplasmic reticulum protein ERp46|endoplasmic reticulum resident protein 46|endothelial protein disulphide isomerase|epididymis secretory sperm binding protein|protein disulfide isomerase family A, member 15|thioredoxin domain containing 5 (endoplasmic reticulum)|thioredoxin related protein|thioredoxin-like protein p46', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7881517, end_position_on_the_genomic_accession=7910788, orientation='minus', exon_count=11, OMIM=[616412], no_hdr0=''),
    81569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81569, CurrentID=0, Status='live', Symbol='ACTL8', Aliases=['CT57'], description='actin like 8', other_designations='actin-like protein 8|actin like protein|cancer/testis antigen 57', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17755333, end_position_on_the_genomic_accession=17827063, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    81570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81570, CurrentID=0, Status='live', Symbol='CLPB', Aliases=['ANKCLB', 'HSP78', 'MEGCANN', 'MGCA7', 'SKD3'], description='caseinolytic mitochondrial matrix peptidase chaperone subunit B', other_designations='caseinolytic peptidase B protein homolog|ClpB caseinolytic peptidase B homolog|ClpB homolog, mitochondrial AAA ATPase chaperonin|ankyrin-repeat containing bacterial clp fusion|suppressor of potassium transport defect 3|testicular secretory protein Li 11', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72285495, end_position_on_the_genomic_accession=72434557, orientation='minus', exon_count=19, OMIM=[616254], no_hdr0=''),
    81572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81572, CurrentID=0, Status='live', Symbol='PDRG1', Aliases=['C20orf126', 'PDRG'], description='p53 and DNA damage regulated 1', other_designations='p53 and DNA damage-regulated protein 1|epididymis secretory sperm binding protein', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31944337, end_position_on_the_genomic_accession=31952046, orientation='minus', exon_count=5, OMIM=[610789], no_hdr0=''),
    81573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81573, CurrentID=0, Status='live', Symbol='ANKRD13C', Aliases=['dJ677H15.3'], description='ankyrin repeat domain 13C', other_designations='ankyrin repeat domain-containing protein 13C', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=70258999, end_position_on_the_genomic_accession=70354977, orientation='minus', exon_count=16, OMIM=[615125], no_hdr0=''),
    81575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81575, CurrentID=0, Status='live', Symbol='APOLD1', Aliases=['VERGE'], description='apolipoprotein L domain containing 1', other_designations='apolipoprotein L domain-containing protein 1|vascular early response gene protein', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12725917, end_position_on_the_genomic_accession=12791466, orientation='plus', exon_count=3, OMIM=[612456], no_hdr0=''),
    81576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81576, CurrentID=0, Status='live', Symbol='YJU2B', Aliases=['CCDC130'], description='YJU2 splicing factor homolog B', other_designations='coiled-coil domain-containing protein 130|9 kDa protein|coiled-coil domain containing 130', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13731752, end_position_on_the_genomic_accession=13763292, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    81577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81577, CurrentID=0, Status='live', Symbol='GFOD2', Aliases=[], description='glucose-fructose oxidoreductase domain containing 2', other_designations='glucose-fructose oxidoreductase domain-containing protein 2', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67674533, end_position_on_the_genomic_accession=67719316, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    81578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81578, CurrentID=0, Status='live', Symbol='COL21A1', Aliases=['COLA1L', 'FP633'], description='collagen type XXI alpha 1 chain', other_designations='collagen alpha-1(XXI) chain|alpha 1 chain-like collagen|collagen, type XXI, alpha 1', map_location='6p12.3-p11.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=56056590, end_position_on_the_genomic_accession=56394128, orientation='minus', exon_count=37, OMIM=[610002], no_hdr0=''),
    81579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81579, CurrentID=0, Status='live', Symbol='PLA2G12A', Aliases=['GXII', 'PLA2G12', 'ROSSY'], description='phospholipase A2 group XIIA', other_designations='group XIIA secretory phospholipase A2|GXII sPLA2|group XII secreted phospholipase A2|group XIIA secreted phospholipase A2|phosphatidylcholine 2-acylhydrolase 12A|phospholipase A2, group XII|sPLA2-XII', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109709989, end_position_on_the_genomic_accession=109730070, orientation='minus', exon_count=4, OMIM=[611652], no_hdr0=''),
    81602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81602, CurrentID=0, Status='live', Symbol='CDADC1', Aliases=['NYD-SP15', 'bA103J18.1'], description='cytidine and dCMP deaminase domain containing 1', other_designations='cytidine and dCMP deaminase domain-containing protein 1|cytidine deaminase|protein kinase NYD-SP15|testis development protein NYD-SP15', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49247875, end_position_on_the_genomic_accession=49293486, orientation='plus', exon_count=15, OMIM=[618997], no_hdr0=''),
    81603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81603, CurrentID=0, Status='live', Symbol='TRIM8', Aliases=['GERP', 'RNF27'], description='tripartite motif containing 8', other_designations='E3 ubiquitin-protein ligase TRIM8|RING-type E3 ubiquitin transferase TRIM8|glioblastoma-expressed RING finger protein|probable E3 ubiquitin-protein ligase TRIM8|ring finger protein 27|tripartite motif protein TRIM8', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102644479, end_position_on_the_genomic_accession=102658319, orientation='plus', exon_count=6, OMIM=[606125], no_hdr0=''),
    81605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81605, CurrentID=0, Status='live', Symbol='URM1', Aliases=['C9orf74'], description='ubiquitin related modifier 1', other_designations='ubiquitin-related modifier 1|ubiquitin-related modifier 1 homolog', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128371319, end_position_on_the_genomic_accession=128392016, orientation='plus', exon_count=3, OMIM=[612693], no_hdr0=''),
    81606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81606, CurrentID=0, Status='live', Symbol='LBH', Aliases=[], description='LBH regulator of WNT signaling pathway', other_designations='protein LBH|hLBH|limb bud and heart development homolog|limb bud and heart development protein homolog', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=30231534, end_position_on_the_genomic_accession=30260028, orientation='plus', exon_count=4, OMIM=[611763], no_hdr0=''),
    81607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81607, CurrentID=0, Status='live', Symbol='NECTIN4', Aliases=['EDSS1', 'LNIR', 'PRR4', 'PVRL4', 'nectin-4'], description='nectin cell adhesion molecule 4', other_designations='nectin-4|Ig superfamily receptor LNIR|nectin 4|poliovirus receptor-related 4|poliovirus receptor-related protein 4', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161070998, end_position_on_the_genomic_accession=161089566, orientation='minus', exon_count=9, OMIM=[609607], no_hdr0=''),
    81608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81608, CurrentID=0, Status='live', Symbol='FIP1L1', Aliases=['FIP1', 'Rhe', 'hFip1'], description='factor interacting with PAPOLA and CPSF1', other_designations="pre-mRNA 3'-end-processing factor FIP1|FIP1 like 1|FIP1-like 1 protein|FIP1L1 cleavage and polyadenylation specific factor subunit|factor interacting with PAP|rearranged in hypereosinophilia", map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=53377641, end_position_on_the_genomic_accession=53462583, orientation='plus', exon_count=20, OMIM=[607686], no_hdr0=''),
    81609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81609, CurrentID=0, Status='live', Symbol='SNX27', Aliases=['MRT1', 'MY014'], description='sorting nexin 27', other_designations='sorting nexin-27|methamphetamine-responsive transcript 1|sorting nexin family member 27', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151612027, end_position_on_the_genomic_accession=151699080, orientation='plus', exon_count=13, OMIM=[611541], no_hdr0=''),
    81610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81610, CurrentID=0, Status='live', Symbol='FAM83D', Aliases=['C20orf129', 'CHICA', 'dJ616B8.3'], description='family with sequence similarity 83 member D', other_designations='protein FAM83D|spindle protein CHICA', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38926417, end_position_on_the_genomic_accession=38953106, orientation='plus', exon_count=5, OMIM=[618380], no_hdr0=''),
    81611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81611, CurrentID=0, Status='live', Symbol='ANP32E', Aliases=['LANP-L', 'LANPL'], description='acidic nuclear phosphoprotein 32 family member E', other_designations='acidic leucine-rich nuclear phosphoprotein 32 family member E|LANP-like protein|acidic (leucine-rich) nuclear phosphoprotein 32 family, member E|leucine-rich acidic nuclear protein like', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150218417, end_position_on_the_genomic_accession=150236133, orientation='minus', exon_count=8, OMIM=[609611], no_hdr0=''),
    81614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81614, CurrentID=0, Status='live', Symbol='NIPA2', Aliases=['SLC57A2'], description='NIPA magnesium transporter 2', other_designations='magnesium transporter NIPA2|non imprinted in Prader-Willi/Angelman syndrome 2|non-imprinted in Prader-Willi/Angelman syndrome region protein 2', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22838641, end_position_on_the_genomic_accession=22868384, orientation='plus', exon_count=11, OMIM=[608146], no_hdr0=''),
    81615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81615, CurrentID=0, Status='live', Symbol='TMEM163', Aliases=['DC29', 'SV31'], description='transmembrane protein 163', other_designations='transmembrane protein 163', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=134455759, end_position_on_the_genomic_accession=134720934, orientation='minus', exon_count=12, OMIM=[618978], no_hdr0=''),
    81616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81616, CurrentID=0, Status='live', Symbol='ACSBG2', Aliases=['BGR', 'BRGL', 'PRTD-NY3', 'PRTDNY3'], description='acyl-CoA synthetase bubblegum family member 2', other_designations='long-chain-fatty-acid--CoA ligase ACSBG2|arachidonate--CoA ligase ACSBG2|bubblegum-related protein|testicular tissue protein Li 8', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6135633, end_position_on_the_genomic_accession=6193102, orientation='plus', exon_count=17, OMIM=[614363], no_hdr0=''),
    81617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81617, CurrentID=0, Status='live', Symbol='CAB39L', Aliases=['MO25-BETA', 'MO2L', 'bA103J18.3'], description='calcium binding protein 39 like', other_designations='calcium-binding protein 39-like|MO25beta|U937-associated antigen|antigen MLAA-34|mo25-like protein|sarcoma antigen NY-SAR-79', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49308650, end_position_on_the_genomic_accession=49444851, orientation='minus', exon_count=16, OMIM=[612175], no_hdr0=''),
    81618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81618, CurrentID=0, Status='live', Symbol='ITM2C', Aliases=['BRI3', 'BRICD2C', 'E25', 'E25C', 'ITM3'], description='integral membrane protein 2C', other_designations='integral membrane protein 2C|BRICHOS domain containing 2C|cerebral protein 14|integral membrane protein 3|transmembrane protein BRI3', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230864185, end_position_on_the_genomic_accession=230879254, orientation='plus', exon_count=7, OMIM=[609554], no_hdr0=''),
    81619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81619, CurrentID=0, Status='live', Symbol='TSPAN14', Aliases=['DC-TM4F2', 'TM4SF14', 'tspan-14'], description='tetraspanin 14', other_designations='tetraspanin-14|tetraspanin similar to TM4SF9|transmembrane 4 superfamily member 14', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80454275, end_position_on_the_genomic_accession=80522631, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    81620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81620, CurrentID=0, Status='live', Symbol='CDT1', Aliases=['DUP', 'RIS2'], description='chromatin licensing and DNA replication factor 1', other_designations='DNA replication factor Cdt1|Double parked, Drosophila, homolog of', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88803789, end_position_on_the_genomic_accession=88809258, orientation='plus', exon_count=10, OMIM=[605525], no_hdr0=''),
    81621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81621, CurrentID=0, Status='live', Symbol='KAZALD1', Aliases=['BONO1', 'FKSG28', 'FKSG40', 'IGFBP-rP10'], description='Kazal type serine peptidase inhibitor domain 1', other_designations='kazal-type serine protease inhibitor domain-containing protein 1|IGFBP-related protein 10|bone- and odontoblast-expressed gene 1|novel kazal-type serine protease inhibitor domain and immunoglobulin domain containing protein', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101061085, end_position_on_the_genomic_accession=101068131, orientation='plus', exon_count=7, OMIM=[609208], no_hdr0=''),
    81622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81622, CurrentID=0, Status='live', Symbol='UNC93B1', Aliases=['IIAE1', 'UNC93', 'UNC93B', 'Unc-93B1'], description='unc-93 homolog B1, TLR signaling regulator', other_designations='protein unc-93 homolog B1|unc-93 related protein|unc93 homolog B1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67991100, end_position_on_the_genomic_accession=68004097, orientation='minus', exon_count=11, OMIM=[608204], no_hdr0=''),
    81623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81623, CurrentID=0, Status='live', Symbol='DEFB126', Aliases=['C20orf8', 'DEFB-26', 'DEFB26', 'HBD26', 'bA530N10.1', 'hBD-26'], description='defensin beta 126', other_designations='beta-defensin 126|epididymal secretory protein ESP13.2|epididymis secretory sperm binding protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=142590, end_position_on_the_genomic_accession=145751, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    81624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81624, CurrentID=0, Status='live', Symbol='DIAPH3', Aliases=['AN', 'AUNA1', 'DIA2', 'DRF3', 'NSDAN', 'diap3', 'mDia2'], description='diaphanous related formin 3', other_designations='protein diaphanous homolog 3|diaphanous homolog 3', map_location='13q21.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=59665583, end_position_on_the_genomic_accession=60163928, orientation='minus', exon_count=38, OMIM=[614567], no_hdr0=''),
    81626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81626, CurrentID=0, Status='live', Symbol='SHCBP1L', Aliases=['C1orf14', 'GE36'], description='SHC binding and spindle associated 1 like', other_designations='testicular spindle-associated protein SHCBP1L|SHC SH2 domain-binding protein 1-like protein|SHC SH2-domain binding protein 1-like', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182899865, end_position_on_the_genomic_accession=182953166, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    81627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81627, CurrentID=0, Status='live', Symbol='TRMT1L', Aliases=['C1orf25', 'MST070', 'MSTP070', 'TRM1L', 'bG120K12.3'], description='tRNA methyltransferase 1 like', other_designations='TRMT1-like protein|TRM1 tRNA methyltransferase 1-like|TRM1-like protein|tRNA methyltransferase 1 homolog-like', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=185118101, end_position_on_the_genomic_accession=185157098, orientation='minus', exon_count=17, OMIM=[611673], no_hdr0=''),
    81628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81628, CurrentID=0, Status='live', Symbol='TSC22D4', Aliases=['THG-1', 'THG1', 'TILZ2'], description='TSC22 domain family member 4', other_designations='TSC22 domain family protein 4|TSC22-related-inducible leucine zipper protein 2|tsc-22-like protein THG-1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100466519, end_position_on_the_genomic_accession=100479214, orientation='minus', exon_count=5, OMIM=[611914], no_hdr0=''),
    81629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81629, CurrentID=0, Status='live', Symbol='TSSK3', Aliases=['SPOGA3', 'STK22C', 'STK22D', 'TSK3'], description='testis specific serine kinase 3', other_designations='testis-specific serine/threonine-protein kinase 3|TSK-3|TSSK-3|serine/threonine-protein kinase 22C|spermiogenesis associated 3|testis-specific kinase 3|testis-specific serine/threonine kinase 22C', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32352720, end_position_on_the_genomic_accession=32365265, orientation='plus', exon_count=4, OMIM=[607660], no_hdr0=''),
    81631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81631, CurrentID=0, Status='live', Symbol='MAP1LC3B', Aliases=['ATG8F', 'LC3B', 'MAP1A/1BLC3-a', 'MAP1LC3B'], description='microtubule associated protein 1 light chain 3 beta', other_designations='microtubule-associated proteins 1A/1B light chain 3B|MAP1 light chain 3-like protein 2|MAP1A/MAP1B LC3 B|MAP1A/MAP1B light chain 3 B|autophagy-related ubiquitin-like modifier LC3 B', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87392336, end_position_on_the_genomic_accession=87404774, orientation='plus', exon_count=4, OMIM=[609604], no_hdr0=''),
    81669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81669, CurrentID=0, Status='live', Symbol='CCNL2', Aliases=['ANIA-6B', 'CCNM', 'CCNS', 'HCLA-ISO', 'HLA-ISO', 'PCEE', 'SB138'], description='cyclin L2', other_designations='cyclin-L2|cyclin M|cyclin S|paneth cell-enhanced expression protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1385711, end_position_on_the_genomic_accession=1399336, orientation='minus', exon_count=16, OMIM=[613482], no_hdr0=''),
    81671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81671, CurrentID=0, Status='live', Symbol='VMP1', Aliases=['EPG3', 'TANGO5', 'TMEM49'], description='vacuole membrane protein 1', other_designations='vacuole membrane protein 1|ectopic P-granules autophagy protein 3 homolog|transmembrane protein 49|transport and golgi organization 5 homolog', map_location='17q23.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59707654, end_position_on_the_genomic_accession=59842255, orientation='plus', exon_count=13, OMIM=[611753], no_hdr0=''),
    81688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81688, CurrentID=0, Status='live', Symbol='C6orf62', Aliases=['Nbla00237', 'XTP12', 'dJ30M3.2'], description='chromosome 6 open reading frame 62', other_designations='uncharacterized protein C6orf62|HBV X-transactivated gene 12 protein|HBV X-transactivated protein 12|HBV XAg-transactivated protein 12', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24704299, end_position_on_the_genomic_accession=24720920, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    81689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81689, CurrentID=0, Status='live', Symbol='ISCA1', Aliases=['HBLD2', 'ISA1', 'MMDS5', 'hIscA'], description='iron-sulfur cluster assembly 1', other_designations='iron-sulfur cluster assembly 1 homolog, mitochondrial|HESB like domain containing 2|HESB-like domain-containing protein 2|iron-sulfur assembly protein IscA', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=86264546, end_position_on_the_genomic_accession=86282538, orientation='minus', exon_count=4, OMIM=[611006], no_hdr0=''),
    81691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81691, CurrentID=0, Status='live', Symbol='REXO5', Aliases=['NEF-sp'], description='RNA exonuclease 5', other_designations='RNA exonuclease 5|exonuclease NEF-sp|putative RNA exonuclease NEF-sp', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20806429, end_position_on_the_genomic_accession=20849682, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    81693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81693, CurrentID=0, Status='live', Symbol='AMN', Aliases=['IGS2', 'PRO1028', 'amnionless'], description='amnion associated transmembrane protein', other_designations='protein amnionless|amnionless homolog|visceral endoderm-specific type 1 transmembrane protein', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102922430, end_position_on_the_genomic_accession=102933597, orientation='plus', exon_count=14, OMIM=[605799], no_hdr0=''),
    81696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81696, CurrentID=0, Status='live', Symbol='OR5V1', Aliases=['6M1-21', 'hs6M1-21'], description='olfactory receptor family 5 subfamily V member 1', other_designations='olfactory receptor 5V1|olfactory receptor OR6-26', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29353749, end_position_on_the_genomic_accession=29455207, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    81697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81697, CurrentID=0, Status='live', Symbol='OR2B2', Aliases=['OR2B2Q', 'OR2B9', 'OR6-1', 'dJ193B12.4', 'hs6M1-10'], description='olfactory receptor family 2 subfamily B member 2', other_designations='olfactory receptor 2B2|olfactory receptor 2B9|olfactory receptor 6-1|olfactory receptor OR6-2|olfactory receptor, family 2, subfamily B, member 9', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27911185, end_position_on_the_genomic_accession=27912396, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81704, CurrentID=0, Status='live', Symbol='DOCK8', Aliases=['HEL-205', 'MRD2', 'ZIR8'], description='dedicator of cytokinesis 8', other_designations='dedicator of cytokinesis protein 8|1200017A24Rik|epididymis luminal protein 205', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=211296, end_position_on_the_genomic_accession=465260, orientation='plus', exon_count=54, OMIM=[611432], no_hdr0=''),
    81706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81706, CurrentID=0, Status='live', Symbol='PPP1R14C', Aliases=['CPI17-like', 'KEPI', 'NY-BR-81'], description='protein phosphatase 1 regulatory inhibitor subunit 14C', other_designations='protein phosphatase 1 regulatory subunit 14C|PKC-potentiated PP1 inhibitory protein|kinase C-enhanced PP1 inhibitor|kinase-enhanced PP1 inhibitor|serologically defined breast cancer antigen NY-BR-81', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150143044, end_position_on_the_genomic_accession=150250392, orientation='plus', exon_count=5, OMIM=[613242], no_hdr0=''),
    81786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81786, CurrentID=0, Status='live', Symbol='TRIM7', Aliases=['GNIP', 'RNF90'], description='tripartite motif containing 7', other_designations='E3 ubiquitin-protein ligase TRIM7|RING finger protein 90|glycogenin-interacting protein|tripartite motif protein TRIM7', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181193924, end_position_on_the_genomic_accession=181218332, orientation='minus', exon_count=9, OMIM=[609315], no_hdr0=''),
    81788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81788, CurrentID=0, Status='live', Symbol='NUAK2', Aliases=['SNARK'], description='NUAK family kinase 2', other_designations='NUAK family SNF1-like kinase 2|NUAK family, SNF1-like kinase, 2|SNF1/AMP activated protein kinase|SNF1/AMP kinase-related kinase|omphalocele kinase 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205302059, end_position_on_the_genomic_accession=205321745, orientation='minus', exon_count=8, OMIM=[608131], no_hdr0=''),
    81789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81789, CurrentID=0, Status='live', Symbol='TIGD6', Aliases=[], description='tigger transposable element derived 6', other_designations='tigger transposable element-derived protein 6', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149993118, end_position_on_the_genomic_accession=150000654, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    81790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81790, CurrentID=0, Status='live', Symbol='RNF170', Aliases=['ADSA', 'SNAX1'], description='ring finger protein 170', other_designations='E3 ubiquitin-protein ligase RNF170|RING-type E3 ubiquitin transferase RNF170|putative LAG1-interacting protein', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42849637, end_position_on_the_genomic_accession=42897294, orientation='minus', exon_count=11, OMIM=[614649], no_hdr0=''),
    81792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81792, CurrentID=0, Status='live', Symbol='ADAMTS12', Aliases=['PRO4389'], description='ADAM metallopeptidase with thrombospondin type 1 motif 12', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 12|ADAM-TS 12|ADAM-TS12|ADAMTS-12|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 12', map_location='5p13.3-p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=33523535, end_position_on_the_genomic_accession=33892180, orientation='minus', exon_count=27, OMIM=[606184], no_hdr0=''),
    81793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81793, CurrentID=0, Status='live', Symbol='TLR10', Aliases=['CD290'], description='toll like receptor 10', other_designations='toll-like receptor 10', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38772238, end_position_on_the_genomic_accession=38782990, orientation='minus', exon_count=5, OMIM=[606270], no_hdr0=''),
    81794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81794, CurrentID=0, Status='live', Symbol='ADAMTS10', Aliases=['ADAM-TS10', 'ADAMTS-10', 'WMS', 'WMS1'], description='ADAM metallopeptidase with thrombospondin type 1 motif 10', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 10|ADAM-TS 10|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 10|zinc metalloendopeptidase', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8580240, end_position_on_the_genomic_accession=8610715, orientation='minus', exon_count=26, OMIM=[608990], no_hdr0=''),
    81796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81796, CurrentID=0, Status='live', Symbol='SLCO5A1', Aliases=['OATP-J', 'OATP-RP4', 'OATP5A1', 'OATPJ', 'OATPRP4', 'SLC21A15'], description='solute carrier organic anion transporter family member 5A1', other_designations='solute carrier organic anion transporter family member 5A1|organic anion transporter polypeptide-related protein 4|solute carrier family 21 (organic anion transporter), member 15|solute carrier family 21 member 15', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=69667046, end_position_on_the_genomic_accession=69835064, orientation='minus', exon_count=13, OMIM=[613543], no_hdr0=''),
    81797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81797, CurrentID=0, Status='live', Symbol='OR12D3', Aliases=['hs6M1-27'], description='olfactory receptor family 12 subfamily D member 3', other_designations='olfactory receptor 12D3|olfactory receptor OR6-27', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29373423, end_position_on_the_genomic_accession=29375291, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81831, CurrentID=0, Status='live', Symbol='NETO2', Aliases=['BTCL2', 'NEOT2'], description='neuropilin and tolloid like 2', other_designations='neuropilin and tolloid-like protein 2|brain-specific transmembrane protein containing 2 CUB and 1 LDL-receptor class A domains protein 2|neuropilin (NRP) and tolloid (TLL)-like 2', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=47077703, end_position_on_the_genomic_accession=47144025, orientation='minus', exon_count=11, OMIM=[607974], no_hdr0=''),
    81832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81832, CurrentID=0, Status='live', Symbol='NETO1', Aliases=['BCTL1', 'BTCL1'], description='neuropilin and tolloid like 1', other_designations='neuropilin and tolloid-like protein 1|brain-specific transmembrane protein containing 2 CUB and 1 LDL-receptor class A domains protein 1|neuropilin (NRP) and tolloid (TLL)-like 1', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=72742314, end_position_on_the_genomic_accession=72867987, orientation='minus', exon_count=19, OMIM=[607973], no_hdr0=''),
    81833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81833, CurrentID=0, Status='live', Symbol='SPACA1', Aliases=['SAMP32'], description='sperm acrosome associated 1', other_designations='sperm acrosome membrane-associated protein 1|sperm acrosomal membrane-associated protein 32', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=88046907, end_position_on_the_genomic_accession=88066838, orientation='plus', exon_count=8, OMIM=[612739], no_hdr0=''),
    81839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81839, CurrentID=0, Status='live', Symbol='VANGL1', Aliases=['KITENIN', 'LPP2', 'STB2', 'STBM2'], description='VANGL planar cell polarity protein 1', other_designations='vang-like protein 1|KAI1 C-terminal interacting tetraspanin|loop-tail protein 2 homolog|strabismus 2|van Gogh-like protein 1|vang-like 1 (van gogh, Drosophila)', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=115641970, end_position_on_the_genomic_accession=115698221, orientation='plus', exon_count=9, OMIM=[610132], no_hdr0=''),
    81844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81844, CurrentID=0, Status='live', Symbol='TRIM56', Aliases=['RNF109'], description='tripartite motif containing 56', other_designations='E3 ubiquitin-protein ligase TRIM56|RING finger protein 109|RING-type E3 ubiquitin transferase TRIM56|tripartite motif-containing protein 56', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101085424, end_position_on_the_genomic_accession=101097967, orientation='plus', exon_count=3, OMIM=[616996], no_hdr0=''),
    81846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81846, CurrentID=0, Status='live', Symbol='SBF2', Aliases=['CMT4B2', 'DENND7B', 'MTMR13'], description='SET binding factor 2', other_designations='myotubularin-related protein 13|DENN/MADD domain containing 7B|inactive phosphatidylinositol 3-phosphatase 13', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9778668, end_position_on_the_genomic_accession=10294219, orientation='minus', exon_count=46, OMIM=[607697], no_hdr0=''),
    81847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81847, CurrentID=0, Status='live', Symbol='RNF146', Aliases=[], description='ring finger protein 146', other_designations='E3 ubiquitin-protein ligase RNF146|RING-type E3 ubiquitin transferase RNF146|dactylidin|iduna', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127263415, end_position_on_the_genomic_accession=127289893, orientation='plus', exon_count=7, OMIM=[612137], no_hdr0=''),
    81848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81848, CurrentID=0, Status='live', Symbol='SPRY4', Aliases=['HH17'], description='sprouty RTK signaling antagonist 4', other_designations='protein sprouty homolog 4|sprouty homolog 4', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=142310430, end_position_on_the_genomic_accession=142325021, orientation='minus', exon_count=5, OMIM=[607984], no_hdr0=''),
    81849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81849, CurrentID=0, Status='live', Symbol='ST6GALNAC5', Aliases=['SIAT7-E', 'SIAT7E', 'ST6GalNAcV'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 5', other_designations='alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase 5|GD1 alpha synthase|GalNAc alpha-2,6-sialyltransferase V|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 5|ST6 GalNAc alpha-2,6-sialyltransferase 5|ST6 neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 5|ST6GalNAc V|alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase V|alpha-N-acetylneuraminyl 2,3-betagalactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase E|sialyltransferase 7 ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase) E|sialyltransferase 7E', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=76867449, end_position_on_the_genomic_accession=77069167, orientation='plus', exon_count=6, OMIM=[610134], no_hdr0=''),
    81850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81850, CurrentID=0, Status='live', Symbol='KRTAP1-3', Aliases=['KAP1.2', 'KAP1.3', 'KAP1.6', 'KAP1.8A', 'KAP1.8B', 'KAP1.9', 'KRTAP1.3'], description='keratin associated protein 1-3', other_designations='keratin-associated protein 1-3|keratin associated protein 1.6|keratin-associated protein 1.8|keratin-associated protein 1.9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41033884, end_position_on_the_genomic_accession=41034874, orientation='minus', exon_count=1, OMIM=[608820], no_hdr0=''),
    81851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81851, CurrentID=0, Status='live', Symbol='KRTAP1-1', Aliases=['HB2A', 'KAP1.1', 'KAP1.1A', 'KAP1.1B', 'KAP1.6', 'KAP1.7', 'KRTAP1.1', 'KRTAP1A', 'hKAP1.7'], description='keratin associated protein 1-1', other_designations='keratin-associated protein 1-1|high sulfur keratin-associated protein 1.1|keratin associated protein 1.7|keratin associated protein 1A|keratin-associated protein 1.1|keratin-associated protein 1.6', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41040541, end_position_on_the_genomic_accession=41041450, orientation='minus', exon_count=1, OMIM=[608819], no_hdr0=''),
    81853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81853, CurrentID=0, Status='live', Symbol='TMEM14B', Aliases=[], description='transmembrane protein 14B', other_designations='transmembrane protein 14B', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10747759, end_position_on_the_genomic_accession=10759774, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    81855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81855, CurrentID=0, Status='live', Symbol='SFXN3', Aliases=['BA108L7.2', 'SFX3', 'SLC56A3'], description='sideroflexin 3', other_designations='sideroflexin-3', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=101031234, end_position_on_the_genomic_accession=101041243, orientation='plus', exon_count=12, OMIM=[615571], no_hdr0=''),
    81856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81856, CurrentID=0, Status='live', Symbol='ZNF611', Aliases=[], description='zinc finger protein 611', other_designations='zinc finger protein 611', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52702813, end_position_on_the_genomic_accession=52735044, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    81857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81857, CurrentID=0, Status='live', Symbol='MED25', Aliases=['ACID1', 'ARC92', 'BVSYS', 'CMT2B2', 'P78', 'PTOV2', 'TCBAP0758'], description='mediator complex subunit 25', other_designations='mediator of RNA polymerase II transcription subunit 25|ARC/mediator transcriptional coactivator subunit|activator interaction domain-containing protein 1|activator-recruited cofactor 92 kDa component|mediator of RNA polymerase II transcription, subunit 25 homolog|prostate-derived protein 78 kDa', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49818289, end_position_on_the_genomic_accession=49840384, orientation='plus', exon_count=19, OMIM=[610197], no_hdr0=''),
    81858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81858, CurrentID=0, Status='live', Symbol='SHARPIN', Aliases=['SIPL1'], description='SHANK associated RH domain interactor', other_designations='sharpin|hSIPL1|shank-associated RH domain-interacting protein|shank-interacting protein-like 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144098637, end_position_on_the_genomic_accession=144104248, orientation='minus', exon_count=8, OMIM=[611885], no_hdr0=''),
    81870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81870, CurrentID=0, Status='live', Symbol='KRTAP9-9', Aliases=['KAP9.5', 'KAP9.9', 'KRTAP9-5', 'KRTAP9.9'], description='keratin associated protein 9-9', other_designations='keratin-associated protein 9-9|keratin-associated protein 9-5|keratin-associated protein 9.5|ultrahigh sulfur keratin-associated protein 9.9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41255384, end_position_on_the_genomic_accession=41256364, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    81871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81871, CurrentID=0, Status='live', Symbol='KRTAP4-6', Aliases=['KAP4.15', 'KAP4.6', 'KRTAP4-15', 'KRTAP4.15'], description='keratin associated protein 4-6', other_designations='keratin-associated protein 4-6|keratin associated protein 4-15|keratin-associated protein 4.6|ultrahigh sulfur keratin-associated protein 4.15', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41139433, end_position_on_the_genomic_accession=41140487, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81872, CurrentID=0, Status='live', Symbol='KRTAP2-1', Aliases=['KAP2.1A', 'KRTAP2.1A'], description='keratin associated protein 2-1', other_designations='keratin-associated protein 2-1|high sulfur keratin-associated protein 2.1|keratin associated protein KRTAP2.1A|keratin-associated protein 2.1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41046541, end_position_on_the_genomic_accession=41047316, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    81873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81873, CurrentID=0, Status='live', Symbol='ARPC5L', Aliases=['ARC16-2'], description='actin related protein 2/3 complex subunit 5 like', other_designations='actin-related protein 2/3 complex subunit 5-like protein|arp2/3 complex 16 kDa subunit 2|epididymis secretory sperm binding protein', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124862130, end_position_on_the_genomic_accession=124877733, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    81875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81875, CurrentID=0, Status='live', Symbol='ISG20L2', Aliases=['HSD38'], description='interferon stimulated exonuclease gene 20 like 2', other_designations='interferon-stimulated 20 kDa exonuclease-like 2|interferon stimulated exonuclease gene 20kDa like 2', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156721891, end_position_on_the_genomic_accession=156728766, orientation='minus', exon_count=5, OMIM=[611930], no_hdr0=''),
    81876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81876, CurrentID=0, Status='live', Symbol='RAB1B', Aliases=[], description='RAB1B, member RAS oncogene family', other_designations='ras-related protein Rab-1B|small GTP-binding protein', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66268526, end_position_on_the_genomic_accession=66277492, orientation='plus', exon_count=5, OMIM=[612565], no_hdr0=''),
    81887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81887, CurrentID=0, Status='live', Symbol='LAS1L', Aliases=['Las1', 'Las1-like', 'WTS', 'dJ475B7.2'], description='LAS1 like ribosome biogenesis factor', other_designations='ribosomal biogenesis protein LAS1L|protein LAS1 homolog', map_location='Xq12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=65512582, end_position_on_the_genomic_accession=65534787, orientation='minus', exon_count=16, OMIM=[300964], no_hdr0=''),
    81888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81888, CurrentID=0, Status='live', Symbol='HYI', Aliases=['HT036'], description='hydroxypyruvate isomerase (putative)', other_designations='putative hydroxypyruvate isomerase|endothelial cell apoptosis protein E-CE1|hydroxypyruvate isomerase homolog', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43450607, end_position_on_the_genomic_accession=43454241, orientation='minus', exon_count=9, OMIM=[619128], no_hdr0=''),
    81889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81889, CurrentID=0, Status='live', Symbol='FAHD1', Aliases=['C16orf36', 'YISKL'], description='fumarylacetoacetate hydrolase domain containing 1', other_designations='acylpyruvase FAHD1, mitochondrial|FAH domain-containing protein 1|OAA decarboxylase|YISK like/RJD15|acylpyruvate hydrolase|fumarylacetoacetate hydrolase domain-containing protein 1|oxaloacetate decarboxylase|yisK-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1827206, end_position_on_the_genomic_accession=1840207, orientation='plus', exon_count=3, OMIM=[616320], no_hdr0=''),
    81890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81890, CurrentID=0, Status='live', Symbol='QTRT1', Aliases=['FP3235', 'TGT', 'TGUT'], description='queuine tRNA-ribosyltransferase catalytic subunit 1', other_designations='queuine tRNA-ribosyltransferase catalytic subunit 1|TGT, 43-KD subunit|TGT, catalytic subunit|guanine insertion enzyme|queuine tRNA-ribosyltransferase 1|tRNA-guanine transglycosylase', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10701439, end_position_on_the_genomic_accession=10713365, orientation='plus', exon_count=10, OMIM=[609615], no_hdr0=''),
    81892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81892, CurrentID=0, Status='live', Symbol='SLIRP', Aliases=['C14orf156', 'DC50', 'PD04872'], description='SRA stem-loop interacting RNA binding protein', other_designations='SRA stem-loop-interacting RNA-binding protein, mitochondrial', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77708071, end_position_on_the_genomic_accession=77717598, orientation='plus', exon_count=5, OMIM=[610211], no_hdr0=''),
    81894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81894, CurrentID=0, Status='live', Symbol='SLC25A28', Aliases=['MFRN2', 'MRS3/4', 'MRS4L', 'NPD016'], description='solute carrier family 25 member 28', other_designations='mitoferrin-2|hMRS3/4|mitochondrial RNA splicing protein 3/4|mitochondrial RNA-splicing protein 3/4 homolog|mitochondrial iron transporter 2|putative mitochondrial solute carrier|solute carrier family 25 (mitochondrial iron transporter), member 28', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99610522, end_position_on_the_genomic_accession=99659507, orientation='minus', exon_count=11, OMIM=[609767], no_hdr0=''),
    81926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81926, CurrentID=0, Status='live', Symbol='ABHD17A', Aliases=['C19orf27', 'FAM108A1'], description='abhydrolase domain containing 17A, depalmitoylase', other_designations='alpha/beta hydrolase domain-containing protein 17A|abhydrolase domain-containing protein 17A|abhydrolase domain-containing protein FAM108A1|family with sequence similarity 108, member A1|protein ABHD17A', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1876810, end_position_on_the_genomic_accession=1885519, orientation='minus', exon_count=7, OMIM=[617942], no_hdr0=''),
    81928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81928, CurrentID=0, Status='live', Symbol='CABLES2', Aliases=['C20orf150', 'dJ908M14.2', 'ik3-2'], description='Cdk5 and Abl enzyme substrate 2', other_designations='CDK5 and ABL1 enzyme substrate 2|interactor with CDK3 2', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62388634, end_position_on_the_genomic_accession=62407285, orientation='minus', exon_count=10, OMIM=[618772], no_hdr0=''),
    81929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81929, CurrentID=0, Status='live', Symbol='SEH1L', Aliases=['SEC13L', 'SEH1A', 'SEH1B', 'Seh1'], description='SEH1 like nucleoporin', other_designations='nucleoporin SEH1|GATOR complex protein SEH1|SEC13-like protein|nup107-160 subcomplex subunit SEH1|sec13 like protein', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12947988, end_position_on_the_genomic_accession=12987665, orientation='plus', exon_count=12, OMIM=[609263], no_hdr0=''),
    81930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81930, CurrentID=0, Status='live', Symbol='KIF18A', Aliases=['MS-KIF18A', 'PPP1R99'], description='kinesin family member 18A', other_designations='kinesin-like protein KIF18A|protein phosphatase 1, regulatory subunit 99', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=28020619, end_position_on_the_genomic_accession=28108180, orientation='minus', exon_count=18, OMIM=[611271], no_hdr0=''),
    81931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81931, CurrentID=0, Status='live', Symbol='ZNF93', Aliases=['HPF34', 'HTF34', 'TF34', 'ZNF505'], description='zinc finger protein 93', other_designations='zinc finger protein 93|zinc finger protein 505|zinc finger protein HTF34', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19900946, end_position_on_the_genomic_accession=19935575, orientation='plus', exon_count=4, OMIM=[603975], no_hdr0=''),
    81932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=81932, CurrentID=0, Status='live', Symbol='HDHD3', Aliases=['2810435D12Rik', 'C9orf158'], description='haloacid dehalogenase like hydrolase domain containing 3', other_designations='haloacid dehalogenase-like hydrolase domain-containing protein 3', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113373416, end_position_on_the_genomic_accession=113376986, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    83259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83259, CurrentID=0, Status='live', Symbol='PCDH11Y', Aliases=['PCDH-PC', 'PCDH22', 'PCDHX', 'PCDHY'], description='protocadherin 11 Y-linked', other_designations='protocadherin-11 Y-linked|protocadherin 22|protocadherin on the Y chromosome|protocadherin prostate cancer|protocadherin-PC', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=5000044, end_position_on_the_genomic_accession=5742228, orientation='plus', exon_count=12, OMIM=[400022], no_hdr0=''),
    83394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83394, CurrentID=0, Status='live', Symbol='PITPNM3', Aliases=['ACKR6', 'CORD5', 'NIR1', 'RDGBA3'], description='PITPNM family member 3', other_designations='membrane-associated phosphatidylinositol transfer protein 3|NIR-1|PITPnm 3|PYK2 N-terminal domain-interacting receptor 1|atypical chemokine receptor 6|cone rod dystrophy 5|phosphatidylinositol transfer protein, membrane-associated 3|retinal degeneration B alpha 3', map_location='17p13.2-p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6451263, end_position_on_the_genomic_accession=6556555, orientation='minus', exon_count=22, OMIM=[608921], no_hdr0=''),
    83401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83401, CurrentID=0, Status='live', Symbol='ELOVL3', Aliases=['CIG-30', 'CIG30'], description='ELOVL fatty acid elongase 3', other_designations='elongation of very long chain fatty acids protein 3|3-keto acyl-CoA synthase ELOVL3|ELOVL FA elongase 3|cold-inducible glycoprotein of 30 kDa|elongation of very long chain fatty acids (FEN1/Elo2, SUR4/Elo3, yeast)-like 3|very long chain 3-ketoacyl-CoA synthase 3|very long chain 3-oxoacyl-CoA synthase 3', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102224767, end_position_on_the_genomic_accession=102229589, orientation='plus', exon_count=5, OMIM=[611815], no_hdr0=''),
    83416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83416, CurrentID=0, Status='live', Symbol='FCRL5', Aliases=['BXMAS1', 'CD307', 'CD307e', 'FCRH5', 'IRTA2', 'PRO820'], description='Fc receptor like 5', other_designations='Fc receptor-like protein 5|fc receptor homolog 5|fcR-like protein 5|immune receptor translocation-associated protein 2|immunoglobulin superfamily receptor translocation associated 2 (IRTA2)', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157513377, end_position_on_the_genomic_accession=157552533, orientation='minus', exon_count=17, OMIM=[605877], no_hdr0=''),
    83417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83417, CurrentID=0, Status='live', Symbol='FCRL4', Aliases=['CD307d', 'FCRH4', 'IGFP2', 'IRTA1'], description='Fc receptor like 4', other_designations='Fc receptor-like protein 4|IFGP family protein 2|fc receptor homolog 4|fcR-like protein 4|hIFGP2|immune receptor translocation-associated protein 1|immunoglobulin superfamily Fc receptor, gp42|immunoglobulin superfamily receptor translocation associated 1', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157573747, end_position_on_the_genomic_accession=157598085, orientation='minus', exon_count=12, OMIM=[605876], no_hdr0=''),
    83439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83439, CurrentID=0, Status='live', Symbol='TCF7L1', Aliases=['TCF-3', 'TCF3'], description='transcription factor 7 like 1', other_designations='transcription factor 7-like 1|HMG box transcription factor 3|transcription factor 7-like 1 (T-cell specific, HMG-box)', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85133392, end_position_on_the_genomic_accession=85310387, orientation='plus', exon_count=12, OMIM=[604652], no_hdr0=''),
    83440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83440, CurrentID=0, Status='live', Symbol='ADPGK', Aliases=['2610017G09Rik', 'ADP-GK'], description='ADP dependent glucokinase', other_designations='ADP-dependent glucokinase|ATP-dependent glucokinase|rbBP-35', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72751294, end_position_on_the_genomic_accession=72783776, orientation='minus', exon_count=9, OMIM=[611861], no_hdr0=''),
    83442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83442, CurrentID=0, Status='live', Symbol='SH3BGRL3', Aliases=['HEL-S-297', 'SH3BP-1', 'TIP-B1'], description='SH3 domain binding glutamate rich protein like 3', other_designations='SH3 domain-binding glutamic acid-rich-like protein 3|SH3 domain binding glutamic acid-rich protein like 3|SH3 domain-binding protein 1|SH3BGRL3-like protein|TNF inhibitory protein|epididymis secretory protein Li 297|epididymis secretory sperm binding protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26280086, end_position_on_the_genomic_accession=26281522, orientation='plus', exon_count=3, OMIM=[615679], no_hdr0=''),
    83443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83443, CurrentID=0, Status='live', Symbol='SF3B5', Aliases=['SF3b10', 'Ysf3'], description='splicing factor 3b subunit 5', other_designations='splicing factor 3B subunit 5|pre-mRNA-splicing factor SF3b 10 kDa subunit|splicing factor 3b, subunit 5, 10kDa', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=144094884, end_position_on_the_genomic_accession=144095573, orientation='minus', exon_count=1, OMIM=[617847], no_hdr0=''),
    83444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83444, CurrentID=0, Status='live', Symbol='INO80B', Aliases=['HMGA1L4', 'HMGIYL4', 'IES2', 'PAP-1BP', 'PAPA-1', 'PAPA1', 'ZNHIT4', 'hIes2'], description='INO80 complex subunit B', other_designations='INO80 complex subunit B|IES2 homolog|PAP (Pim-1 associated protein) associated protein 1|PAP-1 binding protein|PAP-1-associated protein 1|high mobility group AT-hook 1-like 4|zinc finger HIT domain-containing protein 4|zinc finger, HIT type 4', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74455087, end_position_on_the_genomic_accession=74457944, orientation='plus', exon_count=5, OMIM=[616456], no_hdr0=''),
    83445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83445, CurrentID=0, Status='live', Symbol='GSG1', Aliases=[], description='germ cell associated 1', other_designations='germ cell-specific gene 1 protein|testicular secretory protein Li 20', map_location='12p13.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=13083532, end_position_on_the_genomic_accession=13103678, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    83446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83446, CurrentID=0, Status='live', Symbol='CCDC70', Aliases=[], description='coiled-coil domain containing 70', other_designations='coiled-coil domain-containing protein 70', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51861969, end_position_on_the_genomic_accession=51866232, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    83447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83447, CurrentID=0, Status='live', Symbol='SLC25A31', Aliases=['AAC4', 'ANT 4', 'ANT4', 'SFEC35kDa'], description='solute carrier family 25 member 31', other_designations='ADP/ATP translocase 4|ADP,ATP carrier protein 4|adenine nucleotide translocase 4|adenine nucleotide translocator 4|solute carrier family 25 (mitochondrial carrier; adenine nucleotide translocator), member 31|sperm flagellar energy carrier protein', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127730372, end_position_on_the_genomic_accession=127774299, orientation='plus', exon_count=7, OMIM=[610796], no_hdr0=''),
    83448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83448, CurrentID=0, Status='live', Symbol='PUS7L', Aliases=[], description='pseudouridine synthase 7 like', other_designations='pseudouridylate synthase 7 homolog-like protein|pseudouridylate synthase 7 like', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=43718992, end_position_on_the_genomic_accession=43758790, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    83449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83449, CurrentID=0, Status='live', Symbol='PMFBP1', Aliases=['SPGF31', 'STAP'], description='polyamine modulated factor 1 binding protein 1', other_designations='polyamine-modulated factor 1-binding protein 1|PMF-1 binding protein', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=72116697, end_position_on_the_genomic_accession=72173908, orientation='minus', exon_count=27, OMIM=[618085], no_hdr0=''),
    83450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83450, CurrentID=0, Status='live', Symbol='DRC3', Aliases=['CFAP134', 'LRRC48'], description='dynein regulatory complex subunit 3', other_designations='dynein regulatory complex subunit 3|leucine rich repeat containing 48|leucine-rich repeat-containing protein 48', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17972766, end_position_on_the_genomic_accession=18016889, orientation='plus', exon_count=20, OMIM=[618758], no_hdr0=''),
    83451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83451, CurrentID=0, Status='live', Symbol='ABHD11', Aliases=['PP1226', 'WBSCR21'], description='abhydrolase domain containing 11', other_designations='protein ABHD11|Williams Beuren syndrome chromosome region 21|abhydrolase domain-containing protein 11|alpha/beta hydrolase domain-containing protein 11', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73736094, end_position_on_the_genomic_accession=73738866, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    83452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83452, CurrentID=0, Status='live', Symbol='RAB33B', Aliases=['SMC2'], description='RAB33B, member RAS oncogene family', other_designations='ras-related protein Rab-33B', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139453232, end_position_on_the_genomic_accession=139476609, orientation='plus', exon_count=3, OMIM=[605950], no_hdr0=''),
    83460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83460, CurrentID=0, Status='live', Symbol='EMC6', Aliases=['RAB5IFL', 'TMEM93'], description='ER membrane protein complex subunit 6', other_designations='ER membrane protein complex subunit 6|transmembrane protein 93', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3668812, end_position_on_the_genomic_accession=3669665, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    83461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83461, CurrentID=0, Status='live', Symbol='CDCA3', Aliases=['GRCC8', 'TOME-1'], description='cell division cycle associated 3', other_designations='cell division cycle-associated protein 3|gene-rich cluster protein C8|trigger of mitotic entry protein 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6844795, end_position_on_the_genomic_accession=6852079, orientation='minus', exon_count=8, OMIM=[607749], no_hdr0=''),
    83463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83463, CurrentID=0, Status='live', Symbol='MXD3', Aliases=['BHLHC13', 'MAD3', 'MYX'], description='MAX dimerization protein 3', other_designations='max dimerization protein 3|Max-associated protein 3|Max-interacting transcriptional repressor MAD3|class C basic helix-loop-helix protein 13|max dimerizer 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177305499, end_position_on_the_genomic_accession=177312752, orientation='minus', exon_count=8, OMIM=[609450], no_hdr0=''),
    83464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83464, CurrentID=0, Status='live', Symbol='APH1B', Aliases=['APH-1B', 'PRO1328', 'PSFL', 'TAAV688'], description='aph-1 homolog B, gamma-secretase subunit', other_designations='gamma-secretase subunit APH-1B|APH1B gamma secretase subunit|anterior pharynx defective 1 homolog B|aph-1beta', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63277550, end_position_on_the_genomic_accession=63309126, orientation='plus', exon_count=9, OMIM=[607630], no_hdr0=''),
    83468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83468, CurrentID=0, Status='live', Symbol='GLT8D2', Aliases=[], description='glycosyltransferase 8 domain containing 2', other_designations='glycosyltransferase 8 domain-containing protein 2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103988987, end_position_on_the_genomic_accession=104064437, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    83473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83473, CurrentID=0, Status='live', Symbol='KATNAL2', Aliases=[], description='katanin catalytic subunit A1 like 2', other_designations='katanin p60 ATPase-containing subunit A-like 2|katanin catalytic subunit A like 2|katanin p60 subunit A like 2|p60 katanin-like 2', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46917550, end_position_on_the_genomic_accession=47104795, orientation='plus', exon_count=21, OMIM=[614697], no_hdr0=''),
    83475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83475, CurrentID=0, Status='live', Symbol='DOHH', Aliases=['HLRC1', 'hDOHH'], description='deoxyhypusine hydroxylase', other_designations='deoxyhypusine hydroxylase|HEAT-like (PBS lyase) repeat containing 1|HEAT-like repeat-containing protein 1|deoxyhypusine dioxygenase|deoxyhypusine hydroxylase/monooxygenase|deoxyhypusine monooxygenase', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3490824, end_position_on_the_genomic_accession=3500674, orientation='minus', exon_count=6, OMIM=[611262], no_hdr0=''),
    83478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83478, CurrentID=0, Status='live', Symbol='ARHGAP24', Aliases=['FILGAP', 'RC-GAP72', 'RCGAP72', 'p73', 'p73RhoGAP'], description='Rho GTPase activating protein 24', other_designations='rho GTPase-activating protein 24|RAC1- and CDC42-specific GTPase-activating protein of 72 kDa|filamin-A-associated RhoGAP|rhoGAP of 73 kDa|sarcoma antigen NY-SAR-88', map_location='4q21.23-q21.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=85475150, end_position_on_the_genomic_accession=86002666, orientation='plus', exon_count=15, OMIM=[610586], no_hdr0=''),
    83479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83479, CurrentID=0, Status='live', Symbol='DDX59', Aliases=['OFD5', 'ZNHIT5'], description='DEAD-box helicase 59', other_designations='probable ATP-dependent RNA helicase DDX59|DEAD (Asp-Glu-Ala-Asp) box polypeptide 59|DEAD box protein 59|zinc finger HIT domain-containing protein 5', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=200640805, end_position_on_the_genomic_accession=200669969, orientation='minus', exon_count=13, OMIM=[615464], no_hdr0=''),
    83480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83480, CurrentID=0, Status='live', Symbol='PUS3', Aliases=['2610020J05Rik', 'FKSG32', 'MRT55', 'NEDMIGS'], description='pseudouridine synthase 3', other_designations='tRNA pseudouridine(38/39) synthase|pseudouridylate synthase 3|tRNA pseudouridine synthase 3|tRNA pseudouridylate synthase 3|tRNA-uridine isomerase 3', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125893485, end_position_on_the_genomic_accession=125903219, orientation='minus', exon_count=4, OMIM=[616283], no_hdr0=''),
    83481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83481, CurrentID=0, Status='live', Symbol='EPPK1', Aliases=['EPIPL', 'EPIPL1'], description='epiplakin 1', other_designations='epiplakin|450 kDa epidermal antigen|epidermal autoantigen 450K', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143857319, end_position_on_the_genomic_accession=143879043, orientation='minus', exon_count=3, OMIM=[607553], no_hdr0=''),
    83482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83482, CurrentID=0, Status='live', Symbol='SCRT1', Aliases=['SCRT', 'ZNF898'], description='scratch family transcriptional repressor 1', other_designations='transcriptional repressor scratch 1|scratch family zinc finger 1|scratch homolog 1, zinc finger protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144330565, end_position_on_the_genomic_accession=144336482, orientation='minus', exon_count=3, OMIM=[605858], no_hdr0=''),
    83483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83483, CurrentID=0, Status='live', Symbol='PLVAP', Aliases=['DIAR10', 'FELS', 'PV-1', 'PV1', 'gp68'], description='plasmalemma vesicle associated protein', other_designations='plasmalemma vesicle-associated protein|fenestrated endothelial-linked structure protein|fenestrated-endothelial linked structure protein; PV-1 protein|plasmalemma vesicle protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17351455, end_position_on_the_genomic_accession=17377342, orientation='minus', exon_count=6, OMIM=[607647], no_hdr0=''),
    83538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83538, CurrentID=0, Status='live', Symbol='ODAD4', Aliases=['TTC25'], description='outer dynein arm docking complex subunit 4', other_designations='outer dynein arm-docking complex subunit 4|TPR repeat protein 25|tetratricopeptide repeat domain 25|tetratricopeptide repeat protein 25', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41930617, end_position_on_the_genomic_accession=41966503, orientation='plus', exon_count=13, OMIM=[617095], no_hdr0=''),
    83539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83539, CurrentID=0, Status='live', Symbol='CHST9', Aliases=['GALNAC4ST-2', 'GalNAc4ST2'], description='carbohydrate sulfotransferase 9', other_designations='carbohydrate sulfotransferase 9|GalNAc-4-sulfotransferase 2|N-acetylgalactosamine 4-O-sulfotransferase 2|carbohydrate (N-acetylgalactosamine 4-0) sulfotransferase 9|galNAc-4-O-sulfotransferase 2', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26906481, end_position_on_the_genomic_accession=27185364, orientation='minus', exon_count=9, OMIM=[610191], no_hdr0=''),
    83540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83540, CurrentID=0, Status='live', Symbol='NUF2', Aliases=['CDCA1', 'CT106R', 'NUF2'], description='NUF2 component of NDC80 kinetochore complex', other_designations='kinetochore protein Nuf2|NDC80 kinetochore complex component NUF2|NUF2, NDC80 kinetochore complex component, homolog|cancer/testis antigen 106|cell division cycle associated 1|cell division cycle-associated protein 1|hNuf2|hNuf2R|hsNuf2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=163321948, end_position_on_the_genomic_accession=163355764, orientation='plus', exon_count=15, OMIM=[611772], no_hdr0=''),
    83541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83541, CurrentID=0, Status='live', Symbol='FAM110A', Aliases=['C20orf55', 'F10', 'bA371L19.3'], description='family with sequence similarity 110 member A', other_designations='protein FAM110A', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=833715, end_position_on_the_genomic_accession=846279, orientation='plus', exon_count=6, OMIM=[611393], no_hdr0=''),
    83543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83543, CurrentID=0, Status='live', Symbol='AIF1L', Aliases=['C9orf58', 'IBA2'], description='allograft inflammatory factor 1 like', other_designations='allograft inflammatory factor 1-like|ionized calcium binding adapter molecule 2', map_location='9q34.12-q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131096531, end_position_on_the_genomic_accession=131123144, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    83544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83544, CurrentID=0, Status='live', Symbol='DNAL1', Aliases=['C14orf168', 'CILD16', 'LC1'], description='dynein axonemal light chain 1', other_designations='dynein axonemal light chain 1|dynein light chain 1, axonemal', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73644986, end_position_on_the_genomic_accession=73703732, orientation='plus', exon_count=10, OMIM=[610062], no_hdr0=''),
    83546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83546, CurrentID=0, Status='live', Symbol='RTBDN', Aliases=[], description='retbindin', other_designations='retbindin', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12825482, end_position_on_the_genomic_accession=12835428, orientation='minus', exon_count=10, OMIM=[609553], no_hdr0=''),
    83547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83547, CurrentID=0, Status='live', Symbol='RILP', Aliases=['PP10141'], description='Rab interacting lysosomal protein', other_designations='rab-interacting lysosomal protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1646150, end_position_on_the_genomic_accession=1650077, orientation='minus', exon_count=8, OMIM=[607848], no_hdr0=''),
    83548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83548, CurrentID=0, Status='live', Symbol='COG3', Aliases=['SEC34'], description='component of oligomeric golgi complex 3', other_designations='conserved oligomeric Golgi complex subunit 3|COG complex subunit 3|p94|tethering factor SEC34|vesicle-docking protein SEC34 homolog', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45464916, end_position_on_the_genomic_accession=45536701, orientation='plus', exon_count=24, OMIM=[606975], no_hdr0=''),
    83549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83549, CurrentID=0, Status='live', Symbol='UCK1', Aliases=['URK1'], description='uridine-cytidine kinase 1', other_designations='uridine-cytidine kinase 1|cytidine monophosphokinase 1|uridine monophosphokinase 1', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131523801, end_position_on_the_genomic_accession=131531263, orientation='minus', exon_count=8, OMIM=[609328], no_hdr0=''),
    83550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83550, CurrentID=0, Status='live', Symbol='GPR101', Aliases=['GPCR6', 'PAGH2', 'PITA2'], description='G protein-coupled receptor 101', other_designations='probable G-protein coupled receptor 101', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=137023929, end_position_on_the_genomic_accession=137033995, orientation='minus', exon_count=2, OMIM=[300393], no_hdr0=''),
    83551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83551, CurrentID=0, Status='live', Symbol='TAAR8', Aliases=['GPR102', 'TA5', 'TAR5', 'TRAR5', 'TaR-5', 'TaR-8'], description='trace amine associated receptor 8', other_designations='trace amine-associated receptor 8|G-protein coupled receptor 102|trace amine receptor 5|trace amine receptor 8', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132552684, end_position_on_the_genomic_accession=132553731, orientation='plus', exon_count=1, OMIM=[606927], no_hdr0=''),
    83552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83552, CurrentID=0, Status='live', Symbol='MFRP', Aliases=['CTRP5', 'MCOP5', 'NNO2', 'RD6'], description='membrane frizzled-related protein', other_designations='membrane frizzled-related protein|C1q and TNF related 5|membrane-type frizzled-related protein', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119338942, end_position_on_the_genomic_accession=119346705, orientation='minus', exon_count=15, OMIM=[606227], no_hdr0=''),
    83590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83590, CurrentID=0, Status='live', Symbol='TMUB1', Aliases=['C7orf21', 'DULP', 'HOPS', 'SB144'], description='transmembrane and ubiquitin like domain containing 1', other_designations='transmembrane and ubiquitin-like domain-containing protein 1|dendritic cell-derived ubiquitin-like protein|hepatocyte odd protein shuttling protein|ubiquitin-like protein DULP|ubiquitin-like protein SB144', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151081085, end_position_on_the_genomic_accession=151083493, orientation='minus', exon_count=4, OMIM=[614792], no_hdr0=''),
    83591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83591, CurrentID=0, Status='live', Symbol='THAP2', Aliases=[], description='THAP domain containing 2', other_designations='THAP domain-containing protein 2|THAP domain containing, apoptosis associated protein 2', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71664301, end_position_on_the_genomic_accession=71680644, orientation='plus', exon_count=3, OMIM=[612531], no_hdr0=''),
    83592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83592, CurrentID=0, Status='live', Symbol='AKR1E2', Aliases=['AKR1CL2', 'AKRDC1', 'HTSP1', 'LoopADR', 'TAKR', 'hTSP', 'htAKR'], description='aldo-keto reductase family 1 member E2', other_designations='1,5-anhydro-D-fructose reductase|AF reductase|aldo-keto reductase family 1 member C-like protein 2|aldo-keto reductase family 1, member C-like 2|aldo-keto reductase loopADR|human testis aldo-keto reductase|human testis specific protein|testis aldo-keto reductase|testis-specific protein', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=4824554, end_position_on_the_genomic_accession=4908421, orientation='plus', exon_count=17, OMIM=[617451], no_hdr0=''),
    83593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83593, CurrentID=0, Status='live', Symbol='RASSF5', Aliases=['Maxp1', 'NORE1', 'NORE1A', 'NORE1B', 'RAPL', 'RASSF3'], description='Ras association domain family member 5', other_designations='ras association domain-containing protein 5|Rap1-binding protein|Ras association (RalGDS/AF-6) domain family 5|Ras association (RalGDS/AF-6) domain family member 5|Ras effector-like protein|new ras effector 1|novel Ras effector 1|regulator for cell adhesion and polarization enriched in lymphoid tissue|tumor suppressor RASSF3', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206507531, end_position_on_the_genomic_accession=206589448, orientation='plus', exon_count=7, OMIM=[607020], no_hdr0=''),
    83594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83594, CurrentID=0, Status='live', Symbol='NUDT12', Aliases=[], description='nudix hydrolase 12', other_designations='NAD-capped RNA hydrolase NUDT12|NADH pyrophosphatase NUDT12|deNADding enzyme NUDT12|nucleoside diphosphate linked moiety X-type motif 12|nucleoside diphosphate-linked moiety X motif 12|nudix (nucleoside diphosphate linked moiety X)-type motif 12|nudix motif 12|peroxisomal NADH pyrophosphatase NUDT12', map_location='5q21.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=103548855, end_position_on_the_genomic_accession=103562805, orientation='minus', exon_count=7, OMIM=[609232], no_hdr0=''),
    83595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83595, CurrentID=0, Status='live', Symbol='SOX7', Aliases=[], description='SRY-box transcription factor 7', other_designations='transcription factor SOX-7|SRY (sex determining region Y)-box 7|SRY-box 7', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10723768, end_position_on_the_genomic_accession=10730511, orientation='minus', exon_count=2, OMIM=[612202], no_hdr0=''),
    83596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83596, CurrentID=0, Status='live', Symbol='BCL2L12', Aliases=[], description='BCL2 like 12', other_designations='bcl-2-like protein 12|BCL2-like 12 (proline rich)|Bcl-2 related proline-rich protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49664834, end_position_on_the_genomic_accession=49673916, orientation='plus', exon_count=7, OMIM=[610837], no_hdr0=''),
    83597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83597, CurrentID=0, Status='live', Symbol='RTP3', Aliases=['LTM1', 'TMEM7', 'Z3CXXC3'], description='receptor transporter protein 3', other_designations='receptor-transporting protein 3|3CxxC-type zinc finger protein 3|receptor (chemosensory) transporter protein 3|transmembrane protein 7|zinc finger, 3CxxC-type 3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46497976, end_position_on_the_genomic_accession=46500950, orientation='plus', exon_count=2, OMIM=[607181], no_hdr0=''),
    83604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83604, CurrentID=0, Status='live', Symbol='TMEM47', Aliases=['BCMP1', 'TM4SF10', 'VAB-9'], description='transmembrane protein 47', other_designations='transmembrane protein 47|brain cell membrane protein 1|transmembrane 4 superfamily member 10', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=34627075, end_position_on_the_genomic_accession=34657285, orientation='minus', exon_count=3, OMIM=[300698], no_hdr0=''),
    83605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83605, CurrentID=0, Status='live', Symbol='CCM2', Aliases=['C7orf22', 'OSM', 'PP10187'], description='CCM2 scaffold protein', other_designations='cerebral cavernous malformations 2 protein|CCM2 scaffolding protein|cerebral cavernous malformation 2|malcavernin|osmosensing scaffold for MEKK3', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44999746, end_position_on_the_genomic_accession=45076470, orientation='plus', exon_count=14, OMIM=[607929], no_hdr0=''),
    83606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83606, CurrentID=0, Status='live', Symbol='GUCD1', Aliases=['C22orf13', 'LLN4'], description='guanylyl cyclase domain containing 1', other_designations='protein GUCD1|CG13760 gene product [Drosophila melanogaster] homolog|guanylyl cyclase domain-containing protein 1', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24540438, end_position_on_the_genomic_accession=24555929, orientation='minus', exon_count=7, OMIM=[619171], no_hdr0=''),
    83607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83607, CurrentID=0, Status='live', Symbol='AMMECR1L', Aliases=[], description='AMMECR1 like', other_designations='AMMECR1-like protein|AMME chromosomal region gene 1-like', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127861630, end_position_on_the_genomic_accession=127887575, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    83608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83608, CurrentID=0, Status='live', Symbol='C18orf21', Aliases=['HsT3108', 'PNAS-124', 'PNAS-131', 'XTP13'], description='chromosome 18 open reading frame 21', other_designations='UPF0711 protein C18orf21|HBV X-transactivated gene 13 protein|HBV X-transactivated protein 13|HBV XAg-transactivated protein 13', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35971878, end_position_on_the_genomic_accession=35979287, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    83636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83636, CurrentID=0, Status='live', Symbol='C19orf12', Aliases=['MPAN', 'NBIA3', 'NBIA4', 'SPG43'], description='chromosome 19 open reading frame 12', other_designations='protein C19orf12|membrane protein-associated neurodegeneration|neurodegeneration with brain iron accumulation 3', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29698886, end_position_on_the_genomic_accession=29715789, orientation='minus', exon_count=9, OMIM=[614297], no_hdr0=''),
    83637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83637, CurrentID=0, Status='live', Symbol='ZMIZ2', Aliases=['NET27', 'TRAFIP20', 'ZIMP7', 'hZIMP7'], description='zinc finger MIZ-type containing 2', other_designations='zinc finger MIZ domain-containing protein 2|PIAS-like protein Zimp7', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44748547, end_position_on_the_genomic_accession=44769881, orientation='plus', exon_count=24, OMIM=[611196], no_hdr0=''),
    83638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83638, CurrentID=0, Status='live', Symbol='C11orf68', Aliases=['BLES03', 'P5326'], description='chromosome 11 open reading frame 68', other_designations='UPF0696 protein C11orf68|basophilic leukemia expressed protein BLES03|basophilic leukemia-expressed protein Bles03|protein p5326', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65916810, end_position_on_the_genomic_accession=65919062, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    83639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83639, CurrentID=0, Status='live', Symbol='TEX101', Aliases=['CT131', 'GTPR867', 'NYD-SP8', 'PRO1884', 'SGRG', 'SPATA44', 'TES101RP'], description='testis expressed 101', other_designations='testis-expressed protein 101|TES101-reactive protein|cancer/testis antigen 131|cell surface receptor NYD-SP8|scleroderma-associated autoantigen|spermatogenesis associated 44|spermatogenesis-related gene protein|testis expressed sequence 101|testis-expressed sequence 101 protein|testis-specific protein TES101RP', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43388611, end_position_on_the_genomic_accession=43418613, orientation='plus', exon_count=10, OMIM=[612665], no_hdr0=''),
    83640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83640, CurrentID=0, Status='live', Symbol='RAMAC', Aliases=['C15orf18', 'FAM103A1', 'HsT19360', 'RAM', 'RAMMET'], description='RNA guanine-7 methyltransferase activating subunit', other_designations='RNA guanine-N7 methyltransferase activating subunit|RNMT activating mRNA cap methyltransferase subunit|RNMT-activating mini protein|family with sequence similarity 103 member A1|protein FAM103A1', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82986210, end_position_on_the_genomic_accession=82991057, orientation='plus', exon_count=4, OMIM=[614547], no_hdr0=''),
    83641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83641, CurrentID=0, Status='live', Symbol='FAM107B', Aliases=['C10orf45', 'HITS'], description='family with sequence similarity 107 member B', other_designations='protein FAM107B|FAM107B/CDNF fusion|heat shock-inducible tumor small protein', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14518557, end_position_on_the_genomic_accession=14774897, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    83642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83642, CurrentID=0, Status='live', Symbol='SELENOO', Aliases=['SELO'], description='selenoprotein O', other_designations='protein adenylyltransferase SelO, mitochondrial', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50201011, end_position_on_the_genomic_accession=50217616, orientation='plus', exon_count=9, OMIM=[607917], no_hdr0=''),
    83643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83643, CurrentID=0, Status='live', Symbol='CCDC3', Aliases=[], description='coiled-coil domain containing 3', other_designations='coiled-coil domain-containing protein 3|fat/vessel-derived secretory protein|favine', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=12896625, end_position_on_the_genomic_accession=13099989, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    83648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83648, CurrentID=0, Status='live', Symbol='FAM167A', Aliases=['C8orf13', 'D8S265', 'DIORA-1'], description='family with sequence similarity 167 member A', other_designations='protein FAM167A|disordered autoimmunity 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11421465, end_position_on_the_genomic_accession=11475909, orientation='minus', exon_count=9, OMIM=[610085], no_hdr0=''),
    83650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83650, CurrentID=0, Status='live', Symbol='SLC35G5', Aliases=['AMAC', 'AMAC1L2'], description='solute carrier family 35 member G5', other_designations='solute carrier family 35 member G5|acyl-malonyl condensing enzyme 1-like 2|acyl-malonyl-condensing enzyme 1-like protein 2|protein AMAC1L2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11331012, end_position_on_the_genomic_accession=11332360, orientation='plus', exon_count=1, OMIM=[615199], no_hdr0=''),
    83657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83657, CurrentID=0, Status='live', Symbol='DYNLRB2', Aliases=['DNCL2B', 'DNLC2B', 'ROBLD2'], description='dynein light chain roadblock-type 2', other_designations='dynein light chain roadblock-type 2|bithoraxoid-like protein|dynein light chain 2B, cytoplasmic|dynein, cytoplasmic, light polypeptide 2B|roadblock domain-containing protein 2|testicular tissue protein Li 53', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=80540259, end_position_on_the_genomic_accession=80550811, orientation='plus', exon_count=8, OMIM=[607168], no_hdr0=''),
    83658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83658, CurrentID=0, Status='live', Symbol='DYNLRB1', Aliases=['BITH', 'BLP', 'DNCL2A', 'DNLC2A', 'ROBLD1'], description='dynein light chain roadblock-type 1', other_designations='dynein light chain roadblock-type 1|ROBL/LC7-like 1|bithoraxoid-like protein|dynein, cytoplasmic, light polypeptide 2A|dynein-associated protein Km23|roadblock domain-containing protein 1', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34515602, end_position_on_the_genomic_accession=34540958, orientation='plus', exon_count=9, OMIM=[607167], no_hdr0=''),
    83659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83659, CurrentID=0, Status='live', Symbol='TEKT1', Aliases=[], description='tektin 1', other_designations='tektin-1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6797993, end_position_on_the_genomic_accession=6831734, orientation='minus', exon_count=8, OMIM=[609002], no_hdr0=''),
    83660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83660, CurrentID=0, Status='live', Symbol='TLN2', Aliases=['ILWEQ'], description='talin 2', other_designations='talin-2', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=62390523, end_position_on_the_genomic_accession=62844631, orientation='plus', exon_count=68, OMIM=[607349], no_hdr0=''),
    83661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83661, CurrentID=0, Status='live', Symbol='MS4A8', Aliases=['4SPAN4', 'CD20L5', 'MS4A4B', 'MS4A8'], description='membrane spanning 4-domains A8', other_designations='membrane-spanning 4-domains subfamily A member 8|four-span transmembrane protein 4|membrane-spanning 4-domains, subfamily A, member 8B', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60699612, end_position_on_the_genomic_accession=60715807, orientation='plus', exon_count=7, OMIM=[606549], no_hdr0=''),
    83666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83666, CurrentID=0, Status='live', Symbol='PARP9', Aliases=['ARTD9', 'BAL', 'BAL1', 'MGC:7868'], description='poly(ADP-ribose) polymerase family member 9', other_designations='protein mono-ADP-ribosyltransferase PARP9|ADP-ribosyltransferase diphtheria toxin-like 9|PARP-9|b aggressive lymphoma protein|poly (ADP-ribose) polymerase 9|poly [ADP-ribose] polymerase 9', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122527924, end_position_on_the_genomic_accession=122564784, orientation='minus', exon_count=13, OMIM=[612065], no_hdr0=''),
    83667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83667, CurrentID=0, Status='live', Symbol='SESN2', Aliases=['HI95', 'SES2', 'SEST2'], description='sestrin 2', other_designations='sestrin-2|hypoxia induced gene 95|hypoxia-induced', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28259452, end_position_on_the_genomic_accession=28282491, orientation='plus', exon_count=10, OMIM=[607767], no_hdr0=''),
    83690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83690, CurrentID=0, Status='live', Symbol='CRISPLD1', Aliases=['CRISP-10', 'CRISP10', 'LCRISP1'], description='cysteine rich secretory protein LCCL domain containing 1', other_designations='cysteine-rich secretory protein LCCL domain-containing 1|CocoaCrisp|LCCL domain-containing cysteine-rich secretory protein 1|cysteine-rich secretory protein 10|trypsin inhibitor Hl', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=74984505, end_position_on_the_genomic_accession=75034558, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    83692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83692, CurrentID=0, Status='live', Symbol='CD99L2', Aliases=['CD99B', 'MIC2L1'], description='CD99 molecule like 2', other_designations='CD99 antigen-like protein 2|MIC2 like 1|MIC2-like protein 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=150766336, end_position_on_the_genomic_accession=150898717, orientation='minus', exon_count=13, OMIM=[300846], no_hdr0=''),
    83693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83693, CurrentID=0, Status='live', Symbol='HSDL1', Aliases=['SDR12C3'], description='hydroxysteroid dehydrogenase like 1', other_designations='inactive hydroxysteroid dehydrogenase-like protein 1|short chain dehydrogenase/reductase family 12C member 3|steroid dehydrogenase-like protein', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84122141, end_position_on_the_genomic_accession=84145177, orientation='minus', exon_count=7, OMIM=[619067], no_hdr0=''),
    83694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83694, CurrentID=0, Status='live', Symbol='RPS6KL1', Aliases=['RSKL2'], description='ribosomal protein S6 kinase like 1', other_designations='ribosomal protein S6 kinase-like 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74903951, end_position_on_the_genomic_accession=74923282, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    83695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83695, CurrentID=0, Status='live', Symbol='RHNO1', Aliases=['C12orf32', 'HKMT1188', 'RHINO'], description='RAD9-HUS1-RAD1 interacting nuclear orphan 1', other_designations='RAD9, HUS1, RAD1-interacting nuclear orphan protein 1|Rad9, Rad1, Hus1 interacting nuclear orphan|rAD9, RAD1, HUS1-interacting nuclear orphan protein', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2876265, end_position_on_the_genomic_accession=2889524, orientation='plus', exon_count=5, OMIM=[614085], no_hdr0=''),
    83696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83696, CurrentID=0, Status='live', Symbol='TRAPPC9', Aliases=['IBP', 'IKBKBBP', 'MRT13', 'NIBP', 'T1', 'TRS120'], description='trafficking protein particle complex subunit 9', other_designations='trafficking protein particle complex subunit 9|IKK2 binding protein|NIK and IKK-beta binding protein|NIK- and IKBKB-binding protein|TRAPP 120 kDa subunit|trafficking protein particle complex 9|tularik gene 1 protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=139727725, end_position_on_the_genomic_accession=140458579, orientation='minus', exon_count=31, OMIM=[611966], no_hdr0=''),
    83697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83697, CurrentID=0, Status='live', Symbol='SLC4A9', Aliases=['AE4'], description='solute carrier family 4 member 9', other_designations='anion exchange protein 4|anion exchanger 4|sodium bicarbonate cotransporter 5|solute carrier family 4, sodium bicarbonate cotransporter, member 9', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140359645, end_position_on_the_genomic_accession=140375177, orientation='plus', exon_count=23, OMIM=[610207], no_hdr0=''),
    83698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83698, CurrentID=0, Status='live', Symbol='CALN1', Aliases=['CABP8'], description='calneuron 1', other_designations='calcium-binding protein 8|calcium-binding protein CABP8|calneuron I', map_location='7q11.22', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=71779491, end_position_on_the_genomic_accession=72504271, orientation='minus', exon_count=17, OMIM=[607176], no_hdr0=''),
    83699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83699, CurrentID=0, Status='live', Symbol='SH3BGRL2', Aliases=[], description='SH3 domain binding glutamate rich protein like 2', other_designations='SH3 domain-binding glutamic acid-rich-like protein 2|SH3 domain binding glutamic acid-rich protein like 2|fovea-associated SH3 domain-binding protein', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=79537633, end_position_on_the_genomic_accession=79703659, orientation='plus', exon_count=7, OMIM=[615678], no_hdr0=''),
    83700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83700, CurrentID=0, Status='live', Symbol='JAM3', Aliases=['JAM-2', 'JAM-3', 'JAM-C', 'JAMC'], description='junctional adhesion molecule 3', other_designations='junctional adhesion molecule C', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134069072, end_position_on_the_genomic_accession=134152001, orientation='plus', exon_count=9, OMIM=[606871], no_hdr0=''),
    83706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83706, CurrentID=0, Status='live', Symbol='FERMT3', Aliases=['KIND3', 'MIG-2', 'MIG2B', 'UNC112C', 'URP2', 'URP2SF'], description='FERM domain containing kindlin 3', other_designations='fermitin family homolog 3|MIG2-like protein|UNC-112 related protein 2|fermitin family member 3|kindlin 3|unc-112-related protein 2', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64205920, end_position_on_the_genomic_accession=64223891, orientation='plus', exon_count=18, OMIM=[607901], no_hdr0=''),
    83707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83707, CurrentID=0, Status='live', Symbol='TRPT1', Aliases=[], description='tRNA phosphotransferase 1', other_designations="tRNA 2'-phosphotransferase 1|tRNA splicing 2' phosphotransferase 1", map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64223799, end_position_on_the_genomic_accession=64226224, orientation='minus', exon_count=9, OMIM=[610470], no_hdr0=''),
    83714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83714, CurrentID=0, Status='live', Symbol='NRIP2', Aliases=[], description='nuclear receptor interacting protein 2', other_designations='nuclear receptor-interacting protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2825348, end_position_on_the_genomic_accession=2835536, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    83715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83715, CurrentID=0, Status='live', Symbol='ESPN', Aliases=['DFNB36', 'LP2654', 'USH1M'], description='espin', other_designations='espin|autosomal recessive deafness type 36 protein|ectoplasmic specialization protein', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6424776, end_position_on_the_genomic_accession=6461367, orientation='plus', exon_count=21, OMIM=[606351], no_hdr0=''),
    83716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83716, CurrentID=0, Status='live', Symbol='CRISPLD2', Aliases=['CRISP11', 'LCRISP2', 'LGL1'], description='cysteine rich secretory protein LCCL domain containing 2', other_designations='cysteine-rich secretory protein LCCL domain-containing 2|CRISP-11|LCCL domain-containing cysteine-rich secretory protein 2|cysteine-rich secretory protein 11|late gestation lung 1|testis secretory sperm-binding protein Li 207a|trypsin inhibitor', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84819981, end_position_on_the_genomic_accession=84909510, orientation='plus', exon_count=16, OMIM=[612434], no_hdr0=''),
    83719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83719, CurrentID=0, Status='live', Symbol='YPEL3', Aliases=[], description='yippee like 3', other_designations='protein yippee-like 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30092314, end_position_on_the_genomic_accession=30096213, orientation='minus', exon_count=6, OMIM=[609724], no_hdr0=''),
    83723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83723, CurrentID=0, Status='live', Symbol='TLCD3B', Aliases=['FAM57B', 'FP1188'], description='TLC domain containing 3B', other_designations='ceramide synthase|TLC domain 3B|TLC domain ceramide synthase 3B|TLC domain-containing protein 3B|epididymis secretory sperm binding protein|family with sequence similarity 57 member B|protein FAM57B', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30024426, end_position_on_the_genomic_accession=30053026, orientation='minus', exon_count=13, OMIM=[615175], no_hdr0=''),
    83729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83729, CurrentID=0, Status='live', Symbol='INHBE', Aliases=[], description='inhibin subunit beta E', other_designations='inhibin beta E chain|activin beta-E chain|inhibin beta E subunit', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57455307, end_position_on_the_genomic_accession=57458025, orientation='plus', exon_count=2, OMIM=[612031], no_hdr0=''),
    83732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83732, CurrentID=0, Status='live', Symbol='RIOK1', Aliases=['AD034', 'RIO1', 'RRP10', 'bA288G3.1'], description='RIO kinase 1', other_designations='serine/threonine-protein kinase RIO1', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7389808, end_position_on_the_genomic_accession=7418037, orientation='plus', exon_count=18, OMIM=[617753], no_hdr0=''),
    83733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83733, CurrentID=0, Status='live', Symbol='SLC25A18', Aliases=['GC2'], description='solute carrier family 25 member 18', other_designations='mitochondrial glutamate carrier 2|glutamate/H(+) symporter 2|solute carrier family 25 (glutamate carrier), member 18|solute carrier family 25 (mitochondrial carrier), member 18', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=17562470, end_position_on_the_genomic_accession=17592256, orientation='plus', exon_count=13, OMIM=[609303], no_hdr0=''),
    83734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83734, CurrentID=0, Status='live', Symbol='ATG10', Aliases=['APG10', 'APG10L', 'pp12616'], description='autophagy related 10', other_designations='ubiquitin-like-conjugating enzyme ATG10|APG10 autophagy 10-like|ATG10 autophagy related 10 homolog|autophagy-related protein 10', map_location='5q14.1-q14.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=81972021, end_position_on_the_genomic_accession=82258502, orientation='plus', exon_count=13, OMIM=[610800], no_hdr0=''),
    83737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83737, CurrentID=0, Status='live', Symbol='ITCH', Aliases=['ADMFD', 'AIF4', 'AIP4', 'NAPP1'], description='itchy E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase Itchy homolog|HECT-type E3 ubiquitin transferase Itchy homolog|NFE2-associated polypeptide 1|atrophin-1 interacting protein 4|itchy E3 ubiquitin protein ligase homolog', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34363273, end_position_on_the_genomic_accession=34511773, orientation='plus', exon_count=31, OMIM=[606409], no_hdr0=''),
    83740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83740, CurrentID=0, Status='live', Symbol='H2AB3', Aliases=['H2AB2', 'H2ABBD', 'H2AFB', 'H2AFB3'], description='H2A.B variant histone 3', other_designations='histone H2A-Bbd type 2/3|H2A Barr body-deficient|H2A histone family member B3|H2A.Bbd|histone variant H2A, Barr-body deficient', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155459415, end_position_on_the_genomic_accession=155460005, orientation='minus', exon_count=1, OMIM=[300445], no_hdr0=''),
    83741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83741, CurrentID=0, Status='live', Symbol='TFAP2D', Aliases=['AP-2delta', 'TFAP2BL1'], description='transcription factor AP-2 delta', other_designations='transcription factor AP-2-delta|AP-2 like|AP2-delta|activating enhancer binding protein 2 beta-like 1|activating enhancer-binding protein 2-delta|transcription factor AP-2 beta (activating enhancer-binding protein 2 beta)-like 1|transcription factor AP-2 delta (activating enhancer binding protein 2 delta)|transcription factor AP-2-beta-like 1', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=50713526, end_position_on_the_genomic_accession=50773033, orientation='plus', exon_count=8, OMIM=[610161], no_hdr0=''),
    83742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83742, CurrentID=0, Status='live', Symbol='MARVELD1', Aliases=['GB14', 'MARVD1', 'MRVLDC1', 'bA548K23.8'], description='MARVEL domain containing 1', other_designations='MARVEL domain-containing protein 1|MARVEL (membrane-associating) domain containing 1|occludin|putative MARVEL domain-containing protein 1', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97713730, end_position_on_the_genomic_accession=97718150, orientation='plus', exon_count=2, OMIM=[616970], no_hdr0=''),
    83743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83743, CurrentID=0, Status='live', Symbol='GRWD1', Aliases=['CDW4', 'GRWD', 'RRB1', 'WDR28'], description='glutamate rich WD repeat containing 1', other_designations='glutamate-rich WD repeat-containing protein 1|CUL4- and DDB1-associated WDR protein 4|WD repeat domain 28|glutamate rich WD repeat protein GRWD|regulator of ribosome biogenesis 1 homolog', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48445983, end_position_on_the_genomic_accession=48457022, orientation='plus', exon_count=7, OMIM=[610597], no_hdr0=''),
    83744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83744, CurrentID=0, Status='live', Symbol='ZNF484', Aliases=['BA526D8.4'], description='zinc finger protein 484', other_designations='zinc finger protein 484|KRAB box containing C2H2 type zinc finger bA526D8.4', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92844182, end_position_on_the_genomic_accession=92878060, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    83746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83746, CurrentID=0, Status='live', Symbol='L3MBTL2', Aliases=['H-l(3)mbt-l', 'L3MBT'], description='L3MBTL histone methyl-lysine binding protein 2', other_designations='lethal(3)malignant brain tumor-like protein 2|H-l(3)mbt-like protein 2|L(3)mbt-like protein 2|L3MBTL2, polycomb repressive complex 1 subunit|l(3)mbt-like 2', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41205192, end_position_on_the_genomic_accession=41231271, orientation='plus', exon_count=18, OMIM=[611865], no_hdr0=''),
    83752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83752, CurrentID=0, Status='live', Symbol='LONP2', Aliases=['LONP', 'LONPL', 'PLON', 'PSLON'], description='lon peptidase 2, peroxisomal', other_designations='lon protease homolog 2, peroxisomal|lon protease 2|lon protease-like protein 2|peroxisomal LON protease like|peroxisomal Lon protease homolog 2', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=48244300, end_position_on_the_genomic_accession=48363003, orientation='plus', exon_count=18, OMIM=[617774], no_hdr0=''),
    83755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83755, CurrentID=0, Status='live', Symbol='KRTAP4-12', Aliases=['KAP4.12', 'KRTAP4.12'], description='keratin associated protein 4-12', other_designations='keratin-associated protein 4-12|keratin-associated protein 4.12|ultrahigh sulfur keratin-associated protein 4.12', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41123091, end_position_on_the_genomic_accession=41124182, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    83756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83756, CurrentID=0, Status='live', Symbol='TAS1R3', Aliases=['T1R3'], description='taste 1 receptor member 3', other_designations='taste receptor type 1 member 3|sweet taste receptor T1R3|taste receptor, type 1, member 3', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1331280, end_position_on_the_genomic_accession=1335320, orientation='plus', exon_count=6, OMIM=[605865], no_hdr0=''),
    83758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83758, CurrentID=0, Status='live', Symbol='RBP5', Aliases=['CRBP-III', 'CRBP3', 'CRBPIII', 'HRBPiso'], description='retinol binding protein 5', other_designations='retinol-binding protein 5|cellular retinol-binding protein III|putative cellular retinol-binding protein CRBP III|retinol binding protein 5, cellular', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7119106, end_position_on_the_genomic_accession=7130272, orientation='minus', exon_count=8, OMIM=[611866], no_hdr0=''),
    83759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83759, CurrentID=0, Status='live', Symbol='RBM4B', Aliases=['RBM30', 'RBM4L', 'ZCCHC15', 'ZCCHC21B', 'ZCRB3B'], description='RNA binding motif protein 4B', other_designations='RNA-binding protein 4B|RNA-binding motif protein 30|zinc finger CCHC-type and RNA binding motif 3B', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66664998, end_position_on_the_genomic_accession=66677887, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    83786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83786, CurrentID=0, Status='live', Symbol='FRMD8', Aliases=['FKSG44', 'iTAP'], description='FERM domain containing 8', other_designations='FERM domain-containing protein 8|band4.1 inhibitor LRP interactor|bili|iRhom Tail-Associated Protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65386637, end_position_on_the_genomic_accession=65413525, orientation='plus', exon_count=11, OMIM=[618337], no_hdr0=''),
    83787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83787, CurrentID=0, Status='live', Symbol='ARMC10', Aliases=['PNAS-112', 'PNAS112', 'PSEC0198', 'SVH'], description='armadillo repeat containing 10', other_designations='armadillo repeat-containing protein 10|specific splicing variant involved in hepatocarcinogenesis|splicing variant involved in hepatocarcinogenesis protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103074919, end_position_on_the_genomic_accession=103099773, orientation='plus', exon_count=11, OMIM=[611864], no_hdr0=''),
    83795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83795, CurrentID=0, Status='live', Symbol='KCNK16', Aliases=['K2p16.1', 'TALK-1', 'TALK1'], description='potassium two pore domain channel subfamily K member 16', other_designations='potassium channel subfamily K member 16|2P domain potassium channel Talk-1|TWIK-related alkaline pH-activated K(+) channel 1|pancreatic potassium channel Talk-1|potassium channel, subfamily K, member 16|potassium channel, two pore domain subfamily K, member 16', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39314566, end_position_on_the_genomic_accession=39322968, orientation='minus', exon_count=8, OMIM=[607369], no_hdr0=''),
    83844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83844, CurrentID=0, Status='live', Symbol='USP26', Aliases=[], description='ubiquitin specific peptidase 26', other_designations='ubiquitin carboxyl-terminal hydrolase 26|deubiquitinating enzyme 26|ubiquitin specific protease 26|ubiquitin thioesterase 26|ubiquitin thiolesterase 26|ubiquitin-specific processing protease 26', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=133023168, end_position_on_the_genomic_accession=133097109, orientation='minus', exon_count=6, OMIM=[300309], no_hdr0=''),
    83849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83849, CurrentID=0, Status='live', Symbol='SYT15', Aliases=['CHR10SYT', 'sytXV'], description='synaptotagmin 15', other_designations='synaptotagmin-15|chr10 synaptotagmin|synaptotagmin XV|synaptotagmin XV-a', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46578018, end_position_on_the_genomic_accession=46595170, orientation='plus', exon_count=12, OMIM=[608081], no_hdr0=''),
    83850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83850, CurrentID=0, Status='live', Symbol='ESYT3', Aliases=['CHR3SYT', 'E-Syt3', 'FAM62C'], description='extended synaptotagmin 3', other_designations='extended synaptotagmin-3|chr3 synaptotagmin|extended synaptotagmin protein 3|family with sequence similarity 62 (C2 domain containing), member C', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138434577, end_position_on_the_genomic_accession=138481686, orientation='plus', exon_count=23, OMIM=[616692], no_hdr0=''),
    83851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83851, CurrentID=0, Status='live', Symbol='SYT16', Aliases=['CHR14SYT', 'SYT14L', 'Strep14', 'syt14r'], description='synaptotagmin 16', other_designations='synaptotagmin-16|chr14 synaptotagmin|synaptotagmin 14-like protein|synaptotagmin XIV-related protein|synaptotagmin XVI', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=61812162, end_position_on_the_genomic_accession=62112825, orientation='plus', exon_count=20, OMIM=[610950], no_hdr0=''),
    83852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83852, CurrentID=0, Status='live', Symbol='SETDB2', Aliases=['C13orf4', 'CLLD8', 'CLLL8', 'KMT1F'], description='SET domain bifurcated histone lysine methyltransferase 2', other_designations='histone-lysine N-methyltransferase SETDB2|SET domain bifurcated 2|chronic lymphocytic leukemia deletion region gene 8 protein|lysine N-methyltransferase 1F', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49444274, end_position_on_the_genomic_accession=49495003, orientation='plus', exon_count=16, OMIM=[607865], no_hdr0=''),
    83853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83853, CurrentID=0, Status='live', Symbol='ROPN1L', Aliases=['ASP', 'RSPH11'], description='rhophilin associated tail protein 1 like', other_designations='ropporin-1-like protein|AKAP-associated sperm protein|ROPN1-like protein|radial spoke head 11 homolog', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10441879, end_position_on_the_genomic_accession=10482807, orientation='plus', exon_count=9, OMIM=[611756], no_hdr0=''),
    83854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83854, CurrentID=0, Status='live', Symbol='ANGPTL6', Aliases=['AGF', 'ARP5'], description='angiopoietin like 6', other_designations='angiopoietin-related protein 6|angiopoietin-like protein 6|angiopoietin-related growth factor|angiopoietin-related protein 5', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10092338, end_position_on_the_genomic_accession=10106407, orientation='minus', exon_count=8, OMIM=[609336], no_hdr0=''),
    83855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83855, CurrentID=0, Status='live', Symbol='KLF16', Aliases=['BTEB4', 'DRRF', 'NSLP2'], description='Kruppel like factor 16', other_designations='Krueppel-like factor 16|BTE-binding protein 4|basic transcription element binding protein 4|dopamine receptor regulating factor|novel Sp1-like zinc finger transcription factor 2|transcription factor BTEB4|transcription factor NSLP2|unknown transcript', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1852399, end_position_on_the_genomic_accession=1863579, orientation='minus', exon_count=2, OMIM=[606139], no_hdr0=''),
    83856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83856, CurrentID=0, Status='live', Symbol='FSD1L', Aliases=['CCDC10', 'CSDUFD1', 'FSD1CL', 'FSD1NL', 'MIR1'], description='fibronectin type III and SPRY domain containing 1 like', other_designations='FSD1-like protein|FSD1 C-terminal like|FSD1 N-terminal like|coiled-coil domain containing 10|cystatin and DUF19 domain containing 1', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=105442183, end_position_on_the_genomic_accession=105552433, orientation='plus', exon_count=18, OMIM=[609829], no_hdr0=''),
    83857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83857, CurrentID=0, Status='live', Symbol='TMTC1', Aliases=['ARG99', 'OLFA', 'TMTC1'], description='transmembrane O-mannosyltransferase targeting cadherins 1', other_designations='protein O-mannosyl-transferase TMTC1|transmembrane and tetratricopeptide repeat containing 1|transmembrane and tetratricopeptide repeat containing 1A', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=29500813, end_position_on_the_genomic_accession=29784759, orientation='minus', exon_count=23, OMIM=[615855], no_hdr0=''),
    83858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83858, CurrentID=0, Status='live', Symbol='ATAD3B', Aliases=['AAA-TOB3', 'TOB3'], description='ATPase family AAA domain containing 3B', other_designations='ATPase family AAA domain-containing protein 3B|AAA-ATPase TOB3', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1471732, end_position_on_the_genomic_accession=1509466, orientation='plus', exon_count=18, OMIM=[612317], no_hdr0=''),
    83860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83860, CurrentID=0, Status='live', Symbol='TAF3', Aliases=['TAF140', 'TAFII-140', 'TAFII140'], description='TATA-box binding protein associated factor 3', other_designations='transcription initiation factor TFIID subunit 3|140 kDa TATA box-binding protein-associated factor|RNA polymerase II transcription factor TAFII140|TAF(II)140|TAF3 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 140kDa|TBP-associated factor 3|transcription initiation factor TFIID 140 kDa subunit', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=7818505, end_position_on_the_genomic_accession=8016631, orientation='plus', exon_count=7, OMIM=[606576], no_hdr0=''),
    83861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83861, CurrentID=0, Status='live', Symbol='RSPH3', Aliases=['CILD32', 'RSHL2', 'RSP3', 'dJ111C20.1'], description='radial spoke head 3', other_designations='radial spoke head protein 3 homolog|A-kinase anchor protein RSPH3|radial spoke 3 homolog|radial spoke head 3 homolog|radial spoke head-like protein 2', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158947012, end_position_on_the_genomic_accession=159000426, orientation='minus', exon_count=11, OMIM=[615876], no_hdr0=''),
    83862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83862, CurrentID=0, Status='live', Symbol='TMEM120A', Aliases=['NET29', 'TMPIT'], description='transmembrane protein 120A', other_designations='ion channel TACAN|transmembrane protein induced by tumor necrosis factor alpha', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75986831, end_position_on_the_genomic_accession=75994669, orientation='minus', exon_count=12, OMIM=[616550], no_hdr0=''),
    83871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83871, CurrentID=0, Status='live', Symbol='RAB34', Aliases=['NARR', 'RAB39', 'RAH'], description='RAB34, member RAS oncogene family', other_designations='ras-related protein Rab-34|nine amino-acid residue-repeats|ras-related protein Rab-39|ras-related protein Rah', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28714281, end_position_on_the_genomic_accession=28718440, orientation='minus', exon_count=11, OMIM=[610917], no_hdr0=''),
    83872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83872, CurrentID=0, Status='live', Symbol='HMCN1', Aliases=['ARMD1', 'FBLN6', 'FIBL-6', 'FIBL6'], description='hemicentin 1', other_designations='hemicentin-1|LOC100507250/HMCN1 fusion|fibulin-6', map_location='1q25.3-q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=185734391, end_position_on_the_genomic_accession=186190949, orientation='plus', exon_count=107, OMIM=[608548], no_hdr0=''),
    83873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83873, CurrentID=0, Status='live', Symbol='GPR61', Aliases=['BALGR', 'GPCR3'], description='G protein-coupled receptor 61', other_designations='G-protein coupled receptor 61|biogenic amine receptor-like G-protein coupled receptor|biogenic amine receptor-like GPCR|probable G-protein coupled receptor 61', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109539872, end_position_on_the_genomic_accession=109547260, orientation='plus', exon_count=2, OMIM=[606916], no_hdr0=''),
    83874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83874, CurrentID=0, Status='live', Symbol='TBC1D10A', Aliases=['EPI64', 'TBC1D10', 'dJ130H16.1', 'dJ130H16.2'], description='TBC1 domain family member 10A', other_designations='TBC1 domain family member 10A|EBP50-PDX interactor of 64 kDa|EBP50-PDZ interactor of 64 kD|rab27A-GAP-alpha', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30291990, end_position_on_the_genomic_accession=30326941, orientation='minus', exon_count=9, OMIM=[610020], no_hdr0=''),
    83875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83875, CurrentID=0, Status='live', Symbol='BCO2', Aliases=['B-DIOX-II', 'BCDO2'], description='beta-carotene oxygenase 2', other_designations="beta,beta-carotene 9',10'-oxygenase|b,b-carotene-9',10'-dioxygenase|beta,beta-carotene 9',10'-dioxygenase variant 1|beta,beta-carotene 9',10'-dioxygenase variant 2|beta,beta-carotene 9',10'-dioxygenase variant 3|beta-carotene 9',10' oxygenase|beta-carotene dioxygenase 2|carotenoid-9',10'-cleaving dioxygenase", map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112175512, end_position_on_the_genomic_accession=112218946, orientation='plus', exon_count=13, OMIM=[611740], no_hdr0=''),
    83876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83876, CurrentID=0, Status='live', Symbol='MRO', Aliases=['B29', 'C18orf3'], description='maestro', other_designations='protein maestro|beside the Ma29 deletion|male-specific transcription in the developing reproductive organs', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50795130, end_position_on_the_genomic_accession=50825413, orientation='minus', exon_count=10, OMIM=[608080], no_hdr0=''),
    83877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83877, CurrentID=0, Status='live', Symbol='TM2D2', Aliases=['BLP1'], description='TM2 domain containing 2', other_designations='TM2 domain-containing protein 2|BBP-like protein 1|beta-amyloid-binding protein-like protein 1', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38988808, end_position_on_the_genomic_accession=38997139, orientation='minus', exon_count=5, OMIM=[610081], no_hdr0=''),
    83878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83878, CurrentID=0, Status='live', Symbol='USHBP1', Aliases=['AIEBP', 'MCC2'], description='USH1 protein network component harmonin binding protein 1', other_designations='Usher syndrome type-1C protein-binding protein 1|AIE-75-binding protein|USH1C-binding protein 1|Usher syndrome 1C binding protein 1|mutated in colon cancer protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17249171, end_position_on_the_genomic_accession=17264753, orientation='minus', exon_count=14, OMIM=[611810], no_hdr0=''),
    83879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83879, CurrentID=0, Status='live', Symbol='CDCA7', Aliases=['ICF3', 'JPO1'], description='cell division cycle associated 7', other_designations='cell division cycle-associated protein 7|c-Myc target JPO1', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=173354861, end_position_on_the_genomic_accession=173368997, orientation='plus', exon_count=10, OMIM=[609937], no_hdr0=''),
    83881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83881, CurrentID=0, Status='live', Symbol='MIXL1', Aliases=['MILD1', 'MIX', 'MIXL'], description='Mix paired-like homeobox', other_designations='homeobox protein MIXL1|MIX1 homeobox-like protein 1|Mix-like homeobox protein 1|homeodomain protein MIX|mix.1 homeobox-like protein', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226223664, end_position_on_the_genomic_accession=226227060, orientation='plus', exon_count=2, OMIM=[609852], no_hdr0=''),
    83882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83882, CurrentID=0, Status='live', Symbol='TSPAN10', Aliases=['OCSP'], description='tetraspanin 10', other_designations='tetraspanin-10|oculospanin|tspan-10', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81637196, end_position_on_the_genomic_accession=81648755, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    83884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83884, CurrentID=0, Status='live', Symbol='SLC25A2', Aliases=['ORC2', 'ORNT2'], description='solute carrier family 25 member 2', other_designations='mitochondrial ornithine transporter 2|solute carrier family 25 (mitochondrial carrier; ornithine transporter) member 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141302635, end_position_on_the_genomic_accession=141304049, orientation='minus', exon_count=1, OMIM=[608157], no_hdr0=''),
    83886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83886, CurrentID=0, Status='live', Symbol='PRSS27', Aliases=['CAPH2', 'MPN'], description='serine protease 27', other_designations='serine protease 27|channel-activating protease 2|marapsin|pancreasin|protease, serine 27', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2712418, end_position_on_the_genomic_accession=2720224, orientation='minus', exon_count=7, OMIM=[608018], no_hdr0=''),
    83887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83887, CurrentID=0, Status='live', Symbol='TTLL2', Aliases=['C6orf104', 'NYD-TSPG', 'dJ366N23.3'], description='tubulin tyrosine ligase like 2', other_designations='probable tubulin polyglutamylase TTLL2|testis-specific protein NYD-TSPG|tubulin tyrosine ligase-like family, member 2|tubulin--tyrosine ligase-like protein 2', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=167325065, end_position_on_the_genomic_accession=167342710, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    83888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83888, CurrentID=0, Status='live', Symbol='FGFBP2', Aliases=['HBP17RP', 'KSP37'], description='fibroblast growth factor binding protein 2', other_designations='fibroblast growth factor-binding protein 2|37 kDa killer-specific secretory protein|FGF-BP2|FGF-binding protein 2|FGFBP-2|HBp17-RP|HBp17-related protein|killer-specific secretory protein of 37 kDa', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15960245, end_position_on_the_genomic_accession=15963175, orientation='minus', exon_count=2, OMIM=[607713], no_hdr0=''),
    83889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83889, CurrentID=0, Status='live', Symbol='WDR87', Aliases=['NYD-SP11'], description='WD repeat domain 87', other_designations='WD repeat-containing protein 87|testis development protein NYD-SP11', map_location='19q13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37884577, end_position_on_the_genomic_accession=37906617, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    83890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83890, CurrentID=0, Status='live', Symbol='SPATA9', Aliases=['NYD-SP16'], description='spermatogenesis associated 9', other_designations='spermatogenesis-associated protein 9|CTD-2154I11.2|testicular tissue protein Li 179|testis development protein NYD-SP16', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95652181, end_position_on_the_genomic_accession=95732102, orientation='minus', exon_count=20, OMIM=[608039], no_hdr0=''),
    83891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83891, CurrentID=0, Status='live', Symbol='SNX25', Aliases=['MSTP043', 'SBBI31'], description='sorting nexin 25', other_designations='sorting nexin-25', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185204237, end_position_on_the_genomic_accession=185363966, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    83892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83892, CurrentID=0, Status='live', Symbol='KCTD10', Aliases=['BTBD28', 'MSTP028', 'ULRO61', 'hBACURD3'], description='potassium channel tetramerization domain containing 10', other_designations='BTB/POZ domain-containing adapter for CUL3-mediated RhoA degradation protein 3|BTB/POZ domain-containing protein KCTD10|potassium channel tetramerisation domain containing 10|potassium channel tetramerization domain-containing protein 10', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109448655, end_position_on_the_genomic_accession=109477300, orientation='minus', exon_count=7, OMIM=[613421], no_hdr0=''),
    83893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83893, CurrentID=0, Status='live', Symbol='SPATA16', Aliases=['NYD-SP12', 'SPGF6'], description='spermatogenesis associated 16', other_designations='spermatogenesis-associated protein 16|testicular tissue protein Li 185|testis development protein NYD-SP12|testis-specific Golgi protein', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=172889357, end_position_on_the_genomic_accession=173141235, orientation='minus', exon_count=13, OMIM=[609856], no_hdr0=''),
    83894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83894, CurrentID=0, Status='live', Symbol='TTC29', Aliases=['NYD-SP14', 'SPGF42', 'TBPP2A'], description='tetratricopeptide repeat domain 29', other_designations='tetratricopeptide repeat protein 29|TPR repeat protein 29|testicular secretory protein Li 62|testis development protein NYD-SP14', map_location='4q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=146706617, end_position_on_the_genomic_accession=146945882, orientation='minus', exon_count=17, OMIM=[618735], no_hdr0=''),
    83895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83895, CurrentID=0, Status='live', Symbol='KRTAP1-5', Aliases=['KAP1.5', 'KRTAP1.5'], description='keratin associated protein 1-5', other_designations='keratin-associated protein 1-5|high sulfur keratin-associated protein 1.5|keratin associated protein 1.5', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41026026, end_position_on_the_genomic_accession=41027208, orientation='minus', exon_count=1, OMIM=[608822], no_hdr0=''),
    83896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83896, CurrentID=0, Status='live', Symbol='KRTAP3-1', Aliases=['KAP3.1', 'KRTAP3.1'], description='keratin associated protein 3-1', other_designations='keratin-associated protein 3-1|high sulfur keratin-associated protein 3.1|keratin-associated protein 3.1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41008521, end_position_on_the_genomic_accession=41009128, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    83897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83897, CurrentID=0, Status='live', Symbol='KRTAP3-2', Aliases=['KAP3.2', 'KRTAP3.2'], description='keratin associated protein 3-2', other_designations='keratin-associated protein 3-2|high sulfur keratin-associated protein 3.2|keratin associated protein 3.2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40999193, end_position_on_the_genomic_accession=40999906, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    83899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83899, CurrentID=0, Status='live', Symbol='KRTAP9-2', Aliases=['KAP9.2', 'KRTAP9.2'], description='keratin associated protein 9-2', other_designations='keratin-associated protein 9-2|ultrahigh sulfur keratin-associated protein 9.2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41226648, end_position_on_the_genomic_accession=41227652, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    83900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83900, CurrentID=0, Status='live', Symbol='KRTAP9-3', Aliases=['KAP9.3', 'KRTAP9.3'], description='keratin associated protein 9-3', other_designations='keratin-associated protein 9-3|keratin associated protein 9.3|ultrahigh sulfur keratin-associated protein 9.3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41232449, end_position_on_the_genomic_accession=41233454, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    83901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83901, CurrentID=0, Status='live', Symbol='KRTAP9-8', Aliases=['KAP9.8', 'KRTAP9.8'], description='keratin associated protein 9-8', other_designations='keratin-associated protein 9-8|ultrahigh sulfur keratin-associated protein 9.8', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41237999, end_position_on_the_genomic_accession=41239004, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    83902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83902, CurrentID=0, Status='live', Symbol='KRTAP17-1', Aliases=['KAP17.1', 'KRTAP16.1', 'KRTAP17.1'], description='keratin associated protein 17-1', other_designations='keratin-associated protein 17-1|keratin associated protein 16.1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41314912, end_position_on_the_genomic_accession=41315710, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    83903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83903, CurrentID=0, Status='live', Symbol='HASPIN', Aliases=['GSG2'], description='histone H3 associated protein kinase', other_designations='serine/threonine-protein kinase haspin|H-haspin|germ cell associated 2, haspin|germ cell-specific gene 2 protein|haploid germ cell-specific nuclear protein kinase', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3723903, end_position_on_the_genomic_accession=3726699, orientation='plus', exon_count=1, OMIM=[609240], no_hdr0=''),
    83930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83930, CurrentID=0, Status='live', Symbol='STARD3NL', Aliases=['MENTHO'], description='STARD3 N-terminal like', other_designations='STARD3 N-terminal-like protein|MLN64 N-terminal domain homolog', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38178245, end_position_on_the_genomic_accession=38230671, orientation='plus', exon_count=13, OMIM=[611759], no_hdr0=''),
    83931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83931, CurrentID=0, Status='live', Symbol='STK40', Aliases=['SHIK', 'SgK495'], description='serine/threonine kinase 40', other_designations='serine/threonine-protein kinase 40|SINK-homologous serine/threonine-protein kinase|Ser/Thr-like kinase|sugen kinase 495', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36339628, end_position_on_the_genomic_accession=36385924, orientation='minus', exon_count=12, OMIM=[609437], no_hdr0=''),
    83932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83932, CurrentID=0, Status='live', Symbol='SPRTN', Aliases=['C1orf124', 'DVC1', 'PRO4323', 'spartan'], description='SprT-like N-terminal domain', other_designations='DNA-dependent metalloprotease SPRTN|DNA damage protein targeting VCP|DNA damage-targeting VCP (p97) adaptor|zinc finger RAD18 domain-containing protein', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231337980, end_position_on_the_genomic_accession=231355023, orientation='plus', exon_count=6, OMIM=[616086], no_hdr0=''),
    83933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83933, CurrentID=0, Status='live', Symbol='HDAC10', Aliases=['HD10'], description='histone deacetylase 10', other_designations='polyamine deacetylase HDAC10', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50245183, end_position_on_the_genomic_accession=50251265, orientation='minus', exon_count=20, OMIM=[608544], no_hdr0=''),
    83937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83937, CurrentID=0, Status='live', Symbol='RASSF4', Aliases=['AD037'], description='Ras association domain family member 4', other_designations='ras association domain-containing protein 4|Ras association (RalGDS/AF-6) domain family 4|Ras association (RalGDS/AF-6) domain family member 4|Ras association domain family 4|tumor suppressor RASSF4', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=44959753, end_position_on_the_genomic_accession=44995891, orientation='plus', exon_count=11, OMIM=[610559], no_hdr0=''),
    83938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83938, CurrentID=0, Status='live', Symbol='LRMDA', Aliases=['C10orf11', 'CDA017'], description='leucine rich melanocyte differentiation associated', other_designations='leucine-rich melanocyte differentiation-associated protein|leucine-rich repeat-containing protein C10orf11', map_location='10q22.2-q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75431624, end_position_on_the_genomic_accession=76560168, orientation='plus', exon_count=11, OMIM=[614537], no_hdr0=''),
    83939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83939, CurrentID=0, Status='live', Symbol='EIF2A', Aliases=['CDA02', 'EIF-2A', 'MST089', 'MSTP004', 'MSTP089'], description='eukaryotic translation initiation factor 2A', other_designations='eukaryotic translation initiation factor 2A|65 kDa eukaryotic translation initiation factor 2A|eukaryotic translation initiation factor 2A, 65kDa', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150546726, end_position_on_the_genomic_accession=150586016, orientation='plus', exon_count=14, OMIM=[609234], no_hdr0=''),
    83940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83940, CurrentID=0, Status='live', Symbol='TATDN1', Aliases=['CDA11'], description='TatD DNase domain containing 1', other_designations='putative deoxyribonuclease TATDN1|hepatocarcinoma high expression protein', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124488494, end_position_on_the_genomic_accession=124540486, orientation='minus', exon_count=15, OMIM=[619364], no_hdr0=''),
    83941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83941, CurrentID=0, Status='live', Symbol='TM2D1', Aliases=['BBP'], description='TM2 domain containing 1', other_designations='TM2 domain-containing protein 1|Beta-amyloid peptide binding protein|amyloid-beta-binding protein|beta-amyloid-binding protein|hBBP', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=61681046, end_position_on_the_genomic_accession=61725141, orientation='minus', exon_count=8, OMIM=[610080], no_hdr0=''),
    83942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83942, CurrentID=0, Status='live', Symbol='TSSK1B', Aliases=['FKSG81', 'SPOGA4', 'STK22D', 'TSK1', 'TSSK1'], description='testis specific serine kinase 1B', other_designations='testis-specific serine/threonine-protein kinase 1|TSK-1|TSSK-1|serine/threonine kinase 22D (spermiogenesis associated)|serine/threonine kinase FKSG81|serine/threonine-protein kinase 22A|spermiogenesis associated 4|testis tissue sperm-binding protein Li 55e|testis-specific kinase 1|testis-specific serine kinase 1', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=113432553, end_position_on_the_genomic_accession=113434989, orientation='minus', exon_count=1, OMIM=[610709], no_hdr0=''),
    83943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83943, CurrentID=0, Status='live', Symbol='IMMP2L', Aliases=['IMMP2L-IT1', 'IMP2', 'IMP2-LIKE'], description='inner mitochondrial membrane peptidase subunit 2', other_designations='mitochondrial inner membrane protease subunit 2|IMP2 inner mitochondrial membrane peptidase-like|IMP2 inner mitochondrial membrane protease-like|inner mitochondrial membrane peptidase 2 like', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=110662644, end_position_on_the_genomic_accession=111562531, orientation='minus', exon_count=23, OMIM=[605977], no_hdr0=''),
    83953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83953, CurrentID=0, Status='live', Symbol='FCAMR', Aliases=['CD351', 'FCA/MR', 'FKSG87'], description='Fc fragment of IgA and IgM receptor', other_designations='high affinity immunoglobulin alpha and immunoglobulin mu Fc receptor|Fc alpha/mu receptor|Fc receptor, IgA, IgM, high affinity|immunity related factor|receptor for Fc fragment of IgA and IgM', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206957955, end_position_on_the_genomic_accession=206970657, orientation='minus', exon_count=10, OMIM=[605484], no_hdr0=''),
    83959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83959, CurrentID=0, Status='live', Symbol='SLC4A11', Aliases=['BTR1', 'CDPD1', 'CHED', 'CHED2', 'NABC1', 'dJ794I6.2'], description='solute carrier family 4 member 11', other_designations='sodium bicarbonate transporter-like protein 11|bicarbonate transporter related protein 1|sodium-coupled borate cotransporter 1|solute carrier family 4, sodium bicarbonate transporter-like, member 11|solute carrier family 4, sodium borate transporter, member 11', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3227417, end_position_on_the_genomic_accession=3241484, orientation='minus', exon_count=25, OMIM=[610206], no_hdr0=''),
    83982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83982, CurrentID=0, Status='live', Symbol='IFI27L2', Aliases=['FAM14A', 'ISG12B', 'TLH29'], description='interferon alpha inducible protein 27 like 2', other_designations='interferon alpha-inducible protein 27-like protein 2|ISG12(b) protein|family with sequence similarity 14, member A|interferon-stimulated gene 12b protein|pIFI27-like protein', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94127781, end_position_on_the_genomic_accession=94129604, orientation='minus', exon_count=4, OMIM=[611319], no_hdr0=''),
    83983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83983, CurrentID=0, Status='live', Symbol='TSSK6', Aliases=['CT72', 'FKSG82', 'SSTK', 'TSSK4'], description='testis specific serine kinase 6', other_designations='testis-specific serine/threonine-protein kinase 6|TSK-6|cancer/testis antigen 72|serine/threonine protein kinase SSTK|small serine/threonine kinase|testis secretory sperm-binding protein Li 205a', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19514219, end_position_on_the_genomic_accession=19515548, orientation='minus', exon_count=1, OMIM=[610712], no_hdr0=''),
    83985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83985, CurrentID=0, Status='live', Symbol='SPNS1', Aliases=['HSpin1', 'LAT', 'PP2030', 'SLC62A1', 'SLC63A1', 'SPIN1', 'SPINL', 'nrs'], description='sphingolipid transporter 1 (putative)', other_designations='protein spinster homolog 1|SPNS sphingolipid transporter 1 (putative)|spinster homolog 1|spinster-like protein 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28973999, end_position_on_the_genomic_accession=28984769, orientation='plus', exon_count=14, OMIM=[612583], no_hdr0=''),
    83986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83986, CurrentID=0, Status='live', Symbol='FAM234A', Aliases=['C16orf9', 'ITFG3', 'gs19'], description='family with sequence similarity 234 member A', other_designations='protein FAM234A|integrin alpha FG-GAP repeat containing 3|protein ITFG3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=234760, end_position_on_the_genomic_accession=269963, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    83987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83987, CurrentID=0, Status='live', Symbol='CCDC8', Aliases=['3M3', 'PPP1R20', 'p90'], description='coiled-coil domain containing 8', other_designations='coiled-coil domain-containing protein 8|protein phosphatase 1, regulatory subunit 20', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46410329, end_position_on_the_genomic_accession=46413564, orientation='minus', exon_count=1, OMIM=[614145], no_hdr0=''),
    83988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83988, CurrentID=0, Status='live', Symbol='NCALD', Aliases=[], description='neurocalcin delta', other_designations='neurocalcin-delta', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=101686542, end_position_on_the_genomic_accession=102124907, orientation='minus', exon_count=11, OMIM=[606722], no_hdr0=''),
    83989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83989, CurrentID=0, Status='live', Symbol='FAM172A', Aliases=['C5orf21', 'Toupee'], description='family with sequence similarity 172 member A', other_designations='cotranscriptional regulator FAM172A|protein FAM172A', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=93615130, end_position_on_the_genomic_accession=94111699, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    83990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83990, CurrentID=0, Status='live', Symbol='BRIP1', Aliases=['BACH1', 'FANCJ', 'OF'], description='BRCA1 interacting helicase 1', other_designations='Fanconi anemia group J protein|ATP-dependent RNA helicase BRIP1|BRCA1 interacting protein C-terminal helicase 1|BRCA1-associated C-terminal helicase 1|BRCA1-binding helicase-like protein BACH1|BRCA1/BRCA2-associated helicase 1|FANCJ helicase', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61679139, end_position_on_the_genomic_accession=61864120, orientation='minus', exon_count=25, OMIM=[605882], no_hdr0=''),
    83992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83992, CurrentID=0, Status='live', Symbol='CTTNBP2', Aliases=['C7orf8', 'CORTBP2', 'Orf4'], description='cortactin binding protein 2', other_designations='cortactin-binding protein 2|CORTBP2, C7orf8', map_location='7q31.31', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=117710648, end_position_on_the_genomic_accession=117873818, orientation='minus', exon_count=29, OMIM=[609772], no_hdr0=''),
    83998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83998, CurrentID=0, Status='live', Symbol='REG4', Aliases=['GISP', 'REG-IV', 'RELP'], description='regenerating family member 4', other_designations='regenerating islet-derived protein 4|REG-4|REG-like protein|gastrointestinal secretory protein|reg IV|regenerating gene type IV|regenerating islet-derived family, member 4|regenerating islet-derived protein IV', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119794017, end_position_on_the_genomic_accession=119811460, orientation='minus', exon_count=7, OMIM=[609846], no_hdr0=''),
    83999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=83999, CurrentID=0, Status='live', Symbol='KREMEN1', Aliases=['ECTD13', 'KREMEN', 'KRM1'], description='kringle containing transmembrane protein 1', other_designations='kremen protein 1|dickkopf receptor|kringle domain-containing transmembrane protein 1|kringle-coding gene marking the eye and the nose|kringle-containing protein marking the eye and the nose', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29073035, end_position_on_the_genomic_accession=29168333, orientation='plus', exon_count=12, OMIM=[609898], no_hdr0=''),
    84000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84000, CurrentID=0, Status='live', Symbol='TMPRSS13', Aliases=['MSP', 'MSPL', 'MSPS', 'TMPRSS11'], description='transmembrane serine protease 13', other_designations='transmembrane protease serine 13|membrane-type mosaic serine protease|transmembrane protease, serine 11|transmembrane protease, serine 13', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117900641, end_position_on_the_genomic_accession=117929402, orientation='minus', exon_count=14, OMIM=[610050], no_hdr0=''),
    84002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84002, CurrentID=0, Status='live', Symbol='B3GNT5', Aliases=['B3GN-T5', 'beta3Gn-T5'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 5', other_designations='lactosylceramide 1,3-N-acetyl-beta-D-glucosaminyltransferase|BGnT-5|UDP-GlcNAc:beta-Gal beta-1,3-N-acetylglucosaminyltransferase 5|beta 1,3 N-acetyglucosaminyltransferase Lc3 synthase|beta-1,3-Gn-T5|beta-1,3-N-acetylglucosaminyltransferase 5|beta-1,3-N-acetylglucosaminyltransferase bGnT-5|lactotriaosylceramide synthase|lc(3)Cer synthase|lc3 synthase', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183253207, end_position_on_the_genomic_accession=183273391, orientation='plus', exon_count=8, OMIM=[615333], no_hdr0=''),
    84033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84033, CurrentID=0, Status='live', Symbol='OBSCN', Aliases=['ARHGEF30', 'UNC89'], description='obscurin, cytoskeletal calmodulin and titin-interacting RhoGEF', other_designations='obscurin|obscurin, myosin light chain kinase|obscurin-MLCK', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228208044, end_position_on_the_genomic_accession=228378876, orientation='plus', exon_count=118, OMIM=[608616], no_hdr0=''),
    84034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84034, CurrentID=0, Status='live', Symbol='EMILIN2', Aliases=['EMILIN-2', 'FOAP-10'], description='elastin microfibril interfacer 2', other_designations='EMILIN-2|elastin microfibril interface-located protein 2|extracellular glycoprotein EMILIN-2', map_location='18p11.32-p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=2847006, end_position_on_the_genomic_accession=2916003, orientation='plus', exon_count=9, OMIM=[608928], no_hdr0=''),
    84056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84056, CurrentID=0, Status='live', Symbol='KATNAL1', Aliases=[], description='katanin catalytic subunit A1 like 1', other_designations='katanin p60 ATPase-containing subunit A-like 1|katanin catalytic subunit A like 1|katanin p60 subunit A like 1|p60 katanin-like 1', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30200026, end_position_on_the_genomic_accession=30307551, orientation='minus', exon_count=13, OMIM=[614764], no_hdr0=''),
    84057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84057, CurrentID=0, Status='live', Symbol='MND1', Aliases=['GAJ'], description='meiotic nuclear divisions 1', other_designations='meiotic nuclear division protein 1 homolog|homolog of yeast MND1|meiotic nuclear divisions 1 homolog', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153344649, end_position_on_the_genomic_accession=153415118, orientation='plus', exon_count=11, OMIM=[611422], no_hdr0=''),
    84058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84058, CurrentID=0, Status='live', Symbol='WDR54', Aliases=[], description='WD repeat domain 54', other_designations='WD repeat-containing protein 54', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74421721, end_position_on_the_genomic_accession=74426259, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84059, CurrentID=0, Status='live', Symbol='ADGRV1', Aliases=['FEB4', 'GPR98', 'MASS1', 'USH2B', 'USH2C', 'VLGR1', 'VLGR1b'], description='adhesion G protein-coupled receptor V1', other_designations='adhesion G-protein coupled receptor V1|G-protein coupled receptor 98|monogenic audiogenic seizure susceptibility protein 1 homolog|usher syndrome type-2C protein|very large G-protein coupled receptor 1', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=90558796, end_position_on_the_genomic_accession=91164437, orientation='plus', exon_count=91, OMIM=[602851], no_hdr0=''),
    84060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84060, CurrentID=0, Status='live', Symbol='RBM48', Aliases=['C7orf64', 'HSPC304'], description='RNA binding motif protein 48', other_designations='RNA-binding protein 48|UPF0712 protein C7orf64', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92528795, end_position_on_the_genomic_accession=92540481, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    84061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84061, CurrentID=0, Status='live', Symbol='MAGT1', Aliases=['CDG1CC', 'IAP', 'MRX95', 'OST3B', 'PRO0756', 'SLC58A1', 'XMEN', 'bA217H1.1'], description='magnesium transporter 1', other_designations='magnesium transporter protein 1|dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit MAGT1|implantation-associated protein|oligosaccharyl transferase subunit MAGT1|oligosaccharyltransferase 3 homolog B', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77825747, end_position_on_the_genomic_accession=77895568, orientation='minus', exon_count=10, OMIM=[300715], no_hdr0=''),
    84062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84062, CurrentID=0, Status='live', Symbol='DTNBP1', Aliases=['BLOC1S8', 'DBND', 'HPS7', 'My031', 'SDY'], description='dystrobrevin binding protein 1', other_designations='dysbindin|BLOC-1 subunit 8|Hermansky-Pudlak syndrome 7 protein|biogenesis of lysosomal organelles complex-1, subunit 8|biogenesis of lysosome-related organelles complex 1 subunit 8|dysbindin-1', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=15522803, end_position_on_the_genomic_accession=15663058, orientation='minus', exon_count=14, OMIM=[607145], no_hdr0=''),
    84063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84063, CurrentID=0, Status='live', Symbol='KIRREL2', Aliases=['FILTRIN', 'NEPH3', 'NLG1'], description='kirre like nephrin family adhesion molecule 2', other_designations='kin of IRRE-like protein 2|kin of IRRE like 2|kin of irregular chiasm-like protein 2|nephrin-like gene 1|nephrin-like protein 3', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35851635, end_position_on_the_genomic_accession=35867146, orientation='plus', exon_count=16, OMIM=[607762], no_hdr0=''),
    84064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84064, CurrentID=0, Status='live', Symbol='HDHD2', Aliases=['3110052N05Rik', 'HEL-S-301'], description='haloacid dehalogenase like hydrolase domain containing 2', other_designations='haloacid dehalogenase-like hydrolase domain-containing protein 2|epididymis secretory protein Li 301|epididymis secretory sperm binding protein', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47107410, end_position_on_the_genomic_accession=47150520, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    84065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84065, CurrentID=0, Status='live', Symbol='TMEM222', Aliases=['C1orf160'], description='transmembrane protein 222', other_designations='transmembrane protein 222', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27322163, end_position_on_the_genomic_accession=27336400, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    84066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84066, CurrentID=0, Status='live', Symbol='TEX35', Aliases=['C1orf49', 'TSC24'], description='testis expressed 35', other_designations='testis-expressed protein 35|Testis-Specific Conserved gene 24kDa|testis-expressed sequence 35 protein', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=178513109, end_position_on_the_genomic_accession=178523510, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    84067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84067, CurrentID=0, Status='live', Symbol='FHIP1B', Aliases=['C11orf56', 'FAM160A2', 'FHIP'], description='FHF complex subunit HOOK interacting protein 1B', other_designations='FHF complex subunit HOOK interacting protein 1B|FTS and Hook-interacting protein|family with sequence similarity 160 member A2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6211338, end_position_on_the_genomic_accession=6234663, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    84068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84068, CurrentID=0, Status='live', Symbol='SLC10A7', Aliases=['C4orf13', 'P7', 'SSASKS'], description='solute carrier family 10 member 7', other_designations='sodium/bile acid cotransporter 7|Na(+)/bile acid cotransporter 7|SBF-domain containing protein|solute carrier family 10 (sodium/bile acid cotransporter family), member 7', map_location='4q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=146253981, end_position_on_the_genomic_accession=146522351, orientation='minus', exon_count=18, OMIM=[611459], no_hdr0=''),
    84069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84069, CurrentID=0, Status='live', Symbol='PLEKHN1', Aliases=['CLPABP'], description='pleckstrin homology domain containing N1', other_designations='pleckstrin homology domain-containing family N member 1|PH domain-containing family N member 1|cardiolipin and phosphatidic acid-binding protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=965820, end_position_on_the_genomic_accession=975865, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    84070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84070, CurrentID=0, Status='live', Symbol='FAM186B', Aliases=['C12orf25'], description='family with sequence similarity 186 member B', other_designations='protein FAM186B', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49582873, end_position_on_the_genomic_accession=49605709, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84071, CurrentID=0, Status='live', Symbol='ARMC2', Aliases=['SPGF38', 'bA787I22.1'], description='armadillo repeat containing 2', other_designations='armadillo repeat-containing protein 2', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108848410, end_position_on_the_genomic_accession=108989090, orientation='plus', exon_count=25, OMIM=[618424], no_hdr0=''),
    84072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84072, CurrentID=0, Status='live', Symbol='HORMAD1', Aliases=['CT46', 'NOHMA'], description='HORMA domain containing 1', other_designations='HORMA domain-containing protein 1|cancer/testis antigen 46|newborn ovary HORMA protein|testis tissue sperm-binding protein Li 86P', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150698060, end_position_on_the_genomic_accession=150720910, orientation='minus', exon_count=16, OMIM=[609824], no_hdr0=''),
    84073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84073, CurrentID=0, Status='live', Symbol='MYCBPAP', Aliases=['AMAP-1', 'AMAP1'], description='MYCBP associated protein', other_designations='MYCBP-associated protein|AMAM-1|AMY-1-binding protein 1|AMY1-associating protein 1|testis secretory sperm-binding protein Li 214e', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50507778, end_position_on_the_genomic_accession=50531502, orientation='plus', exon_count=21, OMIM=[609835], no_hdr0=''),
    84074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84074, CurrentID=0, Status='live', Symbol='QRICH2', Aliases=['SPGF35'], description='glutamine rich 2', other_designations='glutamine-rich protein 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76271296, end_position_on_the_genomic_accession=76308811, orientation='minus', exon_count=21, OMIM=[618304], no_hdr0=''),
    84075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84075, CurrentID=0, Status='live', Symbol='FSCB', Aliases=['C14orf155'], description='fibrous sheath CABYR binding protein', other_designations='fibrous sheath CABYR-binding protein', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=44504149, end_position_on_the_genomic_accession=44507283, orientation='minus', exon_count=1, OMIM=[611779], no_hdr0=''),
    84076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84076, CurrentID=0, Status='live', Symbol='TKTL2', Aliases=[], description='transketolase like 2', other_designations='transketolase-like protein 2|testis tissue sperm-binding protein Li 39a', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163471095, end_position_on_the_genomic_accession=163473754, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    84077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84077, CurrentID=0, Status='live', Symbol='C3orf20', Aliases=[], description='chromosome 3 open reading frame 20', other_designations='uncharacterized protein C3orf20', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14673470, end_position_on_the_genomic_accession=14773036, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    84078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84078, CurrentID=0, Status='live', Symbol='KBTBD7', Aliases=[], description='kelch repeat and BTB domain containing 7', other_designations='kelch repeat and BTB domain-containing protein 7|kelch repeat and BTB (POZ) domain containing 7', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41189834, end_position_on_the_genomic_accession=41194569, orientation='minus', exon_count=1, OMIM=[617739], no_hdr0=''),
    84079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84079, CurrentID=0, Status='live', Symbol='ANKRD27', Aliases=['PP12899', 'VARP'], description='ankyrin repeat domain 27', other_designations='ankyrin repeat domain-containing protein 27|VPS9 domain-containing protein|VPS9-ankyrin-repeat protein|Vps9 domain and ankyrin-repeat-containing protein|ankyrin repeat domain 27 (VPS9 domain)', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32597005, end_position_on_the_genomic_accession=32675215, orientation='minus', exon_count=30, OMIM=[618957], no_hdr0=''),
    84080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84080, CurrentID=0, Status='live', Symbol='ENKD1', Aliases=['C16orf48', 'DAKV6410', 'FBB11'], description='enkurin domain containing 1', other_designations='enkurin domain-containing protein 1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67662945, end_position_on_the_genomic_accession=67667382, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    84081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84081, CurrentID=0, Status='live', Symbol='NSRP1', Aliases=['CCDC55', 'HSPC095', 'NSrp70'], description='nuclear speckle splicing regulatory protein 1', other_designations='nuclear speckle splicing regulatory protein 1|coiled-coil domain containing 55|coiled-coil domain-containing protein 55|nuclear speckle-related protein 70', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30116816, end_position_on_the_genomic_accession=30186475, orientation='plus', exon_count=8, OMIM=[616173], no_hdr0=''),
    84083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84083, CurrentID=0, Status='live', Symbol='ZRANB3', Aliases=['4933425L19Rik', 'AH2'], description='zinc finger RANBP2-type containing 3', other_designations='DNA annealing helicase and endonuclease ZRANB3|annealing helicase 2|zinc finger Ran-binding domain-containing protein 3|zinc finger, RAN-binding domain containing 3', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=135196969, end_position_on_the_genomic_accession=135531218, orientation='minus', exon_count=23, OMIM=[615655], no_hdr0=''),
    84084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84084, CurrentID=0, Status='live', Symbol='RAB6C', Aliases=['WTH3'], description='RAB6C, member RAS oncogene family', other_designations='ras-related protein Rab-6C|rab6-like protein WTH3', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=129979666, end_position_on_the_genomic_accession=129982738, orientation='plus', exon_count=1, OMIM=[612909], no_hdr0=''),
    84085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84085, CurrentID=0, Status='live', Symbol='FBXO30', Aliases=['Fbx30'], description='F-box protein 30', other_designations='F-box only protein 30|F-box domain protein|F-box only protein, helicase, 18', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=145793502, end_position_on_the_genomic_accession=145864409, orientation='minus', exon_count=5, OMIM=[609101], no_hdr0=''),
    84100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84100, CurrentID=0, Status='live', Symbol='ARL6', Aliases=['BBS3', 'RP55'], description='ADP ribosylation factor like GTPase 6', other_designations='ADP-ribosylation factor-like protein 6|Bardet-Biedl syndrome 3 protein', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=97762581, end_position_on_the_genomic_accession=97812585, orientation='plus', exon_count=14, OMIM=[608845], no_hdr0=''),
    84101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84101, CurrentID=0, Status='live', Symbol='USP44', Aliases=[], description='ubiquitin specific peptidase 44', other_designations='ubiquitin carboxyl-terminal hydrolase 44|deubiquitinating enzyme 44|ubiquitin specific protease 44|ubiquitin thioesterase 44|ubiquitin thiolesterase 44|ubiquitin-specific-processing protease 44', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95516560, end_position_on_the_genomic_accession=95551529, orientation='minus', exon_count=14, OMIM=[610993], no_hdr0=''),
    84102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84102, CurrentID=0, Status='live', Symbol='SLC41A2', Aliases=['SLC41A1-L1'], description='solute carrier family 41 member 2', other_designations='solute carrier family 41 member 2|SLC41A1-like 1|solute carrier family 41 (magnesium transporter), member 2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104801801, end_position_on_the_genomic_accession=104958746, orientation='minus', exon_count=20, OMIM=[610802], no_hdr0=''),
    84103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84103, CurrentID=0, Status='live', Symbol='C4orf17', Aliases=[], description='chromosome 4 open reading frame 17', other_designations='uncharacterized protein C4orf17', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99511004, end_position_on_the_genomic_accession=99542303, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    84105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84105, CurrentID=0, Status='live', Symbol='PCBD2', Aliases=['DCOH2', 'DCOHM', 'PHS2'], description='pterin-4 alpha-carbinolamine dehydratase 2', other_designations='pterin-4-alpha-carbinolamine dehydratase 2|4-alpha-hydroxy-tetrahydropterin dehydratase 2|6-pyruvoyl-tetrahydropterin synthase/dimerization cofactor of hepatocyte nuclear factor 1 alpha (TCF1) 2|DcoH-like protein DCoHm|HNF-1-alpha dimerization cofactor|PHS 2|dimerization cofactor of hepatocyte nuclear factor 1 (HNF1) from muscle|dimerization cofactor of hepatocyte nuclear factor 1 alpha (TCF1)|dimerization cofactor of hepatocyte nuclear factor 1 from muscle|pterin-4 alpha-carbinolamine dehydratase/dimerization cofactor of hepatocyte nuclear factor 1 alpha (TCF1) 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134905131, end_position_on_the_genomic_accession=134962644, orientation='plus', exon_count=4, OMIM=[609836], no_hdr0=''),
    84106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84106, CurrentID=0, Status='live', Symbol='PRAM1', Aliases=['PML-RAR', 'PRAM-1'], description='PML-RARA regulated adaptor molecule 1', other_designations='PML-RARA-regulated adapter molecule 1|PML-RARA target gene encoding an Adaptor Molecule-1|PRAM', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8490055, end_position_on_the_genomic_accession=8502640, orientation='minus', exon_count=10, OMIM=[606466], no_hdr0=''),
    84107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84107, CurrentID=0, Status='live', Symbol='ZIC4', Aliases=[], description='Zic family member 4', other_designations='zinc finger protein ZIC 4|zinc family member 4 protein HZIC4|zinc finger protein of the cerebellum 4', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=147386046, end_position_on_the_genomic_accession=147407476, orientation='minus', exon_count=9, OMIM=[608948], no_hdr0=''),
    84108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84108, CurrentID=0, Status='live', Symbol='PCGF6', Aliases=['MBLR', 'RNF134'], description='polycomb group ring finger 6', other_designations='polycomb group RING finger protein 6|Mel18 and Bmi1-like RING finger protein|ring finger protein 134', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103302796, end_position_on_the_genomic_accession=103351140, orientation='minus', exon_count=10, OMIM=[607816], no_hdr0=''),
    84109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84109, CurrentID=0, Status='live', Symbol='QRFPR', Aliases=['AQ27', 'GPR103', 'SP9155'], description='pyroglutamylated RFamide peptide receptor', other_designations='pyroglutamylated RF-amide peptide receptor|G-protein coupled receptor 103|QRFP receptor|orexigenic neuropeptide QRFP receptor|peptide P518 receptor', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121328642, end_position_on_the_genomic_accession=121381054, orientation='minus', exon_count=7, OMIM=[606925], no_hdr0=''),
    84124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84124, CurrentID=0, Status='live', Symbol='ZNF394', Aliases=['ZKSCAN14', 'ZSCAN46'], description='zinc finger protein 394', other_designations='zinc finger protein 394|zinc finger protein 99|zinc finger protein with KRAB and SCAN domains 14', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99486519, end_position_on_the_genomic_accession=99500281, orientation='minus', exon_count=4, OMIM=[619300], no_hdr0=''),
    84125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84125, CurrentID=0, Status='live', Symbol='LRRIQ1', Aliases=[], description='leucine rich repeats and IQ motif containing 1', other_designations='leucine-rich repeat and IQ domain-containing protein 1|testicular tissue protein Li 111', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85036351, end_position_on_the_genomic_accession=85273060, orientation='plus', exon_count=37, OMIM=[], no_hdr0=''),
    84126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84126, CurrentID=0, Status='live', Symbol='ATRIP', Aliases=[], description='ATR interacting protein', other_designations='ATR-interacting protein|ATM and Rad3-related-interacting protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48446737, end_position_on_the_genomic_accession=48467645, orientation='plus', exon_count=15, OMIM=[606605], no_hdr0=''),
    84128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84128, CurrentID=0, Status='live', Symbol='WDR75', Aliases=['NET16', 'UTP17'], description='WD repeat domain 75', other_designations='WD repeat-containing protein 75|U3 small nucleolar RNA-associated protein 17 homolog|UTP17, small subunit (SSU) processome component, homolog', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189441473, end_position_on_the_genomic_accession=189475556, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    84129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84129, CurrentID=0, Status='live', Symbol='ACAD11', Aliases=['ACAD-11'], description='acyl-CoA dehydrogenase family member 11', other_designations='acyl-CoA dehydrogenase family member 11|acyl-Coenzyme A dehydrogenase family, member 11', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=132558141, end_position_on_the_genomic_accession=132659809, orientation='minus', exon_count=20, OMIM=[614288], no_hdr0=''),
    84131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84131, CurrentID=0, Status='live', Symbol='CEP78', Aliases=['C9orf81', 'CRDHL', 'IP63'], description='centrosomal protein 78', other_designations='centrosomal protein of 78 kDa|centrosomal protein 78kDa', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=78236075, end_position_on_the_genomic_accession=78279690, orientation='plus', exon_count=17, OMIM=[617110], no_hdr0=''),
    84132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84132, CurrentID=0, Status='live', Symbol='USP42', Aliases=[], description='ubiquitin specific peptidase 42', other_designations='ubiquitin carboxyl-terminal hydrolase 42|deubiquitinating enzyme 42|ubiquitin specific protease 42|ubiquitin thioesterase 42|ubiquitin thiolesterase 42|ubiquitin-specific-processing protease 42', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6078743, end_position_on_the_genomic_accession=6161564, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    84133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84133, CurrentID=0, Status='live', Symbol='ZNRF3', Aliases=['BK747E2.3', 'RNF203'], description='zinc and ring finger 3', other_designations='E3 ubiquitin-protein ligase ZNRF3|CTA-292E10.6|RING finger protein 203|RING-type E3 ubiquitin transferase ZNRF3|novel C3HC4 type Zinc finger (ring finger)|zinc/RING finger protein 3', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=28800657, end_position_on_the_genomic_accession=29057488, orientation='plus', exon_count=16, OMIM=[612062], no_hdr0=''),
    84134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84134, CurrentID=0, Status='live', Symbol='TOMM40L', Aliases=['TOMM40B'], description='translocase of outer mitochondrial membrane 40 like', other_designations='mitochondrial import receptor subunit TOM40B|protein TOMM40-like|translocase of outer mitochondrial membrane 40 homolog-like', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161225943, end_position_on_the_genomic_accession=161230746, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84135, CurrentID=0, Status='live', Symbol='UTP15', Aliases=['NET21'], description='UTP15 small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 15 homolog|Src-associated protein SAW|UTP15 SSU processome component|UTP15, U3 small nucleolar ribonucleoprotein, homolog', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73565741, end_position_on_the_genomic_accession=73583380, orientation='plus', exon_count=13, OMIM=[616194], no_hdr0=''),
    84138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84138, CurrentID=0, Status='live', Symbol='SLC7A6OS', Aliases=['EPM12', 'Iwr1'], description='solute carrier family 7 member 6 opposite strand', other_designations='probable RNA polymerase II nuclear localization protein SLC7A6OS|ADAMS proteinase-related protein|protein SLC7A6OS|solute carrier family 7 member 6 opposite strand transcript', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68298034, end_position_on_the_genomic_accession=68310948, orientation='minus', exon_count=5, OMIM=[619192], no_hdr0=''),
    84140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84140, CurrentID=0, Status='live', Symbol='FAM161A', Aliases=['RP28'], description='FAM161 centrosomal protein A', other_designations='protein FAM161A|FAM161A, centrosomal protein|family with sequence similarity 161 member A|retinitis pigmentosa 28 (autosomal recessive)', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61800240, end_position_on_the_genomic_accession=61854126, orientation='minus', exon_count=11, OMIM=[613596], no_hdr0=''),
    84141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84141, CurrentID=0, Status='live', Symbol='EVA1A', Aliases=['FAM176A', 'TMEM166'], description='eva-1 homolog A, regulator of programmed cell death', other_designations='protein eva-1 homolog A|family with sequence similarity 176, member A|protein FAM176A|transmembrane protein 166', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=75492318, end_position_on_the_genomic_accession=75569719, orientation='minus', exon_count=7, OMIM=[618990], no_hdr0=''),
    84142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84142, CurrentID=0, Status='live', Symbol='ABRAXAS1', Aliases=['ABRA1', 'CCDC98', 'FAM175A'], description='abraxas 1, BRCA1 A complex subunit', other_designations='BRCA1-A complex subunit Abraxas 1|abraxas protein|coiled-coil domain containing 98|family with sequence similarity 175 member A', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83459517, end_position_on_the_genomic_accession=83485137, orientation='minus', exon_count=11, OMIM=[611143], no_hdr0=''),
    84144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84144, CurrentID=0, Status='live', Symbol='SYDE2', Aliases=[], description='synapse defective Rho GTPase homolog 2', other_designations='rho GTPase-activating protein SYDE2|protein syd-1 homolog 2|synapse defective 1, Rho GTPase, homolog 2|synapse defective protein 1 homolog 2', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85156381, end_position_on_the_genomic_accession=85201725, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    84146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84146, CurrentID=0, Status='live', Symbol='ZNF644', Aliases=['BM-005', 'MYP21', 'NatF', 'ZEP-2'], description='zinc finger protein 644', other_designations='zinc finger protein 644|zinc finger motif enhancer binding protein 2', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=90915304, end_position_on_the_genomic_accession=91022267, orientation='minus', exon_count=11, OMIM=[614159], no_hdr0=''),
    84148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84148, CurrentID=0, Status='live', Symbol='KAT8', Aliases=['LIGOWS', 'MOF', 'MYST1', 'ZC2HC8', 'hMOF'], description='lysine acetyltransferase 8', other_designations='histone acetyltransferase KAT8|K(lysine) acetyltransferase 8|MOZ, YBF2/SAS3, SAS2 and TIP60 protein 1|MYST histone acetyltransferase 1|MYST-1|histone acetyltransferase MYST1|ortholog of Drosophila males absent on the first (MOF)|probable histone acetyltransferase MYST1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31117664, end_position_on_the_genomic_accession=31131393, orientation='plus', exon_count=13, OMIM=[609912], no_hdr0=''),
    84152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84152, CurrentID=0, Status='live', Symbol='PPP1R1B', Aliases=['DARPP-32', 'DARPP32'], description='protein phosphatase 1 regulatory inhibitor subunit 1B', other_designations='protein phosphatase 1 regulatory subunit 1B|dopamine and cAMP-regulated neuronal phosphoprotein 32', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39626735, end_position_on_the_genomic_accession=39636625, orientation='plus', exon_count=9, OMIM=[604399], no_hdr0=''),
    84153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84153, CurrentID=0, Status='live', Symbol='RNASEH2C', Aliases=['AGS3', 'AYP1'], description='ribonuclease H2 subunit C', other_designations='ribonuclease H2 subunit C|RNase H1 small subunit|RNase H2 subunit C|aicardi-Goutieres syndrome 3 protein|ribonuclease HI subunit C', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65717673, end_position_on_the_genomic_accession=65720798, orientation='minus', exon_count=4, OMIM=[610330], no_hdr0=''),
    84154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84154, CurrentID=0, Status='live', Symbol='RPF2', Aliases=['BXDC1', 'bA397G5.4'], description='ribosome production factor 2 homolog', other_designations='ribosome production factor 2 homolog|brix domain containing 1|brix domain-containing protein 1|homolog of Rpf2|ribosomal processing factor 2 homolog|ribosome biogenesis protein RPF2 homolog', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110982038, end_position_on_the_genomic_accession=111028263, orientation='plus', exon_count=11, OMIM=[618471], no_hdr0=''),
    84159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84159, CurrentID=0, Status='live', Symbol='ARID5B', Aliases=['DESRT', 'MRF-2', 'MRF2'], description='AT-rich interaction domain 5B', other_designations='AT-rich interactive domain-containing protein 5B|ARID domain-containing protein 5B|AT-rich interactive domain 5B (MRF1-like)|MRF1-like protein|modulator recognition factor 2 (MRF2)', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=61901254, end_position_on_the_genomic_accession=62096944, orientation='plus', exon_count=12, OMIM=[608538], no_hdr0=''),
    84162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84162, CurrentID=0, Status='live', Symbol='KIAA1109', Aliases=['ALKKUCS', 'FSA', 'Tweek'], description='KIAA1109', other_designations='transmembrane protein KIAA1109|fragile site-associated protein', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122152331, end_position_on_the_genomic_accession=122362752, orientation='plus', exon_count=94, OMIM=[611565], no_hdr0=''),
    84163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84163, CurrentID=0, Status='live', Symbol='GTF2IRD2', Aliases=['FP630 alpha', 'GTF2IRD2A', 'GTF2IRD2'], description='GTF2I repeat domain containing 2', other_designations='general transcription factor II-I repeat domain-containing protein 2A|GTF2I repeat domain-containing protein 2, alpha|GTF2I repeat domain-containing protein 2A|general transcription factor II i repeat domain 2 alpha|transcription factor GTF2IRD2-alpha', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74796151, end_position_on_the_genomic_accession=74851605, orientation='minus', exon_count=17, OMIM=[608899], no_hdr0=''),
    84164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84164, CurrentID=0, Status='live', Symbol='ASCC2', Aliases=['ASC1p100', 'p100'], description='activating signal cointegrator 1 complex subunit 2', other_designations='activating signal cointegrator 1 complex subunit 2|ASC-1 complex subunit P100|trip4 complex subunit p100', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29788608, end_position_on_the_genomic_accession=29838282, orientation='minus', exon_count=24, OMIM=[614216], no_hdr0=''),
    84166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84166, CurrentID=0, Status='live', Symbol='NLRC5', Aliases=['CLR16.1', 'NOD27', 'NOD4'], description='NLR family CARD domain containing 5', other_designations='protein NLRC5|NOD-like receptor C5|caterpiller protein 16.1|nucleotide-binding oligomerization domain protein 4|nucleotide-binding oligomerization domain, leucine rich repeat and CARD domain containing 5|nucleotide-binding oligomerization domains 27', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56989557, end_position_on_the_genomic_accession=57083520, orientation='plus', exon_count=57, OMIM=[613537], no_hdr0=''),
    84167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84167, CurrentID=0, Status='live', Symbol='C19orf44', Aliases=[], description='chromosome 19 open reading frame 44', other_designations='uncharacterized protein C19orf44', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16496382, end_position_on_the_genomic_accession=16521369, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84168, CurrentID=0, Status='live', Symbol='ANTXR1', Aliases=['ATR', 'GAPO', 'TEM8'], description='ANTXR cell adhesion molecule 1', other_designations='anthrax toxin receptor 1|2310008J16Rik|2810405N18Rik|tumor endothelial marker 8', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69013144, end_position_on_the_genomic_accession=69249327, orientation='plus', exon_count=23, OMIM=[606410], no_hdr0=''),
    84171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84171, CurrentID=0, Status='live', Symbol='LOXL4', Aliases=['LOXC'], description='lysyl oxidase like 4', other_designations='lysyl oxidase homolog 4|lysyl oxidase related C|lysyl oxidase-like 4 pseudogene|lysyl oxidase-like protein 4|lysyl oxidase-related protein C', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=98247690, end_position_on_the_genomic_accession=98268221, orientation='minus', exon_count=17, OMIM=[607318], no_hdr0=''),
    84172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84172, CurrentID=0, Status='live', Symbol='POLR1B', Aliases=['A135', 'RPA135', 'RPA2', 'Rpo1-2', 'TCS4'], description='RNA polymerase I subunit B', other_designations='DNA-directed RNA polymerase I subunit RPA2|DNA-directed RNA polymerase I 135 kDa polypeptide|DNA-directed RNA polymerase I 135kDa polypeptide|RNA polymerase I subunit 2|polymerase (RNA) I polypeptide B, 128kDa|polymerase (RNA) I subunit B', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112542036, end_position_on_the_genomic_accession=112579818, orientation='plus', exon_count=18, OMIM=[602000], no_hdr0=''),
    84173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84173, CurrentID=0, Status='live', Symbol='ELMOD3', Aliases=['DFNB88', 'LST3', 'RBED1', 'RBM29'], description='ELMO domain containing 3', other_designations='ELMO domain-containing protein 3|ELMO/CED-12 domain containing 3|RNA binding motif and ELMO/CED-12 domain 1|RNA-binding motif and ELMO domain-containing protein 1|RNA-binding motif protein 29|deafness, autosomal recessive 88|liver-specific organic anion transporter 3TM12|organic anion transporter LST-3b', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85354394, end_position_on_the_genomic_accession=85391752, orientation='plus', exon_count=16, OMIM=[615427], no_hdr0=''),
    84174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84174, CurrentID=0, Status='live', Symbol='SLA2', Aliases=['C20orf156', 'MARS', 'SLAP-2', 'SLAP2'], description='Src like adaptor 2', other_designations='src-like-adapter 2|Src-like adapter protein-2|modulator of antigen receptor signaling', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36612318, end_position_on_the_genomic_accession=36646207, orientation='minus', exon_count=9, OMIM=[606577], no_hdr0=''),
    84179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84179, CurrentID=0, Status='live', Symbol='SLC49A3', Aliases=['LP2561', 'MFSD7'], description='solute carrier family 49 member 3', other_designations='solute carrier family 49 member A3|MYL5|major facilitator superfamily domain containing 7|major facilitator superfamily domain-containing protein 7|myosin light polypeptide 5 regulatory protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=676205, end_position_on_the_genomic_accession=690748, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    84181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84181, CurrentID=0, Status='live', Symbol='CHD6', Aliases=['CHD-6', 'CHD5', 'RIGB'], description='chromodomain helicase DNA binding protein 6', other_designations='chromodomain-helicase-DNA-binding protein 6|ATP-dependent helicase CHD6|helicase C-terminal domain- and SNF2 N-terminal domain-containing protein|radiation-induced gene B protein', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41402083, end_position_on_the_genomic_accession=41618377, orientation='minus', exon_count=43, OMIM=[616114], no_hdr0=''),
    84182 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84182, CurrentID=0, Status='live', Symbol='MINDY4', Aliases=['AQP-1', 'AQP1', 'C7orf67', 'CHIP28', 'FAM188B'], description='MINDY lysine 48 deubiquitinase 4', other_designations='probable ubiquitin carboxyl-terminal hydrolase MINDY-4|Aquaporin-1|Aquaporin-CHIP|MINDY deubiquitinase 4|Urine water channel|Water channel protein for red blood cells and kidney proximal tubule|family with sequence similarity 188 member B|probable deubiquitinating enzyme MINDY-4|probable ubiquitin carboxyl-terminal hydrolase FAM188B|protein FAM188B', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30771417, end_position_on_the_genomic_accession=30892387, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    84186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84186, CurrentID=0, Status='live', Symbol='ZCCHC7', Aliases=['AIR1', 'HSPC086'], description='zinc finger CCHC-type containing 7', other_designations='zinc finger CCHC domain-containing protein 7|TRAMP-like complex RNA-binding factor ZCCHC7|zinc finger, CCHC domain containing 7', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37120166, end_position_on_the_genomic_accession=37358149, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    84187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84187, CurrentID=0, Status='live', Symbol='TMEM164', Aliases=['bB360B22.3'], description='transmembrane protein 164', other_designations='transmembrane protein 164|RP13-360B22.2', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=110002413, end_position_on_the_genomic_accession=110184251, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    84188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84188, CurrentID=0, Status='live', Symbol='FAR1', Aliases=['CSPSD', 'MLSTD2', 'PFCRD', 'SDR10E1'], description='fatty acyl-CoA reductase 1', other_designations='fatty acyl-CoA reductase 1|male sterility domain-containing protein 2|short chain dehydrogenase/reductase family 10E, member 1', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13668666, end_position_on_the_genomic_accession=13732346, orientation='plus', exon_count=12, OMIM=[616107], no_hdr0=''),
    84189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84189, CurrentID=0, Status='live', Symbol='SLITRK6', Aliases=['DFNMYP'], description='SLIT and NTRK like family member 6', other_designations='SLIT and NTRK-like protein 6|4832410J21Rik|slit and trk like gene 6', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=85792790, end_position_on_the_genomic_accession=85799419, orientation='minus', exon_count=2, OMIM=[609681], no_hdr0=''),
    84190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84190, CurrentID=0, Status='live', Symbol='METTL25', Aliases=['C12orf26'], description='methyltransferase like 25', other_designations='methyltransferase-like protein 25', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=82358417, end_position_on_the_genomic_accession=82479239, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    84191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84191, CurrentID=0, Status='live', Symbol='CIAO2A', Aliases=['CIA2A', 'FAM96A'], description='cytosolic iron-sulfur assembly component 2A', other_designations='cytosolic iron-sulfur assembly component 2A|MIP18 family protein FAM96A|family with sequence similarity 96 member A', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64072565, end_position_on_the_genomic_accession=64093838, orientation='minus', exon_count=6, OMIM=[618382], no_hdr0=''),
    84193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84193, CurrentID=0, Status='live', Symbol='SETD3', Aliases=['C14orf154', 'hSETD3'], description='SET domain containing 3, actin histidine methyltransferase', other_designations='actin-histidine N-methyltransferase|SET domain-containing protein 3|histone-lysine N-methyltransferase setd3|protein-L-histidine N-tele-methyltransferase', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99397746, end_position_on_the_genomic_accession=99486458, orientation='minus', exon_count=19, OMIM=[615671], no_hdr0=''),
    84196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84196, CurrentID=0, Status='live', Symbol='USP48', Aliases=['RAP1GA1', 'USP31'], description='ubiquitin specific peptidase 48', other_designations='ubiquitin carboxyl-terminal hydrolase 48|deubiquitinating enzyme 48|ubiquitin specific protease 31|ubiquitin thioesterase 48|ubiquitin thiolesterase 48|ubiquitin-specific-processing protease 48', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21678298, end_position_on_the_genomic_accession=21784146, orientation='minus', exon_count=30, OMIM=[617445], no_hdr0=''),
    84197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84197, CurrentID=0, Status='live', Symbol='POMK', Aliases=['MDDGA12', 'MDDGC12', 'SGK196'], description='protein O-mannose kinase', other_designations='protein O-mannose kinase|Sugen kinase 196|probable inactive protein kinase-like protein SgK196|protein kinase-like protein SgK196', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=43093515, end_position_on_the_genomic_accession=43123434, orientation='plus', exon_count=5, OMIM=[615247], no_hdr0=''),
    84203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84203, CurrentID=0, Status='live', Symbol='TXNDC2', Aliases=['SPTRX', 'SPTRX1'], description='thioredoxin domain containing 2', other_designations='thioredoxin domain-containing protein 2|sperm-specific thioredoxin 1|spermatid-specific thioredoxin-1|sptrx-1|testicular tissue protein Li 215|thioredoxin domain containing 2 (spermatozoa)', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=9885973, end_position_on_the_genomic_accession=9889275, orientation='plus', exon_count=2, OMIM=[617790], no_hdr0=''),
    84206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84206, CurrentID=0, Status='live', Symbol='MEX3B', Aliases=['MEX-3B', 'RKHD3', 'RNF195'], description='mex-3 RNA binding family member B', other_designations='RNA-binding protein MEX3B|RING finger protein 195|ring finger and KH domain containing 3', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82041778, end_position_on_the_genomic_accession=82046018, orientation='minus', exon_count=2, OMIM=[611008], no_hdr0=''),
    84210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84210, CurrentID=0, Status='live', Symbol='ANKRD20A1', Aliases=['ANKRD20A'], description='ankyrin repeat domain 20 family member A1', other_designations='ankyrin repeat domain-containing protein 20A1|ankyrin repeat domain 20A|epididymis secretory sperm binding protein', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=67858931, end_position_on_the_genomic_accession=67902394, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    84215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84215, CurrentID=0, Status='live', Symbol='ZNF541', Aliases=[], description='zinc finger protein 541', other_designations='zinc finger protein 541', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47520685, end_position_on_the_genomic_accession=47573248, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    84216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84216, CurrentID=0, Status='live', Symbol='TMEM117', Aliases=[], description='transmembrane protein 117', other_designations='transmembrane protein 117', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=43795763, end_position_on_the_genomic_accession=44389758, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    84217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84217, CurrentID=0, Status='live', Symbol='ZMYND12', Aliases=[], description='zinc finger MYND-type containing 12', other_designations='zinc finger MYND domain-containing protein 12|zinc finger, MYND domain containing 12', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42430329, end_position_on_the_genomic_accession=42456022, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    84218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84218, CurrentID=0, Status='live', Symbol='TBC1D3F', Aliases=['TBC1D3', 'TBC1D3G'], description='TBC1 domain family member 3F', other_designations='TBC1 domain family member 3F|TBC1 domain family member 3|TBC1 domain family member 3G|prostate cancer gene 17 protein|protein TRE17-alpha', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36428612, end_position_on_the_genomic_accession=36439521, orientation='minus', exon_count=14, OMIM=[610809], no_hdr0=''),
    84219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84219, CurrentID=0, Status='live', Symbol='WDR24', Aliases=['C16orf21', 'JFP7'], description='WD repeat domain 24', other_designations='GATOR complex protein WDR24|WD repeat-containing protein 24', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=684622, end_position_on_the_genomic_accession=690661, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    84220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84220, CurrentID=0, Status='live', Symbol='RGPD5', Aliases=['BS-63', 'BS63', 'HEL161', 'RGP5'], description='RANBP2 like and GRIP domain containing 5', other_designations='RANBP2-like and GRIP domain-containing protein 5/6|RANBP2-like and GRIP domain-containing protein 5|epididymis luminal protein 161|ran-binding protein 2-like 1|ran-binding protein 2-like 1/2|ranBP2-like 1|ranBP2-like 1/2|ranBP2L1|sperm membrane protein BS-63', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109760594, end_position_on_the_genomic_accession=109857705, orientation='plus', exon_count=28, OMIM=[612708], no_hdr0=''),
    84221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84221, CurrentID=0, Status='live', Symbol='SPATC1L', Aliases=['C21orf56'], description='spermatogenesis and centriole associated 1 like', other_designations='speriolin-like protein|spermatogenesis and centriole-associated protein 1-like protein', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=46161148, end_position_on_the_genomic_accession=46185163, orientation='minus', exon_count=6, OMIM=[612412], no_hdr0=''),
    84223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84223, CurrentID=0, Status='live', Symbol='IQCG', Aliases=['CFAP122', 'DRC9'], description='IQ motif containing G', other_designations='dynein regulatory complex protein 9|IQ domain-containing protein G|dynein regulatory complex subunit 9', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197889077, end_position_on_the_genomic_accession=197960111, orientation='minus', exon_count=15, OMIM=[612477], no_hdr0=''),
    84224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84224, CurrentID=0, Status='live', Symbol='NBPF3', Aliases=['AE2'], description='NBPF member 3', other_designations='neuroblastoma breakpoint family member 3|protein SHIIIa4', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21436775, end_position_on_the_genomic_accession=21484900, orientation='plus', exon_count=21, OMIM=[612992], no_hdr0=''),
    84225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84225, CurrentID=0, Status='live', Symbol='ZMYND15', Aliases=['SPGF14'], description='zinc finger MYND-type containing 15', other_designations='zinc finger MYND domain-containing protein 15', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4739833, end_position_on_the_genomic_accession=4746119, orientation='plus', exon_count=14, OMIM=[614312], no_hdr0=''),
    84226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84226, CurrentID=0, Status='live', Symbol='C2orf16', Aliases=[], description='chromosome 2 open reading frame 16', other_designations='uncharacterized protein C2orf16|P-S-E-R-S-H-H-S repeats containing', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27576522, end_position_on_the_genomic_accession=27582722, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    84229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84229, CurrentID=0, Status='live', Symbol='DRC7', Aliases=['C16orf50', 'CCDC135', 'CFAP50', 'FAP50'], description='dynein regulatory complex subunit 7', other_designations='dynein regulatory complex subunit 7|coiled-coil domain containing 135|coiled-coil domain-containing protein 135|coiled-coil domain-containing protein lobo homolog', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57694806, end_position_on_the_genomic_accession=57731805, orientation='plus', exon_count=19, OMIM=[618769], no_hdr0=''),
    84230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84230, CurrentID=0, Status='live', Symbol='LRRC8C', Aliases=['AD158', 'FAD158'], description='leucine rich repeat containing 8 VRAC subunit C', other_designations='volume-regulated anion channel subunit LRRC8C|factor for adipocyte differentiation 158|hypothetical protein AD158|leucine rich repeat containing 8 family member C|leucine rich repeat containing 8C|leucine-rich repeat-containing protein 8C', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89615810, end_position_on_the_genomic_accession=89719533, orientation='plus', exon_count=6, OMIM=[612889], no_hdr0=''),
    84231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84231, CurrentID=0, Status='live', Symbol='TRAF7', Aliases=['CAFDADD', 'RFWD1', 'RNF119'], description='TNF receptor associated factor 7', other_designations='E3 ubiquitin-protein ligase TRAF7|RING finger and WD repeat-containing protein 1|RING finger protein 119|RING-type E3 ubiquitin transferase TRAF7|TNF receptor-associated factor 7, E3 ubiquitin protein ligase|ring finger and WD repeat domain 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2155778, end_position_on_the_genomic_accession=2178129, orientation='plus', exon_count=21, OMIM=[606692], no_hdr0=''),
    84232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84232, CurrentID=0, Status='live', Symbol='MAF1', Aliases=[], description='MAF1 homolog, negative regulator of RNA polymerase III', other_designations='repressor of RNA polymerase III transcription MAF1 homolog|MAF1 negative regulator of RNA polymerase III|homolog of yeast MAF1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144104461, end_position_on_the_genomic_accession=144107611, orientation='plus', exon_count=8, OMIM=[610210], no_hdr0=''),
    84233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84233, CurrentID=0, Status='live', Symbol='TMEM126A', Aliases=['OPA7'], description='transmembrane protein 126A', other_designations='transmembrane protein 126A', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85647967, end_position_on_the_genomic_accession=85656542, orientation='plus', exon_count=5, OMIM=[612988], no_hdr0=''),
    84236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84236, CurrentID=0, Status='live', Symbol='RHBDD1', Aliases=['RHBDL4', 'RRP4'], description='rhomboid domain containing 1', other_designations='rhomboid-related protein 4|rhomboid domain-containing protein 1|rhomboid-like protein 4', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=226800159, end_position_on_the_genomic_accession=226999210, orientation='plus', exon_count=15, OMIM=[617515], no_hdr0=''),
    84239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84239, CurrentID=0, Status='live', Symbol='ATP13A4', Aliases=[], description='ATPase 13A4', other_designations='probable cation-transporting ATPase 13A4|ATPase type 13A4|P5-ATPase|cation-transporting P5-ATPase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=193398967, end_position_on_the_genomic_accession=193593114, orientation='minus', exon_count=33, OMIM=[609556], no_hdr0=''),
    84240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84240, CurrentID=0, Status='live', Symbol='ZCCHC9', Aliases=['PPP1R41'], description='zinc finger CCHC-type containing 9', other_designations='zinc finger CCHC domain-containing protein 9|protein phosphatase 1, regulatory subunit 41|zinc finger, CCHC domain containing 9', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=81301587, end_position_on_the_genomic_accession=81313297, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    84243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84243, CurrentID=0, Status='live', Symbol='ZDHHC18', Aliases=['DHHC-18', 'DHHC18'], description='zinc finger DHHC-type palmitoyltransferase 18', other_designations='palmitoyltransferase ZDHHC18|DHHC domain-containing cysteine-rich protein 18|zinc finger DHHC domain-containing protein 18|zinc finger DHHC-type containing 18|zinc finger, DHHC domain containing 18', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26826688, end_position_on_the_genomic_accession=26857604, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84245, CurrentID=0, Status='live', Symbol='MRI1', Aliases=['M1Pi', 'MRDI', 'MTNA', 'Ypr118w'], description='methylthioribose-1-phosphate isomerase 1', other_designations='methylthioribose-1-phosphate isomerase|MTR-1-P isomerase|S-methyl-5-thioribose-1-phosphate isomerase 1|mediator of RhoA-dependent invasion|methylthioribose-1-phosphate isomerase homolog|translation initiation factor eIF-2B subunit alpha/beta/delta-like protein', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13764492, end_position_on_the_genomic_accession=13774282, orientation='plus', exon_count=7, OMIM=[615105], no_hdr0=''),
    84246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84246, CurrentID=0, Status='live', Symbol='MED10', Aliases=['L6', 'NUT2', 'TRG20'], description='mediator complex subunit 10', other_designations='mediator of RNA polymerase II transcription subunit 10|TRG-17|TRG-20|transformation-related gene 17 protein|transformation-related gene 20 protein', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=6371874, end_position_on_the_genomic_accession=6378547, orientation='minus', exon_count=4, OMIM=[612382], no_hdr0=''),
    84247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84247, CurrentID=0, Status='live', Symbol='RTL6', Aliases=['LDOC1L', 'Mar6', 'Mart6', 'SIRH3', 'dJ1033E15.2'], description='retrotransposon Gag like 6', other_designations='retrotransposon Gag-like protein 6|LDOC1 like|Sushi-Ichi retrotransposon homolog 3|leucine zipper down-regulated in cancer 1 like|leucine zipper protein down-regulated in cancer cells-like|mammalian retrotransposon-derived 6|mammalian retrotransposon-derived protein 6|protein LDOC1L', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44492583, end_position_on_the_genomic_accession=44498233, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    84248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84248, CurrentID=0, Status='live', Symbol='FYTTD1', Aliases=['UIF'], description='forty-two-three domain containing 1', other_designations='UAP56-interacting factor|forty-two-three domain-containing protein 1|protein 40-2-3', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197749533, end_position_on_the_genomic_accession=197787596, orientation='plus', exon_count=12, OMIM=[616933], no_hdr0=''),
    84249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84249, CurrentID=0, Status='live', Symbol='PSD2', Aliases=['EFA6C'], description='pleckstrin and Sec7 domain containing 2', other_designations='PH and SEC7 domain-containing protein 2|exchange factor for ADP-ribosylation factor guanine nucleotide factor 6 C|exchange factor for ARF6 C|pleckstrin homology and SEC7 domain-containing protein 2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139711263, end_position_on_the_genomic_accession=139844466, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    84250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84250, CurrentID=0, Status='live', Symbol='SLF1', Aliases=['ANKRD32', 'BRCTD1', 'BRCTx'], description='SMC5-SMC6 complex localization factor 1', other_designations='SMC5-SMC6 complex localization factor protein 1|BRCT domain containing 1|BRCT domain-containing protein 1|ankyrin repeat domain 32|ankyrin repeat domain-containing protein 32|smc5/6 localization factor 1', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=94613476, end_position_on_the_genomic_accession=94714918, orientation='plus', exon_count=28, OMIM=[618467], no_hdr0=''),
    84251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84251, CurrentID=0, Status='live', Symbol='SGIP1', Aliases=[], description='SH3GL interacting endocytic adaptor 1', other_designations='SH3-containing GRB2-like protein 3-interacting protein 1|SH3 domain GRB2 like endophilin interacting protein 1|endophilin-3-interacting protein', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66533361, end_position_on_the_genomic_accession=66751139, orientation='plus', exon_count=30, OMIM=[611540], no_hdr0=''),
    84253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84253, CurrentID=0, Status='live', Symbol='GARNL3', Aliases=['bA356B19.1'], description='GTPase activating Rap/RanGAP domain like 3', other_designations='GTPase-activating Rap/Ran-GAP domain-like protein 3|GTPase activating RANGAP domain-like 3', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127224471, end_position_on_the_genomic_accession=127393660, orientation='plus', exon_count=36, OMIM=[], no_hdr0=''),
    84254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84254, CurrentID=0, Status='live', Symbol='CAMKK1', Aliases=['CAMKKA'], description='calcium/calmodulin dependent protein kinase kinase 1', other_designations='calcium/calmodulin-dependent protein kinase kinase 1|CAMKK alpha protein|caM-KK 1|caM-KK alpha|caM-kinase IV kinase|caM-kinase kinase 1|caM-kinase kinase alpha|caMKK 1|calcium/calmodulin-dependent protein kinase kinase 1, alpha|calcium/calmodulin-dependent protein kinase kinase alpha', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3860315, end_position_on_the_genomic_accession=3895633, orientation='minus', exon_count=19, OMIM=[611411], no_hdr0=''),
    84255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84255, CurrentID=0, Status='live', Symbol='SLC37A3', Aliases=['SPX3'], description='solute carrier family 37 member 3', other_designations='sugar phosphate exchanger 3|solute carrier family 37 (glycerol-3-phosphate transporter), member 3', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140333752, end_position_on_the_genomic_accession=140398530, orientation='minus', exon_count=15, OMIM=[619137], no_hdr0=''),
    84256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84256, CurrentID=0, Status='live', Symbol='FLYWCH1', Aliases=[], description='FLYWCH-type zinc finger 1', other_designations='FLYWCH-type zinc finger-containing protein 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2911873, end_position_on_the_genomic_accession=2951208, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    84258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84258, CurrentID=0, Status='live', Symbol='SYT3', Aliases=['SytIII'], description='synaptotagmin 3', other_designations='synaptotagmin-3|synaptotagmin III', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50621977, end_position_on_the_genomic_accession=50639881, orientation='minus', exon_count=11, OMIM=[600327], no_hdr0=''),
    84259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84259, CurrentID=0, Status='live', Symbol='DCUN1D5', Aliases=['DCNL5', 'SCCRO5'], description='defective in cullin neddylation 1 domain containing 5', other_designations='DCN1-like protein 5|DCN1, defective in cullin neddylation 1, domain containing 5|DCUN1 domain-containing protein 5|defective in cullin neddylation protein 1-like protein 5|squamous cell carcinoma-related oncogene 5', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=103050686, end_position_on_the_genomic_accession=103092215, orientation='minus', exon_count=9, OMIM=[616522], no_hdr0=''),
    84260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84260, CurrentID=0, Status='live', Symbol='TCHP', Aliases=['TpMs'], description='trichoplein keratin filament binding', other_designations='trichoplein keratin filament-binding protein|mitochondrial protein with oncostatic activity|mitostatin|tumor suppressor protein', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109880667, end_position_on_the_genomic_accession=109918069, orientation='plus', exon_count=15, OMIM=[612654], no_hdr0=''),
    84261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84261, CurrentID=0, Status='live', Symbol='FBXW9', Aliases=['Fbw9', 'MEC-15'], description='F-box and WD repeat domain containing 9', other_designations='F-box/WD repeat-containing protein 9|F-box and WD-40 domain protein 9|F-box and WD-40 domain-containing protein 9|F-box and WD-40 repeat containing protein 9|specificity factor for SCF ubiquitin ligase', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12688916, end_position_on_the_genomic_accession=12696900, orientation='minus', exon_count=10, OMIM=[609074], no_hdr0=''),
    84262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84262, CurrentID=0, Status='live', Symbol='PSMG3', Aliases=['C7orf48', 'PAC3'], description='proteasome assembly chaperone 3', other_designations='proteasome assembly chaperone 3|PAC-3|hPAC3|proteasome (prosome, macropain) assembly chaperone 3|proteasome assembling chaperone 3', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1567332, end_position_on_the_genomic_accession=1570032, orientation='minus', exon_count=3, OMIM=[617528], no_hdr0=''),
    84263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84263, CurrentID=0, Status='live', Symbol='HSDL2', Aliases=['C9orf99', 'SDR13C1'], description='hydroxysteroid dehydrogenase like 2', other_designations='hydroxysteroid dehydrogenase-like protein 2|short chain dehydrogenase/reductase family 13C member 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112380052, end_position_on_the_genomic_accession=112472410, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    84264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84264, CurrentID=0, Status='live', Symbol='HAGHL', Aliases=[], description='hydroxyacylglutathione hydrolase like', other_designations='hydroxyacylglutathione hydrolase-like protein|GLO2-like/ RJD12', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=726999, end_position_on_the_genomic_accession=729715, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84265, CurrentID=0, Status='live', Symbol='POLR3GL', Aliases=['RPC32HOM', 'SOFM', 'flj32422'], description='RNA polymerase III subunit GL', other_designations='DNA-directed RNA polymerase III subunit RPC7-like|DNA-directed RNA polymerase III subunit G-like|RNA polymerase III 32 kDa beta subunit|RNA polymerase III subunit C7-like|RNA polymerase III subunit G like|RPC32-beta|RPC32-like protein|alternative RNA polymerase III subunit 32|polymerase (RNA) III (DNA directed) polypeptide G (32kD)-like|polymerase (RNA) III subunit G like', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145959037, end_position_on_the_genomic_accession=145978848, orientation='plus', exon_count=9, OMIM=[617457], no_hdr0=''),
    84266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84266, CurrentID=0, Status='live', Symbol='ALKBH7', Aliases=['ABH7', 'SPATA11', 'UNQ6002'], description='alkB homolog 7', other_designations='alpha-ketoglutarate-dependent dioxygenase alkB homolog 7, mitochondrial|alkB, alkylation repair homolog 7|alkylated DNA repair protein alkB homolog 7|probable alpha-ketoglutarate-dependent dioxygenase ABH7|spermatogenesis associated 11|spermatogenesis cell proliferation related protein|spermatogenesis-associated protein 11', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6372794, end_position_on_the_genomic_accession=6375250, orientation='plus', exon_count=5, OMIM=[613305], no_hdr0=''),
    84267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84267, CurrentID=0, Status='live', Symbol='C9orf64', Aliases=[], description='chromosome 9 open reading frame 64', other_designations='queuosine salvage protein|UPF0553 protein C9orf64', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83938311, end_position_on_the_genomic_accession=83956986, orientation='minus', exon_count=6, OMIM=[611342], no_hdr0=''),
    84268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84268, CurrentID=0, Status='live', Symbol='RPAIN', Aliases=['HRIP', 'RIP'], description='RPA interacting protein', other_designations='RPA-interacting protein|RAP interaction protein|nuclear transporter', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5420167, end_position_on_the_genomic_accession=5432879, orientation='plus', exon_count=7, OMIM=[617299], no_hdr0=''),
    84269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84269, CurrentID=0, Status='live', Symbol='CHCHD5', Aliases=['C2orf9', 'CHTM1', 'MIC14', 'MIX14'], description='coiled-coil-helix-coiled-coil-helix domain containing 5', other_designations='coiled-coil-helix-coiled-coil-helix domain-containing protein 5|mitochondrial intermembrane space cysteine motif protein of 14 kDa homolog', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112584447, end_position_on_the_genomic_accession=112589040, orientation='plus', exon_count=6, OMIM=[616978], no_hdr0=''),
    84270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84270, CurrentID=0, Status='live', Symbol='CARD19', Aliases=['BinCARD', 'C9orf89'], description='caspase recruitment domain family member 19', other_designations='caspase recruitment domain-containing protein 19|Bcl10-interacting protein with CARD|bcl10-interacting CARD protein', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93096217, end_position_on_the_genomic_accession=93113283, orientation='plus', exon_count=7, OMIM=[617726], no_hdr0=''),
    84271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84271, CurrentID=0, Status='live', Symbol='POLDIP3', Aliases=['PDIP3', 'PDIP46', 'SKAR'], description='DNA polymerase delta interacting protein 3', other_designations='polymerase delta-interacting protein 3|46 kDa DNA polymerase delta interaction protein|RNA-binding protein P46|S6K1 Aly/REF-like target|polymerase (DNA) delta interacting protein 3|polymerase (DNA-directed), delta interacting protein 3', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42583721, end_position_on_the_genomic_accession=42614918, orientation='minus', exon_count=10, OMIM=[611520], no_hdr0=''),
    84272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84272, CurrentID=0, Status='live', Symbol='YIPF4', Aliases=['FinGER4', 'Nbla11189'], description='Yip1 domain family member 4', other_designations='protein YIPF4|YIP1 family member 4|putative protein product of Nbla11189', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32277904, end_position_on_the_genomic_accession=32316594, orientation='plus', exon_count=6, OMIM=[617534], no_hdr0=''),
    84273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84273, CurrentID=0, Status='live', Symbol='NOA1', Aliases=['C4orf14', 'MTG3', 'hAtNOS1', 'hNOA1', 'mAtNOS1'], description='nitric oxide associated 1', other_designations='nitric oxide-associated protein 1|mitochondrial GTPase 3 homolog|nitric oxide synthase, mitochondrial (putative)|putative ortholog of Arabidopsis mitochondrial nitric oxide synthase', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56963350, end_position_on_the_genomic_accession=56977606, orientation='minus', exon_count=7, OMIM=[614919], no_hdr0=''),
    84274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84274, CurrentID=0, Status='live', Symbol='COQ5', Aliases=['COQ10D9'], description='coenzyme Q5, methyltransferase', other_designations='2-methoxy-6-polyprenyl-1,4-benzoquinol methylase, mitochondrial|coenzyme Q5 homolog, methyltransferase|ubiquinone biosynthesis methyltransferase COQ5, mitochondrial', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120503279, end_position_on_the_genomic_accession=120534613, orientation='minus', exon_count=9, OMIM=[616359], no_hdr0=''),
    84275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84275, CurrentID=0, Status='live', Symbol='SLC25A33', Aliases=['BMSC-MCP', 'PNC1'], description='solute carrier family 25 member 33', other_designations='solute carrier family 25 member 33|bone marrow stromal cell mitochondrial carrier protein|huBMSC-MCP|mitochondrial carrier protein|novel mitochondrial carrier protein|solute carrier family 25 (pyrimidine nucleotide carrier), member 33', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9539465, end_position_on_the_genomic_accession=9585173, orientation='plus', exon_count=7, OMIM=[610816], no_hdr0=''),
    84276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84276, CurrentID=0, Status='live', Symbol='NICN1', Aliases=[], description='nicolin 1', other_designations='nicolin-1|NPCEDRG|PGs5|tubulin polyglutamylase complex subunit 5', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49422333, end_position_on_the_genomic_accession=49429324, orientation='minus', exon_count=6, OMIM=[611516], no_hdr0=''),
    84277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84277, CurrentID=0, Status='live', Symbol='DNAJC30', Aliases=['LHONAR', 'MC1DN38', 'WBSCR18'], description='DnaJ heat shock protein family (Hsp40) member C30', other_designations='dnaJ homolog subfamily C member 30, mitochondrial|DnaJ (Hsp40) homolog, subfamily C, member 30|Williams Beuren syndrome chromosome region 18|williams-Beuren syndrome chromosomal region 18 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73680918, end_position_on_the_genomic_accession=73683453, orientation='minus', exon_count=1, OMIM=[618202], no_hdr0=''),
    84278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84278, CurrentID=0, Status='live', Symbol='MFSD14C', Aliases=['HIATL2'], description='major facilitator superfamily domain containing 14C', other_designations='hippocampus abundant transcript-like protein 2|hippocampus abundant gene transcript-like 2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96917928, end_position_on_the_genomic_accession=97013704, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84279, CurrentID=0, Status='live', Symbol='PRADC1', Aliases=['C2orf7', 'PAP21'], description='protease associated domain containing 1', other_designations='protease-associated domain-containing protein 1|protease-associated domain-containing glycoprotein 21 kDa|protease-associated domain-containing protein of 21 kDa', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73228006, end_position_on_the_genomic_accession=73233284, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    84280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84280, CurrentID=0, Status='live', Symbol='BTBD10', Aliases=['GMRP-1', 'GMRP1'], description='BTB domain containing 10', other_designations='BTB/POZ domain-containing protein 10|BTB (POZ) domain containing 10|BTB (broad-complex tramtrack and bric-a-brac/pox virus and zinc finger) domain-containing protein 10|K+ channel tetramerization protein|epididymis secretory sperm binding protein|glucose metabolism-related protein 1', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13388008, end_position_on_the_genomic_accession=13463292, orientation='minus', exon_count=12, OMIM=[615933], no_hdr0=''),
    84281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84281, CurrentID=0, Status='live', Symbol='C2orf88', Aliases=['smAKAP'], description='chromosome 2 open reading frame 88', other_designations='small membrane A-kinase anchor protein|small A-kinase anchoring protein|small membrane AKAP', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189879479, end_position_on_the_genomic_accession=190203484, orientation='plus', exon_count=12, OMIM=[615117], no_hdr0=''),
    84282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84282, CurrentID=0, Status='live', Symbol='RNF135', Aliases=['L13', 'MMFD', 'REUL', 'Riplet'], description='ring finger protein 135', other_designations='E3 ubiquitin-protein ligase RNF135|RIG-I E3 ubiquitin ligase|RING finger protein leading to RIG-I activation|RING-type E3 ubiquitin transferase RNF135', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30968642, end_position_on_the_genomic_accession=30999911, orientation='plus', exon_count=8, OMIM=[611358], no_hdr0=''),
    84283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84283, CurrentID=0, Status='live', Symbol='TMEM79', Aliases=['MATT'], description='transmembrane protein 79', other_designations='transmembrane protein 79|mattrin', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156282932, end_position_on_the_genomic_accession=156292443, orientation='plus', exon_count=5, OMIM=[615531], no_hdr0=''),
    84284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84284, CurrentID=0, Status='live', Symbol='NTPCR', Aliases=['C1orf57', 'HCR-NTPase', 'THEP1'], description='nucleoside-triphosphatase, cancer-related', other_designations='cancer-related nucleoside-triphosphatase|human cancer-related NTPase|nucleoside triphosphate phosphohydrolase|nucleoside-triphosphatase C1orf57', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=232950611, end_position_on_the_genomic_accession=232983882, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    84285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84285, CurrentID=0, Status='live', Symbol='EIF1AD', Aliases=['OBELIX', 'haponin'], description='eukaryotic translation initiation factor 1A domain containing', other_designations='probable RNA-binding protein EIF1AD|eukaryotic translation initiation factor 1A domain-containing protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65996545, end_position_on_the_genomic_accession=66002217, orientation='minus', exon_count=6, OMIM=[618473], no_hdr0=''),
    84286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84286, CurrentID=0, Status='live', Symbol='TMEM175', Aliases=['hTMEM175'], description='transmembrane protein 175', other_designations='endosomal/lysosomal potassium channel TMEM175|endosomal/lysomomal potassium channel TMEM175', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=932412, end_position_on_the_genomic_accession=958656, orientation='plus', exon_count=15, OMIM=[616660], no_hdr0=''),
    84287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84287, CurrentID=0, Status='live', Symbol='ZDHHC16', Aliases=['APH2', 'DHHC-16'], description='zinc finger DHHC-type palmitoyltransferase 16', other_designations='palmitoyltransferase ZDHHC16|Abl-philin 2|probable palmitoyltransferase ZDHHC16|zinc finger DHHC domain-containing protein 16|zinc finger DHHC-type containing 16|zinc finger, DHHC domain containing 16', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97446143, end_position_on_the_genomic_accession=97457370, orientation='plus', exon_count=12, OMIM=[616750], no_hdr0=''),
    84288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84288, CurrentID=0, Status='live', Symbol='EFCAB2', Aliases=['CFAP200', 'DRC8'], description='EF-hand calcium binding domain 2', other_designations='dynein regulatory complex protein 8|EF-hand calcium-binding domain-containing protein 2|dynein regulatory complex subunit 8', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244969682, end_position_on_the_genomic_accession=245125228, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    84289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84289, CurrentID=0, Status='live', Symbol='ING5', Aliases=['p28ING5'], description='inhibitor of growth family member 5', other_designations='inhibitor of growth protein 5', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241687017, end_position_on_the_genomic_accession=241729481, orientation='plus', exon_count=15, OMIM=[608525], no_hdr0=''),
    84290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84290, CurrentID=0, Status='live', Symbol='CAPNS2', Aliases=['CSS2'], description='calpain small subunit 2', other_designations='calpain small subunit 2|calcium-dependent protease small subunit 2', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55566684, end_position_on_the_genomic_accession=55567687, orientation='plus', exon_count=1, OMIM=[616767], no_hdr0=''),
    84292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84292, CurrentID=0, Status='live', Symbol='WDR83', Aliases=['MORG1'], description='WD repeat domain 83', other_designations='WD repeat domain-containing protein 83|MAPK organizer 1|mitogen-activated protein kinase organizer 1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12666807, end_position_on_the_genomic_accession=12675832, orientation='plus', exon_count=11, OMIM=[616850], no_hdr0=''),
    84293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84293, CurrentID=0, Status='live', Symbol='PRXL2A', Aliases=['Adrx', 'C10orf58', 'FAM213A', 'PAMM'], description='peroxiredoxin like 2A', other_designations='peroxiredoxin-like 2A|Adiporedoxin|UPF0765 protein C10orf58|family with sequence similarity 213 member A|peroxiredoxin (PRX)-like 2 activated in M-CSF stimulated monocytes|peroxiredoxin-like 2 activated in M-CSF stimulated monocytes|redox-regulatory protein FAM213A|redox-regulatory protein PAMM', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80407829, end_position_on_the_genomic_accession=80437115, orientation='plus', exon_count=9, OMIM=[617165], no_hdr0=''),
    84294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84294, CurrentID=0, Status='live', Symbol='UTP23', Aliases=['C8orf53'], description='UTP23 small subunit processome component', other_designations='rRNA-processing protein UTP23 homolog|UTP23, small subunit (SSU) processome component, homolog', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=116766524, end_position_on_the_genomic_accession=116774684, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    84295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84295, CurrentID=0, Status='live', Symbol='PHF6', Aliases=['BFLS', 'BORJ', 'CENP-31'], description='PHD finger protein 6', other_designations='PHD finger protein 6|PHD-like zinc finger protein|centromere protein 31|truncated PHF6', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134373312, end_position_on_the_genomic_accession=134428790, orientation='plus', exon_count=10, OMIM=[300414], no_hdr0=''),
    84296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84296, CurrentID=0, Status='live', Symbol='GINS4', Aliases=['SLD5'], description='GINS complex subunit 4', other_designations='DNA replication complex GINS protein SLD5|SLD5 homolog', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41529205, end_position_on_the_genomic_accession=41545030, orientation='plus', exon_count=8, OMIM=[610611], no_hdr0=''),
    84298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84298, CurrentID=0, Status='live', Symbol='LLPH', Aliases=['C12orf31', 'hLLP'], description='LLP homolog, long-term synaptic facilitation factor', other_designations='protein LLP homolog|LLP homolog, long-term synaptic facilitation (Aplysia)|human LAPS18-like protein', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66116555, end_position_on_the_genomic_accession=66130750, orientation='minus', exon_count=3, OMIM=[616998], no_hdr0=''),
    84299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84299, CurrentID=0, Status='live', Symbol='MIEN1', Aliases=['C17orf37', 'C35', 'ORB3', 'RDX12', 'XTP4'], description='migration and invasion enhancer 1', other_designations='migration and invasion enhancer 1|HBV X-transactivated gene 4 protein|HBV XAg-transactivated protein 4|protein C17orf37', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39728510, end_position_on_the_genomic_accession=39730532, orientation='minus', exon_count=3, OMIM=[611802], no_hdr0=''),
    84300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84300, CurrentID=0, Status='live', Symbol='UQCC2', Aliases=['C6orf125', 'C6orf126', 'Cbp6', 'M19', 'MC3DN7', 'MNF1', 'bA6B20.2'], description='ubiquinol-cytochrome c reductase complex assembly factor 2', other_designations='ubiquinol-cytochrome-c reductase complex assembly factor 2|breast cancer-associated protein SGA-81M|cytochrome B protein synthesis 6 homolog|mitochondrial nucleoid factor 1|mitochondrial protein M19', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33696764, end_position_on_the_genomic_accession=33711700, orientation='minus', exon_count=4, OMIM=[614461], no_hdr0=''),
    84301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84301, CurrentID=0, Status='live', Symbol='DDI2', Aliases=[], description='DNA damage inducible 1 homolog 2', other_designations='protein DDI1 homolog 2|DDI1, DNA-damage inducible 1, homolog 2|DNA-damage inducible protein 2 (DDI2)', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15617458, end_position_on_the_genomic_accession=15669044, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84302, CurrentID=0, Status='live', Symbol='PGAP4', Aliases=['C9orf125', 'TMEM246'], description='post-GPI attachment to proteins GalNAc transferase 4', other_designations='post-GPI attachment to proteins factor 4|transmembrane protein 246|transmembrane protein C9orf125', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101473163, end_position_on_the_genomic_accession=101489195, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84303, CurrentID=0, Status='live', Symbol='CHCHD6', Aliases=['CHCM1', 'MICOS25', 'Mic25', 'PPP1R23'], description='coiled-coil-helix-coiled-coil-helix domain containing 6', other_designations='MICOS complex subunit MIC25|coiled coil helix cristae morphology 1|coiled-coil-helix cristae morphology protein 1|coiled-coil-helix-coiled-coil-helix domain-containing protein 6, mitochondrial|mitochondrial contact site and cristae organizing system subunit 25|protein phosphatase 1, regulatory subunit 23', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126704240, end_position_on_the_genomic_accession=126960420, orientation='plus', exon_count=18, OMIM=[615634], no_hdr0=''),
    84304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84304, CurrentID=0, Status='live', Symbol='NUDT22', Aliases=[], description='nudix hydrolase 22', other_designations='uridine diphosphate glucose pyrophosphatase NUDT22|UDPG pyrophosphatase|UGPPase|nucleoside diphosphate-linked moiety X motif 22|nudix (nucleoside diphosphate linked moiety X)-type motif 22|nudix motif 22', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64226258, end_position_on_the_genomic_accession=64230016, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84305, CurrentID=0, Status='live', Symbol='PYM1', Aliases=['PYM', 'WIBG'], description='PYM homolog 1, exon junction complex associated factor', other_designations='partner of Y14 and mago|protein wibg homolog|within bgcn homolog', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55901413, end_position_on_the_genomic_accession=55927894, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    84306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84306, CurrentID=0, Status='live', Symbol='PDCD2L', Aliases=[], description='programmed cell death 2 like', other_designations='programmed cell death protein 2-like', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34404399, end_position_on_the_genomic_accession=34426168, orientation='plus', exon_count=7, OMIM=[615661], no_hdr0=''),
    84307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84307, CurrentID=0, Status='live', Symbol='ZNF397', Aliases=['ZNF47', 'ZSCAN15'], description='zinc finger protein 397', other_designations='zinc finger protein 397|zinc finger and SCAN domain-containing protein 15|zinc finger protein 47', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35240704, end_position_on_the_genomic_accession=35259227, orientation='plus', exon_count=6, OMIM=[609601], no_hdr0=''),
    84309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84309, CurrentID=0, Status='live', Symbol='NUDT16L1', Aliases=['SDOS', 'TIRR'], description='nudix hydrolase 16 like 1', other_designations='tudor-interacting repair regulator protein|NUDT16-like protein 1|nudix (nucleoside diphosphate linked moiety X)-type motif 16-like 1|protein syndesmos|syndesmos', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4688930, end_position_on_the_genomic_accession=4695859, orientation='plus', exon_count=3, OMIM=[617338], no_hdr0=''),
    84310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84310, CurrentID=0, Status='live', Symbol='C7orf50', Aliases=['YCR016W'], description='chromosome 7 open reading frame 50', other_designations='uncharacterized protein C7orf50', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=977964, end_position_on_the_genomic_accession=1138325, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    84311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84311, CurrentID=0, Status='live', Symbol='MRPL45', Aliases=['L45mt', 'MRP-L45'], description='mitochondrial ribosomal protein L45', other_designations='39S ribosomal protein L45, mitochondrial|mitochondrial large ribosomal subunit protein mL45', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38297168, end_position_on_the_genomic_accession=38323211, orientation='plus', exon_count=8, OMIM=[611850], no_hdr0=''),
    84312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84312, CurrentID=0, Status='live', Symbol='BRMS1L', Aliases=['BRMS1'], description='BRMS1 like transcriptional repressor', other_designations='breast cancer metastasis-suppressor 1-like protein|BRMS1-homolog protein p40|BRMS1-like protein p40|breast cancer metastasis-suppressor 1 like', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35825596, end_position_on_the_genomic_accession=35871963, orientation='plus', exon_count=13, OMIM=[618514], no_hdr0=''),
    84313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84313, CurrentID=0, Status='live', Symbol='VPS25', Aliases=['DERP9', 'EAP20', 'FAP20'], description='vacuolar protein sorting 25 homolog', other_designations='vacuolar protein-sorting-associated protein 25|ELL-associated protein of 20 kDa|ESCRT-II complex subunit VPS25|dermal papilla-derived protein 9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42773449, end_position_on_the_genomic_accession=42779599, orientation='plus', exon_count=6, OMIM=[610907], no_hdr0=''),
    84314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84314, CurrentID=0, Status='live', Symbol='TMEM107', Aliases=['GRVS638', 'JBTS29', 'MKS13', 'PRO1268'], description='transmembrane protein 107', other_designations='transmembrane protein 107', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8172457, end_position_on_the_genomic_accession=8176380, orientation='minus', exon_count=5, OMIM=[616183], no_hdr0=''),
    84315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84315, CurrentID=0, Status='live', Symbol='MON1A', Aliases=['SAND1'], description='MON1 homolog A, secretory trafficking associated', other_designations='vacuolar fusion protein MON1 homolog A|MON1 secretory trafficking family member A', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49908869, end_position_on_the_genomic_accession=49929811, orientation='minus', exon_count=8, OMIM=[611464], no_hdr0=''),
    84316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84316, CurrentID=0, Status='live', Symbol='NAA38', Aliases=['LSMD1', 'MAK31', 'PFAAP2'], description='N-alpha-acetyltransferase 38, NatC auxiliary subunit', other_designations='N-alpha-acetyltransferase 38, NatC auxiliary subunit|LSM domain containing 1|LSM domain-containing protein 1|phosphonoformate immuno-associated protein 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7856685, end_position_on_the_genomic_accession=7885420, orientation='minus', exon_count=6, OMIM=[617990], no_hdr0=''),
    84317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84317, CurrentID=0, Status='live', Symbol='CCDC115', Aliases=['CDG2O', 'ccp1'], description='coiled-coil domain containing 115', other_designations='coiled-coil domain-containing protein 115', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130337933, end_position_on_the_genomic_accession=130342681, orientation='minus', exon_count=6, OMIM=[613734], no_hdr0=''),
    84318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84318, CurrentID=0, Status='live', Symbol='CCDC77', Aliases=[], description='coiled-coil domain containing 77', other_designations='coiled-coil domain-containing protein 77', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=389347, end_position_on_the_genomic_accession=442642, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    84319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84319, CurrentID=0, Status='live', Symbol='CMSS1', Aliases=['C3orf26'], description='cms1 ribosomal small subunit homolog', other_designations='protein CMSS1', map_location='3q12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=99817862, end_position_on_the_genomic_accession=100181732, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    84320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84320, CurrentID=0, Status='live', Symbol='ACBD6', Aliases=[], description='acyl-CoA binding domain containing 6', other_designations='acyl-CoA-binding domain-containing protein 6|acyl-Coenzyme A binding domain containing 6', map_location='1q25.2-q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180269663, end_position_on_the_genomic_accession=180502577, orientation='minus', exon_count=11, OMIM=[616352], no_hdr0=''),
    84321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84321, CurrentID=0, Status='live', Symbol='THOC3', Aliases=['THO3', 'hTREX45'], description='THO complex 3', other_designations='THO complex subunit 3|TEX1 homolog', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=175959531, end_position_on_the_genomic_accession=176034905, orientation='minus', exon_count=8, OMIM=[606929], no_hdr0=''),
    84322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84322, CurrentID=0, Status='live', Symbol='C18orf12', Aliases=['HEIL1', 'HsT2508'], description='chromosome 18 open reading frame 12', other_designations='uncharacterized protein C18orf12', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=48252301, end_position_on_the_genomic_accession=48252837, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    84324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84324, CurrentID=0, Status='live', Symbol='SARNP', Aliases=['CIP29', 'HCC1', 'HSPC316', 'THO1'], description='SAP domain containing ribonucleoprotein', other_designations='SAP domain-containing ribonucleoprotein|cytokine induced protein 29 kDa|cytokine-induced protein of 29 kDa|hepatocellular carcinoma 1|nuclear protein Hcc-1|proliferation associated cytokine-inducible protein CIP29', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55752463, end_position_on_the_genomic_accession=55817724, orientation='minus', exon_count=12, OMIM=[610049], no_hdr0=''),
    84326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84326, CurrentID=0, Status='live', Symbol='METTL26', Aliases=['C16orf13', 'JFP2'], description='methyltransferase like 26', other_designations='methyltransferase-like 26|UPF0585 protein C16orf13', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=634429, end_position_on_the_genomic_accession=636364, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84327, CurrentID=0, Status='live', Symbol='ZBED3', Aliases=[], description='zinc finger BED-type containing 3', other_designations='zinc finger BED domain-containing protein 3|2610005H11Rik|axin-interacting protein|zinc finger, BED domain containing 3', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=77072072, end_position_on_the_genomic_accession=77087285, orientation='minus', exon_count=4, OMIM=[615250], no_hdr0=''),
    84328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84328, CurrentID=0, Status='live', Symbol='LZIC', Aliases=[], description='leucine zipper and CTNNBIP1 domain containing', other_designations='protein LZIC|leucine zipper and CTNNBIP1 domain-containing protein|leucine zipper and ICAT homologous domain-containing protein|leucine zipper domain and ICAT homologous domain containing', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9922118, end_position_on_the_genomic_accession=9943402, orientation='minus', exon_count=10, OMIM=[610458], no_hdr0=''),
    84329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84329, CurrentID=0, Status='live', Symbol='HVCN1', Aliases=['HV1', 'VSOP'], description='hydrogen voltage gated channel 1', other_designations='voltage-gated hydrogen channel 1|voltage sensor domain-only protein', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110648686, end_position_on_the_genomic_accession=110704945, orientation='minus', exon_count=16, OMIM=[611227], no_hdr0=''),
    84330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84330, CurrentID=0, Status='live', Symbol='ZNF414', Aliases=['ZFP414'], description='zinc finger protein 414', other_designations='zinc finger protein 414', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8509678, end_position_on_the_genomic_accession=8514167, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    84331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84331, CurrentID=0, Status='live', Symbol='MCRIP2', Aliases=['C16orf14', 'FAM195A', 'c349E10.1'], description='MAPK regulated corepressor interacting protein 2', other_designations='MAPK regulated corepressor interacting protein 2|MAPK regulated co-repressor interacting protein 2|family with sequence similarity 195, member A|protein FAM195A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=641828, end_position_on_the_genomic_accession=648474, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84332, CurrentID=0, Status='live', Symbol='DYDC2', Aliases=[], description='DPY30 domain containing 2', other_designations='DPY30 domain-containing protein 2', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80344745, end_position_on_the_genomic_accession=80368073, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84333, CurrentID=0, Status='live', Symbol='PCGF5', Aliases=['RNF159'], description='polycomb group ring finger 5', other_designations='polycomb group RING finger protein 5|RING finger protein 159|ring finger protein (C3HC4 type) 159', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91162402, end_position_on_the_genomic_accession=91284337, orientation='plus', exon_count=15, OMIM=[617407], no_hdr0=''),
    84334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84334, CurrentID=0, Status='live', Symbol='COA8', Aliases=['APOP', 'APOP1', 'APOPT1', 'C14orf153', 'MC4DN17'], description='cytochrome c oxidase assembly factor 8', other_designations='cytochrome c oxidase assembly factor 8|UPF0671 protein C14orf153|apoptogenic 1, mitochondrial', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103562960, end_position_on_the_genomic_accession=103590899, orientation='plus', exon_count=8, OMIM=[616003], no_hdr0=''),
    84335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84335, CurrentID=0, Status='live', Symbol='AKT1S1', Aliases=['Lobe', 'PRAS40'], description='AKT1 substrate 1', other_designations='proline-rich AKT1 substrate 1|40 kDa proline-rich AKT substrate|AKT1 substrate 1 (proline rich)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49869033, end_position_on_the_genomic_accession=49878356, orientation='minus', exon_count=7, OMIM=[610221], no_hdr0=''),
    84336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84336, CurrentID=0, Status='live', Symbol='TMEM101', Aliases=[], description='transmembrane protein 101', other_designations='transmembrane protein 101|putative NF-kappa-B-activating protein 130', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44011188, end_position_on_the_genomic_accession=44026046, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    84337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84337, CurrentID=0, Status='live', Symbol='ELOF1', Aliases=['ELF1'], description='elongation factor 1 homolog', other_designations='transcription elongation factor 1 homolog|ELF1 homolog, elongation factor 1|elongation factor 1 homolog (ELF1, S. cerevisiae)', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11553044, end_position_on_the_genomic_accession=11559230, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84340, CurrentID=0, Status='live', Symbol='GFM2', Aliases=['EF-G2mt', 'EFG2', 'MRRF2', 'MST027', 'MSTP027', 'RRF', 'RRF2', 'RRF2mt', 'hEFG2', 'mEF-G 2'], description='GTP dependent ribosome recycling factor mitochondrial 2', other_designations='ribosome-releasing factor 2, mitochondrial|G elongation factor mitochondrial 2|mitochondrial elongation factor G2|mitochondrial ribosome recycling factor 2|mitochondrial ribosome-releasing factor 2|ribosome releasing factor 2', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=74721206, end_position_on_the_genomic_accession=74767147, orientation='minus', exon_count=22, OMIM=[606544], no_hdr0=''),
    84342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84342, CurrentID=0, Status='live', Symbol='COG8', Aliases=['CDG2H', 'DOR1'], description='component of oligomeric golgi complex 8', other_designations='conserved oligomeric Golgi complex subunit 8|COG complex subunit 8|conserved oligomeric golgi complex component 8|dependent on RIC1', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69326428, end_position_on_the_genomic_accession=69339564, orientation='minus', exon_count=7, OMIM=[606979], no_hdr0=''),
    84343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84343, CurrentID=0, Status='live', Symbol='HPS3', Aliases=['BLOC2S1', 'SUTAL'], description='HPS3 biogenesis of lysosomal organelles complex 2 subunit 1', other_designations='Hermansky-Pudlak syndrome 3 protein', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149129624, end_position_on_the_genomic_accession=149173732, orientation='plus', exon_count=18, OMIM=[606118], no_hdr0=''),
    84364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84364, CurrentID=0, Status='live', Symbol='ARFGAP2', Aliases=['IRZ', 'NBLA10535', 'ZFP289', 'ZNF289'], description='ADP ribosylation factor GTPase activating protein 2', other_designations='ADP-ribosylation factor GTPase-activating protein 2|GTPase-activating protein ZNF289|zinc finger protein 289, ID1 regulated', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47164301, end_position_on_the_genomic_accession=47176880, orientation='minus', exon_count=17, OMIM=[606908], no_hdr0=''),
    84365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84365, CurrentID=0, Status='live', Symbol='NIFK', Aliases=['MKI67IP', 'Nopp34'], description='nucleolar protein interacting with the FHA domain of MKI67', other_designations='MKI67 FHA domain-interacting nucleolar phosphoprotein|hNIFK|nucleolar phosphoprotein Nopp34|nucleolar protein interacting with the FHA domain of pKi-67', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=121726945, end_position_on_the_genomic_accession=121736875, orientation='minus', exon_count=7, OMIM=[611970], no_hdr0=''),
    84366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84366, CurrentID=0, Status='live', Symbol='PRAC1', Aliases=['C17orf92', 'PRAC'], description='PRAC1 small nuclear protein', other_designations='small nuclear protein PRAC1|prostate cancer susceptibility candidate 1|prostate cancer susceptibility candidate protein 1|prostate, rectum and colon expressed gene protein|small nuclear protein PRAC', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48721719, end_position_on_the_genomic_accession=48722518, orientation='minus', exon_count=2, OMIM=[609819], no_hdr0=''),
    84376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84376, CurrentID=0, Status='live', Symbol='HOOK3', Aliases=['HK3'], description='hook microtubule tethering protein 3', other_designations='protein Hook homolog 3|h-hook3|hHK3|hook homolog 3', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42896978, end_position_on_the_genomic_accession=43030535, orientation='plus', exon_count=22, OMIM=[607825], no_hdr0=''),
    84417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84417, CurrentID=0, Status='live', Symbol='ECRG4', Aliases=['C2orf40'], description='ECRG4 augurin precursor', other_designations='augurin|esophageal cancer related gene 4 protein', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=106063290, end_position_on_the_genomic_accession=106078155, orientation='plus', exon_count=7, OMIM=[611752], no_hdr0=''),
    84418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84418, CurrentID=0, Status='live', Symbol='CYSTM1', Aliases=['C5orf32', 'ORF1-FL49'], description='cysteine rich transmembrane module containing 1', other_designations='cysteine-rich and transmembrane domain-containing protein 1|UPF0467 protein C5orf32|putative nuclear protein ORF1-FL49', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140175188, end_position_on_the_genomic_accession=140243789, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    84419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84419, CurrentID=0, Status='live', Symbol='C15orf48', Aliases=['COXFA4L3', 'FOAP-11', 'MIR147BHG', 'MISTRAV', 'MOCCI', 'NMES1'], description='chromosome 15 open reading frame 48', other_designations='normal mucosa of esophagus-specific gene 1 protein|MIR147B host|cytochrome c oxidase subunit FA4 like 3|mitochondrial stress response antiviral|modulator of cytochrome C oxidase during inflammation|normal mucosa of esophagus specific 1', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45430610, end_position_on_the_genomic_accession=45433340, orientation='plus', exon_count=4, OMIM=[608409], no_hdr0=''),
    84432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84432, CurrentID=0, Status='live', Symbol='PROK1', Aliases=['EGVEGF', 'PK1', 'PRK1'], description='prokineticin 1', other_designations='prokineticin-1|EG-VEGF|black mamba toxin-related protein|endocrine-gland-derived vascular endothelial growth factor|mambakine', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110451149, end_position_on_the_genomic_accession=110457358, orientation='plus', exon_count=3, OMIM=[606233], no_hdr0=''),
    84433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84433, CurrentID=0, Status='live', Symbol='CARD11', Aliases=['BENTA', 'BIMP3', 'CARMA1', 'IMD11', 'IMD11A', 'PPBL'], description='caspase recruitment domain family member 11', other_designations='caspase recruitment domain-containing protein 11|CARD-containing MAGUK protein 1|bcl10-interacting maguk protein 3|carma 1', map_location='7p22.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2906142, end_position_on_the_genomic_accession=3043867, orientation='minus', exon_count=26, OMIM=[607210], no_hdr0=''),
    84435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84435, CurrentID=0, Status='live', Symbol='ADGRA1', Aliases=['GPR123'], description='adhesion G protein-coupled receptor A1', other_designations='adhesion G protein-coupled receptor A1|G-protein coupled receptor 123|probable G-protein coupled receptor 123', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133087924, end_position_on_the_genomic_accession=133131675, orientation='plus', exon_count=9, OMIM=[612302], no_hdr0=''),
    84436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84436, CurrentID=0, Status='live', Symbol='ZNF528', Aliases=[], description='zinc finger protein 528', other_designations='zinc finger protein 528', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52392752, end_position_on_the_genomic_accession=52418408, orientation='plus', exon_count=13, OMIM=[615580], no_hdr0=''),
    84437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84437, CurrentID=0, Status='live', Symbol='MSANTD4', Aliases=['KIAA1826'], description='Myb/SANT DNA binding domain containing 4 with coiled-coils', other_designations='myb/SANT-like DNA-binding domain-containing protein 4|Myb/SANT-like DNA-binding domain containing 4 with coiled-coils', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=106007899, end_position_on_the_genomic_accession=106022287, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    84439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84439, CurrentID=0, Status='live', Symbol='HHIPL1', Aliases=['KIAA1822', 'UNQ9245'], description='HHIP like 1', other_designations='HHIP-like protein 1|ARAR9245', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99604476, end_position_on_the_genomic_accession=99680569, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    84440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84440, CurrentID=0, Status='live', Symbol='RAB11FIP4', Aliases=['FIP4-Rab11', 'RAB11-FIP4'], description='RAB11 family interacting protein 4', other_designations='rab11 family-interacting protein 4|RAB11 family interacting protein 4 (class II)|arfophilin-2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=31391675, end_position_on_the_genomic_accession=31538211, orientation='plus', exon_count=16, OMIM=[611999], no_hdr0=''),
    84441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84441, CurrentID=0, Status='live', Symbol='MAML2', Aliases=['MAM-3', 'MAM2', 'MAM3', 'MLL-MAML2'], description='mastermind like transcriptional coactivator 2', other_designations='mastermind-like protein 2|mam-2|mastermind-like 2', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95976598, end_position_on_the_genomic_accession=96343308, orientation='minus', exon_count=7, OMIM=[607537], no_hdr0=''),
    84443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84443, CurrentID=0, Status='live', Symbol='FRMPD3', Aliases=[], description='FERM and PDZ domain containing 3', other_designations='FERM and PDZ domain-containing protein 3', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107449652, end_position_on_the_genomic_accession=107605264, orientation='plus', exon_count=19, OMIM=[301005], no_hdr0=''),
    84444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84444, CurrentID=0, Status='live', Symbol='DOT1L', Aliases=['DOT1', 'KMT4'], description='DOT1 like histone lysine methyltransferase', other_designations='histone-lysine N-methyltransferase, H3 lysine-79 specific|DOT1 like histone H3K79 methyltransferase|DOT1-like histone methyltransferase|DOT1-like protein|DOT1-like, histone H3 methyltransferase|H3-K79-HMTase|histone H3-K79 methyltransferase|histone methyltransferase DOT1L|lysine N-methyltransferase 4', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2163933, end_position_on_the_genomic_accession=2232578, orientation='plus', exon_count=31, OMIM=[607375], no_hdr0=''),
    84445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84445, CurrentID=0, Status='live', Symbol='LZTS2', Aliases=['LAPSER1'], description='leucine zipper tumor suppressor 2', other_designations='leucine zipper putative tumor suppressor 2|leucine zipper, putative tumor suppressor 2|protein LAPSER1', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100996588, end_position_on_the_genomic_accession=101007833, orientation='plus', exon_count=9, OMIM=[610454], no_hdr0=''),
    84446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84446, CurrentID=0, Status='live', Symbol='BRSK1', Aliases=['hSAD1'], description='BR serine/threonine kinase 1', other_designations='serine/threonine-protein kinase BRSK1|BR serine/threonine-protein kinase 1|SAD1 homolog|SAD1 kinase|brain-selective kinase 1|brain-specific serine/threonine-protein kinase 1|protein kinase SAD1A|serine/threonine-protein kinase SAD-B|synapses of Amphids Defective homolog 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55283997, end_position_on_the_genomic_accession=55312562, orientation='plus', exon_count=21, OMIM=[609235], no_hdr0=''),
    84447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84447, CurrentID=0, Status='live', Symbol='SYVN1', Aliases=['DER3', 'HRD1'], description='synoviolin 1', other_designations='E3 ubiquitin-protein ligase synoviolin|HMG-coA reductase degradation 1 homolog|RING-type E3 ubiquitin transferase synoviolin|synovial apoptosis inhibitor 1, synoviolin', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65127279, end_position_on_the_genomic_accession=65135178, orientation='minus', exon_count=16, OMIM=[608046], no_hdr0=''),
    84448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84448, CurrentID=0, Status='live', Symbol='ABLIM2', Aliases=[], description='actin binding LIM protein family member 2', other_designations='actin-binding LIM protein 2|abLIM-2|testis tissue sperm-binding protein Li 35a', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7965312, end_position_on_the_genomic_accession=8158813, orientation='minus', exon_count=25, OMIM=[612544], no_hdr0=''),
    84449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84449, CurrentID=0, Status='live', Symbol='ZNF333', Aliases=[], description='zinc finger protein 333', other_designations='zinc finger protein 333', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14689787, end_position_on_the_genomic_accession=14733742, orientation='plus', exon_count=19, OMIM=[611811], no_hdr0=''),
    84450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84450, CurrentID=0, Status='live', Symbol='ZNF512', Aliases=[], description='zinc finger protein 512', other_designations='zinc finger protein 512', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27583042, end_position_on_the_genomic_accession=27623217, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    84451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84451, CurrentID=0, Status='live', Symbol='MAP3K21', Aliases=['MLK4', 'dJ862P8.3'], description='mitogen-activated protein kinase kinase kinase 21', other_designations='mitogen-activated protein kinase kinase kinase 21|mitogen-activated protein kinase kinase kinase MLK4|mixed lineage kinase 4', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=233327724, end_position_on_the_genomic_accession=233385148, orientation='plus', exon_count=10, OMIM=[614793], no_hdr0=''),
    84455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84455, CurrentID=0, Status='live', Symbol='EFCAB7', Aliases=[], description='EF-hand calcium binding domain 7', other_designations='EF-hand calcium-binding domain-containing protein 7', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=63523321, end_position_on_the_genomic_accession=63585401, orientation='plus', exon_count=17, OMIM=[617632], no_hdr0=''),
    84456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84456, CurrentID=0, Status='live', Symbol='L3MBTL3', Aliases=['MBT-1', 'MBT1'], description='L3MBTL histone methyl-lysine binding protein 3', other_designations='lethal(3)malignant brain tumor-like protein 3|H-l(3)mbt-like protein 3|L3MBTL3, histone methyl-lysine binding protein|L3mbt-like 3|l(3)mbt-like 3', map_location='6q23.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=130018581, end_position_on_the_genomic_accession=130141440, orientation='plus', exon_count=30, OMIM=[618844], no_hdr0=''),
    84457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84457, CurrentID=0, Status='live', Symbol='PHYHIPL', Aliases=[], description='phytanoyl-CoA 2-hydroxylase interacting protein like', other_designations='phytanoyl-CoA hydroxylase-interacting protein-like', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=59175872, end_position_on_the_genomic_accession=59247770, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    84458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84458, CurrentID=0, Status='live', Symbol='LCOR', Aliases=['C10orf12', 'MLR2'], description='ligand dependent nuclear receptor corepressor', other_designations='ligand-dependent corepressor|mblk1-related protein 2', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96832298, end_position_on_the_genomic_accession=96995956, orientation='plus', exon_count=10, OMIM=[607698], no_hdr0=''),
    84460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84460, CurrentID=0, Status='live', Symbol='ZMAT1', Aliases=[], description='zinc finger matrin-type 1', other_designations='zinc finger matrin-type protein 1', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101882288, end_position_on_the_genomic_accession=101932135, orientation='minus', exon_count=11, OMIM=[301007], no_hdr0=''),
    84461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84461, CurrentID=0, Status='live', Symbol='NEURL4', Aliases=[], description='neuralized E3 ubiquitin protein ligase 4', other_designations='neuralized-like protein 4|neuralized homolog 4', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7315628, end_position_on_the_genomic_accession=7329335, orientation='minus', exon_count=29, OMIM=[615865], no_hdr0=''),
    84464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84464, CurrentID=0, Status='live', Symbol='SLX4', Aliases=['BTBD12', 'FANCP', 'MUS312'], description='SLX4 structure-specific endonuclease subunit', other_designations='structure-specific endonuclease subunit SLX4|BTB/POZ domain-containing protein 12', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3579653, end_position_on_the_genomic_accession=3611639, orientation='minus', exon_count=17, OMIM=[613278], no_hdr0=''),
    84465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84465, CurrentID=0, Status='live', Symbol='MEGF11', Aliases=[], description='multiple EGF like domains 11', other_designations='multiple epidermal growth factor-like domains protein 11|multiple EGF-like domains protein 11', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65889717, end_position_on_the_genomic_accession=66253750, orientation='minus', exon_count=29, OMIM=[612454], no_hdr0=''),
    84466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84466, CurrentID=0, Status='live', Symbol='MEGF10', Aliases=['EMARDD', 'SR-F3'], description='multiple EGF like domains 10', other_designations='multiple epidermal growth factor-like domains protein 10', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127229519, end_position_on_the_genomic_accession=127461222, orientation='plus', exon_count=31, OMIM=[612453], no_hdr0=''),
    84467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84467, CurrentID=0, Status='live', Symbol='FBN3', Aliases=[], description='fibrillin 3', other_designations='fibrillin-3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8065402, end_position_on_the_genomic_accession=8149592, orientation='minus', exon_count=68, OMIM=[608529], no_hdr0=''),
    84498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84498, CurrentID=0, Status='live', Symbol='FAM120B', Aliases=['CCPG', 'KIAA1838', 'PGCC1', 'SAN1', 'dJ894D12.1'], description='family with sequence similarity 120B', other_designations='constitutive coactivator of peroxisome proliferator-activated receptor gamma|PPARG constitutive coactivator 1|PPARgamma constitutive coactivator 1|constitutive coactivator of PPAR-gamma|senataxin-associated nuclease 1', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=170290703, end_position_on_the_genomic_accession=170407748, orientation='plus', exon_count=15, OMIM=[612266], no_hdr0=''),
    84501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84501, CurrentID=0, Status='live', Symbol='SPIRE2', Aliases=['Spir-2'], description='spire type actin nucleation factor 2', other_designations='protein spire homolog 2|spire actin nucleation factor 2|spire family actin nucleation factor 2|spire homolog 2', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89828475, end_position_on_the_genomic_accession=89871319, orientation='plus', exon_count=15, OMIM=[609217], no_hdr0=''),
    84502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84502, CurrentID=0, Status='live', Symbol='JPH4', Aliases=['JP4', 'JPHL1'], description='junctophilin 4', other_designations='junctophilin-4|JP-4|junctophilin like 1|junctophilin-like 1 protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23568038, end_position_on_the_genomic_accession=23578790, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    84503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84503, CurrentID=0, Status='live', Symbol='ZNF527', Aliases=[], description='zinc finger protein 527', other_designations='zinc finger protein 527', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37371057, end_position_on_the_genomic_accession=37393066, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    84504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84504, CurrentID=0, Status='live', Symbol='NKX6-2', Aliases=['GTX', 'NKX6.2', 'NKX6B', 'SPAX8'], description='NK6 homeobox 2', other_designations='homeobox protein Nkx-6.2|NK homeobox family 6, B|NK6 transcription factor related, locus 2|glial and testis-specific homeobox protein|homeobox 6B|homeobox protein NK-6 homolog B', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132782229, end_position_on_the_genomic_accession=132786147, orientation='minus', exon_count=4, OMIM=[605955], no_hdr0=''),
    84513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84513, CurrentID=0, Status='live', Symbol='PLPP5', Aliases=['DPPL1', 'HTPAP', 'PPAPDC1B'], description='phospholipid phosphatase 5', other_designations='phospholipid phosphatase 5|diacylglycerol pyrophosphate like 1|diacylglycerol pyrophosphate phosphatase-like 1|phosphatidate phosphatase PPAPDC1B|phosphatidic acid phosphatase type 2 domain containing 1B|phosphatidic acid phosphatase type 2 domain-containing protein 1B|testicular secretory protein Li 38', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38261790, end_position_on_the_genomic_accession=38269435, orientation='minus', exon_count=9, OMIM=[610626], no_hdr0=''),
    84514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84514, CurrentID=0, Status='live', Symbol='GHDC', Aliases=['D11LGP1', 'LGP1'], description='GH3 domain containing', other_designations='GH3 domain-containing protein|homolog of mouse LGP1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42189087, end_position_on_the_genomic_accession=42194494, orientation='minus', exon_count=10, OMIM=[608587], no_hdr0=''),
    84515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84515, CurrentID=0, Status='live', Symbol='MCM8', Aliases=['C20orf154', 'POF10', 'dJ967N21.5'], description='minichromosome maintenance 8 homologous recombination repair factor', other_designations='DNA helicase MCM8|DNA replication licensing factor MCM8|MCM8 minichromosome maintenance deficient 8|REC homolog|minichromosome maintenance complex component 8', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5950652, end_position_on_the_genomic_accession=6000941, orientation='plus', exon_count=21, OMIM=[608187], no_hdr0=''),
    84516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84516, CurrentID=0, Status='live', Symbol='DCTN5', Aliases=[], description='dynactin subunit 5', other_designations='dynactin subunit 5|dynactin 4|dynactin 5 (p25)|dynactin subunit p25', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23641431, end_position_on_the_genomic_accession=23677472, orientation='plus', exon_count=9, OMIM=[612962], no_hdr0=''),
    84517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84517, CurrentID=0, Status='live', Symbol='ACTRT3', Aliases=['ARP-T3', 'ARPM1'], description='actin related protein T3', other_designations='actin-related protein T3|actin-related protein M1', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169766921, end_position_on_the_genomic_accession=169769561, orientation='minus', exon_count=2, OMIM=[608534], no_hdr0=''),
    84518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84518, CurrentID=0, Status='live', Symbol='CNFN', Aliases=['PLAC8L2'], description='cornifelin', other_designations='cornifelin|cornefied envelope protein cornefilin', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42387019, end_position_on_the_genomic_accession=42390318, orientation='minus', exon_count=5, OMIM=[611764], no_hdr0=''),
    84519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84519, CurrentID=0, Status='live', Symbol='ACRBP', Aliases=['CT23', 'OY-TES-1', 'SP32'], description='acrosin binding protein', other_designations='acrosin-binding protein|acrosin-binding protein, 60 kDa form|cancer/testis antigen 23|cancer/testis antigen OY-TES-1|proacrosin binding protein sp32|testicular tissue protein Li 10', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6638075, end_position_on_the_genomic_accession=6647432, orientation='minus', exon_count=10, OMIM=[608352], no_hdr0=''),
    84520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84520, CurrentID=0, Status='live', Symbol='GON7', Aliases=['C14orf142', 'PNAS-127'], description='GON7 subunit of KEOPS complex', other_designations='EKC/KEOPS complex subunit GON7|GON7, KEOPS complex subunit homolog|uncharacterized protein C14orf142', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93202894, end_position_on_the_genomic_accession=93207065, orientation='minus', exon_count=2, OMIM=[617436], no_hdr0=''),
    84522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84522, CurrentID=0, Status='live', Symbol='JAGN1', Aliases=['GL009', 'SCN6'], description='jagunal homolog 1', other_designations='protein jagunal homolog 1', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9890610, end_position_on_the_genomic_accession=9894349, orientation='plus', exon_count=2, OMIM=[616012], no_hdr0=''),
    84524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84524, CurrentID=0, Status='live', Symbol='ZC3H8', Aliases=['Fliz1', 'ZC3HDC8'], description='zinc finger CCCH-type containing 8', other_designations='zinc finger CCCH domain-containing protein 8|zinc finger CCCH-type domain containing 8', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112211529, end_position_on_the_genomic_accession=112255042, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    84525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84525, CurrentID=0, Status='live', Symbol='HOPX', Aliases=['CAMEO', 'HOD', 'HOP', 'LAGY', 'NECC1', 'OB1', 'SMAP31', 'TOTO'], description='HOP homeobox', other_designations='homeodomain-only protein|lung cancer-associated Y protein|not expressed in choriocarcinoma clone 1|odd homeobox protein 1', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56647992, end_position_on_the_genomic_accession=56681866, orientation='minus', exon_count=10, OMIM=[607275], no_hdr0=''),
    84527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84527, CurrentID=0, Status='live', Symbol='ZNF559', Aliases=['NBLA00121'], description='zinc finger protein 559', other_designations='zinc finger protein 559|putative protein product of Nbla00121', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9323772, end_position_on_the_genomic_accession=9345871, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84528, CurrentID=0, Status='live', Symbol='RHOXF2', Aliases=['CT107', 'PEPP-2', 'PEPP2', 'THG1'], description='Rhox homeobox family member 2', other_designations='rhox homeobox family member 2|PEPP subfamily gene 2|cancer/testis antigen 107|homeobox protein from AL590526|paired-like homeobox protein PEPP-2|testis homeobox gene 1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120158535, end_position_on_the_genomic_accession=120165630, orientation='plus', exon_count=4, OMIM=[300447], no_hdr0=''),
    84529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84529, CurrentID=0, Status='live', Symbol='CDIN1', Aliases=['C15orf41', 'HH114'], description='CDAN1 interacting nuclease 1', other_designations='CDAN1-interacting nuclease 1|protein C15orf41|uncharacterized protein C15orf41', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=36579611, end_position_on_the_genomic_accession=36810248, orientation='plus', exon_count=18, OMIM=[615626], no_hdr0=''),
    84530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84530, CurrentID=0, Status='live', Symbol='SRRM4', Aliases=['KIAA1853', 'MU-MB-2.76', 'nSR100'], description='serine/arginine repetitive matrix 4', other_designations='serine/arginine repetitive matrix protein 4|medulloblastoma antigen MU-MB-2.76|neural-specific SR-related protein of 100 kDa|neural-specific serine/arginine repetitive splicing factor of 100 kDa', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=118981541, end_position_on_the_genomic_accession=119163051, orientation='plus', exon_count=13, OMIM=[613103], no_hdr0=''),
    84532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84532, CurrentID=0, Status='live', Symbol='ACSS1', Aliases=['ACAS2L', 'ACECS1', 'AceCS2L'], description='acyl-CoA synthetase short chain family member 1', other_designations='acetyl-coenzyme A synthetase 2-like, mitochondrial|acetate--CoA ligase 2|propionate--CoA ligase', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25006232, end_position_on_the_genomic_accession=25058143, orientation='minus', exon_count=15, OMIM=[614355], no_hdr0=''),
    84539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84539, CurrentID=0, Status='live', Symbol='MCHR2', Aliases=['GPR145', 'GPRv17', 'MCH-2R', 'MCH-R2', 'MCH2', 'MCH2R', 'MCHR-2', 'SLT'], description='melanin concentrating hormone receptor 2', other_designations='melanin-concentrating hormone receptor 2|G protein-coupled receptor slt|G-protein coupled receptor 145|MCH receptor 2|melanin-concentrating hormone 2', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99918519, end_position_on_the_genomic_accession=99994223, orientation='minus', exon_count=7, OMIM=[606111], no_hdr0=''),
    84541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84541, CurrentID=0, Status='live', Symbol='KBTBD8', Aliases=['TA-KRP', 'TAKRP'], description='kelch repeat and BTB domain containing 8', other_designations='kelch repeat and BTB domain-containing protein 8|T-cell activation kelch repeat protein|kelch repeat and BTB (POZ) domain containing 8', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=66998307, end_position_on_the_genomic_accession=67011210, orientation='plus', exon_count=4, OMIM=[616607], no_hdr0=''),
    84542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84542, CurrentID=0, Status='live', Symbol='SANBR', Aliases=['KIAA1841'], description='SANT and BTB domain regulator of CSR', other_designations='uncharacterized protein KIAA1841', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61065871, end_position_on_the_genomic_accession=61138032, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    84545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84545, CurrentID=0, Status='live', Symbol='MRPL43', Aliases=['L43mt', 'MRP-L43', 'bMRP36a'], description='mitochondrial ribosomal protein L43', other_designations='39S ribosomal protein L43, mitochondrial|mitochondrial large ribosomal subunit protein mL43|mitochondrial ribosomal protein bMRP36a', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100977820, end_position_on_the_genomic_accession=100987514, orientation='minus', exon_count=8, OMIM=[611848], no_hdr0=''),
    84547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84547, CurrentID=0, Status='live', Symbol='PGBD1', Aliases=['HUCEP-4', 'SCAND4', 'dJ874C20.4'], description='piggyBac transposable element derived 1', other_designations='piggyBac transposable element-derived protein 1|cerebral protein 4', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28281564, end_position_on_the_genomic_accession=28303681, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84548, CurrentID=0, Status='live', Symbol='TMEM185A', Aliases=['CXorf13', 'FAM11A', 'FRAXF', 'ee3'], description='transmembrane protein 185A', other_designations='transmembrane protein 185A|family with sequence similarity 11, member A|fragile site, folic acid type, rare, fra(X)(q28) F', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149596556, end_position_on_the_genomic_accession=149631792, orientation='minus', exon_count=7, OMIM=[300031], no_hdr0=''),
    84549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84549, CurrentID=0, Status='live', Symbol='MAK16', Aliases=['MAK16L', 'RBM13'], description='MAK16 homolog', other_designations='protein MAK16 homolog|NNP78|RNA binding motif protein 13|RNA binding protein', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=33485182, end_position_on_the_genomic_accession=33501262, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    84552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84552, CurrentID=0, Status='live', Symbol='PARD6G', Aliases=['PAR-6G', 'PAR6gamma'], description='par-6 family cell polarity regulator gamma', other_designations='partitioning defective 6 homolog gamma|PAR-6 gamma protein|PAR6D|par-6 partitioning defective 6 homolog gamma', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=80157232, end_position_on_the_genomic_accession=80247514, orientation='minus', exon_count=3, OMIM=[608976], no_hdr0=''),
    84553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84553, CurrentID=0, Status='live', Symbol='FAXC', Aliases=['C6orf168', 'dJ273F20'], description='failed axon connections homolog, metaxin like GST domain containing', other_designations='failed axon connections homolog', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99271161, end_position_on_the_genomic_accession=99350056, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84557, CurrentID=0, Status='live', Symbol='MAP1LC3A', Aliases=['ATG8E', 'LC3', 'LC3A', 'MAP1ALC3', 'MAP1BLC3'], description='microtubule associated protein 1 light chain 3 alpha', other_designations='microtubule-associated proteins 1A/1B light chain 3A|MAP1 light chain 3-like protein 1|MAP1A/1B light chain 3 A|MAP1A/MAP1B LC3 A|MAP1A/MAP1B light chain 3 A|autophagy-related ubiquitin-like modifier LC3 A|microtubule-associated proteins 1A/1B light chain 3', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34546823, end_position_on_the_genomic_accession=34560345, orientation='plus', exon_count=7, OMIM=[601242], no_hdr0=''),
    84560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84560, CurrentID=0, Status='live', Symbol='MT4', Aliases=['MT-4', 'MT-IV', 'MTIV'], description='metallothionein 4', other_designations='metallothionein-4|metallothionein-IV', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=56565073, end_position_on_the_genomic_accession=56568957, orientation='plus', exon_count=3, OMIM=[606206], no_hdr0=''),
    84561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84561, CurrentID=0, Status='live', Symbol='SLC12A8', Aliases=['CCC9'], description='solute carrier family 12 member 8', other_designations='solute carrier family 12 member 8|cation-chloride cotransporter 9|solute carrier family 12 (sodium/potassium/chloride transporters), member 8', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=125082644, end_position_on_the_genomic_accession=125212748, orientation='minus', exon_count=14, OMIM=[611316], no_hdr0=''),
    84569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84569, CurrentID=0, Status='live', Symbol='LYZL1', Aliases=['KAAG648', 'LYC2', 'LYZD1', 'PRO1278', 'bA534G20.1'], description='lysozyme like 1', other_designations='lysozyme-like protein 1|lysozyme D1', map_location='10p12.1-p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=29289051, end_position_on_the_genomic_accession=29318328, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    84570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84570, CurrentID=0, Status='live', Symbol='COL25A1', Aliases=['AMY', 'CFEOM5', 'CLAC', 'CLAC-P', 'CLACP'], description='collagen type XXV alpha 1 chain', other_designations='collagen alpha-1(XXV) chain|alzheimer disease amyloid-associated protein|collagen-like Alzheimer amyloid plaque component|collagenous Alzheimer amyloid plaque component', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=108808725, end_position_on_the_genomic_accession=109302737, orientation='minus', exon_count=48, OMIM=[610004], no_hdr0=''),
    84572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84572, CurrentID=0, Status='live', Symbol='GNPTG', Aliases=['C16orf27', 'GNPTAG', 'LP2537', 'RJD9'], description='N-acetylglucosamine-1-phosphate transferase subunit gamma', other_designations='N-acetylglucosamine-1-phosphotransferase subunit gamma|N-acetylglucosamine-1-phosphate transferase gamma subunit|UDP-N-acetylglucosamine-1-phosphotransferase subunit gamma|glcNAc-1-phosphotransferase subunit gamma', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1351931, end_position_on_the_genomic_accession=1364113, orientation='plus', exon_count=12, OMIM=[607838], no_hdr0=''),
    84612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84612, CurrentID=0, Status='live', Symbol='PARD6B', Aliases=['PAR6B'], description='par-6 family cell polarity regulator beta', other_designations='partitioning defective 6 homolog beta|PAR-6 beta|par-6 partitioning defective 6 homolog beta', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50731580, end_position_on_the_genomic_accession=50753741, orientation='plus', exon_count=3, OMIM=[608975], no_hdr0=''),
    84614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84614, CurrentID=0, Status='live', Symbol='ZBTB37', Aliases=['D430004I08Rik', 'ZNF908'], description='zinc finger and BTB domain containing 37', other_designations='zinc finger and BTB domain-containing protein 37', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173868082, end_position_on_the_genomic_accession=173903547, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    84616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84616, CurrentID=0, Status='live', Symbol='KRTAP4-4', Aliases=['KAP4.13', 'KAP4.4', 'KRTAP4-13', 'KRTAP4.13', 'KRTAP4.4'], description='keratin associated protein 4-4', other_designations='keratin-associated protein 4-4|keratin associated protein 4.4|keratin-associated protein 4-13|keratin-associated protein 4.13|ultrahigh sulfur keratin-associated protein 4.13|ultrahigh sulfur keratin-associated protein 4.4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41159649, end_position_on_the_genomic_accession=41160748, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    84617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84617, CurrentID=0, Status='live', Symbol='TUBB6', Aliases=['FPVEPD', 'HsT1601', 'TUBB-5'], description='tubulin beta 6 class V', other_designations='tubulin beta-6 chain|class V beta-tubulin|tubulin beta MGC4083|tubulin beta class V|tubulin, beta 6', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12307669, end_position_on_the_genomic_accession=12329826, orientation='plus', exon_count=7, OMIM=[615103], no_hdr0=''),
    84618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84618, CurrentID=0, Status='live', Symbol='NT5C1A', Aliases=['CN-I', 'CN-IA', 'CN1', 'CN1A', 'CNI'], description="5'-nucleotidase, cytosolic IA", other_designations="cytosolic 5'-nucleotidase 1A|AMP-specific 5'-NT|cytosolic 5' nucleotidase, type 1A|cytosolic 5'-nucleotidase IA", map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39651229, end_position_on_the_genomic_accession=39672107, orientation='minus', exon_count=6, OMIM=[610525], no_hdr0=''),
    84619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84619, CurrentID=0, Status='live', Symbol='ZGPAT', Aliases=['GPATC6', 'GPATCH6', 'KIAA1847', 'ZC3H9', 'ZC3HDC9', 'ZIP'], description='zinc finger CCCH-type and G-patch domain containing', other_designations='zinc finger CCCH-type with G patch domain-containing protein|g patch domain-containing protein 6|zinc finger CCCH domain-containing protein 9|zinc finger and G patch domain-containing protein|zinc finger, CCCH-type with G patch domain', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63707442, end_position_on_the_genomic_accession=63736142, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84620, CurrentID=0, Status='live', Symbol='ST6GAL2', Aliases=['SIAT2', 'ST6GalII'], description='ST6 beta-galactoside alpha-2,6-sialyltransferase 2', other_designations='beta-galactoside alpha-2,6-sialyltransferase 2|CMP-N-acetylneuraminate-beta-galactosamide-alpha-2,6-sialyltransferase 2|ST6 beta-galactosamide alpha-2,6-sialyltranferase 2|alpha 2,6-ST 2|beta-galactoside alpha-2,6-sialyltransferase II|sialyltransferase 2 (monosialoganglioside sialyltransferase)', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=106801600, end_position_on_the_genomic_accession=106887410, orientation='minus', exon_count=13, OMIM=[608472], no_hdr0=''),
    84622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84622, CurrentID=0, Status='live', Symbol='ZNF594', Aliases=[], description='zinc finger protein 594', other_designations='zinc finger protein 594|zinc finger protein HZF18', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5174021, end_position_on_the_genomic_accession=5191883, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    84623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84623, CurrentID=0, Status='live', Symbol='KIRREL3', Aliases=['KIRRE', 'MRD4', 'NEPH2', 'PRO4502'], description='kirre like nephrin family adhesion molecule 3', other_designations='kin of IRRE-like protein 3|kin of IRRE like 3|kin of irregular chiasm-like protein 3|nephrin-like 2|nephrin-like protein 2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126423358, end_position_on_the_genomic_accession=127003460, orientation='minus', exon_count=19, OMIM=[607761], no_hdr0=''),
    84624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84624, CurrentID=0, Status='live', Symbol='FNDC1', Aliases=['AGS8', 'FNDC2', 'MEL4B3', 'bA243O10.1', 'dJ322A24.1'], description='fibronectin type III domain containing 1', other_designations='fibronectin type III domain-containing protein 1|activation-associated cDNA protein|expressed in synovial lining protein|fibronectin type III domain containing 2', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159169400, end_position_on_the_genomic_accession=159272108, orientation='plus', exon_count=23, OMIM=[609991], no_hdr0=''),
    84626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84626, CurrentID=0, Status='live', Symbol='KRBA1', Aliases=[], description='KRAB-A domain containing 1', other_designations='protein KRBA1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149714945, end_position_on_the_genomic_accession=149734575, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    84627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84627, CurrentID=0, Status='live', Symbol='ZNF469', Aliases=['BCS', 'BCS1', 'Zfp469'], description='zinc finger protein 469', other_designations='zinc finger protein 469', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88382959, end_position_on_the_genomic_accession=88440753, orientation='plus', exon_count=4, OMIM=[612078], no_hdr0=''),
    84628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84628, CurrentID=0, Status='live', Symbol='NTNG2', Aliases=['LHLL9381', 'Lmnt2', 'NEDBASH', 'NTNG1', 'bA479K20.1'], description='netrin G2', other_designations='netrin-G2|laminet 2|netrin G1', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132161234, end_position_on_the_genomic_accession=132244534, orientation='plus', exon_count=22, OMIM=[618689], no_hdr0=''),
    84629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84629, CurrentID=0, Status='live', Symbol='TNRC18', Aliases=['CAGL79A', 'TNRC18'], description='trinucleotide repeat containing 18', other_designations='trinucleotide repeat-containing gene 18 protein|long CAG trinucleotide repeat-containing gene 79 protein', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5306790, end_position_on_the_genomic_accession=5423843, orientation='minus', exon_count=37, OMIM=[], no_hdr0=''),
    84630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84630, CurrentID=0, Status='live', Symbol='TTBK1', Aliases=['BDTK'], description='tau tubulin kinase 1', other_designations='tau-tubulin kinase 1|brain-derived tau kinase', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43243481, end_position_on_the_genomic_accession=43288259, orientation='plus', exon_count=17, OMIM=[619415], no_hdr0=''),
    84631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84631, CurrentID=0, Status='live', Symbol='SLITRK2', Aliases=['CXorf1', 'CXorf2', 'SLITL1', 'TMEM257'], description='SLIT and NTRK like family member 2', other_designations='SLIT and NTRK-like protein 2|slit and trk like gene 2|slit-like 1|transmembrane protein 257', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=145817829, end_position_on_the_genomic_accession=145829856, orientation='plus', exon_count=5, OMIM=[300561], no_hdr0=''),
    84632 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84632, CurrentID=0, Status='live', Symbol='AFAP1L2', Aliases=['CTB-1144G6.4', 'KIAA1914', 'XB130'], description='actin filament associated protein 1 like 2', other_designations='actin filament-associated protein 1-like 2|AFAP1-like protein 2|CTB-1144G6.6', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114280760, end_position_on_the_genomic_accession=114404672, orientation='minus', exon_count=24, OMIM=[612420], no_hdr0=''),
    84634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84634, CurrentID=0, Status='live', Symbol='KISS1R', Aliases=['AXOR12', 'CPPB1', 'GPR54', 'HH8', 'HOT7T175', 'KISS-1R'], description='KISS1 receptor', other_designations='kiSS-1 receptor|G protein-coupled receptor 54|G-protein coupled receptor OT7T175|hypogonadotropin-1|kisspeptins receptor|metastin receptor', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=916693, end_position_on_the_genomic_accession=921005, orientation='plus', exon_count=5, OMIM=[604161], no_hdr0=''),
    84636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84636, CurrentID=0, Status='live', Symbol='GPR174', Aliases=['FKSG79', 'GPCR17', 'LYPSR3'], description='G protein-coupled receptor 174', other_designations='probable G-protein coupled receptor 174', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=79144688, end_position_on_the_genomic_accession=79175318, orientation='plus', exon_count=3, OMIM=[300903], no_hdr0=''),
    84639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84639, CurrentID=0, Status='live', Symbol='IL1F10', Aliases=['FIL1-theta', 'FKSG75', 'IL-1HY2', 'IL-38', 'IL1-theta', 'IL1HY2'], description='interleukin 1 family member 10', other_designations='interleukin-1 family member 10|FIL1 theta|IL-1 theta|IL-1F10 (canonical form IL-1F10a)|family of interleukin 1-theta|interleukin 1 family member 10 (theta)|interleukin-1 HY2|interleukin-1 receptor antagonist FKSG75|interleukin-1 receptor antagonist-like FIL1 theta|interleukin-38', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113067970, end_position_on_the_genomic_accession=113075843, orientation='plus', exon_count=5, OMIM=[615296], no_hdr0=''),
    84640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84640, CurrentID=0, Status='live', Symbol='USP38', Aliases=['HP43.8KD'], description='ubiquitin specific peptidase 38', other_designations='ubiquitin carboxyl-terminal hydrolase 38|deubiquitinating enzyme 38|ubiquitin specific protease 38|ubiquitin thioesterase 38|ubiquitin thiolesterase 38|ubiquitin-specific-processing protease 38', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143184917, end_position_on_the_genomic_accession=143224429, orientation='plus', exon_count=11, OMIM=[618322], no_hdr0=''),
    84641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84641, CurrentID=0, Status='live', Symbol='MFSD14B', Aliases=['HIATL1'], description='major facilitator superfamily domain containing 14B', other_designations='hippocampus abundant transcript-like protein 1|hippocampus abundant transcript-like 1', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94374327, end_position_on_the_genomic_accession=94461042, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    84643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84643, CurrentID=0, Status='live', Symbol='KIF2B', Aliases=[], description='kinesin family member 2B', other_designations='kinesin-like protein KIF2B|kinesin protein|testis tissue sperm-binding protein Li 82P', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=53822927, end_position_on_the_genomic_accession=53825193, orientation='plus', exon_count=1, OMIM=[615142], no_hdr0=''),
    84645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84645, CurrentID=0, Status='live', Symbol='C22orf23', Aliases=['EVG1', 'dJ1039K5.6'], description='chromosome 22 open reading frame 23', other_designations='UPF0193 protein EVG1', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37943050, end_position_on_the_genomic_accession=37953669, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    84647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84647, CurrentID=0, Status='live', Symbol='PLA2G12B', Aliases=['FKSG71', 'GXIIB', 'GXIIIsPLA2', 'PLA2G13', 'sPLA2-GXIIB'], description='phospholipase A2 group XIIB', other_designations='group XIIB secretory phospholipase A2-like protein|group XIII secreted phospholipase A2|phospholipase A2, group XIII', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72934762, end_position_on_the_genomic_accession=72955044, orientation='minus', exon_count=4, OMIM=[611653], no_hdr0=''),
    84648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84648, CurrentID=0, Status='live', Symbol='LCE3D', Aliases=['LEP16', 'SPRL6A', 'SPRL6B'], description='late cornified envelope 3D', other_designations='late cornified envelope protein 3D|late envelope protein 16|small proline rich-like (epidermal differentiation complex) 6A|small proline rich-like (epidermal differentiation complex) 6B|small proline-rich-like epidermal differentiation complex protein 6A|small proline-rich-like epidermal differentiation complex protein 6B', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152579381, end_position_on_the_genomic_accession=152580516, orientation='minus', exon_count=2, OMIM=[612616], no_hdr0=''),
    84649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84649, CurrentID=0, Status='live', Symbol='DGAT2', Aliases=['ARAT', 'GS1999FULL', 'HMFN1045'], description='diacylglycerol O-acyltransferase 2', other_designations='diacylglycerol O-acyltransferase 2|acyl-CoA retinol O-fatty-acyltransferase|diacylglycerol O-acyltransferase homolog 2|diacylglycerol O-acyltransferase-like protein 2|diglyceride acyltransferase 2', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75768778, end_position_on_the_genomic_accession=75801534, orientation='plus', exon_count=9, OMIM=[606983], no_hdr0=''),
    84650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84650, CurrentID=0, Status='live', Symbol='EBPL', Aliases=['EBRP'], description='EBP like', other_designations='emopamil-binding protein-like|emopamil binding protein like|emopamil binding related protein, delta8-delta7 sterol isomerase related protein|emopamil-binding-related protein', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49660674, end_position_on_the_genomic_accession=49691487, orientation='minus', exon_count=6, OMIM=[617335], no_hdr0=''),
    84651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84651, CurrentID=0, Status='live', Symbol='SPINK7', Aliases=['ECG2', 'ECRG2'], description='serine peptidase inhibitor Kazal type 7', other_designations='serine protease inhibitor Kazal-type 7|ECRG-2|esophagus cancer-related gene 2 protein|esophagus cancer-related gene-2|serine peptidase inhibitor, Kazal type 7 (putative)', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148312423, end_position_on_the_genomic_accession=148315919, orientation='plus', exon_count=4, OMIM=[617288], no_hdr0=''),
    84654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84654, CurrentID=0, Status='live', Symbol='SPZ1', Aliases=['CILD38', 'NYD-TSP1', 'PPP1R148'], description='spermatogenic leucine zipper 1', other_designations='spermatogenic leucine zipper protein 1|protein phosphatase 1, regulatory subunit 148|spermatogenic zip 1|testis secretory sperm-binding protein Li 232m|testis-specific protein 1', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80320002, end_position_on_the_genomic_accession=80321842, orientation='plus', exon_count=1, OMIM=[618068], no_hdr0=''),
    84656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84656, CurrentID=0, Status='live', Symbol='GLYR1', Aliases=['BM045', 'HIBDL', 'N-PAC', 'NP60', 'hNDF'], description='glyoxylate reductase 1 homolog', other_designations='putative oxidoreductase GLYR1|3-hydroxyisobutyrate dehydrogenase-like protein|cytokine-like nuclear factor n-pac|nuclear protein 60 kDa|nuclear protein 60kDa|nuclear protein NP60|nuclear protein of 60 kDa|nucleosome-destabilizing factor', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4803203, end_position_on_the_genomic_accession=4848032, orientation='minus', exon_count=18, OMIM=[610660], no_hdr0=''),
    84658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84658, CurrentID=0, Status='live', Symbol='ADGRE3', Aliases=['EMR3'], description='adhesion G protein-coupled receptor E3', other_designations='adhesion G protein-coupled receptor E3|EGF-like module receptor 3|EGF-like module-containing mucin-like hormone receptor-like 3|egf-like module containing, mucin-like, hormone receptor-like 3|egf-like module-containing mucin-like receptor 3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14600175, end_position_on_the_genomic_accession=14674860, orientation='minus', exon_count=17, OMIM=[606101], no_hdr0=''),
    84659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84659, CurrentID=0, Status='live', Symbol='RNASE7', Aliases=['RAE1'], description='ribonuclease A family member 7', other_designations='ribonuclease 7|RNase 7|SAP-2|ribonuclease, RNase A family, 7|skin-derived antimicrobial protein 2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21042362, end_position_on_the_genomic_accession=21044233, orientation='plus', exon_count=2, OMIM=[612484], no_hdr0=''),
    84660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84660, CurrentID=0, Status='live', Symbol='CCDC62', Aliases=['CT109', 'ERAP75', 'TSP-NY'], description='coiled-coil domain containing 62', other_designations='coiled-coil domain-containing protein 62|aaa-protein|cancer/testis antigen 109|coiled-coil domain-containing protein 60|testis-specific protein TSP-NY', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122773621, end_position_on_the_genomic_accession=122827528, orientation='plus', exon_count=15, OMIM=[613481], no_hdr0=''),
    84661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84661, CurrentID=0, Status='live', Symbol='DPY30', Aliases=['Cps25', 'HDPY-30', 'Saf19'], description='dpy-30 histone methyltransferase complex regulatory subunit', other_designations='protein dpy-30 homolog|dpy-30 homolog|dpy-30-like protein|dpy-30L', map_location='2p22.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=32011649, end_position_on_the_genomic_accession=32039840, orientation='minus', exon_count=10, OMIM=[612032], no_hdr0=''),
    84662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84662, CurrentID=0, Status='live', Symbol='GLIS2', Aliases=['NKL', 'NPHP7'], description='GLIS family zinc finger 2', other_designations='zinc finger protein GLIS2|GLI-similar 2|Kruppel-like zinc finger protein GLIS2|nephrocystin-7|neuronal Krueppel-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4314761, end_position_on_the_genomic_accession=4339595, orientation='plus', exon_count=9, OMIM=[608539], no_hdr0=''),
    84665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84665, CurrentID=0, Status='live', Symbol='MYPN', Aliases=['CMD1DD', 'CMH22', 'MYOP', 'NEM11', 'RCM4'], description='myopalladin', other_designations='myopalladin|sarcomeric protein myopalladin, 145 kDa (MYOP)', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68087907, end_position_on_the_genomic_accession=68212017, orientation='plus', exon_count=27, OMIM=[608517], no_hdr0=''),
    84666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84666, CurrentID=0, Status='live', Symbol='RETNLB', Aliases=['FIZZ1', 'FIZZ2', 'HXCP2', 'RELM-beta', 'RELMb', 'RELMbeta', 'XCP2'], description='resistin like beta', other_designations='resistin-like beta|C/EBP-epsilon regulated myeloid-specific secreted cysteine-rich protein precursor 2|colon and small intestine-specific cysteine-rich protein|colon carcinoma-related gene protein|cysteine-rich secreted A12-alpha-like protein 1|cysteine-rich secreted protein A12-alpha-like 1|cysteine-rich secreted protein FIZZ2|found in inflammatory zone 1', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=108755638, end_position_on_the_genomic_accession=108757410, orientation='minus', exon_count=3, OMIM=[605645], no_hdr0=''),
    84667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84667, CurrentID=0, Status='live', Symbol='HES7', Aliases=['SCDO4', 'bHLHb37'], description='hes family bHLH transcription factor 7', other_designations='transcription factor HES-7|bHLH factor Hes7|class B basic helix-loop-helix protein 37|hHes7|hairy and enhancer of split 7', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8120590, end_position_on_the_genomic_accession=8126032, orientation='minus', exon_count=5, OMIM=[608059], no_hdr0=''),
    84668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84668, CurrentID=0, Status='live', Symbol='FAM126A', Aliases=['DRCTNNB1A', 'HCC', 'HLD5', 'HYCC1'], description='family with sequence similarity 126 member A', other_designations='hyccin|down regulated by Ctnnb1, a|down-regulated by CTNNB1 protein A', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=22895848, end_position_on_the_genomic_accession=23014133, orientation='minus', exon_count=14, OMIM=[610531], no_hdr0=''),
    84669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84669, CurrentID=0, Status='live', Symbol='USP32', Aliases=['NY-REN-60', 'USP10'], description='ubiquitin specific peptidase 32', other_designations='ubiquitin carboxyl-terminal hydrolase 32|deubiquitinating enzyme 32|renal carcinoma antigen NY-REN-60|ubiquitin specific protease 32|ubiquitin thioesterase 32|ubiquitin thiolesterase 32|ubiquitin-specific-processing protease 32', map_location='17q23.1-q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60177231, end_position_on_the_genomic_accession=60422470, orientation='minus', exon_count=39, OMIM=[607740], no_hdr0=''),
    84671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84671, CurrentID=0, Status='live', Symbol='ZNF347', Aliases=['ZNF1111'], description='zinc finger protein 347', other_designations='zinc finger protein 347|CTD-2620I22.7|zinc finger 1111|zinc finger protein 1111', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53134935, end_position_on_the_genomic_accession=53159053, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    84674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84674, CurrentID=0, Status='live', Symbol='CARD6', Aliases=['CINCIN1'], description='caspase recruitment domain family member 6', other_designations='caspase recruitment domain-containing protein 6|CARD-containing inhibitor of Nod1 and Cardiak-induced NF-kB activation|caspase recruitment domain protein 6', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40841197, end_position_on_the_genomic_accession=40855354, orientation='plus', exon_count=4, OMIM=[609986], no_hdr0=''),
    84675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84675, CurrentID=0, Status='live', Symbol='TRIM55', Aliases=['MURF-2', 'RNF29', 'muRF2'], description='tripartite motif containing 55', other_designations='tripartite motif-containing protein 55|muscle specific ring finger 2|muscle-specific RING finger protein 2|ring finger protein 29', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66112667, end_position_on_the_genomic_accession=66175485, orientation='plus', exon_count=14, OMIM=[606469], no_hdr0=''),
    84676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84676, CurrentID=0, Status='live', Symbol='TRIM63', Aliases=['IRF', 'MURF1', 'MURF2', 'RNF28', 'SMRZ'], description='tripartite motif containing 63', other_designations='E3 ubiquitin-protein ligase TRIM63|RING-type E3 ubiquitin transferase TRIM63|iris ring finger protein|muscle specific ring finger protein 2|muscle-specific RING finger protein 1|ring finger protein 28|striated muscle RING zinc finger protein|tripartite motif containing 63, E3 ubiquitin protein ligase|tripartite motif-containing protein 63', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26051301, end_position_on_the_genomic_accession=26067633, orientation='minus', exon_count=9, OMIM=[606131], no_hdr0=''),
    84678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84678, CurrentID=0, Status='live', Symbol='KDM2B', Aliases=['CXXC2', 'FBXL10', 'Fbl10', 'JHDM1B', 'PCCX2'], description='lysine demethylase 2B', other_designations='lysine-specific demethylase 2B|CXXC-type zinc finger protein 2|F-box and leucine-rich repeat protein 10|F-box protein FBL10|F-box/LRR-repeat protein 10|JEMMA (Jumonji domain, EMSY-interactor, methyltransferase motif) protein|[Histone-H3]-lysine-36 demethylase 1B|jmjC domain-containing histone demethylation protein 1B|jumonji C domain-containing histone demethylase 1B|lysine (K)-specific demethylase 2B|protein-containing CXXC domain 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121402288, end_position_on_the_genomic_accession=121582268, orientation='minus', exon_count=29, OMIM=[609078], no_hdr0=''),
    84679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84679, CurrentID=0, Status='live', Symbol='SLC9A7', Aliases=['MRX108', 'NHE-7', 'NHE7', 'SLC9A6'], description='solute carrier family 9 member A7', other_designations='sodium/hydrogen exchanger 7|Na(+)/H(+) exchanger 7|nonselective sodium potassium/proton exchanger|solute carrier family 9 (sodium/hydrogen exchanger)|solute carrier family 9, subfamily A (NHE7, cation proton antiporter 7), member 7', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46599251, end_position_on_the_genomic_accession=46759163, orientation='minus', exon_count=19, OMIM=[300368], no_hdr0=''),
    84680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84680, CurrentID=0, Status='live', Symbol='ACCS', Aliases=['ACS', 'PHACS'], description='1-aminocyclopropane-1-carboxylate synthase homolog (inactive)', other_designations='1-aminocyclopropane-1-carboxylate synthase-like protein 1|ACC synthase-like protein 1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44066118, end_position_on_the_genomic_accession=44084237, orientation='plus', exon_count=20, OMIM=[608405], no_hdr0=''),
    84681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84681, CurrentID=0, Status='live', Symbol='HINT2', Aliases=['HIT-17'], description='histidine triad nucleotide binding protein 2', other_designations='histidine triad nucleotide-binding protein 2, mitochondrial|HINT-2|HINT-3|HIT-17kDa|PKCI-1-related HIT protein|protein kinase C inhibitor-2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35812960, end_position_on_the_genomic_accession=35815479, orientation='minus', exon_count=6, OMIM=[609997], no_hdr0=''),
    84684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84684, CurrentID=0, Status='live', Symbol='INSM2', Aliases=['IA-6', 'IA6', 'mlt1'], description='INSM transcriptional repressor 2', other_designations='insulinoma-associated protein 2|INSM2 variant 1|insulinoma-associated 2|insulinoma-associated protein IA-6|zinc finger protein IA-6', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35534164, end_position_on_the_genomic_accession=35537054, orientation='plus', exon_count=1, OMIM=[614027], no_hdr0=''),
    84687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84687, CurrentID=0, Status='live', Symbol='PPP1R9B', Aliases=['PPP1R6', 'PPP1R9', 'SPINO', 'Spn'], description='protein phosphatase 1 regulatory subunit 9B', other_designations='neurabin-2|neurabin-II|protein phosphatase 1, regulatory (inhibitor) subunit 9B|protein phosphatase 1, regulatory subunit 9B, spinophilin', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50133737, end_position_on_the_genomic_accession=50150677, orientation='minus', exon_count=10, OMIM=[603325], no_hdr0=''),
    84688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84688, CurrentID=0, Status='live', Symbol='C9orf24', Aliases=['CBE1', 'NYD-SP22', 'SMRP1', 'bA573M23.4'], description='chromosome 9 open reading frame 24', other_designations='spermatid-specific manchette-related protein 1|ciliated bronchial epithelial protein 1|ciliated bronchial epithelium 1|testis development protein NYD-SP22', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34378463, end_position_on_the_genomic_accession=34397942, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    84689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84689, CurrentID=0, Status='live', Symbol='MS4A14', Aliases=['MS4A16', 'NYD-SP21'], description='membrane spanning 4-domains A14', other_designations='membrane-spanning 4-domains subfamily A member 14|MS4A13 protein|membrane-spanning 4-domains, subfamily A, member 16|testes development-related NYD-SP21|testis development protein NYD-SP21', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60396459, end_position_on_the_genomic_accession=60417756, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    84690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84690, CurrentID=0, Status='live', Symbol='SPATA22', Aliases=['NYD-SP20', 'NYDSP20'], description='spermatogenesis associated 22', other_designations='spermatogenesis-associated protein 22|testicular tissue protein Li 186|testis development protein NYD-SP20', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3440019, end_position_on_the_genomic_accession=3513858, orientation='minus', exon_count=10, OMIM=[617673], no_hdr0=''),
    84691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84691, CurrentID=0, Status='live', Symbol='FAM71F1', Aliases=['FAM137A', 'NYD-SP18'], description='family with sequence similarity 71 member F1', other_designations='protein FAM71F1|family with sequence similarity 137, member A|testes development-related NYD-SP18|testicular tissue protein Li 67|testis development protein NYD-SP18', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128709061, end_position_on_the_genomic_accession=128731743, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    84692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84692, CurrentID=0, Status='live', Symbol='CCDC54', Aliases=['NYD-SP17', 'SP17'], description='coiled-coil domain containing 54', other_designations='coiled-coil domain-containing protein 54|sperm protein 17|testes development-related NYD-SP17|testicular tissue protein Li 33|testis development protein NYD-SP17', map_location='3q13.12', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=107377439, end_position_on_the_genomic_accession=107378635, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    84693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84693, CurrentID=0, Status='live', Symbol='MCEE', Aliases=['GLOD2', 'MCE'], description='methylmalonyl-CoA epimerase', other_designations='methylmalonyl-CoA epimerase, mitochondrial|DL-methylmalonyl-CoA racemase|glyoxalase domain containing 2|methylmalonyl CoA isomerase', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71109684, end_position_on_the_genomic_accession=71130288, orientation='minus', exon_count=4, OMIM=[608419], no_hdr0=''),
    84694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84694, CurrentID=0, Status='live', Symbol='GJA10', Aliases=['CX62'], description='gap junction protein alpha 10', other_designations='gap junction alpha-10 protein|connexin 62|gap junction protein, alpha 10, 62kDa', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89894469, end_position_on_the_genomic_accession=89896120, orientation='plus', exon_count=1, OMIM=[611924], no_hdr0=''),
    84695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84695, CurrentID=0, Status='live', Symbol='LOXL3', Aliases=['LOXL'], description='lysyl oxidase like 3', other_designations='lysyl oxidase homolog 3|lysyl oxidase-like protein 3', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74532258, end_position_on_the_genomic_accession=74555719, orientation='minus', exon_count=16, OMIM=[607163], no_hdr0=''),
    84696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84696, CurrentID=0, Status='live', Symbol='ABHD1', Aliases=['LABH1'], description='abhydrolase domain containing 1', other_designations='protein ABHD1|abhydrolase domain-containing protein 1|alpha/beta hydrolase domain-containing protein 1|lung alpha/beta hydrolase 1|testicular tissue protein Li 5', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27123780, end_position_on_the_genomic_accession=27131114, orientation='plus', exon_count=8, OMIM=[612195], no_hdr0=''),
    84698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84698, CurrentID=0, Status='live', Symbol='CAPS2', Aliases=['UG0636c06'], description='calcyphosine 2', other_designations='calcyphosin-2|calcyphosphine 2', map_location='12q21.1-q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75275979, end_position_on_the_genomic_accession=75390914, orientation='minus', exon_count=22, OMIM=[607724], no_hdr0=''),
    84699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84699, CurrentID=0, Status='live', Symbol='CREB3L3', Aliases=['CREB-H', 'CREBH', 'HYST1481', 'HYTG2'], description='cAMP responsive element binding protein 3 like 3', other_designations='cyclic AMP-responsive element-binding protein 3-like protein 3|CREB/ATF family transcription factor|cAMP-responsive element-binding protein, hepatic-specific', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4153631, end_position_on_the_genomic_accession=4173054, orientation='plus', exon_count=10, OMIM=[611998], no_hdr0=''),
    84700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84700, CurrentID=0, Status='live', Symbol='MYO18B', Aliases=['KFS4'], description='myosin XVIIIB', other_designations='unconventional myosin-XVIIIb|myosin 18B', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=25742133, end_position_on_the_genomic_accession=26063847, orientation='plus', exon_count=52, OMIM=[607295], no_hdr0=''),
    84701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84701, CurrentID=0, Status='live', Symbol='COX4I2', Aliases=['COX4', 'COX4-2', 'COX4B', 'COX4L2', 'COXIV-2', 'dJ857M17.2'], description='cytochrome c oxidase subunit 4I2', other_designations='cytochrome c oxidase subunit 4 isoform 2, mitochondrial|COX IV-2|cytochrome c oxidase subunit IV-like 2', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31637856, end_position_on_the_genomic_accession=31645009, orientation='plus', exon_count=6, OMIM=[607976], no_hdr0=''),
    84705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84705, CurrentID=0, Status='live', Symbol='GTPBP3', Aliases=['COXPD23', 'GTPBG3', 'MSS1', 'MTGP1', 'THDF1'], description='GTP binding protein 3, mitochondrial', other_designations='tRNA modification GTPase GTPBP3, mitochondrial|mitochondrial GTP-binding protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17334982, end_position_on_the_genomic_accession=17342731, orientation='plus', exon_count=10, OMIM=[608536], no_hdr0=''),
    84706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84706, CurrentID=0, Status='live', Symbol='GPT2', Aliases=['ALT2', 'GPT 2', 'MRT49', 'NEDSPM'], description='glutamic--pyruvic transaminase 2', other_designations='alanine aminotransferase 2|glutamate pyruvate transaminase 2|glutamic pyruvate transaminase (alanine aminotransferase) 2|glutamic pyruvate transaminase 2|glutamic--alanine transaminase 2', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46884362, end_position_on_the_genomic_accession=46931289, orientation='plus', exon_count=14, OMIM=[138210], no_hdr0=''),
    84707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84707, CurrentID=0, Status='live', Symbol='BEX2', Aliases=['BEX1', 'DJ79P11.1'], description='brain expressed X-linked 2', other_designations='protein BEX2|brain-expressed X-linked protein 2|hBex2', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103309346, end_position_on_the_genomic_accession=103310990, orientation='minus', exon_count=3, OMIM=[300691], no_hdr0=''),
    84708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84708, CurrentID=0, Status='live', Symbol='LNX1', Aliases=['LNX', 'MPDZ', 'PDZRN2'], description='ligand of numb-protein X 1', other_designations='E3 ubiquitin-protein ligase LNX|PDZ domain-containing ring finger protein 2|RING-type E3 ubiquitin transferase LNX|ligand of numb-protein X 1, E3 ubiquitin protein ligase|multi-PDZ-domain-containing protein, E3 ubiquitin-protein ligase LNX|numb-binding protein 1', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=53458264, end_position_on_the_genomic_accession=53652525, orientation='minus', exon_count=15, OMIM=[609732], no_hdr0=''),
    84709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84709, CurrentID=0, Status='live', Symbol='MGARP', Aliases=['C4orf49', 'CESP-1', 'HUMMR', 'OSAP'], description='mitochondria localized glutamic acid rich protein', other_designations='protein MGARP|corneal endothelium-specific protein 1|hypoxia up-regulated mitochondrial movement regulator protein|ovary-specific acidic protein', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=139266165, end_position_on_the_genomic_accession=139280225, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    84717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84717, CurrentID=0, Status='live', Symbol='HDGFL2', Aliases=['HDGF-2', 'HDGF2', 'HDGFRP2', 'HRP-2', 'HRP2'], description='HDGF like 2', other_designations='hepatoma-derived growth factor-related protein 2|HDGF-related protein 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4472297, end_position_on_the_genomic_accession=4502220, orientation='plus', exon_count=17, OMIM=[617884], no_hdr0=''),
    84720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84720, CurrentID=0, Status='live', Symbol='PIGO', Aliases=['HPMRS2'], description='phosphatidylinositol glycan anchor biosynthesis class O', other_designations='GPI ethanolamine phosphate transferase 3|phosphatidylinositol-glycan biosynthesis class O protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35085496, end_position_on_the_genomic_accession=35096591, orientation='minus', exon_count=12, OMIM=[614730], no_hdr0=''),
    84722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84722, CurrentID=0, Status='live', Symbol='PSRC1', Aliases=['DDA3', 'FP3214'], description='proline and serine rich coiled-coil 1', other_designations='proline/serine-rich coiled-coil protein 1|differential display and activated by p53|p53-regulated DDA3|proline/serine-rich coiled-coil 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109279556, end_position_on_the_genomic_accession=109283172, orientation='minus', exon_count=7, OMIM=[613126], no_hdr0=''),
    84725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84725, CurrentID=0, Status='live', Symbol='PLEKHA8', Aliases=['FAPP2'], description='pleckstrin homology domain containing A8', other_designations='pleckstrin homology domain-containing family A member 8|PH domain-containing family A member 8|phosphatidylinositol 4-phosphate adaptor protein-2|phosphatidylinositol-four-phosphate adapter protein 2|phosphoinositol 4-phosphate adapter protein 2|pleckstrin homology domain containing, family A (phosphoinositide binding specific) member 8|serologically defined breast cancer antigen NY-BR-86', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30028412, end_position_on_the_genomic_accession=30130483, orientation='plus', exon_count=19, OMIM=[608639], no_hdr0=''),
    84726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84726, CurrentID=0, Status='live', Symbol='PRRC2B', Aliases=['BAT2L', 'BAT2L1', 'KIAA0515', 'LQFBS-1'], description='proline rich coiled-coil 2B', other_designations='protein PRRC2B|HLA-B associated transcript 2-like|HLA-B-associated transcript 2-like 1|proline-rich coiled-coil protein 2B|protein BAT2-like 1', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131373651, end_position_on_the_genomic_accession=131500193, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    84727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84727, CurrentID=0, Status='live', Symbol='SPSB2', Aliases=['GRCC9', 'SSB2'], description='splA/ryanodine receptor domain and SOCS box containing 2', other_designations='SPRY domain-containing SOCS box protein 2|SPRY domain-containing SOCS box protein SSB-2|gene-rich cluster protein C9', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6870935, end_position_on_the_genomic_accession=6873303, orientation='minus', exon_count=3, OMIM=[611658], no_hdr0=''),
    84733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84733, CurrentID=0, Status='live', Symbol='CBX2', Aliases=['CDCA6', 'M33', 'SRXY5'], description='chromobox 2', other_designations='chromobox protein homolog 2|Pc class homolog|cell division cycle associated 6|chromobox homolog 2 (Pc class homolog, Drosophila)|modifier 3', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79776254, end_position_on_the_genomic_accession=79787983, orientation='plus', exon_count=7, OMIM=[602770], no_hdr0=''),
    84734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84734, CurrentID=0, Status='live', Symbol='FAM167B', Aliases=['C1orf90', 'DIORA-2'], description='family with sequence similarity 167 member B', other_designations='protein FAM167B|disordered autoimmunity 2', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32247222, end_position_on_the_genomic_accession=32248856, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    84735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84735, CurrentID=0, Status='live', Symbol='CNDP1', Aliases=['CN1', 'CPGL2', 'HsT2308'], description='carnosine dipeptidase 1', other_designations='beta-Ala-His dipeptidase|CNDP dipeptidase 1|carnosinase 1|carnosine dipeptidase 1 (metallopeptidase M20 family)|glutamate carboxypeptidase-like protein 2|serum carnosinase', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74534500, end_position_on_the_genomic_accession=74587212, orientation='plus', exon_count=12, OMIM=[609064], no_hdr0=''),
    84747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84747, CurrentID=0, Status='live', Symbol='UNC119B', Aliases=['POC7B'], description='unc-119 lipid binding chaperone B', other_designations='protein unc-119 homolog B|POC7 centriolar protein homolog B|unc-119 homolog B', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120710458, end_position_on_the_genomic_accession=120723640, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    84749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84749, CurrentID=0, Status='live', Symbol='USP30', Aliases=[], description='ubiquitin specific peptidase 30', other_designations='ubiquitin carboxyl-terminal hydrolase 30|deubiquitinating enzyme 30|ub-specific protease 30|ubiquitin thioesterase 30|ubiquitin thiolesterase 30|ubiquitin-specific protease 30|ubiquitin-specific-processing protease 30', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109023089, end_position_on_the_genomic_accession=109088026, orientation='plus', exon_count=18, OMIM=[612492], no_hdr0=''),
    84750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84750, CurrentID=0, Status='live', Symbol='FUT10', Aliases=['FUCTX'], description='fucosyltransferase 10', other_designations='alpha-(1,3)-fucosyltransferase 10|alpha (1,3) fucosyltransferase|alpha 1,3-fucosyl transferase|fuc-TX|fucT-X|fucosyltransferase X|galactoside 3-L-fucosyltransferase 10', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=33308102, end_position_on_the_genomic_accession=33473146, orientation='minus', exon_count=10, OMIM=[616931], no_hdr0=''),
    84752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84752, CurrentID=0, Status='live', Symbol='B3GNT9', Aliases=[], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 9', other_designations='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 9|BGnT-9|beta-1,3-Gn-T9|beta-1,3-N-acetylglucosaminyltransferase 9|beta-1,3-galactosyltransferase-related protein|beta3Gn-T9', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67148104, end_position_on_the_genomic_accession=67150998, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    84759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84759, CurrentID=0, Status='live', Symbol='PCGF1', Aliases=['2010002K04Rik', 'NSPC1', 'RNF3A-2', 'RNF68'], description='polycomb group ring finger 1', other_designations='polycomb group RING finger protein 1|RING finger protein 68|nervous system Polycomb-1', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74505043, end_position_on_the_genomic_accession=74507695, orientation='minus', exon_count=10, OMIM=[610231], no_hdr0=''),
    84765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84765, CurrentID=0, Status='live', Symbol='ZNF577', Aliases=[], description='zinc finger protein 577', other_designations='zinc finger protein 577', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51804442, end_position_on_the_genomic_accession=51887951, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    84766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84766, CurrentID=0, Status='live', Symbol='CRACR2A', Aliases=['EFCAB4B'], description='calcium release activated channel regulator 2A', other_designations='EF-hand calcium-binding domain-containing protein 4B|CRAC channel regulator 2A|CRAC regulator 2A|Ca2+ release-activated Ca2+ (CRAC) channel regulator 2A|EF-hand calcium binding domain 4B|calcium release-activated calcium channel regulator 2A|ras-related protein Rab-46', map_location='12p13.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=3613366, end_position_on_the_genomic_accession=3753218, orientation='minus', exon_count=22, OMIM=[614178], no_hdr0=''),
    84767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84767, CurrentID=0, Status='live', Symbol='TRIM51', Aliases=['SPRYD5A', 'TRIM51'], description='tripartite motif-containing 51', other_designations='tripartite motif-containing protein 51|SPRY domain containing 5|SPRY domain-containing protein 5', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55883297, end_position_on_the_genomic_accession=55891810, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    84769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84769, CurrentID=0, Status='live', Symbol='MPV17L2', Aliases=['FKSG24'], description='MPV17 mitochondrial inner membrane protein like 2', other_designations='mpv17-like protein 2|MPV17 mitochondrial membrane protein-like 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18193218, end_position_on_the_genomic_accession=18196948, orientation='plus', exon_count=5, OMIM=[616133], no_hdr0=''),
    84775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84775, CurrentID=0, Status='live', Symbol='ZNF607', Aliases=[], description='zinc finger protein 607', other_designations='zinc finger protein 607', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37696363, end_position_on_the_genomic_accession=37720165, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84779, CurrentID=0, Status='live', Symbol='NAA11', Aliases=['ARD1B', 'ARD2', 'hARD2'], description='N-alpha-acetyltransferase 11, NatA catalytic subunit', other_designations='N-alpha-acetyltransferase 11|=N-terminal acetyltransferase complex ARD1 subunit homolog B|ARD1 homolog B|N-terminal acetyltransferase complex ARD1 subunit homolog B|human arrest defective 2|natA catalytic subunit Naa11', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=79155237, end_position_on_the_genomic_accession=79326061, orientation='minus', exon_count=6, OMIM=[619432], no_hdr0=''),
    84787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84787, CurrentID=0, Status='live', Symbol='KMT5C', Aliases=['SUV420H2', 'Suv4-20h2'], description='lysine methyltransferase 5C', other_designations='histone-lysine N-methyltransferase KMT5C|[histone H4]-N-methyl-L-lysine20 N-methyltransferase KMT5B|[histone H4]-lysine20 N-methyltransferase KMT5B|histone-lysine N-methyltransferase SUV420H2|lysine (K)-specific methyltransferase 5C|lysine N-methyltransferase 5C|lysine-specific methyltransferase 5C|su(var)4-20 homolog 2|suppressor of variegation 4-20 homolog 2', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55339876, end_position_on_the_genomic_accession=55348121, orientation='plus', exon_count=11, OMIM=[613198], no_hdr0=''),
    84790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84790, CurrentID=0, Status='live', Symbol='TUBA1C', Aliases=['TUBA6', 'bcm948'], description='tubulin alpha 1c', other_designations='tubulin alpha-1C chain|alpha-tubulin 6|tubulin alpha-6 chain|tubulin, alpha 6', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49227926, end_position_on_the_genomic_accession=49274600, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    84792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84792, CurrentID=0, Status='live', Symbol='FAM220A', Aliases=['ACPIN1', 'C7orf70', 'SIPAR'], description='family with sequence similarity 220 member A', other_designations='protein FAM220A|STAT3-interacting protein as a repressor|acrosomal protein 1', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6329411, end_position_on_the_genomic_accession=6348967, orientation='minus', exon_count=2, OMIM=[616628], no_hdr0=''),
    84795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84795, CurrentID=0, Status='live', Symbol='PYROXD2', Aliases=['C10orf33', 'FP3420', 'YUEF'], description='pyridine nucleotide-disulphide oxidoreductase domain 2', other_designations='pyridine nucleotide-disulfide oxidoreductase domain-containing protein 2', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=98383565, end_position_on_the_genomic_accession=98415182, orientation='minus', exon_count=24, OMIM=[617889], no_hdr0=''),
    84803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84803, CurrentID=0, Status='live', Symbol='GPAT3', Aliases=['AGPAT 10', 'AGPAT10', 'AGPAT8', 'AGPAT9', 'HMFN0839', 'LPAAT-theta', 'MAG1'], description='glycerol-3-phosphate acyltransferase 3', other_designations='glycerol-3-phosphate acyltransferase 3|1-AGP acyltransferase 9|1-AGPAT 9|1-acyl-sn-glycerol-3-phosphate O-acyltransferase 10|1-acyl-sn-glycerol-3-phosphate O-acyltransferase 9|1-acylglycerol-3-phosphate O-acyltransferase 8|1-acylglycerol-3-phosphate O-acyltransferase 9|GPAT-3|MAG-1|acyl-CoA:glycerol-3-phosphate acyltransferase 3|endoplasmic reticulum associated GPAT|hGPAT3|lung cancer metastasis-associated protein 1|lysophosphatidic acid acyltransferase theta|testis secretory sperm-binding protein Li 213e', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83535634, end_position_on_the_genomic_accession=83605875, orientation='plus', exon_count=16, OMIM=[610958], no_hdr0=''),
    84804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84804, CurrentID=0, Status='live', Symbol='MFSD9', Aliases=[], description='major facilitator superfamily domain containing 9', other_designations='major facilitator superfamily domain-containing protein 9', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102713867, end_position_on_the_genomic_accession=102736888, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    84807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84807, CurrentID=0, Status='live', Symbol='NFKBID', Aliases=['IkBNS', 'IkappaBNS', 'TA-NFKBH'], description='NFKB inhibitor delta', other_designations='NF-kappa-B inhibitor delta|I-kappa-B-delta|T-cell activation NFKB-like protein|ikB-delta|ikappaBdelta|nuclear factor of kappa light polypeptide gene enhancer in B-cells inhibitor, delta', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35887630, end_position_on_the_genomic_accession=35902303, orientation='minus', exon_count=18, OMIM=[618887], no_hdr0=''),
    84808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84808, CurrentID=0, Status='live', Symbol='PERM1', Aliases=['C1orf170'], description='PPARGC1 and ESRR induced regulator, muscle 1', other_designations='PGC-1 and ERR-induced regulator in muscle protein 1|PGC-1 and ERR-induced regulator in muscle 1|PPARGC1 and ESRR-induced regulator in muscle 1|pGC-1 and ERR-induced regulator in muscle protein 1|peroxisome proliferator-activated receptor gamma coactivator 1 and estrogen-related receptor-induced regulator in muscle 1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=975198, end_position_on_the_genomic_accession=982093, orientation='minus', exon_count=5, OMIM=[615921], no_hdr0=''),
    84811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84811, CurrentID=0, Status='live', Symbol='BUD13', Aliases=['Cwc26', 'fSAP71'], description='BUD13 homolog', other_designations='BUD13 homolog|functional spliceosome-associated protein 71', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116748170, end_position_on_the_genomic_accession=116772987, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    84812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84812, CurrentID=0, Status='live', Symbol='PLCD4', Aliases=[], description='phospholipase C delta 4', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase delta-4|PLC delta4|phosphoinositide phospholipase C-delta-4', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218606871, end_position_on_the_genomic_accession=218637186, orientation='plus', exon_count=17, OMIM=[605939], no_hdr0=''),
    84814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84814, CurrentID=0, Status='live', Symbol='PLPP7', Aliases=['C9orf67', 'NET39', 'PPAPDC3'], description='phospholipid phosphatase 7 (inactive)', other_designations='inactive phospholipid phosphatase 7|epididymis secretory sperm binding protein|nuclear envelope transmembrane protein NET39|phosphatidic acid phosphatase type 2 domain containing 3|phosphatidic acid phosphatase type 2 domain-containing protein 3|probable lipid phosphate phosphatase PPAPDC3', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131289694, end_position_on_the_genomic_accession=131309261, orientation='plus', exon_count=4, OMIM=[618743], no_hdr0=''),
    84816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84816, CurrentID=0, Status='live', Symbol='RTN4IP1', Aliases=['NIMP', 'OPA10'], description='reticulon 4 interacting protein 1', other_designations='reticulon-4-interacting protein 1, mitochondrial|NOGO-interacting mitochondrial protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106559237, end_position_on_the_genomic_accession=106630921, orientation='minus', exon_count=13, OMIM=[610502], no_hdr0=''),
    84817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84817, CurrentID=0, Status='live', Symbol='TXNDC17', Aliases=['TRP14', 'TXNL5'], description='thioredoxin domain containing 17', other_designations='thioredoxin domain-containing protein 17|14 kDa thioredoxin-related protein|protein 42-9-9|testicular tissue protein Li 214|thioredoxin (Trx)-related protein, 14 kDa|thioredoxin-like 5|thioredoxin-like protein 5', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6641060, end_position_on_the_genomic_accession=6644541, orientation='plus', exon_count=4, OMIM=[616967], no_hdr0=''),
    84818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84818, CurrentID=0, Status='live', Symbol='IL17RC', Aliases=['CANDF9', 'IL17-RL', 'IL17RL'], description='interleukin 17 receptor C', other_designations='interleukin-17 receptor C|IL-17 receptor C|IL-17RL|IL17F receptor|IL17Rhom|interleukin-17 receptor homolog|interleukin-17 receptor-like protein|zcytoR14', map_location='3p25.3-p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9917098, end_position_on_the_genomic_accession=9933627, orientation='plus', exon_count=19, OMIM=[610925], no_hdr0=''),
    84823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84823, CurrentID=0, Status='live', Symbol='LMNB2', Aliases=['EPM9', 'LAMB2', 'LMN2', 'MCPH27'], description='lamin B2', other_designations='lamin-B2|epididymis secretory sperm binding protein|lamin B3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2428166, end_position_on_the_genomic_accession=2456959, orientation='minus', exon_count=12, OMIM=[150341], no_hdr0=''),
    84824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84824, CurrentID=0, Status='live', Symbol='FCRLA', Aliases=['FCRL', 'FCRL1', 'FCRLM1', 'FCRLX', 'FCRLb', 'FCRLc1', 'FCRLc2', 'FCRLd', 'FCRLe', 'FCRX', 'FREB'], description='Fc receptor like A', other_designations='Fc receptor-like A|Fc receptor homolog expressed in B cells (FREB)|Fc receptor related protein X|Fc receptor-like and mucin-like 1|fc receptor homolog expressed in B-cells|fc receptor-like and mucin-like protein 1|fc receptor-like protein|fc receptor-related protein X', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161707022, end_position_on_the_genomic_accession=161714352, orientation='plus', exon_count=6, OMIM=[606891], no_hdr0=''),
    84826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84826, CurrentID=0, Status='live', Symbol='SFT2D3', Aliases=[], description='SFT2 domain containing 3', other_designations='vesicle transport protein SFT2C|SFT2 domain-containing protein 3', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127701497, end_position_on_the_genomic_accession=127705242, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    84830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84830, CurrentID=0, Status='live', Symbol='ADTRP', Aliases=['AIG1L', 'C6orf105', 'dJ413H6.1'], description='androgen dependent TFPI regulating protein', other_designations='androgen-dependent TFPI-regulating protein|FAHFA hydrolase ADTRP|androgen-dependent TPF1-regulating protein|fatty acid esters of hydroxy fatty acids hydrolase ADTRP', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=11713523, end_position_on_the_genomic_accession=11779628, orientation='minus', exon_count=12, OMIM=[614348], no_hdr0=''),
    84833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84833, CurrentID=0, Status='live', Symbol='ATP5MK', Aliases=['AGP', 'ATP5MD', 'DAPIT', 'HCVFTP2', 'MC5DN6', 'USMG5', 'bA792D24.4'], description='ATP synthase membrane subunit k', other_designations='ATP synthase membrane subunit K, mitochondrial|ATP synthase membrane subunit DAPIT, mitochondrial|Diabetes Associated Protein in Insulin-sensitive Tissues|HCV F-transactivated protein 2|diabetes-associated protein in insulin-sensitive tissues|up-regulated during skeletal muscle growth 5 homolog|up-regulated during skeletal muscle growth protein 5|upregulated during skeletal muscle growth 5 homolog', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103389050, end_position_on_the_genomic_accession=103396505, orientation='minus', exon_count=6, OMIM=[615204], no_hdr0=''),
    84836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84836, CurrentID=0, Status='live', Symbol='ABHD14B', Aliases=['CIB', 'HEL-S-299'], description='abhydrolase domain containing 14B', other_designations='protein ABHD14B|CCG1-interacting factor B|abhydrolase domain-containing protein 14B|alpha/beta hydrolase domain-containing protein 14B|cell cycle gene 1-interacting factor B|epididymis secretory protein Li 299|epididymis secretory sperm binding protein', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51968510, end_position_on_the_genomic_accession=51974630, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    84838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84838, CurrentID=0, Status='live', Symbol='ZNF496', Aliases=['NIZP1', 'ZFP496', 'ZKSCAN17', 'ZSCAN49'], description='zinc finger protein 496', other_designations='zinc finger protein 496|NSD1 (nuclear receptor binding SET-domain containing 1)-interacting zinc finger protein 1|zinc finger protein with KRAB and SCAN domains 17', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247297415, end_position_on_the_genomic_accession=247331867, orientation='minus', exon_count=11, OMIM=[613911], no_hdr0=''),
    84839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84839, CurrentID=0, Status='live', Symbol='RAX2', Aliases=['ARMD6', 'CORD11', 'QRX', 'RAXL1'], description='retina and anterior neural fold homeobox 2', other_designations='retina and anterior neural fold homeobox protein 2|Q50-type retinal homeobox protein|retina and anterior neural fold homeobox like 1|retina and anterior neural fold homeobox-like protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3769089, end_position_on_the_genomic_accession=3772228, orientation='minus', exon_count=3, OMIM=[610362], no_hdr0=''),
    84842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84842, CurrentID=0, Status='live', Symbol='HPDL', Aliases=['4-HPPD-L', 'GLOXD1', 'NEDSWMA', 'SPG83'], description='4-hydroxyphenylpyruvate dioxygenase like', other_designations='4-hydroxyphenylpyruvate dioxygenase-like protein|HPD-like protein|glyoxalase domain-containing protein 1', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45326895, end_position_on_the_genomic_accession=45328710, orientation='plus', exon_count=1, OMIM=[618994], no_hdr0=''),
    84844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84844, CurrentID=0, Status='live', Symbol='PHF5A', Aliases=['INI', 'Rds3', 'SAP14b', 'SF3B7', 'SF3b14b', 'bK223H9.2'], description='PHD finger protein 5A', other_designations='PHD finger-like domain-containing protein 5A|PHD finger-like domain protein 5A|PHD-finger 5a|splicing factor 3B associated 14 kDa protein|splicing factor 3b, subunit 7', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41459717, end_position_on_the_genomic_accession=41468692, orientation='minus', exon_count=4, OMIM=[617846], no_hdr0=''),
    84851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84851, CurrentID=0, Status='live', Symbol='TRIM52', Aliases=['RNF102'], description='tripartite motif containing 52', other_designations='E3 ubiquitin-protein ligase TRIM52|RING finger protein 102|tripartite motif-containing protein 52', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181249959, end_position_on_the_genomic_accession=181261355, orientation='minus', exon_count=3, OMIM=[619265], no_hdr0=''),
    84858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84858, CurrentID=0, Status='live', Symbol='ZNF503', Aliases=['NOLZ-1', 'NOLZ1', 'Nlz2'], description='zinc finger protein 503', other_designations='zinc finger protein 503', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75279725, end_position_on_the_genomic_accession=75401916, orientation='minus', exon_count=5, OMIM=[613902], no_hdr0=''),
    84859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84859, CurrentID=0, Status='live', Symbol='LRCH3', Aliases=[], description='leucine rich repeats and calponin homology domain containing 3', other_designations='DISP complex protein LRCH3|leucine-rich repeat and calponin homology domain-containing protein 3|leucine-rich repeats and calponin homology (CH) domain containing 3', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197791226, end_position_on_the_genomic_accession=197889494, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    84861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84861, CurrentID=0, Status='live', Symbol='KLHL22', Aliases=['KELCHL'], description='kelch like family member 22', other_designations='kelch-like protein 22|kelch-like 22', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20441519, end_position_on_the_genomic_accession=20497305, orientation='minus', exon_count=11, OMIM=[618020], no_hdr0=''),
    84864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84864, CurrentID=0, Status='live', Symbol='RIOX2', Aliases=['JMJD10', 'MDIG', 'MINA', 'MINA53', 'NO52', 'ROX'], description='ribosomal oxygenase 2', other_designations='ribosomal oxygenase 2|60S ribosomal protein L27a histidine hydroxylase|MYC induced nuclear antigen|MYC-induced nuclear antigen 53|bifunctional lysine-specific demethylase and histidyl-hydroxylase MINA|histone lysine demethylase MINA|mineral dust induced gene protein|myc-induced nuclear antigen, 53 kDa|nucleolar protein 52|ribosomal oxygenase MINA', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=97941818, end_position_on_the_genomic_accession=97972431, orientation='minus', exon_count=13, OMIM=[612049], no_hdr0=''),
    84865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84865, CurrentID=0, Status='live', Symbol='CCDC142', Aliases=[], description='coiled-coil domain containing 142', other_designations='coiled-coil domain-containing protein 142', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74472832, end_position_on_the_genomic_accession=74482998, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84866, CurrentID=0, Status='live', Symbol='TMEM25', Aliases=[], description='transmembrane protein 25', other_designations='transmembrane protein 25|0610039J01Rik', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118531189, end_position_on_the_genomic_accession=118547286, orientation='plus', exon_count=10, OMIM=[613934], no_hdr0=''),
    84867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84867, CurrentID=0, Status='live', Symbol='PTPN5', Aliases=['PTPSTEP', 'STEP', 'STEP61'], description='protein tyrosine phosphatase non-receptor type 5', other_designations='tyrosine-protein phosphatase non-receptor type 5|neural-specific protein-tyrosine phosphatase|protein tyrosine phosphatase, non-receptor type 5 (striatum-enriched)|protein-tyrosine phosphatase striatum-enriched|striatal-enriched protein tyrosine phosphatase|striatum-enriched protein-tyrosine phosphatase', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18727928, end_position_on_the_genomic_accession=18792721, orientation='minus', exon_count=16, OMIM=[176879], no_hdr0=''),
    84868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84868, CurrentID=0, Status='live', Symbol='HAVCR2', Aliases=['CD366', 'HAVcr-2', 'KIM-3', 'SPTCL', 'TIM3', 'TIMD-3', 'TIMD3', 'Tim-3'], description='hepatitis A virus cellular receptor 2', other_designations='hepatitis A virus cellular receptor 2|T cell immunoglobulin mucin 3|T-cell immunoglobulin and mucin domain-containing protein 3|T-cell immunoglobulin mucin family member 3|T-cell immunoglobulin mucin receptor 3|T-cell membrane protein 3|kidney injury molecule-3', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157085832, end_position_on_the_genomic_accession=157109044, orientation='minus', exon_count=7, OMIM=[606652], no_hdr0=''),
    84869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84869, CurrentID=0, Status='live', Symbol='CBR4', Aliases=['SDR45C1'], description='carbonyl reductase 4', other_designations='3-oxoacyl-[acyl-carrier-protein] reductase|carbonyl reductase family member 4|3-ketoacyl-[acyl-carrier-protein] reductase beta subunit|KAR beta subunit|carbonic reductase 4|quinone reductase CBR4|short chain dehydrogenase/reductase family 45C member 1', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=168894484, end_position_on_the_genomic_accession=169010284, orientation='minus', exon_count=10, OMIM=[619394], no_hdr0=''),
    84870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84870, CurrentID=0, Status='live', Symbol='RSPO3', Aliases=['CRISTIN1', 'PWTSR', 'THSD2'], description='R-spondin 3', other_designations='R-spondin-3|R-spondin 3 homolog|protein with TSP type-1 repeat|roof plate-specific spondin-3|thrombospondin type-1 domain-containing protein 2|thrombospondin, type I, domain containing 2', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127118671, end_position_on_the_genomic_accession=127199481, orientation='plus', exon_count=7, OMIM=[610574], no_hdr0=''),
    84871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84871, CurrentID=0, Status='live', Symbol='AGBL4', Aliases=['CCP6'], description='AGBL carboxypeptidase 4', other_designations='cytosolic carboxypeptidase 6|ATP/GTP binding protein like 4', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=48520157, end_position_on_the_genomic_accession=50023954, orientation='minus', exon_count=20, OMIM=[616476], no_hdr0=''),
    84872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84872, CurrentID=0, Status='live', Symbol='ZC3H10', Aliases=['ZC3HDC10'], description='zinc finger CCCH-type containing 10', other_designations='zinc finger CCCH domain-containing protein 10|zinc finger CCCH-type domain containing 10', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56118266, end_position_on_the_genomic_accession=56127514, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    84873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84873, CurrentID=0, Status='live', Symbol='ADGRG7', Aliases=['GPR128'], description='adhesion G protein-coupled receptor G7', other_designations='adhesion G-protein coupled receptor G7|G-protein coupled receptor 128', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100609601, end_position_on_the_genomic_accession=100696174, orientation='plus', exon_count=16, OMIM=[612307], no_hdr0=''),
    84874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84874, CurrentID=0, Status='live', Symbol='ZNF514', Aliases=[], description='zinc finger protein 514', other_designations='zinc finger protein 514', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95122987, end_position_on_the_genomic_accession=95165187, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84875, CurrentID=0, Status='live', Symbol='PARP10', Aliases=['ARTD10'], description='poly(ADP-ribose) polymerase family member 10', other_designations='protein mono-ADP-ribosyltransferase PARP10|ADP-ribosyltransferase diphtheria toxin-like 10|poly [ADP-ribose] polymerase 10', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143977158, end_position_on_the_genomic_accession=143986460, orientation='minus', exon_count=11, OMIM=[609564], no_hdr0=''),
    84876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84876, CurrentID=0, Status='live', Symbol='ORAI1', Aliases=['CRACM1', 'IMD9', 'ORAT1', 'TAM2', 'TMEM142A'], description='ORAI calcium release-activated calcium modulator 1', other_designations='calcium release-activated calcium channel protein 1|calcium release-activated calcium modulator 1|protein orai-1|transmembrane protein 142A', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121626550, end_position_on_the_genomic_accession=121642040, orientation='plus', exon_count=2, OMIM=[610277], no_hdr0=''),
    84878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84878, CurrentID=0, Status='live', Symbol='ZBTB45', Aliases=['ZNF499'], description='zinc finger and BTB domain containing 45', other_designations='zinc finger and BTB domain-containing protein 45|zinc finger protein 499', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58513530, end_position_on_the_genomic_accession=58542718, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84879, CurrentID=0, Status='live', Symbol='MFSD2A', Aliases=['MCPH15', 'MFSD2', 'NEDMISBA', 'NLS1', 'SLC59A1'], description='major facilitator superfamily domain containing 2A', other_designations='sodium-dependent lysophosphatidylcholine symporter 1|major facilitator superfamily domain-containing protein 2A|sodium-dependent LPC symporter 1', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39955145, end_position_on_the_genomic_accession=39969956, orientation='plus', exon_count=14, OMIM=[614397], no_hdr0=''),
    84881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84881, CurrentID=0, Status='live', Symbol='RPUSD4', Aliases=[], description='RNA pseudouridine synthase D4', other_designations='mitochondrial RNA pseudouridine synthase RPUSD4|RNA pseudouridylate synthase domain containing 4|RNA pseudouridylate synthase domain-containing protein 4', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126202096, end_position_on_the_genomic_accession=126211662, orientation='minus', exon_count=7, OMIM=[617488], no_hdr0=''),
    84883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84883, CurrentID=0, Status='live', Symbol='AIFM2', Aliases=['AMID', 'FSP1', 'PRG3'], description='apoptosis inducing factor mitochondria associated 2', other_designations='ferroptosis suppressor protein 1|apoptosis-inducing factor (AIF)-like mitochondrion-associated inducer of death|apoptosis-inducing factor 2|apoptosis-inducing factor, mitochondrion-associated, 2|ferroptosis suppressor 1|p53-responsive gene 3 protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70112271, end_position_on_the_genomic_accession=70132825, orientation='minus', exon_count=9, OMIM=[605159], no_hdr0=''),
    84885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84885, CurrentID=0, Status='live', Symbol='ZDHHC12', Aliases=['DHHC-12', 'ZNF400'], description='zinc finger DHHC-type palmitoyltransferase 12', other_designations='palmitoyltransferase ZDHHC12|DHHC domain-containing cysteine-rich protein 12|probable palmitoyltransferase ZDHHC12|zinc finger DHHC domain-containing protein 12|zinc finger DHHC-type containing 12|zinc finger protein 400', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128720869, end_position_on_the_genomic_accession=128724138, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    84886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84886, CurrentID=0, Status='live', Symbol='C1orf198', Aliases=[], description='chromosome 1 open reading frame 198', other_designations='uncharacterized protein C1orf198', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=230837119, end_position_on_the_genomic_accession=230869591, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    84888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84888, CurrentID=0, Status='live', Symbol='SPPL2A', Aliases=['IMP3', 'PSL2'], description='signal peptide peptidase like 2A', other_designations='signal peptide peptidase-like 2A|IMP-3|SPP-like 2A|intramembrane cleaving protease|intramembrane protease 3|presenilin-like protein 2', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50702266, end_position_on_the_genomic_accession=50765712, orientation='minus', exon_count=16, OMIM=[608238], no_hdr0=''),
    84889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84889, CurrentID=0, Status='live', Symbol='SLC7A3', Aliases=['ATRC3', 'CAT-3', 'CAT3'], description='solute carrier family 7 member 3', other_designations='cationic amino acid transporter 3|solute carrier family 7 (cationic amino acid transporter, y+ system), member 3', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70925579, end_position_on_the_genomic_accession=70931096, orientation='minus', exon_count=12, OMIM=[300443], no_hdr0=''),
    84890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84890, CurrentID=0, Status='live', Symbol='ADO', Aliases=['C10orf22'], description='2-aminoethanethiol dioxygenase', other_designations='2-aminoethanethiol dioxygenase|2-aminoethanethiol (cysteamine) dioxygenase|cysteamine (2-aminoethanethiol) dioxygenase (ADO)|cysteamine dioxygenase', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=62804720, end_position_on_the_genomic_accession=62808479, orientation='plus', exon_count=1, OMIM=[611392], no_hdr0=''),
    84891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84891, CurrentID=0, Status='live', Symbol='ZSCAN10', Aliases=['ZFP206', 'ZNF206'], description='zinc finger and SCAN domain containing 10', other_designations='zinc finger and SCAN domain-containing protein 10|zinc finger protein 206', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3088890, end_position_on_the_genomic_accession=3099294, orientation='minus', exon_count=6, OMIM=[618365], no_hdr0=''),
    84892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84892, CurrentID=0, Status='live', Symbol='POMGNT2', Aliases=['AGO61', 'C3orf39', 'GTDC2', 'MDDGA8', 'MDDGC8'], description='protein O-linked mannose N-acetylglucosaminyltransferase 2 (beta 1,4-)', other_designations='protein O-linked-mannose beta-1,4-N-acetylglucosaminyltransferase 2|glycosyltransferase-like domain containing 2|glycosyltransferase-like domain-containing protein 2|protein O-mannose beta-1,4-N-acetylglucosaminyltransferase 2', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=43079229, end_position_on_the_genomic_accession=43106085, orientation='minus', exon_count=4, OMIM=[614828], no_hdr0=''),
    84893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84893, CurrentID=0, Status='live', Symbol='FBH1', Aliases=['FBXO18', 'Fbx18', 'hFBH1'], description='F-box DNA helicase 1', other_designations='F-box DNA helicase 1|F-box only protein, helicase, 18|F-box protein, helicase, 18', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5889572, end_position_on_the_genomic_accession=5937593, orientation='plus', exon_count=26, OMIM=[607222], no_hdr0=''),
    84894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84894, CurrentID=0, Status='live', Symbol='LINGO1', Aliases=['LERN1', 'LRRN6A', 'MRT64', 'UNQ201'], description='leucine rich repeat and Ig domain containing 1', other_designations='leucine-rich repeat and immunoglobulin-like domain-containing nogo receptor-interacting protein 1|leucine rich repeat neuronal 6A|leucine-rich repeat and immunoglobulin domain-containing protein 1|leucine-rich repeat neuronal protein 1', map_location='15q24.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=77613024, end_position_on_the_genomic_accession=77820900, orientation='minus', exon_count=17, OMIM=[609791], no_hdr0=''),
    84895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84895, CurrentID=0, Status='live', Symbol='MIGA2', Aliases=['C9orf54', 'FAM73B'], description='mitoguardin 2', other_designations='mitoguardin 2|family with sequence similarity 73, member B|protein FAM73B', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129036605, end_position_on_the_genomic_accession=129072082, orientation='plus', exon_count=20, OMIM=[616774], no_hdr0=''),
    84896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84896, CurrentID=0, Status='live', Symbol='ATAD1', Aliases=['AFDC1', 'FNP001', 'HKPX4', 'Msp1', 'THORASE', 'hATAD1'], description='ATPase family AAA domain containing 1', other_designations='outer mitochondrial transmembrane helix translocase|ATPase family AAA domain-containing protein 1', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87751512, end_position_on_the_genomic_accession=87841359, orientation='minus', exon_count=18, OMIM=[614452], no_hdr0=''),
    84897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84897, CurrentID=0, Status='live', Symbol='TBRG1', Aliases=['NIAM', 'TB-5'], description='transforming growth factor beta regulator 1', other_designations='transforming growth factor beta regulator 1|nuclear interactor of ARF and MDM2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124622846, end_position_on_the_genomic_accession=124635926, orientation='plus', exon_count=10, OMIM=[610614], no_hdr0=''),
    84898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84898, CurrentID=0, Status='live', Symbol='PLXDC2', Aliases=['TEM7R'], description='plexin domain containing 2', other_designations='plexin domain-containing protein 2|1200007L24Rik|tumor endothelial marker 7-related protein', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=19816215, end_position_on_the_genomic_accession=20289856, orientation='plus', exon_count=15, OMIM=[606827], no_hdr0=''),
    84899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84899, CurrentID=0, Status='live', Symbol='TMTC4', Aliases=[], description='transmembrane O-mannosyltransferase targeting cadherins 4', other_designations='protein O-mannosyl-transferase TMTC4|transmembrane and TPR repeat-containing protein 4|transmembrane and tetratricopeptide repeat containing 4', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=100603625, end_position_on_the_genomic_accession=100675631, orientation='minus', exon_count=24, OMIM=[618203], no_hdr0=''),
    84900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84900, CurrentID=0, Status='live', Symbol='RNFT2', Aliases=['TMEM118'], description='ring finger protein, transmembrane 2', other_designations='RING finger and transmembrane domain-containing protein 2|transmembrane protein 118', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=116738315, end_position_on_the_genomic_accession=116853631, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    84901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84901, CurrentID=0, Status='live', Symbol='NFATC2IP', Aliases=['ESC2', 'NIP45', 'RAD60'], description='nuclear factor of activated T cells 2 interacting protein', other_designations='NFATC2-interacting protein|45 kDa NF-AT-interacting protein|45 kDa NFAT-interacting protein|nuclear factor of activated T-cells, cytoplasmic 2-interacting protein|nuclear factor of activated T-cells, cytoplasmic, calcineurin-dependent 2 interacting protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28950937, end_position_on_the_genomic_accession=28967092, orientation='plus', exon_count=8, OMIM=[614525], no_hdr0=''),
    84902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84902, CurrentID=0, Status='live', Symbol='CEP89', Aliases=['CCDC123', 'CEP123'], description='centrosomal protein 89', other_designations='centrosomal protein of 89 kDa|centrosomal protein 123|centrosomal protein 89kDa|coiled-coil domain containing 123|coiled-coil domain-containing protein 123, mitochondrial', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32875925, end_position_on_the_genomic_accession=32972024, orientation='minus', exon_count=22, OMIM=[615470], no_hdr0=''),
    84904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84904, CurrentID=0, Status='live', Symbol='ARHGEF39', Aliases=['C9orf100'], description='Rho guanine nucleotide exchange factor 39', other_designations='rho guanine nucleotide exchange factor 39|Rho guanine nucleotide exchange factor (GEF) 39|vav-like protein C9orf100', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35658875, end_position_on_the_genomic_accession=35665205, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    84905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84905, CurrentID=0, Status='live', Symbol='ZNF341', Aliases=['HIES3'], description='zinc finger protein 341', other_designations='zinc finger protein 341', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33731657, end_position_on_the_genomic_accession=33792269, orientation='plus', exon_count=15, OMIM=[618269], no_hdr0=''),
    84908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84908, CurrentID=0, Status='live', Symbol='FAM136A', Aliases=[], description='family with sequence similarity 136 member A', other_designations='protein FAM136A', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70295976, end_position_on_the_genomic_accession=70302067, orientation='minus', exon_count=4, OMIM=[616275], no_hdr0=''),
    84909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84909, CurrentID=0, Status='live', Symbol='AOPEP', Aliases=['AP-O', 'APO', 'C90RF3', 'C9orf3', 'ONPEP'], description='aminopeptidase O (putative)', other_designations='aminopeptidase O', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94726669, end_position_on_the_genomic_accession=95148264, orientation='plus', exon_count=34, OMIM=[], no_hdr0=''),
    84910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84910, CurrentID=0, Status='live', Symbol='TMEM87B', Aliases=[], description='transmembrane protein 87B', other_designations='transmembrane protein 87B', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112055266, end_position_on_the_genomic_accession=112119314, orientation='plus', exon_count=20, OMIM=[617203], no_hdr0=''),
    84911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84911, CurrentID=0, Status='live', Symbol='ZNF382', Aliases=['KS1'], description='zinc finger protein 382', other_designations='zinc finger protein 382|KRAB/zinc finger suppressor protein 1|multiple zinc finger and krueppel-associated box protein KS1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36605313, end_position_on_the_genomic_accession=36634114, orientation='plus', exon_count=5, OMIM=[609516], no_hdr0=''),
    84912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84912, CurrentID=0, Status='live', Symbol='SLC35B4', Aliases=['YEA', 'YEA4'], description='solute carrier family 35 member B4', other_designations='UDP-xylose and UDP-N-acetylglucosamine transporter|UDP-Xylose/N-Acetylglucosamine transporter|YEA4 homolog|solute carrier family 35 (UDP-xylose/UDP-N-acetylglucosamine transporter), member B4', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134289332, end_position_on_the_genomic_accession=134320307, orientation='minus', exon_count=12, OMIM=[610923], no_hdr0=''),
    84913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84913, CurrentID=0, Status='live', Symbol='ATOH8', Aliases=['HATH6', 'bHLHa21'], description='atonal bHLH transcription factor 8', other_designations='protein atonal homolog 8|atonal homolog 6|atonal homolog 8|atonal homolog bHLH transcription factor 8|basic helix loop helix transcription factor 6|class A basic helix-loop-helix protein 21|helix-loop-helix protein hATH-6', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85753786, end_position_on_the_genomic_accession=85791383, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    84914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84914, CurrentID=0, Status='live', Symbol='ZNF587', Aliases=['ZF6'], description='zinc finger protein 587', other_designations='zinc finger protein 587|zinc finger protein zfp6', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57849859, end_position_on_the_genomic_accession=57865117, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    84915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84915, CurrentID=0, Status='live', Symbol='FAM222A', Aliases=['C12orf34'], description='family with sequence similarity 222 member A', other_designations='protein FAM222A|aggregatin', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109713825, end_position_on_the_genomic_accession=109770509, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    84916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84916, CurrentID=0, Status='live', Symbol='UTP4', Aliases=['CIRH1A', 'CIRHIN', 'NAIC', 'TEX292'], description='UTP4 small subunit processome component', other_designations='U3 small nucleolar RNA-associated protein 4 homolog|UTP4 small subunit (SSU) processome component|UTP4, small subunit (SSU) processome component, homolog|cirrhosis, autosomal recessive 1A (cirhin)|testis expressed gene 292', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69132630, end_position_on_the_genomic_accession=69169024, orientation='plus', exon_count=18, OMIM=[607456], no_hdr0=''),
    84918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84918, CurrentID=0, Status='live', Symbol='LRP11', Aliases=['MANSC3', 'bA350J20.3'], description='LDL receptor related protein 11', other_designations='low-density lipoprotein receptor-related protein 11|LRP-11', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149818757, end_position_on_the_genomic_accession=149864359, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    84919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84919, CurrentID=0, Status='live', Symbol='PPP1R15B', Aliases=['CREP', 'MSSGM2'], description='protein phosphatase 1 regulatory subunit 15B', other_designations='protein phosphatase 1 regulatory subunit 15B|protein phosphatase 1, regulatory (inhibitor) subunit 15B', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204398684, end_position_on_the_genomic_accession=204412454, orientation='minus', exon_count=4, OMIM=[613257], no_hdr0=''),
    84920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84920, CurrentID=0, Status='live', Symbol='ALG10', Aliases=['ALG10A', 'DIE2', 'KCR1'], description='ALG10 alpha-1,2-glucosyltransferase', other_designations='dol-P-Glc:Glc(2)Man(9)GlcNAc(2)-PP-Dol alpha-1,2-glucosyltransferase|alpha-1,2-glucosyltransferase ALG10-A|alpha-2-glucosyltransferase ALG10-A|alpha2-glucosyltransferase|asparagine-linked glycosylation 10 homolog (yeast, alpha-1,2-glucosyltransferase)|asparagine-linked glycosylation 10, alpha-1,2-glucosyltransferase homolog|asparagine-linked glycosylation protein 10 homolog A|derepression of ITR1 expression 2 homolog|dolichyl-P-Glc:Glc(2)Man(9)GlcNAc(2)-PP-dolichol alpha-1,2- glucosyltransferase|potassium channel regulator 1', map_location='12p11.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=34022315, end_position_on_the_genomic_accession=34035296, orientation='plus', exon_count=5, OMIM=[618355], no_hdr0=''),
    84922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84922, CurrentID=0, Status='live', Symbol='FIZ1', Aliases=['ZNF798'], description='FLT3 interacting zinc finger 1', other_designations='flt3-interacting zinc finger protein 1|zinc finger protein 798', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55591376, end_position_on_the_genomic_accession=55599703, orientation='minus', exon_count=4, OMIM=[609133], no_hdr0=''),
    84923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84923, CurrentID=0, Status='live', Symbol='FAM104A', Aliases=[], description='family with sequence similarity 104 member A', other_designations='protein FAM104A', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73207353, end_position_on_the_genomic_accession=73232394, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84924, CurrentID=0, Status='live', Symbol='ZNF566', Aliases=[], description='zinc finger protein 566', other_designations='zinc finger protein 566', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36445119, end_position_on_the_genomic_accession=36489902, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84925, CurrentID=0, Status='live', Symbol='SLC49A4', Aliases=['DIRC2', 'RCC4'], description='solute carrier family 49 member 4', other_designations='solute carrier family 49 member 4|disrupted in renal cancer protein 2|disrupted in renal carcinoma 2|renal cell carcinoma 4', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122795058, end_position_on_the_genomic_accession=122892157, orientation='plus', exon_count=10, OMIM=[602773], no_hdr0=''),
    84926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84926, CurrentID=0, Status='live', Symbol='SPRYD3', Aliases=[], description='SPRY domain containing 3', other_designations='SPRY domain-containing protein 3', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53064316, end_position_on_the_genomic_accession=53079390, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    84928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84928, CurrentID=0, Status='live', Symbol='TMEM209', Aliases=['NET31'], description='transmembrane protein 209', other_designations='transmembrane protein 209|testicular tissue protein Li 202', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130164713, end_position_on_the_genomic_accession=130205406, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    84929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84929, CurrentID=0, Status='live', Symbol='FIBCD1', Aliases=[], description='fibrinogen C domain containing 1', other_designations='fibrinogen C domain-containing protein 1', map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130902440, end_position_on_the_genomic_accession=130939247, orientation='minus', exon_count=8, OMIM=[613357], no_hdr0=''),
    84930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84930, CurrentID=0, Status='live', Symbol='MASTL', Aliases=['GREATWALL', 'GW', 'GWL', 'MAST-L', 'THC2'], description='microtubule associated serine/threonine kinase like', other_designations='serine/threonine-protein kinase greatwall|greatwall kinase homolog|greatwall protein kinase', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27154479, end_position_on_the_genomic_accession=27187953, orientation='plus', exon_count=16, OMIM=[608221], no_hdr0=''),
    84932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84932, CurrentID=0, Status='live', Symbol='RAB2B', Aliases=[], description='RAB2B, member RAS oncogene family', other_designations='ras-related protein Rab-2B|GTP-binding protein RAB2B|RAS family, member RAB2B', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21459020, end_position_on_the_genomic_accession=21476959, orientation='minus', exon_count=9, OMIM=[607466], no_hdr0=''),
    84933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84933, CurrentID=0, Status='live', Symbol='C8orf76', Aliases=[], description='chromosome 8 open reading frame 76', other_designations='uncharacterized protein C8orf76', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123219967, end_position_on_the_genomic_accession=123241377, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    84934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84934, CurrentID=0, Status='live', Symbol='RITA1', Aliases=['C12orf52', 'RITA'], description='RBPJ interacting and tubulin associated 1', other_designations='RBPJ-interacting and tubulin-associated protein 1', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113185560, end_position_on_the_genomic_accession=113192368, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    84935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84935, CurrentID=0, Status='live', Symbol='MEDAG', Aliases=['AWMS3', 'C13orf33', 'MEDA-4', 'MEDA4', 'hAWMS3'], description='mesenteric estrogen dependent adipogenesis', other_designations='mesenteric estrogen-dependent adipogenesis protein|activated in W/Wv mouse stomach 3 homolog|mesenteric estrogen-dependent adipose 4', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30906271, end_position_on_the_genomic_accession=30925577, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    84936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84936, CurrentID=0, Status='live', Symbol='ZFYVE19', Aliases=['ANCHR', 'MPFYVE'], description='zinc finger FYVE-type containing 19', other_designations='abscission/NoCut checkpoint regulator|MLL partner containing FYVE domain|zinc finger FYVE domain-containing protein 19|zinc finger, FYVE domain containing 19', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40807086, end_position_on_the_genomic_accession=40815084, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    84937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84937, CurrentID=0, Status='live', Symbol='ZNRF1', Aliases=['NIN283'], description='zinc and ring finger 1', other_designations='E3 ubiquitin-protein ligase ZNRF1|RING-type E3 ubiquitin transferase ZNRF1|nerve injury gene 283|nerve injury-induced gene 283 protein|zinc and ring finger 1, E3 ubiquitin protein ligase|zinc and ring finger protein 1|zinc/RING finger protein 1', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74999024, end_position_on_the_genomic_accession=75110994, orientation='plus', exon_count=7, OMIM=[612060], no_hdr0=''),
    84938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84938, CurrentID=0, Status='live', Symbol='ATG4C', Aliases=['APG4-C', 'APG4C', 'AUTL1', 'AUTL3'], description='autophagy related 4C cysteine peptidase', other_designations='cysteine protease ATG4C|APG4 autophagy 4 homolog C|ATG4 autophagy related 4 homolog C|AUT-like 1, cysteine endopeptidase|AUT-like 3 cysteine endopeptidase|autophagin-3|autophagy-related cysteine endopeptidase 3|autophagy-related protein 4 homolog C|epididymis secretory sperm binding protein', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62783765, end_position_on_the_genomic_accession=62865516, orientation='plus', exon_count=14, OMIM=[611339], no_hdr0=''),
    84939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84939, CurrentID=0, Status='live', Symbol='PWWP3A', Aliases=['EXPAND1', 'HSPC211', 'MUM-1', 'MUM1'], description='PWWP domain containing 3A, DNA repair factor', other_designations='PWWP domain-containing DNA repair factor 3A|PWWP domain-containing protein MUM1|melanoma associated antigen (mutated) 1|melanoma ubiquitous mutated protein|mutated melanoma-associated antigen 1|protein expandere', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1354959, end_position_on_the_genomic_accession=1378429, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    84940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84940, CurrentID=0, Status='live', Symbol='CORO6', Aliases=[], description='coronin 6', other_designations='coronin-6|clipin-E|coronin, actin binding protein 6|coronin-like protein E', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29614236, end_position_on_the_genomic_accession=29622912, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    84941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84941, CurrentID=0, Status='live', Symbol='HSH2D', Aliases=['ALX', 'HSH2'], description='hematopoietic SH2 domain containing', other_designations='hematopoietic SH2 domain-containing protein|adaptor in lymphocytes of unknown function X', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16134028, end_position_on_the_genomic_accession=16158575, orientation='plus', exon_count=10, OMIM=[608349], no_hdr0=''),
    84942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84942, CurrentID=0, Status='live', Symbol='WDR73', Aliases=['GAMOS', 'GAMOS1', 'HSPC264'], description='WD repeat domain 73', other_designations='WD repeat-containing protein 73|FLJ00296 protein', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84639285, end_position_on_the_genomic_accession=84654290, orientation='minus', exon_count=9, OMIM=[616144], no_hdr0=''),
    84944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84944, CurrentID=0, Status='live', Symbol='MAEL', Aliases=['CT128', 'SPATA35'], description='maelstrom spermatogenic transposon silencer', other_designations='protein maelstrom homolog|cancer/testis antigen 128|maelstrom homolog|spermatogenesis associated 35|testicular tissue protein Li 116', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=166921121, end_position_on_the_genomic_accession=167022214, orientation='plus', exon_count=17, OMIM=[611368], no_hdr0=''),
    84945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84945, CurrentID=0, Status='live', Symbol='ABHD13', Aliases=['BEM46L1', 'C13orf6', 'bA153I24.2'], description='abhydrolase domain containing 13', other_designations='protein ABHD13|abhydrolase domain-containing protein 13|alpha/beta hydrolase domain-containing protein 13', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=108218392, end_position_on_the_genomic_accession=108235440, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    84946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84946, CurrentID=0, Status='live', Symbol='LTV1', Aliases=['C6orf93', 'dJ468K18.4'], description='LTV1 ribosome biogenesis factor', other_designations='protein LTV1 homolog|LTV1 homolog', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143843338, end_position_on_the_genomic_accession=143863812, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    84947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84947, CurrentID=0, Status='live', Symbol='SERAC1', Aliases=[], description='serine active site containing 1', other_designations='protein SERAC1|serine active site-containing protein 1', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158109515, end_position_on_the_genomic_accession=158168270, orientation='minus', exon_count=19, OMIM=[614725], no_hdr0=''),
    84948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84948, CurrentID=0, Status='live', Symbol='TIGD5', Aliases=[], description='tigger transposable element derived 5', other_designations='tigger transposable element-derived protein 5', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143597831, end_position_on_the_genomic_accession=143603224, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    84950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84950, CurrentID=0, Status='live', Symbol='PRPF38A', Aliases=['PRP38A', 'Prp38'], description='pre-mRNA processing factor 38A', other_designations='pre-mRNA-splicing factor 38A|PRP38 pre-mRNA processing factor 38 domain containing A', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52404564, end_position_on_the_genomic_accession=52420836, orientation='plus', exon_count=10, OMIM=[617031], no_hdr0=''),
    84951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84951, CurrentID=0, Status='live', Symbol='TNS4', Aliases=['CTEN', 'PP14434'], description='tensin 4', other_designations='tensin-4|C terminal tensin like|C-terminal tensin-like protein', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40475828, end_position_on_the_genomic_accession=40501681, orientation='minus', exon_count=14, OMIM=[608385], no_hdr0=''),
    84952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84952, CurrentID=0, Status='live', Symbol='CGNL1', Aliases=['JACOP', 'PCING'], description='cingulin like 1', other_designations='cingulin-like protein 1|junction-associated coiled-coil protein|paracingulin', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=57376458, end_position_on_the_genomic_accession=57550723, orientation='plus', exon_count=23, OMIM=[607856], no_hdr0=''),
    84954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84954, CurrentID=0, Status='live', Symbol='MPND', Aliases=[], description='MPN domain containing', other_designations='MPN domain-containing protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4343562, end_position_on_the_genomic_accession=4360084, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    84955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84955, CurrentID=0, Status='live', Symbol='NUDCD1', Aliases=['CML66', 'OVA66'], description='NudC domain containing 1', other_designations='nudC domain-containing protein 1|chronic myelogenous leukemia tumor antigen 66|tumor antigen CML66', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109240919, end_position_on_the_genomic_accession=109334087, orientation='minus', exon_count=12, OMIM=[606109], no_hdr0=''),
    84957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84957, CurrentID=0, Status='live', Symbol='RELT', Aliases=['AI3C', 'TNFRSF19L', 'TRLT'], description='RELT TNF receptor', other_designations='tumor necrosis factor receptor superfamily member 19L|RELT tumor necrosis factor receptor|receptor expressed in lymphoid tissues', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73376395, end_position_on_the_genomic_accession=73397474, orientation='plus', exon_count=12, OMIM=[611211], no_hdr0=''),
    84958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84958, CurrentID=0, Status='live', Symbol='SYTL1', Aliases=['JFC1', 'SLP1'], description='synaptotagmin like 1', other_designations='synaptotagmin-like protein 1|NADPH oxidase-related, C2 domain-containing protein|exophilin-7', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27342022, end_position_on_the_genomic_accession=27353932, orientation='plus', exon_count=14, OMIM=[608042], no_hdr0=''),
    84959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84959, CurrentID=0, Status='live', Symbol='UBASH3B', Aliases=['STS-1', 'STS1', 'TULA-2', 'TULA2', 'p70'], description='ubiquitin associated and SH3 domain containing B', other_designations='ubiquitin-associated and SH3 domain-containing protein B|Cbl-interacting protein Sts-1|SH3 domain-containing 70 kDa protein, suppressor of T-cell receptor signaling 1, nm23-phosphorylated unknown substrate|T-cell ubiquitin ligand 2|cbl-interacting protein p70|nm23-phosphorylated unknown substrate|suppressor of T-cell receptor signaling 1|tyrosine-protein phosphatase STS1/TULA2', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=122655722, end_position_on_the_genomic_accession=122814473, orientation='plus', exon_count=15, OMIM=[609201], no_hdr0=''),
    84960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84960, CurrentID=0, Status='live', Symbol='CCDC183', Aliases=['KIAA1984', 'PARF', 'bA216L13.7'], description='coiled-coil domain containing 183', other_designations='coiled-coil domain-containing protein 183', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136796338, end_position_on_the_genomic_accession=136807741, orientation='plus', exon_count=14, OMIM=[615955], no_hdr0=''),
    84961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84961, CurrentID=0, Status='live', Symbol='FBXL20', Aliases=['Fbl2', 'Fbl20'], description='F-box and leucine rich repeat protein 20', other_designations='F-box/LRR-repeat protein 20|F-box protein FBL2', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39252663, end_position_on_the_genomic_accession=39402556, orientation='minus', exon_count=16, OMIM=[609086], no_hdr0=''),
    84962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84962, CurrentID=0, Status='live', Symbol='AJUBA', Aliases=['JUB'], description='ajuba LIM protein', other_designations='LIM domain-containing protein ajuba|jub, ajuba homolog', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22971177, end_position_on_the_genomic_accession=22982551, orientation='minus', exon_count=9, OMIM=[609066], no_hdr0=''),
    84964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84964, CurrentID=0, Status='live', Symbol='ALKBH6', Aliases=['ABH6'], description='alkB homolog 6', other_designations='alpha-ketoglutarate-dependent dioxygenase alkB homolog 6|alkB, alkylation repair homolog 6|alkylated DNA repair protein alkB homolog 6|alkylation repair homolog 6|probable alpha-ketoglutarate-dependent dioxygenase ABH6', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36009120, end_position_on_the_genomic_accession=36014239, orientation='minus', exon_count=8, OMIM=[613304], no_hdr0=''),
    84966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84966, CurrentID=0, Status='live', Symbol='IGSF21', Aliases=[], description='immunoglobin superfamily member 21', other_designations='immunoglobulin superfamily member 21', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18107746, end_position_on_the_genomic_accession=18378483, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    84967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84967, CurrentID=0, Status='live', Symbol='LSM10', Aliases=['MST074', 'MSTP074'], description='LSM10, U7 small nuclear RNA associated', other_designations='U7 snRNA-associated Sm-like protein LSm10|U7 snRNP-specific Sm-like protein LSM10', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36393436, end_position_on_the_genomic_accession=36397908, orientation='minus', exon_count=2, OMIM=[617909], no_hdr0=''),
    84968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84968, CurrentID=0, Status='live', Symbol='PNMA6A', Aliases=['MA6', 'PNMA6', 'PNMA6C'], description='PNMA family member 6A', other_designations='paraneoplastic antigen-like protein 6A|paraneoplastic Ma antigen family member 6A|paraneoplastic Ma antigen family member 6C|paraneoplastic antigen-like 6A related protein|paraneoplastic antigen-like protein 6C', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153072454, end_position_on_the_genomic_accession=153075019, orientation='plus', exon_count=2, OMIM=[300917], no_hdr0=''),
    84969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84969, CurrentID=0, Status='live', Symbol='TOX2', Aliases=['C20orf100', 'GCX-1', 'GCX1', 'dJ1108D11.2', 'dJ495O3.1'], description='TOX high mobility group box family member 2', other_designations='TOX high mobility group box family member 2|granulosa cell HMG box 1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43914852, end_position_on_the_genomic_accession=44069616, orientation='plus', exon_count=12, OMIM=[611163], no_hdr0=''),
    84970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84970, CurrentID=0, Status='live', Symbol='C1orf94', Aliases=[], description='chromosome 1 open reading frame 94', other_designations='uncharacterized protein C1orf94', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34166993, end_position_on_the_genomic_accession=34219131, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    84971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84971, CurrentID=0, Status='live', Symbol='ATG4D', Aliases=['APG4-D', 'APG4D', 'AUTL4'], description='autophagy related 4D cysteine peptidase', other_designations='cysteine protease ATG4D|APG4 autophagy 4 homolog D|ATG4 autophagy related 4 homolog D|AUT-like 4 cysteine endopeptidase|autophagin-4|autophagy-related cysteine endopeptidase 4|autophagy-related protein 4 homolog D|cysteine protease involved in autophagy', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10543897, end_position_on_the_genomic_accession=10553418, orientation='plus', exon_count=10, OMIM=[611340], no_hdr0=''),
    84975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84975, CurrentID=0, Status='live', Symbol='MFSD5', Aliases=['SLC61A1', 'hsMOT2'], description='major facilitator superfamily domain containing 5', other_designations='molybdate-anion transporter|major facilitator superfamily domain-containing protein 5|molybdate transporter 2 homolog', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53251251, end_position_on_the_genomic_accession=53254406, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    84976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84976, CurrentID=0, Status='live', Symbol='DISP1', Aliases=['DISPA'], description='dispatched RND transporter family member 1', other_designations='protein dispatched homolog 1|dispatched A', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222814514, end_position_on_the_genomic_accession=223005995, orientation='plus', exon_count=25, OMIM=[607502], no_hdr0=''),
    84978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84978, CurrentID=0, Status='live', Symbol='FRMD5', Aliases=[], description='FERM domain containing 5', other_designations='FERM domain-containing protein 5', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43870764, end_position_on_the_genomic_accession=44195271, orientation='minus', exon_count=19, OMIM=[616309], no_hdr0=''),
    84984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84984, CurrentID=0, Status='live', Symbol='CEP19', Aliases=['C3orf34', 'MOSPGF'], description='centrosomal protein 19', other_designations='centrosomal protein of 19 kDa|centrosomal protein 19kDa', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196706277, end_position_on_the_genomic_accession=196712250, orientation='minus', exon_count=3, OMIM=[615586], no_hdr0=''),
    84985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84985, CurrentID=0, Status='live', Symbol='FAM83A', Aliases=['BJ-TSA-9'], description='family with sequence similarity 83 member A', other_designations='protein FAM83A|tumor antigen BJ-TSA-9|tumor-specific gene expressed in prostate protein', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123179047, end_position_on_the_genomic_accession=123210079, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    84986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84986, CurrentID=0, Status='live', Symbol='ARHGAP19', Aliases=[], description='Rho GTPase activating protein 19', other_designations='rho GTPase-activating protein 19|putative RhoGAP protein|rho-type GTPase-activating protein 19', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97222179, end_position_on_the_genomic_accession=97292637, orientation='minus', exon_count=13, OMIM=[611587], no_hdr0=''),
    84987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84987, CurrentID=0, Status='live', Symbol='COX14', Aliases=['C12orf62', 'MC4DN10', 'PCAG1'], description='cytochrome c oxidase assembly factor COX14', other_designations='cytochrome c oxidase assembly protein COX14|COX14 cytochrome c oxidase assembly homolog|COX14, cytochrome c oxidase assembly factor|cytochrome c oxidase assembly homolog 14', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50112236, end_position_on_the_genomic_accession=50120453, orientation='plus', exon_count=3, OMIM=[614478], no_hdr0=''),
    84988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84988, CurrentID=0, Status='live', Symbol='PPP1R16A', Aliases=['MYPT3'], description='protein phosphatase 1 regulatory subunit 16A', other_designations='protein phosphatase 1 regulatory subunit 16A|myosin phosphatase-targeting subunit 3|protein phosphatase 1, regulatory (inhibitor) subunit 16A', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144477982, end_position_on_the_genomic_accession=144502121, orientation='plus', exon_count=15, OMIM=[609172], no_hdr0=''),
    84991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84991, CurrentID=0, Status='live', Symbol='RBM17', Aliases=['SPF45'], description='RNA binding motif protein 17', other_designations='splicing factor 45|45 kDa-splicing factor|splicing factor 45kDa', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=6089034, end_position_on_the_genomic_accession=6117447, orientation='plus', exon_count=13, OMIM=[606935], no_hdr0=''),
    84992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84992, CurrentID=0, Status='live', Symbol='PIGY', Aliases=['HPMRS6', 'PIG-Y'], description='phosphatidylinositol glycan anchor biosynthesis class Y', other_designations='phosphatidylinositol N-acetylglucosaminyltransferase subunit Y|phosphatidylinositol-glycan biosynthesis class Y protein', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88520998, end_position_on_the_genomic_accession=88523776, orientation='minus', exon_count=2, OMIM=[610662], no_hdr0=''),
    84993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=84993, CurrentID=0, Status='live', Symbol='UBL7', Aliases=['BMSC-UbP', 'TCBA1'], description='ubiquitin like 7', other_designations='ubiquitin-like protein 7|ubiquitin-like 7 (bone marrow stromal cell-derived)|ubiquitin-like protein SB132', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74445977, end_position_on_the_genomic_accession=74461188, orientation='minus', exon_count=13, OMIM=[609748], no_hdr0=''),
    85002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85002, CurrentID=0, Status='live', Symbol='FAM86B1', Aliases=[], description='family with sequence similarity 86 member B1', other_designations='putative protein N-methyltransferase FAM86B1|protein FAM86B1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12182106, end_position_on_the_genomic_accession=12195436, orientation='minus', exon_count=10, OMIM=[616122], no_hdr0=''),
    85004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85004, CurrentID=0, Status='live', Symbol='RERG', Aliases=[], description='RAS like estrogen regulated growth inhibitor', other_designations='ras-related and estrogen-regulated growth inhibitor', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=15107783, end_position_on_the_genomic_accession=15221417, orientation='minus', exon_count=6, OMIM=[612664], no_hdr0=''),
    85007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85007, CurrentID=0, Status='live', Symbol='PHYKPL', Aliases=['AGXT2L2', 'PHLU'], description='5-phosphohydroxy-L-lysine phospho-lyase', other_designations='5-phosphohydroxy-L-lysine phospho-lyase|5-phosphonooxy-L-lysine phospho-lyase|alanine--glyoxylate aminotransferase 2-like 2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178207144, end_position_on_the_genomic_accession=178232822, orientation='minus', exon_count=18, OMIM=[614683], no_hdr0=''),
    85012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85012, CurrentID=0, Status='live', Symbol='TCEAL3', Aliases=['WEX8'], description='transcription elongation factor A like 3', other_designations='transcription elongation factor A protein-like 3|TCEA-like protein 3|transcription elongation factor A (SII)-like 3|transcription elongation factor S-II protein-like 3', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103607963, end_position_on_the_genomic_accession=103609927, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    85013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85013, CurrentID=0, Status='live', Symbol='TMEM128', Aliases=[], description='transmembrane protein 128', other_designations='transmembrane protein 128', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4235542, end_position_on_the_genomic_accession=4248232, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    85014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85014, CurrentID=0, Status='live', Symbol='TMEM141', Aliases=[], description='transmembrane protein 141', other_designations='transmembrane protein 141', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136791344, end_position_on_the_genomic_accession=136793317, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    85015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85015, CurrentID=0, Status='live', Symbol='USP45', Aliases=['LCA19'], description='ubiquitin specific peptidase 45', other_designations='ubiquitin carboxyl-terminal hydrolase 45|deubiquitinating enzyme 45|ubiquitin specific protease 45|ubiquitin thioesterase 45|ubiquitin thiolesterase 45|ubiquitin-specific-processing protease 45', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99432325, end_position_on_the_genomic_accession=99515770, orientation='minus', exon_count=24, OMIM=[618439], no_hdr0=''),
    85016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85016, CurrentID=0, Status='live', Symbol='CFAP300', Aliases=['C11orf70', 'CILD38', 'FBB5'], description='cilia and flagella associated protein 300', other_designations='cilia- and flagella-associated protein 300|uncharacterized protein C11orf70', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102047409, end_position_on_the_genomic_accession=102084554, orientation='plus', exon_count=7, OMIM=[618058], no_hdr0=''),
    85019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85019, CurrentID=0, Status='live', Symbol='TMEM241', Aliases=['C18orf45', 'hVVT'], description='transmembrane protein 241', other_designations='transmembrane protein 241|putative vertebrate vrg4-like nucleotide-sugar transporter truncated variant2|putative vertebrate vrg4-like nucleotide-sugar transporter variant1|transmembrane protein C18orf45', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23237252, end_position_on_the_genomic_accession=23437969, orientation='minus', exon_count=23, OMIM=[615430], no_hdr0=''),
    85021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85021, CurrentID=0, Status='live', Symbol='REPS1', Aliases=['NBIA7', 'RALBP1'], description='RALBP1 associated Eps domain containing 1', other_designations='ralBP1-associated Eps domain-containing protein 1|ralBP1-interacting protein 1', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138903493, end_position_on_the_genomic_accession=138988253, orientation='minus', exon_count=21, OMIM=[614825], no_hdr0=''),
    85025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85025, CurrentID=0, Status='live', Symbol='TMEM60', Aliases=['C7orf35', 'DC32'], description='transmembrane protein 60', other_designations='transmembrane protein 60', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77793728, end_position_on_the_genomic_accession=77798434, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    85027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85027, CurrentID=0, Status='live', Symbol='SMIM3', Aliases=['C5orf62', 'MST150', 'NID67'], description='small integral membrane protein 3', other_designations='small integral membrane protein 3|NGF-induced differentiation clone 67 protein|Uncharacterized protein C5orf62|small membrane protein NID67', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150778757, end_position_on_the_genomic_accession=150796734, orientation='plus', exon_count=2, OMIM=[608324], no_hdr0=''),
    85235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85235, CurrentID=0, Status='live', Symbol='H2AC12', Aliases=['H2A/S', 'H2AFALii', 'H2AH', 'HIST1H2AH', 'dJ86C11.1'], description='H2A clustered histone 12', other_designations='histone H2A type 1-H|H2A histone family member|histone H2A/s|histone cluster 1 H2A family member h|histone cluster 1, H2ah', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27147106, end_position_on_the_genomic_accession=27147562, orientation='plus', exon_count=1, OMIM=[615013], no_hdr0=''),
    85236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85236, CurrentID=0, Status='live', Symbol='H2BC12', Aliases=['H2B/S', 'H2BFAiii', 'H2BFT', 'H2BK', 'HIST1H2BK'], description='H2B clustered histone 12', other_designations='histone H2B type 1-K|H2B K|H2B histone family, member T|HIRA-interacting protein 1|histone 1, H2bk|histone cluster 1 H2B family member k|histone cluster 1, H2bk|histone family member', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27138293, end_position_on_the_genomic_accession=27146858, orientation='minus', exon_count=2, OMIM=[615045], no_hdr0=''),
    85280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85280, CurrentID=0, Status='live', Symbol='KRTAP9-4', Aliases=['KAP9.4', 'KRTAP9.4'], description='keratin associated protein 9-4', other_designations='keratin-associated protein 9-4|keratin-associated protein 9.4|ultrahigh sulfur keratin-associated protein 9.4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41249687, end_position_on_the_genomic_accession=41250653, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    85285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85285, CurrentID=0, Status='live', Symbol='KRTAP4-1', Aliases=['KAP4.1', 'KAP4.100', 'KRTAP4.10', 'KRTAP4-1'], description='keratin associated protein 4-1', other_designations='keratin-associated protein 4-1|keratin associated protein 4-10|keratin-associated protein 4.1|ultrahigh sulfur keratin-associated protein 4.10', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41184100, end_position_on_the_genomic_accession=41184911, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85289, CurrentID=0, Status='live', Symbol='KRTAP4-5', Aliases=['KAP4.5', 'KRTAP4.5'], description='keratin associated protein 4-5', other_designations='keratin-associated protein 4-5|keratin-associated protein 4.5|ultrahigh sulfur keratin-associated protein 4.5', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41148924, end_position_on_the_genomic_accession=41149825, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85290, CurrentID=0, Status='live', Symbol='KRTAP4-3', Aliases=['KAP4.3'], description='keratin associated protein 4-3', other_designations='keratin-associated protein 4-3|keratin-associated protein 4.3|ultrahigh sulfur keratin-associated protein 4.3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41167231, end_position_on_the_genomic_accession=41168221, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85291, CurrentID=0, Status='live', Symbol='KRTAP4-2', Aliases=['KAP4.2', 'KRTAP4.2'], description='keratin associated protein 4-2', other_designations='keratin-associated protein 4-2|keratin-associated protein 4.2|ultrahigh sulfur keratin-associated protein 4.2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41177446, end_position_on_the_genomic_accession=41178221, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85293, CurrentID=0, Status='live', Symbol='KRTAP3-3', Aliases=['KAP3.3', 'KRTAP3.3'], description='keratin associated protein 3-3', other_designations='keratin-associated protein 3-3|high sulfur keratin-associated protein 3.3|keratin-associated protein 3.3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40993430, end_position_on_the_genomic_accession=40994164, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85294, CurrentID=0, Status='live', Symbol='KRTAP2-4', Aliases=['KAP2.1B', 'KAP2.3', 'KAP2.4', 'KRTAP2-3', 'KRTAP2.3', 'KRTAP2.4'], description='keratin associated protein 2-4', other_designations='keratin-associated protein 2-4|Keratin-associated protein 2-3|Keratin-associated protein 2.3|high sulfur keratin-associated protein 2.4|keratin associated protein 2.1B|keratin-associated protein 2.4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41065116, end_position_on_the_genomic_accession=41065879, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    85300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85300, CurrentID=0, Status='live', Symbol='ATCAY', Aliases=['BNIP-H', 'CLAC'], description='ATCAY kinesin light chain interacting caytaxin', other_designations='caytaxin|ATCAY, caytaxin|BNIP-2-homolgy|BNIP-2-homology|Cayman ataxia|ataxia cayman type protein|ataxia cerebellar Cayman type', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3880685, end_position_on_the_genomic_accession=3928082, orientation='plus', exon_count=13, OMIM=[608179], no_hdr0=''),
    85301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85301, CurrentID=0, Status='live', Symbol='COL27A1', Aliases=['STLS'], description='collagen type XXVII alpha 1 chain', other_designations='collagen alpha-1(XXVII) chain|collagen, type XXVII, alpha 1', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114154271, end_position_on_the_genomic_accession=114312511, orientation='plus', exon_count=66, OMIM=[608461], no_hdr0=''),
    85302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85302, CurrentID=0, Status='live', Symbol='FBF1', Aliases=['Alb', 'FBF-1'], description='Fas binding factor 1', other_designations='fas-binding factor 1|Fas (TNFRSF6) binding factor 1|Fas binding protein 1|albatross|protein albatross', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75909574, end_position_on_the_genomic_accession=75941042, orientation='minus', exon_count=30, OMIM=[616807], no_hdr0=''),
    85313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85313, CurrentID=0, Status='live', Symbol='PPIL4', Aliases=['HDCME13P'], description='peptidylprolyl isomerase like 4', other_designations='peptidyl-prolyl cis-trans isomerase-like 4|PPIase|cyclophilin-like protein PPIL4|cyclophilin-type peptidyl-prolyl cis-trans isomerase|peptidylprolyl isomerase (cyclophilin)-like 4|rotamase PPIL4|serologically defined breast cancer antigen NY-BR-18', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149504495, end_position_on_the_genomic_accession=149546043, orientation='minus', exon_count=13, OMIM=[607609], no_hdr0=''),
    85315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85315, CurrentID=0, Status='live', Symbol='PAQR8', Aliases=['C6orf33', 'LMPB1', 'MPRB'], description='progestin and adipoQ receptor family member 8', other_designations='membrane progestin receptor beta|lysosomal membrane protein in brain-1|mPR beta|membrane progesterone P4 receptor beta|membrane progesterone receptor beta|progesterone and adipoQ receptor family member 8|progestin and adipoQ receptor family member VIII', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52362151, end_position_on_the_genomic_accession=52407777, orientation='plus', exon_count=2, OMIM=[607780], no_hdr0=''),
    85316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85316, CurrentID=0, Status='live', Symbol='BAGE5', Aliases=['CT2.5'], description='BAGE family member 5', other_designations='B melanoma antigen 5|B melanoma antigen family member 5|cancer/testis antigen 2.5|cancer/testis antigen family 2, member 5', map_location='13cen', chromosome='13', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    85317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85317, CurrentID=0, Status='live', Symbol='BAGE4', Aliases=['CT2.4', 'MLL3P'], description='BAGE family member 4', other_designations='B melanoma antigen 4|B melanoma antigen family member 4|MLL3 pseudogene|cancer/testis antigen 2.4|cancer/testis antigen family 2, member 4', map_location='21p11.1', chromosome='21', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    85318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85318, CurrentID=0, Status='live', Symbol='BAGE3', Aliases=['CT2.3'], description='BAGE family member 3', other_designations='B melanoma antigen 3|B melanoma antigen family member 3|cancer/testis antigen 2.3|cancer/testis antigen family 2, member 3', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[617777], no_hdr0=''),
    85320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85320, CurrentID=0, Status='live', Symbol='ABCC11', Aliases=['EWWD', 'MRP8', 'WW'], description='ATP binding cassette subfamily C member 11', other_designations='ATP-binding cassette sub-family C member 11|ATP-binding cassette protein C11|ATP-binding cassette transporter MRP8|ATP-binding cassette transporter sub-family C member 11|ATP-binding cassette, sub-family C (CFTR/MRP), member 11|multi-resistance protein 8|multidrug resistance-associated protein 8', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=48164842, end_position_on_the_genomic_accession=48249973, orientation='minus', exon_count=40, OMIM=[607040], no_hdr0=''),
    85329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85329, CurrentID=0, Status='live', Symbol='LGALS12', Aliases=['GAL12', 'GRIP1'], description='galectin 12', other_designations='galectin-12|galectin-related inhibitor of proliferation|lectin, galactoside-binding, soluble, 12|testicular secretory protein Li 26', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63506052, end_position_on_the_genomic_accession=63516772, orientation='plus', exon_count=11, OMIM=[606096], no_hdr0=''),
    85352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85352, CurrentID=0, Status='live', Symbol='SHISAL1', Aliases=['KIAA1644'], description='shisa like 1', other_designations='protein shisa-like-1', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44243665, end_position_on_the_genomic_accession=44331693, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    85358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85358, CurrentID=0, Status='live', Symbol='SHANK3', Aliases=['DEL22q13.3', 'PROSAP2', 'PSAP2', 'SCZD15', 'SPANK-2'], description='SH3 and multiple ankyrin repeat domains 3', other_designations='SH3 and multiple ankyrin repeat domains protein 3|proline rich synapse associated protein 2|shank postsynaptic density protein|shank3 postsynaptic density protein', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50672823, end_position_on_the_genomic_accession=50733212, orientation='plus', exon_count=23, OMIM=[606230], no_hdr0=''),
    85359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85359, CurrentID=0, Status='live', Symbol='DGCR6L', Aliases=['DGCR6'], description='DiGeorge syndrome critical region gene 6 like', other_designations='protein DGCR6L|diGeorge syndrome critical region 6-like protein', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20314238, end_position_on_the_genomic_accession=20320060, orientation='minus', exon_count=5, OMIM=[609459], no_hdr0=''),
    85360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85360, CurrentID=0, Status='live', Symbol='SYDE1', Aliases=['7h3', 'SYD1'], description='synapse defective Rho GTPase homolog 1', other_designations='rho GTPase-activating protein SYDE1|protein syd-1 homolog 1|synapse defective 1, Rho GTPase, homolog 1|synapse defective protein 1 homolog 1', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15107401, end_position_on_the_genomic_accession=15114985, orientation='plus', exon_count=8, OMIM=[617377], no_hdr0=''),
    85363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85363, CurrentID=0, Status='live', Symbol='TRIM5', Aliases=['RNF88alpha', 'TRIM5'], description='tripartite motif containing 5', other_designations='tripartite motif-containing protein 5|RING-type E3 ubiquitin transferase TRIM5|ring finger protein 88|tripartite motif containing 5 transcript variant iota|tripartite motif containing 5 transcript variant kappa|tripartite motif protein TRIM5', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5590906, end_position_on_the_genomic_accession=5685108, orientation='minus', exon_count=12, OMIM=[608487], no_hdr0=''),
    85364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85364, CurrentID=0, Status='live', Symbol='ZCCHC3', Aliases=['C20orf99'], description='zinc finger CCHC-type containing 3', other_designations='zinc finger CCHC domain-containing protein 3|zinc finger, CCHC domain containing 3', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=297570, end_position_on_the_genomic_accession=300321, orientation='plus', exon_count=1, OMIM=[618326], no_hdr0=''),
    85365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85365, CurrentID=0, Status='live', Symbol='ALG2', Aliases=['CDG1I', 'CDGIi', 'CMS14', 'CMSTA3', 'NET38', 'hALPG2'], description='ALG2 alpha-1,3/1,6-mannosyltransferase', other_designations='alpha-1,3/1,6-mannosyltransferase ALG2|GDP-Man:Man(1)GlcNAc(2)-PP-Dol alpha-1,3-mannosyltransferase|GDP-Man:Man(1)GlcNAc(2)-PP-dolichol mannosyltransferase|GDP-Man:Man(2)GlcNAc(2)-PP-Dol alpha-1,6-mannosyltransferase|alpha-1,3-mannosyltransferase ALG2|asparagine-linked glycosylation 2 homolog (S. cerevisiae, alpha-1,3-mannosyltransferase)|asparagine-linked glycosylation 2 homolog (yeast, alpha-1,3-mannosyltransferase)|asparagine-linked glycosylation 2, alpha-1,3-mannosyltransferase homolog|asparagine-linked glycosylation protein 2 homolog|homolog of yeast ALG2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=99216425, end_position_on_the_genomic_accession=99221942, orientation='minus', exon_count=3, OMIM=[607905], no_hdr0=''),
    85366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85366, CurrentID=0, Status='live', Symbol='MYLK2', Aliases=['KMLC', 'MLCK', 'MLCK2', 'skMLCK'], description='myosin light chain kinase 2', other_designations='myosin light chain kinase 2, skeletal/cardiac muscle|myosin light chain kinase 2, skeletal muscle', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31819356, end_position_on_the_genomic_accession=31834684, orientation='plus', exon_count=13, OMIM=[606566], no_hdr0=''),
    85369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85369, CurrentID=0, Status='live', Symbol='STRIP1', Aliases=['FAM40A', 'FAR11A'], description='striatin interacting protein 1', other_designations='striatin-interacting protein 1|FAR11 factor arrest 11 homolog A|family with sequence similarity 40, member A|homolog of yeast FAR11 protein 1|protein FAM40A', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110031577, end_position_on_the_genomic_accession=110054641, orientation='plus', exon_count=23, OMIM=[617918], no_hdr0=''),
    85376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85376, CurrentID=0, Status='live', Symbol='RIMBP3', Aliases=['RIM-BP3', 'RIM-BP3.1', 'RIM-BP3.A.1', 'RIMBP3A', 'RIMBP3'], description='RIMS binding protein 3', other_designations='RIMS-binding protein 3A|RIMS binding protein 3.1', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18605815, end_position_on_the_genomic_accession=18611919, orientation='minus', exon_count=1, OMIM=[612699], no_hdr0=''),
    85377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85377, CurrentID=0, Status='live', Symbol='MICALL1', Aliases=['MICAL-L1', 'MIRAB13'], description='MICAL like 1', other_designations='MICAL-like protein 1|molecule interacting with Rab13', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37906176, end_position_on_the_genomic_accession=37942822, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    85378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85378, CurrentID=0, Status='live', Symbol='TUBGCP6', Aliases=['GCP-6', 'GCP6', 'MCCRP', 'MCCRP1', 'MCPHCR'], description='tubulin gamma complex associated protein 6', other_designations='gamma-tubulin complex component 6', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50217694, end_position_on_the_genomic_accession=50245028, orientation='minus', exon_count=25, OMIM=[610053], no_hdr0=''),
    85379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85379, CurrentID=0, Status='live', Symbol='KIAA1671', Aliases=[], description='KIAA1671', other_designations='uncharacterized protein KIAA1671|CTA-221G9.5', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24952716, end_position_on_the_genomic_accession=25197448, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    85395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85395, CurrentID=0, Status='live', Symbol='SLX9', Aliases=['C21orf70', 'FAM207A', 'PRED56'], description='SLX9 ribosome biogenesis factor', other_designations='protein FAM207A|family with sequence similarity 207 member A', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44939697, end_position_on_the_genomic_accession=44976976, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    85397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85397, CurrentID=0, Status='live', Symbol='RGS8', Aliases=[], description='regulator of G protein signaling 8', other_designations='regulator of G-protein signaling 8|regulator of G-protein signalling 8', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182641814, end_position_on_the_genomic_accession=182753293, orientation='minus', exon_count=15, OMIM=[607189], no_hdr0=''),
    85403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85403, CurrentID=0, Status='live', Symbol='EAF1', Aliases=[], description='ELL associated factor 1', other_designations='ELL-associated factor 1|ELL (eleven nineteen lysine-rich leukemia gene)-associated factor 1', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15427598, end_position_on_the_genomic_accession=15442613, orientation='plus', exon_count=7, OMIM=[608315], no_hdr0=''),
    85406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85406, CurrentID=0, Status='live', Symbol='DNAJC14', Aliases=['DNAJ', 'DRIP78', 'HDJ3', 'LIP6'], description='DnaJ heat shock protein family (Hsp40) member C14', other_designations='dnaJ homolog subfamily C member 14|DnaJ (Hsp40) homolog, subfamily C, member 14|LYST-interacting protein LIP6|dnaJ protein homolog 3|dopamine receptor interacting protein|dopamine receptor-interacting protein of 78 kDa|human DnaJ protein 3', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55820985, end_position_on_the_genomic_accession=55830775, orientation='minus', exon_count=9, OMIM=[606092], no_hdr0=''),
    85407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85407, CurrentID=0, Status='live', Symbol='NKD1', Aliases=['Naked1'], description='NKD inhibitor of WNT signaling pathway 1', other_designations='protein naked cuticle homolog 1|Dvl-binding protein|NKD1, WNT signaling pathway inhibitor|naked cuticle homolog 1|naked cuticle-1|naked-1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50548396, end_position_on_the_genomic_accession=50649249, orientation='plus', exon_count=12, OMIM=[607851], no_hdr0=''),
    85409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85409, CurrentID=0, Status='live', Symbol='NKD2', Aliases=['Naked2'], description='NKD inhibitor of WNT signaling pathway 2', other_designations='protein naked cuticle homolog 2|Dvl-binding protein NKD2|NKD2, WNT signaling pathway inhibitor|naked cuticle homolog 2', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1008802, end_position_on_the_genomic_accession=1038943, orientation='plus', exon_count=11, OMIM=[607852], no_hdr0=''),
    85413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85413, CurrentID=0, Status='live', Symbol='SLC22A16', Aliases=['CT2', 'FLIPT2', 'HEL-S-18', 'OAT6', 'OCT6', 'OKB1', 'dJ261K5.1'], description='solute carrier family 22 member 16', other_designations='solute carrier family 22 member 16|WUGSC:RG331P03.1|carnitine transporter 2|epididymis secretory protein Li 18|flipt 2|fly-like putative organic ion transporter 2|fly-like putative transporter 2|organic cation transporter 6|organic cation transporter OKB1|organic cation/carnitine transporter 6|solute carrier family 22 (organic cation transporter), member 16|solute carrier family 22 (organic cation/carnitine transporter), member 16', map_location='6q21-q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110424587, end_position_on_the_genomic_accession=110476674, orientation='minus', exon_count=12, OMIM=[608276], no_hdr0=''),
    85414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85414, CurrentID=0, Status='live', Symbol='SLC45A3', Aliases=['IPCA-2', 'IPCA-6', 'IPCA-8', 'IPCA6', 'PCANAP2', 'PCANAP6', 'PCANAP8', 'PRST'], description='solute carrier family 45 member 3', other_designations='solute carrier family 45 member 3|prostate cancer associated protein 2|prostate cancer associated protein 6|prostate cancer associated protein 8|prostate cancer-associated gene 2|prostate cancer-associated gene 6|prostate cancer-associated gene 8|prostein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205657851, end_position_on_the_genomic_accession=205680509, orientation='minus', exon_count=5, OMIM=[605097], no_hdr0=''),
    85415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85415, CurrentID=0, Status='live', Symbol='RHPN2', Aliases=['P76RBE', 'RHOBP'], description='rhophilin Rho GTPase binding protein 2', other_designations='rhophilin-2|76 kDa RhoB effector protein|GTP-Rho-binding protein 2|rhophilin-like Rho-GTPase binding protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32978592, end_position_on_the_genomic_accession=33064888, orientation='minus', exon_count=15, OMIM=[617932], no_hdr0=''),
    85416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85416, CurrentID=0, Status='live', Symbol='ZIC5', Aliases=[], description='Zic family member 5', other_designations='zinc finger protein ZIC 5|Zic family member 5 (odd-paired homolog, Drosophila)|zinc finger protein of the cerebellum 5', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99962964, end_position_on_the_genomic_accession=99971909, orientation='minus', exon_count=4, OMIM=[617896], no_hdr0=''),
    85417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85417, CurrentID=0, Status='live', Symbol='CCNB3', Aliases=['CYCB3'], description='cyclin B3', other_designations='G2/mitotic-specific cyclin-B3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=50202713, end_position_on_the_genomic_accession=50351914, orientation='plus', exon_count=16, OMIM=[300456], no_hdr0=''),
    85437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85437, CurrentID=0, Status='live', Symbol='ZCRB1', Aliases=['MADP-1', 'MADP1', 'RBM36', 'SNRNP31', 'ZCCHC19'], description='zinc finger CCHC-type and RNA binding motif containing 1', other_designations='zinc finger CCHC-type and RNA-binding motif-containing protein 1|U11/U12 small nuclear ribonucleoprotein 31 kDa protein|U11/U12 snRNP 31 kDa protein|U11/U12 snRNP 31K|U11/U12-31K|zinc finger CCHC-type and RNA binding motif 1', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=42312086, end_position_on_the_genomic_accession=42326107, orientation='minus', exon_count=8, OMIM=[610750], no_hdr0=''),
    85438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85438, CurrentID=0, Status='live', Symbol='CABS1', Aliases=['C4orf35', 'CLPH', 'NYD-SP26'], description='calcium binding protein, spermatid associated 1', other_designations='calcium-binding and spermatid-specific protein 1|calcium-binding protein, sperm-specific 1|calcium-binding protein, spermatid-specific 1|casein-like phosphoprotein|testis development protein NYD-SP26', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70334981, end_position_on_the_genomic_accession=70337116, orientation='plus', exon_count=2, OMIM=[618600], no_hdr0=''),
    85439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85439, CurrentID=0, Status='live', Symbol='STON2', Aliases=['STN2', 'STNB', 'STNB2'], description='stonin 2', other_designations='stonin-2|stoned B homolog 2', map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=81260652, end_position_on_the_genomic_accession=81436465, orientation='minus', exon_count=13, OMIM=[608467], no_hdr0=''),
    85440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85440, CurrentID=0, Status='live', Symbol='DOCK7', Aliases=['DEE23', 'EIEE23', 'ZIR2'], description='dedicator of cytokinesis 7', other_designations='dedicator of cytokinesis protein 7', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62454726, end_position_on_the_genomic_accession=62688386, orientation='minus', exon_count=53, OMIM=[615730], no_hdr0=''),
    85441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85441, CurrentID=0, Status='live', Symbol='HELZ2', Aliases=['PDIP-1', 'PRIC285'], description='helicase with zinc finger 2', other_designations='helicase with zinc finger domain 2|ATP-dependent helicase PRIC285|PDIP1|PPAR gamma DBD-interacting protein 1|PPAR-alpha-interacting complex protein 285|PPAR-gamma DNA-binding domain-interacting protein 1|PPARG-DBD-interacting protein 1|PPARgamma-DNA-binding domain-interacting protein1|PRIC complex|helicase with zinc finger 2, transcriptional coactivator|peroxisomal proliferator-activated receptor A interacting complex 285|peroxisomal proliferator-activated receptor A-interacting complex 285 kDa protein|peroxisomal proliferator-activated receptor alpha-interacting cofactor complex, 285 kD subunit', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63558086, end_position_on_the_genomic_accession=63574239, orientation='minus', exon_count=20, OMIM=[611265], no_hdr0=''),
    85442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85442, CurrentID=0, Status='live', Symbol='KNDC1', Aliases=['C10orf23', 'RASGEF2', 'Very-KIND', 'bB439H18.3', 'v-KIND'], description='kinase non-catalytic C-lobe domain containing 1', other_designations='kinase non-catalytic C-lobe domain-containing protein 1|KIND domain-containing protein 1|RasGEF domain family, member 2|cerebral protein 9|kinase non-catalytic C-lobe domain (KIND) containing 1|protein very KIND|ras-GEF domain-containing family member 2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133160219, end_position_on_the_genomic_accession=133226412, orientation='plus', exon_count=34, OMIM=[616237], no_hdr0=''),
    85443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85443, CurrentID=0, Status='live', Symbol='DCLK3', Aliases=['CLR', 'DCAMKL3', 'DCDC3C', 'DCK3'], description='doublecortin like kinase 3', other_designations='serine/threonine-protein kinase DCLK3|CLICK-I,II-related|doublecortin and CaM kinase-like 3|doublecortin domain-containing protein 3C|doublecortin-like and CAM kinase-like 3', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=36712421, end_position_on_the_genomic_accession=36764553, orientation='minus', exon_count=7, OMIM=[613167], no_hdr0=''),
    85444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85444, CurrentID=0, Status='live', Symbol='LRRCC1', Aliases=['CLERC', 'CLERK', 'SAP2', 'VFL1'], description='leucine rich repeat and coiled-coil centrosomal protein 1', other_designations='leucine-rich repeat and coiled-coil domain-containing protein 1|centrosomal leucine-rich repeat and coiled-coil domain-containing protein|sodium channel associated protein 2|variable number of flagella 1 homolog', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85107149, end_position_on_the_genomic_accession=85146080, orientation='plus', exon_count=20, OMIM=[617791], no_hdr0=''),
    85445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85445, CurrentID=0, Status='live', Symbol='CNTNAP4', Aliases=['CASPR4'], description='contactin associated protein family member 4', other_designations='contactin-associated protein-like 4|cell recognition molecule Caspr4|contactin associated protein like 4', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=76277376, end_position_on_the_genomic_accession=76563610, orientation='plus', exon_count=29, OMIM=[610518], no_hdr0=''),
    85446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85446, CurrentID=0, Status='live', Symbol='ZFHX2', Aliases=['MARSIS', 'ZFH-5', 'ZFH5', 'ZNF409'], description='zinc finger homeobox 2', other_designations='zinc finger homeobox protein 2|ZFH-2|zinc finger homeodomain protein 2|zinc finger protein 409', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23520857, end_position_on_the_genomic_accession=23556315, orientation='minus', exon_count=17, OMIM=[617828], no_hdr0=''),
    85449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85449, CurrentID=0, Status='live', Symbol='KIAA1755', Aliases=[], description='KIAA1755', other_designations='uncharacterized protein KIAA1755|RP5-1054A22.3', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38210503, end_position_on_the_genomic_accession=38260772, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    85450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85450, CurrentID=0, Status='live', Symbol='ITPRIP', Aliases=['DANGER', 'KIAA1754', 'bA127L20', 'bA127L20.2'], description='inositol 1,4,5-trisphosphate receptor interacting protein', other_designations='inositol 1,4,5-trisphosphate receptor-interacting protein|inositol 1,4,5-triphosphate receptor-interacting protein', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104309700, end_position_on_the_genomic_accession=104338465, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    85451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85451, CurrentID=0, Status='live', Symbol='UNK', Aliases=['UNKEMPT', 'ZC3H5', 'ZC3HDC5'], description='unk zinc finger', other_designations='RING finger protein unkempt homolog|unk family zinc finger|unkempt family zinc finger|unkempt homolog|zinc finger CCCH domain-containing protein 5|zinc finger CCCH-type containing 5|zinc finger CCCH-type domain containing 5', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75784771, end_position_on_the_genomic_accession=75825799, orientation='plus', exon_count=21, OMIM=[616375], no_hdr0=''),
    85452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85452, CurrentID=0, Status='live', Symbol='CFAP74', Aliases=['C1orf222', 'KIAA1751'], description='cilia and flagella associated protein 74', other_designations='cilia- and flagella-associated protein 74', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1921957, end_position_on_the_genomic_accession=2003837, orientation='minus', exon_count=41, OMIM=[], no_hdr0=''),
    85453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85453, CurrentID=0, Status='live', Symbol='TSPYL5', Aliases=[], description='TSPY like 5', other_designations='testis-specific Y-encoded-like protein 5|TSPY-like protein 5', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=97273488, end_position_on_the_genomic_accession=97277928, orientation='minus', exon_count=1, OMIM=[614721], no_hdr0=''),
    85455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85455, CurrentID=0, Status='live', Symbol='DISP2', Aliases=['C15orf36', 'DISPB', 'HsT16908', 'LINC00594'], description='dispatched RND transporter family member 2', other_designations='protein dispatched homolog 2|dispatched B|long intergenic non-protein coding RNA 594', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40354359, end_position_on_the_genomic_accession=40378621, orientation='plus', exon_count=10, OMIM=[607503], no_hdr0=''),
    85456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85456, CurrentID=0, Status='live', Symbol='TNKS1BP1', Aliases=['TAB182'], description='tankyrase 1 binding protein 1', other_designations='182 kDa tankyrase-1-binding protein|tankyrase 1 binding protein 1, 182kDa|tankyrase 1-binding protein of 182 kDa|testis secretory sperm-binding protein Li 206a', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57299631, end_position_on_the_genomic_accession=57324952, orientation='minus', exon_count=14, OMIM=[607104], no_hdr0=''),
    85457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85457, CurrentID=0, Status='live', Symbol='CIPC', Aliases=['KIAA1737'], description='CLOCK interacting pacemaker', other_designations='CLOCK-interacting pacemaker|CLOCK-interacting circadian protein|CLOCK-interacting protein, circadian', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77098258, end_position_on_the_genomic_accession=77117287, orientation='plus', exon_count=4, OMIM=[616995], no_hdr0=''),
    85458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85458, CurrentID=0, Status='live', Symbol='DIXDC1', Aliases=['CCD1'], description='DIX domain containing 1', other_designations='dixin|coiled-coil protein DIX1', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111927169, end_position_on_the_genomic_accession=112022653, orientation='plus', exon_count=25, OMIM=[610493], no_hdr0=''),
    85459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85459, CurrentID=0, Status='live', Symbol='CEP295', Aliases=['KIAA1731'], description='centrosomal protein 295', other_designations='centrosomal protein of 295 kDa|centriolar protein CEP295|centrosomal protein 295kDa', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93661682, end_position_on_the_genomic_accession=93730381, orientation='plus', exon_count=32, OMIM=[617728], no_hdr0=''),
    85460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85460, CurrentID=0, Status='live', Symbol='ZNF518B', Aliases=[], description='zinc finger protein 518B', other_designations='zinc finger protein 518B', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=10439880, end_position_on_the_genomic_accession=10457426, orientation='minus', exon_count=5, OMIM=[617734], no_hdr0=''),
    85461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85461, CurrentID=0, Status='live', Symbol='TANC1', Aliases=['ROLSB', 'TANC'], description='tetratricopeptide repeat, ankyrin repeat and coiled-coil containing 1', other_designations='protein TANC1|TPR domain, ankyrin-repeat and coiled-coil-containing|rolling pebbles homolog B|tetratricopeptide repeat, ankyrin repeat and coiled-coil domain-containing protein 1', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=158968600, end_position_on_the_genomic_accession=159232659, orientation='plus', exon_count=34, OMIM=[611397], no_hdr0=''),
    85462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85462, CurrentID=0, Status='live', Symbol='FHDC1', Aliases=['INF1'], description='FH2 domain containing 1', other_designations='FH2 domain-containing protein 1|inverted formin-1', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=152935445, end_position_on_the_genomic_accession=152979671, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    85463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85463, CurrentID=0, Status='live', Symbol='ZC3H12C', Aliases=['MCPIP3'], description='zinc finger CCCH-type containing 12C', other_designations='probable ribonuclease ZC3H12C|MCP-induced protein 3|zinc finger CCCH domain-containing protein 12C', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=110092425, end_position_on_the_genomic_accession=110171841, orientation='plus', exon_count=9, OMIM=[615001], no_hdr0=''),
    85464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85464, CurrentID=0, Status='live', Symbol='SSH2', Aliases=['SSH-2', 'SSH-2L'], description='slingshot protein phosphatase 2', other_designations='protein phosphatase Slingshot homolog 2|SSH-like protein 2', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29625938, end_position_on_the_genomic_accession=29930239, orientation='minus', exon_count=24, OMIM=[606779], no_hdr0=''),
    85465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85465, CurrentID=0, Status='live', Symbol='SELENOI', Aliases=['EPT1', 'SELI', 'SEPI', 'SPG81'], description='selenoprotein I', other_designations='ethanolaminephosphotransferase 1|ethanolaminephosphotransferase 1 (CDP-ethanolamine-specific)|hEPT1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26346143, end_position_on_the_genomic_accession=26395885, orientation='plus', exon_count=10, OMIM=[607915], no_hdr0=''),
    85474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85474, CurrentID=0, Status='live', Symbol='LBX2', Aliases=['LP3727'], description='ladybird homeobox 2', other_designations='transcription factor LBX2|ladybird homeobox protein homolog 2|ladybird-like homeobox 2|ladybird-like homeodomain protein 2', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74497517, end_position_on_the_genomic_accession=74503316, orientation='minus', exon_count=3, OMIM=[607164], no_hdr0=''),
    85476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85476, CurrentID=0, Status='live', Symbol='GFM1', Aliases=['COXPD1', 'EFG', 'EFG1', 'EFGM', 'EGF1', 'GFM', 'hEFG1', 'mtEF-G1'], description='G elongation factor mitochondrial 1', other_designations='elongation factor G, mitochondrial|G translation elongation factor, mitochondrial|mitochondrial elongation factor G|mitochondrial elongation factor G1', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=158644527, end_position_on_the_genomic_accession=158695581, orientation='plus', exon_count=19, OMIM=[606639], no_hdr0=''),
    85477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85477, CurrentID=0, Status='live', Symbol='SCIN', Aliases=[], description='scinderin', other_designations='adseverin', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=12570720, end_position_on_the_genomic_accession=12660182, orientation='plus', exon_count=18, OMIM=[613416], no_hdr0=''),
    85478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85478, CurrentID=0, Status='live', Symbol='CCDC65', Aliases=['CFAP250', 'DRC2', 'FAP250', 'NYD-SP28'], description='coiled-coil domain containing 65', other_designations='dynein regulatory complex subunit 2|testis development protein NYD-SP28', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48904133, end_position_on_the_genomic_accession=48921576, orientation='plus', exon_count=8, OMIM=[611088], no_hdr0=''),
    85479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85479, CurrentID=0, Status='live', Symbol='DNAJC5B', Aliases=['CSP-beta'], description='DnaJ heat shock protein family (Hsp40) member C5 beta', other_designations='dnaJ homolog subfamily C member 5B|DnaJ (Hsp40) homolog, subfamily C, member 5 beta|beta cysteine string protein|beta-CSP|cysteine string protein beta|dnaJ homolog subfamily C member X|testicular tissue protein Li 55', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66014978, end_position_on_the_genomic_accession=66101245, orientation='plus', exon_count=10, OMIM=[613945], no_hdr0=''),
    85480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85480, CurrentID=0, Status='live', Symbol='TSLP', Aliases=[], description='thymic stromal lymphopoietin', other_designations='thymic stromal lymphopoietin', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=111070062, end_position_on_the_genomic_accession=111078026, orientation='plus', exon_count=6, OMIM=[607003], no_hdr0=''),
    85481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85481, CurrentID=0, Status='live', Symbol='PSKH2', Aliases=[], description='protein serine kinase H2', other_designations='serine/threonine-protein kinase H2|serine/threonine kinase PSKH2', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86047109, end_position_on_the_genomic_accession=86069987, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    85508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85508, CurrentID=0, Status='live', Symbol='SCRT2', Aliases=['ZNF898B'], description='scratch family transcriptional repressor 2', other_designations='transcriptional repressor scratch 2|scratch 2 protein|scratch family zinc finger 2|scratch homolog 2, zinc finger protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=661596, end_position_on_the_genomic_accession=675802, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    85509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85509, CurrentID=0, Status='live', Symbol='MBD3L1', Aliases=['MBD3L'], description='methyl-CpG binding domain protein 3 like 1', other_designations='methyl-CpG-binding domain protein 3-like 1|MBD3-like protein 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8832377, end_position_on_the_genomic_accession=8843319, orientation='plus', exon_count=4, OMIM=[607963], no_hdr0=''),
    85569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85569, CurrentID=0, Status='live', Symbol='GALP', Aliases=[], description='galanin like peptide', other_designations='galanin-like peptide|alarin|gal-like peptide', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56176008, end_position_on_the_genomic_accession=56185775, orientation='plus', exon_count=6, OMIM=[611178], no_hdr0=''),
    85865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=85865, CurrentID=0, Status='live', Symbol='GTPBP10', Aliases=['ObgH2', 'UG0751c10'], description='GTP binding protein 10', other_designations='GTP-binding protein 10|GTP binding protein 10 (putative)|protein obg homolog 2', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90346716, end_position_on_the_genomic_accession=90391453, orientation='plus', exon_count=10, OMIM=[610920], no_hdr0=''),
    86614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=86614, CurrentID=0, Status='live', Symbol='HSFY1', Aliases=['HSF2L', 'HSFY'], description='heat shock transcription factor Y-linked 1', other_designations='heat shock transcription factor, Y-linked|heat shock transcription factor 2-like protein', map_location='Yq11.222', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=18529678, end_position_on_the_genomic_accession=18588963, orientation='plus', exon_count=8, OMIM=[400029], no_hdr0=''),
    87178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=87178, CurrentID=0, Status='live', Symbol='PNPT1', Aliases=['COXPD13', 'DFNB70', 'OLD35', 'PNPASE', 'old-35'], description='polyribonucleotide nucleotidyltransferase 1', other_designations="polyribonucleotide nucleotidyltransferase 1, mitochondrial|3'-5' RNA exonuclease OLD35|PNPase 1|PNPase old-35|polynucleotide phosphorylase 1|polynucleotide phosphorylase-like protein", map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55634061, end_position_on_the_genomic_accession=55693853, orientation='minus', exon_count=29, OMIM=[610316], no_hdr0=''),
    87769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=87769, CurrentID=0, Status='live', Symbol='GGACT', Aliases=['A2LD1'], description='gamma-glutamylamine cyclotransferase', other_designations='gamma-glutamylaminecyclotransferase|AIG2-like domain 1|AIG2-like domain-containing protein 1', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=100530180, end_position_on_the_genomic_accession=100588789, orientation='minus', exon_count=5, OMIM=[613378], no_hdr0=''),
    88455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=88455, CurrentID=0, Status='live', Symbol='ANKRD13A', Aliases=['ANKRD13', 'NY-REN-25'], description='ankyrin repeat domain 13A', other_designations='ankyrin repeat domain-containing protein 13A|NY-REN-25 antigen', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109999169, end_position_on_the_genomic_accession=110039763, orientation='plus', exon_count=17, OMIM=[615123], no_hdr0=''),
    88745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=88745, CurrentID=0, Status='live', Symbol='RRP36', Aliases=['C6orf153', 'dJ20C7.4'], description='ribosomal RNA processing 36', other_designations='ribosomal RNA processing protein 36 homolog|RNA processing factor|ribosomal RNA processing 36 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43021623, end_position_on_the_genomic_accession=43029599, orientation='plus', exon_count=7, OMIM=[613475], no_hdr0=''),
    89122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89122, CurrentID=0, Status='live', Symbol='TRIM4', Aliases=['RNF87'], description='tripartite motif containing 4', other_designations='E3 ubiquitin-protein ligase TRIM4|RING finger protein 87|RING-type E3 ubiquitin transferase TRIM4|tripartite motif protein 4', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99890403, end_position_on_the_genomic_accession=99919530, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    89765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89765, CurrentID=0, Status='live', Symbol='RSPH1', Aliases=['CT79', 'RSP440A', 'TSA2', 'TSGA2', 'RSPH1'], description='radial spoke head component 1', other_designations='radial spoke head 1 homolog|cancer/testis antigen 79|male meiotic metaphase chromosome-associated acidic protein|meichroacidin|testes specific gene A2 homolog|testis specific A2 homolog', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42472486, end_position_on_the_genomic_accession=42496246, orientation='minus', exon_count=9, OMIM=[609314], no_hdr0=''),
    89766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89766, CurrentID=0, Status='live', Symbol='UMODL1', Aliases=[], description='uromodulin like 1', other_designations='uromodulin-like 1|olfactorin', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42062877, end_position_on_the_genomic_accession=42142996, orientation='plus', exon_count=27, OMIM=[613859], no_hdr0=''),
    89777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89777, CurrentID=0, Status='live', Symbol='SERPINB12', Aliases=['YUKOPIN'], description='serpin family B member 12', other_designations='serpin B12|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 12|serpin peptidase inhibitor, clade B (ovalbumin), member 12', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63519164, end_position_on_the_genomic_accession=63569329, orientation='plus', exon_count=12, OMIM=[615662], no_hdr0=''),
    89778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89778, CurrentID=0, Status='live', Symbol='SERPINB11', Aliases=['EPIPIN', 'SERPIN11'], description='serpin family B member 11', other_designations='serpin B11|serine (or cysteine) proteinase inhibitor, clade B (ovalbumin), member 11|serpin peptidase inhibitor, clade B (ovalbumin), member 11', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63702304, end_position_on_the_genomic_accession=63723893, orientation='plus', exon_count=9, OMIM=[615682], no_hdr0=''),
    89780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89780, CurrentID=0, Status='live', Symbol='WNT3A', Aliases=[], description='Wnt family member 3A', other_designations='protein Wnt-3a|wingless-type MMTV integration site family, member 3A', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228006998, end_position_on_the_genomic_accession=228067113, orientation='plus', exon_count=6, OMIM=[606359], no_hdr0=''),
    89781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89781, CurrentID=0, Status='live', Symbol='HPS4', Aliases=['BLOC3S2', 'LE'], description='HPS4 biogenesis of lysosomal organelles complex 3 subunit 2', other_designations='Hermansky-Pudlak syndrome 4 protein|light-ear protein homolog', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26443109, end_position_on_the_genomic_accession=26483863, orientation='minus', exon_count=19, OMIM=[606682], no_hdr0=''),
    89782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89782, CurrentID=0, Status='live', Symbol='LMLN', Aliases=['GP63', 'INV', 'IX14', 'LMNL1', 'MSP'], description='leishmanolysin like peptidase', other_designations='leishmanolysin-like peptidase|invadolysin|leishmanolysin-2|leishmanolysin-like (metallopeptidase M8 family)', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=197960200, end_position_on_the_genomic_accession=198043720, orientation='plus', exon_count=17, OMIM=[609380], no_hdr0=''),
    89790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89790, CurrentID=0, Status='live', Symbol='SIGLEC10', Aliases=['PRO940', 'SIGLEC-10', 'SLG2'], description='sialic acid binding Ig like lectin 10', other_designations='sialic acid-binding Ig-like lectin 10|sialic acid binding Ig-like lectin 10 Ig-like lectin 7|siglec-like gene 2|siglec-like protein 2', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51410020, end_position_on_the_genomic_accession=51417642, orientation='minus', exon_count=11, OMIM=[606091], no_hdr0=''),
    89792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89792, CurrentID=0, Status='live', Symbol='GAL3ST3', Aliases=['GAL3ST-3', 'GAL3ST2'], description='galactose-3-O-sulfotransferase 3', other_designations="galactose-3-O-sulfotransferase 3|beta-galactose-3-O-sulfotransferase 3|gal-beta-1, 3-GalNAc 3'-sulfotransferase 3|galactose 3'-sulfotransferase|galbeta1-3GalNAc 3'-sulfotransferase 3", map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66040765, end_position_on_the_genomic_accession=66049161, orientation='minus', exon_count=3, OMIM=[608234], no_hdr0=''),
    89795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89795, CurrentID=0, Status='live', Symbol='NAV3', Aliases=['POMFIL1', 'STEERIN3', 'unc53H3'], description='neuron navigator 3', other_designations='neuron navigator 3|pore membrane and/or filament interacting like protein 1|unc-53 homolog 3', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=77571856, end_position_on_the_genomic_accession=78213010, orientation='plus', exon_count=42, OMIM=[611629], no_hdr0=''),
    89796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89796, CurrentID=0, Status='live', Symbol='NAV1', Aliases=['POMFIL3', 'STEERIN1', 'UNC53H1'], description='neuron navigator 1', other_designations='neuron navigator 1|pore membrane and/or filament interacting like protein 3|unc-53 homolog 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201539127, end_position_on_the_genomic_accession=201826969, orientation='plus', exon_count=35, OMIM=[611628], no_hdr0=''),
    89797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89797, CurrentID=0, Status='live', Symbol='NAV2', Aliases=['HELAD1', 'POMFIL2', 'RAINB1', 'STEERIN2', 'UNC53H2'], description='neuron navigator 2', other_designations='neuron navigator 2|helicase, APC down-regulated 1|pore membrane and/or filament-interacting-like protein 2|retinoic acid inducible gene in neuroblastoma 1|steerin-2|unc-53 homolog 2', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=19345200, end_position_on_the_genomic_accession=20121601, orientation='plus', exon_count=52, OMIM=[607026], no_hdr0=''),
    89801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89801, CurrentID=0, Status='live', Symbol='PPP1R3F', Aliases=['HB2E', 'LL0XNC01-7P3.1', 'R3F'], description='protein phosphatase 1 regulatory subunit 3F', other_designations='protein phosphatase 1 regulatory subunit 3F|protein phosphatase 1, regulatory (inhibitor) subunit 3F', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49269793, end_position_on_the_genomic_accession=49301465, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    89822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89822, CurrentID=0, Status='live', Symbol='KCNK17', Aliases=['K2p17.1', 'TALK-2', 'TALK2', 'TASK-4', 'TASK4'], description='potassium two pore domain channel subfamily K member 17', other_designations='potassium channel subfamily K member 17|2P domain potassium channel Talk-2|TWIK-related acid-sensitive K(+) channel 4|TWIK-related acid-sensitive K+ 4|TWIK-related alkaline pH-activated K(+) channel 2|acid-sensitive potassium channel protein TASK-4|potassium channel, two pore domain subfamily K, member 17', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39299001, end_position_on_the_genomic_accession=39314419, orientation='minus', exon_count=6, OMIM=[607370], no_hdr0=''),
    89832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89832, CurrentID=0, Status='live', Symbol='CHRFAM7A', Aliases=['CHRNA7', 'CHRNA7-DR1', 'D-10', 'NACHRA7'], description='CHRNA7 (exons 5-10) and FAM7A (exons A-E) fusion', other_designations='CHRNA7-FAM7A fusion protein|CHRNA7 (cholinergic receptor, nicotinic, alpha 7, exons 5-10) and FAM7A (family with sequence similarity 7A, exons A-E) fusion|CHRNA7 (cholinergic receptor, nicotinic, alpha polypeptide 7, exons 5-10) and FAM7A (family with sequence similarity 7A, exons A-E) fusion|Neuronal acetylcholine receptor subunit alpha-7|alpha 7 neuronal nicotinic acetylcholine receptor-FAM7A hybrid|alpha-7 nicotinic cholinergic receptor subunit', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30360566, end_position_on_the_genomic_accession=30393849, orientation='minus', exon_count=12, OMIM=[609756], no_hdr0=''),
    89839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89839, CurrentID=0, Status='live', Symbol='ARHGAP11B', Aliases=["B'-T", 'FAM7B1', 'GAP (1-8)'], description='Rho GTPase activating protein 11B', other_designations='inactive Rho GTPase-activating protein 11B|family with sequence similarity 7, member B1|rho GTPase-activating protein 11B|rho-type GTPase-activating protein 11B', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30626128, end_position_on_the_genomic_accession=30649229, orientation='plus', exon_count=11, OMIM=[616310], no_hdr0=''),
    89845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89845, CurrentID=0, Status='live', Symbol='ABCC10', Aliases=['EST182763', 'MRP7', 'SIMRP7'], description='ATP binding cassette subfamily C member 10', other_designations='ATP-binding cassette sub-family C member 10|ATP-binding cassette, sub-family C (CFTR/MRP), member 10|multidrug resistance-associated protein 7', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43427538, end_position_on_the_genomic_accession=43451994, orientation='plus', exon_count=25, OMIM=[612509], no_hdr0=''),
    89846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89846, CurrentID=0, Status='live', Symbol='FGD3', Aliases=['ZFYVE5'], description='FYVE, RhoGEF and PH domain containing 3', other_designations='FYVE, RhoGEF and PH domain-containing protein 3|FGD1 family, member 3|faciogenital dysplasia 3|zinc finger FYVE domain-containing protein 5', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92947523, end_position_on_the_genomic_accession=93036236, orientation='plus', exon_count=21, OMIM=[617554], no_hdr0=''),
    89848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89848, CurrentID=0, Status='live', Symbol='FCHSD1', Aliases=['NWK2'], description='FCH and double SH3 domains 1', other_designations='F-BAR and double SH3 domains protein 1|FCH and double SH3 domains protein 1|nervous wreck homolog 2|protein nervous wreck 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141639302, end_position_on_the_genomic_accession=141651443, orientation='minus', exon_count=21, OMIM=[617555], no_hdr0=''),
    89849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89849, CurrentID=0, Status='live', Symbol='ATG16L2', Aliases=['ATG16B', 'WDR80'], description='autophagy related 16 like 2', other_designations='protein Atg16l2|APG16-like 2|ATG16 autophagy related 16-like 2|WD repeat-containing protein 80|autophagy-related protein 16-2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72814407, end_position_on_the_genomic_accession=72845132, orientation='plus', exon_count=20, OMIM=[618716], no_hdr0=''),
    89853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89853, CurrentID=0, Status='live', Symbol='MVB12B', Aliases=['C9orf28', 'FAM125B'], description='multivesicular body subunit 12B', other_designations='multivesicular body subunit 12B|ESCRT-I complex subunit MVB12B|family with sequence similarity 125, member B', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=126326829, end_position_on_the_genomic_accession=126507040, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    89857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89857, CurrentID=0, Status='live', Symbol='KLHL6', Aliases=[], description='kelch like family member 6', other_designations='kelch-like protein 6', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=183487551, end_position_on_the_genomic_accession=183555711, orientation='minus', exon_count=7, OMIM=[614214], no_hdr0=''),
    89858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89858, CurrentID=0, Status='live', Symbol='SIGLEC12', Aliases=['S2V', 'SIGLECL1', 'SLG', 'Siglec-XII'], description='sialic acid binding Ig like lectin 12', other_designations='sialic acid-binding Ig-like lectin 12|SIGLEC-like 1|sialic acid-binding Ig-like lectin-like 1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51491227, end_position_on_the_genomic_accession=51501800, orientation='minus', exon_count=8, OMIM=[606094], no_hdr0=''),
    89866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89866, CurrentID=0, Status='live', Symbol='SEC16B', Aliases=['LZTR2', 'PGPR-p117', 'RGPR', 'RGPR-p117', 'SEC16S'], description='SEC16 homolog B, endoplasmic reticulum export factor', other_designations='protein transport protein Sec16B|leucine zipper transcription regulator 2|protein SEC16 homolog B|regucalcin gene promoter region-related protein p117|regucalcin gene promotor region related protein', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=177928788, end_position_on_the_genomic_accession=177984284, orientation='minus', exon_count=28, OMIM=[612855], no_hdr0=''),
    89869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89869, CurrentID=0, Status='live', Symbol='PLCZ1', Aliases=['NYD-SP27', 'PLC-zeta-1', 'PLCzeta', 'SPGF17'], description='phospholipase C zeta 1', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase zeta-1|PI-phospholipase C zeta 1|phosphoinositide phospholipase C-zeta-1|testicular tissue protein Li 145|testis-development related NYD-SP27', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=18645529, end_position_on_the_genomic_accession=18738052, orientation='minus', exon_count=19, OMIM=[608075], no_hdr0=''),
    89870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89870, CurrentID=0, Status='live', Symbol='TRIM15', Aliases=['RNF93', 'ZNF178', 'ZNFB7'], description='tripartite motif containing 15', other_designations='tripartite motif-containing protein 15|RING finger protein 93|zinc finger protein 178|zinc finger protein B7', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30163546, end_position_on_the_genomic_accession=30172693, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    89872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89872, CurrentID=0, Status='live', Symbol='AQP10', Aliases=['AQPA_HUMAN'], description='aquaporin 10', other_designations='aquaporin-10|AQP-10|aquaglyceroporin-10|small intestine aquaporin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154321059, end_position_on_the_genomic_accession=154325325, orientation='plus', exon_count=6, OMIM=[606578], no_hdr0=''),
    89874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89874, CurrentID=0, Status='live', Symbol='SLC25A21', Aliases=['MTDPS18', 'ODC', 'ODC1'], description='solute carrier family 25 member 21', other_designations='mitochondrial 2-oxodicarboxylate carrier|oxodicarboxylate carrier|solute carrier family 25 (mitochondrial oxoadipate carrier), member 21|solute carrier family 25 (mitochondrial oxodicarboxylate carrier), member 21', map_location='14q13.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=36677318, end_position_on_the_genomic_accession=37172606, orientation='minus', exon_count=13, OMIM=[607571], no_hdr0=''),
    89876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89876, CurrentID=0, Status='live', Symbol='CFAP91', Aliases=['AAT1', 'AAT1alpha', 'C3orf15', 'CaM-IP2', 'MAATS1', 'SPATA26', 'SPGF51'], description='cilia and flagella associated protein 91', other_designations='cilia- and flagella-associated protein 91|AAT-1|AAT1-alpha|AMY-1-associating protein expressed in testis 1|MYCBP associated and testis expressed 1|MYCBP-associated, testis expressed 1|MYCBP-binding protein|MYCBP/AMY-1-associated testis-expressed protein 1|MYCBP/AMY-1-associated, testis expressed 1|protein MAATS1|spermatogenesis associated 26', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119703022, end_position_on_the_genomic_accession=119767102, orientation='plus', exon_count=19, OMIM=[609910], no_hdr0=''),
    89882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89882, CurrentID=0, Status='live', Symbol='TPD52L3', Aliases=['D55', 'NYDSP25', 'TPD55', 'hD55'], description='TPD52 like 3', other_designations='tumor protein D55|protein kinase NYD-SP25|testis development protein NYD-SP25|testis tissue sperm-binding protein Li 87P|tumor protein D52 like 3', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6328370, end_position_on_the_genomic_accession=6331891, orientation='plus', exon_count=3, OMIM=[617567], no_hdr0=''),
    89884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89884, CurrentID=0, Status='live', Symbol='LHX4', Aliases=['CPHD4'], description='LIM homeobox 4', other_designations='LIM/homeobox protein Lhx4|LIM homeobox protein 4', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=180228372, end_position_on_the_genomic_accession=180278984, orientation='plus', exon_count=9, OMIM=[602146], no_hdr0=''),
    89885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89885, CurrentID=0, Status='live', Symbol='FATE1', Aliases=['CT43', 'FATE'], description='fetal and adult testis expressed 1', other_designations='fetal and adult testis-expressed transcript protein|BJ-HCC-2 antigen|cancer/testis antigen 43|tumor antigen BJ-HCC-2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151716035, end_position_on_the_genomic_accession=151723194, orientation='plus', exon_count=5, OMIM=[300450], no_hdr0=''),
    89886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89886, CurrentID=0, Status='live', Symbol='SLAMF9', Aliases=['CD2F-10', 'CD2F10', 'CD84-H1', 'CD84H1', 'SF2001'], description='SLAM family member 9', other_designations='SLAM family member 9|CD2 family member 10|CD84 homolog 1|cluster of differentiation 2 antigen family member 10|cluster of differentiation 84 homolog 1|signaling lymphocytic activation molecule family member 2001|signaling lymphocytic activation molecule family member 9', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159951492, end_position_on_the_genomic_accession=159984730, orientation='minus', exon_count=6, OMIM=[608589], no_hdr0=''),
    89887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89887, CurrentID=0, Status='live', Symbol='ZNF628', Aliases=['ZEC', 'Zfp628'], description='zinc finger protein 628', other_designations='zinc finger protein 628|zinc finger protein Zec', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55476603, end_position_on_the_genomic_accession=55484487, orientation='plus', exon_count=3, OMIM=[610671], no_hdr0=''),
    89890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89890, CurrentID=0, Status='live', Symbol='KBTBD6', Aliases=[], description='kelch repeat and BTB domain containing 6', other_designations='kelch repeat and BTB domain-containing protein 6|kelch repeat and BTB (POZ) domain containing 6', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=41127569, end_position_on_the_genomic_accession=41132802, orientation='minus', exon_count=1, OMIM=[617738], no_hdr0=''),
    89891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89891, CurrentID=0, Status='live', Symbol='DYNC2I2', Aliases=['CFAP133', 'DIC5', 'FAP133', 'SRTD11', 'WDR34', 'bA216B9.3'], description='dynein 2 intermediate chain 2', other_designations='cytoplasmic dynein 2 intermediate chain 2|WD repeat domain 34|WD repeat-containing protein 34', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128633653, end_position_on_the_genomic_accession=128656847, orientation='minus', exon_count=9, OMIM=[613363], no_hdr0=''),
    89894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89894, CurrentID=0, Status='live', Symbol='TMEM116', Aliases=[], description='transmembrane protein 116', other_designations='transmembrane protein 116', map_location='12q24.12-q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111894880, end_position_on_the_genomic_accession=112013219, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    89910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89910, CurrentID=0, Status='live', Symbol='UBE3B', Aliases=['BPIDS', 'KOS'], description='ubiquitin protein ligase E3B', other_designations='ubiquitin-protein ligase E3B|HECT-type ubiquitin transferase E3B', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109477410, end_position_on_the_genomic_accession=109543628, orientation='plus', exon_count=31, OMIM=[608047], no_hdr0=''),
    89927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89927, CurrentID=0, Status='live', Symbol='BMERB1', Aliases=['C16orf45', 'MINP'], description='bMERB domain containing 1', other_designations='bMERB domain-containing protein 1|migration inhibitory protein|uncharacterized protein C16orf45', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15434588, end_position_on_the_genomic_accession=15588259, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    89932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89932, CurrentID=0, Status='live', Symbol='PAPLN', Aliases=['PPN'], description='papilin, proteoglycan like sulfated glycoprotein', other_designations='papilin', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73235841, end_position_on_the_genomic_accession=73274623, orientation='plus', exon_count=31, OMIM=[617785], no_hdr0=''),
    89941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89941, CurrentID=0, Status='live', Symbol='RHOT2', Aliases=['ARHT2', 'C16orf39', 'MIRO-2', 'MIRO2', 'RASL'], description='ras homolog family member T2', other_designations='mitochondrial Rho GTPase 2|mitochondrial Rho (MIRO) GTPase 2|ras homolog gene family, member T2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=668083, end_position_on_the_genomic_accession=674174, orientation='plus', exon_count=19, OMIM=[613889], no_hdr0=''),
    89944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89944, CurrentID=0, Status='live', Symbol='GLB1L2', Aliases=['MST114', 'MSTP114'], description='galactosidase beta 1 like 2', other_designations='beta-galactosidase-1-like protein 2', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134331988, end_position_on_the_genomic_accession=134376324, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    89953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89953, CurrentID=0, Status='live', Symbol='KLC4', Aliases=['KNSL8', 'bA387M24.3'], description='kinesin light chain 4', other_designations='kinesin light chain 4|kinesin-like protein 8', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43059631, end_position_on_the_genomic_accession=43075093, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    89958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89958, CurrentID=0, Status='live', Symbol='SAPCD2', Aliases=['C9orf140', 'p42.3'], description='suppressor APC domain containing 2', other_designations='suppressor APC domain-containing protein 2|2010317E24Rik|TS/MDEP|protein C9orf140|tumor specificity and mitosis phase-dependent expression protein', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137062127, end_position_on_the_genomic_accession=137070559, orientation='minus', exon_count=7, OMIM=[612057], no_hdr0=''),
    89970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89970, CurrentID=0, Status='live', Symbol='RSPRY1', Aliases=['SEMDFA'], description='ring finger and SPRY domain containing 1', other_designations='RING finger and SPRY domain-containing protein 1', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57186137, end_position_on_the_genomic_accession=57240473, orientation='plus', exon_count=18, OMIM=[616585], no_hdr0=''),
    89978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=89978, CurrentID=0, Status='live', Symbol='DPH6', Aliases=['ATPBD4'], description='diphthamine biosynthesis 6', other_designations='diphthine--ammonia ligase|ATP binding domain 4|ATP-binding domain-containing protein 4|DPH6 homolog|diphthamide synthase|diphthamide synthetase|protein DPH6 homolog', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=35217356, end_position_on_the_genomic_accession=35546193, orientation='minus', exon_count=12, OMIM=[618391], no_hdr0=''),
    90007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90007, CurrentID=0, Status='live', Symbol='MIDN', Aliases=['Stx'], description='midnolin', other_designations='midnolin|midbrain nucleolar protein|stuxnet homolog', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1248552, end_position_on_the_genomic_accession=1259143, orientation='plus', exon_count=9, OMIM=[606700], no_hdr0=''),
    90019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90019, CurrentID=0, Status='live', Symbol='SYT8', Aliases=[], description='synaptotagmin 8', other_designations='synaptotagmin-8|synaptotagmin VIII|sytVIII', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1827484, end_position_on_the_genomic_accession=1837521, orientation='plus', exon_count=12, OMIM=[607719], no_hdr0=''),
    90025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90025, CurrentID=0, Status='live', Symbol='UBE3D', Aliases=['C6orf157', 'H10BH', 'UBE2CBP', 'YJR141W'], description='ubiquitin protein ligase E3D', other_designations='E3 ubiquitin-protein ligase E3D|HECT-type E3 ubiquitin transferase E3D|UBCH10 binding protein with a hect-like domain|ubcH10-binding protein with a HECT-like domain|ubiquitin-conjugating enzyme E2C-binding protein', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=82880834, end_position_on_the_genomic_accession=83065841, orientation='minus', exon_count=22, OMIM=[612495], no_hdr0=''),
    90050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90050, CurrentID=0, Status='live', Symbol='FAM181A', Aliases=['C14orf152'], description='family with sequence similarity 181 member A', other_designations='protein FAM181A', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93918894, end_position_on_the_genomic_accession=93929608, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    90060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90060, CurrentID=0, Status='live', Symbol='CCDC120', Aliases=['JM11'], description='coiled-coil domain containing 120', other_designations='coiled-coil domain-containing protein 120', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49053572, end_position_on_the_genomic_accession=49069858, orientation='plus', exon_count=11, OMIM=[300947], no_hdr0=''),
    90070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90070, CurrentID=0, Status='live', Symbol='LACRT', Aliases=[], description='lacritin', other_designations='extracellular glycoprotein lacritin', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54630811, end_position_on_the_genomic_accession=54634895, orientation='minus', exon_count=5, OMIM=[607360], no_hdr0=''),
    90075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90075, CurrentID=0, Status='live', Symbol='ZNF30', Aliases=['KOX28'], description='zinc finger protein 30', other_designations='zinc finger protein 30|zinc finger protein 30 (KOX 28)|zinc finger protein KOX28', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34923795, end_position_on_the_genomic_accession=34945172, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    90102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90102, CurrentID=0, Status='live', Symbol='PHLDB2', Aliases=['LL5b', 'LL5beta'], description='pleckstrin homology like domain family B member 2', other_designations='pleckstrin homology-like domain family B member 2|LL5 beta|protein LL5-beta', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111732496, end_position_on_the_genomic_accession=111976517, orientation='plus', exon_count=21, OMIM=[610298], no_hdr0=''),
    90113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90113, CurrentID=0, Status='live', Symbol='VWA5B2', Aliases=[], description='von Willebrand factor A domain containing 5B2', other_designations='von Willebrand factor A domain-containing protein 5B2', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184229585, end_position_on_the_genomic_accession=184242329, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    90120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90120, CurrentID=0, Status='live', Symbol='TMEM250', Aliases=['C9orf69'], description='transmembrane protein 250', other_designations='transmembrane protein 250|herpes virus UL25-binding protein|protein C9orf69', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136114581, end_position_on_the_genomic_accession=136118875, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    90121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90121, CurrentID=0, Status='live', Symbol='TSR2', Aliases=['DBA14', 'DT1P1A10', 'WGG1'], description='TSR2 ribosome maturation factor', other_designations='pre-rRNA-processing protein TSR2 homolog|TSR2, 20S rRNA accumulation, homolog|WGG motif containing 1|escortin', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54440404, end_position_on_the_genomic_accession=54448032, orientation='plus', exon_count=5, OMIM=[300945], no_hdr0=''),
    90134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90134, CurrentID=0, Status='live', Symbol='KCNH7', Aliases=['ERG3', 'HERG3', 'Kv11.3'], description='potassium voltage-gated channel subfamily H member 7', other_designations='potassium voltage-gated channel subfamily H member 7|ERG-3|eag-related protein 3|ether-a-go-go-related gene potassium channel 3|ether-a-go-go-related protein 3|potassium channel subunit HERG-3|potassium channel, voltage gated eag related subfamily H, member 7|voltage-gated potassium channel subunit Kv11.3', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=162371407, end_position_on_the_genomic_accession=162838817, orientation='minus', exon_count=17, OMIM=[608169], no_hdr0=''),
    90135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90135, CurrentID=0, Status='live', Symbol='BTBD6', Aliases=['BDPL'], description='BTB domain containing 6', other_designations='BTB/POZ domain-containing protein 6|BTB (POZ) domain containing 6|BTB domain protein BDPL|epididymis secretory sperm binding protein|glucocorticoid receptor AF-1 coactivator-1|lens BTB domain protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105248533, end_position_on_the_genomic_accession=105251093, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    90139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90139, CurrentID=0, Status='live', Symbol='TSPAN18', Aliases=['TSPAN'], description='tetraspanin 18', other_designations='tetraspanin-18|tspan-18', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44726962, end_position_on_the_genomic_accession=44932423, orientation='plus', exon_count=12, OMIM=[619399], no_hdr0=''),
    90141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90141, CurrentID=0, Status='live', Symbol='EFCAB11', Aliases=['C14orf143'], description='EF-hand calcium binding domain 11', other_designations='EF-hand calcium-binding domain-containing protein 11|EF-hand domain-containing protein C14orf143', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=89794669, end_position_on_the_genomic_accession=89954777, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    90161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90161, CurrentID=0, Status='live', Symbol='HS6ST2', Aliases=['MRXSPM'], description='heparan sulfate 6-O-sulfotransferase 2', other_designations='heparan-sulfate 6-O-sulfotransferase 2|HS6ST-2', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=132626012, end_position_on_the_genomic_accession=132961370, orientation='minus', exon_count=11, OMIM=[300545], no_hdr0=''),
    90167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90167, CurrentID=0, Status='live', Symbol='FRMD7', Aliases=['NYS', 'NYS1', 'XIPAN'], description='FERM domain containing 7', other_designations='FERM domain-containing protein 7', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=132074926, end_position_on_the_genomic_accession=132128020, orientation='minus', exon_count=13, OMIM=[300628], no_hdr0=''),
    90187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90187, CurrentID=0, Status='live', Symbol='EMILIN3', Aliases=['C20orf130', 'EMILIN5', 'dJ620E11.4'], description='elastin microfibril interfacer 3', other_designations='EMILIN-3|EMILIN-5|elastin microfibril interface-located protein 3|elastin microfibril interface-located protein 5|elastin microfibril interfacer 5', map_location='20q12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=41359962, end_position_on_the_genomic_accession=41366818, orientation='minus', exon_count=4, OMIM=[608929], no_hdr0=''),
    90196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90196, CurrentID=0, Status='live', Symbol='SYS1', Aliases=['C20orf169', 'dJ453C12.4', 'dJ453C12.4.1'], description='SYS1 golgi trafficking protein', other_designations='protein SYS1 homolog|SYS1 Golgi-localized integral membrane protein homolog', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45361949, end_position_on_the_genomic_accession=45376798, orientation='plus', exon_count=6, OMIM=[612979], no_hdr0=''),
    90199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90199, CurrentID=0, Status='live', Symbol='WFDC8', Aliases=['C20orf170', 'HEL-S-292', 'WAP8', 'dJ461P17.1'], description='WAP four-disulfide core domain 8', other_designations='WAP four-disulfide core domain protein 8|WAP motif protein 1|epididymis secretory protein Li 292|epididymis secretory sperm binding protein|protease inhibitor WAP8|putative protease inhibitor WAP8|testicular secretory protein Li 68', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45551152, end_position_on_the_genomic_accession=45579305, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    90203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90203, CurrentID=0, Status='live', Symbol='SNX21', Aliases=['C20orf161', 'PP3993', 'SNX-L', 'SNXL', 'dJ337O18.4'], description='sorting nexin family member 21', other_designations='sorting nexin-21|sorting nexin L', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45833418, end_position_on_the_genomic_accession=45843276, orientation='plus', exon_count=8, OMIM=[619200], no_hdr0=''),
    90204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90204, CurrentID=0, Status='live', Symbol='ZSWIM1', Aliases=['C20orf162'], description='zinc finger SWIM-type containing 1', other_designations='zinc finger SWIM domain-containing protein 1|zinc finger, SWIM domain containing 1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45880920, end_position_on_the_genomic_accession=45885266, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    90226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90226, CurrentID=0, Status='live', Symbol='UCN2', Aliases=['SRP', 'UCN-II', 'UCNI', 'UR', 'URP'], description='urocortin 2', other_designations='urocortin-2|prepro-urocortin 2|stresscopin-related peptide|ucn II|urocortin II|urocortin-related peptide', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48561718, end_position_on_the_genomic_accession=48563781, orientation='minus', exon_count=2, OMIM=[605902], no_hdr0=''),
    90231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90231, CurrentID=0, Status='live', Symbol='KIAA2013', Aliases=[], description='KIAA2013', other_designations='uncharacterized protein KIAA2013|RP5-1077B9.1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11919591, end_position_on_the_genomic_accession=11926427, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    90233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90233, CurrentID=0, Status='live', Symbol='ZNF551', Aliases=[], description='zinc finger protein 551', other_designations='zinc finger protein 551|KOX 23 protein (56 AA)|zinc finger protein KOX23', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57681977, end_position_on_the_genomic_accession=57690648, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    90249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90249, CurrentID=0, Status='live', Symbol='UNC5A', Aliases=['UNC5H1'], description='unc-5 netrin receptor A', other_designations='netrin receptor UNC5A|netrin receptor Unc5h1|protein unc-5 homolog 1|protein unc-5 homolog A|unc-5 homolog 1|unc-5 homolog A|unc5 (C.elegans homolog) a', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176810559, end_position_on_the_genomic_accession=176880898, orientation='plus', exon_count=17, OMIM=[607869], no_hdr0=''),
    90268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90268, CurrentID=0, Status='live', Symbol='OTULIN', Aliases=['AIPDS', 'FAM105B', 'GUM'], description='OTU deubiquitinase with linear linkage specificity', other_designations='ubiquitin thioesterase otulin|OTU domain-containing deubiquitinase with linear linkage specificity|deubiquitinating enzyme otulin|family with sequence similarity 105, member B|ubiquitin thioesterase Gumby', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=14660794, end_position_on_the_genomic_accession=14716552, orientation='plus', exon_count=9, OMIM=[615712], no_hdr0=''),
    90273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90273, CurrentID=0, Status='live', Symbol='CEACAM21', Aliases=['CEACAM3', 'R29124_1'], description='CEA cell adhesion molecule 21', other_designations='carcinoembryonic antigen-related cell adhesion molecule 21|carcinoembryonic antigen related cell adhesion molecule 21', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41549236, end_position_on_the_genomic_accession=41586844, orientation='plus', exon_count=22, OMIM=[618191], no_hdr0=''),
    90288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90288, CurrentID=0, Status='live', Symbol='EFCAB12', Aliases=['C3orf25'], description='EF-hand calcium binding domain 12', other_designations='EF-hand calcium-binding domain-containing protein 12|EF-hand domain-containing protein C3orf25', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129401321, end_position_on_the_genomic_accession=129428636, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    90293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90293, CurrentID=0, Status='live', Symbol='KLHL13', Aliases=['BKLHD2'], description='kelch like family member 13', other_designations='kelch-like protein 13|BTB and kelch domain containing 2|kelch-like 13', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=117897813, end_position_on_the_genomic_accession=118117340, orientation='minus', exon_count=14, OMIM=[300655], no_hdr0=''),
    90313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90313, CurrentID=0, Status='live', Symbol='TP53I13', Aliases=['DSCP1'], description='tumor protein p53 inducible protein 13', other_designations='tumor protein p53-inducible protein 13|damage-stimulated cytoplasmic protein 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29567180, end_position_on_the_genomic_accession=29573157, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    90316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90316, CurrentID=0, Status='live', Symbol='TGIF2LX', Aliases=['TGIFLX'], description='TGFB induced factor homeobox 2 like X-linked', other_designations='homeobox protein TGIF2LX|TGF-beta-induced transcription factor 2-like protein|TGFB-induced factor 2-like protein, X-linked|TGFB-induced factor 2-like, X-linked|TGIF-like on the X', map_location='Xq21.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=89921908, end_position_on_the_genomic_accession=89922883, orientation='plus', exon_count=2, OMIM=[300411], no_hdr0=''),
    90317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90317, CurrentID=0, Status='live', Symbol='ZNF616', Aliases=[], description='zinc finger protein 616', other_designations='zinc finger protein 616', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52113091, end_position_on_the_genomic_accession=52139938, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    90321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90321, CurrentID=0, Status='live', Symbol='ZNF766', Aliases=[], description='zinc finger protein 766', other_designations='zinc finger protein 766', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52269251, end_position_on_the_genomic_accession=52296046, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    90324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90324, CurrentID=0, Status='live', Symbol='CCDC97', Aliases=[], description='coiled-coil domain containing 97', other_designations='coiled-coil domain-containing protein 97', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41309855, end_position_on_the_genomic_accession=41324873, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    90326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90326, CurrentID=0, Status='live', Symbol='THAP3', Aliases=[], description='THAP domain containing 3', other_designations='THAP domain-containing protein 3|THAP domain containing, apoptosis associated protein 3', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6624616, end_position_on_the_genomic_accession=6635595, orientation='plus', exon_count=8, OMIM=[612532], no_hdr0=''),
    90332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90332, CurrentID=0, Status='live', Symbol='EXOC3L2', Aliases=['XTP7'], description='exocyst complex component 3 like 2', other_designations='exocyst complex component 3-like protein 2|HBV X-transactivated gene 7 protein|HBV XAg-transactivated protein 7|protein 7 transactivated by hepatitis B virus X antigen (HBxAg)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45212370, end_position_on_the_genomic_accession=45245407, orientation='minus', exon_count=12, OMIM=[616927], no_hdr0=''),
    90333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90333, CurrentID=0, Status='live', Symbol='ZNF468', Aliases=[], description='zinc finger protein 468', other_designations='zinc finger protein 468|zinc finger protein ZNF468', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52838010, end_position_on_the_genomic_accession=52857619, orientation='minus', exon_count=6, OMIM=[616841], no_hdr0=''),
    90338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90338, CurrentID=0, Status='live', Symbol='ZNF160', Aliases=['F11', 'HKr18', 'HZF5', 'KR18'], description='zinc finger protein 160', other_designations='zinc finger protein 160|KRAB zinc finger protein KR18|zinc finger protein 5|zinc finger protein HZF5|zinc finger protein Kr18', map_location='19q13.41-q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53066614, end_position_on_the_genomic_accession=53103422, orientation='minus', exon_count=13, OMIM=[600398], no_hdr0=''),
    90342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90342, CurrentID=0, Status='live', Symbol='FER1L5', Aliases=[], description='fer-1 like family member 5', other_designations='fer-1-like protein 5|fer-1-like 5', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96642719, end_position_on_the_genomic_accession=96704887, orientation='plus', exon_count=56, OMIM=[], no_hdr0=''),
    90353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90353, CurrentID=0, Status='live', Symbol='CTU1', Aliases=['ATPBD3', 'NCS6'], description='cytosolic thiouridylase subunit 1', other_designations='cytoplasmic tRNA 2-thiolation protein 1|ATP binding domain 3|ATP-binding domain-containing protein 3|cancer-associated gene protein|cancer-associated protein|cytoplasmic tRNA adenylyltransferase 1|cytosolic thiouridylase subunit 1 homolog', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51097606, end_position_on_the_genomic_accession=51108409, orientation='minus', exon_count=3, OMIM=[612694], no_hdr0=''),
    90355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90355, CurrentID=0, Status='live', Symbol='MACIR', Aliases=['C5orf30'], description='macrophage immunometabolism regulator', other_designations='macrophage immunometabolism regulator|UNC119-binding protein C5orf30|UPF0684 protein C5orf30', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=103258374, end_position_on_the_genomic_accession=103278660, orientation='plus', exon_count=9, OMIM=[616608], no_hdr0=''),
    90362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90362, CurrentID=0, Status='live', Symbol='FAM110B', Aliases=['C8orf72'], description='family with sequence similarity 110 member B', other_designations='protein FAM110B', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=57994523, end_position_on_the_genomic_accession=58148784, orientation='plus', exon_count=7, OMIM=[611394], no_hdr0=''),
    90378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90378, CurrentID=0, Status='live', Symbol='SAMD1', Aliases=[], description='sterile alpha motif domain containing 1', other_designations='atherin|SAM domain containing 1|sterile alpha motif domain-containing protein 1', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14087851, end_position_on_the_genomic_accession=14090751, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    90379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90379, CurrentID=0, Status='live', Symbol='DCAF15', Aliases=['C19orf72'], description='DDB1 and CUL4 associated factor 15', other_designations='DDB1- and CUL4-associated factor 15', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13952509, end_position_on_the_genomic_accession=13961449, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    90381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90381, CurrentID=0, Status='live', Symbol='TICRR', Aliases=['C15orf42', 'SLD3', 'Treslin'], description='TOPBP1 interacting checkpoint and replication regulator', other_designations='treslin|topBP1-interacting checkpoint and replication regulator|topBP1-interacting replication-stimulating protein', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89575469, end_position_on_the_genomic_accession=89628023, orientation='plus', exon_count=22, OMIM=[613298], no_hdr0=''),
    90390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90390, CurrentID=0, Status='live', Symbol='MED30', Aliases=['MED30S', 'THRAP6', 'TRAP25'], description='mediator complex subunit 30', other_designations='mediator of RNA polymerase II transcription subunit 30|TRAP/Mediator complex component TRAP25|putative mediator of RNA polymerase II transcription subunit 30|thyroid hormone receptor-associated protein 6|thyroid hormone receptor-associated protein complex 25 kDa component', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=117520713, end_position_on_the_genomic_accession=117540262, orientation='plus', exon_count=5, OMIM=[610237], no_hdr0=''),
    90407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90407, CurrentID=0, Status='live', Symbol='TMEM41A', Aliases=['2900010K02Rik'], description='transmembrane protein 41A', other_designations='transmembrane protein 41A', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185482671, end_position_on_the_genomic_accession=185499057, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    90410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90410, CurrentID=0, Status='live', Symbol='IFT20', Aliases=[], description='intraflagellar transport 20', other_designations='intraflagellar transport protein 20 homolog|intraflagellar transport 20 homolog|intraflagellar transport protein IFT20', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28328326, end_position_on_the_genomic_accession=28335472, orientation='minus', exon_count=7, OMIM=[614394], no_hdr0=''),
    90411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90411, CurrentID=0, Status='live', Symbol='MCFD2', Aliases=['F5F8D', 'F5F8D2', 'LMAN1IP', 'SDNSF'], description='multiple coagulation factor deficiency 2, ER cargo receptor complex subunit', other_designations='multiple coagulation factor deficiency protein 2|neural stem cell-derived neuronal survival protein', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46901870, end_position_on_the_genomic_accession=46941855, orientation='minus', exon_count=7, OMIM=[607788], no_hdr0=''),
    90416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90416, CurrentID=0, Status='live', Symbol='CCDC32', Aliases=['C15orf57', 'CFNDS'], description='coiled-coil domain containing 32', other_designations='coiled-coil domain-containing protein 32|uncharacterized protein C15orf57', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40520993, end_position_on_the_genomic_accession=40565042, orientation='minus', exon_count=8, OMIM=[618941], no_hdr0=''),
    90417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90417, CurrentID=0, Status='live', Symbol='KNSTRN', Aliases=['C15orf23', 'HSD11', 'ROCHIS', 'SKAP', 'TRAF4AF1'], description='kinetochore localized astrin (SPAG5) binding protein', other_designations='small kinetochore-associated protein|TRAF4 associated factor 1|kinastrin|kinetochore-localized astrin-binding protein|putative TRAF4-associated factor 1|small kinetochore associated protein|small kinetochore-associated protein, kinetochore-localized astrin-binding protein, TRAF4 associated factor 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40382721, end_position_on_the_genomic_accession=40394288, orientation='plus', exon_count=9, OMIM=[614718], no_hdr0=''),
    90423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90423, CurrentID=0, Status='live', Symbol='ATP6V1E2', Aliases=['ATP6E1', 'ATP6EL2', 'ATP6V1EL2', 'VMA4'], description='ATPase H+ transporting V1 subunit E2', other_designations='V-type proton ATPase subunit E 2|ATPase, H+ transporting, lysosomal 31kDa, V1 subunit E2|V-ATPase subunit E 2|testis secretory sperm-binding protein Li 235P|vacuolar proton pump subunit E 2|vacuolar-type proton-translocating ATPase subunit E1', map_location='2p16-p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46511847, end_position_on_the_genomic_accession=46542577, orientation='minus', exon_count=8, OMIM=[617385], no_hdr0=''),
    90427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90427, CurrentID=0, Status='live', Symbol='BMF', Aliases=[], description='Bcl2 modifying factor', other_designations='bcl-2-modifying factor', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40087890, end_position_on_the_genomic_accession=40108879, orientation='minus', exon_count=6, OMIM=[606266], no_hdr0=''),
    90441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90441, CurrentID=0, Status='live', Symbol='ZNF622', Aliases=['ZPR9'], description='zinc finger protein 622', other_designations='zinc finger protein 622|zinc finger-like protein 9', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=16451519, end_position_on_the_genomic_accession=16465800, orientation='minus', exon_count=6, OMIM=[608694], no_hdr0=''),
    90459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90459, CurrentID=0, Status='live', Symbol='ERI1', Aliases=["3'HEXO", 'HEXO', 'THEX1'], description='exoribonuclease 1', other_designations="3'-5' exoribonuclease 1|3' exoribonuclease|3'-5' exonuclease ERI1|enhanced RNAi three prime mRNA exonuclease homolog 1|histone mRNA 3' end-specific exonuclease|histone mRNA 3'-end-specific exoribonuclease|histone mRNA 3'-exonuclease 1|three prime histone mRNA exonuclease 1|three prime mRNA exonuclease 1", map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=8892225, end_position_on_the_genomic_accession=9100262, orientation='plus', exon_count=19, OMIM=[608739], no_hdr0=''),
    90480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90480, CurrentID=0, Status='live', Symbol='GADD45GIP1', Aliases=['CKBBP2', 'CKbetaBP2', 'CRIF1', 'MRP-L59', 'PLINP', 'PLINP-1', 'PRG6', 'Plinp1'], description='GADD45G interacting protein 1', other_designations='growth arrest and DNA damage-inducible proteins-interacting protein 1|39S ribosomal protein L59, mitochondrial|CKII beta binding protein 2|CKII beta-associating protein|CR6 interacting factor 1|growth arrest and DNA-damage-inducible, gamma interacting protein 1|growth arrest- and DNA damage-inducible GADD45G-interacting protein|mitochondrial large ribosomal subunit protein CRIF1|mitochondrial large ribosomal subunit protein mL64|p53-responsive gene 6 protein|papillomavirus L2 interacting nuclear protein 1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12953119, end_position_on_the_genomic_accession=12957223, orientation='minus', exon_count=2, OMIM=[605162], no_hdr0=''),
    90485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90485, CurrentID=0, Status='live', Symbol='ZNF835', Aliases=['BC37295_3'], description='zinc finger protein 835', other_designations='zinc finger protein 835', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56661980, end_position_on_the_genomic_accession=56671783, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    90488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90488, CurrentID=0, Status='live', Symbol='TMEM263', Aliases=['C12orf23'], description='transmembrane protein 263', other_designations='transmembrane protein 263|UPF0444 transmembrane protein C12orf23', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106955907, end_position_on_the_genomic_accession=106974035, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    90506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90506, CurrentID=0, Status='live', Symbol='LRRC46', Aliases=[], description='leucine rich repeat containing 46', other_designations='leucine-rich repeat-containing protein 46', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47831670, end_position_on_the_genomic_accession=47837719, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    90507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90507, CurrentID=0, Status='live', Symbol='SCRN2', Aliases=['Ses2'], description='secernin 2', other_designations='secernin-2|epididymis secretory sperm binding protein', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47837691, end_position_on_the_genomic_accession=47841292, orientation='minus', exon_count=8, OMIM=[614966], no_hdr0=''),
    90522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90522, CurrentID=0, Status='live', Symbol='YIF1B', Aliases=['FinGER8', 'KABAMAS'], description='Yip1 interacting factor homolog B, membrane trafficking protein', other_designations='protein YIF1B|YIP1-interacting factor homolog B', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38303558, end_position_on_the_genomic_accession=38315976, orientation='minus', exon_count=10, OMIM=[619109], no_hdr0=''),
    90523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90523, CurrentID=0, Status='live', Symbol='MLIP', Aliases=['C6orf142', 'CIP'], description='muscular LMNA interacting protein', other_designations='muscular LMNA-interacting protein|cardiac ISL1-interacting protein|muscle-enriched A-type lamin interacting protein|muscular-enriched A-type laminin-interacting protein', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=54018916, end_position_on_the_genomic_accession=54266325, orientation='plus', exon_count=19, OMIM=[614106], no_hdr0=''),
    90525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90525, CurrentID=0, Status='live', Symbol='SHF', Aliases=[], description='Src homology 2 domain containing F', other_designations='SH2 domain-containing adapter protein F|CTD-2651B20.7', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45167214, end_position_on_the_genomic_accession=45201116, orientation='minus', exon_count=13, OMIM=[617313], no_hdr0=''),
    90527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90527, CurrentID=0, Status='live', Symbol='DUOXA1', Aliases=['NIP', 'NUMBIP', 'mol'], description='dual oxidase maturation factor 1', other_designations='dual oxidase maturation factor 1|dual oxidase activator 1|dual oxidase maturation factor 1 alpha|dual oxidase maturation factor 1 beta|dual oxidase maturation factor 1 delta|dual oxidase maturation factor 1 gamma|homolog of Drosophila Numb-interacting protein', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45117366, end_position_on_the_genomic_accession=45129938, orientation='minus', exon_count=12, OMIM=[612771], no_hdr0=''),
    90529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90529, CurrentID=0, Status='live', Symbol='STPG1', Aliases=['C1orf201', 'MAPO2'], description='sperm tail PG-rich repeat containing 1', other_designations='O(6)-methylguanine-induced apoptosis 2|O6-methylguanine-induced apoptosis 2|UPF0490 protein C1orf201|sperm-tail PG-rich repeat-containing protein 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24356999, end_position_on_the_genomic_accession=24415533, orientation='minus', exon_count=12, OMIM=[615826], no_hdr0=''),
    90550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90550, CurrentID=0, Status='live', Symbol='MCU', Aliases=['C10orf42', 'CCDC109A', 'HsMCU'], description='mitochondrial calcium uniporter', other_designations='calcium uniporter protein, mitochondrial|coiled-coil domain-containing protein 109A', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72692143, end_position_on_the_genomic_accession=72887694, orientation='plus', exon_count=12, OMIM=[614197], no_hdr0=''),
    90557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90557, CurrentID=0, Status='live', Symbol='CCDC74A', Aliases=[], description='coiled-coil domain containing 74A', other_designations='coiled-coil domain-containing protein 74A|epididymis secretory sperm binding protein', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131522621, end_position_on_the_genomic_accession=131533666, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    90576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90576, CurrentID=0, Status='live', Symbol='ZNF799', Aliases=['HIT-40', 'ZNF842'], description='zinc finger protein 799', other_designations='zinc finger protein 799|zinc finger protein 14|zinc finger protein 842|zinc finger protein HIT-40', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12390016, end_position_on_the_genomic_accession=12401271, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    90580 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90580, CurrentID=0, Status='live', Symbol='TIMM29', Aliases=['C19orf52', 'TIM29'], description='translocase of inner mitochondrial membrane 29', other_designations='mitochondrial import inner membrane translocase subunit Tim29|uncharacterized protein C19orf52', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10928811, end_position_on_the_genomic_accession=10930254, orientation='plus', exon_count=2, OMIM=[617380], no_hdr0=''),
    90589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90589, CurrentID=0, Status='live', Symbol='ZNF625', Aliases=[], description='zinc finger protein 625', other_designations='zinc finger protein 625', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12144890, end_position_on_the_genomic_accession=12156734, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    90592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90592, CurrentID=0, Status='live', Symbol='ZNF700', Aliases=[], description='zinc finger protein 700', other_designations='zinc finger protein 700', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11925107, end_position_on_the_genomic_accession=11950763, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    90594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90594, CurrentID=0, Status='live', Symbol='ZNF439', Aliases=[], description='zinc finger protein 439', other_designations='zinc finger protein 439', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11848726, end_position_on_the_genomic_accession=11869486, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    90624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90624, CurrentID=0, Status='live', Symbol='LYRM7', Aliases=['C5orf31', 'MC3DN8', 'MZM1L'], description='LYR motif containing 7', other_designations='complex III assembly factor LYRM7|LYR motif-containing protein 7|Lyrm7 homolog', map_location='5q23.3-q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131170944, end_position_on_the_genomic_accession=131205428, orientation='plus', exon_count=5, OMIM=[615831], no_hdr0=''),
    90625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90625, CurrentID=0, Status='live', Symbol='ERVH48-1', Aliases=['C21orf105', 'NDUFV3-AS1', 'SUPYN'], description='endogenous retrovirus group 48 member 1', other_designations='suppressyn|NDUFV3 antisense RNA 1 (non-protein coding)|endogenous retrovirus group Fb member 1|suppresyn', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=42916803, end_position_on_the_genomic_accession=42925630, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    90627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90627, CurrentID=0, Status='live', Symbol='STARD13', Aliases=['ARHGAP37', 'DLC2', 'GT650', 'LINC00464'], description='StAR related lipid transfer domain containing 13', other_designations='stAR-related lipid transfer protein 13|Rho GTPase activating protein on chromosome 13q12|StAR-related lipid transfer (START) domain containing 13|deleted in liver cancer 2 protein|long intergenic non-protein coding RNA 464', map_location='13q13.1-q13.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=33103137, end_position_on_the_genomic_accession=33676829, orientation='minus', exon_count=23, OMIM=[609866], no_hdr0=''),
    90634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90634, CurrentID=0, Status='live', Symbol='N4BP2L1', Aliases=['CG018'], description='NEDD4 binding protein 2 like 1', other_designations='NEDD4-binding protein 2-like 1|hypothetical gene CG018', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32400723, end_position_on_the_genomic_accession=32429616, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    90637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90637, CurrentID=0, Status='live', Symbol='ZFAND2A', Aliases=['AIRAP'], description='zinc finger AN1-type containing 2A', other_designations='AN1-type zinc finger protein 2A|arsenite inducible RNA associated protein|zinc finger, AN1-type domain 2A', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1148850, end_position_on_the_genomic_accession=1160196, orientation='minus', exon_count=6, OMIM=[610699], no_hdr0=''),
    90639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90639, CurrentID=0, Status='live', Symbol='COX19', Aliases=[], description='cytochrome c oxidase assembly factor COX19', other_designations='cytochrome c oxidase assembly protein COX19|COX19 cytochrome c oxidase assembly homolog|COX19, cytochrome c oxidase assembly factor|cytochrome c oxidase assembly homolog 19|hCOX19', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=964852, end_position_on_the_genomic_accession=975549, orientation='minus', exon_count=3, OMIM=[610429], no_hdr0=''),
    90649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90649, CurrentID=0, Status='live', Symbol='ZNF486', Aliases=['KRBO2'], description='zinc finger protein 486', other_designations='zinc finger protein 486|KRAB box only protein 2|KRAB domain only 2|KRAB domain only protein 2', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20167214, end_position_on_the_genomic_accession=20200488, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    90655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90655, CurrentID=0, Status='live', Symbol='TGIF2LY', Aliases=['TGIFLY'], description='TGFB induced factor homeobox 2 like Y-linked', other_designations='homeobox protein TGIF2LY|TGF-beta-induced transcription factor 2-like protein|TGFB-induced factor 2-like protein, Y-linked|TGFB-induced factor 2-like, Y-linked|TGIF-like on the Y', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=3579067, end_position_on_the_genomic_accession=3580041, orientation='plus', exon_count=2, OMIM=[400025], no_hdr0=''),
    90665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90665, CurrentID=0, Status='live', Symbol='TBL1Y', Aliases=['DFNY2', 'TBL1'], description='transducin beta like 1 Y-linked', other_designations='F-box-like/WD repeat-containing protein TBL1Y|transducin beta-like 1|transducin beta-like protein 1Y|transducin-beta-like protein 1, Y-linked', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=6908594, end_position_on_the_genomic_accession=7107154, orientation='plus', exon_count=22, OMIM=[400033], no_hdr0=''),
    90668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90668, CurrentID=0, Status='live', Symbol='CARMIL3', Aliases=['C14orf121', 'LRRC16B', 'crml-1'], description='capping protein regulator and myosin 1 linker 3', other_designations='capping protein, Arp2/3 and myosin-I linker protein 3|capping protein regulator and myosin 1 linker protein 3|leucine rich repeat containing 16B|leucine-rich repeat-containing protein 16B', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24052009, end_position_on_the_genomic_accession=24069729, orientation='plus', exon_count=40, OMIM=[614716], no_hdr0=''),
    90673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90673, CurrentID=0, Status='live', Symbol='PPP1R3E', Aliases=[], description='protein phosphatase 1 regulatory subunit 3E', other_designations='protein phosphatase 1 regulatory subunit 3E|protein phosphatase 1, regulatory (inhibitor) subunit 3E', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23295652, end_position_on_the_genomic_accession=23302859, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    90678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90678, CurrentID=0, Status='live', Symbol='LRSAM1', Aliases=['CMT2P', 'RIFLE', 'TAL'], description='leucine rich repeat and sterile alpha motif containing 1', other_designations='E3 ubiquitin-protein ligase LRSAM1|RING finger leucine repeat rich|RING-type E3 ubiquitin transferase LRSAM1|Tsg101-associated ligase', map_location='9q33.3-q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127451486, end_position_on_the_genomic_accession=127503501, orientation='plus', exon_count=27, OMIM=[610933], no_hdr0=''),
    90693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90693, CurrentID=0, Status='live', Symbol='CCDC126', Aliases=[], description='coiled-coil domain containing 126', other_designations='coiled-coil domain-containing protein 126', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23597382, end_position_on_the_genomic_accession=23644708, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    90701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90701, CurrentID=0, Status='live', Symbol='SEC11C', Aliases=['SEC11L3', 'SPC21', 'SPCS4C'], description='SEC11 homolog C, signal peptidase complex subunit', other_designations='signal peptidase complex catalytic subunit SEC11C|SEC11-like 3|SEC11-like protein 3|SPase 21 kDa subunit|microsomal signal peptidase 21 kDa subunit|signal peptidase complex 21', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59139884, end_position_on_the_genomic_accession=59158837, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    90736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90736, CurrentID=0, Status='live', Symbol='FAM104B', Aliases=['CXorf44'], description='family with sequence similarity 104 member B', other_designations='protein FAM104B', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55143102, end_position_on_the_genomic_accession=55161185, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    90737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90737, CurrentID=0, Status='live', Symbol='PAGE5', Aliases=['CT16', 'CT16.1', 'CT16.2', 'GAGEE1', 'PAGE-5'], description='PAGE family member 5', other_designations='P antigen family member 5|P antigen family, member 5 (prostate associated)|cancer/testis antigen 16.1|cancer/testis antigen family 16, member 1|cancer/testis antigen family 16, member 2|g antigen family E member 1|prostate-associated gene 5 protein', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55220346, end_position_on_the_genomic_accession=55224108, orientation='plus', exon_count=5, OMIM=[301009], no_hdr0=''),
    90780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90780, CurrentID=0, Status='live', Symbol='PYGO2', Aliases=['1190004M21Rik'], description='pygopus family PHD finger 2', other_designations='pygopus homolog 2|pygopus 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154957026, end_position_on_the_genomic_accession=154961782, orientation='minus', exon_count=3, OMIM=[606903], no_hdr0=''),
    90799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90799, CurrentID=0, Status='live', Symbol='CEP95', Aliases=['CCDC45'], description='centrosomal protein 95', other_designations='centrosomal protein of 95 kDa|centrosomal protein 95kDa|coiled-coil domain containing 45|coiled-coil domain-containing protein 45', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64506760, end_position_on_the_genomic_accession=64537951, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    90806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90806, CurrentID=0, Status='live', Symbol='ANGEL2', Aliases=['Ccr4d', 'KIAA0759L'], description='angel homolog 2', other_designations='protein angel homolog 2', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212992182, end_position_on_the_genomic_accession=213015872, orientation='minus', exon_count=11, OMIM=[619001], no_hdr0=''),
    90809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90809, CurrentID=0, Status='live', Symbol='PIP4P1', Aliases=['C14orf9', 'TMEM55B'], description='phosphatidylinositol-4,5-bisphosphate 4-phosphatase 1', other_designations='type 1 phosphatidylinositol 4,5-bisphosphate 4-phosphatase|ptdIns-4,5-P(2) 4-phosphatase type I|ptdIns-4,5-P2 4-Ptase I|transmembrane protein 55B|type 1 PtdIns-4,5-P2 4-Ptase|type I PtdIns-4,5-P(2) 4-phosphatase|type I phosphatidylinositol-4,5-bisphosphate 4-phosphatase', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20457681, end_position_on_the_genomic_accession=20461612, orientation='minus', exon_count=7, OMIM=[609865], no_hdr0=''),
    90826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90826, CurrentID=0, Status='live', Symbol='PRMT9', Aliases=['PRMT10'], description='protein arginine methyltransferase 9', other_designations='protein arginine N-methyltransferase 9|protein arginine N-methyltransferase 10|protein arginine methyltransferase 10 (putative)|putative protein arginine N-methyltransferase 10|putative protein arginine N-methyltransferase 9', map_location='4q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=147635650, end_position_on_the_genomic_accession=147684163, orientation='minus', exon_count=15, OMIM=[616125], no_hdr0=''),
    90827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90827, CurrentID=0, Status='live', Symbol='ZNF479', Aliases=['HKr19', 'KR19'], description='zinc finger protein 479', other_designations='zinc finger protein 479|KRAB zinc finger protein KR19|zinc finger protein Kr19', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=57117676, end_position_on_the_genomic_accession=57139899, orientation='minus', exon_count=8, OMIM=[617444], no_hdr0=''),
    90835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90835, CurrentID=0, Status='live', Symbol='CCDC189', Aliases=['C16orf93'], description='coiled-coil domain containing 189', other_designations='coiled-coil domain-containing protein 189', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30757226, end_position_on_the_genomic_accession=30762272, orientation='minus', exon_count=9, OMIM=[618318], no_hdr0=''),
    90843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90843, CurrentID=0, Status='live', Symbol='TCEAL8', Aliases=['WEX3'], description='transcription elongation factor A like 8', other_designations='transcription elongation factor A protein-like 8|TCEA-like protein 8|transcription elongation factor A (SII)-like 8|transcription elongation factor S-II protein-like 8', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103252995, end_position_on_the_genomic_accession=103255155, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    90850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90850, CurrentID=0, Status='live', Symbol='ZNF598', Aliases=['HEL2'], description='zinc finger protein 598, E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase ZNF598', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1997654, end_position_on_the_genomic_accession=2009821, orientation='minus', exon_count=12, OMIM=[617508], no_hdr0=''),
    90853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90853, CurrentID=0, Status='live', Symbol='SPOCD1', Aliases=['PPP1R146'], description='SPOC domain containing 1', other_designations='SPOC domain-containing protein 1|protein phosphatase 1, regulatory subunit 146', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31790422, end_position_on_the_genomic_accession=31816022, orientation='minus', exon_count=17, OMIM=[619038], no_hdr0=''),
    90861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90861, CurrentID=0, Status='live', Symbol='JPT2', Aliases=['C16orf34', 'HN1L', 'L11'], description='Jupiter microtubule associated homolog 2', other_designations='jupiter microtubule associated homolog 2|CRAMP_1 like|HN1 like|HN1-like protein|hematological and neurological expressed 1 like|hematological and neurological expressed 1-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1678279, end_position_on_the_genomic_accession=1702086, orientation='plus', exon_count=5, OMIM=[619241], no_hdr0=''),
    90864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90864, CurrentID=0, Status='live', Symbol='SPSB3', Aliases=['C16orf31', 'SSB3'], description='splA/ryanodine receptor domain and SOCS box containing 3', other_designations='SPRY domain-containing SOCS box protein 3|SPRY domain-containing SOCS box protein SSB-3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1776712, end_position_on_the_genomic_accession=1782571, orientation='minus', exon_count=8, OMIM=[611659], no_hdr0=''),
    90865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90865, CurrentID=0, Status='live', Symbol='IL33', Aliases=['C9orf26', 'DVS27', 'IL1F11', 'NF-HEV', 'NFEHEV'], description='interleukin 33', other_designations='interleukin-33|DVS27-related protein|interleukin-1 family member 11|nuclear factor for high endothelial venules|nuclear factor from high endothelial venules', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6214591, end_position_on_the_genomic_accession=6257983, orientation='plus', exon_count=11, OMIM=[608678], no_hdr0=''),
    90871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90871, CurrentID=0, Status='live', Symbol='DMAC1', Aliases=['C9orf123', 'TMEM261'], description='distal membrane arm assembly component 1', other_designations='distal membrane-arm assembly complex protein 1|distal membrane arm assembly complex 1|transmembrane protein 261|transmembrane protein C9orf123', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=7796500, end_position_on_the_genomic_accession=7799778, orientation='minus', exon_count=2, OMIM=[617261], no_hdr0=''),
    90874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90874, CurrentID=0, Status='live', Symbol='ZNF697', Aliases=[], description='zinc finger protein 697', other_designations='zinc finger protein 697', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=119619377, end_position_on_the_genomic_accession=119648266, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    90933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90933, CurrentID=0, Status='live', Symbol='TRIM41', Aliases=['RINCK'], description='tripartite motif containing 41', other_designations='E3 ubiquitin-protein ligase TRIM41|RING finger-interacting protein with C kinase|RING-finger protein that interacts with C kinase|RING-type E3 ubiquitin transferase TRIM41', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181223265, end_position_on_the_genomic_accession=181235808, orientation='plus', exon_count=8, OMIM=[610530], no_hdr0=''),
    90952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90952, CurrentID=0, Status='live', Symbol='ESAM', Aliases=['W117m'], description='endothelial cell adhesion molecule', other_designations='endothelial cell-selective adhesion molecule|2310008D05Rik|HUEL (C4orf1)-interacting protein|LP4791 protein', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124753126, end_position_on_the_genomic_accession=124762290, orientation='minus', exon_count=7, OMIM=[614281], no_hdr0=''),
    90956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90956, CurrentID=0, Status='live', Symbol='ADCK2', Aliases=['AARF'], description='aarF domain containing kinase 2', other_designations='uncharacterized aarF domain-containing protein kinase 2|putative ubiquinone biosynthesis protein AarF', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140672895, end_position_on_the_genomic_accession=140695114, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    90957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90957, CurrentID=0, Status='live', Symbol='DHX57', Aliases=['DDX57'], description='DExH-box helicase 57', other_designations='putative ATP-dependent RNA helicase DHX57|DEAH (Asp-Glu-Ala-Asp/His) box polypeptide 57|DEAH box protein 57|DEAH-box RNA/DNA helicase AAM73547|DEAH-box helicase 57', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38797729, end_position_on_the_genomic_accession=38875934, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    90987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90987, CurrentID=0, Status='live', Symbol='ZNF251', Aliases=[], description='zinc finger protein 251', other_designations='zinc finger protein 251', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144720909, end_position_on_the_genomic_accession=144755603, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    90990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90990, CurrentID=0, Status='live', Symbol='KIFC2', Aliases=[], description='kinesin family member C2', other_designations='kinesin-like protein KIFC2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144466246, end_position_on_the_genomic_accession=144474202, orientation='plus', exon_count=18, OMIM=[615216], no_hdr0=''),
    90993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=90993, CurrentID=0, Status='live', Symbol='CREB3L1', Aliases=['OASIS', 'OI16'], description='cAMP responsive element binding protein 3 like 1', other_designations='cyclic AMP-responsive element-binding protein 3-like protein 1|BBF-2 homolog|cAMP-responsive element-binding protein 3-like protein 1|old astrocyte specifically-induced substance', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46277661, end_position_on_the_genomic_accession=46321409, orientation='plus', exon_count=13, OMIM=[616215], no_hdr0=''),
    91010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91010, CurrentID=0, Status='live', Symbol='FMNL3', Aliases=['FHOD3', 'FRL2', 'WBP-3', 'WBP3'], description='formin like 3', other_designations='formin-like protein 3|WW domain binding protein 3|formin homology 2 domain-containing protein 3', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49636499, end_position_on_the_genomic_accession=49707405, orientation='minus', exon_count=31, OMIM=[616288], no_hdr0=''),
    91012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91012, CurrentID=0, Status='live', Symbol='CERS5', Aliases=['LASS5', 'Trh4'], description='ceramide synthase 5', other_designations='ceramide synthase 5|LAG1 homolog, ceramide synthase 5|LAG1 longevity assurance homolog 5|TRAM homolog 4|sphingosine N-acyltransferase CERS5', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50129289, end_position_on_the_genomic_accession=50167371, orientation='minus', exon_count=14, OMIM=[615335], no_hdr0=''),
    91039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91039, CurrentID=0, Status='live', Symbol='DPP9', Aliases=['DP9', 'DPLP9', 'DPP IX', 'DPRP-2', 'DPRP2'], description='dipeptidyl peptidase 9', other_designations='dipeptidyl peptidase 9|dipeptidyl peptidase IV-related protein-2|dipeptidyl peptidase IX|dipeptidyl peptidase-like protein 9', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4675226, end_position_on_the_genomic_accession=4723842, orientation='minus', exon_count=32, OMIM=[608258], no_hdr0=''),
    91050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91050, CurrentID=0, Status='live', Symbol='CCDC149', Aliases=[], description='coiled-coil domain containing 149', other_designations='coiled-coil domain-containing protein 149', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=24803514, end_position_on_the_genomic_accession=24980204, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    91056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91056, CurrentID=0, Status='live', Symbol='AP5B1', Aliases=['AP-5', 'PP1030'], description='adaptor related protein complex 5 subunit beta 1', other_designations='AP-5 complex subunit beta-1|AP-5 complex subunit beta|adaptor related protein complex 5 beta 1 subunit|adaptor-related protein complex 5 beta subunit|beta5', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65773898, end_position_on_the_genomic_accession=65780976, orientation='minus', exon_count=2, OMIM=[614367], no_hdr0=''),
    91057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91057, CurrentID=0, Status='live', Symbol='CCDC34', Aliases=['L15', 'NY-REN-41', 'RAMA3'], description='coiled-coil domain containing 34', other_designations='coiled-coil domain-containing protein 34|NY-REN-41 antigen|renal carcinoma antigen NY-REN-41', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=27338512, end_position_on_the_genomic_accession=27363215, orientation='minus', exon_count=6, OMIM=[612324], no_hdr0=''),
    91074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91074, CurrentID=0, Status='live', Symbol='ANKRD30A', Aliases=['NY-BR-1'], description='ankyrin repeat domain 30A', other_designations='ankyrin repeat domain-containing protein 30A|serologically defined breast cancer antigen NY-BR-1', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=37125598, end_position_on_the_genomic_accession=37309298, orientation='plus', exon_count=59, OMIM=[610856], no_hdr0=''),
    91107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91107, CurrentID=0, Status='live', Symbol='TRIM47', Aliases=['GOA', 'RNF100'], description='tripartite motif containing 47', other_designations='E3 ubiquitin-protein ligase TRIM47|RING finger protein 100|gene overexpressed in astrocytoma protein|tripartite motif-containing protein 47', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75874164, end_position_on_the_genomic_accession=75878599, orientation='minus', exon_count=7, OMIM=[611041], no_hdr0=''),
    91120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91120, CurrentID=0, Status='live', Symbol='ZNF682', Aliases=['BC39498_3'], description='zinc finger protein 682', other_designations='zinc finger protein 682', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20004418, end_position_on_the_genomic_accession=20039505, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    91133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91133, CurrentID=0, Status='live', Symbol='L3MBTL4', Aliases=['HsT1031'], description='L3MBTL histone methyl-lysine binding protein 4', other_designations='lethal(3)malignant brain tumor-like protein 4|H-l(3)mbt-like protein 4|L3MBTL4, histone methyl-lysine binding protein', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5954703, end_position_on_the_genomic_accession=6415259, orientation='minus', exon_count=32, OMIM=[617135], no_hdr0=''),
    91137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91137, CurrentID=0, Status='live', Symbol='SLC25A46', Aliases=['HMSN6B', 'PCH1E'], description='solute carrier family 25 member 46', other_designations='solute carrier family 25 member 46', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=110738145, end_position_on_the_genomic_accession=110765157, orientation='plus', exon_count=10, OMIM=[610826], no_hdr0=''),
    91147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91147, CurrentID=0, Status='live', Symbol='TMEM67', Aliases=['JBTS6', 'MECKELIN', 'MKS3', 'NPHP11', 'TNEM67'], description='transmembrane protein 67', other_designations='meckelin|meckel syndrome type 3 protein', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=93754844, end_position_on_the_genomic_accession=93832653, orientation='plus', exon_count=35, OMIM=[609884], no_hdr0=''),
    91151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91151, CurrentID=0, Status='live', Symbol='TIGD7', Aliases=['Sancho'], description='tigger transposable element derived 7', other_designations='tigger transposable element-derived protein 7', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3298808, end_position_on_the_genomic_accession=3305430, orientation='minus', exon_count=2, OMIM=[612969], no_hdr0=''),
    91156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91156, CurrentID=0, Status='live', Symbol='IGFN1', Aliases=['EEF1A2BP1'], description='immunoglobulin like and fibronectin type III domain containing 1', other_designations='immunoglobulin-like and fibronectin type III domain-containing protein 1|EEF1A2-binding protein 1|KY-interacting protein 1|eEF1A2 binding protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201190780, end_position_on_the_genomic_accession=201228952, orientation='plus', exon_count=25, OMIM=[617309], no_hdr0=''),
    91179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91179, CurrentID=0, Status='live', Symbol='SCARF2', Aliases=['NSR1', 'SREC-II', 'SREC2', 'SRECRP-1', 'VDEGS'], description='scavenger receptor class F member 2', other_designations='scavenger receptor class F member 2|scavenger receptor expressed by endothelial cells 2 protein', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20424584, end_position_on_the_genomic_accession=20437825, orientation='minus', exon_count=11, OMIM=[613619], no_hdr0=''),
    91181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91181, CurrentID=0, Status='live', Symbol='NUP210L', Aliases=[], description='nucleoporin 210 like', other_designations='nuclear pore membrane glycoprotein 210-like|nuclear pore membrane glycoprotein 210-like (LOC91181)|nucleoporin 210kDa like|nucleoporin Nup210-like', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153992582, end_position_on_the_genomic_accession=154155116, orientation='minus', exon_count=40, OMIM=[], no_hdr0=''),
    91227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91227, CurrentID=0, Status='live', Symbol='GGTLC2', Aliases=['GGTL4'], description='gamma-glutamyltransferase light chain 2', other_designations='glutathione hydrolase light chain 2|gamma-glutamyltransferase-like 4|gamma-glutamyltransferase-like protein 4', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22644614, end_position_on_the_genomic_accession=22647898, orientation='plus', exon_count=5, OMIM=[612339], no_hdr0=''),
    91252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91252, CurrentID=0, Status='live', Symbol='SLC39A13', Aliases=['EDSSPD3', 'LZT-Hs9', 'SCDEDS', 'ZIP13'], description='solute carrier family 39 member 13', other_designations='zinc transporter ZIP13|LIV-1 subfamily of ZIP zinc transporter 9|solute carrier family 39 (metal ion transporter), member 13|solute carrier family 39 (zinc transporter), member 13|zrt- and Irt-like protein 13', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47407132, end_position_on_the_genomic_accession=47416500, orientation='plus', exon_count=14, OMIM=[608735], no_hdr0=''),
    91272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91272, CurrentID=0, Status='live', Symbol='BOD1', Aliases=['FAM44B'], description='biorientation of chromosomes in cell division 1', other_designations='biorientation of chromosomes in cell division protein 1|biorientation defective 1|family with sequence similarity 44, member B', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173607145, end_position_on_the_genomic_accession=173617072, orientation='minus', exon_count=5, OMIM=[616745], no_hdr0=''),
    91283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91283, CurrentID=0, Status='live', Symbol='MSANTD3', Aliases=['C9orf30', 'L8'], description='Myb/SANT DNA binding domain containing 3', other_designations='myb/SANT-like DNA-binding domain-containing protein 3|Myb/SANT-like DNA-binding domain containing 3|UPF0439 protein C9orf30', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100427143, end_position_on_the_genomic_accession=100451734, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    91289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91289, CurrentID=0, Status='live', Symbol='LMF2', Aliases=['TMEM112B', 'TMEM153'], description='lipase maturation factor 2', other_designations='lipase maturation factor 2|transmembrane protein 112B|transmembrane protein 153', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50502949, end_position_on_the_genomic_accession=50507781, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    91298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91298, CurrentID=0, Status='live', Symbol='C12orf29', Aliases=[], description='chromosome 12 open reading frame 29', other_designations='uncharacterized protein C12orf29', map_location='12q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=88035536, end_position_on_the_genomic_accession=88050160, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    91300 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91300, CurrentID=0, Status='live', Symbol='R3HDM4', Aliases=['C19orf22'], description='R3H domain containing 4', other_designations='R3H domain-containing protein 4|R3H domain-containing protein C19orf22', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=896503, end_position_on_the_genomic_accession=913219, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    91304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91304, CurrentID=0, Status='live', Symbol='TMEM259', Aliases=['ASBABP1', 'C19orf6', 'MBRL', 'MEMBRALIN', 'R32184_3'], description='transmembrane protein 259', other_designations='membralin|aspecific BCL2 ARE-binding protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1009651, end_position_on_the_genomic_accession=1021142, orientation='minus', exon_count=12, OMIM=[611011], no_hdr0=''),
    91319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91319, CurrentID=0, Status='live', Symbol='DERL3', Aliases=['C22orf14', 'IZP6', 'LLN2', 'derlin-3'], description='derlin 3', other_designations='derlin-3|DERtrin 3|Der1-like domain family, member 3|degradation in endoplasmic reticulum protein 3|der1-like protein 3', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23834498, end_position_on_the_genomic_accession=23839348, orientation='minus', exon_count=8, OMIM=[610305], no_hdr0=''),
    91351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91351, CurrentID=0, Status='live', Symbol='DDX60L', Aliases=[], description='DExD/H-box 60 like', other_designations='probable ATP-dependent RNA helicase DDX60-like|DEAD (Asp-Glu-Ala-Asp) box polypeptide 60-like|DEAD box protein 60-like|DEAD-box helicase 60 like|putative ATP-dependent RNA helicase DDX60', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=168356735, end_position_on_the_genomic_accession=168480514, orientation='minus', exon_count=46, OMIM=[616725], no_hdr0=''),
    91368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91368, CurrentID=0, Status='live', Symbol='CDKN2AIPNL', Aliases=['C2AIL'], description='CDKN2A interacting protein N-terminal like', other_designations='CDKN2AIP N-terminal-like protein|CDKN2A-interacting protein N-terminal-like protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134402065, end_position_on_the_genomic_accession=134414625, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    91369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91369, CurrentID=0, Status='live', Symbol='ANKRD40', Aliases=[], description='ankyrin repeat domain 40', other_designations='ankyrin repeat domain-containing protein 40', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50693195, end_position_on_the_genomic_accession=50707914, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    91373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91373, CurrentID=0, Status='live', Symbol='UAP1L1', Aliases=[], description='UDP-N-acetylglucosamine pyrophosphorylase 1 like 1', other_designations='UDP-N-acetylhexosamine pyrophosphorylase-like protein 1|UDP-N-acteylglucosamine pyrophosphorylase 1-like 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137077475, end_position_on_the_genomic_accession=137084538, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    91392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91392, CurrentID=0, Status='live', Symbol='ZNF502', Aliases=[], description='zinc finger protein 502', other_designations='zinc finger protein 502', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44712660, end_position_on_the_genomic_accession=44723831, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    91404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91404, CurrentID=0, Status='live', Symbol='SESTD1', Aliases=['SOLO'], description='SEC14 and spectrin domain containing 1', other_designations='SEC14 domain and spectrin repeat-containing protein 1|SEC14 and spectrin domains 1|huntingtin-interacting protein-like protein|protein Solo', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=179101678, end_position_on_the_genomic_accession=179264832, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    91408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91408, CurrentID=0, Status='live', Symbol='BTF3L4', Aliases=[], description='basic transcription factor 3 like 4', other_designations='transcription factor BTF3 homolog 4', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52056295, end_position_on_the_genomic_accession=52090716, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    91409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91409, CurrentID=0, Status='live', Symbol='CCDC74B', Aliases=[], description='coiled-coil domain containing 74B', other_designations='coiled-coil domain-containing protein 74B', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130139283, end_position_on_the_genomic_accession=130145112, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    91419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91419, CurrentID=0, Status='live', Symbol='ATP23', Aliases=['KUB3', 'XRCC6BP1'], description='ATP23 metallopeptidase and ATP synthase assembly factor homolog', other_designations='mitochondrial inner membrane protease ATP23 homolog|Ku70-binding protein 3|XRCC6-binding protein 1', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57941567, end_position_on_the_genomic_accession=57959148, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    91433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91433, CurrentID=0, Status='live', Symbol='RCCD1', Aliases=[], description='RCC1 domain containing 1', other_designations='RCC1 domain-containing protein 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90954864, end_position_on_the_genomic_accession=90964858, orientation='plus', exon_count=9, OMIM=[617997], no_hdr0=''),
    91442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91442, CurrentID=0, Status='live', Symbol='FAAP24', Aliases=['C19orf40'], description='FA core complex associated protein 24', other_designations='Fanconi anemia core complex-associated protein 24|Fanconi anemia core complex associated protein 24|Fanconi anemia-associated protein of 24 kDa', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32972212, end_position_on_the_genomic_accession=32978229, orientation='plus', exon_count=5, OMIM=[610884], no_hdr0=''),
    91445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91445, CurrentID=0, Status='live', Symbol='RNF185', Aliases=[], description='ring finger protein 185', other_designations='E3 ubiquitin-protein ligase RNF185|BSK65-MONO1|BSK65-MONO2|BSK65-PANC1|BSK65-PANC2|BSK65-TEST1|BSK65-TEST2|BSK65-TEST3|RING-type E3 ubiquitin transferase RNF185', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31160182, end_position_on_the_genomic_accession=31207019, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    91452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91452, CurrentID=0, Status='live', Symbol='ACBD5', Aliases=['RDLKD'], description='acyl-CoA binding domain containing 5', other_designations='acyl-CoA-binding domain-containing protein 5|acyl-Coenzyme A binding domain containing 5|endozepine-related protein|membrane-associated diazepam binding inhibitor', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27182838, end_position_on_the_genomic_accession=27243542, orientation='minus', exon_count=18, OMIM=[616618], no_hdr0=''),
    91461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91461, CurrentID=0, Status='live', Symbol='PKDCC', Aliases=['RLSDF', 'SGK493', 'Vlk'], description='protein kinase domain containing, cytoplasmic', other_designations='extracellular tyrosine-protein kinase PKDCC|protein kinase domain containing, cytoplasmic homolog|protein kinase domain-containing protein, cytoplasmic|protein kinase-like protein SgK493|sugen kinase 493|vertebrate lonesome kinase', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42048021, end_position_on_the_genomic_accession=42058517, orientation='plus', exon_count=7, OMIM=[614150], no_hdr0=''),
    91464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91464, CurrentID=0, Status='live', Symbol='ISX', Aliases=['Pix-1', 'RAXLX'], description='intestine specific homeobox', other_designations='intestine-specific homeobox|RAX-like homeobox|pancreas-intestine homeodomain transcription factor', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=35066158, end_position_on_the_genomic_accession=35087387, orientation='plus', exon_count=5, OMIM=[612019], no_hdr0=''),
    91522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91522, CurrentID=0, Status='live', Symbol='COL23A1', Aliases=[], description='collagen type XXIII alpha 1 chain', other_designations='collagen alpha-1(XXIII) chain|collagen, type XXIII, alpha 1|procollagen, type XXIII, alpha 1', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178237616, end_position_on_the_genomic_accession=178590393, orientation='minus', exon_count=32, OMIM=[610043], no_hdr0=''),
    91523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91523, CurrentID=0, Status='live', Symbol='PCED1B', Aliases=['FAM113B'], description='PC-esterase domain containing 1B', other_designations='PC-esterase domain-containing protein 1B|family with sequence similarity 113, member B', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47079621, end_position_on_the_genomic_accession=47236660, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    91526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91526, CurrentID=0, Status='live', Symbol='ANKRD44', Aliases=['PP6-ARS-B'], description='ankyrin repeat domain 44', other_designations='serine/threonine-protein phosphatase 6 regulatory ankyrin repeat subunit B|ankyrin repeat domain-containing protein 44|serine/threonine-protein phosphatase 6 regulatory subunit ARS-B', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196962617, end_position_on_the_genomic_accession=197310787, orientation='minus', exon_count=33, OMIM=[], no_hdr0=''),
    91543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91543, CurrentID=0, Status='live', Symbol='RSAD2', Aliases=['cig33', 'cig5', 'vig1'], description='radical S-adenosyl methionine domain containing 2', other_designations='radical S-adenosyl methionine domain-containing protein 2|cytomegalovirus-induced gene 5 protein|viperin|virus inhibitory protein, endoplasmic reticulum-associated, interferon-inducible', map_location='2p25.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=6865733, end_position_on_the_genomic_accession=6898239, orientation='plus', exon_count=7, OMIM=[607810], no_hdr0=''),
    91544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91544, CurrentID=0, Status='live', Symbol='UBXN11', Aliases=['COA-1', 'PP2243', 'SOC', 'SOCI', 'UBXD5'], description='UBX domain protein 11', other_designations='UBX domain-containing protein 11|UBX domain-containing protein 5|colorectal tumor-associated antigen COA-1|colorectal tumor-associated antigen-1|socius', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26282282, end_position_on_the_genomic_accession=26318355, orientation='minus', exon_count=17, OMIM=[609151], no_hdr0=''),
    91574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91574, CurrentID=0, Status='live', Symbol='MTRFR', Aliases=['C12orf65', 'COXPD7', 'SPG55'], description='mitochondrial translation release factor in rescue', other_designations='mitochondrial translation release factor in rescue|probable peptide chain release factor C12orf65, mitochondrial', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123233436, end_position_on_the_genomic_accession=123257960, orientation='plus', exon_count=5, OMIM=[613541], no_hdr0=''),
    91582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91582, CurrentID=0, Status='live', Symbol='RPS19BP1', Aliases=['AROS', 'S19BP'], description='ribosomal protein S19 binding protein 1', other_designations='active regulator of SIRT1|40S ribosomal protein S19-binding protein 1|RPS19-binding protein 1|homolog of mouse S19 binding protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39529093, end_position_on_the_genomic_accession=39532748, orientation='minus', exon_count=5, OMIM=[610225], no_hdr0=''),
    91584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91584, CurrentID=0, Status='live', Symbol='PLXNA4', Aliases=['FAYV2820', 'PLEXA4A', 'PLXNA4B', 'PRO34003', 'PLXNA4'], description='plexin A4', other_designations='plexin-A4|epididymis secretory sperm binding protein', map_location='7q32.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=132123340, end_position_on_the_genomic_accession=132648688, orientation='minus', exon_count=40, OMIM=[604280], no_hdr0=''),
    91603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91603, CurrentID=0, Status='live', Symbol='ZNF830', Aliases=['CCDC16', 'OMCG1'], description='zinc finger protein 830', other_designations='zinc finger protein 830|coiled-coil domain containing 16|coiled-coil domain-containing protein 16|hypothetical protein MGC20398|orphan maintenance of genome 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34961540, end_position_on_the_genomic_accession=34963777, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    91607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91607, CurrentID=0, Status='live', Symbol='SLFN11', Aliases=['SLFN8/9'], description='schlafen family member 11', other_designations='schlafen family member 11', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35350305, end_position_on_the_genomic_accession=35373621, orientation='minus', exon_count=7, OMIM=[614953], no_hdr0=''),
    91608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91608, CurrentID=0, Status='live', Symbol='RASL10B', Aliases=['RRP17', 'VTS58635'], description='RAS like family 10 member B', other_designations='ras-like protein family member 10B|Ras-related protein 17|alternative protein RASL10B|ras-like protein VTS58635', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35731639, end_position_on_the_genomic_accession=35743521, orientation='plus', exon_count=6, OMIM=[612128], no_hdr0=''),
    91612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91612, CurrentID=0, Status='live', Symbol='CHURC1', Aliases=['C14orf52', 'My015', 'chch'], description='churchill domain containing 1', other_designations='protein Churchill', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64914455, end_position_on_the_genomic_accession=64935368, orientation='plus', exon_count=4, OMIM=[608577], no_hdr0=''),
    91614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91614, CurrentID=0, Status='live', Symbol='DEPDC7', Aliases=['TR2', 'dJ85M6.4'], description='DEP domain containing 7', other_designations='DEP domain-containing protein 7|dJ85M6.4 (novel 58.3 KDA protein)|novel 58.3 KDA protein', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33015878, end_position_on_the_genomic_accession=33033582, orientation='plus', exon_count=10, OMIM=[612294], no_hdr0=''),
    91624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91624, CurrentID=0, Status='live', Symbol='NEXN', Aliases=['CMH20', 'NELIN'], description='nexilin F-actin binding protein', other_designations='nexilin', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77888528, end_position_on_the_genomic_accession=77948643, orientation='plus', exon_count=14, OMIM=[613121], no_hdr0=''),
    91646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91646, CurrentID=0, Status='live', Symbol='TDRD12', Aliases=['ECAT8'], description='tudor domain containing 12', other_designations='putative ATP-dependent RNA helicase TDRD12|ES cell associated transcript 8|ES cell-associated transcript 8 protein|tudor domain-containing protein 12', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32719767, end_position_on_the_genomic_accession=32829580, orientation='plus', exon_count=35, OMIM=[], no_hdr0=''),
    91647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91647, CurrentID=0, Status='live', Symbol='ATPAF2', Aliases=['ATP12', 'ATP12p', 'LP3663', 'MC5DN1'], description='ATP synthase mitochondrial F1 complex assembly factor 2', other_designations='ATP synthase mitochondrial F1 complex assembly factor 2|ATP12 homolog', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18015059, end_position_on_the_genomic_accession=18039168, orientation='minus', exon_count=11, OMIM=[608918], no_hdr0=''),
    91653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91653, CurrentID=0, Status='live', Symbol='BOC', Aliases=['Boi', 'CDON2'], description='BOC cell adhesion associated, oncogene regulated', other_designations='brother of CDO|Boc homolog|brother of CDON|cell adhesion associated, oncogene regulated 2', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113211003, end_position_on_the_genomic_accession=113287463, orientation='plus', exon_count=24, OMIM=[608708], no_hdr0=''),
    91661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91661, CurrentID=0, Status='live', Symbol='ZNF765', Aliases=[], description='zinc finger protein 765', other_designations='zinc finger protein 765', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53395149, end_position_on_the_genomic_accession=53427321, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    91662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91662, CurrentID=0, Status='live', Symbol='NLRP12', Aliases=['CLR19.3', 'FCAS2', 'NALP12', 'PAN6', 'PYPAF7', 'RNO', 'RNO2'], description='NLR family pyrin domain containing 12', other_designations='NACHT, LRR and PYD domains-containing protein 12|PYRIN-containing APAF1-like protein 7|monarch 1|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 12|regulated by nitric oxide', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53793584, end_position_on_the_genomic_accession=53824403, orientation='minus', exon_count=12, OMIM=[609648], no_hdr0=''),
    91663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91663, CurrentID=0, Status='live', Symbol='MYADM', Aliases=['SB135'], description='myeloid associated differentiation marker', other_designations='myeloid-associated differentiation marker|myeloid upregulated protein', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53865628, end_position_on_the_genomic_accession=53876435, orientation='plus', exon_count=8, OMIM=[609959], no_hdr0=''),
    91664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91664, CurrentID=0, Status='live', Symbol='ZNF845', Aliases=[], description='zinc finger protein 845', other_designations='zinc finger protein 845', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53333749, end_position_on_the_genomic_accession=53356906, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    91683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91683, CurrentID=0, Status='live', Symbol='SYT12', Aliases=['SYT11', 'sytXII'], description='synaptotagmin 12', other_designations='synaptotagmin-12|synaptotagmin-XII', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67006773, end_position_on_the_genomic_accession=67050863, orientation='plus', exon_count=16, OMIM=[606436], no_hdr0=''),
    91687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91687, CurrentID=0, Status='live', Symbol='CENPL', Aliases=['C1orf155', 'CENP-L', 'dJ383J4.3'], description='centromere protein L', other_designations='centromere protein L|interphase centromere complex protein 33', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173799550, end_position_on_the_genomic_accession=173824883, orientation='minus', exon_count=8, OMIM=[611503], no_hdr0=''),
    91689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91689, CurrentID=0, Status='live', Symbol='SMDT1', Aliases=['C22orf32', 'DDDD', 'EMRE'], description='single-pass membrane protein with aspartate rich tail 1', other_designations='essential MCU regulator, mitochondrial|UPF0466 protein C22orf32, mitochondrial|single-pass membrane protein with aspartate-rich tail 1, mitochondrial', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42079700, end_position_on_the_genomic_accession=42084284, orientation='plus', exon_count=4, OMIM=[615588], no_hdr0=''),
    91694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91694, CurrentID=0, Status='live', Symbol='LONRF1', Aliases=['RNF191'], description='LON peptidase N-terminal domain and ring finger 1', other_designations='LON peptidase N-terminal domain and RING finger protein 1|RING finger protein 191', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12721900, end_position_on_the_genomic_accession=12755526, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    91703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91703, CurrentID=0, Status='live', Symbol='ACY3', Aliases=['ACY-3', 'HCBP1'], description='aminoacylase 3', other_designations='N-acyl-aromatic-L-amino acid amidohydrolase (carboxylate-forming)|HCV core-binding protein 1|acylase III|aspartoacylase (aminoacylase) 3|aspartoacylase (aminocyclase) 3|aspartoacylase-2|hepatitis C virus core-binding protein 1', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67642551, end_position_on_the_genomic_accession=67650829, orientation='minus', exon_count=9, OMIM=[614413], no_hdr0=''),
    91734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91734, CurrentID=0, Status='live', Symbol='IDI2', Aliases=['IPPI2'], description='isopentenyl-diphosphate delta isomerase 2', other_designations='isopentenyl-diphosphate delta-isomerase 2|IPP isomerase 2|diphosphate dimethylallyl diphosphate isomerase 2|isopentenyl pyrophosphate isomerase 2|isopentenyl-diphosphate Delta-isomerase 2', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=1018910, end_position_on_the_genomic_accession=1025859, orientation='minus', exon_count=5, OMIM=[615389], no_hdr0=''),
    91746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91746, CurrentID=0, Status='live', Symbol='YTHDC1', Aliases=['YT521', 'YT521-B'], description='YTH domain containing 1', other_designations='YTH domain-containing protein 1|putative splicing factor YT521|splicing factor YT521|splicing factor YT521-B', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68310387, end_position_on_the_genomic_accession=68350093, orientation='minus', exon_count=17, OMIM=[617283], no_hdr0=''),
    91748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91748, CurrentID=0, Status='live', Symbol='MIDEAS', Aliases=['C14orf117', 'C14orf43', 'ELMSAN1', 'LSR68', 'c14_5541'], description='mitotic deacetylase associated SANT domain protein', other_designations='mitotic deacetylase-associated SANT domain protein|ELM2 and Myb/SANT domain containing 1|ELM2 and Myb/SANT-like domain containing 1|ELM2 and SANT domain-containing protein 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73715122, end_position_on_the_genomic_accession=73790285, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    91749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91749, CurrentID=0, Status='live', Symbol='MFSD4B', Aliases=['KIAA1919', 'NaGLT1', 'SLC60A2'], description='major facilitator superfamily domain containing 4B', other_designations='sodium-dependent glucose transporter 1|major facilitator superfamily domain-containing protein 4B', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=111259279, end_position_on_the_genomic_accession=111280005, orientation='plus', exon_count=5, OMIM=[617331], no_hdr0=''),
    91750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91750, CurrentID=0, Status='live', Symbol='LIN52', Aliases=['C14orf46', 'c14_5549'], description='lin-52 DREAM MuvB core complex component', other_designations='protein lin-52 homolog|lin-52 homolog', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74084867, end_position_on_the_genomic_accession=74201493, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    91752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91752, CurrentID=0, Status='live', Symbol='ZNF804A', Aliases=['C2orf10'], description='zinc finger protein 804A', other_designations='zinc finger protein 804A', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=184598529, end_position_on_the_genomic_accession=184939492, orientation='plus', exon_count=4, OMIM=[612282], no_hdr0=''),
    91754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91754, CurrentID=0, Status='live', Symbol='NEK9', Aliases=['APUG', 'LCCS10', 'NC', 'NERCC', 'NERCC1'], description='NIMA related kinase 9', other_designations='serine/threonine-protein kinase Nek9|NIMA (never in mitosis gene a)- related kinase 9|nercc1 kinase|nimA-related protein kinase 9', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75079353, end_position_on_the_genomic_accession=75127637, orientation='minus', exon_count=23, OMIM=[609798], no_hdr0=''),
    91768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91768, CurrentID=0, Status='live', Symbol='CABLES1', Aliases=['CABL1', 'CABLES', 'HsT2563', 'IK3-1'], description='Cdk5 and Abl enzyme substrate 1', other_designations='CDK5 and ABL1 enzyme substrate 1|interactor with CDK3 1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23134564, end_position_on_the_genomic_accession=23260470, orientation='plus', exon_count=12, OMIM=[609194], no_hdr0=''),
    91775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91775, CurrentID=0, Status='live', Symbol='NXPE3', Aliases=['FAM55C', 'MST115', 'MSTP115'], description='neurexophilin and PC-esterase domain family member 3', other_designations='NXPE family member 3|family with sequence similarity 55, member C', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=101779211, end_position_on_the_genomic_accession=101828231, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    91782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91782, CurrentID=0, Status='live', Symbol='CHMP7', Aliases=[], description='charged multivesicular body protein 7', other_designations='charged multivesicular body protein 7|CHMP family, member 7|chromatin-modifying protein 7', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23243637, end_position_on_the_genomic_accession=23262000, orientation='plus', exon_count=11, OMIM=[611130], no_hdr0=''),
    91801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91801, CurrentID=0, Status='live', Symbol='ALKBH8', Aliases=['ABH8', 'MRT71', 'TRM9', 'TRMT9', 'TRMT9A'], description='alkB homolog 8, tRNA methyltransferase', other_designations='alkylated DNA repair protein alkB homolog 8|AlkB homologue 8|S-adenosyl-L-methionine-dependent tRNA methyltransferase ABH8|alkB, alkylation repair homolog 8|probable alpha-ketoglutarate-dependent dioxygenase ABH8|tRNA (carboxymethyluridine(34)-5-O)-methyltransferase ABH8|tRNA methyltransferase 9 homolog|tRNA methyltransferase 9 related', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107502726, end_position_on_the_genomic_accession=107565737, orientation='minus', exon_count=13, OMIM=[613306], no_hdr0=''),
    91807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91807, CurrentID=0, Status='live', Symbol='MYLK3', Aliases=['MLCK', 'MLCK2', 'caMLCK'], description='myosin light chain kinase 3', other_designations='myosin light chain kinase 3|MLC kinase|cardiac-MLCK|cardiac-MyBP-C associated Ca/CaM kinase|putative myosin light chain kinase 3', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46702282, end_position_on_the_genomic_accession=46763246, orientation='minus', exon_count=14, OMIM=[612147], no_hdr0=''),
    91828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91828, CurrentID=0, Status='live', Symbol='EXOC3L4', Aliases=['C14orf73'], description='exocyst complex component 3 like 4', other_designations='exocyst complex component 3-like protein 4|SEC6-like protein C14orf73', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103094202, end_position_on_the_genomic_accession=103110562, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    91833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91833, CurrentID=0, Status='live', Symbol='WDR20', Aliases=['Bun107', 'DMR'], description='WD repeat domain 20', other_designations='WD repeat-containing protein 20', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102139423, end_position_on_the_genomic_accession=102224686, orientation='plus', exon_count=13, OMIM=[617741], no_hdr0=''),
    91851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91851, CurrentID=0, Status='live', Symbol='CHRDL1', Aliases=['CHL', 'MGC1', 'MGCN', 'NRLN1', 'VOPT', 'dA141H5.1'], description='chordin like 1', other_designations='chordin-like protein 1|neuralin-1|neurogenesin-1|ventroptin', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=110673856, end_position_on_the_genomic_accession=110795817, orientation='minus', exon_count=13, OMIM=[300350], no_hdr0=''),
    91860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91860, CurrentID=0, Status='live', Symbol='CALML4', Aliases=['NY-BR-20'], description='calmodulin like 4', other_designations='calmodulin-like protein 4|serologically defined breast cancer antigen NY-BR-20', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68190705, end_position_on_the_genomic_accession=68206110, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    91862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91862, CurrentID=0, Status='live', Symbol='MARVELD3', Aliases=['MARVD3', 'MRVLDC3'], description='MARVEL domain containing 3', other_designations='MARVEL domain-containing protein 3|MARVEL (membrane-associating) domain containing 3', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71626180, end_position_on_the_genomic_accession=71641965, orientation='plus', exon_count=5, OMIM=[614094], no_hdr0=''),
    91869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91869, CurrentID=0, Status='live', Symbol='RFT1', Aliases=['CDG1N'], description='RFT1 homolog', other_designations='protein RFT1 homolog|RFT1, requiring fifty three 1 homolog|congenital disorder of glycosylation 1N|putative endoplasmic reticulum multispan transmembrane protein', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53071151, end_position_on_the_genomic_accession=53130469, orientation='minus', exon_count=18, OMIM=[611908], no_hdr0=''),
    91875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91875, CurrentID=0, Status='live', Symbol='TTC5', Aliases=['NEDCAFD', 'Strap'], description='tetratricopeptide repeat domain 5', other_designations='tetratricopeptide repeat protein 5|TPR repeat protein 5|stress-responsive activator of p300', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20286227, end_position_on_the_genomic_accession=20305951, orientation='minus', exon_count=10, OMIM=[619014], no_hdr0=''),
    91893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91893, CurrentID=0, Status='live', Symbol='FDXACB1', Aliases=['hCG_2033039'], description='ferredoxin-fold anticodon binding domain containing 1', other_designations='ferredoxin-fold anticodon-binding domain-containing protein 1|FDX-ACDB domain-containing protein 1|hypothetical protein BC006136', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111874056, end_position_on_the_genomic_accession=111879165, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    91894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91894, CurrentID=0, Status='live', Symbol='C11orf52', Aliases=[], description='chromosome 11 open reading frame 52', other_designations='uncharacterized protein C11orf52', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111918913, end_position_on_the_genomic_accession=111926871, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    91937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91937, CurrentID=0, Status='live', Symbol='TIMD4', Aliases=['SMUCKLER', 'TIM4'], description='T cell immunoglobulin and mucin domain containing 4', other_designations='T-cell immunoglobulin and mucin domain-containing protein 4|T-cell immunoglobulin mucin receptor 4|T-cell membrane protein 4|TIM-4|TIMD-4', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=156919292, end_position_on_the_genomic_accession=156963226, orientation='minus', exon_count=10, OMIM=[610096], no_hdr0=''),
    91942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91942, CurrentID=0, Status='live', Symbol='NDUFAF2', Aliases=['B17.2L', 'MC1DN10', 'MMTN', 'NDUFA12L', 'mimitin'], description='NADH:ubiquinone oxidoreductase complex assembly factor 2', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex assembly factor 2|Myc-induced mitochondrial protein|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, assembly factor 2|NADH dehydrogenase (ubiquinone) complex I, assembly factor 2|NADH dehydrogenase 1 alpha subcomplex assembly factor 2|NDUFA12-like protein|mimitin, mitochondrial', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=60945205, end_position_on_the_genomic_accession=61153026, orientation='plus', exon_count=4, OMIM=[609653], no_hdr0=''),
    91947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91947, CurrentID=0, Status='live', Symbol='ARRDC4', Aliases=[], description='arrestin domain containing 4', other_designations='arrestin domain-containing protein 4', map_location='15q26.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=97960703, end_position_on_the_genomic_accession=97973833, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    91949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91949, CurrentID=0, Status='live', Symbol='COG7', Aliases=['CDG2E'], description='component of oligomeric golgi complex 7', other_designations='conserved oligomeric Golgi complex subunit 7|COG complex subunit 7', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23388493, end_position_on_the_genomic_accession=23453215, orientation='minus', exon_count=17, OMIM=[606978], no_hdr0=''),
    91966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91966, CurrentID=0, Status='live', Symbol='EOLA1', Aliases=['CXorf40', 'CXorf40A'], description='endothelium and lymphocyte associated ASCH domain 1', other_designations='protein EOLA1|endothelial-overexpressed lipopolysaccharide-associated factor 1|protein CXorf40A', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149540601, end_position_on_the_genomic_accession=149555345, orientation='plus', exon_count=8, OMIM=[300954], no_hdr0=''),
    91975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91975, CurrentID=0, Status='live', Symbol='ZNF300', Aliases=[], description='zinc finger protein 300', other_designations='zinc finger protein 300|kruppel-like zinc finger protein', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150892958, end_position_on_the_genomic_accession=150904980, orientation='minus', exon_count=8, OMIM=[612429], no_hdr0=''),
    91977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91977, CurrentID=0, Status='live', Symbol='MYOZ3', Aliases=['CS-3', 'CS3', 'FATZ-3', 'FRP3'], description='myozenin 3', other_designations='myozenin-3|FATZ-related protein 3|calsarcin-3', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150660869, end_position_on_the_genomic_accession=150679368, orientation='plus', exon_count=8, OMIM=[610735], no_hdr0=''),
    91978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=91978, CurrentID=0, Status='live', Symbol='TPGS1', Aliases=['C19orf20', 'GTRGEO22', 'PGs1'], description='tubulin polyglutamylase complex subunit 1', other_designations='tubulin polyglutamylase complex subunit 1|gene trap ROSA b-geo 22', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=507497, end_position_on_the_genomic_accession=519654, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    92002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92002, CurrentID=0, Status='live', Symbol='CCNQ', Aliases=['CycM', 'FAM58A'], description='cyclin Q', other_designations='cyclin-Q|CDK10-activating cyclin|cyclin M|cyclin-related protein FAM58A|family with sequence similarity 58 member A', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153587925, end_position_on_the_genomic_accession=153599165, orientation='minus', exon_count=6, OMIM=[300708], no_hdr0=''),
    92014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92014, CurrentID=0, Status='live', Symbol='SLC25A51', Aliases=['CG7943', 'MCART1'], description='solute carrier family 25 member 51', other_designations='mitochondrial nicotinamide adenine dinucleotide transporter SLC25A51|mitochondrial NAD(+) transporter SLC25A51|mitochondrial NAD+ transporter|mitochondrial carrier triple repeat 1|mitochondrial carrier triple repeat protein 1', map_location='9p13.2-p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37877575, end_position_on_the_genomic_accession=37904127, orientation='minus', exon_count=6, OMIM=[619153], no_hdr0=''),
    92017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92017, CurrentID=0, Status='live', Symbol='SNX29', Aliases=['A-388D4.1', 'RUNDC2A'], description='sorting nexin 29', other_designations='sorting nexin-29|RUN domain containing 2A|RUN domain-containing protein 2A', map_location='16p13.13-p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11976734, end_position_on_the_genomic_accession=12574287, orientation='plus', exon_count=27, OMIM=[], no_hdr0=''),
    92086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92086, CurrentID=0, Status='live', Symbol='GGTLC1', Aliases=['GGTL6', 'GGTLA3', 'GGTLA4', 'dJ831C21.1', 'dJ831C21.2'], description='gamma-glutamyltransferase light chain 1', other_designations='glutathione hydrolase light chain 1|gamma-glutamyl transpeptidase|gamma-glutamyltransferase-like activity 3|gamma-glutamyltransferase-like activity 4|gamma-glutamyltransferase-like protein 6', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23985053, end_position_on_the_genomic_accession=23989134, orientation='minus', exon_count=8, OMIM=[612338], no_hdr0=''),
    92092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92092, CurrentID=0, Status='live', Symbol='ZC3HAV1L', Aliases=['C7orf39'], description='zinc finger CCCH-type containing, antiviral 1 like', other_designations='zinc finger CCCH-type antiviral protein 1-like|zinc finger CCCH-type, antiviral 1-like', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139021498, end_position_on_the_genomic_accession=139036472, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    92104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92104, CurrentID=0, Status='live', Symbol='TTC30A', Aliases=['FAP259', 'IFT70A', 'TTC30B'], description='tetratricopeptide repeat domain 30A', other_designations='tetratricopeptide repeat protein 30A|TPR repeat protein 30A|TPR repeat protein 30B|Tetratricopeptide repeat protein 30B', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177612999, end_position_on_the_genomic_accession=177618742, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    92105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92105, CurrentID=0, Status='live', Symbol='INTS4', Aliases=['INT4', 'MST093'], description='integrator complex subunit 4', other_designations='integrator complex subunit 4|MSTP093', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77874418, end_position_on_the_genomic_accession=77994670, orientation='minus', exon_count=28, OMIM=[611348], no_hdr0=''),
    92106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92106, CurrentID=0, Status='live', Symbol='OXNAD1', Aliases=[], description='oxidoreductase NAD binding domain containing 1', other_designations='oxidoreductase NAD-binding domain-containing protein 1', map_location='3p25.1-p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16265190, end_position_on_the_genomic_accession=16386979, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    92126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92126, CurrentID=0, Status='live', Symbol='DSEL', Aliases=['C18orf4', 'DE-epi2'], description='dermatan sulfate epimerase like', other_designations='dermatan-sulfate epimerase-like protein|NCAG1', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=67506587, end_position_on_the_genomic_accession=67516720, orientation='minus', exon_count=2, OMIM=[611125], no_hdr0=''),
    92129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92129, CurrentID=0, Status='live', Symbol='RIPPLY1', Aliases=[], description='ripply transcriptional repressor 1', other_designations='protein ripply1|ripply1 homolog', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106900063, end_position_on_the_genomic_accession=106903341, orientation='minus', exon_count=4, OMIM=[300575], no_hdr0=''),
    92140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92140, CurrentID=0, Status='live', Symbol='MTDH', Aliases=['3D3', 'AEG-1', 'AEG1', 'LYRIC', 'LYRIC/3D3'], description='metadherin', other_designations='protein LYRIC|3D3/LYRIC|astrocyte elevated gene 1|astrocyte elevated gene-1 protein|lysine-rich CEACAM1 co-isolated protein|metastasis adhesion protein', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=97643972, end_position_on_the_genomic_accession=97730260, orientation='plus', exon_count=13, OMIM=[610323], no_hdr0=''),
    92154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92154, CurrentID=0, Status='live', Symbol='MTSS2', Aliases=['ABBA', 'ABBA-1', 'ABBA1', 'MTSS1L'], description='MTSS I-BAR domain containing 2', other_designations='protein MTSS 2|MTSS1-like protein|MTSS1L, I-BAR domain containing|actin-bundling with BAIAP2 homology protein 1|metastasis suppressor 1-like', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70661204, end_position_on_the_genomic_accession=70686053, orientation='minus', exon_count=20, OMIM=[616951], no_hdr0=''),
    92162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92162, CurrentID=0, Status='live', Symbol='TMEM88', Aliases=[], description='transmembrane protein 88', other_designations='transmembrane protein 88', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7854886, end_position_on_the_genomic_accession=7856099, orientation='plus', exon_count=2, OMIM=[617813], no_hdr0=''),
    92170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92170, CurrentID=0, Status='live', Symbol='MTG1', Aliases=['GTP', 'GTPBP7'], description='mitochondrial ribosome associated GTPase 1', other_designations='mitochondrial ribosome-associated GTPase 1|GTP-binding protein 7 (putative)|mitochondrial GTPase 1 homolog', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133394157, end_position_on_the_genomic_accession=133422520, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    92181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92181, CurrentID=0, Status='live', Symbol='UBTD2', Aliases=['DCUBP'], description='ubiquitin domain containing 2', other_designations='ubiquitin domain-containing protein 2|ubiquitin-like protein SB72', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172209645, end_position_on_the_genomic_accession=172283797, orientation='minus', exon_count=4, OMIM=[610174], no_hdr0=''),
    92196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92196, CurrentID=0, Status='live', Symbol='DAPL1', Aliases=[], description='death associated protein like 1', other_designations='death-associated protein-like 1|early epithelial differentiation-associated protein', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=158795317, end_position_on_the_genomic_accession=158815990, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    92211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92211, CurrentID=0, Status='live', Symbol='CDHR1', Aliases=['CORD15', 'PCDH21', 'PRCAD', 'RP65'], description='cadherin related family member 1', other_designations='cadherin-related family member 1|MT-protocadherin|photoreceptor cadherin|protocadherin-21', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84194537, end_position_on_the_genomic_accession=84219621, orientation='plus', exon_count=19, OMIM=[609502], no_hdr0=''),
    92235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92235, CurrentID=0, Status='live', Symbol='STYXL2', Aliases=['DUSP27'], description='serine/threonine/tyrosine interacting like 2', other_designations='serine/threonine/tyrosine-interacting-like protein 2|dual specificity phosphatase 27 (putative)|dual specificity phosphatase 27, atypical|inactive dual specificity phosphatase 27', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167094048, end_position_on_the_genomic_accession=167129165, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    92241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92241, CurrentID=0, Status='live', Symbol='RCSD1', Aliases=['CAPZIP', 'MK2S4'], description='RCSD domain containing 1', other_designations='capZ-interacting protein|RCSD domain-containing protein 1|protein kinase substrate CapZIP|protein kinase substrate MK2S4', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=167630232, end_position_on_the_genomic_accession=167708696, orientation='plus', exon_count=9, OMIM=[610579], no_hdr0=''),
    92255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92255, CurrentID=0, Status='live', Symbol='LMBRD2', Aliases=[], description='LMBR1 domain containing 2', other_designations='G-protein coupled receptor-associated protein LMBRD2|LMBR1 domain-containing protein 2', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36098407, end_position_on_the_genomic_accession=36151961, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    92259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92259, CurrentID=0, Status='live', Symbol='MRPS36', Aliases=['DC47', 'MRP-S36'], description='mitochondrial ribosomal protein S36', other_designations='28S ribosomal protein S36, mitochondrial|S36mt|alpha-ketoglutarate dehydrogenase component 4', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69217760, end_position_on_the_genomic_accession=69230158, orientation='plus', exon_count=4, OMIM=[611996], no_hdr0=''),
    92283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92283, CurrentID=0, Status='live', Symbol='ZNF461', Aliases=['GIOT-1', 'GIOT1', 'HZF28'], description='zinc finger protein 461', other_designations='zinc finger protein 461|gonadotropin-inducible ovary transcription repressor 1|zinc finger protein 28', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36636618, end_position_on_the_genomic_accession=36666837, orientation='minus', exon_count=9, OMIM=[608640], no_hdr0=''),
    92285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92285, CurrentID=0, Status='live', Symbol='ZNF585B', Aliases=['SZFP41', 'Zfp27'], description='zinc finger protein 585B', other_designations='zinc finger protein 585B|zinc finger protein 41-like protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37181579, end_position_on_the_genomic_accession=37210536, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    92291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92291, CurrentID=0, Status='live', Symbol='CAPN13', Aliases=[], description='calpain 13', other_designations='calpain-13|CANP 13|calcium-activated neutral proteinase 13', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=30722771, end_position_on_the_genomic_accession=30809527, orientation='minus', exon_count=28, OMIM=[610228], no_hdr0=''),
    92292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92292, CurrentID=0, Status='live', Symbol='GLYATL1', Aliases=['GATF-C', 'GNAT'], description='glycine-N-acyltransferase like 1', other_designations='glycine N-acyltransferase-like protein 1|acyl-CoA:glycine N-acyltransferase-like protein 1|glutamine N-acyltransferase', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58905481, end_position_on_the_genomic_accession=58957062, orientation='plus', exon_count=14, OMIM=[614761], no_hdr0=''),
    92293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92293, CurrentID=0, Status='live', Symbol='TMEM132C', Aliases=['PPP1R152'], description='transmembrane protein 132C', other_designations='transmembrane protein 132C|protein phosphatase 1, regulatory subunit 152', map_location='12q24.32-q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=128267170, end_position_on_the_genomic_accession=128707915, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    92304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92304, CurrentID=0, Status='live', Symbol='SCGB3A1', Aliases=['HIN-1', 'HIN1', 'LU105', 'PnSP-2', 'UGRP2'], description='secretoglobin family 3A member 1', other_designations='secretoglobin family 3A member 1|cytokine HIN-1|cytokine high in normal-1|high in normal 1|pneumo secretory protein 2|uteroglobin-related protein 2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180590105, end_position_on_the_genomic_accession=180591499, orientation='minus', exon_count=3, OMIM=[606500], no_hdr0=''),
    92305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92305, CurrentID=0, Status='live', Symbol='TMEM129', Aliases=['D4S2561E'], description='transmembrane protein 129, E3 ubiquitin ligase', other_designations='E3 ubiquitin-protein ligase TM129|RING-type E3 ubiquitin transferase TM129|transmembrane protein 129, E3 ubiquitin protein ligase', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1715952, end_position_on_the_genomic_accession=1721373, orientation='minus', exon_count=6, OMIM=[615975], no_hdr0=''),
    92312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92312, CurrentID=0, Status='live', Symbol='MEX3A', Aliases=['MEX-3A', 'RKHD4', 'RNF162'], description='mex-3 RNA binding family member A', other_designations='RNA-binding protein MEX3A|RING finger and KH domain-containing protein 4|ring finger and KH domain containing 4|ring finger and KH domain containing protein', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156072013, end_position_on_the_genomic_accession=156082465, orientation='minus', exon_count=2, OMIM=[611007], no_hdr0=''),
    92335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92335, CurrentID=0, Status='live', Symbol='STRADA', Aliases=['LYK5', 'NY-BR-96', 'PMSE', 'STRAD', 'STRAD alpha', 'Stlk'], description='STE20 related adaptor alpha', other_designations='STE20-related kinase adapter protein alpha|STE20-like pseudokinase|STE20-related kinase adaptor alpha|protein kinase LYK5|serologically defined breast cancer antigen NY-BR-96', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63702832, end_position_on_the_genomic_accession=63741986, orientation='minus', exon_count=14, OMIM=[608626], no_hdr0=''),
    92340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92340, CurrentID=0, Status='live', Symbol='PRR29', Aliases=['C17orf72'], description='proline rich 29', other_designations='proline-rich protein 29', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63998351, end_position_on_the_genomic_accession=64004305, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    92342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92342, CurrentID=0, Status='live', Symbol='METTL18', Aliases=['AsTP2', 'C1orf156', 'HPM1'], description='methyltransferase like 18', other_designations='histidine protein methyltransferase 1 homolog|arsenic-transactivated protein 2|methyltransferase-like protein 18', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=169792524, end_position_on_the_genomic_accession=169794907, orientation='minus', exon_count=3, OMIM=[615255], no_hdr0=''),
    92344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92344, CurrentID=0, Status='live', Symbol='GORAB', Aliases=['GO', 'NTKLBP1', 'SCYL1BP1'], description='golgin, RAB6 interacting', other_designations='RAB6-interacting golgin|N-terminal kinase-like-binding protein 1|NTKL-binding protein 1|SCY1-like 1-binding protein 1|SCYL1-binding protein 1', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=170532134, end_position_on_the_genomic_accession=170553834, orientation='plus', exon_count=7, OMIM=[607983], no_hdr0=''),
    92345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92345, CurrentID=0, Status='live', Symbol='NAF1', Aliases=[], description='nuclear assembly factor 1 ribonucleoprotein', other_designations='H/ACA ribonucleoprotein complex non-core subunit NAF1|nuclear assembly factor 1 homolog', map_location='4q32.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=163109133, end_position_on_the_genomic_accession=163166910, orientation='minus', exon_count=13, OMIM=[617868], no_hdr0=''),
    92346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92346, CurrentID=0, Status='live', Symbol='C1orf105', Aliases=[], description='chromosome 1 open reading frame 105', other_designations='uncharacterized protein C1orf105', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=172418560, end_position_on_the_genomic_accession=172468829, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    92359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92359, CurrentID=0, Status='live', Symbol='CRB3', Aliases=[], description='crumbs cell polarity complex component 3', other_designations='protein crumbs homolog 3|crumbs 3, cell polarity complex component|crumbs family member 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6463777, end_position_on_the_genomic_accession=6467221, orientation='plus', exon_count=5, OMIM=[609737], no_hdr0=''),
    92369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92369, CurrentID=0, Status='live', Symbol='SPSB4', Aliases=['SSB-4', 'SSB4'], description='splA/ryanodine receptor domain and SOCS box containing 4', other_designations='SPRY domain-containing SOCS box protein 4|SPRY domain-containing SOCS box protein SSB-4', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141051347, end_position_on_the_genomic_accession=141148611, orientation='plus', exon_count=5, OMIM=[611660], no_hdr0=''),
    92370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92370, CurrentID=0, Status='live', Symbol='PXYLP1', Aliases=['ACPL2', 'HEL124', 'XYLP'], description='2-phosphoxylose phosphatase 1', other_designations='2-phosphoxylose phosphatase 1|acid phosphatase-like 2|acid phosphatase-like protein 2|epididymis luminal protein 124|xylosyl phosphatase', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141231825, end_position_on_the_genomic_accession=141294924, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    92399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92399, CurrentID=0, Status='live', Symbol='MRRF', Aliases=['MRFF', 'MTRRF', 'RRF'], description='mitochondrial ribosome recycling factor', other_designations='ribosome-recycling factor, mitochondrial|ribosome-releasing factor, mitochondrial', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122264882, end_position_on_the_genomic_accession=122331337, orientation='plus', exon_count=11, OMIM=[604602], no_hdr0=''),
    92400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92400, CurrentID=0, Status='live', Symbol='RBM18', Aliases=[], description='RNA binding motif protein 18', other_designations='probable RNA-binding protein 18', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122237622, end_position_on_the_genomic_accession=122264840, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    92421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92421, CurrentID=0, Status='live', Symbol='CHMP4C', Aliases=['SNF7-3', 'Shax3', 'VPS32C'], description='charged multivesicular body protein 4C', other_designations='charged multivesicular body protein 4c|SNF7 homolog associated with Alix 3|Snf7 homologue associated with Alix 3|chromatin modifying protein 4C|chromatin-modifying protein 4c|hSnf7-3|hVps32-3|vacuolar protein sorting-associated protein 32-3|vps32-3', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81732448, end_position_on_the_genomic_accession=81759515, orientation='plus', exon_count=5, OMIM=[610899], no_hdr0=''),
    92482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92482, CurrentID=0, Status='live', Symbol='BBIP1', Aliases=['BBIP10', 'BBS18', 'NCRNA00081', 'bA348N5.3'], description='BBSome interacting protein 1', other_designations='BBSome-interacting protein 1|BBSome-interacting protein of 10 kDa|UPF0604 protein', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110898730, end_position_on_the_genomic_accession=110919366, orientation='minus', exon_count=5, OMIM=[613605], no_hdr0=''),
    92483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92483, CurrentID=0, Status='live', Symbol='LDHAL6B', Aliases=['LDH6B', 'LDHAL6', 'LDHL'], description='lactate dehydrogenase A like 6B', other_designations='L-lactate dehydrogenase A-like 6B|lactate dehydrogenase A-like 6|testicular tissue protein Li 105', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59206843, end_position_on_the_genomic_accession=59208588, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    92521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92521, CurrentID=0, Status='live', Symbol='SPECC1', Aliases=['CYTSB', 'HCMOGT-1', 'HCMOGT1', 'NSP', 'NSP5'], description='sperm antigen with calponin homology and coiled-coil domains 1', other_designations='cytospin-B|cytokinesis and spindle organization B|nuclear structure protein 5|sperm antigen HCMOGT-1|sperm antigen with calponin-like and coiled coil domains 1|structure protein NSP5a3a|structure protein NSP5a3b|structure protein NSP5b3a|structure protein NSP5b3b', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=20009301, end_position_on_the_genomic_accession=20319026, orientation='plus', exon_count=22, OMIM=[608793], no_hdr0=''),
    92552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92552, CurrentID=0, Status='live', Symbol='ATXN3L', Aliases=['MJDL'], description='ataxin 3 like', other_designations='ataxin-3-like protein|machado-Joseph disease protein 1-like|putative ataxin-3-like protein', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13318647, end_position_on_the_genomic_accession=13320053, orientation='minus', exon_count=2, OMIM=[300920], no_hdr0=''),
    92558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92558, CurrentID=0, Status='live', Symbol='BICDL1', Aliases=['BICDR-1', 'BICDR1', 'CCDC64', 'CCDC64A', 'H_267D11.1'], description='BICD family like cargo adaptor 1', other_designations='BICD family-like cargo adapter 1|BICD-related protein 1|bicaudal D-related protein 1|coiled-coil domain containing 64|coiled-coil domain-containing protein 64A', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119989236, end_position_on_the_genomic_accession=120094495, orientation='plus', exon_count=15, OMIM=[617002], no_hdr0=''),
    92565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92565, CurrentID=0, Status='live', Symbol='FANK1', Aliases=['HSD13'], description='fibronectin type III and ankyrin repeat domains 1', other_designations='fibronectin type 3 and ankyrin repeat domains protein 1|fibronectin type 3 and ankyrin repeat domains 1', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125896223, end_position_on_the_genomic_accession=126009599, orientation='plus', exon_count=22, OMIM=[611640], no_hdr0=''),
    92579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92579, CurrentID=0, Status='live', Symbol='G6PC3', Aliases=['SCN4', 'UGRP'], description='glucose-6-phosphatase catalytic subunit 3', other_designations='glucose-6-phosphatase 3|G-6-Pase 3|G6Pase 3|G6Pase-beta|glucose 6 phosphatase, catalytic, 3|ubiquitous glucose-6-phosphatase catalytic subunit-related protein|ubiquitously expressed G6Pase catalytic subunit-related protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44070673, end_position_on_the_genomic_accession=44076344, orientation='plus', exon_count=8, OMIM=[611045], no_hdr0=''),
    92591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92591, CurrentID=0, Status='live', Symbol='ASB16', Aliases=[], description='ankyrin repeat and SOCS box containing 16', other_designations='ankyrin repeat and SOCS box protein 16|ankyrin repeat and SOCS box-containing protein 16', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44170704, end_position_on_the_genomic_accession=44179084, orientation='plus', exon_count=5, OMIM=[615056], no_hdr0=''),
    92595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92595, CurrentID=0, Status='live', Symbol='ZNF764', Aliases=[], description='zinc finger protein 764', other_designations='zinc finger protein 764', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30553764, end_position_on_the_genomic_accession=30558374, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    92597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92597, CurrentID=0, Status='live', Symbol='MOB1B', Aliases=['MATS2', 'MOB4A', 'MOBKL1A'], description='MOB kinase activator 1B', other_designations='MOB kinase activator 1B|MOB1 Mps One Binder homolog B|MOB1, Mps One Binder kinase activator-like 1A|mob1 homolog 1A|mob1A|mps one binder kinase activator-like 1A', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70901970, end_position_on_the_genomic_accession=70988174, orientation='plus', exon_count=10, OMIM=[609282], no_hdr0=''),
    92609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92609, CurrentID=0, Status='live', Symbol='TIMM50', Aliases=['MGCA9', 'TIM50', 'TIM50L'], description='translocase of inner mitochondrial membrane 50', other_designations='mitochondrial import inner membrane translocase subunit TIM50|Tim50-like protein|homolog of yeast Tim50', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39480838, end_position_on_the_genomic_accession=39493779, orientation='plus', exon_count=11, OMIM=[607381], no_hdr0=''),
    92610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92610, CurrentID=0, Status='live', Symbol='TIFA', Aliases=['T2BP', 'T6BPA', 'TIFA'], description='TRAF interacting protein with forkhead associated domain', other_designations='TRAF-interacting protein with FHA domain-containing protein A|TRAF-interacting protein with a forkhead-associated domain|TRAF2 binding protein|TRAF6 binding protein|putative MAPK-activating protein PM14|putative NF-kappa-B-activating protein 20', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112274537, end_position_on_the_genomic_accession=112285904, orientation='minus', exon_count=2, OMIM=[609028], no_hdr0=''),
    92667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92667, CurrentID=0, Status='live', Symbol='MGME1', Aliases=['C20orf72', 'DDK1', 'MTDPS11', 'bA504H3.4'], description='mitochondrial genome maintenance exonuclease 1', other_designations='mitochondrial genome maintenance exonuclease 1', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17968594, end_position_on_the_genomic_accession=17991122, orientation='plus', exon_count=8, OMIM=[615076], no_hdr0=''),
    92675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92675, CurrentID=0, Status='live', Symbol='DTD1', Aliases=['C20orf88', 'DTD', 'DUE-B', 'DUEB', 'HARS2', 'pqn-68'], description='D-aminoacyl-tRNA deacylase 1', other_designations='D-aminoacyl-tRNA deacylase 1|D-tyrosyl-tRNA deacylase 1 homolog|D-tyrosyl-tRNA(Tyr) deacylase 1|DNA-unwinding element-binding protein B|gly-tRNA(Ala) deacylase|histidyl-tRNA synthase-related|histidyl-tRNA synthetase 2', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18588054, end_position_on_the_genomic_accession=18766644, orientation='plus', exon_count=8, OMIM=[610996], no_hdr0=''),
    92689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92689, CurrentID=0, Status='live', Symbol='FAM114A1', Aliases=['Noxp20'], description='family with sequence similarity 114 member A1', other_designations='protein NOXP20|nervous system over-expressed protein 20', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=38867806, end_position_on_the_genomic_accession=38945739, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    92691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92691, CurrentID=0, Status='live', Symbol='TMEM169', Aliases=[], description='transmembrane protein 169', other_designations='transmembrane protein 169', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=216081919, end_position_on_the_genomic_accession=216102783, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    92703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92703, CurrentID=0, Status='live', Symbol='TMEM183A', Aliases=['C1orf37'], description='transmembrane protein 183A', other_designations='transmembrane protein 183A', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203007374, end_position_on_the_genomic_accession=203024848, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    92714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92714, CurrentID=0, Status='live', Symbol='ARRDC1', Aliases=[], description='arrestin domain containing 1', other_designations='arrestin domain-containing protein 1|alpha-arrestin 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137605641, end_position_on_the_genomic_accession=137615360, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    92715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92715, CurrentID=0, Status='live', Symbol='DPH7', Aliases=['C9orf112', 'RRT2', 'WDR85'], description='diphthamide biosynthesis 7', other_designations='diphthine methyltransferase|WD repeat-containing protein 85', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137554444, end_position_on_the_genomic_accession=137578925, orientation='minus', exon_count=13, OMIM=[613210], no_hdr0=''),
    92736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92736, CurrentID=0, Status='live', Symbol='OTOP2', Aliases=[], description='otopetrin 2', other_designations='proton channel OTOP2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74922955, end_position_on_the_genomic_accession=74933913, orientation='plus', exon_count=8, OMIM=[607827], no_hdr0=''),
    92737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92737, CurrentID=0, Status='live', Symbol='DNER', Aliases=['UNQ26', 'bet'], description='delta/notch like EGF repeat containing', other_designations='delta and Notch-like epidermal growth factor-related receptor|H_NH0150O02.1|WUGSC:H_NH0150O02.1|delta-notch-like EGF repeat-containing transmembrane', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=229357629, end_position_on_the_genomic_accession=229714555, orientation='minus', exon_count=13, OMIM=[607299], no_hdr0=''),
    92745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92745, CurrentID=0, Status='live', Symbol='SLC38A5', Aliases=['JM24', 'SN2', 'SNAT5', 'pp7194'], description='solute carrier family 38 member 5', other_designations='sodium-coupled neutral amino acid transporter 5|solute carrier family 38 (amino acid transporter), member 5|system N transporter 2|transport system N, protein 2', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48458544, end_position_on_the_genomic_accession=48470260, orientation='minus', exon_count=20, OMIM=[300649], no_hdr0=''),
    92747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92747, CurrentID=0, Status='live', Symbol='BPIFB1', Aliases=['C20orf114', 'LPLUNC1'], description='BPI fold containing family B member 1', other_designations='BPI fold-containing family B member 1|VEMSGP|long palate, lung and nasal epithelium carcinoma associated 1|long palate, lung and nasal epithelium carcinoma-associated protein 1|von Ebner minor salivary gland protein', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33273550, end_position_on_the_genomic_accession=33309871, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    92749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92749, CurrentID=0, Status='live', Symbol='DRC1', Aliases=['C2orf39', 'CCDC164', 'CILD21'], description='dynein regulatory complex subunit 1', other_designations='dynein regulatory complex protein 1|coiled-coil domain-containing protein 164', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26401920, end_position_on_the_genomic_accession=26456713, orientation='plus', exon_count=17, OMIM=[615288], no_hdr0=''),
    92797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92797, CurrentID=0, Status='live', Symbol='HELB', Aliases=['DHB', 'hDHB'], description='DNA helicase B', other_designations='DNA helicase B|helicase (DNA) B', map_location='12q', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66302493, end_position_on_the_genomic_accession=66343643, orientation='plus', exon_count=14, OMIM=[614539], no_hdr0=''),
    92799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92799, CurrentID=0, Status='live', Symbol='SHKBP1', Aliases=['PP203', 'Sb1'], description='SH3KBP1 binding protein 1', other_designations='SH3KBP1-binding protein 1|SETA-binding protein 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40576864, end_position_on_the_genomic_accession=40591399, orientation='plus', exon_count=18, OMIM=[617322], no_hdr0=''),
    92815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92815, CurrentID=0, Status='live', Symbol='H2AW', Aliases=['HIST3H2A'], description='H2A.W histone', other_designations='histone H2A type 3|histone 3, H2a|histone cluster 3 H2A|histone cluster 3, H2a', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228457364, end_position_on_the_genomic_accession=228457873, orientation='minus', exon_count=1, OMIM=[615015], no_hdr0=''),
    92822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92822, CurrentID=0, Status='live', Symbol='ZNF276', Aliases=['CENP-Z', 'CENPZ', 'ZADT', 'ZFP276', 'ZNF477'], description='zinc finger protein 276', other_designations='zinc finger protein 276|centromere protein Z|zinc finger protein 276 homolog|zinc finger protein 477|zinc finger, AD-type', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89720368, end_position_on_the_genomic_accession=89740925, orientation='plus', exon_count=14, OMIM=[608460], no_hdr0=''),
    92840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92840, CurrentID=0, Status='live', Symbol='REEP6', Aliases=['C19orf32', 'DP1L1.1', 'REEP6.2', 'RP77', 'TB2L1', 'Yip2f', 'REEP6'], description='receptor accessory protein 6', other_designations='receptor expression-enhancing protein 6|deleted in polyposis 1-like 1|polyposis locus protein 1-like 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1491181, end_position_on_the_genomic_accession=1497927, orientation='plus', exon_count=6, OMIM=[609346], no_hdr0=''),
    92856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92856, CurrentID=0, Status='live', Symbol='IMP4', Aliases=['BXDC4'], description='IMP U3 small nucleolar ribonucleoprotein 4', other_designations='U3 small nucleolar ribonucleoprotein protein IMP4|IMP4 homolog, U3 small nucleolar ribonucleoprotein|IMP4, U3 small nucleolar ribonucleoprotein, homolog|U3 snoRNP protein 4 homolog|U3 snoRNP protein IMP4|brix domain-containing protein 4', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130342242, end_position_on_the_genomic_accession=130347967, orientation='plus', exon_count=9, OMIM=[612981], no_hdr0=''),
    92906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92906, CurrentID=0, Status='live', Symbol='HNRNPLL', Aliases=['HNRPLL', 'SRRF'], description='heterogeneous nuclear ribonucleoprotein L like', other_designations='heterogeneous nuclear ribonucleoprotein L-like|stromal RNA regulating factor', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38561969, end_position_on_the_genomic_accession=38603035, orientation='minus', exon_count=15, OMIM=[611208], no_hdr0=''),
    92912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92912, CurrentID=0, Status='live', Symbol='UBE2Q2', Aliases=[], description='ubiquitin conjugating enzyme E2 Q2', other_designations='ubiquitin-conjugating enzyme E2 Q2|E2 ubiquitin-conjugating enzyme Q2|ubiquitin carrier protein Q2|ubiquitin conjugating enzyme E2Q family member 2|ubiquitin-protein ligase Q2', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75843343, end_position_on_the_genomic_accession=75901078, orientation='plus', exon_count=17, OMIM=[612501], no_hdr0=''),
    92922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92922, CurrentID=0, Status='live', Symbol='CCDC102A', Aliases=[], description='coiled-coil domain containing 102A', other_designations='coiled-coil domain-containing protein 102A', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57512178, end_position_on_the_genomic_accession=57538305, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    92935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92935, CurrentID=0, Status='live', Symbol='MARS2', Aliases=['COXPD25', 'MetRS', 'mtMetRS'], description='methionyl-tRNA synthetase 2, mitochondrial', other_designations='methionine--tRNA ligase, mitochondrial|methionine tRNA ligase 2, mitochondrial|methionine--tRNA ligase 2|methionine-tRNA synthetase 2, mitochondrial', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197705369, end_position_on_the_genomic_accession=197708395, orientation='plus', exon_count=1, OMIM=[609728], no_hdr0=''),
    92949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92949, CurrentID=0, Status='live', Symbol='ADAMTSL1', Aliases=['ADAMTSL-1', 'ADAMTSR1', 'C9orf94', 'PUNCTIN'], description='ADAMTS like 1', other_designations='ADAMTS-like protein 1|ADAM-TS related protein 1|punctin-1', map_location='9p22.2-p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=17906515, end_position_on_the_genomic_accession=18910950, orientation='plus', exon_count=39, OMIM=[609198], no_hdr0=''),
    92960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92960, CurrentID=0, Status='live', Symbol='PEX11G', Aliases=[], description='peroxisomal biogenesis factor 11 gamma', other_designations='peroxisomal membrane protein 11C|PEX11-gamma|Pex11pgamma|peroxin Pex11p gamma|peroxin-11C|peroxisomal biogenesis factor 11C|peroxisomal biogenesis factor 11G|protein PEX11 homolog gamma', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7476875, end_position_on_the_genomic_accession=7494977, orientation='minus', exon_count=12, OMIM=[607583], no_hdr0=''),
    92979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92979, CurrentID=0, Status='live', Symbol='MARCHF9', Aliases=['MARCH-IX', 'MARCH9', 'RNF179'], description='membrane associated ring-CH-type finger 9', other_designations='E3 ubiquitin-protein ligase MARCHF9|E3 ubiquitin-protein ligase MARCH9|RING finger protein 179|RING-type E3 ubiquitin transferase MARCH9|RING-type E3 ubiquitin transferase MARCHF9|membrane associated ring finger 9|membrane-associated RING finger protein 9|membrane-associated RING-CH protein IX|membrane-associated ring finger (C3HC4) 9', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57755103, end_position_on_the_genomic_accession=57760411, orientation='plus', exon_count=4, OMIM=[613336], no_hdr0=''),
    92999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=92999, CurrentID=0, Status='live', Symbol='ZBTB47', Aliases=['ZNF651'], description='zinc finger and BTB domain containing 47', other_designations='zinc finger and BTB domain-containing protein 47|zinc finger protein 651', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42653697, end_position_on_the_genomic_accession=42667580, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    93010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93010, CurrentID=0, Status='live', Symbol='B3GNT7', Aliases=['beta3GnT7'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 7', other_designations='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 7|BGnT-7|beta 1,3-N-acetylglucosaminyltransferase 7|beta-1,3-Gn-T7|beta3Gn-T7', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231395710, end_position_on_the_genomic_accession=231401164, orientation='plus', exon_count=3, OMIM=[615313], no_hdr0=''),
    93034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93034, CurrentID=0, Status='live', Symbol='NT5C1B', Aliases=['AIRP', 'CN-IB', 'CN1B'], description="5'-nucleotidase, cytosolic IB", other_designations="cytosolic 5'-nucleotidase 1B|autoimmune infertility-related protein|testicular tissue protein Li 1", map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=18562871, end_position_on_the_genomic_accession=18589569, orientation='minus', exon_count=10, OMIM=[610526], no_hdr0=''),
    93035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93035, CurrentID=0, Status='live', Symbol='PKHD1L1', Aliases=['PKHDL1'], description='PKHD1 like 1', other_designations='fibrocystin-L|PKHD1-like protein 1|polycystic kidney and hepatic disease 1 (autosomal recessive)-like 1|polycystic kidney and hepatic disease 1-like protein 1|polycystic kidney and hepatic disease-like 1', map_location='8q23.1-q23.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=109362461, end_position_on_the_genomic_accession=109537207, orientation='plus', exon_count=79, OMIM=[607843], no_hdr0=''),
    93058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93058, CurrentID=0, Status='live', Symbol='COQ10A', Aliases=[], description='coenzyme Q10A', other_designations='coenzyme Q-binding protein COQ10 homolog A, mitochondrial|coenzyme Q10 homolog A', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56266942, end_position_on_the_genomic_accession=56270966, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    93081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93081, CurrentID=0, Status='live', Symbol='TEX30', Aliases=['C13orf27'], description='testis expressed 30', other_designations='testis-expressed protein 30|testis-expressed sequence 30 protein', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102765888, end_position_on_the_genomic_accession=102773792, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    93082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93082, CurrentID=0, Status='live', Symbol='NEURL3', Aliases=['LINCR', 'RNF132'], description='neuralized E3 ubiquitin protein ligase 3', other_designations='E3 ubiquitin-protein ligase NEURL3|RING-type E3 ubiquitin transferase NEURL3|lung-inducible neuralized-related C3CH4 RING domain protein|neuralized homolog 3 pseudogene|neuralized-like protein 3', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96497643, end_position_on_the_genomic_accession=96508157, orientation='minus', exon_count=7, OMIM=[617206], no_hdr0=''),
    93099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93099, CurrentID=0, Status='live', Symbol='DMKN', Aliases=['UNQ729', 'ZD52F10'], description='dermokine', other_designations='dermokine|epidermis-specific secreted protein SK30/SK89', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35497220, end_position_on_the_genomic_accession=35513678, orientation='minus', exon_count=26, OMIM=[617211], no_hdr0=''),
    93100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93100, CurrentID=0, Status='live', Symbol='NAPRT', Aliases=['NAPRT1', 'PP3856'], description='nicotinate phosphoribosyltransferase', other_designations='nicotinate phosphoribosyltransferase|FHA-HIT-interacting protein|NAPRTase|nicotinate phosphoribosyltransferase domain containing 1|nicotinate phosphoribosyltransferase domain-containing protein 1|nicotinic acid phosphoribosyltransferase', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143574585, end_position_on_the_genomic_accession=143578349, orientation='minus', exon_count=12, OMIM=[611552], no_hdr0=''),
    93107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93107, CurrentID=0, Status='live', Symbol='KCNG4', Aliases=['KV6.3', 'KV6.4'], description='potassium voltage-gated channel modifier subfamily G member 4', other_designations='potassium voltage-gated channel subfamily G member 4|potassium channel, voltage gated modifier subfamily G, member 4|voltage-gated potassium channel Kv6.3|voltage-gated potassium channel subunit Kv6.4', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84218657, end_position_on_the_genomic_accession=84240012, orientation='minus', exon_count=3, OMIM=[607603], no_hdr0=''),
    93109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93109, CurrentID=0, Status='live', Symbol='TMEM44', Aliases=[], description='transmembrane protein 44', other_designations='transmembrane protein 44', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194587678, end_position_on_the_genomic_accession=194633419, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    93129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93129, CurrentID=0, Status='live', Symbol='ORAI3', Aliases=['TMEM142C'], description='ORAI calcium release-activated calcium modulator 3', other_designations='protein orai-3|transmembrane protein 142C', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30949068, end_position_on_the_genomic_accession=30954938, orientation='plus', exon_count=2, OMIM=[610930], no_hdr0=''),
    93134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93134, CurrentID=0, Status='live', Symbol='ZNF561', Aliases=[], description='zinc finger protein 561', other_designations='zinc finger protein 561', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9607326, end_position_on_the_genomic_accession=9621249, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    93145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93145, CurrentID=0, Status='live', Symbol='OLFM2', Aliases=['NOE2', 'NOELIN2', 'NOELIN2_V1', 'OlfC'], description='olfactomedin 2', other_designations='noelin-2|neuronal olfactomedin related ER localized protein 2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9853718, end_position_on_the_genomic_accession=9936515, orientation='minus', exon_count=8, OMIM=[617492], no_hdr0=''),
    93166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93166, CurrentID=0, Status='live', Symbol='PRDM6', Aliases=['KMT8C', 'PDA3', 'PRISM'], description='PR/SET domain 6', other_designations='putative histone-lysine N-methyltransferase PRDM6|PR domain 6|PR domain containing 6|PR domain-containing protein 6|PR-domain zinc finger protein 6', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=123089148, end_position_on_the_genomic_accession=123194266, orientation='plus', exon_count=11, OMIM=[616982], no_hdr0=''),
    93183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93183, CurrentID=0, Status='live', Symbol='PIGM', Aliases=['GPI-MT-I'], description='phosphatidylinositol glycan anchor biosynthesis class M', other_designations='GPI mannosyltransferase 1|DPM:GlcN-(acyl-)PI mannosyltransferase|GPI mannosyltransferase I|PIG-M mannosyltransferase|dol-P-Man dependent GPI mannosyltransferase|phosphatidylinositol-glycan biosynthesis class M protein', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160024953, end_position_on_the_genomic_accession=160031990, orientation='minus', exon_count=1, OMIM=[610273], no_hdr0=''),
    93185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93185, CurrentID=0, Status='live', Symbol='IGSF8', Aliases=['CD316', 'CD81P3', 'EWI-2', 'EWI2', 'KCT-4', 'LIR-D1', 'PGRL'], description='immunoglobulin superfamily member 8', other_designations='immunoglobulin superfamily member 8|CD81 partner 3|glu-Trp-Ile EWI motif-containing protein 2|keratinocytes-associated transmembrane protein 4|prostaglandin regulatory-like protein', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160091339, end_position_on_the_genomic_accession=160099442, orientation='minus', exon_count=12, OMIM=[606644], no_hdr0=''),
    93190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93190, CurrentID=0, Status='live', Symbol='C1orf158', Aliases=[], description='chromosome 1 open reading frame 158', other_designations='uncharacterized protein C1orf158', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12746200, end_position_on_the_genomic_accession=12763699, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    93210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93210, CurrentID=0, Status='live', Symbol='PGAP3', Aliases=['AGLA546', 'CAB2', 'PERLD1', 'PP1498', 'hCOS16'], description='post-GPI attachment to proteins phospholipase 3', other_designations='post-GPI attachment to proteins factor 3|COS16 homolog|gene coamplified with ERBB2 protein|per1-like domain containing 1|post-GPI attachment to proteins 3', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39671122, end_position_on_the_genomic_accession=39688057, orientation='minus', exon_count=8, OMIM=[611801], no_hdr0=''),
    93233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93233, CurrentID=0, Status='live', Symbol='ODAD1', Aliases=['CCDC114', 'CILD20'], description='outer dynein arm docking complex subunit 1', other_designations='outer dynein arm-docking complex subunit 1|coiled-coil domain containing 114|coiled-coil domain-containing protein 114', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48296452, end_position_on_the_genomic_accession=48321971, orientation='minus', exon_count=17, OMIM=[615038], no_hdr0=''),
    93273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93273, CurrentID=0, Status='live', Symbol='LEMD1', Aliases=['CT50', 'LEMP-1'], description='LEM domain containing 1', other_designations='LEM domain-containing protein 1|LEM domain protein 1|cancer/testis antigen 50', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205381378, end_position_on_the_genomic_accession=205449956, orientation='minus', exon_count=11, OMIM=[610480], no_hdr0=''),
    93323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93323, CurrentID=0, Status='live', Symbol='HAUS8', Aliases=['DGT4', 'HICE1', 'NY-SAR-48'], description='HAUS augmin like complex subunit 8', other_designations='HAUS augmin-like complex subunit 8|HEC1/NDC80 interacting, centrosome associated 1|HEC1/NDC80-interacting centrosome-associated protein 1|Hec1-interacting and centrosome-associated 1|sarcoma antigen NY-SAR-48', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17049729, end_position_on_the_genomic_accession=17075606, orientation='minus', exon_count=11, OMIM=[613434], no_hdr0=''),
    93343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93343, CurrentID=0, Status='live', Symbol='MVB12A', Aliases=['CFBP', 'FAM125A'], description='multivesicular body subunit 12A', other_designations='multivesicular body subunit 12A|CIN85/CD2AP family binding protein|ESCRT-I complex subunit MVB12A|family with sequence similarity 125, member A', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17405741, end_position_on_the_genomic_accession=17425332, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    93349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93349, CurrentID=0, Status='live', Symbol='SP140L', Aliases=[], description='SP140 nuclear body protein like', other_designations='nuclear body protein SP140-like protein|SP140L-1 protein|SP140L-2 protein|SP140L-3 protein', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230327152, end_position_on_the_genomic_accession=230407506, orientation='plus', exon_count=21, OMIM=[617747], no_hdr0=''),
    93377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93377, CurrentID=0, Status='live', Symbol='OPALIN', Aliases=['HTMP10', 'TMEM10', 'TMP10'], description='oligodendrocytic myelin paranodal and inner loop protein', other_designations='opalin|transmembrane protein 10|transmembrane protein TMP10', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96343221, end_position_on_the_genomic_accession=96359002, orientation='minus', exon_count=8, OMIM=[617200], no_hdr0=''),
    93380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93380, CurrentID=0, Status='live', Symbol='MMGT1', Aliases=['EMC5', 'TMEM32'], description='membrane magnesium transporter 1', other_designations='ER membrane protein complex subunit 5|transmembrane protein 32', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135960588, end_position_on_the_genomic_accession=135973988, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    93408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93408, CurrentID=0, Status='live', Symbol='MYL10', Aliases=['MYLC2PL', 'PLRLC'], description='myosin light chain 10', other_designations='myosin regulatory light chain 10|myosin light chain 2, lymphocyte-specific|myosin light chain 2, precursor lymphocyte-specific|myosin, light chain 10, regulatory|precursor lymphocyte-specific regulatory light chain', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101613330, end_position_on_the_genomic_accession=101629296, orientation='minus', exon_count=9, OMIM=[617177], no_hdr0=''),
    93426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93426, CurrentID=0, Status='live', Symbol='SYCE1', Aliases=['C10orf94', 'CT76', 'POF12', 'SPGF15'], description='synaptonemal complex central element protein 1', other_designations='synaptonemal complex central element protein 1|cancer/testis antigen 76|epididymis secretory sperm binding protein', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133553899, end_position_on_the_genomic_accession=133568291, orientation='minus', exon_count=15, OMIM=[611486], no_hdr0=''),
    93432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93432, CurrentID=0, Status='live', Symbol='MGAM2', Aliases=[], description='maltase-glucoamylase 2 (putative)', other_designations='putative maltase-glucoamylase-like protein FLJ16351|Putative maltase-glucoamylase-like protein FLJ16351|maltase-glucoamylase (alpha-glucosidase)', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142111703, end_position_on_the_genomic_accession=142223733, orientation='plus', exon_count=49, OMIM=[], no_hdr0=''),
    93436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93436, CurrentID=0, Status='live', Symbol='ARMC6', Aliases=['R30923_1'], description='armadillo repeat containing 6', other_designations='armadillo repeat-containing protein 6', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19033603, end_position_on_the_genomic_accession=19058176, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    93474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93474, CurrentID=0, Status='live', Symbol='ZNF670', Aliases=[], description='zinc finger protein 670', other_designations='zinc finger protein 670', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247034637, end_position_on_the_genomic_accession=247078811, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    93487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93487, CurrentID=0, Status='live', Symbol='MAPK1IP1L', Aliases=['C14orf32', 'MISS', 'c14_5346'], description='mitogen-activated protein kinase 1 interacting protein 1 like', other_designations='MAPK-interacting and spindle-stabilizing protein-like|MAPK-interacting and spindle-stabilizing protein', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55051647, end_position_on_the_genomic_accession=55070194, orientation='plus', exon_count=5, OMIM=[617226], no_hdr0=''),
    93492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93492, CurrentID=0, Status='live', Symbol='TPTE2', Aliases=['TPIP'], description='transmembrane phosphoinositide 3-phosphatase and tensin homolog 2', other_designations='phosphatidylinositol 3,4,5-trisphosphate 3-phosphatase TPTE2|PTEN-like inositol lipid phosphatase|TPIP lipid phosphatase|TPTE and PTEN homologous inositol lipid phosphatase|lipid phosphatase TPIP|transmembrane phosphoinositide 3-phosphatase and tensin 2-like protein', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=19422877, end_position_on_the_genomic_accession=19561574, orientation='minus', exon_count=26, OMIM=[606791], no_hdr0=''),
    93517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93517, CurrentID=0, Status='live', Symbol='SDR42E1', Aliases=['HSPC105'], description='short chain dehydrogenase/reductase family 42E, member 1', other_designations='short-chain dehydrogenase/reductase family 42E member 1', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81988855, end_position_on_the_genomic_accession=82011526, orientation='minus', exon_count=5, OMIM=[616164], no_hdr0=''),
    93550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93550, CurrentID=0, Status='live', Symbol='ZFAND4', Aliases=['ANUBL1'], description='zinc finger AN1-type containing 4', other_designations='AN1-type zinc finger protein 4|AN1, ubiquitin-like, homolog|AN1-type zinc finger and ubiquitin domain-containing protein 1|AN1-type zinc finger and ubiquitin domain-containing protein-like 1|zinc finger, AN1-type domain 4', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45614567, end_position_on_the_genomic_accession=45672962, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    93587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93587, CurrentID=0, Status='live', Symbol='TRMT10A', Aliases=['HEL-S-88', 'MSSGM', 'MSSGM1', 'RG9MTD2', 'TRM10'], description='tRNA methyltransferase 10A', other_designations='tRNA methyltransferase 10 homolog A|RNA (guanine-9-)-methyltransferase domain-containing protein 2|epididymis secretory protein Li 88|tRNA (guanine(9)-N(1))-methyltransferase TRMT10A', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99546711, end_position_on_the_genomic_accession=99564039, orientation='minus', exon_count=9, OMIM=[616013], no_hdr0=''),
    93589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93589, CurrentID=0, Status='live', Symbol='CACNA2D4', Aliases=['RCD4'], description='calcium voltage-gated channel auxiliary subunit alpha2delta 4', other_designations='voltage-dependent calcium channel subunit alpha-2/delta-4|calcium channel, voltage-dependent, alpha 2/delta subunit 4|voltage-gated calcium channel alpha(2)delta-4 subunit|voltage-gated calcium channel subunit alpha-2/delta-4', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1791963, end_position_on_the_genomic_accession=1922606, orientation='minus', exon_count=38, OMIM=[608171], no_hdr0=''),
    93594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93594, CurrentID=0, Status='live', Symbol='TBC1D31', Aliases=['Gm85', 'WDR67'], description='TBC1 domain family member 31', other_designations='TBC1 domain family member 31|WD repeat domain 67|WD repeat-containing protein 67', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123041961, end_position_on_the_genomic_accession=123165173, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    93611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93611, CurrentID=0, Status='live', Symbol='FBXO44', Aliases=['FBG3', 'FBX30', 'FBX6A', 'Fbx44', 'Fbxo6a'], description='F-box protein 44', other_designations='F-box only protein 44|F-box gene 3|F-box protein FBX30|F-box/G-domain protein 3', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11654375, end_position_on_the_genomic_accession=11663327, orientation='plus', exon_count=9, OMIM=[609111], no_hdr0=''),
    93621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93621, CurrentID=0, Status='live', Symbol='MRFAP1', Aliases=['PAM14', 'PGR1'], description='Morf4 family associated protein 1', other_designations='MORF4 family-associated protein 1|Mof4 family associated protein 1|T-cell activation protein|protein associated with MRG of 14 kDa', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6640685, end_position_on_the_genomic_accession=6642729, orientation='plus', exon_count=2, OMIM=[616905], no_hdr0=''),
    93624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93624, CurrentID=0, Status='live', Symbol='TADA2B', Aliases=['ADA2(beta)', 'ADA2B'], description='transcriptional adaptor 2B', other_designations='transcriptional adapter 2-beta|ADA2-beta|ADA2-like protein beta|transcriptional adaptor 2 (ADA2 homolog, yeast)-beta', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7043372, end_position_on_the_genomic_accession=7057952, orientation='plus', exon_count=3, OMIM=[608790], no_hdr0=''),
    93627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93627, CurrentID=0, Status='live', Symbol='TBCK', Aliases=['HSPC302', 'IHPRF3L', 'TBCK'], description='TBC1 domain containing kinase', other_designations='TBC domain-containing protein kinase-like protein', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=106041599, end_position_on_the_genomic_accession=106316683, orientation='minus', exon_count=34, OMIM=[616899], no_hdr0=''),
    93643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93643, CurrentID=0, Status='live', Symbol='TJAP1', Aliases=['PILT', 'TJP4'], description='tight junction associated protein 1', other_designations='tight junction-associated protein 1|protein incorporated later into tight junctions|tight junction associated protein 1 (peripheral)|tight junction protein 4 (peripheral)', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43477523, end_position_on_the_genomic_accession=43506556, orientation='plus', exon_count=15, OMIM=[612658], no_hdr0=''),
    93649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93649, CurrentID=0, Status='live', Symbol='MYOCD', Aliases=['MGBL', 'MYCD'], description='myocardin', other_designations='myocardin', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=12665890, end_position_on_the_genomic_accession=12768949, orientation='plus', exon_count=15, OMIM=[606127], no_hdr0=''),
    93650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93650, CurrentID=0, Status='live', Symbol='ACP4', Aliases=['ACPT', 'AI1J'], description='acid phosphatase 4', other_designations='testicular acid phosphatase|acid phosphatase, testicular', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50790415, end_position_on_the_genomic_accession=50795219, orientation='plus', exon_count=11, OMIM=[606362], no_hdr0=''),
    93659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93659, CurrentID=0, Status='live', Symbol='CGB5', Aliases=['CGB', 'HCG', 'hCGB'], description='chorionic gonadotropin subunit beta 5', other_designations='chorionic gonadotropin, beta polypeptide 5|chorionic gonadotropin beta 5 subunit|chorionic gonadotropin beta subunit 5', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49043848, end_position_on_the_genomic_accession=49045311, orientation='plus', exon_count=3, OMIM=[608825], no_hdr0=''),
    93661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93661, CurrentID=0, Status='live', Symbol='CAPZA3', Aliases=['CAPPA3', 'Gsg3', 'HEL-S-86'], description='capping actin protein of muscle Z-line subunit alpha 3', other_designations='F-actin-capping protein subunit alpha-3|CP-alpha-3|CapZ alpha-3|F-actin capping protein alpha-3 subunit|capping actin protein of muscle Z-line alpha subunit 3|capping protein (actin filament) muscle Z-line, alpha 3|epididymis secretory protein Li 86|germ cell-specific protein 3|testis tissue sperm-binding protein Li 73n', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=18738119, end_position_on_the_genomic_accession=18739188, orientation='plus', exon_count=1, OMIM=[608722], no_hdr0=''),
    93663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93663, CurrentID=0, Status='live', Symbol='ARHGAP18', Aliases=['MacGAP', 'SENEX', 'bA307O14.2'], description='Rho GTPase activating protein 18', other_designations='rho GTPase-activating protein 18|rho-type GTPase-activating protein 18', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=129576132, end_position_on_the_genomic_accession=129710177, orientation='minus', exon_count=15, OMIM=[613351], no_hdr0=''),
    93664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93664, CurrentID=0, Status='live', Symbol='CADPS2', Aliases=['CAPS2'], description='calcium dependent secretion activator 2', other_designations='calcium-dependent secretion activator 2|CAPS-2|Ca++-dependent secretion activator 2|Ca2+ dependent secretion activator 2|Ca2+-dependent activator protein for secretion 2|calcium-dependent activator protein for secretion 2', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122318411, end_position_on_the_genomic_accession=122886500, orientation='minus', exon_count=34, OMIM=[609978], no_hdr0=''),
    93953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93953, CurrentID=0, Status='live', Symbol='GCNA', Aliases=['ACRC', 'NAAR1'], description='germ cell nuclear acidic peptidase', other_designations='acidic repeat-containing protein|acidic repeat containing|germ cell nuclear antigen|putative nuclear protein', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71578041, end_position_on_the_genomic_accession=71613583, orientation='plus', exon_count=17, OMIM=[300369], no_hdr0=''),
    93973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93973, CurrentID=0, Status='live', Symbol='ACTR8', Aliases=['ARP8', 'INO80N', 'hArp8'], description='actin related protein 8', other_designations='actin-related protein 8|ARP8 actin related protein 8 homolog|INO80 complex subunit N', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=53858992, end_position_on_the_genomic_accession=53882160, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    93974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93974, CurrentID=0, Status='live', Symbol='ATP5IF1', Aliases=['ATPI', 'ATPIF1', 'ATPIP', 'IP'], description='ATP synthase inhibitory factor subunit 1', other_designations='ATPase inhibitor, mitochondrial|ATP synthase F1 subunit epsilon|ATP synthase inhibitor protein|ATPase inhibitor protein|ATPase inhibitory factor 1|IF(1)|IF1|inhibitor of F(1)F(o)-ATPase', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28236124, end_position_on_the_genomic_accession=28238100, orientation='plus', exon_count=3, OMIM=[614981], no_hdr0=''),
    93978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93978, CurrentID=0, Status='live', Symbol='CLEC6A', Aliases=['CLEC4N', 'CLECSF10', 'dectin-2', 'hDECTIN-2'], description='C-type lectin domain containing 6A', other_designations='C-type lectin domain family 6 member A|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 10|C-type lectin superfamily member 10|DC-associated C-type lectin 2|dectin 2|dendritic cell-associated C-type lectin 2', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8455962, end_position_on_the_genomic_accession=8478330, orientation='plus', exon_count=6, OMIM=[613579], no_hdr0=''),
    93979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93979, CurrentID=0, Status='live', Symbol='CPA5', Aliases=[], description='carboxypeptidase A5', other_designations='carboxypeptidase A5|testicular tissue protein Li 32', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130344791, end_position_on_the_genomic_accession=130368730, orientation='plus', exon_count=14, OMIM=[609561], no_hdr0=''),
    93986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=93986, CurrentID=0, Status='live', Symbol='FOXP2', Aliases=['CAGH44', 'SPCH1', 'TNRC10'], description='forkhead box P2', other_designations='forkhead box protein P2|CAG repeat protein 44|forkhead/winged-helix transcription factor|trinucleotide repeat containing 10|trinucleotide repeat-containing gene 10 protein', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=114086327, end_position_on_the_genomic_accession=114693765, orientation='plus', exon_count=24, OMIM=[605317], no_hdr0=''),
    94005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94005, CurrentID=0, Status='live', Symbol='PIGS', Aliases=['DEE95', 'GPIBD18'], description='phosphatidylinositol glycan anchor biosynthesis class S', other_designations='GPI transamidase component PIG-S|GPI transamidase subunit|phosphatidylinositol glycan, class S|phosphatidylinositol-glycan biosynthesis class S protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28553387, end_position_on_the_genomic_accession=28571524, orientation='minus', exon_count=12, OMIM=[610271], no_hdr0=''),
    94015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94015, CurrentID=0, Status='live', Symbol='TTYH2', Aliases=['C17orf29'], description='tweety family member 2', other_designations='protein tweety homolog 2|hTTY2|tweety homolog 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74213571, end_position_on_the_genomic_accession=74262020, orientation='plus', exon_count=15, OMIM=[608855], no_hdr0=''),
    94025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94025, CurrentID=0, Status='live', Symbol='MUC16', Aliases=['CA125'], description='mucin 16, cell surface associated', other_designations='mucin-16|CA125 ovarian cancer antigen|cancer antigen 125|ovarian cancer-related tumor marker CA125|ovarian carcinoma antigen CA125', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8848840, end_position_on_the_genomic_accession=9010390, orientation='minus', exon_count=88, OMIM=[606154], no_hdr0=''),
    94026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94026, CurrentID=0, Status='live', Symbol='POM121L2', Aliases=['POM121-L', 'POM121L'], description='POM121 transmembrane nucleoporin like 2', other_designations='POM121-like protein 2|OM121 membrane glycoprotein (rat homolog)-like 2|POM121 membrane glycoprotein (rat homolog)-like 2|POM121 membrane glycoprotein-like 2', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27308377, end_position_on_the_genomic_accession=27312273, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    94027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94027, CurrentID=0, Status='live', Symbol='CGB7', Aliases=['CG-beta-a', 'CGB6'], description='chorionic gonadotropin subunit beta 7', other_designations='choriogonadotropin subunit beta 7|chorionic gonadotropin beta 7 subunit|chorionic gonadotropin beta subunit 7|chorionic gonadotropin, beta polypeptide 7', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49054274, end_position_on_the_genomic_accession=49057749, orientation='minus', exon_count=5, OMIM=[608826], no_hdr0=''),
    94030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94030, CurrentID=0, Status='live', Symbol='LRRC4B', Aliases=['HSM', 'LRIG4', 'NGL-3'], description='leucine rich repeat containing 4B', other_designations='leucine-rich repeat-containing protein 4B|leucine-rich repeats and immunoglobulin-like domains 4|netrin-G3 ligand', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50516892, end_position_on_the_genomic_accession=50568435, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    94031 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94031, CurrentID=0, Status='live', Symbol='HTRA3', Aliases=['Prsp', 'Tasp'], description='HtrA serine peptidase 3', other_designations='serine protease HTRA3|high-temperature requirement factor A3|pregnancy-related serine protease|probable serine protease HTRA3', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8269712, end_position_on_the_genomic_accession=8307098, orientation='plus', exon_count=10, OMIM=[608785], no_hdr0=''),
    94032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94032, CurrentID=0, Status='live', Symbol='CAMK2N2', Aliases=['CAM-KIIN', 'CAMKIIN'], description='calcium/calmodulin dependent protein kinase II inhibitor 2', other_designations='calcium/calmodulin-dependent protein kinase II inhibitor 2|CaM-KII inhibitory protein', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184259213, end_position_on_the_genomic_accession=184261553, orientation='minus', exon_count=2, OMIM=[608721], no_hdr0=''),
    94033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94033, CurrentID=0, Status='live', Symbol='FTMT', Aliases=['MTF'], description='ferritin mitochondrial', other_designations='ferritin, mitochondrial|ferritin H subunit|mitochondrial ferritin', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=121851882, end_position_on_the_genomic_accession=121852833, orientation='plus', exon_count=1, OMIM=[608847], no_hdr0=''),
    94039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94039, CurrentID=0, Status='live', Symbol='ZNF101', Aliases=['HZF12'], description='zinc finger protein 101', other_designations='zinc finger protein 101|zinc finger protein 101 (Y2)|zinc finger protein 12|zinc finger protein HZF12', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19668070, end_position_on_the_genomic_accession=19683506, orientation='plus', exon_count=7, OMIM=[603983], no_hdr0=''),
    94056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94056, CurrentID=0, Status='live', Symbol='SYAP1', Aliases=['BSTA', 'PRO3113'], description='synapse associated protein 1', other_designations='synapse-associated protein 1|BSD domain-containing signal transducer and Akt interactor protein|SAP47 homolog|synapse associated protein 1, SAP47 homolog', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16719612, end_position_on_the_genomic_accession=16765340, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    94059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94059, CurrentID=0, Status='live', Symbol='LENG9', Aliases=[], description='leukocyte receptor cluster member 9', other_designations='leukocyte receptor cluster member 9|leukocyte receptor cluster (LRC) member 9', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54461732, end_position_on_the_genomic_accession=54463778, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    94081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94081, CurrentID=0, Status='live', Symbol='SFXN1', Aliases=['SLC56A1', 'TCC'], description='sideroflexin 1', other_designations='sideroflexin-1|tricarboxylate carrier protein', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=175478560, end_position_on_the_genomic_accession=175529742, orientation='plus', exon_count=11, OMIM=[615569], no_hdr0=''),
    94086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94086, CurrentID=0, Status='live', Symbol='HSPB9', Aliases=['CT51'], description='heat shock protein family B (small) member 9', other_designations='heat shock protein beta-9|cancer/testis antigen 51|heat shock protein, alpha-crystallin-related, B9|small heat shock protein B9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42122804, end_position_on_the_genomic_accession=42123352, orientation='plus', exon_count=1, OMIM=[608344], no_hdr0=''),
    94097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94097, CurrentID=0, Status='live', Symbol='SFXN5', Aliases=['BBG-TCC', 'SLC56A5'], description='sideroflexin 5', other_designations='sideroflexin-5', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=72942036, end_position_on_the_genomic_accession=73071712, orientation='minus', exon_count=19, OMIM=[615572], no_hdr0=''),
    94101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94101, CurrentID=0, Status='live', Symbol='ORMDL1', Aliases=[], description='ORMDL sphingolipid biosynthesis regulator 1', other_designations='ORM1-like protein 1|adoplin-1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189763859, end_position_on_the_genomic_accession=189784339, orientation='minus', exon_count=7, OMIM=[610073], no_hdr0=''),
    94103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94103, CurrentID=0, Status='live', Symbol='ORMDL3', Aliases=[], description='ORMDL sphingolipid biosynthesis regulator 3', other_designations='ORM1-like protein 3', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39921041, end_position_on_the_genomic_accession=39927601, orientation='minus', exon_count=7, OMIM=[610075], no_hdr0=''),
    94104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94104, CurrentID=0, Status='live', Symbol='PAXBP1', Aliases=['BM020', 'C21orf66', 'FSAP105', 'GCFC', 'GCFC1'], description='PAX3 and PAX7 binding protein 1', other_designations='PAX3- and PAX7-binding protein 1|GC-rich sequence DNA-binding factor 1|GC-rich sequence DNA-binding factor candidate|functional spliceosome-associated protein 105', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32733899, end_position_on_the_genomic_accession=32771835, orientation='minus', exon_count=20, OMIM=[617621], no_hdr0=''),
    94107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94107, CurrentID=0, Status='live', Symbol='TMEM203', Aliases=['HBEBP1'], description='transmembrane protein 203', other_designations='transmembrane protein 203|HBeAg-binding protein 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137204082, end_position_on_the_genomic_accession=137205648, orientation='minus', exon_count=1, OMIM=[616499], no_hdr0=''),
    94115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94115, CurrentID=0, Status='live', Symbol='CGB8', Aliases=[], description='chorionic gonadotropin subunit beta 8', other_designations='chorionic gonadotropin, beta polypeptide 8|chorionic gonadotropin beta 8 subunit|chorionic gonadotropin beta subunit 8', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49047638, end_position_on_the_genomic_accession=49049111, orientation='minus', exon_count=3, OMIM=[608827], no_hdr0=''),
    94120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94120, CurrentID=0, Status='live', Symbol='SYTL3', Aliases=['SLP3'], description='synaptotagmin like 3', other_designations='synaptotagmin-like protein 3|exophilin-6', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158644867, end_position_on_the_genomic_accession=158766298, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    94121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94121, CurrentID=0, Status='live', Symbol='SYTL4', Aliases=['SLP4'], description='synaptotagmin like 4', other_designations='synaptotagmin-like protein 4|exophilin-2|granuphilin-a', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100671964, end_position_on_the_genomic_accession=100732137, orientation='minus', exon_count=22, OMIM=[300723], no_hdr0=''),
    94122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94122, CurrentID=0, Status='live', Symbol='SYTL5', Aliases=['slp5'], description='synaptotagmin like 5', other_designations='synaptotagmin-like protein 5|exophilin 9', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37888915, end_position_on_the_genomic_accession=38128820, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    94134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94134, CurrentID=0, Status='live', Symbol='ARHGAP12', Aliases=[], description='Rho GTPase activating protein 12', other_designations='rho GTPase-activating protein 12|rho-type GTPase-activating protein 12', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=31805398, end_position_on_the_genomic_accession=31928876, orientation='minus', exon_count=20, OMIM=[610577], no_hdr0=''),
    94137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94137, CurrentID=0, Status='live', Symbol='RP1L1', Aliases=['DCDC4B', 'OCMD', 'RP88'], description='RP1 like 1', other_designations='retinitis pigmentosa 1-like 1 protein|doublecortin domain containing 4B|retinitis pigmentosa 1 like 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10606349, end_position_on_the_genomic_accession=10655143, orientation='minus', exon_count=4, OMIM=[608581], no_hdr0=''),
    94160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94160, CurrentID=0, Status='live', Symbol='ABCC12', Aliases=['MRP9'], description='ATP binding cassette subfamily C member 12', other_designations='ATP-binding cassette sub-family C member 12|ATP-binding cassette transporter sub-family C member 12|ATP-binding cassette, sub-family C (CFTR/MRP), member 12|multidrug resistance-associated protein 9', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=48080882, end_position_on_the_genomic_accession=48155993, orientation='minus', exon_count=31, OMIM=[607041], no_hdr0=''),
    94233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94233, CurrentID=0, Status='live', Symbol='OPN4', Aliases=['MOP'], description='opsin 4', other_designations='melanopsin', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=86653495, end_position_on_the_genomic_accession=86666460, orientation='plus', exon_count=11, OMIM=[606665], no_hdr0=''),
    94234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94234, CurrentID=0, Status='live', Symbol='FOXQ1', Aliases=['HFH1'], description='forkhead box Q1', other_designations='forkhead box protein Q1|HFH-1|HNF-3/forkhead-like protein 1|hepatocyte nuclear factor 3 forkhead homolog 1|winged helix/forkhead transcription factor', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=1312098, end_position_on_the_genomic_accession=1314758, orientation='plus', exon_count=1, OMIM=[612788], no_hdr0=''),
    94235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94235, CurrentID=0, Status='live', Symbol='GNG8', Aliases=[], description='G protein subunit gamma 8', other_designations='guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-8|gamma-9|guanine nucleotide binding protein (G protein), gamma 8', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46633953, end_position_on_the_genomic_accession=46639326, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    94239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94239, CurrentID=0, Status='live', Symbol='H2AZ2', Aliases=['H2A.Z-2', 'H2AFV', 'H2AV'], description='H2A.Z variant histone 2', other_designations='histone H2A.V|H2A histone family member V|H2A.F/Z|histone H2A.F/Z|purine-rich binding element protein B', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44826889, end_position_on_the_genomic_accession=44848126, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    94240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94240, CurrentID=0, Status='live', Symbol='EPSTI1', Aliases=['BRESI1'], description='epithelial stromal interaction 1', other_designations='epithelial-stromal interaction protein 1|epithelial stromal interaction 1 (breast)', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=42886388, end_position_on_the_genomic_accession=42992271, orientation='minus', exon_count=20, OMIM=[607441], no_hdr0=''),
    94241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94241, CurrentID=0, Status='live', Symbol='TP53INP1', Aliases=['SIP', 'TP53DINP1A', 'TP53INP1B', 'Teap', 'p53DINP1', 'TP53INP1'], description='tumor protein p53 inducible nuclear protein 1', other_designations='tumor protein p53-inducible nuclear protein 1|p53-dependent damage-inducible nuclear protein 1|p53-inducible p53DINP1|stress-induced protein', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94925972, end_position_on_the_genomic_accession=94949378, orientation='minus', exon_count=6, OMIM=[606185], no_hdr0=''),
    94274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=94274, CurrentID=0, Status='live', Symbol='PPP1R14A', Aliases=['CPI-17', 'CPI17', 'PPP1INL'], description='protein phosphatase 1 regulatory inhibitor subunit 14A', other_designations='protein phosphatase 1 regulatory subunit 14A|17 kDa PKC-potentiated inhibitory protein of PP1|17-KDa protein|PKC-potentiated inhibitory protein of PP1|protein kinase C-potentiated inhibitor protein of 17 kDa', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38251237, end_position_on_the_genomic_accession=38256374, orientation='minus', exon_count=4, OMIM=[608153], no_hdr0=''),
    95681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=95681, CurrentID=0, Status='live', Symbol='CEP41', Aliases=['JBTS15', 'TSGA14'], description='centrosomal protein 41', other_designations='centrosomal protein of 41 kDa|centrosomal protein 41 kDa|centrosomal protein 41kDa|testis specific protein A14|testis specific, 14|testis-specific gene A14 protein', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130393771, end_position_on_the_genomic_accession=130441057, orientation='minus', exon_count=14, OMIM=[610523], no_hdr0=''),
    96459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=96459, CurrentID=0, Status='live', Symbol='FNIP1', Aliases=[], description='folliculin interacting protein 1', other_designations='folliculin-interacting protein 1', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131641714, end_position_on_the_genomic_accession=131797017, orientation='minus', exon_count=18, OMIM=[610594], no_hdr0=''),
    96626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=96626, CurrentID=0, Status='live', Symbol='LIMS3', Aliases=['LIMS3L', 'LIMS4', 'PINCH-3'], description='LIM zinc finger domain containing 3', other_designations='LIM and senescent cell antigen-like-containing domain protein 3|LIM and senescent cell antigen-like domains 3|LIM and senescent cell antigen-like-containing domain protein 3-like|LIM and senescent cell antigen-like-containing domain protein 4|LIM-type zinc finger domains 3|particularly interesting new Cys-His protein 3|pinch 2', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109898688, end_position_on_the_genomic_accession=109925625, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    96764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=96764, CurrentID=0, Status='live', Symbol='TGS1', Aliases=['NCOA6IP', 'PIMT', 'PIPMT'], description='trimethylguanosine synthase 1', other_designations='trimethylguanosine synthase|CLL-associated antigen KW-2|PRIP-interacting protein with methyltransferase motif|cap-specific guanine-N2 methyltransferase|hepatocellular carcinoma-associated antigen 137|nuclear receptor coactivator 6-interacting protein', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=55773446, end_position_on_the_genomic_accession=55826445, orientation='plus', exon_count=13, OMIM=[606461], no_hdr0=''),
    103910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=103910, CurrentID=0, Status='live', Symbol='MYL12B', Aliases=['MLC-B', 'MRLC2'], description='myosin light chain 12B', other_designations='myosin regulatory light chain 12B|MLC-2|MLC-2A|MLC20|SHUJUN-1|myosin regulatory light chain 2|myosin regulatory light chain 20 kDa|myosin regulatory light chain MRLC2|myosin, light chain 12B, regulatory', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=3262133, end_position_on_the_genomic_accession=3278461, orientation='plus', exon_count=5, OMIM=[609211], no_hdr0=''),
    112398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112398, CurrentID=0, Status='live', Symbol='EGLN2', Aliases=['EIT-6', 'EIT6', 'HIF-PH1', 'HIFPH1', 'HPH-1', 'HPH-3', 'PHD1'], description='egl-9 family hypoxia inducible factor 2', other_designations='prolyl hydroxylase EGLN2|HIF-prolyl hydroxylase 1|egl nine homolog 2|estrogen-induced tag 6|hypoxia-inducible factor prolyl hydroxylase 1|prolyl hydroxylase domain-containing protein 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40799191, end_position_on_the_genomic_accession=40808434, orientation='plus', exon_count=7, OMIM=[606424], no_hdr0=''),
    112399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112399, CurrentID=0, Status='live', Symbol='EGLN3', Aliases=['HIFP4H3', 'HIFPH3', 'PHD3'], description='egl-9 family hypoxia inducible factor 3', other_designations='prolyl hydroxylase EGLN3|HIF-PH3|HIF-prolyl hydroxylase 3|HPH-1|HPH-3|hypoxia-inducible factor prolyl hydroxylase 3|prolyl hydroxylase domain-containing protein 3', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=33924227, end_position_on_the_genomic_accession=33951074, orientation='minus', exon_count=5, OMIM=[606426], no_hdr0=''),
    112464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112464, CurrentID=0, Status='live', Symbol='CAVIN3', Aliases=['HSRBC', 'PRKCDBP', 'SRBC', 'cavin-3'], description='caveolae associated protein 3', other_designations='caveolae-associated protein 3|protein kinase C delta binding protein|sdr-related gene product that binds to c-kinase|serum deprivation response factor-related gene product that binds to C-kinase', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6318946, end_position_on_the_genomic_accession=6320501, orientation='minus', exon_count=2, OMIM=[618303], no_hdr0=''),
    112476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112476, CurrentID=0, Status='live', Symbol='PRRT2', Aliases=['BFIC2', 'BFIS2', 'DSPB3', 'DYT10', 'EKD1', 'FICCA', 'ICCA', 'IFITMD1', 'PKC'], description='proline rich transmembrane protein 2', other_designations='proline-rich transmembrane protein 2|dispanin subfamily B member 3|dystonia 10|infantile convulsions and paroxysmal choreoathetosis|interferon induced transmembrane protein domain containing 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29812193, end_position_on_the_genomic_accession=29815920, orientation='plus', exon_count=2, OMIM=[614386], no_hdr0=''),
    112479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112479, CurrentID=0, Status='live', Symbol='ERI2', Aliases=['EXOD1', 'ZGRF5'], description='ERI1 exoribonuclease family member 2', other_designations='ERI1 exoribonuclease 2|enhanced RNAi three prime mRNA exonuclease homolog 2|exonuclease domain containing 1|exonuclease domain-containing protein 1|exoribonuclease 2|zinc finger, GRF-type containing 5', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20780193, end_position_on_the_genomic_accession=20806472, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    112483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112483, CurrentID=0, Status='live', Symbol='SAT2', Aliases=['SSAT-2', 'SSAT2'], description='spermidine/spermine N1-acetyltransferase family member 2', other_designations='thialysine N-epsilon-acetyltransferase|diamine N-acetyltransferase 2|diamine acetyltransferase 2|polyamine N-acetyltransferase 2|spermidine/spermine N(1)-acetyltransferase 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7626234, end_position_on_the_genomic_accession=7627878, orientation='minus', exon_count=6, OMIM=[611463], no_hdr0=''),
    112487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112487, CurrentID=0, Status='live', Symbol='DTD2', Aliases=['ATD', 'C14orf126'], description='D-aminoacyl-tRNA deacylase 2', other_designations='D-aminoacyl-tRNA deacylase 2|D-tyrosyl-tRNA deacylase 2 (putative)|D-tyrosyl-tRNA(Tyr) deacylase 2|L-alanyl-tRNA deacylase|animalia-specifc tRNA deacylase|animalia-specific tRNA deacylase|probable D-tyrosyl-tRNA(Tyr) deacylase 2|putative D-tyrosyl-tRNA deacylase 2|putative D-tyrosyl-tRNA(Tyr) deacylase 2', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=31446036, end_position_on_the_genomic_accession=31457506, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    112495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112495, CurrentID=0, Status='live', Symbol='GTF3C6', Aliases=['C6orf51', 'TFIIIC35', 'bA397G5.3'], description='general transcription factor IIIC subunit 6', other_designations='general transcription factor 3C polypeptide 6|TFIIIC 35 kDa subunit|general transcription factor IIIC, polypeptide 6, alpha 35kDa|transcription factor IIIC 35 kDa subunit|transcription factor IIIC 35kDa|transcription factor IIIC subunit 6', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110958706, end_position_on_the_genomic_accession=110967872, orientation='plus', exon_count=6, OMIM=[611784], no_hdr0=''),
    112574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112574, CurrentID=0, Status='live', Symbol='SNX18', Aliases=['SH3PX2', 'SH3PXD3B', 'SNAG1'], description='sorting nexin 18', other_designations='sorting nexin-18|SH3 and PX domain-containing protein 3B|sorting nexin associated golgi protein 1|sorting nexin-associated Golgi protein 1', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=54517759, end_position_on_the_genomic_accession=54619249, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    112609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112609, CurrentID=0, Status='live', Symbol='MRAP2', Aliases=['C6orf117', 'bA51G5.2'], description='melanocortin 2 receptor accessory protein 2', other_designations='melanocortin-2 receptor accessory protein 2|MC2R accessory protein 2', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=84032621, end_position_on_the_genomic_accession=84146278, orientation='plus', exon_count=11, OMIM=[615410], no_hdr0=''),
    112611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112611, CurrentID=0, Status='live', Symbol='RWDD2A', Aliases=['RWDD2', 'dJ747H23.2'], description='RWD domain containing 2A', other_designations='RWD domain-containing protein 2A|RWD domain containing 2', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83193355, end_position_on_the_genomic_accession=83198935, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    112616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112616, CurrentID=0, Status='live', Symbol='CMTM7', Aliases=['CKLFSF7'], description='CKLF like MARVEL transmembrane domain containing 7', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 7|chemokine-like factor super family 7|chemokine-like factor super family member 7 variant 2|chemokine-like factor superfamily 7|chemokine-like factor superfamily member 7', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32391825, end_position_on_the_genomic_accession=32455528, orientation='plus', exon_count=6, OMIM=[607890], no_hdr0=''),
    112703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112703, CurrentID=0, Status='live', Symbol='FAM71E1', Aliases=[], description='family with sequence similarity 71 member E1', other_designations='protein FAM71E1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50466643, end_position_on_the_genomic_accession=50476848, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    112714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112714, CurrentID=0, Status='live', Symbol='TUBA3E', Aliases=[], description='tubulin alpha 3e', other_designations='tubulin alpha-3E chain', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130191745, end_position_on_the_genomic_accession=130198439, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    112724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112724, CurrentID=0, Status='live', Symbol='RDH13', Aliases=['SDR7C3'], description='retinol dehydrogenase 13', other_designations='retinol dehydrogenase 13|retinol dehydrogenase 13 (all-trans and 9-cis)|retinol dehydrogenase 13 (all-trans/9-cis)|short chain dehydrogenase/reductase family 7C member 3', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55040375, end_position_on_the_genomic_accession=55069531, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    112744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112744, CurrentID=0, Status='live', Symbol='IL17F', Aliases=['CANDF6', 'IL-17F', 'ML-1', 'ML1'], description='interleukin 17F', other_designations='interleukin-17F|cytokine ML-1', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52236681, end_position_on_the_genomic_accession=52245689, orientation='minus', exon_count=4, OMIM=[606496], no_hdr0=''),
    112752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112752, CurrentID=0, Status='live', Symbol='IFT43', Aliases=['C14orf179', 'CED3', 'RP81', 'SRTD18'], description='intraflagellar transport 43', other_designations='intraflagellar transport protein 43 homolog|IFT complex A subunit|intraflagellar transport 43 homolog', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75985763, end_position_on_the_genomic_accession=76084073, orientation='plus', exon_count=11, OMIM=[614068], no_hdr0=''),
    112755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112755, CurrentID=0, Status='live', Symbol='STX1B', Aliases=['GEFSP91', 'STX1B2', 'STX1B'], description='syntaxin 1B', other_designations='syntaxin-1B|syntaxin-1B1|syntaxin-1B2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30989256, end_position_on_the_genomic_accession=31010638, orientation='minus', exon_count=11, OMIM=[601485], no_hdr0=''),
    112770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112770, CurrentID=0, Status='live', Symbol='GLMP', Aliases=['C1orf85', 'NCU-G1'], description='glycosylated lysosomal membrane protein', other_designations='glycosylated lysosomal membrane protein|kidney lysosomal membrane protein|kidney predominant protein NCU-G1|lysosomal protein NCU-G1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156292688, end_position_on_the_genomic_accession=156295689, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    112802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112802, CurrentID=0, Status='live', Symbol='KRT71', Aliases=['HYPT13', 'K6IRS1', 'KRT6IRS', 'KRT6IRS1'], description='keratin 71', other_designations='keratin, type II cytoskeletal 71|CK-71|K71|cytokeratin-71|hK6irs|hK6irs1|keratin 6 irs|keratin 71, type II|type II inner root sheath-specific keratin-K6irs1|type-II keratin Kb34', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52543909, end_position_on_the_genomic_accession=52553145, orientation='minus', exon_count=9, OMIM=[608245], no_hdr0=''),
    112812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112812, CurrentID=0, Status='live', Symbol='FDX2', Aliases=['FDX1L', 'MEOAL'], description='ferredoxin 2', other_designations='ferredoxin-2, mitochondrial|adrenodoxin-like protein, mitochondrial|ferredoxin 1 like', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10310045, end_position_on_the_genomic_accession=10316015, orientation='minus', exon_count=5, OMIM=[614585], no_hdr0=''),
    112817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112817, CurrentID=0, Status='live', Symbol='HOGA1', Aliases=['C10orf65', 'DHDPS2', 'DHDPSL', 'HP3', 'NPL2'], description='4-hydroxy-2-oxoglutarate aldolase 1', other_designations='4-hydroxy-2-oxoglutarate aldolase, mitochondrial|DHDPS-like protein|N-acetylneuraminate pyruvate lyase 2 (putative)|dihydrodipicolinate synthase-like, mitochondrial|dihydrodipicolinate synthetase homolog 2|probable 2-keto-4-hydroxyglutarate aldolase|probable 4-hydroxy-2-oxoglutarate aldolase, mitochondrial|probable KHG-aldolase|protein 569272', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97584389, end_position_on_the_genomic_accession=97612802, orientation='plus', exon_count=7, OMIM=[613597], no_hdr0=''),
    112840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112840, CurrentID=0, Status='live', Symbol='WDR89', Aliases=['C14orf150', 'MSTP050'], description='WD repeat domain 89', other_designations='WD repeat-containing protein 89', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63597039, end_position_on_the_genomic_accession=63641871, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    112849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112849, CurrentID=0, Status='live', Symbol='L3HYPDH', Aliases=['C14orf149'], description='trans-L-3-hydroxyproline dehydratase', other_designations='trans-3-hydroxy-L-proline dehydratase|L-3-hydroxyproline dehydratase (trans-)|trans-3-hydroxy-l-proline dehydratase|trans-3-hydroxyl-L-proline dehydratase', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59472606, end_position_on_the_genomic_accession=59505266, orientation='minus', exon_count=7, OMIM=[614811], no_hdr0=''),
    112858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112858, CurrentID=0, Status='live', Symbol='TP53RK', Aliases=['BUD32', 'C20orf64', 'GAMOS4', 'Nori-2', 'Nori-2p', 'PRPK', 'TPRKB', 'dJ101A2'], description='TP53 regulating kinase', other_designations='EKC/KEOPS complex subunit TP53RK|atypical serine/threonine protein kinase TP53RK|p53-related protein kinase', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46684365, end_position_on_the_genomic_accession=46689444, orientation='minus', exon_count=2, OMIM=[608679], no_hdr0=''),
    112869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112869, CurrentID=0, Status='live', Symbol='SGF29', Aliases=['CCDC101', 'STAF36', 'TDRD29'], description='SAGA complex associated factor 29', other_designations='SAGA-associated factor 29|SAGA-associated factor 29 homolog|coiled-coil domain containing 101|coiled-coil domain-containing protein 101', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28553915, end_position_on_the_genomic_accession=28591790, orientation='plus', exon_count=11, OMIM=[613374], no_hdr0=''),
    112885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112885, CurrentID=0, Status='live', Symbol='PHF21B', Aliases=['BHC80L', 'PHF4'], description='PHD finger protein 21B', other_designations='PHD finger protein 21B|PHD finger protein 4', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44881162, end_position_on_the_genomic_accession=45010005, orientation='minus', exon_count=17, OMIM=[616727], no_hdr0=''),
    112936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112936, CurrentID=0, Status='live', Symbol='VPS26B', Aliases=['Pep8b'], description='VPS26, retromer complex component B', other_designations='vacuolar protein sorting-associated protein 26B|vesicle protein sorting 26B', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134224664, end_position_on_the_genomic_accession=134247788, orientation='plus', exon_count=7, OMIM=[610027], no_hdr0=''),
    112937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112937, CurrentID=0, Status='live', Symbol='GLB1L3', Aliases=[], description='galactosidase beta 1 like 3', other_designations='beta-galactosidase-1-like protein 3', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=134272716, end_position_on_the_genomic_accession=134325307, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    112939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112939, CurrentID=0, Status='live', Symbol='NACC1', Aliases=['BEND8', 'BTBD14B', 'BTBD30', 'NAC-1', 'NAC1', 'NECFM'], description='nucleus accumbens associated 1', other_designations='nucleus accumbens-associated protein 1|BEN domain containing 8|BTB/POZ domain-containing protein 14B|nucleus accumbens associated 1, BEN and BTB (POZ) domain containing|transcriptional repressor NAC1', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13116848, end_position_on_the_genomic_accession=13141147, orientation='plus', exon_count=8, OMIM=[610672], no_hdr0=''),
    112942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112942, CurrentID=0, Status='live', Symbol='CFAP36', Aliases=['BARTL1', 'CCDC104'], description='cilia and flagella associated protein 36', other_designations='cilia- and flagella-associated protein 36|coiled-coil domain containing 104|coiled-coil domain-containing protein 104', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55519604, end_position_on_the_genomic_accession=55545079, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    112950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112950, CurrentID=0, Status='live', Symbol='MED8', Aliases=['ARC32'], description='mediator complex subunit 8', other_designations='mediator of RNA polymerase II transcription subunit 8|activator-recruited cofactor 32 kDa component|mediator of RNA polymerase II transcription subunit MED8', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43383917, end_position_on_the_genomic_accession=43389800, orientation='minus', exon_count=8, OMIM=[607956], no_hdr0=''),
    112970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112970, CurrentID=0, Status='live', Symbol='KTI12', Aliases=['SBBI81', 'TOT4'], description='KTI12 chromatin associated homolog', other_designations='protein KTI12 homolog|KTI12 homolog, chromatin associated', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52032103, end_position_on_the_genomic_accession=52033810, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    113000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113000, CurrentID=0, Status='live', Symbol='RPUSD1', Aliases=['C16orf40', 'RLUCL'], description='RNA pseudouridine synthase domain containing 1', other_designations='RNA pseudouridylate synthase domain-containing protein 1|RNA pseudouridylate synthase domain containing 1|ribosomal large subunit pseudouridine synthase C-like protein', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=784974, end_position_on_the_genomic_accession=788381, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    113026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113026, CurrentID=0, Status='live', Symbol='PLCD3', Aliases=['PLC-delta-3'], description='phospholipase C delta 3', other_designations='1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase delta-3|1-phosphatidylinositol-4,5-bisphosphate phosphodiesterase delta-3|PLC delta3|phosphoinositide phospholipase C-delta-3', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45108959, end_position_on_the_genomic_accession=45132524, orientation='minus', exon_count=16, OMIM=[608795], no_hdr0=''),
    113091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113091, CurrentID=0, Status='live', Symbol='PTH2', Aliases=['TIP39'], description='parathyroid hormone 2', other_designations='tuberoinfundibular peptide of 39 residues|tuberoinfundibular 39 residue protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49422419, end_position_on_the_genomic_accession=49423441, orientation='minus', exon_count=2, OMIM=[608386], no_hdr0=''),
    113115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113115, CurrentID=0, Status='live', Symbol='MTFR2', Aliases=['DUFD1', 'FAM54A'], description='mitochondrial fission regulator 2', other_designations='mitochondrial fission regulator 2|DUF729 domain-containing protein 1|family with sequence similarity 54, member A', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136231030, end_position_on_the_genomic_accession=136253659, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    113130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113130, CurrentID=0, Status='live', Symbol='CDCA5', Aliases=['SORORIN'], description='cell division cycle associated 5', other_designations='sororin|cell division cycle-associated protein 5|p35', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65061009, end_position_on_the_genomic_accession=65084129, orientation='minus', exon_count=16, OMIM=[609374], no_hdr0=''),
    113146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113146, CurrentID=0, Status='live', Symbol='AHNAK2', Aliases=['C14orf78'], description='AHNAK nucleoprotein 2', other_designations='protein AHNAK2', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104937253, end_position_on_the_genomic_accession=104978374, orientation='minus', exon_count=9, OMIM=[608570], no_hdr0=''),
    113174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113174, CurrentID=0, Status='live', Symbol='SAAL1', Aliases=['SPACIA1'], description='serum amyloid A like 1', other_designations='protein SAAL1|synoviocyte proliferation-associated in collagen-induced arthritis 1|synoviocyte proliferation-associated in collagen-induced arthritis protein 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18080292, end_position_on_the_genomic_accession=18106082, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    113177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113177, CurrentID=0, Status='live', Symbol='IZUMO4', Aliases=['C19orf36', 'IMAGE:4215339'], description='IZUMO family member 4', other_designations='izumo sperm-egg fusion protein 4|putative SAMP14 binding protein variant 1|putative SAMP14 binding protein variant 2|sperm 22 kDa protein c113', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2096669, end_position_on_the_genomic_accession=2099590, orientation='plus', exon_count=8, OMIM=[618897], no_hdr0=''),
    113178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113178, CurrentID=0, Status='live', Symbol='SCAMP4', Aliases=['SCAMP-4'], description='secretory carrier membrane protein 4', other_designations='secretory carrier-associated membrane protein 4', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1905399, end_position_on_the_genomic_accession=1926013, orientation='plus', exon_count=7, OMIM=[613764], no_hdr0=''),
    113179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113179, CurrentID=0, Status='live', Symbol='ADAT3', Aliases=['FWP005', 'MRT36', 'MST121', 'MSTP121', 'S863-5', 'TAD3'], description='adenosine deaminase tRNA specific 3', other_designations='probable inactive tRNA-specific adenosine deaminase-like protein 3|adenosine deaminase, tRNA-specific 3, TAD3 homolog|tRNA-specific adenosine-34 deaminase subunit ADAT3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1905399, end_position_on_the_genomic_accession=1913447, orientation='plus', exon_count=2, OMIM=[615302], no_hdr0=''),
    113189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113189, CurrentID=0, Status='live', Symbol='CHST14', Aliases=['ATCS', 'D4ST1', 'EDSMC1', 'HNK1ST'], description='carbohydrate sulfotransferase 14', other_designations='carbohydrate sulfotransferase 14|carbohydrate (N-acetylgalactosamine 4-0) sulfotransferase 14|carbohydrate (dermatan 4) sulfotransferase 14|dermatan 4 sulfotransferase 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40470984, end_position_on_the_genomic_accession=40473158, orientation='plus', exon_count=1, OMIM=[608429], no_hdr0=''),
    113201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113201, CurrentID=0, Status='live', Symbol='GOLM2', Aliases=['CASC4', 'H63'], description='golgi membrane protein 2', other_designations='protein GOLM2|cancer susceptibility 4|cancer susceptibility candidate 4|cancer susceptibility candidate gene 4 protein|gene associated with HER-2/neu overexpression|protein CASC4', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44288709, end_position_on_the_genomic_accession=44415758, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    113220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113220, CurrentID=0, Status='live', Symbol='KIF12', Aliases=[], description='kinesin family member 12', other_designations='kinesin-like protein KIF12', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114091623, end_position_on_the_genomic_accession=114100090, orientation='minus', exon_count=20, OMIM=[611278], no_hdr0=''),
    113230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113230, CurrentID=0, Status='live', Symbol='MISP3', Aliases=[], description='MISP family member 3', other_designations='uncharacterized protein MISP3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14072786, end_position_on_the_genomic_accession=14075062, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    113235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113235, CurrentID=0, Status='live', Symbol='SLC46A1', Aliases=['G21', 'HCP1', 'PCFT'], description='solute carrier family 46 member 1', other_designations='proton-coupled folate transporter|heme carrier protein 1|solute carrier family 46 (folate transporter), member 1', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28394642, end_position_on_the_genomic_accession=28406630, orientation='minus', exon_count=6, OMIM=[611672], no_hdr0=''),
    113246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113246, CurrentID=0, Status='live', Symbol='C12orf57', Aliases=['C10', 'GRCC10'], description='chromosome 12 open reading frame 57', other_designations='protein C10|gene rich cluster C10|likely ortholog of mouse gene rich cluster, C10', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6943433, end_position_on_the_genomic_accession=6946003, orientation='plus', exon_count=4, OMIM=[615140], no_hdr0=''),
    113251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113251, CurrentID=0, Status='live', Symbol='LARP4', Aliases=['PP13296'], description='La ribonucleoprotein 4', other_designations='la-related protein 4|La ribonucleoprotein domain family member 4|c-Mpl binding protein', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50400862, end_position_on_the_genomic_accession=50480004, orientation='plus', exon_count=22, OMIM=[618657], no_hdr0=''),
    113263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113263, CurrentID=0, Status='live', Symbol='GLCCI1', Aliases=['FAM117C', 'GCTR', 'GIG18', 'TSSN1'], description='glucocorticoid induced 1', other_designations='glucocorticoid-induced transcript 1 protein|glucocorticoid induced transcript 1', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7968796, end_position_on_the_genomic_accession=8089080, orientation='plus', exon_count=8, OMIM=[614283], no_hdr0=''),
    113277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113277, CurrentID=0, Status='live', Symbol='TMEM106A', Aliases=[], description='transmembrane protein 106A', other_designations='transmembrane protein 106A', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43211875, end_position_on_the_genomic_accession=43220041, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    113278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113278, CurrentID=0, Status='live', Symbol='SLC52A3', Aliases=['BVVLS', 'BVVLS1', 'C20orf54', 'RFT2', 'RFVT3', 'bA371L19.1', 'hRFT2'], description='solute carrier family 52 member 3', other_designations='solute carrier family 52, riboflavin transporter, member 3|SLC52A3a|SLC52A3b|riboflavin transporter 2|solute carrier family 52 (riboflavin transporter), member 3', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=760080, end_position_on_the_genomic_accession=775985, orientation='minus', exon_count=7, OMIM=[613350], no_hdr0=''),
    113402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113402, CurrentID=0, Status='live', Symbol='SFT2D1', Aliases=['C6orf83', 'pRGR1'], description='SFT2 domain containing 1', other_designations='vesicle transport protein SFT2A|SFT2 domain-containing protein 1', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166319728, end_position_on_the_genomic_accession=166342545, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    113419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113419, CurrentID=0, Status='live', Symbol='TEX261', Aliases=['TEG-261'], description='testis expressed 261', other_designations='protein TEX261|testis expressed sequence 261', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70985942, end_position_on_the_genomic_accession=70994873, orientation='minus', exon_count=6, OMIM=[618562], no_hdr0=''),
    113444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113444, CurrentID=0, Status='live', Symbol='SMIM12', Aliases=['C1orf212'], description='small integral membrane protein 12', other_designations='small integral membrane protein 12|UPF0767 protein C1orf212|alternative protein C1orf212', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34850362, end_position_on_the_genomic_accession=34859749, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    113451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113451, CurrentID=0, Status='live', Symbol='AZIN2', Aliases=['ADC', 'AZI2', 'AZIB1', 'ODC-p', 'ODC1L', 'ODCp'], description='antizyme inhibitor 2', other_designations='antizyme inhibitor 2|ODC antizyme inhibitor-2|ODC-like protein|ODC-paralogue|arginine decarboxylase|ornithine decarboxylase like|ornithine decarboxylase-like protein|ornithine decarboxylase-paralog', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33081152, end_position_on_the_genomic_accession=33162288, orientation='plus', exon_count=15, OMIM=[608353], no_hdr0=''),
    113452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113452, CurrentID=0, Status='live', Symbol='TMEM54', Aliases=['BCLP', 'CAC-1', 'CAC1'], description='transmembrane protein 54', other_designations='transmembrane protein 54|beta-casein-like protein|protein CAC-1', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32894595, end_position_on_the_genomic_accession=32901389, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    113457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113457, CurrentID=0, Status='live', Symbol='TUBA3D', Aliases=['H2-ALPHA', 'KTCN9', 'TUBA2'], description='tubulin alpha 3d', other_designations='tubulin alpha-3D chain|Alpha-tubulin 3C|Tubulin alpha-3C chain|alpha-tubulin 3D|alpha-tubulin isotype H2-alpha|tubulin alpha-2 chain|tubulin alpha-3C/D chain', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131476119, end_position_on_the_genomic_accession=131482934, orientation='plus', exon_count=5, OMIM=[617878], no_hdr0=''),
    113510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113510, CurrentID=0, Status='live', Symbol='HELQ', Aliases=['HEL308'], description='helicase, POLQ like', other_designations='helicase POLQ-like|DNA helicase HEL308|POLQ-like helicase|mus308-like helicase', map_location='4q21.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=83407346, end_position_on_the_genomic_accession=83455883, orientation='minus', exon_count=18, OMIM=[606769], no_hdr0=''),
    113540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113540, CurrentID=0, Status='live', Symbol='CMTM1', Aliases=['CKLFH', 'CKLFH1', 'CKLFSF1'], description='CKLF like MARVEL transmembrane domain containing 1', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 1|chemokine-like factor super family 1|chemokine-like factor superfamily 1|chemokine-like factor superfamily member 1|chemokine-like factor-like protein CKLFH1', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66566439, end_position_on_the_genomic_accession=66579135, orientation='plus', exon_count=4, OMIM=[607884], no_hdr0=''),
    113612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113612, CurrentID=0, Status='live', Symbol='CYP2U1', Aliases=['P450TEC', 'SPG49', 'SPG56'], description='cytochrome P450 family 2 subfamily U member 1', other_designations='cytochrome P450 2U1|cytochrome P450, family 2, subfamily U, polypeptide 1|long-chain fatty acid omega-monooxygenase|spastic paraplegia 49|spastic paraplegia 56 (autosomal dominant)', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=107931549, end_position_on_the_genomic_accession=107953461, orientation='plus', exon_count=5, OMIM=[610670], no_hdr0=''),
    113622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113622, CurrentID=0, Status='live', Symbol='ADPRHL1', Aliases=['ARH2'], description='ADP-ribosylhydrolase like 1', other_designations='[Protein ADP-ribosylarginine] hydrolase-like protein 1|protein ADP-ribosylarginine hydrolase-like protein 1|ADP-ribosyl-hydrolase|ADP-ribosylarginine hydrolase like 1|ADP-ribosylhydrolase 2', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113399607, end_position_on_the_genomic_accession=113453488, orientation='minus', exon_count=12, OMIM=[610620], no_hdr0=''),
    113655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113655, CurrentID=0, Status='live', Symbol='MFSD3', Aliases=[], description='major facilitator superfamily domain containing 3', other_designations='major facilitator superfamily domain-containing protein 3', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144508081, end_position_on_the_genomic_accession=144511213, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    113675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113675, CurrentID=0, Status='live', Symbol='SDSL', Aliases=['SDH 2', 'SDS-RS1', 'TDH', 'cSDH'], description='serine dehydratase like', other_designations='serine dehydratase-like|L-serine deaminase|L-serine dehydratase/L-threonine deaminase|L-threonine dehydratase|serine dehydratase 2|serine dehydratase related sequence 1', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113422265, end_position_on_the_genomic_accession=113438277, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    113730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113730, CurrentID=0, Status='live', Symbol='KLHDC7B', Aliases=[], description='kelch domain containing 7B', other_designations='kelch domain-containing protein 7B', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50545899, end_position_on_the_genomic_accession=50551023, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    113746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113746, CurrentID=0, Status='live', Symbol='ODF3', Aliases=['CT135', 'SHIPPO1', 'TISP50'], description='outer dense fiber of sperm tails 3', other_designations='outer dense fiber protein 3|cancer/testis antigen 135|sperm tail protein SHIPPO1|transcript induced in spermiogenesis protein 50', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=196761, end_position_on_the_genomic_accession=200258, orientation='plus', exon_count=7, OMIM=[608356], no_hdr0=''),
    113763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113763, CurrentID=0, Status='live', Symbol='ZBED6CL', Aliases=['C7orf29'], description='ZBED6 C-terminal like', other_designations='ZBED6 C-terminal-like protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150329849, end_position_on_the_genomic_accession=150332721, orientation='plus', exon_count=1, OMIM=[615252], no_hdr0=''),
    113791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113791, CurrentID=0, Status='live', Symbol='PIK3IP1', Aliases=['HGFL', 'TrIP', 'hHGFL(S)'], description='phosphoinositide-3-kinase interacting protein 1', other_designations='phosphoinositide-3-kinase-interacting protein 1|PI3K-interacting protein 1|kringle domain-containing protein HGFL|transmembrane inhibitor of PI3K', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31281593, end_position_on_the_genomic_accession=31292534, orientation='minus', exon_count=6, OMIM=[619158], no_hdr0=''),
    113802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113802, CurrentID=0, Status='live', Symbol='HENMT1', Aliases=['C1orf59', 'HEN1'], description='HEN methyltransferase 1', other_designations="small RNA 2'-O-methyltransferase|HEN1 methyltransferase homolog 1|hua enhancer 1 homolog 1", map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108648295, end_position_on_the_genomic_accession=108661474, orientation='minus', exon_count=9, OMIM=[612178], no_hdr0=''),
    113828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113828, CurrentID=0, Status='live', Symbol='FAM83F', Aliases=[], description='family with sequence similarity 83 member F', other_designations='protein FAM83F', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39994954, end_position_on_the_genomic_accession=40043534, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    113829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113829, CurrentID=0, Status='live', Symbol='SLC35A4', Aliases=[], description='solute carrier family 35 member A4', other_designations='probable UDP-sugar transporter protein SLC35A4|solute carrier family 35 (UDP-galactose transporter), member A4|tumor rejection antigen', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140564828, end_position_on_the_genomic_accession=140569100, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    113835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113835, CurrentID=0, Status='live', Symbol='ZNF257', Aliases=['BMZF-4', 'BMZF4'], description='zinc finger protein 257', other_designations='zinc finger protein 257|bone marrow zinc finger 4', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22052484, end_position_on_the_genomic_accession=22091480, orientation='plus', exon_count=6, OMIM=[606957], no_hdr0=''),
    113878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113878, CurrentID=0, Status='live', Symbol='DTX2', Aliases=['RNF58'], description='deltex E3 ubiquitin ligase 2', other_designations='probable E3 ubiquitin-protein ligase DTX2|RING-type E3 ubiquitin transferase DTX2|deltex 2, E3 ubiquitin ligase|deltex homolog 2|deltex2|hDTX2|protein deltex-2|ring finger protein 58|zinc ion binding protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76461676, end_position_on_the_genomic_accession=76505995, orientation='plus', exon_count=17, OMIM=[613141], no_hdr0=''),
    114026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114026, CurrentID=0, Status='live', Symbol='ZIM3', Aliases=['ZNF264', 'ZNF657'], description='zinc finger imprinted 3', other_designations='zinc finger imprinted 3|Zinc finger protein 264|zinc finger protein 657', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57134096, end_position_on_the_genomic_accession=57145202, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    114034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114034, CurrentID=0, Status='live', Symbol='TOE1', Aliases=['PCH7', 'TOE-1', 'hCaf1z'], description='target of EGR1, exonuclease', other_designations='target of EGR1 protein 1|target of EGR1, member 1 (nuclear)', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45339751, end_position_on_the_genomic_accession=45343973, orientation='plus', exon_count=8, OMIM=[613931], no_hdr0=''),
    114049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114049, CurrentID=0, Status='live', Symbol='BUD23', Aliases=['HASJ4442', 'HUSSY-3', 'MERM1', 'PP3381', 'WBMT', 'WBSCR22'], description='BUD23 rRNA methyltransferase and ribosome maturation factor', other_designations='probable 18S rRNA (guanine-N(7))-methyltransferase|Williams-Beuren candidate region putative methyltransferase|Williams-Beuren syndrome chromosomal region 22 protein|Williams-Beuren syndrome chromosome region 22|bud site selection protein 23 homolog|metastasis-related methyltransferase 1|rRNA methyltransferase and ribosome maturation factor|ribosome biogenesis methyltransferase WBSCR22', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73683571, end_position_on_the_genomic_accession=73698212, orientation='plus', exon_count=13, OMIM=[615733], no_hdr0=''),
    114088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114088, CurrentID=0, Status='live', Symbol='TRIM9', Aliases=['RNF91', 'SPRING'], description='tripartite motif containing 9', other_designations='E3 ubiquitin-protein ligase TRIM9|RING finger protein 91|RING-type E3 ubiquitin transferase TRIM9|SNAP-25-interacting RING finger protein|homolog of rat RING finger Spring|tripartite motif-containing protein 9', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50975261, end_position_on_the_genomic_accession=51105173, orientation='minus', exon_count=16, OMIM=[606555], no_hdr0=''),
    114112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114112, CurrentID=0, Status='live', Symbol='TXNRD3', Aliases=['TGR', 'TR2', 'TR2IT1', 'TRXR3IT1', 'TXNRD3NB', 'TXNRD3NT1', 'TXNRD3'], description='thioredoxin reductase 3', other_designations='thioredoxin reductase 3|TXNRD3 neighbor gene protein|selenoprotein TXNRD3|thioredoxin and glutathione reductase|thioredoxin glutathione reductase|thioredoxin reductase 2 intronic transcript 1|thioredoxin reductase 3 intronic transcript 1|thioredoxin reductase 3 neighbor gene protein|thioredoxin reductase 3 new transcript 1|thioredoxin reductase TR2', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126607050, end_position_on_the_genomic_accession=126655124, orientation='minus', exon_count=16, OMIM=[606235], no_hdr0=''),
    114131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114131, CurrentID=0, Status='live', Symbol='UCN3', Aliases=['SCP', 'SPC', 'UCNIII'], description='urocortin 3', other_designations='urocortin-3|prepro-urocortin 3|stresscopin|ucn III|urocortin III', map_location='10p15.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=5364966, end_position_on_the_genomic_accession=5374692, orientation='plus', exon_count=2, OMIM=[605901], no_hdr0=''),
    114132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114132, CurrentID=0, Status='live', Symbol='SIGLEC11', Aliases=[], description='sialic acid binding Ig like lectin 11', other_designations='sialic acid-binding Ig-like lectin 11|siglec-11', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49948825, end_position_on_the_genomic_accession=49961172, orientation='minus', exon_count=11, OMIM=[607157], no_hdr0=''),
    114134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114134, CurrentID=0, Status='live', Symbol='SLC2A13', Aliases=['HMIT'], description='solute carrier family 2 member 13', other_designations='proton myo-inositol cotransporter|H(+)-myo-inositol symporter|h(+)-myo-inositol cotransporter|proton (H+) myo-inositol symporter|solute carrier family 2 (facilitated glucose transporter), member 13', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=39755021, end_position_on_the_genomic_accession=40106085, orientation='minus', exon_count=17, OMIM=[611036], no_hdr0=''),
    114294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114294, CurrentID=0, Status='live', Symbol='LACTB', Aliases=['G24', 'MRPL56'], description='lactamase beta', other_designations='serine beta-lactamase-like protein LACTB, mitochondrial|mitochondrial 39S ribosomal protein L56|serine beta-lactamase-like protein, mitochondrial', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63121806, end_position_on_the_genomic_accession=63142062, orientation='plus', exon_count=7, OMIM=[608440], no_hdr0=''),
    114327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114327, CurrentID=0, Status='live', Symbol='EFHC1', Aliases=['EJM1', 'POC9', 'RIB72', 'dJ304B14.2'], description='EF-hand domain containing 1', other_designations='EF-hand domain-containing protein 1|EF-hand domain (C-terminal) containing 1|myoclonin-1', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52420342, end_position_on_the_genomic_accession=52497198, orientation='plus', exon_count=12, OMIM=[608815], no_hdr0=''),
    114335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114335, CurrentID=0, Status='live', Symbol='CGB1', Aliases=[], description='chorionic gonadotropin subunit beta 1', other_designations='choriogonadotropin subunit beta variant 1|chorionic gonadotropin beta subunit 1|chorionic gonadotropin, beta polypeptide 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49035569, end_position_on_the_genomic_accession=49036895, orientation='minus', exon_count=3, OMIM=[608823], no_hdr0=''),
    114336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114336, CurrentID=0, Status='live', Symbol='CGB2', Aliases=[], description='chorionic gonadotropin subunit beta 2', other_designations='choriogonadotropin subunit beta variant 2|chorionic gonadotropin beta subunit 2|chorionic gonadotropin, beta polypeptide 2|product of CGB2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49031890, end_position_on_the_genomic_accession=49033238, orientation='plus', exon_count=3, OMIM=[608824], no_hdr0=''),
    114548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114548, CurrentID=0, Status='live', Symbol='NLRP3', Aliases=['AGTAVPRL', 'AII', 'AVP', 'C1orf7', 'CIAS1', 'CLR1.1', 'DFNA34', 'FCAS', 'FCAS1', 'FCU', 'KEFH', 'MWS', 'NALP3', 'PYPAF1'], description='NLR family pyrin domain containing 3', other_designations='NACHT, LRR and PYD domains-containing protein 3|NACHT domain-, leucine-rich repeat-, and PYD-containing protein 3|NACHT, LRR and PYD containing protein 3|PYRIN-containing APAF1-like protein 1|caterpiller protein 1.1|cold autoinflammatory syndrome 1 protein|cold-induced autoinflammatory syndrome 1 protein|cryopyrin|cryopyrin, NACHT, LRR and PYD domains - containing protein 3|deafness, autosomal dominant 34|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 3', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247416163, end_position_on_the_genomic_accession=247448823, orientation='plus', exon_count=11, OMIM=[606416], no_hdr0=''),
    114569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114569, CurrentID=0, Status='live', Symbol='MAL2', Aliases=[], description='mal, T cell differentiation protein 2', other_designations='protein MAL2|MAL proteolipid protein 2|MAL2 proteolipid protein|myelin and lymphocyte protein 2', map_location='8q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=119208363, end_position_on_the_genomic_accession=119245673, orientation='plus', exon_count=4, OMIM=[609684], no_hdr0=''),
    114571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114571, CurrentID=0, Status='live', Symbol='SLC22A9', Aliases=['HOAT4', 'OAT4', 'OAT7', 'UST3H', 'ust3'], description='solute carrier family 22 member 9', other_designations='solute carrier family 22 member 9|organic anion transporter 4|organic anion transporter 7|solute carrier family 22 (organic anion transporter), member 9|solute carrier family 22 (organic anion/cation transporter), member 9', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63368871, end_position_on_the_genomic_accession=63410878, orientation='plus', exon_count=10, OMIM=[607579], no_hdr0=''),
    114609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114609, CurrentID=0, Status='live', Symbol='TIRAP', Aliases=['BACTS1', 'Mal', 'MyD88-2', 'wyatt'], description='TIR domain containing adaptor protein', other_designations='toll/interleukin-1 receptor domain-containing adapter protein|MyD88 adapter-like protein|Toll-like receptor adaptor protein|adapter protein wyatt|adaptor protein Wyatt|toll-interleukin 1 receptor (TIR) domain containing adaptor protein', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126283093, end_position_on_the_genomic_accession=126294933, orientation='plus', exon_count=6, OMIM=[606252], no_hdr0=''),
    114625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114625, CurrentID=0, Status='live', Symbol='ERMAP', Aliases=['BTN5', 'PRO2801', 'RD', 'SC'], description='erythroblast membrane associated protein (Scianna blood group)', other_designations='erythroid membrane-associated protein|Radin blood group (Rd)|Scianna blood group (Sc)|radin blood group antigen|scianna blood group antigen', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42817122, end_position_on_the_genomic_accession=42844991, orientation='plus', exon_count=13, OMIM=[609017], no_hdr0=''),
    114659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114659, CurrentID=0, Status='live', Symbol='LRRC37B', Aliases=['LRRC37'], description='leucine rich repeat containing 37B', other_designations='leucine-rich repeat-containing protein 37B|C66 SLIT-like testicular protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32007383, end_position_on_the_genomic_accession=32053487, orientation='plus', exon_count=15, OMIM=[616558], no_hdr0=''),
    114757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114757, CurrentID=0, Status='live', Symbol='CYGB', Aliases=['HGB', 'STAP'], description='cytoglobin', other_designations='cytoglobin|histoglobin|stellate cell activation-associated protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76527356, end_position_on_the_genomic_accession=76557692, orientation='minus', exon_count=7, OMIM=[608759], no_hdr0=''),
    114769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114769, CurrentID=0, Status='live', Symbol='CARD16', Aliases=['COP', 'COP1', 'LLID-114769', 'PSEUDO-ICE'], description='caspase recruitment domain family member 16', other_designations='caspase recruitment domain-containing protein 16|CARD only domain-containing protein 1|CARD only protein|CARD-only protein 1|caspase recruitment domain-only protein 1|caspase-1 dominant-negative inhibitor pseudo-ICE|caspase-1 inhibitor COP|pseudo interleukin-1 beta converting enzyme|pseudo interleukin-1beta converting enzyme|pseudo-IL1B-converting enzyme', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=105040218, end_position_on_the_genomic_accession=105045416, orientation='minus', exon_count=4, OMIM=[615680], no_hdr0=''),
    114770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114770, CurrentID=0, Status='live', Symbol='PGLYRP2', Aliases=['HMFT0141', 'PGLYRPL', 'PGRP-L', 'PGRPL', 'TAGL-like', 'tagL', 'tagL-alpha', 'tagl-beta'], description='peptidoglycan recognition protein 2', other_designations='N-acetylmuramoyl-L-alanine amidase|peptidoglycan recognition protein L|peptidoglycan recognition protein long', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15468645, end_position_on_the_genomic_accession=15479501, orientation='minus', exon_count=5, OMIM=[608199], no_hdr0=''),
    114771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114771, CurrentID=0, Status='live', Symbol='PGLYRP3', Aliases=['PGLYRPIalpha', 'PGRP-Ialpha', 'PGRPIA'], description='peptidoglycan recognition protein 3', other_designations='peptidoglycan recognition protein 3|peptidoglycan recognition protein I alpha|peptidoglycan recognition protein intermediate alpha', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153297116, end_position_on_the_genomic_accession=153312975, orientation='minus', exon_count=11, OMIM=[608197], no_hdr0=''),
    114780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114780, CurrentID=0, Status='live', Symbol='PKD1L2', Aliases=['PC1L2'], description='polycystin 1 like 2 (gene/pseudogene)', other_designations='polycystic kidney disease protein 1-like 2|PC1-like 2 protein|polycystic kidney disease 1-like 2|polycystin-1L2', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81100875, end_position_on_the_genomic_accession=81220394, orientation='minus', exon_count=44, OMIM=[607894], no_hdr0=''),
    114781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114781, CurrentID=0, Status='live', Symbol='BTBD9', Aliases=['dJ322I12.1'], description='BTB domain containing 9', other_designations='BTB/POZ domain-containing protein 9|BTB (POZ) domain containing 9', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=38168451, end_position_on_the_genomic_accession=38640541, orientation='minus', exon_count=17, OMIM=[611237], no_hdr0=''),
    114783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114783, CurrentID=0, Status='live', Symbol='LMTK3', Aliases=['LMR3', 'PPP1R101', 'TYKLM3'], description='lemur tyrosine kinase 3', other_designations='serine/threonine-protein kinase LMTK3|protein phosphatase 1, regulatory subunit 101', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48485271, end_position_on_the_genomic_accession=48513926, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    114784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114784, CurrentID=0, Status='live', Symbol='CSMD2', Aliases=['dJ1007G16.1', 'dJ1007G16.2', 'dJ947L8.1'], description='CUB and Sushi multiple domains 2', other_designations='CUB and sushi domain-containing protein 2|CUB and Sushi (SCR repeat) domain|CUB and sushi multiple domains protein 2', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33513998, end_position_on_the_genomic_accession=34165842, orientation='minus', exon_count=74, OMIM=[608398], no_hdr0=''),
    114785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114785, CurrentID=0, Status='live', Symbol='MBD6', Aliases=[], description='methyl-CpG binding domain protein 6', other_designations='methyl-CpG-binding domain protein 6|methyl-CpG-binding protein MBD6', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57520710, end_position_on_the_genomic_accession=57530148, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    114786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114786, CurrentID=0, Status='live', Symbol='XKR4', Aliases=['XRG4'], description='XK related 4', other_designations='XK-related protein 4|X Kell blood group precursor-related family, member 4|X-linked Kx blood group related 4|XK, Kell blood group complex subunit-related family, member 4', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=55102028, end_position_on_the_genomic_accession=55542054, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    114787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114787, CurrentID=0, Status='live', Symbol='GPRIN1', Aliases=['GRIN1'], description='G protein regulated inducer of neurite outgrowth 1', other_designations='G protein-regulated inducer of neurite outgrowth 1', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176595802, end_position_on_the_genomic_accession=176610156, orientation='minus', exon_count=2, OMIM=[611239], no_hdr0=''),
    114788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114788, CurrentID=0, Status='live', Symbol='CSMD3', Aliases=[], description='CUB and Sushi multiple domains 3', other_designations='CUB and sushi domain-containing protein 3|CUB and sushi multiple domains protein 3', map_location='8q23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=112222928, end_position_on_the_genomic_accession=113437499, orientation='minus', exon_count=75, OMIM=[608399], no_hdr0=''),
    114789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114789, CurrentID=0, Status='live', Symbol='SLC25A25', Aliases=['MCSC', 'PCSCL', 'SCAMC-2'], description='solute carrier family 25 member 25', other_designations='calcium-binding mitochondrial carrier protein SCaMC-2|mitochondrial ATP-Mg/Pi carrier protein 3|mitochondrial Ca(2+)-dependent solute carrier protein 3|short calcium-binding mitochondrial carrier 2|small calcium-binding mitochondrial carrier 2|solute carrier family 25 (mitochondrial carrier; phosphate carrier), member 25', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128068200, end_position_on_the_genomic_accession=128109245, orientation='plus', exon_count=13, OMIM=[608745], no_hdr0=''),
    114790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114790, CurrentID=0, Status='live', Symbol='STK11IP', Aliases=['LIP1', 'LKB1IP1', 'STK11IP'], description='serine/threonine kinase 11 interacting protein', other_designations='serine/threonine-protein kinase 11-interacting protein|LKB1-interacting protein 1|STK11 interacting protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219597857, end_position_on_the_genomic_accession=219616451, orientation='plus', exon_count=29, OMIM=[607172], no_hdr0=''),
    114791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114791, CurrentID=0, Status='live', Symbol='TUBGCP5', Aliases=['GCP5'], description='tubulin gamma complex associated protein 5', other_designations='gamma-tubulin complex component 5|gamma-tubulin complex component GCP5', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22983025, end_position_on_the_genomic_accession=23039580, orientation='minus', exon_count=28, OMIM=[608147], no_hdr0=''),
    114792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114792, CurrentID=0, Status='live', Symbol='KLHL32', Aliases=['BKLHD5', 'KIAA1900', 'UG0030H05', 'dJ21F7.1'], description='kelch like family member 32', other_designations='kelch-like protein 32|BTB and kelch domain containing 5', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=96898083, end_position_on_the_genomic_accession=97145030, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    114793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114793, CurrentID=0, Status='live', Symbol='FMNL2', Aliases=['FHOD2'], description='formin like 2', other_designations='formin-like protein 2|formin homology 2 domain containing 2|formin homology 2 domain-containing protein 2', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=152335170, end_position_on_the_genomic_accession=152649826, orientation='plus', exon_count=30, OMIM=[616285], no_hdr0=''),
    114794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114794, CurrentID=0, Status='live', Symbol='ELFN2', Aliases=['LRRC62', 'PPP1R29'], description='extracellular leucine rich repeat and fibronectin type III domain containing 2', other_designations='protein phosphatase 1 regulatory subunit 29|dJ63G5.3 (putative Leucine rich protein)|leucine-rich repeat and fibronectin type-III domain-containing protein 6|leucine-rich repeat-containing protein 62', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37340644, end_position_on_the_genomic_accession=37427479, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    114795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114795, CurrentID=0, Status='live', Symbol='TMEM132B', Aliases=[], description='transmembrane protein 132B', other_designations='transmembrane protein 132B', map_location='12q24.31-q24.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=125186386, end_position_on_the_genomic_accession=125662377, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    114798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114798, CurrentID=0, Status='live', Symbol='SLITRK1', Aliases=['LRRC12', 'TTM'], description='SLIT and NTRK like family member 1', other_designations='SLIT and NTRK-like protein 1|leucine-rich repeat-containing protein 12|slit and trk like gene 1', map_location='13q31.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=83877205, end_position_on_the_genomic_accession=83882474, orientation='minus', exon_count=2, OMIM=[609678], no_hdr0=''),
    114799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114799, CurrentID=0, Status='live', Symbol='ESCO1', Aliases=['A930014I12Rik', 'CTF', 'ECO1', 'EFO1', 'ESO1'], description='establishment of sister chromatid cohesion N-acetyltransferase 1', other_designations='N-acetyltransferase ESCO1|CTF7 homolog 1|ECO1 homolog 1|EFO1p|ESO1 homolog 1|N-acetyltransferase ESCO1 variant 2|establishment factor-like protein 1|establishment of cohesion 1 homolog 1|hEFO1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=21529281, end_position_on_the_genomic_accession=21600736, orientation='minus', exon_count=13, OMIM=[609674], no_hdr0=''),
    114800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114800, CurrentID=0, Status='live', Symbol='CCDC85A', Aliases=[], description='coiled-coil domain containing 85A', other_designations='coiled-coil domain-containing protein 85A', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=56183990, end_position_on_the_genomic_accession=56386174, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    114801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114801, CurrentID=0, Status='live', Symbol='TMEM200A', Aliases=['KIAA1913', 'TTMA', 'TTMC'], description='transmembrane protein 200A', other_designations='transmembrane protein 200A|two transmembrane C', map_location='6q23.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=130366017, end_position_on_the_genomic_accession=130443424, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    114803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114803, CurrentID=0, Status='live', Symbol='MYSM1', Aliases=['2A-DUB', '2ADUB', 'BMFS4'], description='Myb like, SWIRM and MPN domains 1', other_designations='deubiquitinase MYSM1|histone H2A deubiquitinase MYSM1|myb-like, SWIRM and MPN domain-containing protein 1', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=58654739, end_position_on_the_genomic_accession=58700091, orientation='minus', exon_count=23, OMIM=[612176], no_hdr0=''),
    114804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114804, CurrentID=0, Status='live', Symbol='RNF157', Aliases=[], description='ring finger protein 157', other_designations='E3 ubiquitin ligase RNF157|RING-type E3 ubiquitin transferase RNF157', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76142456, end_position_on_the_genomic_accession=76240493, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    114805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114805, CurrentID=0, Status='live', Symbol='GALNT13', Aliases=['GalNAc-T13'], description='polypeptide N-acetylgalactosaminyltransferase 13', other_designations='polypeptide N-acetylgalactosaminyltransferase 13|GalNAc transferase 13|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 13|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 13 (GalNAc-T13)|polypeptide GalNAc transferase 13|polypeptide N-acetylgalactosaminyltransferase 13 variant delta39bpEx9|polypeptide N-acetylgalactosaminyltransferase 13 variant deltaEx2-7|polypeptide N-acetylgalactosaminyltransferase 13 variant deltaEx6 delta39bpEx9|polypeptide N-acetylgalactosaminyltransferase 13 variant deltaEx6 deltaEx8 delta39bpEx9|polypeptide N-acetylgalactosaminyltransferase 13 variant deltaEx8|polypeptide N-acetylgalactosaminyltransferase 13 variant deltaEx9|pp-GaNTase 13|protein-UDP acetylgalactosaminyltransferase 13', map_location='2q23.3-q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=153871922, end_position_on_the_genomic_accession=154454177, orientation='plus', exon_count=18, OMIM=[608369], no_hdr0=''),
    114815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114815, CurrentID=0, Status='live', Symbol='SORCS1', Aliases=['hSorCS'], description='sortilin related VPS10 domain containing receptor 1', other_designations='VPS10 domain-containing receptor SorCS1|VPS10 domain receptor protein SORCS 1', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=106573663, end_position_on_the_genomic_accession=107181138, orientation='minus', exon_count=31, OMIM=[606283], no_hdr0=''),
    114818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114818, CurrentID=0, Status='live', Symbol='KLHL29', Aliases=['KBTBD9'], description='kelch like family member 29', other_designations='kelch-like protein 29|kelch repeat and BTB (POZ) domain containing 9|kelch repeat and BTB domain-containing protein 9|kelch-like 29', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=23385179, end_position_on_the_genomic_accession=23708606, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    114821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114821, CurrentID=0, Status='live', Symbol='ZBED9', Aliases=['Buster4', 'SCAND3', 'ZFP38-L', 'ZNF305P2', 'ZNF452', 'dJ1186N24.3'], description='zinc finger BED-type containing 9', other_designations='SCAN domain-containing protein 3|SCAN domain containing 3|transposon-derived Buster4 transposase-like protein|zinc finger BED domain-containing protein 9|zinc finger protein 305 pseudogene 2|zinc finger protein 452', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28568288, end_position_on_the_genomic_accession=28616202, orientation='minus', exon_count=8, OMIM=[615254], no_hdr0=''),
    114822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114822, CurrentID=0, Status='live', Symbol='RHPN1', Aliases=['ODF5', 'RHOPHILIN', 'RHPN'], description='rhophilin Rho GTPase binding protein 1', other_designations='rhophilin-1|GTP-Rho-binding protein 1|outer dense fiber of sperm tails 5', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143368827, end_position_on_the_genomic_accession=143384221, orientation='plus', exon_count=18, OMIM=[601031], no_hdr0=''),
    114823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114823, CurrentID=0, Status='live', Symbol='LENG8', Aliases=['pp13842'], description='leukocyte receptor cluster member 8', other_designations='leukocyte receptor cluster member 8|leukocyte receptor cluster (LRC) member 8', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54447621, end_position_on_the_genomic_accession=54462022, orientation='plus', exon_count=16, OMIM=[616575], no_hdr0=''),
    114824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114824, CurrentID=0, Status='live', Symbol='PNMA5', Aliases=[], description='PNMA family member 5', other_designations='paraneoplastic antigen-like protein 5|paraneoplastic Ma antigen family member 5|tumor antigen BJ-HCC-25', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152988824, end_position_on_the_genomic_accession=152994458, orientation='minus', exon_count=5, OMIM=[300916], no_hdr0=''),
    114825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114825, CurrentID=0, Status='live', Symbol='PWWP2A', Aliases=['MST101'], description='PWWP domain containing 2A', other_designations='PWWP domain-containing protein 2A|MSTP101', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160043538, end_position_on_the_genomic_accession=160120701, orientation='minus', exon_count=11, OMIM=[617823], no_hdr0=''),
    114826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114826, CurrentID=0, Status='live', Symbol='SMYD4', Aliases=['ZMYND21'], description='SET and MYND domain containing 4', other_designations='SET and MYND domain-containing protein 4', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1779485, end_position_on_the_genomic_accession=1829902, orientation='minus', exon_count=14, OMIM=[619134], no_hdr0=''),
    114827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114827, CurrentID=0, Status='live', Symbol='FHAD1', Aliases=[], description='forkhead associated phosphopeptide binding domain 1', other_designations='forkhead-associated domain-containing protein 1|FHA domain-containing protein 1|forkhead-associated (FHA) phosphopeptide binding domain 1', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15236560, end_position_on_the_genomic_accession=15400283, orientation='plus', exon_count=43, OMIM=[], no_hdr0=''),
    114836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114836, CurrentID=0, Status='live', Symbol='SLAMF6', Aliases=['CD352', 'KALI', 'KALIb', 'Ly108', 'NTB-A', 'NTBA', 'SF2000'], description='SLAM family member 6', other_designations='SLAM family member 6|NK-T-B-antigen|NTBA receptor|activating NK receptor|natural killer-, T- and B-cell antigen', map_location='1q23.2-q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160485030, end_position_on_the_genomic_accession=160523263, orientation='minus', exon_count=8, OMIM=[606446], no_hdr0=''),
    114876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114876, CurrentID=0, Status='live', Symbol='OSBPL1A', Aliases=['ORP-1', 'ORP1', 'OSBPL1B'], description='oxysterol binding protein like 1A', other_designations='oxysterol-binding protein-related protein 1|OSBP-related protein 1|oxysterol binding protein-like 1B|oxysterol-binding protein-related protein 1 variant 1|oxysterol-binding protein-related protein 1 variant 2', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=24162045, end_position_on_the_genomic_accession=24397882, orientation='minus', exon_count=32, OMIM=[606730], no_hdr0=''),
    114879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114879, CurrentID=0, Status='live', Symbol='OSBPL5', Aliases=['OBPH1', 'ORP5'], description='oxysterol binding protein like 5', other_designations='oxysterol-binding protein-related protein 5|ORP-5|OSBP-related protein 5|oxysterol-binding protein homolog 1|oxysterol-binding protein homologue 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3087107, end_position_on_the_genomic_accession=3165310, orientation='minus', exon_count=25, OMIM=[606733], no_hdr0=''),
    114880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114880, CurrentID=0, Status='live', Symbol='OSBPL6', Aliases=['ORP6'], description='oxysterol binding protein like 6', other_designations='oxysterol-binding protein-related protein 6|ORP-6|OSBP-related protein 6', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178194465, end_position_on_the_genomic_accession=178402893, orientation='plus', exon_count=30, OMIM=[606734], no_hdr0=''),
    114881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114881, CurrentID=0, Status='live', Symbol='OSBPL7', Aliases=['ORP7'], description='oxysterol binding protein like 7', other_designations='oxysterol-binding protein-related protein 7|ORP-7|OSBP-related protein 7', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47807367, end_position_on_the_genomic_accession=47821822, orientation='minus', exon_count=23, OMIM=[606735], no_hdr0=''),
    114882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114882, CurrentID=0, Status='live', Symbol='OSBPL8', Aliases=['MST120', 'MSTP120', 'ORP8', 'OSBP10'], description='oxysterol binding protein like 8', other_designations='oxysterol-binding protein-related protein 8|OSBP-related protein 8', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=76351797, end_position_on_the_genomic_accession=76559805, orientation='minus', exon_count=30, OMIM=[606736], no_hdr0=''),
    114883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114883, CurrentID=0, Status='live', Symbol='OSBPL9', Aliases=['ORP-9', 'ORP9'], description='oxysterol binding protein like 9', other_designations='oxysterol-binding protein-related protein 9|OSBP-related protein 9', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51617084, end_position_on_the_genomic_accession=51789219, orientation='plus', exon_count=30, OMIM=[606737], no_hdr0=''),
    114884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114884, CurrentID=0, Status='live', Symbol='OSBPL10', Aliases=['ORP10', 'OSBP9'], description='oxysterol binding protein like 10', other_designations='oxysterol-binding protein-related protein 10|ORP-10|OSBP-related protein 10', map_location='3p23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=31660825, end_position_on_the_genomic_accession=31981301, orientation='minus', exon_count=15, OMIM=[606738], no_hdr0=''),
    114885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114885, CurrentID=0, Status='live', Symbol='OSBPL11', Aliases=['ORP-11', 'ORP11', 'OSBP12', 'TCCCIA00292'], description='oxysterol binding protein like 11', other_designations='oxysterol-binding protein-related protein 11|OSBP-related protein 11|testicular tissue protein Li 132', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=125528858, end_position_on_the_genomic_accession=125595497, orientation='minus', exon_count=13, OMIM=[606739], no_hdr0=''),
    114897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114897, CurrentID=0, Status='live', Symbol='C1QTNF1', Aliases=['CTRP1', 'GIP', 'ZSIG37'], description='C1q and TNF related 1', other_designations='complement C1q tumor necrosis factor-related protein 1|C1q and tumor necrosis factor related protein 1|G protein coupled receptor interacting protein|g protein-coupled receptor-interacting protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79022934, end_position_on_the_genomic_accession=79049788, orientation='plus', exon_count=9, OMIM=[610365], no_hdr0=''),
    114898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114898, CurrentID=0, Status='live', Symbol='C1QTNF2', Aliases=['CTRP2', 'zacrp2'], description='C1q and TNF related 2', other_designations='complement C1q tumor necrosis factor-related protein 2|C1q and tumor necrosis factor related protein 2|complement-c1q tumor necrosis factor-related protein 2', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=160347558, end_position_on_the_genomic_accession=160370656, orientation='minus', exon_count=5, OMIM=[618647], no_hdr0=''),
    114899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114899, CurrentID=0, Status='live', Symbol='C1QTNF3', Aliases=['C1ATNF3', 'CORCS', 'CORS', 'CORS-26', 'CORS26', 'CTRP3'], description='C1q and TNF related 3', other_designations='complement C1q tumor necrosis factor-related protein 3|C1q and tumor necrosis factor related protein 3|cartonectin|collagenous repeat-containing sequence 26 kDa protein|collagenous repeat-containing sequence of 26-kDa|secretory protein CORS26', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34017858, end_position_on_the_genomic_accession=34244724, orientation='minus', exon_count=13, OMIM=[612045], no_hdr0=''),
    114900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114900, CurrentID=0, Status='live', Symbol='C1QTNF4', Aliases=['CTRP4', 'ZACRP4'], description='C1q and TNF related 4', other_designations='complement C1q tumor necrosis factor-related protein 4|C1q and tumor necrosis factor related protein 4|C1q/TNF-related protein 4|complement-c1q tumor necrosis factor-related protein 4', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47589664, end_position_on_the_genomic_accession=47596336, orientation='minus', exon_count=3, OMIM=[614911], no_hdr0=''),
    114902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114902, CurrentID=0, Status='live', Symbol='C1QTNF5', Aliases=['CTRP5', 'MFRP'], description='C1q and TNF related 5', other_designations='complement C1q tumor necrosis factor-related protein 5|C1q TNF-alpha-related protein 5|C1q and tumor necrosis factor related protein 5|Membrane frizzled-related protein|myonectin', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119338942, end_position_on_the_genomic_accession=119346705, orientation='minus', exon_count=15, OMIM=[608752], no_hdr0=''),
    114904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114904, CurrentID=0, Status='live', Symbol='C1QTNF6', Aliases=['CTFP6', 'CTRP6', 'ZACRP6'], description='C1q and TNF related 6', other_designations='complement C1q tumor necrosis factor-related protein 6|C1q and tumor necrosis factor related protein 6|complement-c1q tumor necrosis factor-related protein 6', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37180166, end_position_on_the_genomic_accession=37199423, orientation='minus', exon_count=9, OMIM=[614910], no_hdr0=''),
    114905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114905, CurrentID=0, Status='live', Symbol='C1QTNF7', Aliases=['CTRP7', 'ZACRP7'], description='C1q and TNF related 7', other_designations='complement C1q tumor necrosis factor-related protein 7|C1q and tumor necrosis factor related protein 7|complement-c1q tumor necrosis factor-related protein 7', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15339818, end_position_on_the_genomic_accession=15446169, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    114907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114907, CurrentID=0, Status='live', Symbol='FBXO32', Aliases=['Fbx32', 'MAFbx'], description='F-box protein 32', other_designations='F-box only protein 32|atrogin 1|muscle atrophy F-box protein', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123497889, end_position_on_the_genomic_accession=123541206, orientation='minus', exon_count=9, OMIM=[606604], no_hdr0=''),
    114908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114908, CurrentID=0, Status='live', Symbol='TMEM123', Aliases=['KCT3', 'PORIMIN', 'PORMIN'], description='transmembrane protein 123', other_designations='porimin|KCT-3|keratinocytes associated transmembrane protein 3|pro-oncosis receptor inducing membrane injury|serine/threonine-rich receptor', map_location='11q22.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=102396332, end_position_on_the_genomic_accession=102452765, orientation='minus', exon_count=5, OMIM=[606356], no_hdr0=''),
    114926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114926, CurrentID=0, Status='live', Symbol='SMIM19', Aliases=['C8orf40'], description='small integral membrane protein 19', other_designations='small integral membrane protein 19|UPF0697 protein C8orf40', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=42541148, end_position_on_the_genomic_accession=42555195, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    114928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114928, CurrentID=0, Status='live', Symbol='GPRASP2', Aliases=['DFNX7', 'GASP2'], description='G protein-coupled receptor associated sorting protein 2', other_designations='G-protein coupled receptor-associated sorting protein 2', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102712448, end_position_on_the_genomic_accession=102717733, orientation='plus', exon_count=5, OMIM=[300969], no_hdr0=''),
    114932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114932, CurrentID=0, Status='live', Symbol='MRFAP1L1', Aliases=['PP784'], description='Morf4 family associated protein 1 like 1', other_designations='MORF4 family-associated protein 1-like 1', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6707701, end_position_on_the_genomic_accession=6709865, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    114960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114960, CurrentID=0, Status='live', Symbol='TSGA13', Aliases=[], description='testis specific 13', other_designations='testis-specific gene 13 protein|testis-specific A13', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130668643, end_position_on_the_genomic_accession=130687432, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    114971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114971, CurrentID=0, Status='live', Symbol='PTPMT1', Aliases=['DUSP23', 'MOSP', 'PLIP', 'PNAS-129'], description='protein tyrosine phosphatase mitochondrial 1', other_designations='phosphatidylglycerophosphatase and protein-tyrosine phosphatase 1|NB4 apoptosis/differentiation related protein|PTEN-like phosphatase|phosphoinositide lipid phosphatase', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47565599, end_position_on_the_genomic_accession=47573461, orientation='plus', exon_count=4, OMIM=[609538], no_hdr0=''),
    114984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114984, CurrentID=0, Status='live', Symbol='FLYWCH2', Aliases=[], description='FLYWCH family member 2', other_designations='FLYWCH family member 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2882804, end_position_on_the_genomic_accession=2899382, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    114987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114987, CurrentID=0, Status='live', Symbol='WDR31', Aliases=[], description='WD repeat domain 31', other_designations='WD repeat-containing protein 31', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113313222, end_position_on_the_genomic_accession=113340326, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    114990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114990, CurrentID=0, Status='live', Symbol='VASN', Aliases=['SLITL2'], description='vasorin', other_designations='vasorin|protein slit-like 2|slit-like 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4371848, end_position_on_the_genomic_accession=4383538, orientation='plus', exon_count=2, OMIM=[608843], no_hdr0=''),
    114991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114991, CurrentID=0, Status='live', Symbol='ZNF618', Aliases=['FP13169', 'NEDD10'], description='zinc finger protein 618', other_designations='zinc finger protein 618|neural precursor cell expressed, developmentally down-regulated 10', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113876285, end_position_on_the_genomic_accession=114056595, orientation='plus', exon_count=20, OMIM=[617077], no_hdr0=''),
    115004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115004, CurrentID=0, Status='live', Symbol='CGAS', Aliases=['C6orf150', 'MB21D1', 'h-cGAS'], description='cyclic GMP-AMP synthase', other_designations="cyclic GMP-AMP synthase|2'3'-cGAMP synthase|Mab-21 domain containing 1|cGAMP synthase|mab-21 domain-containing protein 1|protein MB21D1", map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73423711, end_position_on_the_genomic_accession=73452297, orientation='minus', exon_count=5, OMIM=[613973], no_hdr0=''),
    115019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115019, CurrentID=0, Status='live', Symbol='SLC26A9', Aliases=[], description='solute carrier family 26 member 9', other_designations='solute carrier family 26 member 9|anion transporter/exchanger protein 9|anion transporter/exchanger-9|solute carrier family 26 (anion exchanger), member 9', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205913048, end_position_on_the_genomic_accession=205943472, orientation='minus', exon_count=21, OMIM=[608481], no_hdr0=''),
    115024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115024, CurrentID=0, Status='live', Symbol='NT5C3B', Aliases=['NT5C3L', 'cN-IIIB'], description="5'-nucleotidase, cytosolic IIIB", other_designations="7-methylguanosine phosphate-specific 5'-nucleotidase|5'-nucleotidase, cytosolic III-like|7-methylguanosine nucleotidase|N(7)-methylguanylate 5'-phosphatase|cN-III-like protein|cytosolic 5'-nucleotidase 3B|cytosolic 5'-nucleotidase III-like protein", map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41825057, end_position_on_the_genomic_accession=41836276, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    115098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115098, CurrentID=0, Status='live', Symbol='CCDC124', Aliases=['Lso2', 'oxs1'], description='coiled-coil domain containing 124', other_designations='coiled-coil domain-containing protein 124', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17933015, end_position_on_the_genomic_accession=17943985, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    115106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115106, CurrentID=0, Status='live', Symbol='HAUS1', Aliases=['CCDC5', 'HEI-C', 'HEIC', 'HsT1461'], description='HAUS augmin like complex subunit 1', other_designations='HAUS augmin-like complex subunit 1|coiled-coil domain containing 5 (spindle associated)|coiled-coil domain-containing protein 5|enhancer of invasion-cluster', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46104385, end_position_on_the_genomic_accession=46128333, orientation='plus', exon_count=9, OMIM=[608775], no_hdr0=''),
    115111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115111, CurrentID=0, Status='live', Symbol='SLC26A7', Aliases=['SUT2'], description='solute carrier family 26 member 7', other_designations='anion exchange transporter|solute carrier family 26 (anion exchanger), member 7|solute carrier family 6 member 7|sulfate anion transporter', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=91209496, end_position_on_the_genomic_accession=91398155, orientation='plus', exon_count=22, OMIM=[608479], no_hdr0=''),
    115123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115123, CurrentID=0, Status='live', Symbol='MARCHF3', Aliases=['MARCH-III', 'MARCH3', 'RNF173'], description='membrane associated ring-CH-type finger 3', other_designations='E3 ubiquitin-protein ligase MARCHF3|E3 ubiquitin-protein ligase MARCH3|RING finger protein 173|RING-type E3 ubiquitin transferase MARCH3|RING-type E3 ubiquitin transferase MARCHF3|membrane associated ring finger 3|membrane-associated RING-CH protein III|membrane-associated ring finger (C3HC4) 3, E3 ubiquitin protein ligase', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126867714, end_position_on_the_genomic_accession=127032402, orientation='minus', exon_count=10, OMIM=[613333], no_hdr0=''),
    115196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115196, CurrentID=0, Status='live', Symbol='ZNF554', Aliases=[], description='zinc finger protein 554', other_designations='zinc finger protein 554', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2819868, end_position_on_the_genomic_accession=2836735, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    115201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115201, CurrentID=0, Status='live', Symbol='ATG4A', Aliases=['APG4A', 'AUTL2'], description='autophagy related 4A cysteine peptidase', other_designations='cysteine protease ATG4A|APG4 autophagy 4 homolog A|ATG4 autophagy related 4 homolog A|AUT-like 2, cysteine endopeptidase|autophagin 2|autophagy-related cysteine endopeptidase 2|autophagy-related protein 4 homolog A|hAPG4A', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108091778, end_position_on_the_genomic_accession=108154671, orientation='plus', exon_count=14, OMIM=[300663], no_hdr0=''),
    115207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115207, CurrentID=0, Status='live', Symbol='KCTD12', Aliases=['C13orf2', 'PFET1', 'PFETIN'], description='potassium channel tetramerization domain containing 12', other_designations='BTB/POZ domain-containing protein KCTD12|potassium channel tetramerisation domain containing 12|predominantly fetal expressed T1 domain|testicular tissue protein Li 100', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=76880175, end_position_on_the_genomic_accession=76886405, orientation='minus', exon_count=1, OMIM=[610521], no_hdr0=''),
    115209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115209, CurrentID=0, Status='live', Symbol='OMA1', Aliases=['2010001O09Rik', 'DAB1', 'MPRP-1', 'MPRP1', 'YKR087C', 'ZMPOMA1', 'peptidase'], description='OMA1 zinc metallopeptidase', other_designations='metalloendopeptidase OMA1, mitochondrial|OMA1 homolog, zinc metallopeptidase|OMA1 zinc metallopeptidase homolog|metalloprotease-related protein 1|overlapping activity with M-AAA protease|overlapping with the m-AAA protease 1 homolog|zinc metallopeptidase OMA1', map_location='1p32.2-p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=58480719, end_position_on_the_genomic_accession=58546726, orientation='minus', exon_count=9, OMIM=[617081], no_hdr0=''),
    115265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115265, CurrentID=0, Status='live', Symbol='DDIT4L', Aliases=['REDD2', 'Rtp801L'], description='DNA damage inducible transcript 4 like', other_designations='DNA damage-inducible transcript 4-like protein|HIF-1 responsive protein RTP801-like|REDD-2|homolog of mouse SMHS1|protein regulated in development and DNA damage response 2|regulated in development and DNA damage response 2', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=100185870, end_position_on_the_genomic_accession=100190468, orientation='minus', exon_count=3, OMIM=[607730], no_hdr0=''),
    115273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115273, CurrentID=0, Status='live', Symbol='RAB42', Aliases=[], description='RAB42, member RAS oncogene family', other_designations='ras-related protein Rab-42|RAB42, member RAS homolog family|putative Ras-related protein Rab-42', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=28592265, end_position_on_the_genomic_accession=28596666, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    115286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115286, CurrentID=0, Status='live', Symbol='SLC25A26', Aliases=['COXPD28', 'SAMC'], description='solute carrier family 25 member 26', other_designations='S-adenosylmethionine mitochondrial carrier protein|mitochondrial S-adenosylmethionine transporter|solute carrier family 25 (S-adenosylmethionine carrier), member 26|solute carrier family 25 (mitochondrial carrier; phosphate carrier), member 26', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=66133610, end_position_on_the_genomic_accession=66380021, orientation='plus', exon_count=18, OMIM=[611037], no_hdr0=''),
    115290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115290, CurrentID=0, Status='live', Symbol='FBXO17', Aliases=['FBG4', 'FBX26', 'FBXO26', 'Fbx17'], description='F-box protein 17', other_designations='F-box only protein 17|F-box only protein 26|F-box protein FBG4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38941401, end_position_on_the_genomic_accession=38975742, orientation='minus', exon_count=7, OMIM=[609094], no_hdr0=''),
    115294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115294, CurrentID=0, Status='live', Symbol='PCMTD1', Aliases=[], description='protein-L-isoaspartate (D-aspartate) O-methyltransferase domain containing 1', other_designations='protein-L-isoaspartate O-methyltransferase domain-containing protein 1', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=51817575, end_position_on_the_genomic_accession=51899186, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    115330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115330, CurrentID=0, Status='live', Symbol='GPR146', Aliases=['PGR8'], description='G protein-coupled receptor 146', other_designations='probable G-protein coupled receptor 146|G-protein coupled receptor PGR8', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1044546, end_position_on_the_genomic_accession=1059261, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    115350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115350, CurrentID=0, Status='live', Symbol='FCRL1', Aliases=['CD307a', 'FCRH1', 'IFGP1', 'IRTA5'], description='Fc receptor like 1', other_designations='Fc receptor-like protein 1|IFGP family protein 1|fc receptor homolog 1|fcR-like protein 1|hIFGP1|immune receptor translocation-associated protein 5|immunoglobulin superfamily Fc receptor, gp42', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157792249, end_position_on_the_genomic_accession=157820134, orientation='minus', exon_count=12, OMIM=[606508], no_hdr0=''),
    115352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115352, CurrentID=0, Status='live', Symbol='FCRL3', Aliases=['CD307c', 'FCRH3', 'IFGP3', 'IRTA3', 'SPAP2'], description='Fc receptor like 3', other_designations='Fc receptor-like protein 3|Fc receptor homolog 3|IFGP family protein 3|SH2 domain-containing phosphatase anchor protein 2|fcR-like protein 3|hIFGP3|immune receptor translocation-associated protein 3|immunoglobulin superfamily receptor translocation associated protein 3', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157676481, end_position_on_the_genomic_accession=157700985, orientation='minus', exon_count=17, OMIM=[606510], no_hdr0=''),
    115353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115353, CurrentID=0, Status='live', Symbol='LRRC42', Aliases=['dJ167A19.4'], description='leucine rich repeat containing 42', other_designations='leucine-rich repeat-containing protein 42', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53946350, end_position_on_the_genomic_accession=53968168, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    115361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115361, CurrentID=0, Status='live', Symbol='GBP4', Aliases=['Mpa2'], description='guanylate binding protein 4', other_designations='guanylate-binding protein 4|GBP-4|GTP-binding protein 4|guanine nucleotide-binding protein 4', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89181144, end_position_on_the_genomic_accession=89198942, orientation='minus', exon_count=11, OMIM=[612466], no_hdr0=''),
    115362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115362, CurrentID=0, Status='live', Symbol='GBP5', Aliases=['GBP-5'], description='guanylate binding protein 5', other_designations='guanylate-binding protein 5|GBP-TA antigen|GTP-binding protein 5|guanine nucleotide-binding protein 5', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89256189, end_position_on_the_genomic_accession=89272860, orientation='minus', exon_count=12, OMIM=[611467], no_hdr0=''),
    115399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115399, CurrentID=0, Status='live', Symbol='LRRC56', Aliases=['CILD39', 'DNAAF12'], description='leucine rich repeat containing 56', other_designations='leucine-rich repeat-containing protein 56', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=518967, end_position_on_the_genomic_accession=554916, orientation='plus', exon_count=18, OMIM=[618227], no_hdr0=''),
    115416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115416, CurrentID=0, Status='live', Symbol='MALSU1', Aliases=['C7orf30', 'mtRsfA'], description='mitochondrial assembly of ribosomal large subunit 1', other_designations='mitochondrial assembly of ribosomal large subunit protein 1', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23298744, end_position_on_the_genomic_accession=23311729, orientation='plus', exon_count=5, OMIM=[614624], no_hdr0=''),
    115426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115426, CurrentID=0, Status='live', Symbol='UHRF2', Aliases=['NIRF', 'RNF107', 'TDRD23', 'URF2'], description='ubiquitin like with PHD and ring finger domains 2', other_designations='E3 ubiquitin-protein ligase UHRF2|Np95-like ring finger protein|RING finger protein 107|RING-type E3 ubiquitin transferase UHRF2|np95/ICBP90-like RING finger protein|nuclear protein 97|nuclear zinc finger protein NP97|ubiquitin-like PHD and RING finger domain-containing protein 2|ubiquitin-like with PHD and ring finger domains 2, E3 ubiquitin protein ligase|ubiquitin-like, containing PHD and RING finger domains, 2|ubiquitin-like-containing PHD and RING finger domains protein 2', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=6413148, end_position_on_the_genomic_accession=6507056, orientation='plus', exon_count=20, OMIM=[615211], no_hdr0=''),
    115509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115509, CurrentID=0, Status='live', Symbol='ZNF689', Aliases=['TIPUH1'], description='zinc finger protein 689', other_designations='zinc finger protein 689|transcription-involved protein upregulated in HCC 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30602558, end_position_on_the_genomic_accession=30610775, orientation='minus', exon_count=5, OMIM=[618033], no_hdr0=''),
    115548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115548, CurrentID=0, Status='live', Symbol='FCHO2', Aliases=[], description='FCH and mu domain containing endocytic adaptor 2', other_designations='F-BAR domain only protein 2|FCH domain only 2|FCH domain only protein 2', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72956041, end_position_on_the_genomic_accession=73090522, orientation='plus', exon_count=28, OMIM=[613438], no_hdr0=''),
    115557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115557, CurrentID=0, Status='live', Symbol='ARHGEF25', Aliases=['GEFT', 'p63RhoGEF'], description='Rho guanine nucleotide exchange factor 25', other_designations='rho guanine nucleotide exchange factor 25|RAC/CDC42 exchange factor|Rho guanine nucleotide exchange factor (GEF) 25|RhoA/RAC/CDC42 exchange factor|guanine nucleotide exchange factor GEFT|rac/Cdc42/Rho exchange factor GEFT|rhoA/Rac/Cdc42 guanine nucleotide exchange factor GEFT', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57610116, end_position_on_the_genomic_accession=57617245, orientation='plus', exon_count=18, OMIM=[610215], no_hdr0=''),
    115560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115560, CurrentID=0, Status='live', Symbol='ZNF501', Aliases=['ZNF', 'ZNF52'], description='zinc finger protein 501', other_designations='zinc finger protein 501|zinc finger protein 52', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44729635, end_position_on_the_genomic_accession=44737083, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    115572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115572, CurrentID=0, Status='live', Symbol='TENT5B', Aliases=['FAM46', 'FAM46B'], description='terminal nucleotidyltransferase 5B', other_designations='terminal nucleotidyltransferase 5B|family with sequence similarity 46 member B|protein FAM46B|putative nucleotidyltransferase FAM46B', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27005020, end_position_on_the_genomic_accession=27012850, orientation='minus', exon_count=2, OMIM=[619069], no_hdr0=''),
    115584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115584, CurrentID=0, Status='live', Symbol='SLC5A11', Aliases=['KST1', 'RKST1', 'SGLT6', 'SMIT2'], description='solute carrier family 5 member 11', other_designations='sodium/myo-inositol cotransporter 2|Na(+)/myo-inositol cotransporter 2|homolog of rabbit KST1|putative sodium-coupled cotransporter RKST1|sodium-dependent glucose cotransporter|sodium/glucose cotransporter KST1|sodium/myo-inositol transporter 2|solute carrier family 5 (sodium/glucose cotransporter), member 11|solute carrier family 5 (sodium/inositol cotransporter), member 11', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=24845963, end_position_on_the_genomic_accession=24911626, orientation='plus', exon_count=21, OMIM=[610238], no_hdr0=''),
    115650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115650, CurrentID=0, Status='live', Symbol='TNFRSF13C', Aliases=['BAFF-R', 'BAFFR', 'BROMIX', 'CD268', 'CVID4', 'prolixin'], description='TNF receptor superfamily member 13C', other_designations='tumor necrosis factor receptor superfamily member 13C|B cell-activating factor receptor|BAFF receptor|BLyS receptor 3', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41922032, end_position_on_the_genomic_accession=41926806, orientation='minus', exon_count=3, OMIM=[606269], no_hdr0=''),
    115653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115653, CurrentID=0, Status='live', Symbol='KIR3DL3', Aliases=['CD158Z', 'KIR3DL7', 'KIR44', 'KIRC1'], description='killer cell immunoglobulin like receptor, three Ig domains and long cytoplasmic tail 3', other_designations='killer cell immunoglobulin-like receptor 3DL3|CD158 antigen-like family member Z|KIR3DL3 Killer-cell Immunoglobulin-like Receptor|KIR3DL33DL3*novel_CDS_genomic_submission_1|killer cell Ig-like receptor KIR3DL7|killer cell immunoglobulin-like receptor, three domains, long cytoplasmic tail, 3|killer cell inhibitory receptor 1|killer-cell immunoglobulin-like receptor 3DL3|truncated killer cell immunoglobulin-like receptor 3DL3', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54724442, end_position_on_the_genomic_accession=54736632, orientation='plus', exon_count=8, OMIM=[610095], no_hdr0=''),
    115677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115677, CurrentID=0, Status='live', Symbol='NOSTRIN', Aliases=['DaIP2'], description='nitric oxide synthase trafficking', other_designations='nostrin|BM247 homolog|ENOS traffic inducer|eNOS-trafficking inducer|endothelial nitric oxide synthase traffic inducer|nitric oxide synthase traffic inducer|nitric oxide synthase trafficker|ortholog of mouse disabled 2 interacting proein 2', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=168786539, end_position_on_the_genomic_accession=168865514, orientation='plus', exon_count=25, OMIM=[607496], no_hdr0=''),
    115701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115701, CurrentID=0, Status='live', Symbol='ALPK2', Aliases=['HAK'], description='alpha kinase 2', other_designations='alpha-protein kinase 2|heart alpha-kinase|heart alpha-protein kinase', map_location='18q21.31-q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=58481247, end_position_on_the_genomic_accession=58629091, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    115703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115703, CurrentID=0, Status='live', Symbol='ARHGAP33', Aliases=['NOMA-GAP', 'SNX26', 'TCGAP'], description='Rho GTPase activating protein 33', other_designations='rho GTPase-activating protein 33|neurite outgrowth multiadaptor RhoGAP protein|rho-type GTPase-activating protein 33|sorting nexin 26|tc10/CDC42 GTPase-activating protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35775515, end_position_on_the_genomic_accession=35788822, orientation='plus', exon_count=22, OMIM=[614902], no_hdr0=''),
    115704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115704, CurrentID=0, Status='live', Symbol='EVI5L', Aliases=[], description='ecotropic viral integration site 5 like', other_designations='EVI5-like protein|ecotropic viral integration site 5-like protein|epididymis secretory sperm binding protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7830218, end_position_on_the_genomic_accession=7864976, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    115708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115708, CurrentID=0, Status='live', Symbol='TRMT61A', Aliases=['C14orf172', 'GCD14', 'Gcd14p', 'TRM61', 'hTRM61'], description='tRNA methyltransferase 61A', other_designations='tRNA (adenine(58)-N(1))-methyltransferase catalytic subunit TRMT61A|mRNA methyladenosine-N(1)-methyltransferase catalytic subunit TRMT61A|tRNA (adenine-N(1)-)-methyltransferase catalytic subunit TRM61|tRNA (adenine-N(1)-)-methyltransferase catalytic subunit TRMT61A|tRNA methyltransferase 61 homolog A|tRNA(m1A58)-methyltransferase subunit TRM61|tRNA(m1A58)-methyltransferase subunit TRMT61A|tRNA(m1A58)MTase subunit TRM61|tRNA(m1A58)MTase subunit TRMT61A', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103529196, end_position_on_the_genomic_accession=103537073, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    115727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115727, CurrentID=0, Status='live', Symbol='RASGRP4', Aliases=[], description='RAS guanyl releasing protein 4', other_designations='RAS guanyl-releasing protein 4|guanyl nucleotide releasing protein 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38409055, end_position_on_the_genomic_accession=38426219, orientation='minus', exon_count=18, OMIM=[607320], no_hdr0=''),
    115749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115749, CurrentID=0, Status='live', Symbol='C12orf56', Aliases=[], description='chromosome 12 open reading frame 56', other_designations='uncharacterized protein C12orf56', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64264762, end_position_on_the_genomic_accession=64390758, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    115752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115752, CurrentID=0, Status='live', Symbol='DIS3L', Aliases=['DIS3L1'], description="DIS3 like exosome 3'-5' exoribonuclease", other_designations='DIS3-like exonuclease 1|DIS3 mitotic control homolog-like', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66293309, end_position_on_the_genomic_accession=66333898, orientation='plus', exon_count=21, OMIM=[614183], no_hdr0=''),
    115761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115761, CurrentID=0, Status='live', Symbol='ARL11', Aliases=['ARLTS1'], description='ADP ribosylation factor like GTPase 11', other_designations='ADP-ribosylation factor-like protein 11|ADP-ribosylation factor-like 11|ADP-ribosylation factor-like tumor suppressor gene 1|ADP-ribosylation factor-like tumor suppressor protein 1', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49628456, end_position_on_the_genomic_accession=49633872, orientation='plus', exon_count=3, OMIM=[609351], no_hdr0=''),
    115795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115795, CurrentID=0, Status='live', Symbol='FANCD2OS', Aliases=['C3orf24'], description='FANCD2 opposite strand', other_designations='FANCD2 opposite strand protein|Fanconi anemia group D2 protein opposite strand transcript protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=10081320, end_position_on_the_genomic_accession=10108603, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    115811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115811, CurrentID=0, Status='live', Symbol='IQCD', Aliases=['4933433C09Rik', 'CFAP84', 'DRC10'], description='IQ motif containing D', other_designations='dynein regulatory complex protein 10|IQ domain-containing protein D|dynein regulatory complex subunit 10', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113195441, end_position_on_the_genomic_accession=113221341, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    115817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115817, CurrentID=0, Status='live', Symbol='DHRS1', Aliases=['SDR19C1'], description='dehydrogenase/reductase 1', other_designations='dehydrogenase/reductase SDR family member 1|dehydrogenase/reductase (SDR family) member 1|short chain dehydrogenase/reductase family 19C member 1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24290598, end_position_on_the_genomic_accession=24299780, orientation='minus', exon_count=10, OMIM=[610410], no_hdr0=''),
    115825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115825, CurrentID=0, Status='live', Symbol='WDFY2', Aliases=['PROF', 'WDF2', 'ZFYVE22'], description='WD repeat and FYVE domain containing 2', other_designations='WD repeat and FYVE domain-containing protein 2|WD40 and FYVE domain containing 2|WD40- and FYVE domain-containing protein 2|propeller-FYVE protein|zinc finger FYVE domain-containing protein 22', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51584194, end_position_on_the_genomic_accession=51767709, orientation='plus', exon_count=15, OMIM=[610418], no_hdr0=''),
    115827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115827, CurrentID=0, Status='live', Symbol='RAB3C', Aliases=[], description='RAB3C, member RAS oncogene family', other_designations='ras-related protein Rab-3C', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=58582152, end_position_on_the_genomic_accession=58859394, orientation='plus', exon_count=6, OMIM=[612829], no_hdr0=''),
    115861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115861, CurrentID=0, Status='live', Symbol='NXNL1', Aliases=['RDCVF', 'TXNL6'], description='nucleoredoxin like 1', other_designations='nucleoredoxin-like protein 1|rod-derived cone viability factor|thioredoxin-like 6|thioredoxin-like protein 6', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17455425, end_position_on_the_genomic_accession=17460926, orientation='minus', exon_count=2, OMIM=[608791], no_hdr0=''),
    115908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115908, CurrentID=0, Status='live', Symbol='CTHRC1', Aliases=[], description='collagen triple helix repeat containing 1', other_designations='collagen triple helix repeat-containing protein 1', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=103371538, end_position_on_the_genomic_accession=103382989, orientation='plus', exon_count=5, OMIM=[610635], no_hdr0=''),
    115939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115939, CurrentID=0, Status='live', Symbol='TSR3', Aliases=['C16orf42', 'HsTsr3'], description='TSR3 ribosome maturation factor', other_designations='18S rRNA aminocarboxypropyltransferase|20S S rRNA accumulation protein 3 homolog|TSR3, 20S rRNA accumulation, homolog|TSR3, acp transferase ribosome maturation factor|probable ribosome biogenesis protein C16orf42|ribosome biogenesis protein TSR3 homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1349240, end_position_on_the_genomic_accession=1351878, orientation='minus', exon_count=6, OMIM=[617058], no_hdr0=''),
    115948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115948, CurrentID=0, Status='live', Symbol='ODAD3', Aliases=['CCDC151', 'CILD30', 'ODA10'], description='outer dynein arm docking complex subunit 3', other_designations='outer dynein arm-docking complex subunit 3|coiled-coil domain containing 151|coiled-coil domain-containing protein 151', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11420605, end_position_on_the_genomic_accession=11435782, orientation='minus', exon_count=14, OMIM=[615956], no_hdr0=''),
    115950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115950, CurrentID=0, Status='live', Symbol='ZNF653', Aliases=['E430039K05Rik', 'ZIP67'], description='zinc finger protein 653', other_designations='zinc finger protein 653|67 kDa zinc finger protein|zinc finger protein Zip67', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11483429, end_position_on_the_genomic_accession=11505839, orientation='minus', exon_count=9, OMIM=[611371], no_hdr0=''),
    115992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115992, CurrentID=0, Status='live', Symbol='RNF166', Aliases=[], description='ring finger protein 166', other_designations='E3 ubiquitin-protein ligase RNF166|RING-type E3 ubiquitin transferase RNF166', map_location='16q24.2-q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88696499, end_position_on_the_genomic_accession=88706421, orientation='minus', exon_count=10, OMIM=[617178], no_hdr0=''),
    116028 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116028, CurrentID=0, Status='live', Symbol='RMI2', Aliases=['BLAP18', 'C16orf75'], description='RecQ mediated genome instability 2', other_designations='recQ-mediated genome instability protein 2|BLM-associated protein of 18 kDa|RMI2, RecQ mediated genome instability 2, homolog', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11345459, end_position_on_the_genomic_accession=11351760, orientation='plus', exon_count=2, OMIM=[612426], no_hdr0=''),
    116039 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116039, CurrentID=0, Status='live', Symbol='OSR2', Aliases=[], description='odd-skipped related transciption factor 2', other_designations='protein odd-skipped-related 2|odd-skipped related 2', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98944442, end_position_on_the_genomic_accession=98952100, orientation='plus', exon_count=6, OMIM=[611297], no_hdr0=''),
    116064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116064, CurrentID=0, Status='live', Symbol='LRRC58', Aliases=[], description='leucine rich repeat containing 58', other_designations='leucine-rich repeat-containing protein 58', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120324509, end_position_on_the_genomic_accession=120349354, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    116068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116068, CurrentID=0, Status='live', Symbol='LYSMD3', Aliases=[], description='LysM domain containing 3', other_designations='lysM and putative peptidoglycan-binding domain-containing protein 3|LysM, putative peptidoglycan-binding, domain containing 3', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=90515626, end_position_on_the_genomic_accession=90529616, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    116071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116071, CurrentID=0, Status='live', Symbol='BATF2', Aliases=['SARI'], description='basic leucine zipper ATF-like transcription factor 2', other_designations='basic leucine zipper transcriptional factor ATF-like 2|B-ATF-2|basic leucine zipper transcription factor, ATF-like 2|suppressor of AP-1 regulated by IFN', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64987945, end_position_on_the_genomic_accession=64996971, orientation='minus', exon_count=4, OMIM=[614983], no_hdr0=''),
    116085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116085, CurrentID=0, Status='live', Symbol='SLC22A12', Aliases=['OAT4L', 'RST', 'URAT1'], description='solute carrier family 22 member 12', other_designations='solute carrier family 22 member 12|organic anion transporter 4-like protein|renal-specific transporter|solute carrier family 22 (organic anion/cation transporter), member 12|solute carrier family 22 (organic anion/urate transporter), member 12|urate anion exchanger 1|urate transporter 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64591219, end_position_on_the_genomic_accession=64603250, orientation='plus', exon_count=9, OMIM=[607096], no_hdr0=''),
    116092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116092, CurrentID=0, Status='live', Symbol='DNTTIP1', Aliases=['C20orf167', 'Tdif1', 'dJ447F3.4'], description='deoxynucleotidyltransferase terminal interacting protein 1', other_designations='deoxynucleotidyltransferase terminal-interacting protein 1|TdT binding protein|tdT-interacting factor 1|terminal deoxynucleotidyltransferase-interacting factor 1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45791954, end_position_on_the_genomic_accession=45811419, orientation='plus', exon_count=14, OMIM=[611388], no_hdr0=''),
    116113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116113, CurrentID=0, Status='live', Symbol='FOXP4', Aliases=['hFKHLA'], description='forkhead box P4', other_designations='forkhead box protein P4|fork head-related protein like A|winged-helix repressor FOXP4', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41546381, end_position_on_the_genomic_accession=41602384, orientation='plus', exon_count=21, OMIM=[608924], no_hdr0=''),
    116115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116115, CurrentID=0, Status='live', Symbol='ZNF526', Aliases=[], description='zinc finger protein 526', other_designations='zinc finger protein 526', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42220312, end_position_on_the_genomic_accession=42228201, orientation='plus', exon_count=3, OMIM=[614387], no_hdr0=''),
    116135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116135, CurrentID=0, Status='live', Symbol='LRRC3B', Aliases=['LRP15'], description='leucine rich repeat containing 3B', other_designations='leucine-rich repeat-containing protein 3B|leucine-rich repeat protein 15|leucine-rich repeat protein LRP15', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=26622772, end_position_on_the_genomic_accession=26717301, orientation='plus', exon_count=9, OMIM=[618996], no_hdr0=''),
    116138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116138, CurrentID=0, Status='live', Symbol='KLHDC3', Aliases=['PEAS', 'dJ20C7.3'], description='kelch domain containing 3', other_designations='kelch domain-containing protein 3|testis intracellular mediator protein', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43014249, end_position_on_the_genomic_accession=43021294, orientation='plus', exon_count=11, OMIM=[611248], no_hdr0=''),
    116143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116143, CurrentID=0, Status='live', Symbol='DNAAF10', Aliases=['WDR92'], description='dynein axonemal assembly factor 10', other_designations='dynein axonemal assembly factor 10|WD repeat domain 92|WD repeat-containing protein 92|WD repeat-containing protein Monad|monad|testicular secretory protein Li 67', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68129805, end_position_on_the_genomic_accession=68157527, orientation='minus', exon_count=8, OMIM=[610729], no_hdr0=''),
    116150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116150, CurrentID=0, Status='live', Symbol='NUS1', Aliases=['C6orf68', 'CDG1AA', 'MGC:7199', 'MRD55', 'NgBR', 'TANGO14'], description='NUS1 dehydrodolichyl diphosphate synthase subunit', other_designations='dehydrodolichyl diphosphate synthase complex subunit NUS1|Nogo-B receptor|cis-prenyltransferase subunit NgBR|dehydrodolichyl diphosphate syntase complex subunit NUS1|di-trans,poly-cis-decaprenylcistransferase|nuclear undecaprenyl pyrophosphate synthase 1 homolog|transport and golgi organization 14 homolog', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117675469, end_position_on_the_genomic_accession=117710727, orientation='plus', exon_count=5, OMIM=[610463], no_hdr0=''),
    116151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116151, CurrentID=0, Status='live', Symbol='FAM210B', Aliases=['5A3', 'C20orf108', 'dJ1167H4.1'], description='family with sequence similarity 210 member B', other_designations='protein FAM210B, mitochondrial|transmembrane protein C20orf108', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56358974, end_position_on_the_genomic_accession=56368663, orientation='plus', exon_count=3, OMIM=[618722], no_hdr0=''),
    116154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116154, CurrentID=0, Status='live', Symbol='PHACTR3', Aliases=['C20orf101', 'H17739', 'PPP1R123', 'SCAPIN1', 'SCAPININ'], description='phosphatase and actin regulator 3', other_designations='phosphatase and actin regulator 3|protein phosphatase 1, regulatory subunit 123|scaffold-associated PP1-inhibiting protein', map_location='20q13.32-q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59577497, end_position_on_the_genomic_accession=59849829, orientation='plus', exon_count=21, OMIM=[608725], no_hdr0=''),
    116159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116159, CurrentID=0, Status='live', Symbol='CYYR1', Aliases=['C21orf95'], description='cysteine and tyrosine rich 1', other_designations='cysteine and tyrosine-rich protein 1|cysteine/tyrosine-rich 1|proline-rich domain-containing protein', map_location='21q21.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=26466216, end_position_on_the_genomic_accession=26573286, orientation='minus', exon_count=8, OMIM=[616020], no_hdr0=''),
    116173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116173, CurrentID=0, Status='live', Symbol='CMTM5', Aliases=['CKLFSF5'], description='CKLF like MARVEL transmembrane domain containing 5', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 5|chemokine-like factor super family 5|chemokine-like factor superfamily member 5', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23376432, end_position_on_the_genomic_accession=23379772, orientation='plus', exon_count=7, OMIM=[607888], no_hdr0=''),
    116179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116179, CurrentID=0, Status='live', Symbol='TGM7', Aliases=['TGMZ'], description='transglutaminase 7', other_designations='protein-glutamine gamma-glutamyltransferase Z|TG(Z)|TGZ|TGase Z|TGase-7|transglutaminase Z', map_location='15q15.2-q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43276271, end_position_on_the_genomic_accession=43302255, orientation='minus', exon_count=14, OMIM=[606776], no_hdr0=''),
    116211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116211, CurrentID=0, Status='live', Symbol='TM4SF19', Aliases=['OCTM4'], description='transmembrane 4 L six family member 19', other_designations='transmembrane 4 L6 family member 19|osteoclast maturation-associated gene 4 protein|tetraspan membrane protein OCTM4', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196323547, end_position_on_the_genomic_accession=196338388, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    116224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116224, CurrentID=0, Status='live', Symbol='PABIR1', Aliases=['C9orf42', 'FAM122A'], description='PP2A Aalpha (PPP2R1A) and B55A (PPP2R2A) interacting phosphatase regulator 1', other_designations='PPP2R1A-PPP2R2A-interacting phosphatase regulator 1|PABIR family member 1|family with sequence similarity 122A|protein FAM122A', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68780065, end_position_on_the_genomic_accession=68785566, orientation='plus', exon_count=1, OMIM=[617249], no_hdr0=''),
    116225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116225, CurrentID=0, Status='live', Symbol='ZMYND19', Aliases=['MIZIP'], description='zinc finger MYND-type containing 19', other_designations='zinc finger MYND domain-containing protein 19|MCH-R1-interacting zinc finger protein|melanin-concentrating hormone receptor 1 interacting zinc-finger protein|zinc finger, MYND domain containing 19', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137582079, end_position_on_the_genomic_accession=137590512, orientation='minus', exon_count=8, OMIM=[611424], no_hdr0=''),
    116228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116228, CurrentID=0, Status='live', Symbol='COX20', Aliases=['FAM36A', 'MC4DN11'], description='cytochrome c oxidase assembly factor COX20', other_designations='cytochrome c oxidase assembly protein COX20, mitochondrial|COX20 Cox2 chaperone homolog|COX20, cytochrome c oxidase assembly factor|cytochrome c oxidase protein 20 homolog|family with sequence similarity 36, member A', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244835306, end_position_on_the_genomic_accession=244845063, orientation='plus', exon_count=6, OMIM=[614698], no_hdr0=''),
    116236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116236, CurrentID=0, Status='live', Symbol='ABHD15', Aliases=[], description='abhydrolase domain containing 15', other_designations='protein ABHD15|abhydrolase domain-containing protein 15|alpha/beta hydrolase domain-containing protein 15', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29560547, end_position_on_the_genomic_accession=29567037, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    116238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116238, CurrentID=0, Status='live', Symbol='TLCD1', Aliases=[], description='TLC domain containing 1', other_designations='TLC domain-containing protein 1|calfacilitin', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28724024, end_position_on_the_genomic_accession=28727930, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    116254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116254, CurrentID=0, Status='live', Symbol='GINM1', Aliases=['C6orf72'], description='glycoprotein integral membrane 1', other_designations='glycoprotein integral membrane protein 1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149566375, end_position_on_the_genomic_accession=149591748, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    116255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116255, CurrentID=0, Status='live', Symbol='MOGAT1', Aliases=['DGAT2L', 'DGAT2L1', 'MGAT1'], description='monoacylglycerol O-acyltransferase 1', other_designations='2-acylglycerol O-acyltransferase 1|acyl-CoA:monoacylglycerol acyltransferase 1|diacylglycerol O-acyltransferase 2 like 1|diacylglycerol O-acyltransferase candidate 2|diacylglycerol acyltransferase 2-like protein 1|hDC2', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=222671658, end_position_on_the_genomic_accession=222709930, orientation='plus', exon_count=6, OMIM=[610268], no_hdr0=''),
    116285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116285, CurrentID=0, Status='live', Symbol='ACSM1', Aliases=['BUCS1', 'MACS1'], description='acyl-CoA synthetase medium chain family member 1', other_designations='acyl-coenzyme A synthetase ACSM1, mitochondrial|Butyrate CoA ligase|benzoate--CoA ligase|butyrate--CoA ligase 1|butyryl Coenzyme A synthetase 1|butyryl-coenzyme A synthetase 1|lipoate-activating enzyme|medium-chain acyl-CoA synthetase|middle-chain acyl-CoA synthetase 1|xenobiotic/medium-chain fatty acid-CoA ligase HXM-B', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20623235, end_position_on_the_genomic_accession=20697680, orientation='minus', exon_count=18, OMIM=[614357], no_hdr0=''),
    116328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116328, CurrentID=0, Status='live', Symbol='C8orf34', Aliases=['VEST-1', 'VEST1'], description='chromosome 8 open reading frame 34', other_designations='uncharacterized protein C8orf34|protein VEST-1|vestibule-1 protein', map_location='8q13.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=68330373, end_position_on_the_genomic_accession=68819023, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    116337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116337, CurrentID=0, Status='live', Symbol='PANX3', Aliases=['PX3'], description='pannexin 3', other_designations='pannexin-3|gap junction protein pannexin 3', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124611428, end_position_on_the_genomic_accession=124620356, orientation='plus', exon_count=4, OMIM=[608422], no_hdr0=''),
    116362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116362, CurrentID=0, Status='live', Symbol='RBP7', Aliases=['CRABP4', 'CRBP4', 'CRBPIV'], description='retinol binding protein 7', other_designations='retinoid-binding protein 7|cellular retinoic acid-binding protein 4|cellular retinoic acid-binding protein IV|cellular retinol binding protein 7|putative cellular retinol-binding protein CRBP IV|retinol binding protein 7, cellular', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9997228, end_position_on_the_genomic_accession=10016021, orientation='plus', exon_count=5, OMIM=[608604], no_hdr0=''),
    116369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116369, CurrentID=0, Status='live', Symbol='SLC26A8', Aliases=['SPGF3', 'TAT1'], description='solute carrier family 26 member 8', other_designations='testis anion transporter 1|anion transporter/exchanger-8|solute carrier family 26 (anion exchanger), member 8', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35943516, end_position_on_the_genomic_accession=36024641, orientation='minus', exon_count=22, OMIM=[608480], no_hdr0=''),
    116372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116372, CurrentID=0, Status='live', Symbol='LYPD1', Aliases=['LYPDC1', 'PHTS'], description='LY6/PLAUR domain containing 1', other_designations='ly6/PLAUR domain-containing protein 1|putative HeLa tumor suppressor', map_location='2q21.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=132643286, end_position_on_the_genomic_accession=132671526, orientation='minus', exon_count=6, OMIM=[610450], no_hdr0=''),
    116379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116379, CurrentID=0, Status='live', Symbol='IL22RA2', Aliases=['CRF2-10', 'CRF2-S1', 'CRF2X', 'IL-22BP', 'IL-22R-alpha-2', 'IL-22RA2', 'ZCYTOR16'], description='interleukin 22 receptor subunit alpha 2', other_designations='interleukin-22 receptor subunit alpha-2|cytokine receptor class-II member 10|cytokine receptor family type 2, soluble 1|interleukin 22 receptor, alpha 2|interleukin 22-binding protein', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=137143820, end_position_on_the_genomic_accession=137173644, orientation='minus', exon_count=7, OMIM=[606648], no_hdr0=''),
    116412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116412, CurrentID=0, Status='live', Symbol='ZNF837', Aliases=[], description='zinc finger protein 837', other_designations='zinc finger protein 837', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58367623, end_position_on_the_genomic_accession=58381030, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    116441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116441, CurrentID=0, Status='live', Symbol='TM4SF18', Aliases=['L6D'], description='transmembrane 4 L six family member 18', other_designations='transmembrane 4 L6 family member 18', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149318498, end_position_on_the_genomic_accession=149333636, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    116442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116442, CurrentID=0, Status='live', Symbol='RAB39B', Aliases=['BGMR', 'MRX72', 'WSMN', 'WSN'], description='RAB39B, member RAS oncogene family', other_designations='ras-related protein Rab-39B|Waisman syndrome (basal ganglion disorder with mental retardation)', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155258235, end_position_on_the_genomic_accession=155264491, orientation='minus', exon_count=2, OMIM=[300774, 311510], no_hdr0=''),
    116443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116443, CurrentID=0, Status='live', Symbol='GRIN3A', Aliases=['GluN3A', 'NMDAR-L', 'NMDAR3A', 'NR3A'], description='glutamate ionotropic receptor NMDA type subunit 3A', other_designations='glutamate receptor ionotropic, NMDA 3A|N-methyl-D-aspartate receptor subtype 3A|glutamate [NMDA] receptor subunit 3A|glutamate receptor, ionotropic, N-methyl-D-aspartate 3A', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=101569352, end_position_on_the_genomic_accession=101738647, orientation='minus', exon_count=10, OMIM=[606650], no_hdr0=''),
    116444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116444, CurrentID=0, Status='live', Symbol='GRIN3B', Aliases=['GluN3B', 'NR3B'], description='glutamate ionotropic receptor NMDA type subunit 3B', other_designations='glutamate receptor ionotropic, NMDA 3B|N-methyl-D-aspartate receptor subtype 3B|NMDA receptor subunit 3B|NMDA type glutamate receptor subunit NR3B|NMDAR3B|glutamate [NMDA] receptor subunit 3B|glutamate receptor, ionotropic, N-methyl-D-aspartate 3B', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1000419, end_position_on_the_genomic_accession=1009748, orientation='plus', exon_count=9, OMIM=[606651], no_hdr0=''),
    116447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116447, CurrentID=0, Status='live', Symbol='TOP1MT', Aliases=[], description='DNA topoisomerase I mitochondrial', other_designations='DNA topoisomerase I, mitochondrial|mitochondrial topoisomerase IB|topoisomerase (DNA) I, mitochondrial', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143309324, end_position_on_the_genomic_accession=143359977, orientation='minus', exon_count=16, OMIM=[606387], no_hdr0=''),
    116448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116448, CurrentID=0, Status='live', Symbol='OLIG1', Aliases=['BHLHB6', 'BHLHE21'], description='oligodendrocyte transcription factor 1', other_designations='oligodendrocyte transcription factor 1|basic domain, helix-loop-helix protein, class B, 6|class B basic helix-loop-helix protein 6|class E basic helix-loop-helix protein 21|oligo1|oligodendrocyte lineage transcription factor 1|oligodendrocyte-specific bHLH transcription factor 1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=33070141, end_position_on_the_genomic_accession=33072413, orientation='plus', exon_count=1, OMIM=[606385], no_hdr0=''),
    116449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116449, CurrentID=0, Status='live', Symbol='CLNK', Aliases=['MIST'], description='cytokine dependent hematopoietic cell linker', other_designations='cytokine-dependent hematopoietic cell linker|mast cell immunoreceptor signal transducer', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=10486395, end_position_on_the_genomic_accession=10734853, orientation='minus', exon_count=21, OMIM=[611434], no_hdr0=''),
    116461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116461, CurrentID=0, Status='live', Symbol='TSEN15', Aliases=['C1orf19', 'PCH2F', 'sen15'], description='tRNA splicing endonuclease subunit 15', other_designations='tRNA-splicing endonuclease subunit Sen15|TSEN15 tRNA splicing endonuclease subunit|tRNA splicing endonuclease 15 homolog|tRNA-intron endonuclease Sen15', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=184051730, end_position_on_the_genomic_accession=184097485, orientation='plus', exon_count=8, OMIM=[608756], no_hdr0=''),
    116496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116496, CurrentID=0, Status='live', Symbol='NIBAN1', Aliases=['C1orf24', 'FAM129A', 'GIG39', 'NIBAN'], description='niban apoptosis regulator 1', other_designations='protein Niban 1|cell growth-inhibiting gene 39 protein|family with sequence similarity 129 member A', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=184791032, end_position_on_the_genomic_accession=184974508, orientation='minus', exon_count=15, OMIM=[619294], no_hdr0=''),
    116511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116511, CurrentID=0, Status='live', Symbol='MAS1L', Aliases=['MAS-L', 'MRG', 'dJ994E9.2'], description='MAS1 proto-oncogene like, G protein-coupled receptor', other_designations='mas-related G-protein coupled receptor MRG|MAS-R|MAS1 oncogene-like|MAS1-like|mas-related G protein-coupled MRG', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29486697, end_position_on_the_genomic_accession=29487956, orientation='minus', exon_count=1, OMIM=[607235], no_hdr0=''),
    116512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116512, CurrentID=0, Status='live', Symbol='MRGPRD', Aliases=['MRGD', 'TGR7'], description='MAS related GPR family member D', other_designations='mas-related G-protein coupled receptor member D|G-protein coupled receptor TGR7|MAS-related GPR, member D|beta-alanine receptor|mas-related G protein-coupled MRGD', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68980021, end_position_on_the_genomic_accession=68980986, orientation='minus', exon_count=1, OMIM=[607231], no_hdr0=''),
    116519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116519, CurrentID=0, Status='live', Symbol='APOA5', Aliases=['APOAV', 'RAP3'], description='apolipoprotein A5', other_designations='apolipoprotein A-V|apo-AV|apolipoprotein A-V precursor variant 3|regeneration-associated protein 3', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=116789367, end_position_on_the_genomic_accession=116792420, orientation='minus', exon_count=4, OMIM=[606368], no_hdr0=''),
    116534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116534, CurrentID=0, Status='live', Symbol='MRGPRE', Aliases=['GPR167', 'MGRF', 'MRGE'], description='MAS related GPR family member E', other_designations='mas-related G-protein coupled receptor member E|G-protein coupled receptor 167|MAS-related GPR, member E|Mas-related G protein-coupled receptor F|mas-related G protein-coupled MRGE', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3225030, end_position_on_the_genomic_accession=3232417, orientation='minus', exon_count=2, OMIM=[607232], no_hdr0=''),
    116535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116535, CurrentID=0, Status='live', Symbol='MRGPRF', Aliases=['GPR140', 'GPR168', 'MRGF', 'RTA'], description='MAS related GPR family member F', other_designations='mas-related G-protein coupled receptor member F|G protein-coupled receptor MrgF|G-protein coupled receptor 140|G-protein coupled receptor 168|MAS-related GPR, member F|Mas-related G protein-coupled receptor F|mas-related G protein-coupled MRGF|mas-related gene F protein|seven transmembrane helix receptor', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69004375, end_position_on_the_genomic_accession=69013671, orientation='minus', exon_count=5, OMIM=[607233], no_hdr0=''),
    116540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116540, CurrentID=0, Status='live', Symbol='MRPL53', Aliases=['L53MT'], description='mitochondrial ribosomal protein L53', other_designations='39S ribosomal protein L53, mitochondrial|mitochondrial large ribosomal subunit protein mL53', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74471982, end_position_on_the_genomic_accession=74472680, orientation='minus', exon_count=3, OMIM=[611857], no_hdr0=''),
    116541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116541, CurrentID=0, Status='live', Symbol='MRPL54', Aliases=['L54mt', 'MRP-L54'], description='mitochondrial ribosomal protein L54', other_designations='39S ribosomal protein L54, mitochondrial|mitochondrial large ribosomal subunit protein mL54', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3762682, end_position_on_the_genomic_accession=3767565, orientation='plus', exon_count=3, OMIM=[611858], no_hdr0=''),
    116729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116729, CurrentID=0, Status='live', Symbol='PPP1R27', Aliases=['DYSFIP1'], description='protein phosphatase 1 regulatory subunit 27', other_designations='protein phosphatase 1 regulatory subunit 27|dysferlin interacting protein 1|dysferlin-interacting protein 1 (toonin)|toonin', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81833492, end_position_on_the_genomic_accession=81835050, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    116832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116832, CurrentID=0, Status='live', Symbol='RPL39L', Aliases=['L39-21', 'RPL39L'], description='ribosomal protein L39 like', other_designations='60S ribosomal protein L39-like|60S ribosomal protein L39-2|large ribosomal subunit protein eL39-like|ribosomal protein L39-like 1|ribosomal protein L39-like protein', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187120948, end_position_on_the_genomic_accession=187139496, orientation='minus', exon_count=3, OMIM=[607547], no_hdr0=''),
    116835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116835, CurrentID=0, Status='live', Symbol='HSPA12B', Aliases=['C20orf60'], description='heat shock protein family A (Hsp70) member 12B', other_designations='heat shock 70 kDa protein 12B', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=3732685, end_position_on_the_genomic_accession=3753111, orientation='plus', exon_count=15, OMIM=[610702], no_hdr0=''),
    116840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116840, CurrentID=0, Status='live', Symbol='CNTROB', Aliases=['LIP8', 'PP1221'], description='centrobin, centriole duplication and spindle assembly protein', other_designations='centrobin|LYST-interacting protein 8|LYST-interacting protein LIP8|centrobin, centrosomal BRCA2 interacting protein|centrosomal BRCA2-interacting protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7932054, end_position_on_the_genomic_accession=7949920, orientation='plus', exon_count=22, OMIM=[611425], no_hdr0=''),
    116841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116841, CurrentID=0, Status='live', Symbol='SNAP47', Aliases=['C1orf142', 'ESFI5812', 'HEL-S-290', 'HEL170', 'SNAP-47', 'SVAP1'], description='synaptosome associated protein 47', other_designations='synaptosomal-associated protein 47|epididymis luminal protein 170|epididymis secretory protein Li 290|synaptosomal-associated 47 kDa protein|synaptosomal-associated protein, 47kDa|synaptosome associated protein 47kDa', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=227728168, end_position_on_the_genomic_accession=227781228, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    116842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116842, CurrentID=0, Status='live', Symbol='LEAP2', Aliases=['LEAP-2'], description='liver enriched antimicrobial peptide 2', other_designations='liver-expressed antimicrobial peptide 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132873668, end_position_on_the_genomic_accession=132875046, orientation='plus', exon_count=3, OMIM=[611373], no_hdr0=''),
    116843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116843, CurrentID=0, Status='live', Symbol='SLC18B1', Aliases=['C6orf192', 'dJ55C23.6'], description='solute carrier family 18 member B1', other_designations='MFS-type transporter SLC18B1|MFS-type transporter C6orf192|solute carrier family 18, subfamily B, member 1', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132769370, end_position_on_the_genomic_accession=132798656, orientation='minus', exon_count=15, OMIM=[613361], no_hdr0=''),
    116844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116844, CurrentID=0, Status='live', Symbol='LRG1', Aliases=['HMFT1766', 'LRG'], description='leucine rich alpha-2-glycoprotein 1', other_designations='leucine-rich alpha-2-glycoprotein|1300008B03Rik|2310031E04Rik|leucine rich alpha 2 glycoprotein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4536402, end_position_on_the_genomic_accession=4540036, orientation='minus', exon_count=2, OMIM=[611289], no_hdr0=''),
    116931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116931, CurrentID=0, Status='live', Symbol='MED12L', Aliases=['NIZIDS', 'NOPAR', 'TNRC11L', 'TRALP', 'TRALPUSH'], description='mediator complex subunit 12L', other_designations='mediator of RNA polymerase II transcription subunit 12-like protein|mediator complex subunit 12 like|mediator of RNA polymerase II transcription, subunit 12 homolog-like|no opposite paired repeat protein|thyroid hormone receptor-associated-like protein|trinucleotide repeat-containing gene 11 protein-like', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151085664, end_position_on_the_genomic_accession=151436653, orientation='plus', exon_count=49, OMIM=[611318], no_hdr0=''),
    116966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116966, CurrentID=0, Status='live', Symbol='WDR17', Aliases=[], description='WD repeat domain 17', other_designations='WD repeat-containing protein 17|epididymis secretory sperm binding protein', map_location='4q34.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=176065841, end_position_on_the_genomic_accession=176182824, orientation='plus', exon_count=33, OMIM=[609005], no_hdr0=''),
    116969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116969, CurrentID=0, Status='live', Symbol='ART5', Aliases=['ARTC5'], description='ADP-ribosyltransferase 5', other_designations='ecto-ADP-ribosyltransferase 5|ADP-ribosyltransferase C2 and C3 toxin-like 5|NAD(P)(+)--arginine ADP-ribosyltransferase 5|mono(ADP-ribosyl)transferase 5', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3638503, end_position_on_the_genomic_accession=3642392, orientation='minus', exon_count=7, OMIM=[610625], no_hdr0=''),
    116983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116983, CurrentID=0, Status='live', Symbol='ACAP3', Aliases=['CENTB5'], description='ArfGAP with coiled-coil, ankyrin repeat and PH domains 3', other_designations='arf-GAP with coiled-coil, ANK repeat and PH domain-containing protein 3|centaurin-beta-5|cnt-b5', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1292384, end_position_on_the_genomic_accession=1307930, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    116984 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116984, CurrentID=0, Status='live', Symbol='ARAP2', Aliases=['CENTD1', 'PARX'], description='ArfGAP with RhoGAP domain, ankyrin repeat and PH domain 2', other_designations='arf-GAP with Rho-GAP domain, ANK repeat and PH domain-containing protein 2|Arf and Rho GAP adapter protein 2|centaurin-delta-1', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=36005186, end_position_on_the_genomic_accession=36244833, orientation='minus', exon_count=44, OMIM=[606645], no_hdr0=''),
    116985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116985, CurrentID=0, Status='live', Symbol='ARAP1', Aliases=['CENTD2'], description='ArfGAP with RhoGAP domain, ankyrin repeat and PH domain 1', other_designations='arf-GAP with Rho-GAP domain, ANK repeat and PH domain-containing protein 1|ARF-GAP, RHO-GAP, ankyrin repeat, and pleckstrin homology domains-containing protein 1|centaurin-delta-2|cnt-d2', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72685069, end_position_on_the_genomic_accession=72752408, orientation='minus', exon_count=36, OMIM=[606646], no_hdr0=''),
    116986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116986, CurrentID=0, Status='live', Symbol='AGAP2', Aliases=['CENTG1', 'GGAP2', 'PIKE'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 2', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 2|Arf GAP with GTP-binding protein-like, ANK repeat and PH domains 2|GTP-binding and GTPase activating protein 2|centaurin, gamma 1|phosphatidylinositol 3-kinase enhancer|phosphoinositide 3-kinase enhancer', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57723761, end_position_on_the_genomic_accession=57742201, orientation='minus', exon_count=20, OMIM=[605476], no_hdr0=''),
    116987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116987, CurrentID=0, Status='live', Symbol='AGAP1', Aliases=['AGAP-1', 'CENTG2', 'GGAP1', 'cnt-g2'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 1', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 1|Arf GAP with GTP-binding protein-like, ANK repeat and PH domains 1|GTP-binding and GTPase-activating protein 1|centaurin, gamma 2', map_location='2q37.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=235494043, end_position_on_the_genomic_accession=236131795, orientation='plus', exon_count=25, OMIM=[608651], no_hdr0=''),
    116988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116988, CurrentID=0, Status='live', Symbol='AGAP3', Aliases=['AGAP-3', 'CENTG3', 'CRAG', 'MRIP-1', 'cnt-g3'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 3', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 3|CRAM-associated GTPase|CRMP (collapsin response mediator protein) associated|MR1-interacting protein|centaurin-gamma-3', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151085867, end_position_on_the_genomic_accession=151144435, orientation='plus', exon_count=23, OMIM=[616813], no_hdr0=''),
    117143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117143, CurrentID=0, Status='live', Symbol='TADA1', Aliases=['ADA1', 'HFI1', 'STAF42L', 'hADA1', 'TADA1'], description='transcriptional adaptor 1', other_designations='transcriptional adapter 1|SPT3-associated factor 42 (STAF42)|transcriptional adapter 1-like protein|transcriptional adaptor 1 (HFI1 homolog, yeast)', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=166856510, end_position_on_the_genomic_accession=166876264, orientation='minus', exon_count=8, OMIM=[612763], no_hdr0=''),
    117144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117144, CurrentID=0, Status='live', Symbol='CATSPER1', Aliases=['CATSPER', 'SPGF7'], description='cation channel sperm associated 1', other_designations='cation channel sperm-associated protein 1|hCatSper|sperm ion channel|sperm-associated cation channel 1', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66016752, end_position_on_the_genomic_accession=66026518, orientation='minus', exon_count=12, OMIM=[606389], no_hdr0=''),
    117145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117145, CurrentID=0, Status='live', Symbol='THEM4', Aliases=['CTMP'], description='thioesterase superfamily member 4', other_designations='acyl-coenzyme A thioesterase THEM4|C-terminal modulator protein|acyl-CoA thioesterase THEM4|carboxyl-terminal modulator protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151870866, end_position_on_the_genomic_accession=151909511, orientation='minus', exon_count=7, OMIM=[606388], no_hdr0=''),
    117154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117154, CurrentID=0, Status='live', Symbol='DACH2', Aliases=[], description='dachshund family transcription factor 2', other_designations='dachshund homolog 2', map_location='Xq21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=86148451, end_position_on_the_genomic_accession=86832602, orientation='plus', exon_count=13, OMIM=[300608], no_hdr0=''),
    117155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117155, CurrentID=0, Status='live', Symbol='CATSPER2', Aliases=[], description='cation channel sperm associated 2', other_designations='cation channel sperm-associated protein 2|sperm ion channel', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43628503, end_position_on_the_genomic_accession=43648884, orientation='minus', exon_count=14, OMIM=[607249], no_hdr0=''),
    117156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117156, CurrentID=0, Status='live', Symbol='SCGB3A2', Aliases=['LU103', 'PNSP1', 'UGRP1', 'pnSP-1'], description='secretoglobin family 3A member 2', other_designations='secretoglobin family 3A member 2|pneumo secretory protein 1|uteroglobin-related protein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147878711, end_position_on_the_genomic_accession=147882191, orientation='plus', exon_count=3, OMIM=[606531], no_hdr0=''),
    117157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117157, CurrentID=0, Status='live', Symbol='SH2D1B', Aliases=['EAT2'], description='SH2 domain containing 1B', other_designations='SH2 domain-containing protein 1B|EAT-2|EWS/FLI1-activated transcript 2|SH2 domain-containing molecule EAT2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162395268, end_position_on_the_genomic_accession=162412136, orientation='minus', exon_count=4, OMIM=[608510], no_hdr0=''),
    117159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117159, CurrentID=0, Status='live', Symbol='DCD', Aliases=['AIDD-1', 'DSEP', 'HCAP', 'PIF', 'DCD'], description='dermcidin', other_designations='dermcidin|diffusible survival/evasion peptide|preproteolysin|proteolysis inducing factor|survival promoting peptide', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54644589, end_position_on_the_genomic_accession=54648365, orientation='minus', exon_count=6, OMIM=[606634], no_hdr0=''),
    117166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117166, CurrentID=0, Status='live', Symbol='WFIKKN1', Aliases=['C16orf12', 'RJD2', 'WFDC20A', 'WFIKKN'], description='WAP, follistatin/kazal, immunoglobulin, kunitz and netrin domain containing 1', other_designations='WAP, Kazal, immunoglobulin, Kunitz and NTR domain-containing protein 1|GASP-2|WAP four-disulfide core domain 20A|WAP, FS, Ig, KU, and NTR-containing protein|WAP, follistatin, immunoglobulin, kunitz and NTR domain-containing protein|growth and differentiation factor-associated serum protein 2|hGASP-2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=630985, end_position_on_the_genomic_accession=634117, orientation='plus', exon_count=2, OMIM=[608021], no_hdr0=''),
    117177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117177, CurrentID=0, Status='live', Symbol='RAB3IP', Aliases=['RABIN3', 'RABIN8'], description='RAB3A interacting protein', other_designations='rab-3A-interacting protein|SSX2 interacting protein|rab3A-interacting protein|rabin-3', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69738007, end_position_on_the_genomic_accession=69823204, orientation='plus', exon_count=17, OMIM=[608686], no_hdr0=''),
    117178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117178, CurrentID=0, Status='live', Symbol='SSX2IP', Aliases=['ADIP', 'hMsd1'], description='SSX family member 2 interacting protein', other_designations='afadin- and alpha-actinin-binding protein|SSX2-interacting protein|afadin DIL domain-interacting protein|synovial sarcoma, X breakpoint 2 interacting protein', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84643706, end_position_on_the_genomic_accession=84690757, orientation='minus', exon_count=18, OMIM=[608690], no_hdr0=''),
    117194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117194, CurrentID=0, Status='live', Symbol='MRGPRX2', Aliases=['MGRG3', 'MRGX2'], description='MAS related GPR family member X2', other_designations='mas-related G-protein coupled receptor member X2|G protein-coupled receptor MRGX2|MAS-related GPR, member X2|Mas-related G protein-coupled receptor G3', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=19054455, end_position_on_the_genomic_accession=19060717, orientation='minus', exon_count=4, OMIM=[607228], no_hdr0=''),
    117195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117195, CurrentID=0, Status='live', Symbol='MRGPRX3', Aliases=['GPCR', 'MRGX3', 'SNSR1', 'SNSR2'], description='MAS related GPR family member X3', other_designations='mas-related G-protein coupled receptor member X3|G protein-coupled receptor MRGX3|G protein-coupled receptor SNSR1|G protein-coupled receptor SNSR2|MAS-related GPR, member X3|mas-related GPCR member X3|sensory neuron-specific G-protein coupled receptor 1/2', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18120955, end_position_on_the_genomic_accession=18138488, orientation='plus', exon_count=3, OMIM=[607229], no_hdr0=''),
    117196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117196, CurrentID=0, Status='live', Symbol='MRGPRX4', Aliases=['GPCR', 'MRGX4', 'SNSR6'], description='MAS related GPR family member X4', other_designations='mas-related G-protein coupled receptor member X4|G protein-coupled receptor MRGX4|G protein-coupled receptor SNSR5|G protein-coupled receptor SNSR6|MAS-related GPR, member X4|Mas-related G protein-coupled receptor X4|sensory neuron-specific G-protein coupled receptor 5/6', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18172837, end_position_on_the_genomic_accession=18174280, orientation='plus', exon_count=1, OMIM=[607230], no_hdr0=''),
    117245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117245, CurrentID=0, Status='live', Symbol='PLAAT5', Aliases=['HRASLS5', 'HRLP5', 'HRSL5', 'PLAAT-5', 'RLP1', 'iNAT'], description='phospholipase A and acyltransferase 5', other_designations='phospholipase A and acyltransferase 5|Ca(2+)-independent N-acyltransferase|H-rev107-like protein 5|HRAS like suppressor family member 5|HRAS-like suppressor 5|calcium-independent phosphatidylethanolamine N-acyltransferase|lecithin-retinol acyltransferase (LRAT)-like protein-1|phospholipase A/acyltransferase-5|testicular tissue protein Li 90', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63461404, end_position_on_the_genomic_accession=63491203, orientation='minus', exon_count=7, OMIM=[611474], no_hdr0=''),
    117246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117246, CurrentID=0, Status='live', Symbol='FTSJ3', Aliases=['EPCS3', 'SPB1'], description="FtsJ RNA 2'-O-methyltransferase 3", other_designations="pre-rRNA 2'-O-ribose RNA methyltransferase FTSJ3|2'-O-ribose RNA methyltransferase SPB1 homolog|FtsJ RNA methyltransferase homolog 3|FtsJ homolog 3|SPB1 RNA methyltransferase homolog|pre-rRNA processing protein FTSJ3|protein ftsJ homolog 3|putative rRNA methyltransferase 3|rRNA (uridine-2'-O-)-methyltransferase 3", map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63819433, end_position_on_the_genomic_accession=63827663, orientation='minus', exon_count=22, OMIM=[618411], no_hdr0=''),
    117247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117247, CurrentID=0, Status='live', Symbol='SLC16A10', Aliases=['MCT10', 'PRO0813', 'TAT1'], description='solute carrier family 16 member 10', other_designations='monocarboxylate transporter 10|MCT 10|T-type amino acid transporter 1|aromatic amino acid transporter 1|solute carrier family 16 (aromatic amino acid transporter), member 10|solute carrier family 16 (monocarboxylic acid transporters), member 10|solute carrier family 16, member 10 (aromatic amino acid transporter)', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=111087503, end_position_on_the_genomic_accession=111231194, orientation='plus', exon_count=10, OMIM=[607550], no_hdr0=''),
    117248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117248, CurrentID=0, Status='live', Symbol='GALNT15', Aliases=['GALNACT15', 'GALNT13', 'GALNT7', 'GALNTL2', 'PIH5', 'pp-GalNAc-T15'], description='polypeptide N-acetylgalactosaminyltransferase 15', other_designations='polypeptide N-acetylgalactosaminyltransferase 15|UDP-GalNAc transferase T15|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase-like protein 2|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 15|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 7|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase-like 2|galNAc-T-like protein 2|polypeptide GalNAc transferase 15|polypeptide GalNAc transferase-like protein 2|polypeptide N-acetylgalactosaminyltransferase 13|polypeptide N-acetylgalactosaminyltransferase-like protein 2|pp-GaNTase-like protein 2|pregnancy-induced hypertension syndrome-related protein 5|protein-UDP acetylgalactosaminyltransferase-like protein 2', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16174579, end_position_on_the_genomic_accession=16248224, orientation='plus', exon_count=13, OMIM=[615131], no_hdr0=''),
    117283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117283, CurrentID=0, Status='live', Symbol='IP6K3', Aliases=['IHPK3', 'INSP6K3'], description='inositol hexakisphosphate kinase 3', other_designations='inositol hexakisphosphate kinase 3|ATP:1D-myo-inositol-hexakisphosphate phosphotransferase|InsP6 kinase 3|inositol hexaphosphate kinase 3', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33721476, end_position_on_the_genomic_accession=33755671, orientation='minus', exon_count=12, OMIM=[606993], no_hdr0=''),
    117285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117285, CurrentID=0, Status='live', Symbol='DEFB118', Aliases=['C20orf63', 'DEFB-18', 'ESC42', 'ESP13.6'], description='defensin beta 118', other_designations='beta-defensin 118|defensin, beta 18|epididymal secretory protein 13.6|epididymis secretory sperm binding protein|epididymus specific clone 42', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31368601, end_position_on_the_genomic_accession=31373923, orientation='plus', exon_count=2, OMIM=[607650], no_hdr0=''),
    117286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117286, CurrentID=0, Status='live', Symbol='CIB3', Aliases=['KIP3'], description='calcium and integrin binding family member 3', other_designations='calcium and integrin-binding family member 3|DNA-dependent protein kinase catalytic subunit-interacting protein 3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16161368, end_position_on_the_genomic_accession=16173525, orientation='minus', exon_count=6, OMIM=[610645], no_hdr0=''),
    117289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117289, CurrentID=0, Status='live', Symbol='TAGAP', Aliases=['ARHGAP47', 'FKSG15', 'IDDM211', 'TAGAP'], description='T cell activation RhoGTPase activating protein', other_designations='T-cell activation Rho GTPase-activating protein', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159034481, end_position_on_the_genomic_accession=159044991, orientation='minus', exon_count=10, OMIM=[609667], no_hdr0=''),
    117531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117531, CurrentID=0, Status='live', Symbol='TMC1', Aliases=['DFNA36', 'DFNB11', 'DFNB7'], description='transmembrane channel like 1', other_designations='transmembrane channel-like protein 1|transmembrane cochlear-expressed protein 1|transmembrane, cochlear expressed, 1', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=72521608, end_position_on_the_genomic_accession=72838297, orientation='plus', exon_count=25, OMIM=[606706], no_hdr0=''),
    117532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117532, CurrentID=0, Status='live', Symbol='TMC2', Aliases=['C20orf145'], description='transmembrane channel like 2', other_designations='transmembrane channel-like protein 2|transmembrane cochlear-expressed gene 2|transmembrane cochlear-expressed protein 2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2536573, end_position_on_the_genomic_accession=2643580, orientation='plus', exon_count=20, OMIM=[606707], no_hdr0=''),
    117579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117579, CurrentID=0, Status='live', Symbol='RLN3', Aliases=['H3', 'RXN3', 'ZINS4', 'insl7'], description='relaxin 3', other_designations='relaxin-3|insulin-like peptide 7|insulin-like peptide INSL7|prorelaxin H3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14028148, end_position_on_the_genomic_accession=14031551, orientation='plus', exon_count=3, OMIM=[606855], no_hdr0=''),
    117581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117581, CurrentID=0, Status='live', Symbol='TWIST2', Aliases=['AMS', 'BBRSAY', 'DERMO1', 'FFDD3', 'SETLSS', 'bHLHa39'], description='twist family bHLH transcription factor 2', other_designations='twist-related protein 2|class A basic helix-loop-helix protein 39|dermis-expressed protein 1|twist basic helix-loop-helix transcription factor 2|twist homolog 2|twist-related bHLH protein Dermo1', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238848085, end_position_on_the_genomic_accession=238910534, orientation='plus', exon_count=3, OMIM=[607556], no_hdr0=''),
    117583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117583, CurrentID=0, Status='live', Symbol='PARD3B', Aliases=['ALS2CR19', 'PAR3B', 'PAR3L', 'PAR3beta'], description='par-3 family cell polarity regulator beta', other_designations='partitioning defective 3 homolog B|PAR3-L protein|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 19|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 19 protein|par-3 partitioning defective 3 homolog B|partitioning defective 3-like protein|partitioning-defective 3-beta', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=204545475, end_position_on_the_genomic_accession=205620162, orientation='plus', exon_count=33, OMIM=[619353], no_hdr0=''),
    117584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117584, CurrentID=0, Status='live', Symbol='RFFL', Aliases=['CARP-2', 'CARP2', 'FRING', 'RIFIFYLIN', 'RNF189', 'RNF34L'], description='ring finger and FYVE like domain containing E3 ubiquitin protein ligase', other_designations='E3 ubiquitin-protein ligase rififylin|FYVE-RING finger protein SAKURA|RING finger and FYVE-like domain-containing protein 1|RING finger protein 189|RING-type E3 ubiquitin transferase rififylin|caspase 8 and 10 associated RING protein-2|caspase regulator CARP2|caspases-8 and -10-associated RING finger protein 2|ring finger and FYVE-like domain containing 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35005990, end_position_on_the_genomic_accession=35089226, orientation='minus', exon_count=8, OMIM=[609735], no_hdr0=''),
    117608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117608, CurrentID=0, Status='live', Symbol='ZNF354B', Aliases=['KID2'], description='zinc finger protein 354B', other_designations='zinc finger protein 354B', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178859953, end_position_on_the_genomic_accession=178885020, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    117854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117854, CurrentID=0, Status='live', Symbol='TRIM6', Aliases=['RNF89'], description='tripartite motif containing 6', other_designations='tripartite motif-containing protein 6|RING finger protein 89|RING-type E3 ubiquitin transferase TRIM6', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5596111, end_position_on_the_genomic_accession=5612952, orientation='plus', exon_count=9, OMIM=[607564], no_hdr0=''),
    118424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118424, CurrentID=0, Status='live', Symbol='UBE2J2', Aliases=['NCUBE-2', 'NCUBE2', 'PRO2121'], description='ubiquitin conjugating enzyme E2 J2', other_designations='ubiquitin-conjugating enzyme E2 J2|E2 ubiquitin-conjugating enzyme J2|non-canonical ubiquitin-conjugating enzyme 2|ubiquitin conjugating enzyme 6|ubiquitin-conjugating enzyme E2, J2 (UBC6 homolog, yeast)|yeast UBC6 homolog', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1253912, end_position_on_the_genomic_accession=1273854, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    118426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118426, CurrentID=0, Status='live', Symbol='BORCS5', Aliases=['LOH12CR1', 'LOH1CR12'], description='BLOC-1 related complex subunit 5', other_designations='BLOC-1-related complex subunit 5|loss of heterozygosity 12 chromosomal region 1 protein|loss of heterozygosity, 12, chromosomal region 1|myristoylated lysosomal protein|myrlysin', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=12357078, end_position_on_the_genomic_accession=12471233, orientation='plus', exon_count=6, OMIM=[616598], no_hdr0=''),
    118427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118427, CurrentID=0, Status='live', Symbol='OLFM3', Aliases=['NOE3', 'NOELIN3', 'OPTIMEDIN'], description='olfactomedin 3', other_designations='noelin-3|olfactomedin related ER localized protein 3', map_location='1p21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=101800028, end_position_on_the_genomic_accession=101996926, orientation='minus', exon_count=10, OMIM=[607567], no_hdr0=''),
    118429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118429, CurrentID=0, Status='live', Symbol='ANTXR2', Aliases=['CMG-2', 'CMG2', 'HFS', 'ISH', 'JHF'], description='ANTXR cell adhesion molecule 2', other_designations='anthrax toxin receptor 2|capillary morphogenesis gene 2 protein|capillary morphogenesis protein 2', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=79901146, end_position_on_the_genomic_accession=80073472, orientation='minus', exon_count=18, OMIM=[608041], no_hdr0=''),
    118430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118430, CurrentID=0, Status='live', Symbol='MUCL1', Aliases=['SBEM'], description='mucin like 1', other_designations='mucin-like protein 1|small breast epithelial mucin', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54854516, end_position_on_the_genomic_accession=54858387, orientation='plus', exon_count=4, OMIM=[610857], no_hdr0=''),
    118442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118442, CurrentID=0, Status='live', Symbol='GPR62', Aliases=['GPCR8', 'KPG_005'], description='G protein-coupled receptor 62', other_designations='G-protein coupled receptor 62|G-protein coupled receptor GPCR8|G-protein coupled receptor KPG_005|hGPCR8|probable G-protein coupled receptor 62', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51955381, end_position_on_the_genomic_accession=51957499, orientation='plus', exon_count=1, OMIM=[606917], no_hdr0=''),
    118460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118460, CurrentID=0, Status='live', Symbol='EXOSC6', Aliases=['EAP4', 'MTR3', 'Mtr3p', 'hMtr3p', 'p11'], description='exosome component 6', other_designations='exosome complex component MTR3|Mtr3 (mRNA transport regulator 3)-homolog|exosome complex exonuclease MTR3|hMtr3|homolog of yeast mRNA transport regulator 3|mRNA transport regulator 3 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70246778, end_position_on_the_genomic_accession=70251940, orientation='minus', exon_count=1, OMIM=[606490], no_hdr0=''),
    118461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118461, CurrentID=0, Status='live', Symbol='C10orf71', Aliases=['CEFIP'], description='chromosome 10 open reading frame 71', other_designations='cardiac-enriched FHL2-interacting protein|cardiac enriched FHL2-interacting protein|uncharacterized protein C10orf71', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49297009, end_position_on_the_genomic_accession=49330145, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    118471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118471, CurrentID=0, Status='live', Symbol='PRAP1', Aliases=['PRO1195', 'UPA'], description='proline rich acidic protein 1', other_designations='proline-rich acidic protein 1|epididymis secretory sperm binding protein|epididymis tissue protein Li 178', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133347373, end_position_on_the_genomic_accession=133352683, orientation='plus', exon_count=5, OMIM=[609776], no_hdr0=''),
    118472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118472, CurrentID=0, Status='live', Symbol='ZNF511', Aliases=['Zfp511'], description='zinc finger protein 511', other_designations='zinc finger protein 511', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133308914, end_position_on_the_genomic_accession=133313161, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    118487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118487, CurrentID=0, Status='live', Symbol='CHCHD1', Aliases=['C10orf34', 'C2360', 'MRP-S37'], description='coiled-coil-helix-coiled-coil-helix domain containing 1', other_designations='coiled-coil-helix-coiled-coil-helix domain-containing protein 1|28S ribosomal protein S37, mitochondrial|mitochondrial small ribosomal subunit protein mS37|nuclear protein C2360', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73782048, end_position_on_the_genomic_accession=73783652, orientation='plus', exon_count=3, OMIM=[608842], no_hdr0=''),
    118490 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118490, CurrentID=0, Status='live', Symbol='MSS51', Aliases=['ZMYND17'], description='MSS51 mitochondrial translational activator', other_designations='putative protein MSS51 homolog, mitochondrial|MSS51 mitochondrial translational activator homolog|zinc finger MYND domain-containing protein 17|zinc finger, MYND domain containing 17|zinc finger, MYND-type containing 17', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73423579, end_position_on_the_genomic_accession=73433561, orientation='minus', exon_count=7, OMIM=[614773], no_hdr0=''),
    118491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118491, CurrentID=0, Status='live', Symbol='CFAP70', Aliases=['SPGF41', 'TTC18'], description='cilia and flagella associated protein 70', other_designations='cilia- and flagella-associated protein 70|TPR repeat protein 18|tetratricopeptide repeat domain 18|tetratricopeptide repeat protein 18|tetratricopeptide repeat-containing protein (LOC118491)', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73253758, end_position_on_the_genomic_accession=73361064, orientation='minus', exon_count=31, OMIM=[618661], no_hdr0=''),
    118611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118611, CurrentID=0, Status='live', Symbol='C10orf90', Aliases=['FATS', 'bA422P15.2'], description='chromosome 10 open reading frame 90', other_designations='(E2-independent) E3 ubiquitin-conjugating enzyme FATS|E2/E3 hybrid ubiquitin-protein ligase FATS|centrosomal protein C10orf90|fragile-site associated tumor suppressor homolog', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=126424997, end_position_on_the_genomic_accession=126670693, orientation='minus', exon_count=19, OMIM=[617735], no_hdr0=''),
    118663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118663, CurrentID=0, Status='live', Symbol='BTBD16', Aliases=['C10orf87'], description='BTB domain containing 16', other_designations='BTB/POZ domain-containing protein 16', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122270745, end_position_on_the_genomic_accession=122338160, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    118670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118670, CurrentID=0, Status='live', Symbol='FAM24A', Aliases=[], description='family with sequence similarity 24 member A', other_designations='protein FAM24A', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122910595, end_position_on_the_genomic_accession=122913111, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    118672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118672, CurrentID=0, Status='live', Symbol='PSTK', Aliases=['C10orf89'], description='phosphoseryl-tRNA kinase', other_designations='L-seryl-tRNA(Sec) kinase|O-phosphoseryl-tRNA(Sec) kinase', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122980401, end_position_on_the_genomic_accession=122990390, orientation='plus', exon_count=8, OMIM=[611310], no_hdr0=''),
    118738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118738, CurrentID=0, Status='live', Symbol='ZNF488', Aliases=[], description='zinc finger protein 488', other_designations='zinc finger protein 488', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47365482, end_position_on_the_genomic_accession=47384339, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    118788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118788, CurrentID=0, Status='live', Symbol='PIK3AP1', Aliases=['BCAP'], description='phosphoinositide-3-kinase adaptor protein 1', other_designations='phosphoinositide 3-kinase adapter protein 1|B cell adaptor protein|B-cell adapter for phosphoinositide 3-kinase|B-cell phosphoinositide 3-kinase adapter protein 1', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=96593312, end_position_on_the_genomic_accession=96720514, orientation='minus', exon_count=19, OMIM=[607942], no_hdr0=''),
    118812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118812, CurrentID=0, Status='live', Symbol='MORN4', Aliases=['C10orf83', 'UTA', 'bA548K23.4', 'rtp'], description='MORN repeat containing 4', other_designations='MORN repeat-containing protein 4|44050 protein|protein 44050|retinophilin homolog', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97614555, end_position_on_the_genomic_accession=97634156, orientation='minus', exon_count=7, OMIM=[617736], no_hdr0=''),
    118813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118813, CurrentID=0, Status='live', Symbol='ZFYVE27', Aliases=['PROTRUDIN', 'SPG33'], description='zinc finger FYVE-type containing 27', other_designations='protrudin|spastic paraplegia 33 protein|zinc finger FYVE domain containing 27', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97737123, end_position_on_the_genomic_accession=97760896, orientation='plus', exon_count=16, OMIM=[610243], no_hdr0=''),
    118856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118856, CurrentID=0, Status='live', Symbol='MMP21', Aliases=['HTX7', 'MMP-21'], description='matrix metallopeptidase 21', other_designations='matrix metalloproteinase-21|matrix metalloproteinase 21', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125766453, end_position_on_the_genomic_accession=125775821, orientation='minus', exon_count=7, OMIM=[608416], no_hdr0=''),
    118881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118881, CurrentID=0, Status='live', Symbol='COMTD1', Aliases=[], description='catechol-O-methyltransferase domain containing 1', other_designations='catechol O-methyltransferase domain-containing protein 1', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75233641, end_position_on_the_genomic_accession=75236027, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    118924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118924, CurrentID=0, Status='live', Symbol='FRA10AC1', Aliases=['C10orf4', 'F26C11.1-like', 'FRA10A'], description='FRA10A associated CGG repeat 1', other_designations='protein FRA10AC1|fragile site 10q23.3|fragile site, folic acid type, rare, fra(10)(q23.3) or fra(10)(q24.2) candidate 1|rare folic acid-type fragile site, FRA(10)(q23.3), candidate gene 1', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93667883, end_position_on_the_genomic_accession=93702959, orientation='minus', exon_count=16, OMIM=[608866], no_hdr0=''),
    118932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118932, CurrentID=0, Status='live', Symbol='ANKRD22', Aliases=[], description='ankyrin repeat domain 22', other_designations='ankyrin repeat domain-containing protein 22', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88819896, end_position_on_the_genomic_accession=88851844, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    118980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118980, CurrentID=0, Status='live', Symbol='SFXN2', Aliases=['SLC56A2'], description='sideroflexin 2', other_designations='sideroflexin-2', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102714631, end_position_on_the_genomic_accession=102743492, orientation='plus', exon_count=17, OMIM=[615570], no_hdr0=''),
    118987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118987, CurrentID=0, Status='live', Symbol='PDZD8', Aliases=['PDZK8'], description='PDZ domain containing 8', other_designations='PDZ domain-containing protein 8|sarcoma antigen NY-SAR-84/NY-SAR-104', map_location='10q25.3-q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=117277274, end_position_on_the_genomic_accession=117375492, orientation='minus', exon_count=8, OMIM=[614235], no_hdr0=''),
    119016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119016, CurrentID=0, Status='live', Symbol='AGAP4', Aliases=['AGAP-4', 'AGAP-8', 'AGAP8', 'CTGLF1', 'CTGLF5', 'MRIP2'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 4', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 4|ARF GTPase-activating protein|ArfGAP with GTPase domain, ankyrin repeat and PH domain 8|arf-GAP with GTPase, ANK repeat and PH domain-containing protein 8|centaurin, gamma-like family, member 1|centaurin, gamma-like family, member 5', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45825594, end_position_on_the_genomic_accession=45854690, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    119032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119032, CurrentID=0, Status='live', Symbol='BORCS7', Aliases=['C10orf32'], description='BLOC-1 related complex subunit 7', other_designations='BLOC-1-related complex subunit 7|UPF0693 protein C10orf32|diaskedin', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102854259, end_position_on_the_genomic_accession=102864961, orientation='plus', exon_count=5, OMIM=[616600], no_hdr0=''),
    119180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119180, CurrentID=0, Status='live', Symbol='LYZL2', Aliases=['LYZD2'], description='lysozyme like 2', other_designations='lysozyme-like protein 2|lysozyme D2|lysozyme-2', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=30606222, end_position_on_the_genomic_accession=30629761, orientation='minus', exon_count=8, OMIM=[612748], no_hdr0=''),
    119391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119391, CurrentID=0, Status='live', Symbol='GSTO2', Aliases=['GSTO 2-2', 'bA127L20.1'], description='glutathione S-transferase omega 2', other_designations='glutathione S-transferase omega-2|GSTO-2|MMA(V) reductase|bA127L20.1 (novel glutathione-S-transferase)|glutathione S-transferase omega 2-2|glutathione-S-transferase-like protein|glutathione-dependent dehydroascorbate reductase|monomethylarsonic acid reductase', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104267626, end_position_on_the_genomic_accession=104304950, orientation='plus', exon_count=9, OMIM=[612314], no_hdr0=''),
    119392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119392, CurrentID=0, Status='live', Symbol='SFR1', Aliases=['C10orf78', 'MEI5', 'MEIR5', 'bA373N18.1'], description='SWI5 dependent homologous recombination repair protein 1', other_designations='swi5-dependent recombination DNA repair protein 1 homolog|MEI5 recombination repair protein homolog|SWI5-dependent recombination repair 1|SWI5-dependent recombination repair protein 1|meiosis protein 5 homolog', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104120166, end_position_on_the_genomic_accession=104126385, orientation='plus', exon_count=6, OMIM=[616527], no_hdr0=''),
    119395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119395, CurrentID=0, Status='live', Symbol='CALHM3', Aliases=['FAM26A', 'bA225H22.7'], description='calcium homeostasis modulator 3', other_designations='calcium homeostasis modulator protein 3|family with sequence similarity 26, member A|protein A', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103472804, end_position_on_the_genomic_accession=103479240, orientation='minus', exon_count=3, OMIM=[618263], no_hdr0=''),
    119467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119467, CurrentID=0, Status='live', Symbol='CLRN3', Aliases=['TMEM12', 'USH3AL1'], description='clarin 3', other_designations='clarin-3|transmembrane protein 12|usher syndrome type-3A-like protein 1', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=127877841, end_position_on_the_genomic_accession=127892946, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    119504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119504, CurrentID=0, Status='live', Symbol='ANAPC16', Aliases=['APC16', 'C10orf104', 'CENP-27', 'MSAG', 'bA570G20.3'], description='anaphase promoting complex subunit 16', other_designations='anaphase-promoting complex subunit 16|centromere protein 27|cyclosome subunit 16|metabolic syndrome-associated protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72216012, end_position_on_the_genomic_accession=72235860, orientation='plus', exon_count=5, OMIM=[613427], no_hdr0=''),
    119548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119548, CurrentID=0, Status='live', Symbol='PNLIPRP3', Aliases=[], description='pancreatic lipase related protein 3', other_designations='pancreatic lipase-related protein 3|PL-RP3', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116427847, end_position_on_the_genomic_accession=116477961, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    119559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119559, CurrentID=0, Status='live', Symbol='SFXN4', Aliases=['BCRM1', 'COXPD18', 'SLC56A4'], description='sideroflexin 4', other_designations='sideroflexin-4|breast cancer resistance marker 1', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119140767, end_position_on_the_genomic_accession=119165728, orientation='minus', exon_count=16, OMIM=[615564], no_hdr0=''),
    119587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119587, CurrentID=0, Status='live', Symbol='CPXM2', Aliases=['CPX2', 'UNQ676'], description='carboxypeptidase X, M14 family member 2', other_designations='inactive carboxypeptidase-like protein X2|4632435C11Rik|carboxypeptidase Hlo|carboxypeptidase X (M14 family), member 2|carboxypeptidase-like protein X2|cytosolic carboxypeptidase', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123745636, end_position_on_the_genomic_accession=123944094, orientation='minus', exon_count=21, OMIM=[617348], no_hdr0=''),
    119678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119678, CurrentID=0, Status='live', Symbol='OR52E2', Aliases=[], description='olfactory receptor family 52 subfamily E member 2', other_designations='olfactory receptor 52E2|olfactory receptor, family 10, subfamily AC, member 1 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5058650, end_position_on_the_genomic_accession=5059627, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    119679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119679, CurrentID=0, Status='live', Symbol='OR52J3', Aliases=['OR11-32'], description='olfactory receptor family 52 subfamily J member 3', other_designations='olfactory receptor 52J3|olfactory receptor OR11-32', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5046526, end_position_on_the_genomic_accession=5047461, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    119682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119682, CurrentID=0, Status='live', Symbol='OR51L1', Aliases=['OR11-31'], description='olfactory receptor family 51 subfamily L member 1', other_designations='olfactory receptor 51L1|olfactory receptor OR11-31', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4994851, end_position_on_the_genomic_accession=5005536, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    119687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119687, CurrentID=0, Status='live', Symbol='OR51A7', Aliases=['OR11-27'], description='olfactory receptor family 51 subfamily A member 7', other_designations='olfactory receptor 51A7|olfactory receptor OR11-27', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4903783, end_position_on_the_genomic_accession=4909462, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    119692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119692, CurrentID=0, Status='live', Symbol='OR51S1', Aliases=['OR11-24'], description='olfactory receptor family 51 subfamily S member 1', other_designations='olfactory receptor 51S1|olfactory receptor OR11-24', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4848237, end_position_on_the_genomic_accession=4849208, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    119694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119694, CurrentID=0, Status='live', Symbol='OR51F2', Aliases=['OR11-23'], description='olfactory receptor family 51 subfamily F member 2', other_designations='olfactory receptor 51F2|olfactory receptor OR11-23', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4821321, end_position_on_the_genomic_accession=4822456, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    119695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119695, CurrentID=0, Status='live', Symbol='OR52R1', Aliases=['OR11-22'], description='olfactory receptor family 52 subfamily R member 1', other_designations='olfactory receptor 52R1|olfactory receptor OR11-22', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4803433, end_position_on_the_genomic_accession=4804380, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    119710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119710, CurrentID=0, Status='live', Symbol='IFTAP', Aliases=['C11orf74', 'HEPIS', 'NWC'], description='intraflagellar transport associated protein', other_designations='intraflagellar transport-associated protein|protein C11orf74|uncharacterized protein C11orf74', map_location='11p12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=36594246, end_position_on_the_genomic_accession=36659272, orientation='plus', exon_count=8, OMIM=[619270], no_hdr0=''),
    119749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119749, CurrentID=0, Status='live', Symbol='OR4C46', Aliases=[], description='olfactory receptor family 4 subfamily C member 46', other_designations='olfactory receptor 4C46', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=54603069, end_position_on_the_genomic_accession=54603998, orientation='minus', exon_count=1, OMIM=[614273], no_hdr0=''),
    119764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119764, CurrentID=0, Status='live', Symbol='OR4X2', Aliases=['OR11-105'], description='olfactory receptor family 4 subfamily X member 2', other_designations='olfactory receptor 4X2|olfactory receptor OR11-105', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48245104, end_position_on_the_genomic_accession=48246015, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    119765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119765, CurrentID=0, Status='live', Symbol='OR4B1', Aliases=['OR11-106', 'OST208'], description='olfactory receptor family 4 subfamily B member 1', other_designations='olfactory receptor 4B1|olfactory receptor OR11-106', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48216810, end_position_on_the_genomic_accession=48217739, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    119772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119772, CurrentID=0, Status='live', Symbol='OR52M1', Aliases=['OR11-11P', 'OR52M3P', 'OR52M1'], description='olfactory receptor family 52 subfamily M member 1', other_designations='olfactory receptor 52M1|olfactory receptor OR11-11|olfactory receptor, family 52, subfamily M, member 1 pseudogene|olfactory receptor, family 52, subfamily M, member 3 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4545191, end_position_on_the_genomic_accession=4546144, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    119774 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119774, CurrentID=0, Status='live', Symbol='OR52K2', Aliases=['OR11-7'], description='olfactory receptor family 52 subfamily K member 2', other_designations='olfactory receptor 52K2|olfactory receptor OR11-7', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4449295, end_position_on_the_genomic_accession=4450361, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    120065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120065, CurrentID=0, Status='live', Symbol='OR5P2', Aliases=['JCG3', 'JCG4'], description='olfactory receptor family 5 subfamily P member 2', other_designations='olfactory receptor 5P2|olfactory receptor OR11-93|olfactory receptor-like protein JCG3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7795974, end_position_on_the_genomic_accession=7796942, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    120066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120066, CurrentID=0, Status='live', Symbol='OR5P3', Aliases=['JCG1'], description='olfactory receptor family 5 subfamily P member 3', other_designations='olfactory receptor 5P3|olfactory receptor OR11-94|olfactory receptor-like protein JCG1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7824818, end_position_on_the_genomic_accession=7830840, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    120071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120071, CurrentID=0, Status='live', Symbol='LARGE2', Aliases=['GYLTL1B', 'PP5656'], description='LARGE xylosyl- and glucuronyltransferase 2', other_designations='LARGE xylosyl- and glucuronyltransferase 2|glycosyltransferase-like 1B|glycosyltransferase-like protein LARGE2|like-glycosyltransferase 2|ortholog of mouse glycosyltransferase-like 1B', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45921621, end_position_on_the_genomic_accession=45929096, orientation='plus', exon_count=17, OMIM=[609709], no_hdr0=''),
    120103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120103, CurrentID=0, Status='live', Symbol='SLC36A4', Aliases=['PAT4'], description='solute carrier family 36 member 4', other_designations='proton-coupled amino acid transporter 4|solute carrier family 36 (proton/amino acid symporter), member 4', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93144174, end_position_on_the_genomic_accession=93386038, orientation='minus', exon_count=15, OMIM=[613760], no_hdr0=''),
    120114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120114, CurrentID=0, Status='live', Symbol='FAT3', Aliases=['CDHF15', 'CDHR10', 'hFat3'], description='FAT atypical cadherin 3', other_designations='protocadherin Fat 3|FAT tumor suppressor homolog 3|cadherin family member 15|cadherin-related family member 10', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=92224636, end_position_on_the_genomic_accession=92896473, orientation='plus', exon_count=34, OMIM=[612483], no_hdr0=''),
    120146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120146, CurrentID=0, Status='live', Symbol='TRIM64', Aliases=['C11orf28A', 'TRIM64'], description='tripartite motif containing 64', other_designations='tripartite motif-containing protein 64', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89966037, end_position_on_the_genomic_accession=89974072, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    120224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120224, CurrentID=0, Status='live', Symbol='TMEM45B', Aliases=[], description='transmembrane protein 45B', other_designations='transmembrane protein 45B', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=129815828, end_position_on_the_genomic_accession=129860003, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    120227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120227, CurrentID=0, Status='live', Symbol='CYP2R1', Aliases=[], description='cytochrome P450 family 2 subfamily R member 1', other_designations='vitamin D 25-hydroxylase|cytochrome P450 2R1|cytochrome P450, family 2, R1|cytochrome P450, family 2, subfamily R, polypeptide 1', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=14877440, end_position_on_the_genomic_accession=14898915, orientation='minus', exon_count=9, OMIM=[608713], no_hdr0=''),
    120237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120237, CurrentID=0, Status='live', Symbol='DBX1', Aliases=[], description='developing brain homeobox 1', other_designations='homeobox protein DBX1|developing brain homeobox protein 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=20156155, end_position_on_the_genomic_accession=20160475, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    120376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120376, CurrentID=0, Status='live', Symbol='COLCA2', Aliases=['C11orf93', 'CASC13', 'LOH11CR1G'], description='colorectal cancer associated 2', other_designations='colorectal cancer-associated protein 2|cancer susceptibility candidate 13|cancer susceptibility candidate protein 13|colorectal cancer associated two', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111298349, end_position_on_the_genomic_accession=111308735, orientation='plus', exon_count=10, OMIM=[615694], no_hdr0=''),
    120379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120379, CurrentID=0, Status='live', Symbol='PIH1D2', Aliases=['DNAAF15'], description='PIH1 domain containing 2', other_designations='PIH1 domain-containing protein 2', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112052161, end_position_on_the_genomic_accession=112074034, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    120400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120400, CurrentID=0, Status='live', Symbol='NXPE1', Aliases=['FAM55A'], description='neurexophilin and PC-esterase domain family member 1', other_designations='NXPE family member 1|family with sequence similarity 55, member A|protein FAM55A', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114518934, end_position_on_the_genomic_accession=114560244, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    120406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120406, CurrentID=0, Status='live', Symbol='NXPE2', Aliases=['FAM55B'], description='neurexophilin and PC-esterase domain family member 2', other_designations='NXPE family member 2|family with sequence similarity 55, member B|protein FAM55B', map_location='11q23.2-q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=114464276, end_position_on_the_genomic_accession=114813702, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    120425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120425, CurrentID=0, Status='live', Symbol='JAML', Aliases=['AMICA', 'AMICA1', 'CREA7-1', 'CREA7-4', 'Gm638'], description='junction adhesion molecule like', other_designations='junctional adhesion molecule-like|adhesion molecule AMICA|adhesion molecule interacting with CXADR antigen 1|adhesion molecule, interacts with CXADR antigen 1|dendritic-cell specific protein CREA7-1|dendritic-cell specific protein CREA7-4', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118193725, end_position_on_the_genomic_accession=118225089, orientation='minus', exon_count=13, OMIM=[609770], no_hdr0=''),
    120526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120526, CurrentID=0, Status='live', Symbol='DNAJC24', Aliases=['DPH4', 'JJJ3', 'ZCSL3'], description='DnaJ heat shock protein family (Hsp40) member C24', other_designations='dnaJ homolog subfamily C member 24|1700030A21Rik|CSL-type zinc finger-containing protein 3|DPH4 homolog (JJJ3, S. cerevisiae)|DPH4, JJJ3 homolog|DnaJ (Hsp40) homolog, subfamily C, member 24|diphthamide biosynthesis protein 4|zinc finger, CSL domain containing 3|zinc finger, CSL-type containing 3', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=31369840, end_position_on_the_genomic_accession=31432835, orientation='plus', exon_count=6, OMIM=[611072], no_hdr0=''),
    120534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120534, CurrentID=0, Status='live', Symbol='ARL14EP', Aliases=['ARF7EP', 'C11orf46', 'dJ299F11.1'], description='ADP ribosylation factor like GTPase 14 effector protein', other_designations='ARL14 effector protein|ADP-ribosylation factor-like 14 effector protein|ARF7 effector protein', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=30323104, end_position_on_the_genomic_accession=30338458, orientation='plus', exon_count=4, OMIM=[612295], no_hdr0=''),
    120586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120586, CurrentID=0, Status='live', Symbol='OR8I2', Aliases=['OR11-170'], description='olfactory receptor family 8 subfamily I member 2', other_designations='olfactory receptor 8I2|olfactory receptor OR11-170', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56093308, end_position_on_the_genomic_accession=56094240, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    120775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120775, CurrentID=0, Status='live', Symbol='OR2D3', Aliases=['OR11-89'], description='olfactory receptor family 2 subfamily D member 3', other_designations='olfactory receptor 2D3|olfactory receptor OR11-89', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6921002, end_position_on_the_genomic_accession=6921994, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    120776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120776, CurrentID=0, Status='live', Symbol='OR2D2', Aliases=['OR11-610', 'OR2D1', 'hg27'], description='olfactory receptor family 2 subfamily D member 2', other_designations='olfactory receptor 2D2|HB2|olfactory receptor 11-610|olfactory receptor 2D1|olfactory receptor OR11-88|olfactory receptor, family 2, subfamily D, member 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6891574, end_position_on_the_genomic_accession=6892500, orientation='minus', exon_count=1, OMIM=[608494], no_hdr0=''),
    120787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120787, CurrentID=0, Status='live', Symbol='OR52W1', Aliases=['OR11-71P', 'OR52W1'], description='olfactory receptor family 52 subfamily W member 1', other_designations='olfactory receptor 52W1|olfactory receptor OR11-71|olfactory receptor, family 52, subfamily W, member 1 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6199224, end_position_on_the_genomic_accession=6200186, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    120793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120793, CurrentID=0, Status='live', Symbol='OR56A4', Aliases=['OR11-49'], description='olfactory receptor family 56 subfamily A member 4', other_designations='olfactory receptor 56A4|olfactory receptor OR11-49', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5999445, end_position_on_the_genomic_accession=6006946, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    120796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120796, CurrentID=0, Status='live', Symbol='OR56A1', Aliases=['OR11-75'], description='olfactory receptor family 56 subfamily A member 1', other_designations='olfactory receptor 56A1|olfactory receptor OR11-75', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6019336, end_position_on_the_genomic_accession=6034338, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    120863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120863, CurrentID=0, Status='live', Symbol='DEPDC4', Aliases=['DEP.4'], description='DEP domain containing 4', other_designations='DEP domain-containing protein 4', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100231635, end_position_on_the_genomic_accession=100268094, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    120892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120892, CurrentID=0, Status='live', Symbol='LRRK2', Aliases=['AURA17', 'DARDARIN', 'PARK8', 'RIPK7', 'ROCO2'], description='leucine rich repeat kinase 2', other_designations='leucine-rich repeat serine/threonine-protein kinase 2|augmented in rheumatoid arthritis 17', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=40224890, end_position_on_the_genomic_accession=40369285, orientation='plus', exon_count=54, OMIM=[609007], no_hdr0=''),
    120935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120935, CurrentID=0, Status='live', Symbol='CCDC38', Aliases=[], description='coiled-coil domain containing 38', other_designations='coiled-coil domain-containing protein 38', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95867048, end_position_on_the_genomic_accession=95943301, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    120939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120939, CurrentID=0, Status='live', Symbol='TMEM52B', Aliases=['C12orf59'], description='transmembrane protein 52B', other_designations='transmembrane protein 52B', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10170513, end_position_on_the_genomic_accession=10191804, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    121006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121006, CurrentID=0, Status='live', Symbol='FAM186A', Aliases=[], description='family with sequence similarity 186 member A', other_designations='protein FAM186A', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50326854, end_position_on_the_genomic_accession=50396633, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    121053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121053, CurrentID=0, Status='live', Symbol='NOPCHAP1', Aliases=['C12orf45'], description='NOP protein chaperone 1', other_designations='NOP protein chaperone 1|uncharacterized protein C12orf45', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104986316, end_position_on_the_genomic_accession=105017625, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    121129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121129, CurrentID=0, Status='live', Symbol='OR2AP1', Aliases=['OR2AP1P'], description='olfactory receptor family 2 subfamily AP member 1', other_designations='olfactory receptor 2AP1|olfactory receptor OR12-9|olfactory receptor, family 2, subfamily AP, member 1 pseudogene|seven transmembrane helix receptor', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55572468, end_position_on_the_genomic_accession=55575612, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    121130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121130, CurrentID=0, Status='live', Symbol='OR10P1', Aliases=['OR10P1P', 'OR10P2P', 'OR10P3P', 'OR12-7', 'OST701'], description='olfactory receptor family 10 subfamily P member 1', other_designations='olfactory receptor 10P1|olfactory receptor 10P2|olfactory receptor 10P3|olfactory receptor OR12-7|olfactory receptor, family 10, subfamily P, member 1 pseudogene|olfactory receptor, family 10, subfamily P, member 2 pseudogene|olfactory receptor, family 10, subfamily P, member 3 pseudogene|seven transmembrane helix receptor', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55636892, end_position_on_the_genomic_accession=55637833, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    121214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121214, CurrentID=0, Status='live', Symbol='SDR9C7', Aliases=['ARCI13', 'RDHS', 'SDR-O', 'SDRO'], description='short chain dehydrogenase/reductase family 9C member 7', other_designations='short-chain dehydrogenase/reductase family 9C member 7|RDH-S|orphan short-chain dehydrogenase / reductase|orphan short-chain dehydrogenase/reductase|retinol dehydrogenase similar protein', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56923133, end_position_on_the_genomic_accession=56934408, orientation='minus', exon_count=4, OMIM=[609769], no_hdr0=''),
    121227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121227, CurrentID=0, Status='live', Symbol='LRIG3', Aliases=['LIG3'], description='leucine rich repeats and immunoglobulin like domains 3', other_designations='leucine-rich repeats and immunoglobulin-like domains protein 3|LIG-3', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=58872155, end_position_on_the_genomic_accession=58920519, orientation='minus', exon_count=21, OMIM=[608870], no_hdr0=''),
    121256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121256, CurrentID=0, Status='live', Symbol='TMEM132D', Aliases=['MOLT', 'PPP1R153'], description='transmembrane protein 132D', other_designations='transmembrane protein 132D|mature OL transmembrane protein|mature oligodendrocytes transmembrane protein|protein phosphatase 1, regulatory subunit 153', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=129071726, end_position_on_the_genomic_accession=129904025, orientation='minus', exon_count=9, OMIM=[611257], no_hdr0=''),
    121260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121260, CurrentID=0, Status='live', Symbol='SLC15A4', Aliases=['FP12591', 'PHT1', 'PTR4'], description='solute carrier family 15 member 4', other_designations='solute carrier family 15 member 4|hPHT1|peptide transporter 4|peptide-histidine transporter 4|peptide/histidine transporter 1|solute carrier family 15 (oligopeptide transporter), member 4', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=128793194, end_position_on_the_genomic_accession=128823966, orientation='minus', exon_count=9, OMIM=[615806], no_hdr0=''),
    121268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121268, CurrentID=0, Status='live', Symbol='RHEBL1', Aliases=['RHEBL1c'], description='RHEB like 1', other_designations='GTPase RhebL1|Ras homolog enriched in brain like 1 c|ras homolog enriched in brain like-1 c|ras homolog enriched in brain-like protein 1|rheb-like protein 1|rheb2', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49064676, end_position_on_the_genomic_accession=49069979, orientation='minus', exon_count=8, OMIM=[618956], no_hdr0=''),
    121273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121273, CurrentID=0, Status='live', Symbol='C12orf54', Aliases=['HSD-29', 'HSD-30'], description='chromosome 12 open reading frame 54', other_designations='uncharacterized protein C12orf54', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48413154, end_position_on_the_genomic_accession=48496524, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    121274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121274, CurrentID=0, Status='live', Symbol='ZNF641', Aliases=[], description='zinc finger protein 641', other_designations='zinc finger protein 641', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48334380, end_position_on_the_genomic_accession=48351414, orientation='minus', exon_count=9, OMIM=[613906], no_hdr0=''),
    121275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121275, CurrentID=0, Status='live', Symbol='OR10AD1', Aliases=['OR10AD1P', 'OR12-1'], description='olfactory receptor family 10 subfamily AD member 1', other_designations='olfactory receptor 10AD1|olfactory receptor OR12-1|olfactory receptor, family 10, subfamily AD, member 1 pseudogene', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48202339, end_position_on_the_genomic_accession=48203292, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    121278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121278, CurrentID=0, Status='live', Symbol='TPH2', Aliases=['ADHD7', 'NTPH'], description='tryptophan hydroxylase 2', other_designations='tryptophan 5-hydroxylase 2|neuronal tryptophan hydroxylase|tryptophan 5-monooxygenase 2', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71938845, end_position_on_the_genomic_accession=72032440, orientation='plus', exon_count=13, OMIM=[607478], no_hdr0=''),
    121340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121340, CurrentID=0, Status='live', Symbol='SP7', Aliases=['OI11', 'OI12', 'OSX', 'osterix'], description='Sp7 transcription factor', other_designations='transcription factor Sp7|zinc finger protein osterix', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53326575, end_position_on_the_genomic_accession=53344793, orientation='minus', exon_count=5, OMIM=[606633], no_hdr0=''),
    121355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121355, CurrentID=0, Status='live', Symbol='GTSF1', Aliases=['Cue110', 'FAM112B'], description='gametocyte specific factor 1', other_designations='gametocyte-specific factor 1|family with sequence similarity 112, member B', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54455952, end_position_on_the_genomic_accession=54473602, orientation='minus', exon_count=11, OMIM=[617484], no_hdr0=''),
    121364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121364, CurrentID=0, Status='live', Symbol='OR10A7', Aliases=['OR12-6'], description='olfactory receptor family 10 subfamily A member 7', other_designations='olfactory receptor 10A7|olfactory receptor OR12-6', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55221025, end_position_on_the_genomic_accession=55221975, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    121391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121391, CurrentID=0, Status='live', Symbol='KRT74', Aliases=['ADWH', 'HTSS2', 'HYPT3', 'K6IRS4', 'KRT5C', 'KRT6IRS4'], description='keratin 74', other_designations='keratin, type II cytoskeletal 74|CK-74|K5C|K74|cytokeratin-74|keratin 5c|keratin 6 irs4|keratin 74, type II|type II inner root sheath-specific keratin-K6irs4|type-II keratin Kb37', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52565782, end_position_on_the_genomic_accession=52573843, orientation='minus', exon_count=9, OMIM=[608248], no_hdr0=''),
    121441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121441, CurrentID=0, Status='live', Symbol='NEDD1', Aliases=['GCP-WD', 'TUBGCP7'], description='NEDD1 gamma-tubulin ring complex targeting factor', other_designations='protein NEDD1|NEDD-1|neural precursor cell expressed developmentally down-regulated protein 1|neural precursor cell expressed, developmentally down-regulated 1|tubulin gamma complex associated protein 7', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=96907222, end_position_on_the_genomic_accession=96953780, orientation='plus', exon_count=17, OMIM=[600372], no_hdr0=''),
    121457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121457, CurrentID=0, Status='live', Symbol='IKBIP', Aliases=['IKIP'], description='IKBKB interacting protein', other_designations='inhibitor of nuclear factor kappa-B kinase-interacting protein|I kappa B kinase interacting protein|IKK interacting protein|i kappa-B kinase-interacting protein', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=98613404, end_position_on_the_genomic_accession=98644788, orientation='minus', exon_count=4, OMIM=[609861], no_hdr0=''),
    121504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121504, CurrentID=0, Status='live', Symbol='H4-16', Aliases=['H4/p', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C15', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'HIST4H4'], description='H4 histone 16', other_designations='histone H4|histone 4, H4|histone cluster 4 H4', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14770720, end_position_on_the_genomic_accession=14771131, orientation='minus', exon_count=1, OMIM=[615069], no_hdr0=''),
    121506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121506, CurrentID=0, Status='live', Symbol='ERP27', Aliases=['C12orf46', 'PDIA8'], description='endoplasmic reticulum protein 27', other_designations='endoplasmic reticulum resident protein 27|ER protein 27|endoplasmic reticulum protein 27 kDa|inactive protein disulfide-isomerase 27|protein disulfide isomerase family A, member 8', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14914039, end_position_on_the_genomic_accession=14938537, orientation='minus', exon_count=8, OMIM=[610642], no_hdr0=''),
    121512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121512, CurrentID=0, Status='live', Symbol='FGD4', Aliases=['CMT4H', 'FRABP', 'ZFYVE6'], description='FYVE, RhoGEF and PH domain containing 4', other_designations='FYVE, RhoGEF and PH domain-containing protein 4|FGD1 family, member 4|FGD1-related F-actin-binding protein|actin-filament binding protein frabin|zinc finger FYVE domain-containing protein 6', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=32399523, end_position_on_the_genomic_accession=32646050, orientation='plus', exon_count=27, OMIM=[611104], no_hdr0=''),
    121536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121536, CurrentID=0, Status='live', Symbol='AEBP2', Aliases=[], description='AE binding protein 2', other_designations='zinc finger protein AEBP2|AE(adipocyte enhancer)-binding protein 2|adipocyte enhancer-binding protein 2', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=19404101, end_position_on_the_genomic_accession=19522227, orientation='plus', exon_count=11, OMIM=[617934], no_hdr0=''),
    121549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121549, CurrentID=0, Status='live', Symbol='ASCL4', Aliases=['ASH-4', 'HASH4', 'bHLHa44'], description='achaete-scute family bHLH transcription factor 4', other_designations='achaete-scute homolog 4|achaete-scute complex homolog 4|achaete-scute complex-like 4|achaete-scute-like protein 4|class A basic helix-loop-helix protein 44|class II bHLH protein ASCL4', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=107774704, end_position_on_the_genomic_accession=107776644, orientation='plus', exon_count=1, OMIM=[609155], no_hdr0=''),
    121551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121551, CurrentID=0, Status='live', Symbol='BTBD11', Aliases=['ABTB2B'], description='BTB domain containing 11', other_designations='ankyrin repeat and BTB/POZ domain-containing protein BTBD11|ANK-repeat BTB domain containing protein|BTB (POZ) domain containing 11|BTB/POZ domain-containing protein 11', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=107316749, end_position_on_the_genomic_accession=107659642, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    121599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121599, CurrentID=0, Status='live', Symbol='SPIC', Aliases=['SPI-C'], description='Spi-C transcription factor', other_designations='transcription factor Spi-C|Spi-C transcription factor (Spi-1/PU.1 related)', map_location='12q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101475276, end_position_on_the_genomic_accession=101486997, orientation='plus', exon_count=6, OMIM=[612568], no_hdr0=''),
    121601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121601, CurrentID=0, Status='live', Symbol='ANO4', Aliases=['TMEM16D'], description='anoctamin 4', other_designations='anoctamin-4|transmembrane protein 16D', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100717457, end_position_on_the_genomic_accession=101128641, orientation='plus', exon_count=33, OMIM=[610111], no_hdr0=''),
    121642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121642, CurrentID=0, Status='live', Symbol='ALKBH2', Aliases=['ABH2'], description='alkB homolog 2, alpha-ketoglutarate dependent dioxygenase', other_designations='DNA oxidative demethylase ALKBH2|2OG-Fe(II) oxy DC1|alkB, alkylation repair homolog 2|alkylated DNA repair protein alkB homolog 2|alpha-ketoglutarate-dependent dioxygenase alkB homolog 2|oxy DC1', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109088189, end_position_on_the_genomic_accession=109093631, orientation='minus', exon_count=4, OMIM=[610602], no_hdr0=''),
    121643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121643, CurrentID=0, Status='live', Symbol='FOXN4', Aliases=[], description='forkhead box N4', other_designations='forkhead box protein N4|forkhead/winged helix transcription factor FOXN4', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109277978, end_position_on_the_genomic_accession=109309406, orientation='minus', exon_count=12, OMIM=[609429], no_hdr0=''),
    121665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121665, CurrentID=0, Status='live', Symbol='SPPL3', Aliases=['IMP2', 'MDHV1887', 'PRO4332', 'PSH1', 'PSL4'], description='signal peptide peptidase like 3', other_designations='signal peptide peptidase-like 3|SPP-like 3|intramembrane protease 2|presenilin homologous protein 1|presenilin-like protein 4', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120762510, end_position_on_the_genomic_accession=120904358, orientation='minus', exon_count=12, OMIM=[608240], no_hdr0=''),
    121793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121793, CurrentID=0, Status='live', Symbol='TEX29', Aliases=['C13orf16', 'bA474D23.1'], description='testis expressed 29', other_designations='testis-expressed protein 29|testis-expressed sequence 29 protein', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=111305838, end_position_on_the_genomic_accession=111344248, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    122011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122011, CurrentID=0, Status='live', Symbol='CSNK1A1L', Aliases=['CK1'], description='casein kinase 1 alpha 1 like', other_designations='casein kinase I isoform alpha-like|CKI-alpha-like|casein kinase I alpha S-like', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=37103259, end_position_on_the_genomic_accession=37105664, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    122042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122042, CurrentID=0, Status='live', Symbol='RXFP2', Aliases=['GPR106', 'GREAT', 'INSL3R', 'LGR8', 'LGR8.1', 'RXFPR2'], description='relaxin family peptide receptor 2', other_designations='relaxin receptor 2|G protein coupled receptor affecting testicular descent|G-protein coupled receptor 106|leucine-rich repeat-containing G-protein coupled receptor 8|relaxin/insulin like family peptide receptor 2', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=31739526, end_position_on_the_genomic_accession=31803389, orientation='plus', exon_count=18, OMIM=[606655], no_hdr0=''),
    122046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122046, CurrentID=0, Status='live', Symbol='TEX26', Aliases=['C13orf26'], description='testis expressed 26', other_designations='testis-expressed protein 26|testis-expressed sequence 26 protein', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30932654, end_position_on_the_genomic_accession=30975502, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    122060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122060, CurrentID=0, Status='live', Symbol='SLAIN1', Aliases=['C13orf32'], description='SLAIN motif family member 1', other_designations='SLAIN motif-containing protein 1', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=77697674, end_position_on_the_genomic_accession=77764231, orientation='plus', exon_count=10, OMIM=[610491], no_hdr0=''),
    122183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122183, CurrentID=0, Status='live', Symbol='PRR20A', Aliases=['PRR20', 'PRR20B', 'PRR20C', 'PRR20D', 'PRR20E'], description='proline rich 20A', other_designations='proline-rich protein 20A|Proline-rich protein 20B|Proline-rich protein 20C|Proline-rich protein 20D|Proline-rich protein 20E|proline rich 20|proline-rich protein 20', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57140918, end_position_on_the_genomic_accession=57143939, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    122258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122258, CurrentID=0, Status='live', Symbol='SPACA7', Aliases=['C13orf28'], description='sperm acrosome associated 7', other_designations='sperm acrosome-associated protein 7|protein SPACA7', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112376300, end_position_on_the_genomic_accession=112434689, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    122402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122402, CurrentID=0, Status='live', Symbol='TDRD9', Aliases=['C14orf75', 'HIG-1', 'HLS', 'NET54', 'SPGF30', 'SPNE'], description='tudor domain containing 9', other_designations='ATP-dependent RNA helicase TDRD9|hypoxia-inducible HIG-1|putative ATP-dependent RNA helicase TDRD9|tudor domain-containing protein 9', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103928343, end_position_on_the_genomic_accession=104052667, orientation='plus', exon_count=39, OMIM=[617963], no_hdr0=''),
    122416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122416, CurrentID=0, Status='live', Symbol='ANKRD9', Aliases=[], description='ankyrin repeat domain 9', other_designations='ankyrin repeat domain-containing protein 9', map_location='14q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=102501767, end_position_on_the_genomic_accession=102509776, orientation='minus', exon_count=4, OMIM=[618605], no_hdr0=''),
    122481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122481, CurrentID=0, Status='live', Symbol='AK7', Aliases=['AK 7', 'CFAP75', 'FAP75', 'SPGF27'], description='adenylate kinase 7', other_designations='adenylate kinase 7|ATP-AMP transphosphorylase 7|putative adenylate kinase 7', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=96392111, end_position_on_the_genomic_accession=96489427, orientation='plus', exon_count=18, OMIM=[615364], no_hdr0=''),
    122509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122509, CurrentID=0, Status='live', Symbol='IFI27L1', Aliases=['FAM14B', 'ISG12C'], description='interferon alpha inducible protein 27 like 1', other_designations='interferon alpha-inducible protein 27-like protein 1|ISG12(c) protein|family with sequence similarity 14, member B|interferon-stimulated gene 12c protein', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94081308, end_position_on_the_genomic_accession=94102710, orientation='plus', exon_count=8, OMIM=[611320], no_hdr0=''),
    122525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122525, CurrentID=0, Status='live', Symbol='C14orf28', Aliases=['DRIP-1', 'DRIP1', 'c14_5270'], description='chromosome 14 open reading frame 28', other_designations='uncharacterized protein C14orf28|dopamine receptor interacting protein 1', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=44897275, end_position_on_the_genomic_accession=44907257, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    122553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122553, CurrentID=0, Status='live', Symbol='TRAPPC6B', Aliases=['NEDMEBA', 'TPC6'], description='trafficking protein particle complex subunit 6B', other_designations='trafficking protein particle complex subunit 6B|TRAPP complex subunit 6B|trafficking protein particle complex 6B', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39147811, end_position_on_the_genomic_accession=39170400, orientation='minus', exon_count=7, OMIM=[610397], no_hdr0=''),
    122616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122616, CurrentID=0, Status='live', Symbol='CLBA1', Aliases=['C14orf79'], description='clathrin binding box of aftiphilin containing 1', other_designations='uncharacterized protein CLBA1|clathrin-binding box of aftiphilin-containing protein 1|uncharacterized protein C14orf79', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104985788, end_position_on_the_genomic_accession=105000310, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    122618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122618, CurrentID=0, Status='live', Symbol='PLD4', Aliases=['C14orf175'], description='phospholipase D family member 4', other_designations="5'-3' exonuclease PLD4|PLD 4|choline phosphatase 4|phosphatidylcholine-hydrolyzing phospholipase D4|phospholipase D4", map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104924301, end_position_on_the_genomic_accession=104937789, orientation='plus', exon_count=11, OMIM=[618488], no_hdr0=''),
    122622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122622, CurrentID=0, Status='live', Symbol='ADSS1', Aliases=['ADSSL1', 'MPD5'], description='adenylosuccinate synthase 1', other_designations='adenylosuccinate synthetase isozyme 1|AMPSase 1|IMP--aspartate ligase 1|M-type adenylosuccinate synthetase|adSS 1|adenylosuccinate synthase like 1|adenylosuccinate synthetase, basic isozyme|adenylosuccinate synthetase, muscle isozyme|adenylosuccinate synthetase-like 1', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104724201, end_position_on_the_genomic_accession=104747325, orientation='plus', exon_count=15, OMIM=[612498], no_hdr0=''),
    122651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122651, CurrentID=0, Status='live', Symbol='RNASE11', Aliases=['C14orf6', 'HEL-S-84p', 'RAJ1'], description='ribonuclease A family member 11 (inactive)', other_designations='probable ribonuclease 11|epididymis secretory sperm binding protein Li 84p|ribonuclease 11|ribonuclease A J1|ribonuclease, RNase A family, 11 (non-active)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20582892, end_position_on_the_genomic_accession=20590257, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    122664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122664, CurrentID=0, Status='live', Symbol='TPPP2', Aliases=['C14orf8', 'CT152', 'P18', 'p25beta'], description='tubulin polymerization promoting protein family member 2', other_designations='tubulin polymerization-promoting protein family member 2|TPPP/p18|protein p25-beta', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21024262, end_position_on_the_genomic_accession=21036352, orientation='plus', exon_count=9, OMIM=[616956], no_hdr0=''),
    122665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122665, CurrentID=0, Status='live', Symbol='RNASE8', Aliases=['RAE2'], description='ribonuclease A family member 8', other_designations='ribonuclease 8|RNase 8, placental|ribonuclease, RNase A family, 8', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21057822, end_position_on_the_genomic_accession=21058455, orientation='plus', exon_count=1, OMIM=[612485], no_hdr0=''),
    122704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122704, CurrentID=0, Status='live', Symbol='MRPL52', Aliases=[], description='mitochondrial ribosomal protein L52', other_designations='39S ribosomal protein L52, mitochondrial|L52mt|MRP-L52|mitochondrial large ribosomal subunit protein mL52', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22829862, end_position_on_the_genomic_accession=22835037, orientation='plus', exon_count=6, OMIM=[611856], no_hdr0=''),
    122706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122706, CurrentID=0, Status='live', Symbol='PSMB11', Aliases=['BETA5T'], description='proteasome subunit beta 11', other_designations='proteasome subunit beta type-11|proteasome (prosome, macropain) subunit, beta type, 11|proteasome subunit beta 5T|proteasome subunit beta-5t', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23042212, end_position_on_the_genomic_accession=23044060, orientation='plus', exon_count=1, OMIM=[611137], no_hdr0=''),
    122740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122740, CurrentID=0, Status='live', Symbol='OR4K14', Aliases=['OR14-18', 'OR14-22'], description='olfactory receptor family 4 subfamily K member 14', other_designations='olfactory receptor 4K14|olfactory receptor OR14-18 pseudogene|olfactory receptor OR14-22', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20014143, end_position_on_the_genomic_accession=20019307, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    122742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122742, CurrentID=0, Status='live', Symbol='OR4L1', Aliases=['OR14-28', 'OR4L2P'], description='olfactory receptor family 4 subfamily L member 1', other_designations='olfactory receptor 4L1|olfactory receptor 4L2|olfactory receptor OR14-28|olfactory receptor, family 4, subfamily L, member 2 pseudogene', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20060045, end_position_on_the_genomic_accession=20060983, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    122748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122748, CurrentID=0, Status='live', Symbol='OR11H6', Aliases=[], description='olfactory receptor family 11 subfamily H member 6', other_designations='olfactory receptor 11H6|olfactory receptor OR14-35', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20223710, end_position_on_the_genomic_accession=20224702, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    122769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122769, CurrentID=0, Status='live', Symbol='LRR1', Aliases=['4-1BBLRR', 'LRR-1', 'PPIL5'], description='leucine rich repeat protein 1', other_designations='leucine-rich repeat protein 1|4-1BB-mediated signaling molecule|LRR-repeat protein 1|cyclophilin-like 5|epididymis secretory sperm binding protein|peptidylprolyl isomerase-like 5', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49598940, end_position_on_the_genomic_accession=49614672, orientation='plus', exon_count=7, OMIM=[609193], no_hdr0=''),
    122773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122773, CurrentID=0, Status='live', Symbol='KLHDC1', Aliases=['MST025'], description='kelch domain containing 1', other_designations='kelch domain-containing protein 1', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=49690462, end_position_on_the_genomic_accession=49753152, orientation='plus', exon_count=15, OMIM=[611281], no_hdr0=''),
    122786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122786, CurrentID=0, Status='live', Symbol='FRMD6', Aliases=['C14orf31', 'EX1', 'Willin', 'c14_5320'], description='FERM domain containing 6', other_designations='FERM domain-containing protein 6|4.1 ezrin radixin moesin (FERM)-containing protein|expanded homolog', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=51489100, end_position_on_the_genomic_accession=51730727, orientation='plus', exon_count=22, OMIM=[614555], no_hdr0=''),
    122809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122809, CurrentID=0, Status='live', Symbol='SOCS4', Aliases=['SOCS7'], description='suppressor of cytokine signaling 4', other_designations='suppressor of cytokine signaling 4|SH2 domain containing SOCS box protein|SOCS-4|SOCS-7|suppressor of cytokine signaling 7', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55027131, end_position_on_the_genomic_accession=55049489, orientation='plus', exon_count=3, OMIM=[616337], no_hdr0=''),
    122830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122830, CurrentID=0, Status='live', Symbol='NAA30', Aliases=['C14orf35', 'MAK3', 'Mak3p', 'NAT12', 'NAT12P'], description='N-alpha-acetyltransferase 30, NatC catalytic subunit', other_designations='N-alpha-acetyltransferase 30|N-acetyltransferase 12 (GCN5-related, putative)|N-acetyltransferase MAK3 homolog|natC catalytic subunit|putative N-acetyltransferase', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57390586, end_position_on_the_genomic_accession=57415906, orientation='plus', exon_count=5, OMIM=[617989], no_hdr0=''),
    122876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122876, CurrentID=0, Status='live', Symbol='GPHB5', Aliases=['B5', 'GPB5', 'ZLUT1'], description='glycoprotein hormone subunit beta 5', other_designations='glycoprotein hormone beta-5|glycoprotein beta 5|glycoprotein hormone beta 5|glycoprotein hormone beta subunit|thyrostimulin subunit beta', map_location='14q23.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=63312835, end_position_on_the_genomic_accession=63318935, orientation='minus', exon_count=3, OMIM=[609652], no_hdr0=''),
    122945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122945, CurrentID=0, Status='live', Symbol='NOXRED1', Aliases=['C14orf148'], description='NADP dependent oxidoreductase domain containing 1', other_designations='NADP-dependent oxidoreductase domain-containing protein 1|pyrroline-5-carboxylate reductase-like protein C14orf148', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77394021, end_position_on_the_genomic_accession=77426013, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    122953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122953, CurrentID=0, Status='live', Symbol='JDP2', Aliases=['JUNDM2'], description='Jun dimerization protein 2', other_designations='jun dimerization protein 2|progesterone receptor co-activator', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=75426692, end_position_on_the_genomic_accession=75474107, orientation='plus', exon_count=12, OMIM=[608657], no_hdr0=''),
    122961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122961, CurrentID=0, Status='live', Symbol='ISCA2', Aliases=['HBLD1', 'ISA2', 'MMDS4', 'c14_5557'], description='iron-sulfur cluster assembly 2', other_designations='iron-sulfur cluster assembly 2 homolog, mitochondrial|HESB-like domain-containing protein 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74493765, end_position_on_the_genomic_accession=74497106, orientation='plus', exon_count=4, OMIM=[615317], no_hdr0=''),
    122970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=122970, CurrentID=0, Status='live', Symbol='ACOT4', Aliases=['PTE-Ib', 'PTE1B', 'PTE2B'], description='acyl-CoA thioesterase 4', other_designations='peroxisomal succinyl-coenzyme A thioesterase|PTE-2b|acyl-coenzyme A thioesterase 4|peroxisomal acyl coenzyme A thioester hydrolase Ib|peroxisomal acyl-CoA thioesterase 2B|peroxisomal long-chain acyl-CoA thioesterase Ib', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73591873, end_position_on_the_genomic_accession=73595766, orientation='plus', exon_count=3, OMIM=[614314], no_hdr0=''),
    123016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123016, CurrentID=0, Status='live', Symbol='TTC8', Aliases=['BBS8', 'RP51'], description='tetratricopeptide repeat domain 8', other_designations='tetratricopeptide repeat protein 8|Bardet-Biedl syndrome type 8|TPR repeat protein 8', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88824153, end_position_on_the_genomic_accession=88881079, orientation='plus', exon_count=18, OMIM=[608132], no_hdr0=''),
    123036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123036, CurrentID=0, Status='live', Symbol='TC2N', Aliases=['C14orf47', 'C2CD1', 'MTAC2D1', 'TAC2N', 'Tac2-N'], description='tandem C2 domains, nuclear', other_designations='tandem C2 domains nuclear protein|C2 calcium-dependent domain containing 1|membrane targeting (tandem) C2 domain containing 1|tandem C2 protein in nucleus', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91779746, end_position_on_the_genomic_accession=91867536, orientation='minus', exon_count=13, OMIM=[619305], no_hdr0=''),
    123041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123041, CurrentID=0, Status='live', Symbol='SLC24A4', Aliases=['AI2A5', 'NCKX4', 'SHEP6', 'SLC24A2'], description='solute carrier family 24 member 4', other_designations='sodium/potassium/calcium exchanger 4|Na(+)/K(+)/Ca(2+)-exchange protein 4|solute carrier family 24 (sodium/potassium/calcium exchanger), member 4', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=92322581, end_position_on_the_genomic_accession=92501481, orientation='plus', exon_count=24, OMIM=[609840], no_hdr0=''),
    123096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123096, CurrentID=0, Status='live', Symbol='SLC25A29', Aliases=['C14orf69', 'CACL', 'ORNT3'], description='solute carrier family 25 member 29', other_designations='mitochondrial basic amino acids transporter|carnitine-acylcarnitine translocase like|mitochondrial carnitine/acylcarnitine carrier protein CACL|mitochondrial ornithine transporter 3|solute carrier family 25 (mitochondrial carnitine/acylcarnitine carrier), member 29', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100277986, end_position_on_the_genomic_accession=100306536, orientation='minus', exon_count=10, OMIM=[615064], no_hdr0=''),
    123099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123099, CurrentID=0, Status='live', Symbol='DEGS2', Aliases=['C14orf66', 'DES2', 'FADS8'], description='delta 4-desaturase, sphingolipid 2', other_designations='sphingolipid delta(4)-desaturase/C4-monooxygenase DES2|degenerative spermatocyte homolog 2, lipid desaturase|dihydroceramide desaturase 2|sphingolipid 4-desaturase|sphingolipid C4-hydroxylase/delta 4-desaturase|sphingolipid C4-monooxygenase|sphingolipid delta 4 desaturase/C-4 hydroxylase|sphingolipid delta(4)-desaturase 2|sphingolipid delta(4)-desaturase/C4-hydroxylase DES2', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100143957, end_position_on_the_genomic_accession=100166886, orientation='minus', exon_count=5, OMIM=[610862], no_hdr0=''),
    123103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123103, CurrentID=0, Status='live', Symbol='KLHL33', Aliases=[], description='kelch like family member 33', other_designations='kelch-like protein 33', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20425852, end_position_on_the_genomic_accession=20436166, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    123169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123169, CurrentID=0, Status='live', Symbol='LEO1', Aliases=['RDL'], description='LEO1 homolog, Paf1/RNA polymerase II complex component', other_designations='RNA polymerase-associated protein LEO1|Leo1 Paf1/RNA polymerase II complex component|Leo1, Paf1/RNA polymerase II complex component, homolog|replicative senescence down-regulated leo1-like protein', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51938024, end_position_on_the_genomic_accession=51971798, orientation='minus', exon_count=13, OMIM=[610507], no_hdr0=''),
    123207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123207, CurrentID=0, Status='live', Symbol='C15orf40', Aliases=[], description='chromosome 15 open reading frame 40', other_designations='UPF0235 protein C15orf40', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82988297, end_position_on_the_genomic_accession=83012298, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    123228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123228, CurrentID=0, Status='live', Symbol='SENP8', Aliases=['DEN1', 'NEDP1', 'PRSC2'], description='SUMO peptidase family member, NEDD8 specific', other_designations='sentrin-specific protease 8|NEDD8 specific-protease cysteine 2|NEDD8-specific protease 1|SUMO sentrin specific protease family member 8|SUMO/sentrin peptidase family member, NEDD8 specific|SUMO/sentrin specific peptidase family member 8|deneddylase 1|protease, cysteine 2', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72114258, end_position_on_the_genomic_accession=72143692, orientation='plus', exon_count=5, OMIM=[608659], no_hdr0=''),
    123263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123263, CurrentID=0, Status='live', Symbol='MTFMT', Aliases=['COXPD15', 'FMT1', 'MC1DN27'], description='mitochondrial methionyl-tRNA formyltransferase', other_designations='methionyl-tRNA formyltransferase, mitochondrial', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65001512, end_position_on_the_genomic_accession=65029639, orientation='minus', exon_count=9, OMIM=[611766], no_hdr0=''),
    123264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123264, CurrentID=0, Status='live', Symbol='SLC51B', Aliases=['OSTB', 'OSTBETA'], description='solute carrier family 51 subunit beta', other_designations='organic solute transporter subunit beta|OST-beta|organic solute transporter beta subunit|solute carrier family 51 beta subunit', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65045387, end_position_on_the_genomic_accession=65053397, orientation='plus', exon_count=5, OMIM=[612085], no_hdr0=''),
    123283 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123283, CurrentID=0, Status='live', Symbol='TARS3', Aliases=['TARSL2', 'ThrRS-L'], description='threonyl-tRNA synthetase 3', other_designations='threonine--tRNA ligase 2, cytoplasmic|probable threonine--tRNA ligase 2, cytoplasmic|probable threonyl-tRNA synthetase 2, cytoplasmic|thrRS|threonyl-tRNA synthetase like 2|threonyl-tRNA synthetase protein 3|threonyl-tRNA synthetase-like protein 2', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101653596, end_position_on_the_genomic_accession=101724473, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    123346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123346, CurrentID=0, Status='live', Symbol='HIGD2B', Aliases=['HIGD2BP'], description='HIG1 hypoxia inducible domain family member 2B', other_designations='putative HIG1 domain family member 2B|HIG1 hypoxia inducible domain family, member 2B (pseudogene)', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72675798, end_position_on_the_genomic_accession=72686215, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    123355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123355, CurrentID=0, Status='live', Symbol='LRRC28', Aliases=[], description='leucine rich repeat containing 28', other_designations='leucine-rich repeat-containing protein 28', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99251449, end_position_on_the_genomic_accession=99390729, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    123591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123591, CurrentID=0, Status='live', Symbol='TMEM266', Aliases=['C15orf27', 'HVRP1', 'HsHVRP1', 'hTMEM266'], description='transmembrane protein 266', other_designations='transmembrane protein 266|Hv1 related protein 1|transmembrane protein C15orf27', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=76059913, end_position_on_the_genomic_accession=76204963, orientation='plus', exon_count=13, OMIM=[618691], no_hdr0=''),
    123606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123606, CurrentID=0, Status='live', Symbol='NIPA1', Aliases=['FSP3', 'SLC57A1', 'SPG6'], description='NIPA magnesium transporter 1', other_designations='magnesium transporter NIPA1|non imprinted in Prader-Willi/Angelman syndrome 1|non-imprinted in Prader-Willi/Angelman syndrome region protein 1|spastic paraplegia 6 protein', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22786225, end_position_on_the_genomic_accession=22829789, orientation='plus', exon_count=6, OMIM=[608145], no_hdr0=''),
    123624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123624, CurrentID=0, Status='live', Symbol='AGBL1', Aliases=['CCP4', 'FECD8'], description='AGBL carboxypeptidase 1', other_designations='cytosolic carboxypeptidase 4|ATP/GTP binding protein like 1', map_location='15q25.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=86079620, end_position_on_the_genomic_accession=87031476, orientation='plus', exon_count=29, OMIM=[615496], no_hdr0=''),
    123688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123688, CurrentID=0, Status='live', Symbol='HYKK', Aliases=['AGPHD1'], description='hydroxylysine kinase', other_designations='hydroxylysine kinase|5-hydroxy-L-lysine kinase|5-hydroxylysine kinase|aminoglycoside phosphotransferase domain-containing protein 1', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78507577, end_position_on_the_genomic_accession=78537373, orientation='plus', exon_count=6, OMIM=[614681], no_hdr0=''),
    123720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123720, CurrentID=0, Status='live', Symbol='WHAMM', Aliases=['WHAMM1', 'WHDC1'], description='WASP homolog associated with actin, golgi membranes and microtubules', other_designations='WASP homolog-associated protein with actin, membranes and microtubules|WAS protein homolog associated with actin, golgi membranes and microtubules|WAS protein homology region 2 domain-containing protein 1|WH2 domain-containing protein 1', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82809628, end_position_on_the_genomic_accession=82836108, orientation='plus', exon_count=13, OMIM=[612393], no_hdr0=''),
    123722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123722, CurrentID=0, Status='live', Symbol='FSD2', Aliases=['SPRYD1'], description='fibronectin type III and SPRY domain containing 2', other_designations='fibronectin type III and SPRY domain-containing protein 2|SPRY domain containing 1|SPRY domain-containing protein 1|minispryn', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82755362, end_position_on_the_genomic_accession=82807701, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    123745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123745, CurrentID=0, Status='live', Symbol='PLA2G4E', Aliases=[], description='phospholipase A2 group IVE', other_designations='cytosolic phospholipase A2 epsilon|cPLA2-epsilon|calcium-dependent N-acyltransferase', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41981582, end_position_on_the_genomic_accession=42050703, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    123775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123775, CurrentID=0, Status='live', Symbol='C16orf46', Aliases=[], description='chromosome 16 open reading frame 46', other_designations='uncharacterized protein C16orf46', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=81053497, end_position_on_the_genomic_accession=81077254, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    123803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123803, CurrentID=0, Status='live', Symbol='NTAN1', Aliases=['PNAA', 'PNAD'], description='N-terminal asparagine amidase', other_designations='protein N-terminal asparagine amidohydrolase|protein N-terminal Asn amidase|protein N-terminal asparagine amidase|protein NH2-terminal asparagine deamidase|protein NTN-amidase', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15037853, end_position_on_the_genomic_accession=15056074, orientation='minus', exon_count=11, OMIM=[615367], no_hdr0=''),
    123811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123811, CurrentID=0, Status='live', Symbol='CEP20', Aliases=['C16orf63', 'FOPNL', 'FOR20', 'PHSECRG2'], description='centrosomal protein 20', other_designations='centrosomal protein 20|FGFR1OP N-terminal like|FOP-related protein of 20 kDa|lisH domain-containing protein C16orf63|lisH domain-containing protein FOPNL|pluripotent embryonic stem cell-related protein', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15865719, end_position_on_the_genomic_accession=15888603, orientation='minus', exon_count=6, OMIM=[617149], no_hdr0=''),
    123872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123872, CurrentID=0, Status='live', Symbol='DNAAF1', Aliases=['CILD13', 'DAU1', 'LRRC50', 'ODA7', 'swt'], description='dynein axonemal assembly factor 1', other_designations='dynein axonemal assembly factor 1|dynein assembly factor 1, axonemal|leucine-rich repeat-containing protein 50|outer row dynein assembly 7 homolog|testicular tissue protein Li 110', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84145266, end_position_on_the_genomic_accession=84178761, orientation='plus', exon_count=14, OMIM=[613190], no_hdr0=''),
    123876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123876, CurrentID=0, Status='live', Symbol='ACSM2A', Aliases=['A-923A4.1', 'ACSM2'], description='acyl-CoA synthetase medium chain family member 2A', other_designations='acyl-coenzyme A synthetase ACSM2A, mitochondrial|acyl-CoA synthetase medium-chain family member 2|benzoate--CoA ligase|butyrate--CoA ligase 2A|butyryl-coenzyme A synthetase 2A|middle-chain acyl-CoA synthetase 2A', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20451504, end_position_on_the_genomic_accession=20487669, orientation='plus', exon_count=16, OMIM=[614358], no_hdr0=''),
    123879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123879, CurrentID=0, Status='live', Symbol='DCUN1D3', Aliases=['44M2.4', 'DCNL3', 'SCCRO3'], description='defective in cullin neddylation 1 domain containing 3', other_designations='DCN1-like protein 3|DCN1, defective in cullin neddylation 1, domain containing 3|DCUN1 domain-containing protein 3|defective in cullin neddylation protein 1-like protein 3|squamous cell carcinoma-related oncogene 3', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20854925, end_position_on_the_genomic_accession=20900358, orientation='minus', exon_count=3, OMIM=[616167], no_hdr0=''),
    123904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123904, CurrentID=0, Status='live', Symbol='NRN1L', Aliases=['MRCC2446', 'UNQ2446', 'cpg15-2'], description='neuritin 1 like', other_designations='neuritin-like protein', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67884885, end_position_on_the_genomic_accession=67888855, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    123920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123920, CurrentID=0, Status='live', Symbol='CMTM3', Aliases=['BNAS2', 'CKLFSF3'], description='CKLF like MARVEL transmembrane domain containing 3', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 3|chemokine-like factor superfamily member 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66603996, end_position_on_the_genomic_accession=66613892, orientation='plus', exon_count=6, OMIM=[607886], no_hdr0=''),
    123970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=123970, CurrentID=0, Status='live', Symbol='C16orf78', Aliases=[], description='chromosome 16 open reading frame 78', other_designations='uncharacterized protein C16orf78', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=49373804, end_position_on_the_genomic_accession=49399431, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    124044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124044, CurrentID=0, Status='live', Symbol='SPATA2L', Aliases=['C16orf76', 'tamo'], description='spermatogenesis associated 2 like', other_designations='spermatogenesis-associated protein 2-like protein|SPATA2-like protein', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89696357, end_position_on_the_genomic_accession=89701705, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    124045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124045, CurrentID=0, Status='live', Symbol='SPATA33', Aliases=['C16orf55'], description='spermatogenesis associated 33', other_designations='spermatogenesis-associated protein 33', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89657776, end_position_on_the_genomic_accession=89670458, orientation='plus', exon_count=5, OMIM=[615409], no_hdr0=''),
    124056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124056, CurrentID=0, Status='live', Symbol='NOXO1', Aliases=['P41NOX', 'P41NOXA', 'P41NOXB', 'P41NOXC', 'SH3PXD5', 'SNX28'], description='NADPH oxidase organizer 1', other_designations='NADPH oxidase organizer 1|NADPH oxidase regulatory protein|Nox organizer 1|SH3 and PX domain-containing protein 5|nox-organizing protein 1|regulatory protein P41NOX', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1978917, end_position_on_the_genomic_accession=1984027, orientation='minus', exon_count=9, OMIM=[611256], no_hdr0=''),
    124093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124093, CurrentID=0, Status='live', Symbol='CCDC78', Aliases=['C16orf25', 'CNM4', 'JFP10', 'hsCCDC78'], description='coiled-coil domain containing 78', other_designations='coiled-coil domain-containing protein 78', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=722578, end_position_on_the_genomic_accession=726880, orientation='minus', exon_count=12, OMIM=[614666], no_hdr0=''),
    124152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124152, CurrentID=0, Status='live', Symbol='IQCK', Aliases=[], description='IQ motif containing K', other_designations='IQ domain-containing protein K', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19718271, end_position_on_the_genomic_accession=19858467, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    124220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124220, CurrentID=0, Status='live', Symbol='ZG16B', Aliases=['EECP', 'HRPE773', 'JCLN2', 'PAUF', 'PRO1567'], description='zymogen granule protein 16B', other_designations='zymogen granule protein 16 homolog B|endocrine and exocrine protein|jacalin-like lectin domain containing 2|pancreatic adenocarcinoma upregulated factor', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2830303, end_position_on_the_genomic_accession=2832276, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    124222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124222, CurrentID=0, Status='live', Symbol='PAQR4', Aliases=[], description='progestin and adipoQ receptor family member 4', other_designations='progestin and adipoQ receptor family member 4|progestin and adipoQ receptor family member IV', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2969348, end_position_on_the_genomic_accession=2973484, orientation='plus', exon_count=4, OMIM=[614578], no_hdr0=''),
    124245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124245, CurrentID=0, Status='live', Symbol='ZC3H18', Aliases=['NHN1'], description='zinc finger CCCH-type containing 18', other_designations='zinc finger CCCH domain-containing protein 18|conserved nuclear protein NHN1|nuclear protein NHN1', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88570403, end_position_on_the_genomic_accession=88631964, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    124274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124274, CurrentID=0, Status='live', Symbol='GPR139', Aliases=['GPRg1', 'PGR3'], description='G protein-coupled receptor 139', other_designations='probable G-protein coupled receptor 139|G protein-coupled receptor PGR3|g(q)-coupled orphan receptor GPRg1', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20028239, end_position_on_the_genomic_accession=20073890, orientation='minus', exon_count=3, OMIM=[618448], no_hdr0=''),
    124359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124359, CurrentID=0, Status='live', Symbol='CDYL2', Aliases=['PCCP1'], description='chromodomain Y like 2', other_designations='chromodomain Y-like protein 2|CDY-like 2|chromodomain protein, Y-like 2|prostate cancer candidate protein 1, PCCP1', map_location='16q23.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=80597899, end_position_on_the_genomic_accession=80805043, orientation='minus', exon_count=10, OMIM=[618816], no_hdr0=''),
    124401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124401, CurrentID=0, Status='live', Symbol='ANKS3', Aliases=[], description='ankyrin repeat and sterile alpha motif domain containing 3', other_designations='ankyrin repeat and SAM domain-containing protein 3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4696510, end_position_on_the_genomic_accession=4734347, orientation='minus', exon_count=19, OMIM=[617310], no_hdr0=''),
    124402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124402, CurrentID=0, Status='live', Symbol='UBALD1', Aliases=['FAM100A', 'PP11303'], description='UBA like domain containing 1', other_designations='UBA-like domain-containing protein 1|family with sequence similarity 100, member A|protein FAM100A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4608884, end_position_on_the_genomic_accession=4614888, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    124404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124404, CurrentID=0, Status='live', Symbol='SEPTIN12', Aliases=['SEPT12', 'SPGF10'], description='septin 12', other_designations='septin-12|testicular tissue protein Li 168', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4777590, end_position_on_the_genomic_accession=4791610, orientation='minus', exon_count=11, OMIM=[611562], no_hdr0=''),
    124411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124411, CurrentID=0, Status='live', Symbol='ZNF720', Aliases=[], description='zinc finger protein 720', other_designations='putative protein ZNF720', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31713244, end_position_on_the_genomic_accession=31761565, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    124446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124446, CurrentID=0, Status='live', Symbol='TMEM219', Aliases=['IGFBP-3R'], description='transmembrane protein 219', other_designations='insulin-like growth factor-binding protein 3 receptor|testicular tissue protein Li 203', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29962079, end_position_on_the_genomic_accession=29973048, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    124454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124454, CurrentID=0, Status='live', Symbol='EARS2', Aliases=['COXPD12', 'MSE1', 'gluRS', 'mtGlnRS'], description='glutamyl-tRNA synthetase 2, mitochondrial', other_designations='probable glutamate--tRNA ligase, mitochondrial|glutamate tRNA ligase 2, mitochondrial|glutamate--tRNA ligase|probable glutamyl-tRNA synthetase, mitochondrial', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=23520754, end_position_on_the_genomic_accession=23557375, orientation='minus', exon_count=10, OMIM=[612799], no_hdr0=''),
    124460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124460, CurrentID=0, Status='live', Symbol='SNX20', Aliases=['SLIC1'], description='sorting nexin 20', other_designations='sorting nexin-20|selectin ligand-interactor cytoplasmic 1', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50666300, end_position_on_the_genomic_accession=50681312, orientation='minus', exon_count=5, OMIM=[613281], no_hdr0=''),
    124491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124491, CurrentID=0, Status='live', Symbol='TMEM170A', Aliases=['TMEM170'], description='transmembrane protein 170A', other_designations='transmembrane protein 170A|transmembrane protein 170', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75443054, end_position_on_the_genomic_accession=75464757, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    124512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124512, CurrentID=0, Status='live', Symbol='METTL23', Aliases=['C17orf95', 'MRT44'], description='methyltransferase like 23', other_designations='methyltransferase-like protein 23|spike binding protein 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76726041, end_position_on_the_genomic_accession=76733881, orientation='plus', exon_count=7, OMIM=[615262], no_hdr0=''),
    124535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124535, CurrentID=0, Status='live', Symbol='HSF5', Aliases=['HSF 5', 'HSTF 5'], description='heat shock transcription factor 5', other_designations='heat shock factor protein 5|heat shock transcription factor family member 5', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58420167, end_position_on_the_genomic_accession=58488408, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    124538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124538, CurrentID=0, Status='live', Symbol='OR4D2', Aliases=['BC2009', 'OR17-24'], description='olfactory receptor family 4 subfamily D member 2', other_designations='olfactory receptor 4D2|B-lymphocyte membrane protein BC2009|G-protein coupled membrane protein|olfactory receptor OR17-24', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58166982, end_position_on_the_genomic_accession=58171116, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    124540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124540, CurrentID=0, Status='live', Symbol='MSI2', Aliases=['MSI2H'], description='musashi RNA binding protein 2', other_designations='RNA-binding protein Musashi homolog 2|musashi homolog 2|musashi-2', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57255851, end_position_on_the_genomic_accession=57684689, orientation='plus', exon_count=20, OMIM=[607897], no_hdr0=''),
    124565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124565, CurrentID=0, Status='live', Symbol='SLC38A10', Aliases=['PP1744'], description='solute carrier family 38 member 10', other_designations='putative sodium-coupled neutral amino acid transporter 10', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81244811, end_position_on_the_genomic_accession=81295433, orientation='minus', exon_count=18, OMIM=[616525], no_hdr0=''),
    124583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124583, CurrentID=0, Status='live', Symbol='CANT1', Aliases=['DBQD', 'DBQD1', 'EDM7', 'SCAN-1', 'SCAN1', 'SHAPY'], description='calcium activated nucleotidase 1', other_designations='soluble calcium-activated nucleotidase 1|Ca2+-dependent endoplasmic reticulum nucleoside diphosphatase|apyrase 1 homolog (C. lectularius)|apyrase homolog|micromelic dwarfism with vertebral and metaphyseal abnormalities and advanced carpotarsal ossification|putative MAPK-activating protein PM09|putative NF-kappa-B-activating protein 107|soluble Ca-activated nucleotidase, isozyme 1|soluble calcium-activated nucleotidase SCAN-1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78991716, end_position_on_the_genomic_accession=79009793, orientation='minus', exon_count=8, OMIM=[613165], no_hdr0=''),
    124590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124590, CurrentID=0, Status='live', Symbol='USH1G', Aliases=['ANKS4A', 'SANS'], description='USH1 protein network component sans', other_designations='Usher syndrome type-1G protein|Usher syndrome 1G (autosomal recessive)|scaffold protein containing ankyrin repeats and SAM domain', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74916083, end_position_on_the_genomic_accession=74923255, orientation='minus', exon_count=4, OMIM=[607696], no_hdr0=''),
    124599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124599, CurrentID=0, Status='live', Symbol='CD300LB', Aliases=['CD300b', 'CLM-7', 'CLM7', 'CMRF35-A2', 'IREM-3', 'IREM3', 'TREM-5', 'TREM5'], description='CD300 molecule like family member b', other_designations='CMRF35-like molecule 7|CD300 antigen like family member B|immune receptor expressed on myeloid cells 3|leukocyte mono-Ig-like receptor 5|triggering receptor expressed on myeloid cells 5', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74521174, end_position_on_the_genomic_accession=74531475, orientation='minus', exon_count=4, OMIM=[610705], no_hdr0=''),
    124602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124602, CurrentID=0, Status='live', Symbol='KIF19', Aliases=['KIF19A'], description='kinesin family member 19', other_designations='kinesin-like protein KIF19', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74326212, end_position_on_the_genomic_accession=74355820, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    124626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124626, CurrentID=0, Status='live', Symbol='ZPBP2', Aliases=['ZPBPL'], description='zona pellucida binding protein 2', other_designations='zona pellucida-binding protein 2|ZPBP-like protein', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39868164, end_position_on_the_genomic_accession=39877896, orientation='plus', exon_count=8, OMIM=[608499], no_hdr0=''),
    124637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124637, CurrentID=0, Status='live', Symbol='CYB5D1', Aliases=[], description='cytochrome b5 domain containing 1', other_designations='cytochrome b5 domain-containing protein 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7858003, end_position_on_the_genomic_accession=7862282, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    124641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124641, CurrentID=0, Status='live', Symbol='OVCA2', Aliases=[], description='OVCA2 serine hydrolase domain containing', other_designations='esterase OVCA2|candidate tumor suppressor in ovarian cancer 2|ovarian cancer gene-2 protein|ovarian cancer-associated gene 2 protein|ovarian tumor suppressor candidate 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2042022, end_position_on_the_genomic_accession=2043425, orientation='plus', exon_count=2, OMIM=[607896], no_hdr0=''),
    124739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124739, CurrentID=0, Status='live', Symbol='USP43', Aliases=[], description='ubiquitin specific peptidase 43', other_designations='ubiquitin carboxyl-terminal hydrolase 43|deubiquitinating enzyme 43|ubiquitin specific protease 43|ubiquitin thioesterase 43|ubiquitin thiolesterase 43|ubiquitin-specific-processing protease 43', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9643493, end_position_on_the_genomic_accession=9729687, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    124751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124751, CurrentID=0, Status='live', Symbol='KRBA2', Aliases=[], description='KRAB-A domain containing 2', other_designations='KRAB-A domain-containing protein 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8358822, end_position_on_the_genomic_accession=8376704, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    124773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124773, CurrentID=0, Status='live', Symbol='C17orf64', Aliases=[], description='chromosome 17 open reading frame 64', other_designations='uncharacterized protein C17orf64', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=60421090, end_position_on_the_genomic_accession=60431426, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    124783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124783, CurrentID=0, Status='live', Symbol='SPATA32', Aliases=['AEP2', 'C17orf46', 'TEX34', 'VAD1.2'], description='spermatogenesis associated 32', other_designations='spermatogenesis-associated protein 32|CTD-2020K17.4|acrosome expressed 2|testis expressed 34|testis-expressed protein 34|testis-expressed sequence 34 protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45254393, end_position_on_the_genomic_accession=45262094, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    124790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124790, CurrentID=0, Status='live', Symbol='HEXIM2', Aliases=['L3'], description='HEXIM P-TEFb complex subunit 2', other_designations='protein HEXIM2|MAQ1 paralog|hexamethylene bis-acetamide inducible 2|hexamethylene bis-acetamide-inducible protein 2|hexamethylene bisacetamide inducible 2|hexamethylene-bis-acetamide-inducible transcript 2', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45159948, end_position_on_the_genomic_accession=45170040, orientation='plus', exon_count=5, OMIM=[615695], no_hdr0=''),
    124801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124801, CurrentID=0, Status='live', Symbol='LSM12', Aliases=['PNAS-135'], description='LSM12 homolog', other_designations='protein LSM12 homolog', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44034328, end_position_on_the_genomic_accession=44067587, orientation='minus', exon_count=9, OMIM=[611793], no_hdr0=''),
    124808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124808, CurrentID=0, Status='live', Symbol='CCDC43', Aliases=[], description='coiled-coil domain containing 43', other_designations='coiled-coil domain-containing protein 43', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44677440, end_position_on_the_genomic_accession=44689776, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    124817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124817, CurrentID=0, Status='live', Symbol='CNTD1', Aliases=['CNTD', 'COSA1'], description='cyclin N-terminal domain containing 1', other_designations='cyclin N-terminal domain-containing protein 1', map_location='17q21.2-q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42798749, end_position_on_the_genomic_accession=42811587, orientation='plus', exon_count=8, OMIM=[618166], no_hdr0=''),
    124842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124842, CurrentID=0, Status='live', Symbol='TMEM132E', Aliases=['DFNB99'], description='transmembrane protein 132E', other_designations='transmembrane protein 132E', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=34579582, end_position_on_the_genomic_accession=34639318, orientation='plus', exon_count=9, OMIM=[616178], no_hdr0=''),
    124857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124857, CurrentID=0, Status='live', Symbol='WFIKKN2', Aliases=['GASP-1', 'WFDC20B', 'WFIKKNRP', 'hGASP-1'], description='WAP, follistatin/kazal, immunoglobulin, kunitz and netrin domain containing 2', other_designations='WAP, Kazal, immunoglobulin, Kunitz and NTR domain-containing protein 2|WAP four-disulfide core domain 20B|WAP, FS, Ig, two KU and NTR module related protein|WAP, follistatin, immunoglobulin, kunitz and NTR domain-containing-related protein|WFIKKN-related protein|growth and differentiation factor-associated serum protein 1|multivalent protease inhibitor protein', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50834584, end_position_on_the_genomic_accession=50842353, orientation='plus', exon_count=3, OMIM=[610895], no_hdr0=''),
    124872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124872, CurrentID=0, Status='live', Symbol='B4GALNT2', Aliases=['B4GALT', 'GALGT2'], description='beta-1,4-N-acetyl-galactosaminyltransferase 2', other_designations='beta-1,4 N-acetylgalactosaminyltransferase 2|UDP-GalNAc:Neu5Aca2-3Galb-R b1,4-N-acetylgalactosaminyltransferase|UDP-GalNAc:Neu5Acalpha2-3Galbeta-R beta1,4-N-acetylgalactosaminyltransferase|beta 1,4 N-acetylgalactosaminyltransferase/betal,4 GalNAcT/Sda-GalNAcT|beta-1,4-N-acetyl-galactosaminyl transferase 2|beta-4-N-acetylgalactosaminyltransferase|sd(a) beta-1,4-GalNAc transferase|sda beta-1,4-GalNAc transferase', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49120347, end_position_on_the_genomic_accession=49176840, orientation='plus', exon_count=13, OMIM=[111730], no_hdr0=''),
    124912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124912, CurrentID=0, Status='live', Symbol='SPACA3', Aliases=['ALLP17', 'CT54', 'LYC3', 'LYZC', 'LYZL3', 'SLLP1'], description='sperm acrosome associated 3', other_designations='sperm acrosome membrane-associated protein 3|cancer/testis antigen 54|lysozyme C|lysozyme-like acrosomal sperm-specific secretory protein ALLP-17|lysozyme-like protein 3|lysozyme-like sperm-specific secretory protein ALLP17|sperm lysozyme-like protein 1|sperm lyzozyme-like acrosomal protein 1|sperm protein reactive with ASA|sperm protein reactive with antisperm antibodies', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32991847, end_position_on_the_genomic_accession=32997877, orientation='plus', exon_count=6, OMIM=[612749], no_hdr0=''),
    124923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124923, CurrentID=0, Status='live', Symbol='RSKR', Aliases=['SGK494'], description='ribosomal protein S6 kinase related', other_designations='ribosomal protein S6 kinase-related protein|sugen kinase 494', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28607963, end_position_on_the_genomic_accession=28614185, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    124925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124925, CurrentID=0, Status='live', Symbol='SEZ6', Aliases=['BSRPC'], description='seizure related 6 homolog', other_designations='seizure protein 6 homolog', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28954905, end_position_on_the_genomic_accession=29006440, orientation='minus', exon_count=18, OMIM=[616666], no_hdr0=''),
    124930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124930, CurrentID=0, Status='live', Symbol='ANKRD13B', Aliases=[], description='ankyrin repeat domain 13B', other_designations='ankyrin repeat domain-containing protein 13B', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29589769, end_position_on_the_genomic_accession=29615006, orientation='plus', exon_count=19, OMIM=[615124], no_hdr0=''),
    124935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124935, CurrentID=0, Status='live', Symbol='SLC43A2', Aliases=['LAT4'], description='solute carrier family 43 member 2', other_designations='large neutral amino acids transporter small subunit 4|L-type amino acid transporter 4|solute carrier family 43 (amino acid system L transporter), member 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1569254, end_position_on_the_genomic_accession=1630014, orientation='minus', exon_count=18, OMIM=[610791], no_hdr0=''),
    124936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124936, CurrentID=0, Status='live', Symbol='CYB5D2', Aliases=[], description='cytochrome b5 domain containing 2', other_designations='neuferricin|cytochrome b5 domain-containing protein 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4143117, end_position_on_the_genomic_accession=4157701, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    124944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124944, CurrentID=0, Status='live', Symbol='C17orf49', Aliases=['BAP18', 'HEPIS'], description='chromosome 17 open reading frame 49', other_designations='chromatin complexes subunit BAP18|BPTF-associated protein of 18 kDa|MLL1/MLL complex subunit C17orf49|human embryo lung cellular protein interacting with SARS-CoV nsp-10', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7014782, end_position_on_the_genomic_accession=7017520, orientation='plus', exon_count=6, OMIM=[617215], no_hdr0=''),
    124961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124961, CurrentID=0, Status='live', Symbol='ZFP3', Aliases=['ZNF752'], description='ZFP3 zinc finger protein', other_designations='zinc finger protein 3 homolog|zfp-3|zinc finger protein 752|zinc finger protein homologous to Zfp-3 in mouse|zinc finger protein-3', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5078467, end_position_on_the_genomic_accession=5096374, orientation='plus', exon_count=2, OMIM=[194480], no_hdr0=''),
    124975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124975, CurrentID=0, Status='live', Symbol='GGT6', Aliases=[], description='gamma-glutamyltransferase 6', other_designations='glutathione hydrolase 6|gamma-glutamyltransferase 6 homolog|gamma-glutamyltranspeptidase 6', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4556927, end_position_on_the_genomic_accession=4560920, orientation='minus', exon_count=4, OMIM=[612341], no_hdr0=''),
    124976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124976, CurrentID=0, Status='live', Symbol='SPNS2', Aliases=['DFNB115', 'SLC62A2', 'SLC63A2'], description='sphingolipid transporter 2', other_designations='protein spinster homolog 2|SPNS sphingolipid transporter 2|spinster homolog 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4498881, end_position_on_the_genomic_accession=4539035, orientation='plus', exon_count=14, OMIM=[612584], no_hdr0=''),
    124989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124989, CurrentID=0, Status='live', Symbol='EFCAB13', Aliases=['C17orf57'], description='EF-hand calcium binding domain 13', other_designations='EF-hand calcium-binding domain-containing protein 13|EF-hand domain-containing protein C17orf57', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47323955, end_position_on_the_genomic_accession=47441312, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    124995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124995, CurrentID=0, Status='live', Symbol='MRPL10', Aliases=['L10MT', 'MRP-L10', 'MRP-L8', 'MRPL8', 'RPML8'], description='mitochondrial ribosomal protein L10', other_designations='39S ribosomal protein L10, mitochondrial|39S ribosomal protein L8, mitochondrial|L8mt|mitochondrial large ribosomal subunit protein uL10m', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=47823272, end_position_on_the_genomic_accession=47831541, orientation='minus', exon_count=6, OMIM=[611825], no_hdr0=''),
    124997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=124997, CurrentID=0, Status='live', Symbol='WDR81', Aliases=['CAMRQ2', 'HYC3', 'PPP1R166', 'SORF-2'], description='WD repeat domain 81', other_designations='WD repeat-containing protein 81|protein phosphatase 1, regulatory subunit 166', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1716523, end_position_on_the_genomic_accession=1738585, orientation='plus', exon_count=12, OMIM=[614218], no_hdr0=''),
    125058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125058, CurrentID=0, Status='live', Symbol='TBC1D16', Aliases=[], description='TBC1 domain family member 16', other_designations='TBC1 domain family member 16|CTD-2529O21.1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79932343, end_position_on_the_genomic_accession=80035875, orientation='minus', exon_count=17, OMIM=[616637], no_hdr0=''),
    125061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125061, CurrentID=0, Status='live', Symbol='AFMID', Aliases=['FKF', 'KF', 'KFA'], description='arylformamidase', other_designations='kynurenine formamidase|KFase|N-formylkynurenine formamidase|probable arylformamidase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78185102, end_position_on_the_genomic_accession=78207702, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    125111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125111, CurrentID=0, Status='live', Symbol='GJD3', Aliases=['CX31.9', 'Cx30.2', 'GJA11', 'GJC1'], description='gap junction protein delta 3', other_designations='gap junction delta-3 protein|connexin-31.9|gap junction alpha-11 protein|gap junction chi-1 protein|gap junction protein, delta 3, 31.9kDa', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40360652, end_position_on_the_genomic_accession=40364737, orientation='minus', exon_count=1, OMIM=[607425], no_hdr0=''),
    125113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125113, CurrentID=0, Status='live', Symbol='KRT222', Aliases=['KA21P', 'KRT222'], description='keratin 222', other_designations='keratin-like protein KRT222|keratin 222, type II|keratin-222 pseudogene', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40654665, end_position_on_the_genomic_accession=40665177, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    125115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125115, CurrentID=0, Status='live', Symbol='KRT40', Aliases=['CK-40', 'K40', 'KA36'], description='keratin 40', other_designations='keratin, type I cytoskeletal 40|cytokeratin-40|keratin 40, type I|type I hair keratin KA36', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40977715, end_position_on_the_genomic_accession=40987135, orientation='minus', exon_count=10, OMIM=[616679], no_hdr0=''),
    125150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125150, CurrentID=0, Status='live', Symbol='ZSWIM7', Aliases=['SWS1'], description='zinc finger SWIM-type containing 7', other_designations='zinc finger SWIM domain-containing protein 7|SWIM domain-containing and Srs2-interacting protein 1 homolog|SWIM-type zinc finger domain-containing protein 7', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15976560, end_position_on_the_genomic_accession=15999704, orientation='minus', exon_count=6, OMIM=[614535], no_hdr0=''),
    125168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125168, CurrentID=0, Status='live', Symbol='RIBIN', Aliases=[], description='rRNA promoter binding protein', other_designations='', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    125170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125170, CurrentID=0, Status='live', Symbol='MIEF2', Aliases=['COXPD49', 'MID49', 'SMCR7'], description='mitochondrial elongation factor 2', other_designations='mitochondrial dynamics protein MID49|Smith-Magenis syndrome chromosomal region candidate gene 7 protein|Smith-Magenis syndrome chromosome region, candidate 7|mitochondrial dynamic protein MID49|mitochondrial dynamic protein of 49 kDa|mitochondrial dynamics protein of 49 kDa', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18260662, end_position_on_the_genomic_accession=18266552, orientation='plus', exon_count=6, OMIM=[615498], no_hdr0=''),
    125206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125206, CurrentID=0, Status='live', Symbol='SLC5A10', Aliases=['SGLT-5', 'SGLT5'], description='solute carrier family 5 member 10', other_designations='sodium/glucose cotransporter 5|Na(+)/glucose cotransporter 5|solute carrier family 5 (sodium/glucose cotransporter), member 10|solute carrier family 5 (sodium/sugar cotransporter), member 10', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18950676, end_position_on_the_genomic_accession=19022565, orientation='plus', exon_count=17, OMIM=[618636], no_hdr0=''),
    125228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125228, CurrentID=0, Status='live', Symbol='FAM210A', Aliases=['C18orf19', 'HsT2329'], description='family with sequence similarity 210 member A', other_designations='protein FAM210A|uncharacterized protein C18orf19', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=13663347, end_position_on_the_genomic_accession=13726558, orientation='minus', exon_count=6, OMIM=[617975], no_hdr0=''),
    125336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125336, CurrentID=0, Status='live', Symbol='LOXHD1', Aliases=['DFNB77', 'LH2D1'], description='lipoxygenase homology PLAT domains 1', other_designations='lipoxygenase homology domain-containing protein 1|lipoxygenase homology domains 1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46476961, end_position_on_the_genomic_accession=46657220, orientation='minus', exon_count=48, OMIM=[613072], no_hdr0=''),
    125476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125476, CurrentID=0, Status='live', Symbol='INO80C', Aliases=['C18orf37', 'IES6', 'hIes6'], description='INO80 complex subunit C', other_designations='INO80 complex subunit C|IES6 homolog', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35468333, end_position_on_the_genomic_accession=35497960, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    125488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125488, CurrentID=0, Status='live', Symbol='TTC39C', Aliases=['C18orf17', 'HsT2697'], description='tetratricopeptide repeat domain 39C', other_designations='tetratricopeptide repeat protein 39C|TPR repeat protein 39C', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23992843, end_position_on_the_genomic_accession=24135970, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    125704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125704, CurrentID=0, Status='live', Symbol='DIPK1C', Aliases=['C18orf51', 'FAM69C'], description='divergent protein kinase domain 1C', other_designations='divergent protein kinase domain 1C|family with sequence similarity 69 member C|protein FAM69C', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74434775, end_position_on_the_genomic_accession=74464646, orientation='minus', exon_count=6, OMIM=[614544], no_hdr0=''),
    125875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125875, CurrentID=0, Status='live', Symbol='CLDND2', Aliases=[], description='claudin domain containing 2', other_designations='claudin domain-containing protein 2', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51366750, end_position_on_the_genomic_accession=51369255, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    125893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125893, CurrentID=0, Status='live', Symbol='ZNF816', Aliases=['ZNF816A'], description='zinc finger protein 816', other_designations='zinc finger protein 816|zinc finger protein 816A', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52949385, end_position_on_the_genomic_accession=52962881, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    125919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125919, CurrentID=0, Status='live', Symbol='ZNF543', Aliases=[], description='zinc finger protein 543', other_designations='zinc finger protein 543', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57320472, end_position_on_the_genomic_accession=57330770, orientation='plus', exon_count=4, OMIM=[616847], no_hdr0=''),
    125931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125931, CurrentID=0, Status='live', Symbol='CEACAM20', Aliases=['UNQ9366'], description='CEA cell adhesion molecule 20', other_designations='carcinoembryonic antigen-related cell adhesion molecule 20|GPAD9366|carcinoembryonic antigen related cell adhesion molecule 20', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44501309, end_position_on_the_genomic_accession=44530101, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    125950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125950, CurrentID=0, Status='live', Symbol='RAVER1', Aliases=[], description='ribonucleoprotein, PTB binding 1', other_designations='ribonucleoprotein PTB-binding 1|protein raver-1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10316212, end_position_on_the_genomic_accession=10333529, orientation='minus', exon_count=14, OMIM=[609950], no_hdr0=''),
    125958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125958, CurrentID=0, Status='live', Symbol='OR7D4', Aliases=['OR19-7', 'OR19-B', 'OR19BP', 'hg105', 'OR7D4'], description='olfactory receptor family 7 subfamily D member 4', other_designations='olfactory receptor 7D4|odorant receptor family 7 subfamily D member 4 RT|olfactory receptor OR19-7|olfactory receptor, family 7, subfamily D, member 4 pseudogene', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9210276, end_position_on_the_genomic_accession=9219589, orientation='minus', exon_count=2, OMIM=[611538], no_hdr0=''),
    125962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125962, CurrentID=0, Status='live', Symbol='OR7G1', Aliases=['OR19-15', 'OR19-8P', 'OR7G1'], description='olfactory receptor family 7 subfamily G member 1', other_designations='olfactory receptor 7G1|olfactory receptor 19-15|olfactory receptor OR19-8', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9114828, end_position_on_the_genomic_accession=9115763, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    125963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125963, CurrentID=0, Status='live', Symbol='OR1M1', Aliases=['OR19-5', 'OR19-6'], description='olfactory receptor family 1 subfamily M member 1', other_designations='olfactory receptor 1M1|olfactory receptor 19-6|olfactory receptor OR19-5', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9087061, end_position_on_the_genomic_accession=9095669, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    125965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125965, CurrentID=0, Status='live', Symbol='COX6B2', Aliases=['COXVIB2', 'CT59'], description='cytochrome c oxidase subunit 6B2', other_designations='cytochrome c oxidase subunit 6B2|COX VIb-2|cancer/testis antigen 59|cytochrome c oxidase subunit VIb polypeptide 2 (testis)|cytochrome c oxidase subunit VIb, testes-specific', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55349704, end_position_on_the_genomic_accession=55354719, orientation='minus', exon_count=8, OMIM=[618127], no_hdr0=''),
    125972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125972, CurrentID=0, Status='live', Symbol='CALR3', Aliases=['CMH19', 'CRT2', 'CT93'], description='calreticulin 3', other_designations='calreticulin-3|calreticulin-2|calsperin|cancer/testis antigen 93|testis secretory sperm-binding protein Li 226n', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16479061, end_position_on_the_genomic_accession=16496167, orientation='minus', exon_count=9, OMIM=[611414], no_hdr0=''),
    125981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125981, CurrentID=0, Status='live', Symbol='ACER1', Aliases=['ALKCDase1', 'ASAH3'], description='alkaline ceramidase 1', other_designations='alkaline ceramidase 1|CTB-180A7.3|N-acylsphingosine amidohydrolase (alkaline ceramidase) 3|N-acylsphingosine amidohydrolase 3|acylsphingosine deacylase 3|alkCDase 1|alkaline CDase 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6306142, end_position_on_the_genomic_accession=6360368, orientation='minus', exon_count=8, OMIM=[613491], no_hdr0=''),
    125988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125988, CurrentID=0, Status='live', Symbol='MICOS13', Aliases=['C19orf70', 'MIC12', 'MIC13', 'P117', 'QIL1'], description='mitochondrial contact site and cristae organizing system subunit 13', other_designations='MICOS complex subunit MIC13|protein QIL1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5678422, end_position_on_the_genomic_accession=5680516, orientation='minus', exon_count=6, OMIM=[616658], no_hdr0=''),
    125997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=125997, CurrentID=0, Status='live', Symbol='MBD3L2', Aliases=[], description='methyl-CpG binding domain protein 3 like 2', other_designations='methyl-CpG-binding domain protein 3-like 2|CTB-25J19.1|MBD3-like protein 2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7049321, end_position_on_the_genomic_accession=7051735, orientation='plus', exon_count=2, OMIM=[607964], no_hdr0=''),
    126003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126003, CurrentID=0, Status='live', Symbol='TRAPPC5', Aliases=['TRS31'], description='trafficking protein particle complex subunit 5', other_designations='trafficking protein particle complex subunit 5|trafficking protein particle complex 5', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7680833, end_position_on_the_genomic_accession=7687703, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    126006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126006, CurrentID=0, Status='live', Symbol='PCP2', Aliases=['GPSM4', 'PCD5'], description='Purkinje cell protein 2', other_designations='Purkinje cell protein 2 homolog|CTD-3214H19.6|Purkinje cell-specific protein 2|Purkinje cell-specific protein L7', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7631614, end_position_on_the_genomic_accession=7637026, orientation='minus', exon_count=6, OMIM=[619344], no_hdr0=''),
    126014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126014, CurrentID=0, Status='live', Symbol='OSCAR', Aliases=['PIGR3', 'PIgR-3'], description='osteoclast associated Ig-like receptor', other_designations='osteoclast-associated immunoglobulin-like receptor|osteoclast associated receptor OSCAR-S1|osteoclast associated receptor OSCAR-S2|osteoclast associated, immunoglobulin-like receptor|poly-Ig receptor 3|polymeric immunoglobulin receptor 3', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54094668, end_position_on_the_genomic_accession=54100803, orientation='minus', exon_count=6, OMIM=[606862], no_hdr0=''),
    126017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126017, CurrentID=0, Status='live', Symbol='ZNF813', Aliases=[], description='zinc finger protein 813', other_designations='zinc finger protein 813', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53467733, end_position_on_the_genomic_accession=53496255, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    126068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126068, CurrentID=0, Status='live', Symbol='ZNF441', Aliases=[], description='zinc finger protein 441', other_designations='zinc finger protein 441', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11767000, end_position_on_the_genomic_accession=11784078, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    126069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126069, CurrentID=0, Status='live', Symbol='ZNF491', Aliases=[], description='zinc finger protein 491', other_designations='zinc finger protein 491', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11798523, end_position_on_the_genomic_accession=11809622, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    126070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126070, CurrentID=0, Status='live', Symbol='ZNF440', Aliases=[], description='zinc finger protein 440', other_designations='zinc finger protein 440', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11814273, end_position_on_the_genomic_accession=11835617, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    126074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126074, CurrentID=0, Status='live', Symbol='SWSAP1', Aliases=['C19orf39', 'SWS1AP1', 'ZSWIM7AP1'], description='SWIM-type zinc finger 7 associated protein 1', other_designations='ATPase SWSAP1|SWS1-associated protein 1|ZSWIM7-associated protein 1|zinc finger, SWIM-type containing 7 associated protein 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11374666, end_position_on_the_genomic_accession=11376169, orientation='plus', exon_count=2, OMIM=[614536], no_hdr0=''),
    126075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126075, CurrentID=0, Status='live', Symbol='CCDC159', Aliases=[], description='coiled-coil domain containing 159', other_designations='coiled-coil domain-containing protein 159', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11346483, end_position_on_the_genomic_accession=11354951, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    126119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126119, CurrentID=0, Status='live', Symbol='JOSD2', Aliases=['SBBI54'], description='Josephin domain containing 2', other_designations='josephin-2|josephin domain-containing protein 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50505998, end_position_on_the_genomic_accession=50511204, orientation='minus', exon_count=5, OMIM=[615324], no_hdr0=''),
    126123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126123, CurrentID=0, Status='live', Symbol='IZUMO2', Aliases=['C19orf41', 'PLAL6978', 'PRO21961', 'SCRL'], description='IZUMO family member 2', other_designations='izumo sperm-egg fusion protein 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50152548, end_position_on_the_genomic_accession=50163281, orientation='minus', exon_count=10, OMIM=[618895], no_hdr0=''),
    126129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126129, CurrentID=0, Status='live', Symbol='CPT1C', Aliases=['CATL1', 'CPT1-B', 'CPT1P', 'CPTI-B', 'CPTIC', 'SPG73'], description='carnitine palmitoyltransferase 1C', other_designations='carnitine O-palmitoyltransferase 1, brain isoform|carnitine palmitoyltransferase I related C', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49690672, end_position_on_the_genomic_accession=49713731, orientation='plus', exon_count=24, OMIM=[608846], no_hdr0=''),
    126133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126133, CurrentID=0, Status='live', Symbol='ALDH16A1', Aliases=[], description='aldehyde dehydrogenase 16 family member A1', other_designations='aldehyde dehydrogenase family 16 member A1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49453225, end_position_on_the_genomic_accession=49471050, orientation='plus', exon_count=19, OMIM=[613358], no_hdr0=''),
    126147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126147, CurrentID=0, Status='live', Symbol='NTN5', Aliases=[], description='netrin 5', other_designations='netrin-5|netrin-1-like protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48661407, end_position_on_the_genomic_accession=48673119, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    126204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126204, CurrentID=0, Status='live', Symbol='NLRP13', Aliases=['CLR19.7', 'NALP13', 'NOD14', 'PAN13'], description='NLR family pyrin domain containing 13', other_designations='NACHT, LRR and PYD domains-containing protein 13|NACHT, LRR and PYD containing protein 13|NACHT, leucine rich repeat and PYD containing 13|nucleotide-binding oligomerization domain protein 14|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 13', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55891692, end_position_on_the_genomic_accession=55932336, orientation='minus', exon_count=12, OMIM=[609660], no_hdr0=''),
    126205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126205, CurrentID=0, Status='live', Symbol='NLRP8', Aliases=['CLR19.2', 'NALP8', 'NOD16', 'PAN4'], description='NLR family pyrin domain containing 8', other_designations='NACHT, LRR and PYD domains-containing protein 8|NACHT, leucine rich repeat and PYD containing 8|PYRIN and NACHT-containing protein 4|nucleotide-binding oligomerization domain protein 16|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 8', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55947832, end_position_on_the_genomic_accession=55988629, orientation='plus', exon_count=10, OMIM=[609659], no_hdr0=''),
    126206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126206, CurrentID=0, Status='live', Symbol='NLRP5', Aliases=['CLR19.8', 'MATER', 'NALP5', 'PAN11', 'PYPAF8'], description='NLR family pyrin domain containing 5', other_designations='NACHT, LRR and PYD domains-containing protein 5|NACHT, leucine rich repeat and PYD containing 5|mater protein homolog|maternal antigen that embryos require|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 5', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55999726, end_position_on_the_genomic_accession=56061810, orientation='plus', exon_count=15, OMIM=[609658], no_hdr0=''),
    126208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126208, CurrentID=0, Status='live', Symbol='ZNF787', Aliases=['TIP20'], description='zinc finger protein 787', other_designations='zinc finger protein 787|TTF-I-interacting peptide 20|transcription termination factor I interacting peptide 20', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56087366, end_position_on_the_genomic_accession=56121295, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    126231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126231, CurrentID=0, Status='live', Symbol='ZNF573', Aliases=[], description='zinc finger protein 573', other_designations='zinc finger protein 573', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37738302, end_position_on_the_genomic_accession=37779586, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    126248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126248, CurrentID=0, Status='live', Symbol='WDR88', Aliases=['PQWD'], description='WD repeat domain 88', other_designations='WD repeat-containing protein 88|PQQ repeat and WD repeat domain containing|PQQ repeat and WD repeat-containing protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=33132098, end_position_on_the_genomic_accession=33175799, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    126259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126259, CurrentID=0, Status='live', Symbol='TMIGD2', Aliases=['CD28H', 'IGPR-1', 'IGPR1'], description='transmembrane and immunoglobulin domain containing 2', other_designations='transmembrane and immunoglobulin domain-containing protein 2|CD28 homolog|CD28 homologue|immunoglobulin and proline-rich receptor 1|immunoglobulin-containing and proline-rich receptor 1|transmembrane and immunoglobulin domain-containing protein 2 variant 2|transmembrane and immunoglobulin domain-containing protein 2 variant 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4292227, end_position_on_the_genomic_accession=4302439, orientation='minus', exon_count=6, OMIM=[614715], no_hdr0=''),
    126272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126272, CurrentID=0, Status='live', Symbol='EID2B', Aliases=['EID-2B', 'EID-3'], description='EP300 interacting inhibitor of differentiation 2B', other_designations='EP300-interacting inhibitor of differentiation 2B|EID-2-like inhibitor of differentiation-3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39530987, end_position_on_the_genomic_accession=39532852, orientation='minus', exon_count=1, OMIM=[617355], no_hdr0=''),
    126282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126282, CurrentID=0, Status='live', Symbol='TNFAIP8L1', Aliases=['TIPE1'], description='TNF alpha induced protein 8 like 1', other_designations='tumor necrosis factor alpha-induced protein 8-like protein 1|TNF alpha-induced protein 8-like protein 1|TNFAIP8-like protein 1|oxidative stress-regulated gene-beta|oxy-beta|tumor necrosis factor, alpha induced protein 8 like 1|tumor necrosis factor, alpha-induced protein 8-like protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4639505, end_position_on_the_genomic_accession=4655568, orientation='plus', exon_count=4, OMIM=[615869], no_hdr0=''),
    126295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126295, CurrentID=0, Status='live', Symbol='ZNF57', Aliases=['ZNF424'], description='zinc finger protein 57', other_designations='zinc finger protein 57|zinc finger protein 424', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2900928, end_position_on_the_genomic_accession=2918646, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    126298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126298, CurrentID=0, Status='live', Symbol='IRGQ', Aliases=['FKSG271', 'IRGQ'], description='immunity related GTPase Q', other_designations='immunity-related GTPase family Q protein|immunity-related GTPase family, Q|immunity-related GTPase family, Q1', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43584367, end_position_on_the_genomic_accession=43596134, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    126299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126299, CurrentID=0, Status='live', Symbol='ZNF428', Aliases=['C19orf37', 'Zfp428'], description='zinc finger protein 428', other_designations='zinc finger protein 428|enzyme-like protein PIT13', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43607224, end_position_on_the_genomic_accession=43619629, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    126306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126306, CurrentID=0, Status='live', Symbol='JSRP1', Aliases=['JP-45', 'JP45'], description='junctional sarcoplasmic reticulum protein 1', other_designations='junctional sarcoplasmic reticulum protein 1|2310032K21Rik|homolog of mouse skeletal muscle sarcoplasmic reticulum protein JP-45|junctional-face membrane protein of 45 kDa homolog|skeletal muscle sarcoplasmic reticulum protein JP-45', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2252252, end_position_on_the_genomic_accession=2260813, orientation='minus', exon_count=8, OMIM=[608743], no_hdr0=''),
    126308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126308, CurrentID=0, Status='live', Symbol='MOB3A', Aliases=['MOB-LAK', 'MOB1C', 'MOBKL2A', 'moblak'], description='MOB kinase activator 3A', other_designations='MOB kinase activator 3A|MOB LAK|MOB1, Mps One Binder kinase activator-like 2A|mob1 homolog 2A|mps one binder kinase activator-like 2A', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2071036, end_position_on_the_genomic_accession=2096664, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    126321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126321, CurrentID=0, Status='live', Symbol='MFSD12', Aliases=['C19orf28', 'PP3501'], description='major facilitator superfamily domain containing 12', other_designations='major facilitator superfamily domain-containing protein 12', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3538270, end_position_on_the_genomic_accession=3557592, orientation='minus', exon_count=12, OMIM=[617745], no_hdr0=''),
    126326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126326, CurrentID=0, Status='live', Symbol='GIPC3', Aliases=['C19orf64', 'DFNB15', 'DFNB72', 'DFNB95'], description='GIPC PDZ domain containing family member 3', other_designations='PDZ domain-containing protein GIPC3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3585478, end_position_on_the_genomic_accession=3593541, orientation='plus', exon_count=6, OMIM=[608792], no_hdr0=''),
    126328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126328, CurrentID=0, Status='live', Symbol='NDUFA11', Aliases=['B14.7', 'CI-B14.7', 'MC1DN14'], description='NADH:ubiquinone oxidoreductase subunit A11', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex subunit 11|NADH dehydrogenase (ubiquinone) 1 alpha subcomplex, 11, 14.7kDa|NADH-ubiquinone oxidoreductase subunit B14.7|complex I B14.7 subunit', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5891229, end_position_on_the_genomic_accession=5903790, orientation='minus', exon_count=6, OMIM=[612638], no_hdr0=''),
    126353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126353, CurrentID=0, Status='live', Symbol='MISP', Aliases=['C19orf211', 'MISP'], description='mitotic spindle positioning', other_designations='mitotic interactor and substrate of PLK1|caprice|mitotic interactor and substrate of Plk1|mitotic spindle positioning protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=748413, end_position_on_the_genomic_accession=764318, orientation='plus', exon_count=7, OMIM=[615289], no_hdr0=''),
    126364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126364, CurrentID=0, Status='live', Symbol='LRRC25', Aliases=['MAPA'], description='leucine rich repeat containing 25', other_designations='leucine-rich repeat-containing protein 25|monocyte and plasmacytoid activated molecule|monocyte and plasmacytoid-activated protein', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18391137, end_position_on_the_genomic_accession=18397645, orientation='minus', exon_count=3, OMIM=[607518], no_hdr0=''),
    126370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126370, CurrentID=0, Status='live', Symbol='OR1I1', Aliases=['OR19-20P', 'OR1I1Q', 'OR1I1'], description='olfactory receptor family 1 subfamily I member 1', other_designations='olfactory receptor 1I1|olfactory receptor 19-20', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15082211, end_position_on_the_genomic_accession=15092970, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    126374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126374, CurrentID=0, Status='live', Symbol='WTIP', Aliases=[], description='WT1 interacting protein', other_designations='Wilms tumor protein 1-interacting protein|Wilms tumor 1 interacting protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34481758, end_position_on_the_genomic_accession=34512304, orientation='plus', exon_count=10, OMIM=[614790], no_hdr0=''),
    126375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126375, CurrentID=0, Status='live', Symbol='ZNF792', Aliases=[], description='zinc finger protein 792', other_designations='zinc finger protein 792', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34956354, end_position_on_the_genomic_accession=34964229, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    126382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126382, CurrentID=0, Status='live', Symbol='NR2C2AP', Aliases=['TRA16'], description='nuclear receptor 2C2 associated protein', other_designations='nuclear receptor 2C2-associated protein|TR4 orphan receptor associated protein TRA16|TR4 orphan receptor-associated 16 kDa protein|repressor for TR4 transactivation', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19201409, end_position_on_the_genomic_accession=19203414, orientation='minus', exon_count=6, OMIM=[608719], no_hdr0=''),
    126393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126393, CurrentID=0, Status='live', Symbol='HSPB6', Aliases=['HEL55', 'Hsp20', 'PPP1R91'], description='heat shock protein family B (small) member 6', other_designations='heat shock protein beta-6|epididymis luminal protein 55|epididymis secretory sperm binding protein|heat shock 20 kDa-like protein p20|heat shock protein family B (small) member B6|heat shock protein, alpha-crystallin-related, B6|protein phosphatase 1, regulatory subunit 91', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35754566, end_position_on_the_genomic_accession=35757029, orientation='minus', exon_count=3, OMIM=[610695], no_hdr0=''),
    126402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126402, CurrentID=0, Status='live', Symbol='CCDC105', Aliases=[], description='coiled-coil domain containing 105', other_designations='coiled-coil domain-containing protein 105', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15010726, end_position_on_the_genomic_accession=15023276, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    126410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126410, CurrentID=0, Status='live', Symbol='CYP4F22', Aliases=['ARCI5', 'INLNE', 'LI3'], description='cytochrome P450 family 4 subfamily F member 22', other_designations='cytochrome P450 4F22|cytochrome P450, family 2, subfamily E, polypeptide 2 homolog|cytochrome P450, family 4, subfamily F, polypeptide 22', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15508487, end_position_on_the_genomic_accession=15552317, orientation='plus', exon_count=16, OMIM=[611495], no_hdr0=''),
    126432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126432, CurrentID=0, Status='live', Symbol='RINL', Aliases=[], description='Ras and Rab interactor like', other_designations='ras and Rab interactor-like protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38867825, end_position_on_the_genomic_accession=38878275, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    126433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126433, CurrentID=0, Status='live', Symbol='FBXO27', Aliases=['FBG5', 'Fbx27'], description='F-box protein 27', other_designations='F-box only protein 27|F-box protein FBG5|F-box/G-domain protein 5|epididymis secretory sperm binding protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39007064, end_position_on_the_genomic_accession=39032555, orientation='minus', exon_count=7, OMIM=[609099], no_hdr0=''),
    126520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126520, CurrentID=0, Status='live', Symbol='PLK5', Aliases=['PLK-5P', 'SgK384ps', 'PLK5'], description='polo like kinase 5 (inactive)', other_designations='inactive serine/threonine-protein kinase PLK5|polo-like kinase 5, pseudogene', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1524077, end_position_on_the_genomic_accession=1536046, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    126526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126526, CurrentID=0, Status='live', Symbol='C19orf47', Aliases=[], description='chromosome 19 open reading frame 47', other_designations='uncharacterized protein C19orf47', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40292743, end_position_on_the_genomic_accession=40348527, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    126541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126541, CurrentID=0, Status='live', Symbol='OR10H4', Aliases=['OR19-28'], description='olfactory receptor family 10 subfamily H member 4', other_designations='olfactory receptor 10H4|olfactory receptor OR19-28', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15949008, end_position_on_the_genomic_accession=15949958, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    126549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126549, CurrentID=0, Status='live', Symbol='ANKLE1', Aliases=['ANKRD41', 'LEM3', 'LEMD6'], description='ankyrin repeat and LEM domain containing 1', other_designations='ankyrin repeat and LEM domain-containing protein 1|LEM domain containing 6|LEM-domain containing 3|ankyrin repeat domain-containing protein 41', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17281901, end_position_on_the_genomic_accession=17287646, orientation='plus', exon_count=9, OMIM=[619348], no_hdr0=''),
    126567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126567, CurrentID=0, Status='live', Symbol='C2CD4C', Aliases=['FAM148C', 'KIAA1957', 'NLF3'], description='C2 calcium dependent domain containing 4C', other_designations='C2 calcium-dependent domain-containing protein 4C|family with sequence similarity 148, member C|nuclear-localized factor 3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=405435, end_position_on_the_genomic_accession=409147, orientation='minus', exon_count=3, OMIM=[610336], no_hdr0=''),
    126626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126626, CurrentID=0, Status='live', Symbol='GABPB2', Aliases=['GABPB-2'], description='GA binding protein transcription factor subunit beta 2', other_designations='GA-binding protein subunit beta-2|GA binding protein transcription factor beta subunit 2|GABP subunit beta-2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151070180, end_position_on_the_genomic_accession=151125542, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    126637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126637, CurrentID=0, Status='live', Symbol='TCHHL1', Aliases=['S100A17', 'THHL1'], description='trichohyalin like 1', other_designations='trichohyalin-like protein 1|S100 calcium-binding protein A17|basalin|intermediate filament-associated protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152084141, end_position_on_the_genomic_accession=152089064, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    126638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126638, CurrentID=0, Status='live', Symbol='RPTN', Aliases=[], description='repetin', other_designations='repetin|intermediate filament-associated protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152153595, end_position_on_the_genomic_accession=152159228, orientation='minus', exon_count=3, OMIM=[613259], no_hdr0=''),
    126661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126661, CurrentID=0, Status='live', Symbol='CCDC163', Aliases=['C1orf231P', 'CCDC163'], description='coiled-coil domain containing 163', other_designations='transmembrane protein CCDC163|coiled-coil domain containing 163, pseudogene|coiled-coil domain-containing protein 163', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45493863, end_position_on_the_genomic_accession=45500111, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    126668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126668, CurrentID=0, Status='live', Symbol='TDRD10', Aliases=[], description='tudor domain containing 10', other_designations='tudor domain-containing protein 10', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154502219, end_position_on_the_genomic_accession=154548147, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    126669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126669, CurrentID=0, Status='live', Symbol='SHE', Aliases=[], description='Src homology 2 domain containing E', other_designations='SH2 domain-containing adapter protein E', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154467195, end_position_on_the_genomic_accession=154502560, orientation='minus', exon_count=8, OMIM=[610482], no_hdr0=''),
    126695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126695, CurrentID=0, Status='live', Symbol='KDF1', Aliases=['C1orf172', 'ECTD12'], description='keratinocyte differentiation factor 1', other_designations='keratinocyte differentiation factor 1|RP11-344H11.3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26949556, end_position_on_the_genomic_accession=26960496, orientation='minus', exon_count=5, OMIM=[616758], no_hdr0=''),
    126731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126731, CurrentID=0, Status='live', Symbol='CCSAP', Aliases=['C1orf96', 'CSAP'], description='centriole, cilia and spindle associated protein', other_designations='centriole, cilia and spindle-associated protein|centriole and spindle-associated protein', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=229321015, end_position_on_the_genomic_accession=229343795, orientation='minus', exon_count=4, OMIM=[616762], no_hdr0=''),
    126755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126755, CurrentID=0, Status='live', Symbol='LRRC38', Aliases=[], description='leucine rich repeat containing 38', other_designations='leucine-rich repeat-containing protein 38|BK channel auxiliary gamma subunit LRRC38|BK channel auxilliary gamma subunit LRRC38', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13474973, end_position_on_the_genomic_accession=13514003, orientation='minus', exon_count=2, OMIM=[615212], no_hdr0=''),
    126767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126767, CurrentID=0, Status='live', Symbol='AADACL3', Aliases=[], description='arylacetamide deacetylase like 3', other_designations='arylacetamide deacetylase-like 3', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12716110, end_position_on_the_genomic_accession=12728760, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    126789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126789, CurrentID=0, Status='live', Symbol='PUSL1', Aliases=[], description='pseudouridine synthase like 1', other_designations='tRNA pseudouridine synthase-like 1|pseudouridylate synthase like 1|tRNA pseudouridylate synthase-like 1|tRNA-uridine isomerase-like 1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1308563, end_position_on_the_genomic_accession=1311677, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    126792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126792, CurrentID=0, Status='live', Symbol='B3GALT6', Aliases=['ALGAZ', 'EDSP2', 'EDSSPD2', 'SEMDJL1', 'beta3GalT6'], description='beta-1,3-galactosyltransferase 6', other_designations='beta-1,3-galactosyltransferase 6|GAG GalTII|UDP-Gal:betaGal beta 1,3-galactosyltransferase 6|UDP-Gal:betaGal beta 1,3-galactosyltransferase polypeptide 6|UDP-Gal:betaGlcNAc beta 1,3-galactosyltransferase, polypeptide 6|beta-1,3-GalTase 6|beta3Gal-T6|galactosyltransferase II|galactosylxylosylprotein 3-beta-galactosyltransferase', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1232237, end_position_on_the_genomic_accession=1235041, orientation='plus', exon_count=1, OMIM=[615291], no_hdr0=''),
    126820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126820, CurrentID=0, Status='live', Symbol='DNAI3', Aliases=['DIC3', 'NYD-SP29', 'WDR63'], description='dynein axonemal intermediate chain 3', other_designations='dynein axonemal intermediate chain 3|WD repeat domain 63|WD repeat-containing protein 63|dynein intermediate chain 3, axonemal|testicular tissue protein Li 225|testis development protein NYD-SP29 (NYD-SP29)', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85062327, end_position_on_the_genomic_accession=85133138, orientation='plus', exon_count=23, OMIM=[617968], no_hdr0=''),
    126823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126823, CurrentID=0, Status='live', Symbol='KLHDC9', Aliases=['KARCA1'], description='kelch domain containing 9', other_designations='kelch domain-containing protein 9|kelch/ankyrin repeat-containing cyclin A1-interacting protein', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161098361, end_position_on_the_genomic_accession=161100346, orientation='plus', exon_count=5, OMIM=[617375], no_hdr0=''),
    126859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126859, CurrentID=0, Status='live', Symbol='AXDND1', Aliases=['C1orf125'], description='axonemal dynein light chain domain containing 1', other_designations='axonemal dynein light chain domain-containing protein 1', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179365704, end_position_on_the_genomic_accession=179554735, orientation='plus', exon_count=34, OMIM=[], no_hdr0=''),
    126868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126868, CurrentID=0, Status='live', Symbol='MAB21L3', Aliases=['C1orf161'], description='mab-21 like 3', other_designations='protein mab-21-like 3', map_location='1p13.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=116111399, end_position_on_the_genomic_accession=116138149, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    126917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126917, CurrentID=0, Status='live', Symbol='IFFO2', Aliases=[], description='intermediate filament family orphan 2', other_designations='intermediate filament family orphan 2', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18904280, end_position_on_the_genomic_accession=18956676, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    126961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126961, CurrentID=0, Status='live', Symbol='H3C14', Aliases=['H3', 'H3.2', 'H3/M', 'H3C13', 'H3C15', 'H3F2', 'H3FM', 'H3FN', 'HIST2H3C'], description='H3 clustered histone 14', other_designations='histone H3.2|H3 histone family, member M|H3 histone, family 2|H3-clustered histone 13|H3-clustered histone 15|histone 2, H3c|histone H3/m|histone cluster 2 H3 family member c|histone cluster 2, H3c', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149840687, end_position_on_the_genomic_accession=149841208, orientation='minus', exon_count=1, OMIM=[142780], no_hdr0=''),
    126969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=126969, CurrentID=0, Status='live', Symbol='SLC44A3', Aliases=['CTL3'], description='solute carrier family 44 member 3', other_designations='choline transporter-like protein 3', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94820351, end_position_on_the_genomic_accession=94895247, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    127002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127002, CurrentID=0, Status='live', Symbol='ATXN7L2', Aliases=[], description='ataxin 7 like 2', other_designations='ataxin-7-like protein 2|ataxin 7-like 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109483905, end_position_on_the_genomic_accession=109492804, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    127003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127003, CurrentID=0, Status='live', Symbol='C1orf194', Aliases=[], description='chromosome 1 open reading frame 194', other_designations='protein C1orf194|uncharacterized protein C1orf194', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109105951, end_position_on_the_genomic_accession=109113831, orientation='minus', exon_count=6, OMIM=[618682], no_hdr0=''),
    127018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127018, CurrentID=0, Status='live', Symbol='LYPLAL1', Aliases=['Q96AV0'], description='lysophospholipase like 1', other_designations='lysophospholipase-like protein 1', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=219173850, end_position_on_the_genomic_accession=219445121, orientation='plus', exon_count=18, OMIM=[616548], no_hdr0=''),
    127059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127059, CurrentID=0, Status='live', Symbol='OR2M5', Aliases=['OR2M5P'], description='olfactory receptor family 2 subfamily M member 5', other_designations='olfactory receptor 2M5|olfactory receptor, family 2, subfamily M, member 5 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248145148, end_position_on_the_genomic_accession=248146086, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    127062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127062, CurrentID=0, Status='live', Symbol='OR2M3', Aliases=['OR1-54P', 'OR2M6', 'OST003', 'OR2M3'], description='olfactory receptor family 2 subfamily M member 3', other_designations='olfactory receptor 2M3|novel 7 transmembrane receptor (rhodopsin family) protein|olfactory receptor 2M6|olfactory receptor OR1-54|olfactory receptor, family 2, subfamily M, member 3 pseudogene|olfactory receptor, family 2, subfamily M, member 6', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248197265, end_position_on_the_genomic_accession=248212925, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    127064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127064, CurrentID=0, Status='live', Symbol='OR2T12', Aliases=['OR1-57'], description='olfactory receptor family 2 subfamily T member 12', other_designations='olfactory receptor 2T12|novel 7 transmembrane receptor (rhodopsin family) protein|olfactory receptor OR1-57', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248290139, end_position_on_the_genomic_accession=248303424, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    127066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127066, CurrentID=0, Status='live', Symbol='OR14C36', Aliases=['OR5BF1'], description='olfactory receptor family 14 subfamily C member 36', other_designations='olfactory receptor 14C36|olfactory receptor 5BF1|olfactory receptor OR1-59|olfactory receptor, family 5, subfamily BF, member 1', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248348775, end_position_on_the_genomic_accession=248349713, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    127068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127068, CurrentID=0, Status='live', Symbol='OR2T34', Aliases=[], description='olfactory receptor family 2 subfamily T member 34', other_designations='olfactory receptor 2T34|olfactory receptor OR1-63', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248573801, end_position_on_the_genomic_accession=248574757, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    127069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127069, CurrentID=0, Status='live', Symbol='OR2T10', Aliases=['OR1-64'], description='olfactory receptor family 2 subfamily T member 10', other_designations='olfactory receptor 2T10|olfactory receptor OR1-64', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248590487, end_position_on_the_genomic_accession=248597700, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    127074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127074, CurrentID=0, Status='live', Symbol='OR2T4', Aliases=['OR1-60Q', 'OR2T4'], description='olfactory receptor family 2 subfamily T member 4', other_designations='olfactory receptor 2T4|olfactory receptor OR1-60', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248361665, end_position_on_the_genomic_accession=248362627, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    127077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127077, CurrentID=0, Status='live', Symbol='OR2T11', Aliases=['OR2T11Q'], description='olfactory receptor family 2 subfamily T member 11', other_designations='olfactory receptor 2T11|olfactory receptor OR1-65', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248623557, end_position_on_the_genomic_accession=248635091, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    127124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127124, CurrentID=0, Status='live', Symbol='ATP6V1G3', Aliases=['ATP6G3', 'Vma10'], description='ATPase H+ transporting V1 subunit G3', other_designations='V-type proton ATPase subunit G 3|ATPase, H+ transporting, lysosomal (vacuolar proton pump) subunit G3|ATPase, H+ transporting, lysosomal 13kDa, V1 subunit G3|V-ATPase 13 kDa subunit 3|V-ATPase G subunit 3|V-ATPase G3 subunit|V-ATPase subunit G 3|vacuolar ATP synthase subunit G 3|vacuolar proton pump G subunit 3|vacuolar proton pump subunit G 3|vacuolar proton pump, subunit G3', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=198523222, end_position_on_the_genomic_accession=198540945, orientation='minus', exon_count=5, OMIM=[618071], no_hdr0=''),
    127247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127247, CurrentID=0, Status='live', Symbol='ASB17', Aliases=['Asb-17'], description='ankyrin repeat and SOCS box containing 17', other_designations='ankyrin repeat and SOCS box protein 17', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75918873, end_position_on_the_genomic_accession=75937625, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    127253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127253, CurrentID=0, Status='live', Symbol='TYW3', Aliases=['C1orf171'], description='tRNA-yW synthesizing protein 3 homolog', other_designations='tRNA wybutosine-synthesizing protein 3 homolog|tRNA(Phe) 7-((3-amino-3-carboxypropyl)-4-demethylwyosine(37)-N(4))-methyltransferase|tRNA-yW-synthesizing protein 3', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74733152, end_position_on_the_genomic_accession=74766677, orientation='plus', exon_count=6, OMIM=[611245], no_hdr0=''),
    127254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127254, CurrentID=0, Status='live', Symbol='ERICH3', Aliases=['C1orf173'], description='glutamate rich 3', other_designations='glutamate-rich protein 3|RP11-653A5.1', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74568113, end_position_on_the_genomic_accession=74674343, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    127255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127255, CurrentID=0, Status='live', Symbol='LRRIQ3', Aliases=['LRRC44'], description='leucine rich repeats and IQ motif containing 3', other_designations='leucine-rich repeat and IQ domain-containing protein 3|leucine rich repeat containing 44|leucine-rich repeat-containing protein 44', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74026015, end_position_on_the_genomic_accession=74198201, orientation='minus', exon_count=12, OMIM=[617957], no_hdr0=''),
    127262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127262, CurrentID=0, Status='live', Symbol='TPRG1L', Aliases=['FAM79A', 'h-mover', 'mover'], description='tumor protein p63 regulated 1 like', other_designations='tumor protein p63-regulated gene 1-like protein|RP11-46F15.3|family with sequence similarity 79, member A|mossy fiber terminal-associated vertebrate-specific presynaptic protein', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3625015, end_position_on_the_genomic_accession=3630127, orientation='plus', exon_count=5, OMIM=[611460], no_hdr0=''),
    127281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127281, CurrentID=0, Status='live', Symbol='PRXL2B', Aliases=['C1orf93', 'FAM213B'], description='peroxiredoxin like 2B', other_designations='prostamide/prostaglandin F synthase|family with sequence similarity 213 member B|prostamide/PG F synthase|prostamide/PGF synthase|thioredoxin-type PGF synthase', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2586523, end_position_on_the_genomic_accession=2591469, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    127294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127294, CurrentID=0, Status='live', Symbol='MYOM3', Aliases=[], description='myomesin 3', other_designations='myomesin-3|myomesin family, member 3', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24056041, end_position_on_the_genomic_accession=24112135, orientation='minus', exon_count=37, OMIM=[616832], no_hdr0=''),
    127343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127343, CurrentID=0, Status='live', Symbol='DMBX1', Aliases=['MBX', 'OTX3', 'PAXB'], description='diencephalon/mesencephalon homeobox 1', other_designations='diencephalon/mesencephalon homeobox protein 1|homeoprotein MBX|orthodenticle homolog 3|paired-like homeobox protein DMBX1', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46489836, end_position_on_the_genomic_accession=46516216, orientation='plus', exon_count=6, OMIM=[607410], no_hdr0=''),
    127385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127385, CurrentID=0, Status='live', Symbol='OR10J5', Aliases=['OR1-28'], description='olfactory receptor family 10 subfamily J member 5', other_designations='olfactory receptor 10J5|olfactory receptor OR1-28', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159535078, end_position_on_the_genomic_accession=159536007, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    127391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127391, CurrentID=0, Status='live', Symbol='TMCO2', Aliases=['dJ39G22.2'], description='transmembrane and coiled-coil domains 2', other_designations='transmembrane and coiled-coil domain-containing protein 2|testis tissue sperm-binding protein Li 35a', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40247937, end_position_on_the_genomic_accession=40251684, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    127396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127396, CurrentID=0, Status='live', Symbol='ZNF684', Aliases=[], description='zinc finger protein 684', other_designations='zinc finger protein 684|hypothetical protein MGC27466', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40531637, end_position_on_the_genomic_accession=40548167, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    127428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127428, CurrentID=0, Status='live', Symbol='TCEANC2', Aliases=['C1orf83'], description='transcription elongation factor A N-terminal and central domain containing 2', other_designations='transcription elongation factor A N-terminal and central domain-containing protein 2|transcription elongation factor A (SII) N-terminal and central domain containing 2', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54053608, end_position_on_the_genomic_accession=54112520, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    127435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127435, CurrentID=0, Status='live', Symbol='PODN', Aliases=['PCAN', 'SLRR5A'], description='podocan', other_designations='podocan|podocan proteoglycan', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53062198, end_position_on_the_genomic_accession=53085502, orientation='plus', exon_count=13, OMIM=[608661], no_hdr0=''),
    127495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127495, CurrentID=0, Status='live', Symbol='LRRC39', Aliases=[], description='leucine rich repeat containing 39', other_designations='leucine-rich repeat-containing protein 39|densin hlg|myomasp|myosin-interacting M-band-associated stress-responsive protein', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100148448, end_position_on_the_genomic_accession=100178256, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    127534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127534, CurrentID=0, Status='live', Symbol='GJB4', Aliases=['CX30.3', 'EKV', 'EKVP2'], description='gap junction protein beta 4', other_designations='gap junction beta-4 protein|connexin 30.3|gap junction protein, beta 4, 30.3kDa', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34759740, end_position_on_the_genomic_accession=34762327, orientation='plus', exon_count=3, OMIM=[605425], no_hdr0=''),
    127540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127540, CurrentID=0, Status='live', Symbol='HMGB4', Aliases=['dJ1007G16.5'], description='high mobility group box 4', other_designations='high mobility group protein B4|HMG2 like', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33860475, end_position_on_the_genomic_accession=33864791, orientation='plus', exon_count=2, OMIM=[617285], no_hdr0=''),
    127544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127544, CurrentID=0, Status='live', Symbol='RNF19B', Aliases=['IBRDC3', 'NKLAM'], description='ring finger protein 19B', other_designations='E3 ubiquitin-protein ligase RNF19B|IBR domain-containing protein 3|natural killer lytic-associated molecule', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32932498, end_position_on_the_genomic_accession=32965266, orientation='minus', exon_count=10, OMIM=[610872], no_hdr0=''),
    127550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127550, CurrentID=0, Status='live', Symbol='A3GALT2', Aliases=['A3GALT2P', 'IGB3S', 'IGBS3S'], description='alpha 1,3-galactosyltransferase 2', other_designations='alpha-1,3-galactosyltransferase 2|alpha 1,3-galactosyltransferase 2, pseudogene|iGb3 synthase|isoglobotriaosylceramide synthase', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33306766, end_position_on_the_genomic_accession=33321098, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    127579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127579, CurrentID=0, Status='live', Symbol='DCST2', Aliases=[], description='DC-STAMP domain containing 2', other_designations='DC-STAMP domain-containing protein 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155018513, end_position_on_the_genomic_accession=155033781, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    127602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127602, CurrentID=0, Status='live', Symbol='DNAH14', Aliases=['C1orf67', 'Dnahc14', 'HL-18', 'HL18'], description='dynein axonemal heavy chain 14', other_designations='dynein axonemal heavy chain 14|dynein heavy chain 14, axonemal|axonemal beta dynein heavy chain 14|ciliary dynein heavy chain 14|dynein, axonemal, heavy polypeptide 14', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224928422, end_position_on_the_genomic_accession=225399292, orientation='plus', exon_count=90, OMIM=[603341], no_hdr0=''),
    127608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127608, CurrentID=0, Status='live', Symbol='OR2AJ1', Aliases=['OR2AJ1PQ', 'OR2AJ1'], description='olfactory receptor family 2 subfamily AJ member 1', other_designations='olfactory receptor 2AJ1|olfactory receptor OR1-52|olfactory receptor, family 2, subfamily AJ, member 1 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247924889, end_position_on_the_genomic_accession=247935339, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    127623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127623, CurrentID=0, Status='live', Symbol='OR2B11', Aliases=[], description='olfactory receptor family 2 subfamily B member 11', other_designations='olfactory receptor 2B11|novel 7 transmembrane receptor (rhodopsin family) protein', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247449118, end_position_on_the_genomic_accession=247458104, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    127665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127665, CurrentID=0, Status='live', Symbol='ZNF648', Aliases=[], description='zinc finger protein 648', other_designations='zinc finger protein 648', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182053740, end_position_on_the_genomic_accession=182081725, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    127670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127670, CurrentID=0, Status='live', Symbol='TEDDM1', Aliases=['EDDM9', 'Epdd1', 'HE9', 'HEL-S-45e', 'TMEM45C'], description='transmembrane epididymal protein 1', other_designations='transmembrane epididymal protein 1|epididymal protein 9|epididymis secretory sperm binding protein Li 45e|human epididymis-specific protein 9|putative membrane protein HE9|transmembrane protein 45C', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182398117, end_position_on_the_genomic_accession=182400667, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    127687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127687, CurrentID=0, Status='live', Symbol='C1orf122', Aliases=['ALAESM'], description='chromosome 1 open reading frame 122', other_designations='uncharacterized protein C1orf122', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37807790, end_position_on_the_genomic_accession=37809454, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    127700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127700, CurrentID=0, Status='live', Symbol='OSCP1', Aliases=['C1orf102', 'NOR1'], description='organic solute carrier partner 1', other_designations='protein OSCP1|organic solute carrier protein 1|organic solute transport protein 1|oxidored nitro domain containing protein|oxidored-nitro domain-containing protein 1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=36417906, end_position_on_the_genomic_accession=36450485, orientation='minus', exon_count=13, OMIM=[608854], no_hdr0=''),
    127703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127703, CurrentID=0, Status='live', Symbol='C1orf216', Aliases=[], description='chromosome 1 open reading frame 216', other_designations='UPF0500 protein C1orf216', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35713877, end_position_on_the_genomic_accession=35718884, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    127707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127707, CurrentID=0, Status='live', Symbol='KLHDC7A', Aliases=[], description='kelch domain containing 7A', other_designations='kelch domain-containing protein 7A', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=18480930, end_position_on_the_genomic_accession=18485974, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    127731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127731, CurrentID=0, Status='live', Symbol='VWA5B1', Aliases=[], description='von Willebrand factor A domain containing 5B1', other_designations='von Willebrand factor A domain-containing protein 5B1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20290875, end_position_on_the_genomic_accession=20360442, orientation='plus', exon_count=31, OMIM=[], no_hdr0=''),
    127733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127733, CurrentID=0, Status='live', Symbol='UBXN10', Aliases=['UBXD3'], description='UBX domain protein 10', other_designations='UBX domain-containing protein 10|UBX domain containing 3|UBX domain-containing protein 3', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20183007, end_position_on_the_genomic_accession=20196050, orientation='plus', exon_count=4, OMIM=[616783], no_hdr0=''),
    127795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127795, CurrentID=0, Status='live', Symbol='C1orf87', Aliases=['CREF'], description='chromosome 1 open reading frame 87', other_designations='uncharacterized protein C1orf87|carcinoma-related EF-hand protein', map_location='1p32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=59990394, end_position_on_the_genomic_accession=60073770, orientation='minus', exon_count=14, OMIM=[618860], no_hdr0=''),
    127829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127829, CurrentID=0, Status='live', Symbol='ARL8A', Aliases=['ARL10B', 'GIE2'], description='ADP ribosylation factor like GTPase 8A', other_designations='ADP-ribosylation factor-like protein 8A|ADP-ribosylation factor-like 10B|ADP-ribosylation factor-like 8A|novel small G protein indispensable for equal chromosome segregation 2', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202133404, end_position_on_the_genomic_accession=202144737, orientation='minus', exon_count=7, OMIM=[616597], no_hdr0=''),
    127833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127833, CurrentID=0, Status='live', Symbol='SYT2', Aliases=['CMS7', 'MYSPC', 'SytII'], description='synaptotagmin 2', other_designations='synaptotagmin-2|synaptotagmin II', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=202590596, end_position_on_the_genomic_accession=202710454, orientation='minus', exon_count=11, OMIM=[600104], no_hdr0=''),
    127845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127845, CurrentID=0, Status='live', Symbol='GOLT1A', Aliases=['CGI-141', 'GOT1', 'HMFN1187', 'YMR292W', 'hGOT1b'], description='golgi transport 1A', other_designations='vesicle transport protein GOT1A', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=204198158, end_position_on_the_genomic_accession=204214092, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    127933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127933, CurrentID=0, Status='live', Symbol='UHMK1', Aliases=['KIS', 'KIST', 'P-CIP2'], description='U2AF homology motif kinase 1', other_designations='serine/threonine-protein kinase Kist|KIS protein kinase|PAM COOH-terminal interactor protein 2|U2AF homology motif (UHM) kinase 1|kinase interacting with leukemia-associated gene (stathmin)', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162497174, end_position_on_the_genomic_accession=162529631, orientation='plus', exon_count=9, OMIM=[608849], no_hdr0=''),
    127943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=127943, CurrentID=0, Status='live', Symbol='FCRLB', Aliases=['FCRL2', 'FCRLM2', 'FCRLY', 'FREB-2', 'FREB2', 'FcRY'], description='Fc receptor like B', other_designations='Fc receptor-like B|fc receptor homolog expressed in B cells protein 2|fc receptor-like and mucin-like protein 2|fc receptor-like protein 2|fc receptor-related protein Y', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161721544, end_position_on_the_genomic_accession=161728143, orientation='plus', exon_count=9, OMIM=[609251], no_hdr0=''),
    128025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128025, CurrentID=0, Status='live', Symbol='WDR64', Aliases=[], description='WD repeat domain 64', other_designations='WD repeat-containing protein 64', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241652278, end_position_on_the_genomic_accession=241802777, orientation='plus', exon_count=32, OMIM=[], no_hdr0=''),
    128061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128061, CurrentID=0, Status='live', Symbol='C1orf131', Aliases=[], description='chromosome 1 open reading frame 131', other_designations='uncharacterized protein C1orf131', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231223765, end_position_on_the_genomic_accession=231241175, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    128077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128077, CurrentID=0, Status='live', Symbol='LIX1L', Aliases=[], description='limb and CNS expressed 1 like', other_designations='LIX1-like protein|Lix1 homolog-like', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145933423, end_position_on_the_genomic_accession=145958038, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    128153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128153, CurrentID=0, Status='live', Symbol='SPATA17', Aliases=['CFAP305', 'FAP305', 'IQCH', 'MOT17', 'MSRG-11', 'MSRG11'], description='spermatogenesis associated 17', other_designations='spermatogenesis-associated protein 17|IQ motif containing H|spermatogenesis-related protein 11', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=217631333, end_position_on_the_genomic_accession=217871696, orientation='plus', exon_count=12, OMIM=[611032], no_hdr0=''),
    128178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128178, CurrentID=0, Status='live', Symbol='EDARADD', Aliases=['ECTD11A', 'ECTD11B', 'ED3', 'EDA3'], description='EDAR associated death domain', other_designations='ectodysplasin-A receptor-associated adapter protein|EDAR-associated death domain protein|crinkled homolog|ectodysplasia A receptor associated death domain', map_location='1q42.3-q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=236394286, end_position_on_the_genomic_accession=236484930, orientation='plus', exon_count=7, OMIM=[606603], no_hdr0=''),
    128209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128209, CurrentID=0, Status='live', Symbol='KLF17', Aliases=['ZLF393', 'ZNF393', 'Zfp393'], description='Kruppel like factor 17', other_designations='Krueppel-like factor 17|novel zinc-finger protein|zinc finger protein 393', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44043927, end_position_on_the_genomic_accession=44135140, orientation='plus', exon_count=9, OMIM=[609602], no_hdr0=''),
    128218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128218, CurrentID=0, Status='live', Symbol='TMEM125', Aliases=[], description='transmembrane protein 125', other_designations='transmembrane protein 125', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43269865, end_position_on_the_genomic_accession=43274002, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    128229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128229, CurrentID=0, Status='live', Symbol='TSACC', Aliases=['C1orf182', 'SIP', 'SSTK-IP'], description='TSSK6 activating cochaperone', other_designations='TSSK6-activating co-chaperone protein|SSTK-interacting protein (SSTK-IP)|TSSK6 activating co-chaperone', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156337314, end_position_on_the_genomic_accession=156346995, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    128239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128239, CurrentID=0, Status='live', Symbol='IQGAP3', Aliases=[], description='IQ motif containing GTPase activating protein 3', other_designations='ras GTPase-activating-like protein IQGAP3', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156525405, end_position_on_the_genomic_accession=156572605, orientation='minus', exon_count=41, OMIM=[], no_hdr0=''),
    128240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128240, CurrentID=0, Status='live', Symbol='NAXE', Aliases=['AIBP', 'APOA1BP', 'PEBEL', 'YJEFN1'], description='NAD(P)HX epimerase', other_designations='NAD(P)H-hydrate epimerase|AI-BP|apoA-I binding protein|apolipoprotein A-I-binding protein|yjeF N-terminal domain-containing protein 1|yjeF_N1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156591776, end_position_on_the_genomic_accession=156599818, orientation='plus', exon_count=7, OMIM=[608862], no_hdr0=''),
    128272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128272, CurrentID=0, Status='live', Symbol='ARHGEF19', Aliases=['WGEF'], description='Rho guanine nucleotide exchange factor 19', other_designations='rho guanine nucleotide exchange factor 19|Rho guanine nucleotide exchange factor (GEF) 19|ephexin-2|ephexin2|weakly similar to Rho GEF', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16197854, end_position_on_the_genomic_accession=16212700, orientation='minus', exon_count=17, OMIM=[612496], no_hdr0=''),
    128308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128308, CurrentID=0, Status='live', Symbol='MRPL55', Aliases=['AAVG5835', 'L55nt', 'MRP-L55', 'PRO19675'], description='mitochondrial ribosomal protein L55', other_designations='39S ribosomal protein L55, mitochondrial|L55mt|mitochondrial large ribosomal subunit protein bL31m|mitochondrial large ribosomal subunit protein mL55', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228106680, end_position_on_the_genomic_accession=228111746, orientation='minus', exon_count=7, OMIM=[611859], no_hdr0=''),
    128312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128312, CurrentID=0, Status='live', Symbol='H2BU1', Aliases=['H2Bb', 'HIST3H2BB'], description='H2B.U histone 1', other_designations='histone H2B type 3-B|H2B type 12|histone 3, H2bb|histone cluster 3 H2B family member b|histone cluster 3, H2bb', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228458103, end_position_on_the_genomic_accession=228458558, orientation='plus', exon_count=1, OMIM=[615046], no_hdr0=''),
    128338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128338, CurrentID=0, Status='live', Symbol='DRAM2', Aliases=['CORD21', 'PRO180', 'TMEM77', 'WWFQ154'], description='DNA damage regulated autophagy modulator 2', other_designations='DNA damage-regulated autophagy modulator protein 2|damage regulated autophagy modulator 2|transmembrane protein 77', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111117163, end_position_on_the_genomic_accession=111140216, orientation='minus', exon_count=11, OMIM=[613360], no_hdr0=''),
    128344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128344, CurrentID=0, Status='live', Symbol='PIFO', Aliases=['C1orf88', 'pitchfork'], description='primary cilia formation', other_designations='protein pitchfork', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111324663, end_position_on_the_genomic_accession=111353017, orientation='plus', exon_count=7, OMIM=[614234], no_hdr0=''),
    128346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128346, CurrentID=0, Status='live', Symbol='C1orf162', Aliases=[], description='chromosome 1 open reading frame 162', other_designations='transmembrane protein C1orf162', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=111462027, end_position_on_the_genomic_accession=111478512, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    128360 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128360, CurrentID=0, Status='live', Symbol='OR10T2', Aliases=['OR1-3'], description='olfactory receptor family 10 subfamily T member 2', other_designations='olfactory receptor 10T2|olfactory receptor OR1-3', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158398522, end_position_on_the_genomic_accession=158399466, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    128366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128366, CurrentID=0, Status='live', Symbol='OR6P1', Aliases=[], description='olfactory receptor family 6 subfamily P member 1', other_designations='olfactory receptor 6P1|olfactory receptor OR1-12|seven transmembrane helix receptor', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158560606, end_position_on_the_genomic_accession=158570580, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    128367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128367, CurrentID=0, Status='live', Symbol='OR10X1', Aliases=['OR1-13', 'OR1-14P', 'OR10X1'], description='olfactory receptor family 10 subfamily X member 1', other_designations='olfactory receptor 10X1|olfactory receptor OR1-13 pseudogene|olfactory receptor OR1-14|olfactory receptor, family 10, subfamily X, member 1 pseudogene', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158578919, end_position_on_the_genomic_accession=158579899, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    128368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128368, CurrentID=0, Status='live', Symbol='OR10Z1', Aliases=['OR1-15'], description='olfactory receptor family 10 subfamily Z member 1', other_designations='olfactory receptor 10Z1|olfactory receptor OR1-15', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158605268, end_position_on_the_genomic_accession=158612514, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    128371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128371, CurrentID=0, Status='live', Symbol='OR6K6', Aliases=['OR1-21'], description='olfactory receptor family 6 subfamily K member 6', other_designations='olfactory receptor 6K6|olfactory receptor OR1-21', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158754816, end_position_on_the_genomic_accession=158755847, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    128372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128372, CurrentID=0, Status='live', Symbol='OR6N1', Aliases=['OR1-22'], description='olfactory receptor family 6 subfamily N member 1', other_designations='olfactory receptor 6N1|olfactory receptor OR1-22', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158764214, end_position_on_the_genomic_accession=158840979, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    128387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128387, CurrentID=0, Status='live', Symbol='TATDN3', Aliases=[], description='TatD DNase domain containing 3', other_designations='putative deoxyribonuclease TATDN3', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212791833, end_position_on_the_genomic_accession=212816830, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    128408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128408, CurrentID=0, Status='live', Symbol='BHLHE23', Aliases=['BETA4', 'BHLHB4', 'Beta3b', 'bA305P22.3'], description='basic helix-loop-helix family member e23', other_designations='class E basic helix-loop-helix protein 23|basic helix-loop-helix domain containing, class B, 4|class B basic helix-loop-helix protein 4', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63005927, end_position_on_the_genomic_accession=63006964, orientation='minus', exon_count=1, OMIM=[609331], no_hdr0=''),
    128414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128414, CurrentID=0, Status='live', Symbol='NKAIN4', Aliases=['C20orf58', 'FAM77A', 'bA261N11.2'], description='sodium/potassium transporting ATPase interacting 4', other_designations='sodium/potassium-transporting ATPase subunit beta-1-interacting protein 4|Na(+)/K(+)-transporting ATPase subunit beta-1-interacting protein 4|Na+/K+ transporting ATPase interacting 4', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63240780, end_position_on_the_genomic_accession=63256406, orientation='minus', exon_count=10, OMIM=[612873], no_hdr0=''),
    128434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128434, CurrentID=0, Status='live', Symbol='VSTM2L', Aliases=['C20orf102', 'dJ1118M15.2'], description='V-set and transmembrane domain containing 2 like', other_designations='V-set and transmembrane domain-containing protein 2-like protein', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37903104, end_position_on_the_genomic_accession=37945350, orientation='plus', exon_count=4, OMIM=[616537], no_hdr0=''),
    128486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128486, CurrentID=0, Status='live', Symbol='FITM2', Aliases=['C20orf142', 'Fit2', 'SIDDIS', 'dJ881L22.2'], description='fat storage inducing transmembrane protein 2', other_designations='acyl-coenzyme A diphosphatase FITM2|fat-inducing protein 2|fat-inducing transcript 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44302840, end_position_on_the_genomic_accession=44311202, orientation='minus', exon_count=2, OMIM=[612029], no_hdr0=''),
    128488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128488, CurrentID=0, Status='live', Symbol='WFDC12', Aliases=['C20orf122', 'SWAM2', 'WAP2', 'dJ211D12.4'], description='WAP four-disulfide core domain 12', other_designations='WAP four-disulfide core domain protein 12|protease inhibitor WAP2|putative protease inhibitor WAP12|single WAP motif protein 2|whey acidic protein 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45123425, end_position_on_the_genomic_accession=45124465, orientation='minus', exon_count=3, OMIM=[609872], no_hdr0=''),
    128497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128497, CurrentID=0, Status='live', Symbol='SPATA25', Aliases=['C20orf165', 'TSG23', 'dJ337O18.8'], description='spermatogenesis associated 25', other_designations='spermatogenesis-associated protein 25|testis-specific gene 23 protein', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45886491, end_position_on_the_genomic_accession=45890815, orientation='minus', exon_count=3, OMIM=[618936], no_hdr0=''),
    128506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128506, CurrentID=0, Status='live', Symbol='OCSTAMP', Aliases=['C20orf123', 'OC-STAMP', 'dJ257E24.3'], description='osteoclast stimulatory transmembrane protein', other_designations='osteoclast stimulatory transmembrane protein|transmembrane protein C20orf123', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=46540946, end_position_on_the_genomic_accession=46550654, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    128553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128553, CurrentID=0, Status='live', Symbol='TSHZ2', Aliases=['C20orf17', 'OVC10-2', 'TSH2', 'ZABC2', 'ZNF218'], description='teashirt zinc finger homeobox 2', other_designations='teashirt homolog 2|cell growth-inhibiting protein 7|ovarian cancer-related protein 10-2|serologically defined colon cancer antigen 33 like|teashirt family zinc finger 2|zinc finger protein 218', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=52972309, end_position_on_the_genomic_accession=53495330, orientation='plus', exon_count=5, OMIM=[614118], no_hdr0=''),
    128602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128602, CurrentID=0, Status='live', Symbol='C20orf85', Aliases=['LLC1', 'bA196N14.1'], description='chromosome 20 open reading frame 85', other_designations='uncharacterized protein C20orf85|low in lung cancer 1', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58150902, end_position_on_the_genomic_accession=58161150, orientation='plus', exon_count=4, OMIM=[619277], no_hdr0=''),
    128611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128611, CurrentID=0, Status='live', Symbol='ZNF831', Aliases=['C20orf174'], description='zinc finger protein 831', other_designations='zinc finger protein 831', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=59123388, end_position_on_the_genomic_accession=59259113, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    128637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128637, CurrentID=0, Status='live', Symbol='TBC1D20', Aliases=['C20orf140', 'WARBM4'], description='TBC1 domain family member 20', other_designations='TBC1 domain family member 20', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=435480, end_position_on_the_genomic_accession=462543, orientation='minus', exon_count=10, OMIM=[611663], no_hdr0=''),
    128646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128646, CurrentID=0, Status='live', Symbol='SIRPD', Aliases=['PTPNS1L2', 'dJ576H24.4'], description='signal regulatory protein delta', other_designations='signal-regulatory protein delta|SIRP-delta|protein tyrosine phosphatase, non-receptor type substrate 1-like 2', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1534251, end_position_on_the_genomic_accession=1557705, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    128653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128653, CurrentID=0, Status='live', Symbol='C20orf141', Aliases=['dJ860F19.4'], description='chromosome 20 open reading frame 141', other_designations='uncharacterized protein C20orf141', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2814987, end_position_on_the_genomic_accession=2815830, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    128674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128674, CurrentID=0, Status='live', Symbol='PROKR2', Aliases=['GPR73L1', 'GPR73b', 'GPRg2', 'HH3', 'KAL3', 'PKR2', 'dJ680N4.3'], description='prokineticin receptor 2', other_designations='prokineticin receptor 2|G protein-coupled receptor 73-like 1|G-protein coupled receptor I5E|PK-R2', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5298852, end_position_on_the_genomic_accession=5316954, orientation='minus', exon_count=4, OMIM=[607123], no_hdr0=''),
    128710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128710, CurrentID=0, Status='live', Symbol='SLX4IP', Aliases=['C20orf94', 'bA204H22.1', 'bA254M13.1', 'dJ1099D15.3'], description='SLX4 interacting protein', other_designations='protein SLX4IP', map_location='20p12.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=10435136, end_position_on_the_genomic_accession=10628138, orientation='plus', exon_count=14, OMIM=[615958], no_hdr0=''),
    128817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128817, CurrentID=0, Status='live', Symbol='CSTL1', Aliases=['CTES1', 'RCET11', 'dJ322G13.4'], description='cystatin like 1', other_designations='cystatin-like 1', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23439670, end_position_on_the_genomic_accession=23461209, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    128821 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128821, CurrentID=0, Status='live', Symbol='CST9L', Aliases=['CTES7B', 'bA218C14.1'], description='cystatin 9 like', other_designations='cystatin-9-like|testatin|testicular tissue protein Li 45', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23564732, end_position_on_the_genomic_accession=23568484, orientation='minus', exon_count=3, OMIM=[616536], no_hdr0=''),
    128822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128822, CurrentID=0, Status='live', Symbol='CST9', Aliases=['CLM', 'CTES7A'], description='cystatin 9', other_designations='cystatin-9|cystatin-like molecule|testatin', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23602410, end_position_on_the_genomic_accession=23605917, orientation='minus', exon_count=2, OMIM=[616543], no_hdr0=''),
    128853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128853, CurrentID=0, Status='live', Symbol='DUSP15', Aliases=['C20orf57', 'VHY'], description='dual specificity phosphatase 15', other_designations='dual specificity protein phosphatase 15|VH1-related member Y|dual specificity phosphatase-like 15|vaccinia virus VH1-related dual-specific protein phosphatase Y', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31845578, end_position_on_the_genomic_accession=31870664, orientation='minus', exon_count=17, OMIM=[616776], no_hdr0=''),
    128859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128859, CurrentID=0, Status='live', Symbol='BPIFB6', Aliases=['BPIL3', 'LPLUNC6'], description='BPI fold containing family B member 6', other_designations='BPI fold-containing family B member 6|bactericidal/permeability-increasing protein-like 3', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33031648, end_position_on_the_genomic_accession=33044108, orientation='plus', exon_count=15, OMIM=[614110], no_hdr0=''),
    128861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128861, CurrentID=0, Status='live', Symbol='BPIFA3', Aliases=['C20orf71', 'SPLUNC3'], description='BPI fold containing family A member 3', other_designations='BPI fold-containing family A member 3|short long palate, lung and nasal epithelium carcinoma associated 3', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33217310, end_position_on_the_genomic_accession=33227806, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    128864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128864, CurrentID=0, Status='live', Symbol='C20orf144', Aliases=['dJ63M2.6'], description='chromosome 20 open reading frame 144', other_designations='uncharacterized protein C20orf144|bcl-2-like protein from testis|bclt', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33662327, end_position_on_the_genomic_accession=33663908, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    128866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128866, CurrentID=0, Status='live', Symbol='CHMP4B', Aliases=['C20orf178', 'CHMP4A', 'CTPP3', 'CTRCT31', 'SNF7', 'SNF7-2', 'Shax1', 'VPS32B', 'Vps32-2', 'dJ553F4.4'], description='charged multivesicular body protein 4B', other_designations='charged multivesicular body protein 4b|SNF7 homolog associated with Alix 1|Snf7 homologue associated with Alix 1|chromatin modifying protein 4B|chromatin-modifying protein 4b|hSnf7-2|hVps32-2|vacuolar protein-sorting-associated protein 32-2', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33811348, end_position_on_the_genomic_accession=33854366, orientation='plus', exon_count=5, OMIM=[610897], no_hdr0=''),
    128869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128869, CurrentID=0, Status='live', Symbol='PIGU', Aliases=['CDC91L1', 'GAB1', 'GPIBD21', 'NEDBSS'], description='phosphatidylinositol glycan anchor biosynthesis class U', other_designations='phosphatidylinositol glycan anchor biosynthesis class U protein|CDC91 (cell division cycle 91, S. cerevisiae, homolog)-like 1|GPI transamidase component PIG-U|GPI transamidase subunit|cell division cycle 91-like 1 protein|cell division cycle protein 91-like 1|protein CDC91-like 1', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=34560542, end_position_on_the_genomic_accession=34677103, orientation='minus', exon_count=15, OMIM=[608528], no_hdr0=''),
    128876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128876, CurrentID=0, Status='live', Symbol='FAM83C', Aliases=['C20orf128', 'dJ614O4.7'], description='family with sequence similarity 83 member C', other_designations='protein FAM83C', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35285731, end_position_on_the_genomic_accession=35292425, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    128954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128954, CurrentID=0, Status='live', Symbol='GAB4', Aliases=[], description='GRB2 associated binding protein family member 4', other_designations='GRB2-associated-binding protein 4|GRB2-associated binder 2-like protein|GRB2-associated binder 4|growth factor receptor bound protein 2-associated protein 4', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=16961936, end_position_on_the_genomic_accession=17008281, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    128977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128977, CurrentID=0, Status='live', Symbol='C22orf39', Aliases=[], description='chromosome 22 open reading frame 39', other_designations='UPF0545 protein C22orf39', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=19440886, end_position_on_the_genomic_accession=19447711, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    128989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=128989, CurrentID=0, Status='live', Symbol='TANGO2', Aliases=['C22orf25', 'MECRCN'], description='transport and golgi organization 2 homolog', other_designations='transport and Golgi organization protein 2 homolog', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20017000, end_position_on_the_genomic_accession=20067164, orientation='plus', exon_count=12, OMIM=[616830], no_hdr0=''),
    129025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129025, CurrentID=0, Status='live', Symbol='ZNF280A', Aliases=["3'OY11.1", 'SUHW1', 'ZNF280', 'ZNF636'], description='zinc finger protein 280A', other_designations='zinc finger protein 280A|suppressor of hairy wing homolog 1|zinc finger protein 280|zinc finger protein 636', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22513736, end_position_on_the_genomic_accession=22520270, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    129049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129049, CurrentID=0, Status='live', Symbol='SGSM1', Aliases=['RUTBC2'], description='small G protein signaling modulator 1', other_designations='small G protein signaling modulator 1|RUN and TBC1 domain containing 2|RUN and TBC1 domain-containing protein 2|small G protein signaling modulator 1 protein', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24806211, end_position_on_the_genomic_accession=24927578, orientation='plus', exon_count=26, OMIM=[611417], no_hdr0=''),
    129080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129080, CurrentID=0, Status='live', Symbol='EMID1', Aliases=['EMI5', 'EMU1'], description='EMI domain containing 1', other_designations='EMI domain-containing protein 1|emilin and multimerin domain-containing protein 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29205896, end_position_on_the_genomic_accession=29259597, orientation='plus', exon_count=23, OMIM=[608926], no_hdr0=''),
    129138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129138, CurrentID=0, Status='live', Symbol='ANKRD54', Aliases=['LIAR'], description='ankyrin repeat domain 54', other_designations='ankyrin repeat domain-containing protein 54|lyn-interacting ankyrin repeat protein', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37830853, end_position_on_the_genomic_accession=37849341, orientation='minus', exon_count=9, OMIM=[613383], no_hdr0=''),
    129285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129285, CurrentID=0, Status='live', Symbol='PPP1R21', Aliases=['CCDC128', 'KLRAQ1', 'NEDHFBA'], description='protein phosphatase 1 regulatory subunit 21', other_designations='protein phosphatase 1 regulatory subunit 21|KLRAQ motif containing 1|KLRAQ motif-containing protein 1|coiled-coil domain containing 128|coiled-coil domain-containing protein 128', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48440766, end_position_on_the_genomic_accession=48515386, orientation='plus', exon_count=24, OMIM=[618159], no_hdr0=''),
    129293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129293, CurrentID=0, Status='live', Symbol='TRABD2A', Aliases=['C2orf89', 'TIKI1'], description='TraB domain containing 2A', other_designations='metalloprotease TIKI1|TRAB domain-containing protein 2A|UPF0632 protein C2orf89', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=84821650, end_position_on_the_genomic_accession=84881975, orientation='minus', exon_count=9, OMIM=[614912], no_hdr0=''),
    129303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129303, CurrentID=0, Status='live', Symbol='TMEM150A', Aliases=['TM6P1', 'TMEM150', 'TTN1'], description='transmembrane protein 150A', other_designations='transmembrane protein 150A|fasting-inducible integral membrane protein TM6P1|tentonin 1|transmembrane protein 150', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85598547, end_position_on_the_genomic_accession=85602698, orientation='minus', exon_count=11, OMIM=[616757], no_hdr0=''),
    129401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129401, CurrentID=0, Status='live', Symbol='NUP35', Aliases=['MP-44', 'MP44', 'NP44', 'NUP53'], description='nucleoporin 35', other_designations='nucleoporin NUP35|mitotic phosphoprotein 44|nuclear pore complex protein Nup53|nucleoporin 35kDa|nucleoporin NUP53', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=183117480, end_position_on_the_genomic_accession=183161680, orientation='plus', exon_count=14, OMIM=[608140], no_hdr0=''),
    129446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129446, CurrentID=0, Status='live', Symbol='XIRP2', Aliases=['CMYA3'], description='xin actin binding repeat containing 2', other_designations='xin actin-binding repeat-containing protein 2|beta-xin|cardiomyopathy associated 3|cardiomyopathy-associated protein 3|myomaxin|xeplin|xin repeat protein 2', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=166888480, end_position_on_the_genomic_accession=167259753, orientation='plus', exon_count=13, OMIM=[609778], no_hdr0=''),
    129450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129450, CurrentID=0, Status='live', Symbol='TYW5', Aliases=['C2orf60', 'hTYW5'], description='tRNA-yW synthesizing protein 5', other_designations='tRNA wybutosine-synthesizing protein 5|jmjC domain-containing protein C2orf60|tRNA yW-synthesizing enzyme 5|tRNA(Phe) (7-(3-amino-3-carboxypropyl)wyosine(37)-C(2))-hydroxylase', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=199928913, end_position_on_the_genomic_accession=199955624, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    129521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129521, CurrentID=0, Status='live', Symbol='NMS', Aliases=[], description='neuromedin S', other_designations='neuromedin-S|neuromedin S precursor-related peptide/neuromedin S preproprotein|prepro-NMS', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=100470482, end_position_on_the_genomic_accession=100483280, orientation='plus', exon_count=10, OMIM=[619337], no_hdr0=''),
    129530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129530, CurrentID=0, Status='live', Symbol='LYG1', Aliases=['LYGA1', 'SALW1939'], description='lysozyme g1', other_designations='lysozyme g-like protein 1|lysozyme G-like 1', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99284238, end_position_on_the_genomic_accession=99304775, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    129531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129531, CurrentID=0, Status='live', Symbol='MITD1', Aliases=[], description='microtubule interacting and trafficking domain containing 1', other_designations='MIT domain-containing protein 1|MIT, microtubule interacting and transport, domain containing 1', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99161427, end_position_on_the_genomic_accession=99181061, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    129563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129563, CurrentID=0, Status='live', Symbol='DIS3L2', Aliases=['FAM6A', 'PRLMNS', 'hDIS3L2'], description="DIS3 like 3'-5' exoribonuclease 2", other_designations='DIS3-like exonuclease 2|DIS3 mitotic control homolog-like 2|family with sequence similarity 6, member A', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231961713, end_position_on_the_genomic_accession=232344350, orientation='plus', exon_count=21, OMIM=[614184], no_hdr0=''),
    129607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129607, CurrentID=0, Status='live', Symbol='CMPK2', Aliases=['NDK', 'TMPK2', 'TYKi', 'UMP-CMPK2'], description='cytidine/uridine monophosphate kinase 2', other_designations='UMP-CMP kinase 2, mitochondrial|UMP/CMP kinase|cytidine monophosphate (UMP-CMP) kinase 2, mitochondrial|cytidylate kinase 2|mitochondrial UMP-CMP kinase|nucleoside-diphosphate kinase|thymidine monophosphate kinase 2|thymidylate kinase family LPS-inducible member', map_location='2p25.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=6840417, end_position_on_the_genomic_accession=6866635, orientation='minus', exon_count=8, OMIM=[611787], no_hdr0=''),
    129642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129642, CurrentID=0, Status='live', Symbol='MBOAT2', Aliases=['LPAAT', 'LPCAT', 'LPCAT4', 'LPEAT', 'LPLAT 2', 'OACT2'], description='membrane bound O-acyltransferase domain containing 2', other_designations='lysophospholipid acyltransferase 2|1-acylglycerophosphate O-acyltransferase|1-acylglycerophosphate O-acyltransferase MBOAT2|1-acylglycerophosphocholine O-acyltransferase MBOAT2|1-acylglycerophosphoethanolamine MBOAT2 O-acyltransferase|1-acylglycerophosphoethanolamine O-acyltransferase|O-acyltransferase (membrane bound) domain containing 2|lyso-PA acyltransferase|lyso-PC acyltransferase|lyso-PC acyltransferase 4|lyso-PE acyltransferase|lysophosphatidic acid acyltransferase|lysophosphatidylcholine acyltransferase|lysophosphatidylcholine acyltransferase 4|lysophosphatidylethanolamine acyltransferase|membrane-bound O-acyltransferase domain-containing protein 2', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=8852690, end_position_on_the_genomic_accession=9003710, orientation='minus', exon_count=15, OMIM=[611949], no_hdr0=''),
    129684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129684, CurrentID=0, Status='live', Symbol='CNTNAP5', Aliases=['caspr5'], description='contactin associated protein family member 5', other_designations='contactin-associated protein-like 5|cell recognition molecule Caspr5|contactin associated protein like 5', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=124025287, end_position_on_the_genomic_accession=124921219, orientation='plus', exon_count=24, OMIM=[610519], no_hdr0=''),
    129685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129685, CurrentID=0, Status='live', Symbol='TAF8', Aliases=['II', 'TAF', 'TAF(II)43', 'TAFII-43', 'TAFII43', 'TBN'], description='TATA-box binding protein associated factor 8', other_designations='transcription initiation factor TFIID subunit 8|TAF8 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 43kDa|TATA box binding protein (TBP)-associated factor, RNA polymerase II, A, 45/50kDa|TBP-associated factor 43 kDa|TBP-associated factor 8|TBP-associated factor TAFII43|TBP-associated factor, RNA polymerase II, 43 kD|hTAFII43|protein taube nuss|taube nuss homolog|transcription initiation factor TFIID 43 kDa subunit', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42050522, end_position_on_the_genomic_accession=42083278, orientation='plus', exon_count=12, OMIM=[609514], no_hdr0=''),
    129787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129787, CurrentID=0, Status='live', Symbol='TMEM18', Aliases=['lncND'], description='transmembrane protein 18', other_designations='transmembrane protein 18', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=663877, end_position_on_the_genomic_accession=677406, orientation='minus', exon_count=7, OMIM=[613220], no_hdr0=''),
    129804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129804, CurrentID=0, Status='live', Symbol='FBLN7', Aliases=['TM14'], description='fibulin 7', other_designations='fibulin-7|FIBL-7', map_location='2q13-q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112138385, end_position_on_the_genomic_accession=112254558, orientation='plus', exon_count=18, OMIM=[611551], no_hdr0=''),
    129807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129807, CurrentID=0, Status='live', Symbol='NEU4', Aliases=[], description='neuraminidase 4', other_designations='sialidase-4|N-acetyl-alpha-neuraminidase 4|neuraminidase 4 (sialidase)', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241809193, end_position_on_the_genomic_accession=241817413, orientation='plus', exon_count=6, OMIM=[608527], no_hdr0=''),
    129831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129831, CurrentID=0, Status='live', Symbol='RBM45', Aliases=['DRB1', 'RB-1'], description='RNA binding motif protein 45', other_designations='RNA-binding protein 45|developmentally regulated RNA-binding protein 1|putative RNA binding protein RB-1', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178112409, end_position_on_the_genomic_accession=178129656, orientation='plus', exon_count=10, OMIM=[608888], no_hdr0=''),
    129852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129852, CurrentID=0, Status='live', Symbol='C2orf73', Aliases=[], description='chromosome 2 open reading frame 73', other_designations='uncharacterized protein C2orf73', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=54329943, end_position_on_the_genomic_accession=54383673, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    129868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129868, CurrentID=0, Status='live', Symbol='TRIM43', Aliases=['TRIM43A'], description='tripartite motif containing 43', other_designations='tripartite motif-containing protein 43', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95592001, end_position_on_the_genomic_accession=95599778, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    129880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129880, CurrentID=0, Status='live', Symbol='BBS5', Aliases=[], description='Bardet-Biedl syndrome 5', other_designations='Bardet-Biedl syndrome 5 protein', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169479494, end_position_on_the_genomic_accession=169506655, orientation='plus', exon_count=12, OMIM=[603650], no_hdr0=''),
    129881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=129881, CurrentID=0, Status='live', Symbol='CCDC173', Aliases=['C2orf77'], description='coiled-coil domain containing 173', other_designations='coiled-coil domain-containing protein 173', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169645425, end_position_on_the_genomic_accession=169694405, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    130013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130013, CurrentID=0, Status='live', Symbol='ACMSD', Aliases=[], description='aminocarboxymuconate semialdehyde decarboxylase', other_designations='2-amino-3-carboxymuconate-6-semialdehyde decarboxylase|picolinate carboxylase', map_location='2q21.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=134838319, end_position_on_the_genomic_accession=134902906, orientation='plus', exon_count=13, OMIM=[608889], no_hdr0=''),
    130026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130026, CurrentID=0, Status='live', Symbol='ICA1L', Aliases=['ALS2CR14', 'ALS2CR15'], description='islet cell autoantigen 1 like', other_designations='islet cell autoantigen 1-like protein|Ica69-related protein|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 14|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 15|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 14 protein|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 15 protein|islet cell autoantigen 1,69kDa-like', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202773176, end_position_on_the_genomic_accession=202871766, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    130074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130074, CurrentID=0, Status='live', Symbol='FAM168B', Aliases=['MANI'], description='family with sequence similarity 168 member B', other_designations='myelin-associated neurite-outgrowth inhibitor|protein FAM168B', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131047876, end_position_on_the_genomic_accession=131093468, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    130075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130075, CurrentID=0, Status='live', Symbol='OR9A4', Aliases=[], description='olfactory receptor family 9 subfamily A member 4', other_designations='olfactory receptor 9A4|olfactory receptor OR7-1', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141916399, end_position_on_the_genomic_accession=141920625, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    130106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130106, CurrentID=0, Status='live', Symbol='CIB4', Aliases=['KIP4'], description='calcium and integrin binding family member 4', other_designations='calcium and integrin-binding family member 4', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26581205, end_position_on_the_genomic_accession=26641798, orientation='minus', exon_count=11, OMIM=[610646], no_hdr0=''),
    130120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130120, CurrentID=0, Status='live', Symbol='REG3G', Aliases=['LPPM429', 'PAP IB', 'PAP-1B', 'PAP1B', 'PAPIB', 'REG III', 'REG-III', 'UNQ429'], description='regenerating family member 3 gamma', other_designations='regenerating islet-derived protein 3-gamma|REG-3-gamma|pancreatitis-associated protein 1B|pancreatitis-associated protein IB|reg III-gamma|regenerating gene III|regenerating islet-derived 3 gamma|regenerating islet-derived protein III-gamma', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=79025664, end_position_on_the_genomic_accession=79028502, orientation='plus', exon_count=7, OMIM=[609933], no_hdr0=''),
    130132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130132, CurrentID=0, Status='live', Symbol='RFTN2', Aliases=['C2orf11', 'Raftlin-2'], description='raftlin family member 2', other_designations='raftlin-2|raft-linking protein 2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197568224, end_position_on_the_genomic_accession=197675794, orientation='minus', exon_count=10, OMIM=[618215], no_hdr0=''),
    130162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130162, CurrentID=0, Status='live', Symbol='CLHC1', Aliases=['C2orf63'], description='clathrin heavy chain linker domain containing 1', other_designations='clathrin heavy chain linker domain-containing protein 1', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=55172547, end_position_on_the_genomic_accession=55232563, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    130271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130271, CurrentID=0, Status='live', Symbol='PLEKHH2', Aliases=['PLEKHH1L'], description='pleckstrin homology, MyTH4 and FERM domain containing H2', other_designations='pleckstrin homology domain-containing family H member 2|pleckstrin homology domain containing, family H (with MyTH4 domain) member 2', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43637260, end_position_on_the_genomic_accession=43767987, orientation='plus', exon_count=34, OMIM=[612723], no_hdr0=''),
    130340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130340, CurrentID=0, Status='live', Symbol='AP1S3', Aliases=['PSORS15', 'sigma1C'], description='adaptor related protein complex 1 subunit sigma 3', other_designations='AP-1 complex subunit sigma-3|adapter-related protein complex 1 subunit sigma-1C|adaptor protein complex AP-1 sigma-1C subunit|adaptor related protein complex 1 sigma 3 subunit|adaptor-related protein complex 1 subunit sigma-1C|clathrin assembly protein complex 1 sigma-1C small chain|golgi adaptor HA1/AP1 adaptin sigma-1C subunit|sigma 1C subunit of AP-1 clathrin', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=223755326, end_position_on_the_genomic_accession=223837582, orientation='minus', exon_count=6, OMIM=[615781], no_hdr0=''),
    130355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130355, CurrentID=0, Status='live', Symbol='C2orf76', Aliases=['AIM29'], description='chromosome 2 open reading frame 76', other_designations='UPF0538 protein C2orf76', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119281472, end_position_on_the_genomic_accession=119367151, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    130367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130367, CurrentID=0, Status='live', Symbol='SGPP2', Aliases=['SPP2', 'SPPase2'], description='sphingosine-1-phosphate phosphatase 2', other_designations='sphingosine-1-phosphate phosphatase 2|sphingosine 1-phosphate phosphohydrolase 2|sphingosine-1-phosphatase 2|sphingosine-1-phosphate phosphotase 2', map_location='2q36.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=222423988, end_position_on_the_genomic_accession=222562621, orientation='plus', exon_count=7, OMIM=[612827], no_hdr0=''),
    130399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130399, CurrentID=0, Status='live', Symbol='ACVR1C', Aliases=['ACVRLK7', 'ALK7'], description='activin A receptor type 1C', other_designations='activin receptor type-1C|ACTR-IC|ALK-7|activin A receptor, type IC|activin receptor type IC|activin receptor-like kinase 7', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157526767, end_position_on_the_genomic_accession=157628864, orientation='minus', exon_count=10, OMIM=[608981], no_hdr0=''),
    130497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130497, CurrentID=0, Status='live', Symbol='OSR1', Aliases=['ODD'], description='odd-skipped related transcription factor 1', other_designations='protein odd-skipped-related 1|odd-skipped homolog|odd-skipped related 1|odd-skipped related transciption factor 1', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=19351485, end_position_on_the_genomic_accession=19358623, orientation='minus', exon_count=4, OMIM=[608891], no_hdr0=''),
    130502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130502, CurrentID=0, Status='live', Symbol='TTC32', Aliases=[], description='tetratricopeptide repeat domain 32', other_designations='tetratricopeptide repeat protein 32|TPR repeat protein 32', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=19896631, end_position_on_the_genomic_accession=19901983, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    130507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130507, CurrentID=0, Status='live', Symbol='UBR3', Aliases=['ZNF650'], description='ubiquitin protein ligase E3 component n-recognin 3', other_designations='E3 ubiquitin-protein ligase UBR3|N-recognin-3|RING-type E3 ubiquitin transferase UBR3|ubiquitin protein ligase E3 component n-recognin 3 (putative)|ubiquitin-protein ligase E3-alpha-3|ubiquitin-protein ligase E3-alpha-III|zinc finger protein 650', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169827454, end_position_on_the_genomic_accession=170084131, orientation='plus', exon_count=45, OMIM=[613831], no_hdr0=''),
    130535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130535, CurrentID=0, Status='live', Symbol='KCTD18', Aliases=['6530404F10Rik'], description='potassium channel tetramerization domain containing 18', other_designations='BTB/POZ domain-containing protein KCTD18|potassium channel tetramerisation domain containing 18', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200488958, end_position_on_the_genomic_accession=200510068, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    130540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130540, CurrentID=0, Status='live', Symbol='FLACC1', Aliases=['ALS2CR12'], description='flagellum associated containing coiled-coil domains 1', other_designations='flagellum-associated coiled-coil domain-containing protein 1|ALS2 chromosome region 12|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 12|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 12 protein|amyotrophic lateral sclerosis 2 chromosome region 12|amyotrophic lateral sclerosis 2 chromosome region candidate 12', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201288271, end_position_on_the_genomic_accession=201364285, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    130557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130557, CurrentID=0, Status='live', Symbol='ZNF513', Aliases=['HMFT0656', 'RP58', 'Zfp513'], description='zinc finger protein 513', other_designations='zinc finger protein 513', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27377231, end_position_on_the_genomic_accession=27380866, orientation='minus', exon_count=5, OMIM=[613598], no_hdr0=''),
    130560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130560, CurrentID=0, Status='live', Symbol='SPATA3', Aliases=['TSARG1'], description='spermatogenesis associated 3', other_designations='spermatogenesis-associated protein 3|testis and spermatogenesis cell apoptosis related gene 1|testis and spermatogenesis cell-related protein 1|testis spermatocyte apoptosis-related protein 1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230996121, end_position_on_the_genomic_accession=231019938, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    130574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130574, CurrentID=0, Status='live', Symbol='LYPD6', Aliases=[], description='LY6/PLAUR domain containing 6', other_designations='ly6/PLAUR domain-containing protein 6', map_location='2q23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=149329985, end_position_on_the_genomic_accession=149474138, orientation='plus', exon_count=9, OMIM=[613359], no_hdr0=''),
    130576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130576, CurrentID=0, Status='live', Symbol='LYPD6B', Aliases=['CT116', 'LYPD7'], description='LY6/PLAUR domain containing 6B', other_designations='ly6/PLAUR domain-containing protein 6B|cancer/testis antigen 116', map_location='2q23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=149038695, end_position_on_the_genomic_accession=149215262, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    130589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130589, CurrentID=0, Status='live', Symbol='GALM', Aliases=['BLOCK25', 'GALAC4', 'GLAT', 'HEL-S-63p', 'IBD1'], description='galactose mutarotase', other_designations='galactose mutarotase|aldose 1-epimerase|aldose mutarotase|epididymis secretory sperm binding protein Li 63p|galactomutarotase|galactose enzyme activator', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38665922, end_position_on_the_genomic_accession=38734765, orientation='plus', exon_count=9, OMIM=[137030], no_hdr0=''),
    130612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130612, CurrentID=0, Status='live', Symbol='TMEM198', Aliases=['TMEM198A'], description='transmembrane protein 198', other_designations='transmembrane protein 198', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219543663, end_position_on_the_genomic_accession=219550595, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    130617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130617, CurrentID=0, Status='live', Symbol='ZFAND2B', Aliases=['AIRAPL'], description='zinc finger AN1-type containing 2B', other_designations='AN1-type zinc finger protein 2B|AIRAP-like protein|arsenite-inducible RNA-associated protein-like protein|zinc finger, AN1-type domain 2B', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219206782, end_position_on_the_genomic_accession=219209648, orientation='plus', exon_count=10, OMIM=[613474], no_hdr0=''),
    130733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130733, CurrentID=0, Status='live', Symbol='TMEM178A', Aliases=['TMEM178'], description='transmembrane protein 178A', other_designations='transmembrane protein 178A|transmembrane protein 178', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=39646748, end_position_on_the_genomic_accession=39736429, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    130749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130749, CurrentID=0, Status='live', Symbol='CPO', Aliases=[], description='carboxypeptidase O', other_designations='carboxypeptidase O|metallocarboxypeptidase C|metallocarboxypeptidase O', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206792477, end_position_on_the_genomic_accession=206971064, orientation='plus', exon_count=18, OMIM=[609563], no_hdr0=''),
    130752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130752, CurrentID=0, Status='live', Symbol='MDH1B', Aliases=['RP11-95H11'], description='malate dehydrogenase 1B', other_designations='putative malate dehydrogenase 1B|malate dehydrogenase 1B, NAD (soluble)', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206737763, end_position_on_the_genomic_accession=206765544, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    130813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130813, CurrentID=0, Status='live', Symbol='C2orf50', Aliases=[], description='chromosome 2 open reading frame 50', other_designations='uncharacterized protein C2orf50', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11133128, end_position_on_the_genomic_accession=11154564, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    130814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130814, CurrentID=0, Status='live', Symbol='SLC66A3', Aliases=['C2orf22', 'PQLC3'], description='solute carrier family 66 member 3', other_designations='solute carrier family 66 member 3|PQ loop repeat containing 3|PQ-loop repeat-containing protein 3', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=11155372, end_position_on_the_genomic_accession=11182028, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    130827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130827, CurrentID=0, Status='live', Symbol='TMEM182', Aliases=[], description='transmembrane protein 182', other_designations='transmembrane protein 182', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102736910, end_position_on_the_genomic_accession=102843838, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    130888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130888, CurrentID=0, Status='live', Symbol='FBXO36', Aliases=['Fbx36'], description='F-box protein 36', other_designations='F-box only protein 36', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=229922503, end_position_on_the_genomic_accession=230013913, orientation='plus', exon_count=5, OMIM=[609105], no_hdr0=''),
    130916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130916, CurrentID=0, Status='live', Symbol='MTERF4', Aliases=['MTERFD2'], description='mitochondrial transcription termination factor 4', other_designations='transcription termination factor 4, mitochondrial|MTERF domain-containing protein 2', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241072168, end_position_on_the_genomic_accession=241102321, orientation='minus', exon_count=10, OMIM=[615393], no_hdr0=''),
    130940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130940, CurrentID=0, Status='live', Symbol='CCDC148', Aliases=[], description='coiled-coil domain containing 148', other_designations='coiled-coil domain-containing protein 148', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=158171073, end_position_on_the_genomic_accession=158456753, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    130951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=130951, CurrentID=0, Status='live', Symbol='M1AP', Aliases=['C2orf65', 'D6Mm5e', 'SPATA37', 'SPGF48'], description='meiosis 1 associated protein', other_designations='meiosis 1 arrest protein|meiosis 1 arresting protein|spermatogenesis associated 37', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74557640, end_position_on_the_genomic_accession=74648330, orientation='minus', exon_count=15, OMIM=[619098], no_hdr0=''),
    131034 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131034, CurrentID=0, Status='live', Symbol='CPNE4', Aliases=['COPN4', 'CPN4'], description='copine 4', other_designations='copine-4|copine 8|copine IV', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=131533569, end_position_on_the_genomic_accession=132285696, orientation='minus', exon_count=28, OMIM=[604208], no_hdr0=''),
    131076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131076, CurrentID=0, Status='live', Symbol='MIX23', Aliases=['CCDC58'], description='mitochondrial matrix import factor 23', other_designations='protein MIX23|coiled-coil domain containing 58|coiled-coil domain-containing protein 58', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122359587, end_position_on_the_genomic_accession=122383231, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    131096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131096, CurrentID=0, Status='live', Symbol='KCNH8', Aliases=['ELK', 'ELK1', 'Kv12.1', 'elk3'], description='potassium voltage-gated channel subfamily H member 8', other_designations='potassium voltage-gated channel subfamily H member 8|ELK channel 3|ether-a-go-go-like potassium channel 1|ether-a-go-go-like potassium channel 3|hElk1|potassium channel, voltage gated eag related subfamily H, member 8|potassium voltage-gated channel, subfamily H (eag-related), member 8|voltage-gated potassium channel subunit Kv12.1', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=19148510, end_position_on_the_genomic_accession=19535642, orientation='plus', exon_count=17, OMIM=[608260], no_hdr0=''),
    131118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131118, CurrentID=0, Status='live', Symbol='DNAJC19', Aliases=['PAM18', 'TIM14', 'TIMM14'], description='DnaJ heat shock protein family (Hsp40) member C19', other_designations='mitochondrial import inner membrane translocase subunit TIM14|DnaJ (Hsp40) homolog, subfamily C, member 19|DnaJ-like protein subfamily C member 19|homolog of yeast TIM14', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=180983709, end_position_on_the_genomic_accession=180989838, orientation='minus', exon_count=6, OMIM=[608977], no_hdr0=''),
    131149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131149, CurrentID=0, Status='live', Symbol='OTOL1', Aliases=['C1QTNF15', 'C1QTNF16'], description='otolin 1', other_designations='otolin-1|C1q and TNF related 16|C1q and tumor necrosis factor related protein 15', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=161496808, end_position_on_the_genomic_accession=161503942, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    131177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131177, CurrentID=0, Status='live', Symbol='FAM3D', Aliases=['EF7', 'OIT1'], description='FAM3 metabolism regulating signaling molecule D', other_designations='protein FAM3D|Oncoprotein-induced transcript 1|cytokine-like protein EF-7|family with sequence similarity 3 member D', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58633943, end_position_on_the_genomic_accession=58666843, orientation='minus', exon_count=12, OMIM=[608619], no_hdr0=''),
    131368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131368, CurrentID=0, Status='live', Symbol='ZPLD1', Aliases=[], description='zona pellucida like domain containing 1', other_designations='zona pellucida-like domain-containing protein 1|ZP domain-containing protein 1|cupulin', map_location='3q12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=102385144, end_position_on_the_genomic_accession=102479841, orientation='plus', exon_count=14, OMIM=[615915], no_hdr0=''),
    131375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131375, CurrentID=0, Status='live', Symbol='LYZL4', Aliases=['LYC4', 'LYZA'], description='lysozyme like 4', other_designations='lysozyme-like protein 4|lysozyme A|lysozyme-4', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42360766, end_position_on_the_genomic_accession=42411794, orientation='minus', exon_count=7, OMIM=[612750], no_hdr0=''),
    131377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131377, CurrentID=0, Status='live', Symbol='KLHL40', Aliases=['KBTBD5', 'NEM8', 'SRYP', 'SYRP'], description='kelch like family member 40', other_designations='kelch-like protein 40|kelch repeat and BTB (POZ) domain containing 5|kelch repeat and BTB domain-containing protein 5|nemaline myopathy type 8|sarcosynapsin', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42685537, end_position_on_the_genomic_accession=42692544, orientation='plus', exon_count=6, OMIM=[615340], no_hdr0=''),
    131405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131405, CurrentID=0, Status='live', Symbol='TRIM71', Aliases=['HYDCC1', 'LIN-41', 'LIN41'], description='tripartite motif containing 71', other_designations='E3 ubiquitin-protein ligase TRIM71|RING-type E3 ubiquitin transferase TRIM71|abnormal cell LINeage LIN-41|homolog of C. elegans Lin-41|protein lin-41 homolog|tripartite motif containing 71, E3 ubiquitin protein ligase|tripartite motif-containing protein 71', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32817997, end_position_on_the_genomic_accession=32897824, orientation='plus', exon_count=4, OMIM=[618570], no_hdr0=''),
    131408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131408, CurrentID=0, Status='live', Symbol='FAM131A', Aliases=['C3orf40', 'FLAT715', 'PRO1378'], description='family with sequence similarity 131 member A', other_designations='protein FAM131A', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184335924, end_position_on_the_genomic_accession=184346275, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    131450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131450, CurrentID=0, Status='live', Symbol='CD200R1', Aliases=['CD200R', 'HCRTR2', 'MOX2R', 'OX2R'], description='CD200 receptor 1', other_designations='cell surface glycoprotein CD200 receptor 1|CD200 cell surface glycoprotein receptor|MOX2 receptor|cell surface glycoprotein OX2 receptor 1|cell surface glycoprotein receptor CD200', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112921205, end_position_on_the_genomic_accession=112975103, orientation='minus', exon_count=8, OMIM=[607546], no_hdr0=''),
    131474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131474, CurrentID=0, Status='live', Symbol='CHCHD4', Aliases=['MIA40', 'TIMM40'], description='coiled-coil-helix-coiled-coil-helix domain containing 4', other_designations='mitochondrial intermembrane space import and assembly protein 40|coiled-coil-helix-coiled-coil-helix domain-containing protein 4|translocase of inner mitochondrial membrane 40 homolog', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14112077, end_position_on_the_genomic_accession=14124870, orientation='minus', exon_count=4, OMIM=[611077], no_hdr0=''),
    131540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131540, CurrentID=0, Status='live', Symbol='ZDHHC19', Aliases=['DHHC19'], description='zinc finger DHHC-type palmitoyltransferase 19', other_designations='palmitoyltransferase ZDHHC19|DHHC-19|probable palmitoyltransferase ZDHHC19|zinc finger DHHC domain-containing protein 19|zinc finger DHHC-type containing 19|zinc finger, DHHC domain containing 19', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196197443, end_position_on_the_genomic_accession=196211437, orientation='minus', exon_count=11, OMIM=[618671], no_hdr0=''),
    131544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131544, CurrentID=0, Status='live', Symbol='CRYBG3', Aliases=['DKFZp667G2110', 'vlAKAP'], description='crystallin beta-gamma domain containing 3', other_designations='very large A-kinase anchor protein|beta-gamma crystallin domain containing 3|beta/gamma crystallin domain-containing protein 3', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=97821693, end_position_on_the_genomic_accession=97944984, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    131566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131566, CurrentID=0, Status='live', Symbol='DCBLD2', Aliases=['CLCP1', 'ESDN'], description='discoidin, CUB and LCCL domain containing 2', other_designations='discoidin, CUB and LCCL domain-containing protein 2|1700055P21Rik|CUB, LCCL and coagulation factor V/VIII-homology domains protein 1|coagulation factor V/VIII-homology domains protein 1|endothelial and smooth muscle cell-derived neuropilin-like protein', map_location='3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98795941, end_position_on_the_genomic_accession=98901695, orientation='minus', exon_count=18, OMIM=[608698], no_hdr0=''),
    131578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131578, CurrentID=0, Status='live', Symbol='LRRC15', Aliases=['LIB'], description='leucine rich repeat containing 15', other_designations='leucine-rich repeat-containing protein 15|hLib|leucine-rich repeat protein induced by beta amyloid|leucine-rich repeat protein induced by beta-amyloid homolog', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194355249, end_position_on_the_genomic_accession=194369743, orientation='minus', exon_count=3, OMIM=[619327], no_hdr0=''),
    131583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131583, CurrentID=0, Status='live', Symbol='FAM43A', Aliases=[], description='family with sequence similarity 43 member A', other_designations='protein FAM43A', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194685883, end_position_on_the_genomic_accession=194689037, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    131601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131601, CurrentID=0, Status='live', Symbol='TPRA1', Aliases=['GPR175', 'TMEM227', 'TPRA40'], description='transmembrane protein adipocyte associated 1', other_designations='transmembrane protein adipocyte-associated 1|G protein-coupled receptor 175|integral membrane protein GPR175|seven transmembrane domain orphan receptor|transmembrane domain protein regulated in adipocytes 40 kDa|transmembrane protein 227|transmembrane protein, adipocyte asscociated 1', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127571232, end_position_on_the_genomic_accession=127598231, orientation='minus', exon_count=18, OMIM=[608336], no_hdr0=''),
    131616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131616, CurrentID=0, Status='live', Symbol='TMEM42', Aliases=[], description='transmembrane protein 42', other_designations='transmembrane protein 42', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44861912, end_position_on_the_genomic_accession=44865664, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    131669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131669, CurrentID=0, Status='live', Symbol='UROC1', Aliases=['HMFN0320', 'UROCD'], description='urocanate hydratase 1', other_designations='urocanate hydratase|imidazolonepropionate hydrolase|urocanase 1|urocanase domain containing 1', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126481166, end_position_on_the_genomic_accession=126517773, orientation='minus', exon_count=21, OMIM=[613012], no_hdr0=''),
    131831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131831, CurrentID=0, Status='live', Symbol='ERICH6', Aliases=['C3orf44A', 'FAM194A', 'ERICH6'], description='glutamate rich 6', other_designations='glutamate-rich protein 6|family with sequence similarity 194, member A|glutamate-rich 6A|protein FAM194A', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150659885, end_position_on_the_genomic_accession=150704563, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    131870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131870, CurrentID=0, Status='live', Symbol='NUDT16', Aliases=[], description='nudix hydrolase 16', other_designations='U8 snoRNA-decapping enzyme|IDP phosphatase|IDPase|U8 snoRNA-binding protein H29K|inosine diphosphate phosphatase|m7GpppN-mRNA hydrolase|nucleoside diphosphate-linked moiety X motif 16|nudix (nucleoside diphosphate linked moiety X)-type motif 16|nudix motif 16|testicular tissue protein Li 129', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=131381671, end_position_on_the_genomic_accession=131388830, orientation='plus', exon_count=5, OMIM=[617381], no_hdr0=''),
    131873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131873, CurrentID=0, Status='live', Symbol='COL6A6', Aliases=[], description='collagen type VI alpha 6 chain', other_designations='collagen alpha-6(VI) chain|collagen, type VI, alpha 6', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130516709, end_position_on_the_genomic_accession=130678137, orientation='plus', exon_count=44, OMIM=[616613], no_hdr0=''),
    131890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131890, CurrentID=0, Status='live', Symbol='GRK7', Aliases=['GPRK7'], description='G protein-coupled receptor kinase 7', other_designations='rhodopsin kinase GRK7|g protein-coupled receptor kinase GRK7', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141763408, end_position_on_the_genomic_accession=141819352, orientation='plus', exon_count=6, OMIM=[606987], no_hdr0=''),
    131920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131920, CurrentID=0, Status='live', Symbol='TMEM207', Aliases=['UNQ846'], description='transmembrane protein 207', other_designations='transmembrane protein 207|SRSR846', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=190428655, end_position_on_the_genomic_accession=190449901, orientation='minus', exon_count=5, OMIM=[614786], no_hdr0=''),
    131965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=131965, CurrentID=0, Status='live', Symbol='METTL6', Aliases=[], description='methyltransferase 6, methylcytidine', other_designations='tRNA N(3)-methylcytidine methyltransferase METTL6|methyltransferase like 6|methyltransferase-like protein 6', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=15381275, end_position_on_the_genomic_accession=15427580, orientation='minus', exon_count=12, OMIM=[618903], no_hdr0=''),
    132001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132001, CurrentID=0, Status='live', Symbol='TAMM41', Aliases=['C3orf31', 'RAM41', 'TAM41'], description='TAM41 mitochondrial translocator assembly and maintenance homolog', other_designations='phosphatidate cytidylyltransferase, mitochondrial|CDP-DAG synthase|CDP-diacylglycerol synthase|MMP37-like protein, mitochondrial|TAM41, mitochondrial translocator assembly and maintenance protein, homolog|mitochondrial translocator assembly and maintenance protein 41 homolog', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=11721896, end_position_on_the_genomic_accession=11846900, orientation='minus', exon_count=15, OMIM=[614948], no_hdr0=''),
    132014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132014, CurrentID=0, Status='live', Symbol='IL17RE', Aliases=[], description='interleukin 17 receptor E', other_designations='interleukin-17 receptor E|IL-17 receptor E', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9902087, end_position_on_the_genomic_accession=9916402, orientation='plus', exon_count=20, OMIM=[614995], no_hdr0=''),
    132112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132112, CurrentID=0, Status='live', Symbol='RTP1', Aliases=['Z3CXXC1'], description='receptor transporter protein 1', other_designations='receptor-transporting protein 1|3CxxC-type zinc finger protein 1|receptor (chemosensory) transporter protein 1|zinc finger, 3CxxC-type 1', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187197486, end_position_on_the_genomic_accession=187201462, orientation='plus', exon_count=2, OMIM=[609137], no_hdr0=''),
    132141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132141, CurrentID=0, Status='live', Symbol='IQCF1', Aliases=[], description='IQ motif containing F1', other_designations='IQ domain-containing protein F1', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51894876, end_position_on_the_genomic_accession=51903353, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    132158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132158, CurrentID=0, Status='live', Symbol='GLYCTK', Aliases=['HBEBP2', 'HBEBP4', 'HBeAgBP4A'], description='glycerate kinase', other_designations='glycerate kinase|HBeAg binding protein 4|HBeAg-binding protein 2', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52287558, end_position_on_the_genomic_accession=52295257, orientation='plus', exon_count=5, OMIM=[610516], no_hdr0=''),
    132160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132160, CurrentID=0, Status='live', Symbol='PPM1M', Aliases=['PP2C-eta', 'PP2CE', 'PP2Ceta'], description='protein phosphatase, Mg2+/Mn2+ dependent 1M', other_designations='protein phosphatase 1M|protein phosphatase 1M (PP2C domain containing)|protein phosphatase 2C eta-2', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52245725, end_position_on_the_genomic_accession=52250599, orientation='plus', exon_count=11, OMIM=[608979], no_hdr0=''),
    132200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132200, CurrentID=0, Status='live', Symbol='C3orf49', Aliases=[], description='chromosome 3 open reading frame 49', other_designations='putative uncharacterized protein C3orf49', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=63816946, end_position_on_the_genomic_accession=63848636, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    132203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132203, CurrentID=0, Status='live', Symbol='SNTN', Aliases=['S100A1L', 'S100AL', 'sentan'], description='sentan, cilia apical structure protein', other_designations='sentan|S100A-like protein', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=63652675, end_position_on_the_genomic_accession=63665212, orientation='plus', exon_count=5, OMIM=[617832], no_hdr0=''),
    132204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132204, CurrentID=0, Status='live', Symbol='SYNPR', Aliases=['SPO'], description='synaptoporin', other_designations='synaptoporin', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=63200604, end_position_on_the_genomic_accession=63616924, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    132228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132228, CurrentID=0, Status='live', Symbol='LSMEM2', Aliases=['C3orf45'], description='leucine rich single-pass membrane protein 2', other_designations='leucine-rich single-pass membrane protein 2', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=50277907, end_position_on_the_genomic_accession=50288116, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    132243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132243, CurrentID=0, Status='live', Symbol='H1-8', Aliases=['H1.8', 'H1FOO', 'H1oo', 'osH1'], description='H1.8 linker histone', other_designations='histone H1.8|H1 histone family member O oocyte specific|histone H1oo|oocyte-specific histone H1|oocyte-specific linker histone H1', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129543175, end_position_on_the_genomic_accession=129555185, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    132299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132299, CurrentID=0, Status='live', Symbol='OCIAD2', Aliases=[], description='OCIA domain containing 2', other_designations='OCIA domain-containing protein 2|ovarian cancer immunoreactive antigen domain containing 2|ovarian carcinoma immunoreactive antigen-like protein', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48885019, end_position_on_the_genomic_accession=48906828, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    132320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132320, CurrentID=0, Status='live', Symbol='SCLT1', Aliases=['CAP-1A', 'CAP1A'], description='sodium channel and clathrin linker 1', other_designations='sodium channel and clathrin linker 1|sodium channel-associated protein 1', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=128874390, end_position_on_the_genomic_accession=129093580, orientation='minus', exon_count=29, OMIM=[611399], no_hdr0=''),
    132321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132321, CurrentID=0, Status='live', Symbol='C4orf33', Aliases=[], description='chromosome 4 open reading frame 33', other_designations='UPF0462 protein C4orf33', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=129093691, end_position_on_the_genomic_accession=129116637, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    132332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132332, CurrentID=0, Status='live', Symbol='SMIM43', Aliases=['TMEM155'], description='small integral membrane protein 43', other_designations='small integral membrane protein 43|protein TMEM155|transmembrane protein 155', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=121758930, end_position_on_the_genomic_accession=121765400, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    132430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132430, CurrentID=0, Status='live', Symbol='PABPC4L', Aliases=[], description='poly(A) binding protein cytoplasmic 4 like', other_designations='polyadenylate-binding protein 4-like|PABP-4-like', map_location='4q28.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=133948459, end_position_on_the_genomic_accession=134201789, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    132612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132612, CurrentID=0, Status='live', Symbol='ADAD1', Aliases=['Tenr'], description='adenosine deaminase domain containing 1', other_designations='adenosine deaminase domain-containing protein 1|adenosine deaminase domain containing 1 (testis-specific)|testis nuclear RNA-binding protein|testis tissue sperm-binding protein Li 92mP', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122378971, end_position_on_the_genomic_accession=122429815, orientation='plus', exon_count=14, OMIM=[614130], no_hdr0=''),
    132625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132625, CurrentID=0, Status='live', Symbol='ZFP42', Aliases=['REX-1', 'REX1', 'ZNF754', 'zfp-42'], description='ZFP42 zinc finger protein', other_designations='zinc finger protein 42 homolog|REX1 transcription factor|reduced expression protein 1|zinc finger protein 754', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=187994044, end_position_on_the_genomic_accession=188005046, orientation='plus', exon_count=5, OMIM=[614572], no_hdr0=''),
    132660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132660, CurrentID=0, Status='live', Symbol='LIN54', Aliases=['CXCDC1', 'JC8.6', 'MIP120', 'TCX1'], description='lin-54 DREAM MuvB core complex component', other_designations='protein lin-54 homolog|CXC domain-containing protein 1|lin-54 homolog', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82924603, end_position_on_the_genomic_accession=83012951, orientation='minus', exon_count=14, OMIM=[613367], no_hdr0=''),
    132671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132671, CurrentID=0, Status='live', Symbol='SPATA18', Aliases=['Mieap', 'SPETEX1'], description='spermatogenesis associated 18', other_designations='mitochondria-eating protein|spermatogenesis associated 18 homolog|testis tissue sperm-binding protein Li 71n', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52051304, end_position_on_the_genomic_accession=52097299, orientation='plus', exon_count=14, OMIM=[612814], no_hdr0=''),
    132720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132720, CurrentID=0, Status='live', Symbol='FAM241A', Aliases=['C4orf32'], description='family with sequence similarity 241 member A', other_designations='uncharacterized protein FAM241A|uncharacterized protein C4orf32', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=112145454, end_position_on_the_genomic_accession=112195256, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    132724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132724, CurrentID=0, Status='live', Symbol='TMPRSS11B', Aliases=['HATL5'], description='transmembrane serine protease 11B', other_designations='transmembrane protease serine 11B|airway trypsin-like protease 5|transmembrane protease, serine 11B', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68226653, end_position_on_the_genomic_accession=68245694, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    132789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132789, CurrentID=0, Status='live', Symbol='GNPDA2', Aliases=['GNP2', 'SB52'], description='glucosamine-6-phosphate deaminase 2', other_designations='glucosamine-6-phosphate isomerase 2|glcN6P deaminase 2|glucosamine-6-phosphate isomerase SB52', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=44701795, end_position_on_the_genomic_accession=44726634, orientation='minus', exon_count=8, OMIM=[613222], no_hdr0=''),
    132851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132851, CurrentID=0, Status='live', Symbol='SPATA4', Aliases=['CFAP178', 'FAP178', 'SPEF1B', 'TSARG2'], description='spermatogenesis associated 4', other_designations='spermatogenesis-associated protein 4|testis and spermatogenesis cell related protein 2|testis spermatocyte apoptosis-related gene 2 protein', map_location='4q34.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=176184579, end_position_on_the_genomic_accession=176195585, orientation='minus', exon_count=6, OMIM=[609879], no_hdr0=''),
    132864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132864, CurrentID=0, Status='live', Symbol='CPEB2', Aliases=['CPE-BP2', 'CPEB-2', 'hCPEB-2'], description='cytoplasmic polyadenylation element binding protein 2', other_designations='cytoplasmic polyadenylation element-binding protein 2|CPE-binding protein 2', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15002426, end_position_on_the_genomic_accession=15070153, orientation='plus', exon_count=16, OMIM=[610605], no_hdr0=''),
    132884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132884, CurrentID=0, Status='live', Symbol='EVC2', Aliases=['LBN', 'WAD'], description='EvC ciliary complex subunit 2', other_designations='limbin|Ellis van Creveld syndrome 2|ellis-van Creveld syndrome protein 2', map_location='4p16.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5562408, end_position_on_the_genomic_accession=5709548, orientation='minus', exon_count=26, OMIM=[607261], no_hdr0=''),
    132946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132946, CurrentID=0, Status='live', Symbol='ARL9', Aliases=[], description='ADP ribosylation factor like GTPase 9', other_designations='ADP-ribosylation factor-like protein 9|ADP-ribosylation factor-like 9', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56505209, end_position_on_the_genomic_accession=56524453, orientation='plus', exon_count=7, OMIM=[612405], no_hdr0=''),
    132949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132949, CurrentID=0, Status='live', Symbol='AASDH', Aliases=['ACSF4', 'LYS2', 'NRPS1098', 'NRPS998'], description='aminoadipate-semialdehyde dehydrogenase', other_designations='beta-alanine-activating enzyme|2-aminoadipic 6-semialdehyde dehydrogenase|acyl-CoA synthetase family member 4|non-ribosomal peptide synthetase 1098|non-ribosomal peptide synthetase 998', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56337687, end_position_on_the_genomic_accession=56389418, orientation='minus', exon_count=17, OMIM=[614365], no_hdr0=''),
    132954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132954, CurrentID=0, Status='live', Symbol='PDCL2', Aliases=['GCPHLP'], description='phosducin like 2', other_designations='phosducin-like protein 2', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55556519, end_position_on_the_genomic_accession=55592274, orientation='minus', exon_count=7, OMIM=[611676], no_hdr0=''),
    132989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=132989, CurrentID=0, Status='live', Symbol='C4orf36', Aliases=[], description='chromosome 4 open reading frame 36', other_designations='uncharacterized protein C4orf36', map_location='4q21.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=86876205, end_position_on_the_genomic_accession=86897256, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    133015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133015, CurrentID=0, Status='live', Symbol='PACRGL', Aliases=['C4orf28'], description='parkin coregulated like', other_designations='PACRG-like protein|PARK2 co-regulated like|PARK2 coregulated like', map_location='4p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=20696282, end_position_on_the_genomic_accession=20754828, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    133022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133022, CurrentID=0, Status='live', Symbol='TRAM1L1', Aliases=[], description='translocation associated membrane protein 1 like 1', other_designations='translocating chain-associated membrane protein 1-like 1', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=117083554, end_position_on_the_genomic_accession=117085576, orientation='minus', exon_count=1, OMIM=[617505], no_hdr0=''),
    133060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133060, CurrentID=0, Status='live', Symbol='OTOP1', Aliases=[], description='otopetrin 1', other_designations='proton channel OTOP1', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4188726, end_position_on_the_genomic_accession=4226929, orientation='minus', exon_count=6, OMIM=[607806], no_hdr0=''),
    133121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133121, CurrentID=0, Status='live', Symbol='ENPP6', Aliases=['NPP6'], description='ectonucleotide pyrophosphatase/phosphodiesterase 6', other_designations='glycerophosphocholine cholinephosphodiesterase ENPP6|B830047L21Rik|E-NPP 6|GPC-Cpde|NPP-6|choline-specific glycerophosphodiester phosphodiesterase|ectonucleotide pyrophosphatase/phosphodiesterase family member 6', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184088706, end_position_on_the_genomic_accession=184217873, orientation='minus', exon_count=8, OMIM=[616983], no_hdr0=''),
    133308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133308, CurrentID=0, Status='live', Symbol='SLC9B2', Aliases=['NHA2', 'NHE10', 'NHEDC2'], description='solute carrier family 9 member B2', other_designations='sodium/hydrogen exchanger 9B2|NHE domain-containing protein 2|Na(+)/H(+) exchanger NHA2|Na(+)/H(+) exchanger-like domain-containing protein 2|Na+/H+ exchanger domain containing 2|mitochondrial Na(+)/H(+) exchanger NHA2|mitochondrial sodium/hydrogen exchanger 9B2|mitochondrial sodium/hydrogen exchanger NHA2|sodium/hydrogen exchanger-like domain-containing protein 2|solute carrier family 9 subfamily B member 2|solute carrier family 9, subfamily B (NHA2, cation proton antiporter 2), member 2|solute carrier family 9, subfamily B (cation proton antiporter 2), member 2', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=103018029, end_position_on_the_genomic_accession=103077319, orientation='minus', exon_count=14, OMIM=[611789], no_hdr0=''),
    133383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133383, CurrentID=0, Status='live', Symbol='SETD9', Aliases=['C5orf35'], description='SET domain containing 9', other_designations='SET domain-containing protein 9', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=56909260, end_position_on_the_genomic_accession=56928900, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    133396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133396, CurrentID=0, Status='live', Symbol='IL31RA', Aliases=['CRL', 'CRL3', 'GLM-R', 'GLMR', 'GPL', 'IL-31RA', 'PLCA2', 'PRO21384', 'hGLM-R', 'zcytoR17'], description='interleukin 31 receptor A', other_designations='interleukin-31 receptor subunit alpha|IL-31 receptor subunit alpha|IL-31R subunit alpha|class I cytokine receptor|cytokine receptor-like 3|gp130-like monocyte receptor|soluble type I cytokine receptor CRL3', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55840334, end_position_on_the_genomic_accession=55922854, orientation='plus', exon_count=20, OMIM=[609510], no_hdr0=''),
    133418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133418, CurrentID=0, Status='live', Symbol='EMB', Aliases=['GP70'], description='embigin', other_designations='embigin|embigin homolog', map_location='5q11.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=50396192, end_position_on_the_genomic_accession=50443299, orientation='minus', exon_count=11, OMIM=[615669], no_hdr0=''),
    133482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133482, CurrentID=0, Status='live', Symbol='SLCO6A1', Aliases=['CT48', 'GST', 'OATP-I', 'OATP6A1', 'OATPY'], description='solute carrier organic anion transporter family member 6A1', other_designations='solute carrier organic anion transporter family member 6A1|cancer/testis antigen 48|gonad-specific transporter|organic anion-transporting polypeptide I|solute carrier family 21 member 19|testicular tissue protein Li 174|testis-specific organic anion transporter', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=102371774, end_position_on_the_genomic_accession=102502213, orientation='minus', exon_count=14, OMIM=[613365], no_hdr0=''),
    133491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133491, CurrentID=0, Status='live', Symbol='C5orf47', Aliases=[], description='chromosome 5 open reading frame 47', other_designations='uncharacterized protein C5orf47', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173989165, end_position_on_the_genomic_accession=174007524, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    133522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133522, CurrentID=0, Status='live', Symbol='PPARGC1B', Aliases=['ERRL1', 'PERC', 'PGC-1(beta)', 'PGC1B'], description='PPARG coactivator 1 beta', other_designations='peroxisome proliferator-activated receptor gamma coactivator 1-beta|PGC-1-related estrogen receptor alpha coactivator|PPAR-gamma coactivator 1-beta|PPARGC-1-beta|PPARgamma coactivator 1 beta|peroxisome proliferator-activated receptor gamma, coactivator 1 beta', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149730302, end_position_on_the_genomic_accession=149857861, orientation='plus', exon_count=16, OMIM=[608886], no_hdr0=''),
    133558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133558, CurrentID=0, Status='live', Symbol='MROH2B', Aliases=['HEATR7B2', 'SPIF'], description='maestro heat like repeat family member 2B', other_designations='maestro heat-like repeat-containing protein family member 2B|HEAT repeat family member 7B2|HEAT repeat family member B2|HEAT repeat-containing protein 7B2|sperm PKA-interacting factor', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=40998020, end_position_on_the_genomic_accession=41071342, orientation='minus', exon_count=43, OMIM=[], no_hdr0=''),
    133584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133584, CurrentID=0, Status='live', Symbol='EGFLAM', Aliases=['AGRINL', 'AGRNL', 'PIKA'], description='EGF like, fibronectin type III and laminin G domains', other_designations='pikachurin|EGF-like, fibronectin type-III and laminin G-like domain-containing protein|agrin-like protein', map_location='5p13.2-p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=38258559, end_position_on_the_genomic_accession=38465480, orientation='plus', exon_count=24, OMIM=[617683], no_hdr0=''),
    133619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133619, CurrentID=0, Status='live', Symbol='PRRC1', Aliases=[], description='proline rich coiled-coil 1', other_designations='protein PRRC1|proline-rich and coiled-coil-containing protein 1', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127517624, end_position_on_the_genomic_accession=127555085, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    133686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133686, CurrentID=0, Status='live', Symbol='NADK2', Aliases=['C5orf33', 'DECRD', 'MNADK', 'NADKD1'], description='NAD kinase 2, mitochondrial', other_designations='NAD kinase 2, mitochondrial|NAD kinase domain-containing protein 1, mitochondrial', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36192589, end_position_on_the_genomic_accession=36242279, orientation='minus', exon_count=15, OMIM=[615787], no_hdr0=''),
    133688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133688, CurrentID=0, Status='live', Symbol='UGT3A1', Aliases=[], description='UDP glycosyltransferase family 3 member A1', other_designations='UDP-glucuronosyltransferase 3A1|UDP glycosyltransferase 3 family, polypeptide A1|UDPGT 3A1', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=35951006, end_position_on_the_genomic_accession=36001055, orientation='minus', exon_count=10, OMIM=[616383], no_hdr0=''),
    133690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133690, CurrentID=0, Status='live', Symbol='CAPSL', Aliases=[], description='calcyphosine like', other_designations='calcyphosin-like protein', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=35904288, end_position_on_the_genomic_accession=35938779, orientation='minus', exon_count=6, OMIM=[618799], no_hdr0=''),
    133746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133746, CurrentID=0, Status='live', Symbol='JMY', Aliases=['WHAMM2', 'WHDC1L3'], description='junction mediating and regulatory protein, p53 cofactor', other_designations='junction-mediating and -regulatory protein|WAS protein homology region 2 domain containing 1-like 3', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79236131, end_position_on_the_genomic_accession=79327215, orientation='plus', exon_count=11, OMIM=[604279], no_hdr0=''),
    133874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133874, CurrentID=0, Status='live', Symbol='C5orf58', Aliases=[], description='chromosome 5 open reading frame 58', other_designations='putative uncharacterized protein C5orf58', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=170232922, end_position_on_the_genomic_accession=170252570, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    133923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133923, CurrentID=0, Status='live', Symbol='ZNF474', Aliases=[], description='zinc finger protein 474', other_designations='zinc finger protein 474|4933409D10Rik|TSZFP|testis-specific zinc finger protein', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122129546, end_position_on_the_genomic_accession=122153569, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    133957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=133957, CurrentID=0, Status='live', Symbol='CCDC127', Aliases=[], description='coiled-coil domain containing 127', other_designations='coiled-coil domain-containing protein 127', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=196868, end_position_on_the_genomic_accession=218153, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    134083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134083, CurrentID=0, Status='live', Symbol='OR2Y1', Aliases=['OR5-2'], description='olfactory receptor family 2 subfamily Y member 1', other_designations='olfactory receptor 2Y1|olfactory receptor OR5-2', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180739123, end_position_on_the_genomic_accession=180740058, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    134111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134111, CurrentID=0, Status='live', Symbol='UBE2QL1', Aliases=[], description='ubiquitin conjugating enzyme E2 Q family like 1', other_designations='ubiquitin-conjugating enzyme E2Q-like protein 1|E2Q-like ubiquitin-conjugating enzyme 1|ubiquitin-conjugating enzyme E2Q family-like 1', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=6437347, end_position_on_the_genomic_accession=6496723, orientation='plus', exon_count=3, OMIM=[615832], no_hdr0=''),
    134121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134121, CurrentID=0, Status='live', Symbol='C5orf49', Aliases=[], description='chromosome 5 open reading frame 49', other_designations='uncharacterized protein C5orf49', map_location='5p15.31', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=7830378, end_position_on_the_genomic_accession=7851133, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    134145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134145, CurrentID=0, Status='live', Symbol='ATPSCKMT', Aliases=['FAM173B', 'JS-2', 'hFAM173B'], description='ATP synthase c subunit lysine N-methyltransferase', other_designations='ATP synthase subunit C lysine N-methyltransferase|family with sequence similarity 173 member B|protein FAM173B|protein N-lysine methyltransferase FAM173B', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10225507, end_position_on_the_genomic_accession=10249888, orientation='minus', exon_count=7, OMIM=[618568], no_hdr0=''),
    134147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134147, CurrentID=0, Status='live', Symbol='CMBL', Aliases=['JS-1'], description='carboxymethylenebutenolidase homolog', other_designations='carboxymethylenebutenolidase homolog|carboxymethylenebutenolidase homolog (Pseudomonas)|carboxymethylenebutenolidase-like (Pseudomonas)', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10277595, end_position_on_the_genomic_accession=10307902, orientation='minus', exon_count=6, OMIM=[613379], no_hdr0=''),
    134187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134187, CurrentID=0, Status='live', Symbol='POU5F2', Aliases=['SPRM-1'], description='POU domain class 5, transcription factor 2', other_designations='POU domain, class 5, transcription factor 2|sperm 1 POU domain transcription factor', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=93733220, end_position_on_the_genomic_accession=93741600, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    134218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134218, CurrentID=0, Status='live', Symbol='DNAJC21', Aliases=['BMFS3', 'DNAJA5', 'GS3', 'JJJ1'], description='DnaJ heat shock protein family (Hsp40) member C21', other_designations='dnaJ homolog subfamily C member 21|DnaJ (Hsp40) homolog, subfamily C, member 21|DnaJ homology subfamily A member 5|JJJ1 DnaJ domain protein homolog|dnaJ homolog subfamily A member 5', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34929540, end_position_on_the_genomic_accession=34958964, orientation='plus', exon_count=14, OMIM=[617048], no_hdr0=''),
    134265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134265, CurrentID=0, Status='live', Symbol='AFAP1L1', Aliases=[], description='actin filament associated protein 1 like 1', other_designations='actin filament-associated protein 1-like 1|AFAP1-like protein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149271859, end_position_on_the_genomic_accession=149343637, orientation='plus', exon_count=21, OMIM=[614410], no_hdr0=''),
    134266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134266, CurrentID=0, Status='live', Symbol='GRPEL2', Aliases=['Mt-GrpE#2'], description='GrpE like 2, mitochondrial', other_designations='grpE protein homolog 2, mitochondrial', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149345499, end_position_on_the_genomic_accession=149354583, orientation='plus', exon_count=4, OMIM=[618545], no_hdr0=''),
    134285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134285, CurrentID=0, Status='live', Symbol='TMEM171', Aliases=['PRP2'], description='transmembrane protein 171', other_designations='transmembrane protein 171|proline-rich protein PRP2', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73120575, end_position_on_the_genomic_accession=73131814, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    134288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134288, CurrentID=0, Status='live', Symbol='TMEM174', Aliases=[], description='transmembrane protein 174', other_designations='transmembrane protein 174', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=73173193, end_position_on_the_genomic_accession=73175143, orientation='plus', exon_count=2, OMIM=[614909], no_hdr0=''),
    134353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134353, CurrentID=0, Status='live', Symbol='LSM11', Aliases=[], description='LSM11, U7 small nuclear RNA associated', other_designations='U7 snRNA-associated Sm-like protein LSm11', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157743712, end_position_on_the_genomic_accession=157760709, orientation='plus', exon_count=4, OMIM=[617910], no_hdr0=''),
    134359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134359, CurrentID=0, Status='live', Symbol='POC5', Aliases=['C5orf37'], description='POC5 centriolar protein', other_designations='centrosomal protein POC5|POC5 centriolar protein homolog|hPOC5|protein of centriole 5|proteome of centriole 5', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75674124, end_position_on_the_genomic_accession=75717488, orientation='minus', exon_count=16, OMIM=[617880], no_hdr0=''),
    134391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134391, CurrentID=0, Status='live', Symbol='GPR151', Aliases=['GALR4', 'GALRL', 'GPCR', 'GPCR-2037', 'PGR7'], description='G protein-coupled receptor 151', other_designations='G-protein coupled receptor 151|G-protein coupled receptor PGR7|galanin receptor 4|galanin-receptor-like protein', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146513144, end_position_on_the_genomic_accession=146516190, orientation='minus', exon_count=1, OMIM=[618487], no_hdr0=''),
    134429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134429, CurrentID=0, Status='live', Symbol='STARD4', Aliases=[], description='StAR related lipid transfer domain containing 4', other_designations='stAR-related lipid transfer protein 4|START domain containing 4, sterol regulated|START domain-containing protein 4|StAR-related lipid transfer (START) domain containing 4', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=111491422, end_position_on_the_genomic_accession=111512567, orientation='minus', exon_count=8, OMIM=[607049], no_hdr0=''),
    134430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134430, CurrentID=0, Status='live', Symbol='WDR36', Aliases=['GLC1G', 'TA-WDRP', 'TAWDRP', 'UTP21'], description='WD repeat domain 36', other_designations='WD repeat-containing protein 36|T-cell activation WD repeat protein|T-cell activation WD repeat-containing protein', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=111092348, end_position_on_the_genomic_accession=111130502, orientation='plus', exon_count=23, OMIM=[609669], no_hdr0=''),
    134492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134492, CurrentID=0, Status='live', Symbol='NUDCD2', Aliases=['NudCL2'], description='NudC domain containing 2', other_designations='nudC domain-containing protein 2|NudC-like protein 2', map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=163446526, end_position_on_the_genomic_accession=163460102, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    134510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134510, CurrentID=0, Status='live', Symbol='UBLCP1', Aliases=['CPUB1'], description='ubiquitin like domain containing CTD phosphatase 1', other_designations='ubiquitin-like domain-containing CTD phosphatase 1|CTD phosphatase-like with ubiquitin domain 1|CTD-like phosphatase domain-containing protein|nuclear proteasome inhibitor UBLCP1', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=159263290, end_position_on_the_genomic_accession=159286036, orientation='plus', exon_count=11, OMIM=[609867], no_hdr0=''),
    134526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134526, CurrentID=0, Status='live', Symbol='ACOT12', Aliases=['CACH-1', 'Cach', 'STARD15', 'THEAL'], description='acyl-CoA thioesterase 12', other_designations='acetyl-coenzyme A thioesterase|START domain-containing protein 15|StAR-related lipid transfer (START) domain containing 15|acyl-CoA thioester hydrolase 12|acyl-coenzyme A thioesterase 12|cytoplasmic acetyl-CoA hydrolase 1|cytosolic acetyl-CoA hydrolase|hCACH-1', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=81309045, end_position_on_the_genomic_accession=81394174, orientation='minus', exon_count=18, OMIM=[614315], no_hdr0=''),
    134548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134548, CurrentID=0, Status='live', Symbol='SOWAHA', Aliases=['ANKRD43'], description='sosondowah ankyrin repeat domain family member A', other_designations='ankyrin repeat domain-containing protein SOWAHA|ankyrin repeat domain-containing protein 43|protein sosondowah homolog A', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132813302, end_position_on_the_genomic_accession=132816786, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    134549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134549, CurrentID=0, Status='live', Symbol='SHROOM1', Aliases=['APXL2'], description='shroom family member 1', other_designations='protein Shroom1|apical protein 2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132822141, end_position_on_the_genomic_accession=132831627, orientation='minus', exon_count=11, OMIM=[611179], no_hdr0=''),
    134553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134553, CurrentID=0, Status='live', Symbol='C5orf24', Aliases=[], description='chromosome 5 open reading frame 24', other_designations='UPF0461 protein C5orf24', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134833603, end_position_on_the_genomic_accession=134859735, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    134637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134637, CurrentID=0, Status='live', Symbol='ADAT2', Aliases=['DEADC1', 'TAD2', 'dJ20N2', 'dJ20N2.1'], description='adenosine deaminase tRNA specific 2', other_designations='tRNA-specific adenosine deaminase 2|adenosine deaminase, tRNA-specific 2, TAD2 homolog|deaminase domain containing 1|deaminase domain-containing protein 1|tRNA-specific adenosine deaminase 2 homolog|tRNA-specific adenosine-34 deaminase subunit ADAT2', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143422832, end_position_on_the_genomic_accession=143450750, orientation='minus', exon_count=10, OMIM=[615388], no_hdr0=''),
    134701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134701, CurrentID=0, Status='live', Symbol='RIPPLY2', Aliases=['C6orf159', 'SCDO6', 'dJ237I15.1'], description='ripply transcriptional repressor 2', other_designations='protein ripply2|ripply2 homolog', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83853360, end_position_on_the_genomic_accession=83857515, orientation='plus', exon_count=4, OMIM=[609891], no_hdr0=''),
    134728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134728, CurrentID=0, Status='live', Symbol='IRAK1BP1', Aliases=['AIP70', 'SIMPL'], description='interleukin 1 receptor associated kinase 1 binding protein 1', other_designations='interleukin-1 receptor-associated kinase 1-binding protein 1|ActA binding protein 3|IRAK1-binding protein 1', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=78867486, end_position_on_the_genomic_accession=78979411, orientation='plus', exon_count=8, OMIM=[615375], no_hdr0=''),
    134829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134829, CurrentID=0, Status='live', Symbol='CLVS2', Aliases=['C6orf212', 'C6orf213', 'RLBP1L2', 'bA160A10.4'], description='clavesin 2', other_designations='clavesin-2|clathrin vesicle-associated Sec14 protein 2|retinaldehyde binding protein 1-like 2', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=122996235, end_position_on_the_genomic_accession=123072925, orientation='plus', exon_count=6, OMIM=[616945], no_hdr0=''),
    134860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134860, CurrentID=0, Status='live', Symbol='TAAR9', Aliases=['TA3', 'TAR3', 'TAR9', 'TRAR3'], description='trace amine associated receptor 9', other_designations='trace amine-associated receptor 9|trace amine receptor 3|trace amine receptor 9', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132538288, end_position_on_the_genomic_accession=132539336, orientation='plus', exon_count=1, OMIM=[608282], no_hdr0=''),
    134864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134864, CurrentID=0, Status='live', Symbol='TAAR1', Aliases=['TA1', 'TAR1', 'TRAR1'], description='trace amine associated receptor 1', other_designations='trace amine-associated receptor 1|trace amine receptor 1', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132643312, end_position_on_the_genomic_accession=132659182, orientation='minus', exon_count=2, OMIM=[609333], no_hdr0=''),
    134957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=134957, CurrentID=0, Status='live', Symbol='STXBP5', Aliases=['LGL3', 'LLGL3', 'Nbla04300'], description='syntaxin binding protein 5', other_designations='syntaxin-binding protein 5|lethal(2) giant larvae protein homolog 3|putative protein product of Nbla04300|tomosyn|tomosyn-1', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=147204184, end_position_on_the_genomic_accession=147390473, orientation='plus', exon_count=34, OMIM=[604586], no_hdr0=''),
    135112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135112, CurrentID=0, Status='live', Symbol='NCOA7', Aliases=['ERAP140', 'ESNA1-AS', 'Nbla00052', 'Nbla10993', 'TLDC4', 'dJ187J11.3', 'NCOA7'], description='nuclear receptor coactivator 7', other_designations='nuclear receptor coactivator 7|140 kDa estrogen receptor-associated protein|TBC/LysM-associated domain containing 4|estrogen nuclear receptor coactivator 1|estrogen receptor associated protein 140 kDa|putative protein product of Nbla00052|putative protein product of Nbla10993', map_location='6q22.31-q22.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125780943, end_position_on_the_genomic_accession=125932034, orientation='plus', exon_count=23, OMIM=[609752], no_hdr0=''),
    135114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135114, CurrentID=0, Status='live', Symbol='HINT3', Aliases=['HINT4'], description='histidine triad nucleotide binding protein 3', other_designations='histidine triad nucleotide-binding protein 3|HINT-3|HIT-like protein', map_location='6q22.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=125956770, end_position_on_the_genomic_accession=125980244, orientation='plus', exon_count=5, OMIM=[609998], no_hdr0=''),
    135138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135138, CurrentID=0, Status='live', Symbol='PACRG', Aliases=['GLUP', 'HAK0057712.1', 'PARK2CRG', 'PACRG'], description='parkin coregulated', other_designations='parkin coregulated gene protein|PARK2 co-regulated|PARK2 coregulated|molecular chaperone/chaperonin-binding protein|parkin co-regulated gene protein', map_location='6q26', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=162726870, end_position_on_the_genomic_accession=163315500, orientation='plus', exon_count=23, OMIM=[608427], no_hdr0=''),
    135152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135152, CurrentID=0, Status='live', Symbol='B3GAT2', Aliases=['GLCATS'], description='beta-1,3-glucuronyltransferase 2', other_designations='galactosylgalactosylxylosylprotein 3-beta-glucuronosyltransferase 2|UDP-glucuronosyltransferase S|UDP-glucuronyltransferase S|glcAT-D|glucuronosyltransferase S|uridine diphosphate glucuronic acid:acceptor glucuronosyltransferase', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=70856679, end_position_on_the_genomic_accession=70957060, orientation='minus', exon_count=4, OMIM=[607497], no_hdr0=''),
    135154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135154, CurrentID=0, Status='live', Symbol='SDHAF4', Aliases=['C6orf57', 'Sdh8'], description='succinate dehydrogenase complex assembly factor 4', other_designations='succinate dehydrogenase assembly factor 4, mitochondrial|SDH assembly factor 4|UPF0369 protein C6orf57', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=70566930, end_position_on_the_genomic_accession=70589569, orientation='plus', exon_count=3, OMIM=[619198], no_hdr0=''),
    135228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135228, CurrentID=0, Status='live', Symbol='CD109', Aliases=['CPAMD7', 'p180', 'r150'], description='CD109 molecule', other_designations='CD109 antigen|150 kDa TGF-beta-1-binding protein|C3 and PZP-like alpha-2-macroglobulin domain-containing protein 7|Gov platelet alloantigens|activated T-cell marker CD109|platelet-specific Gov antigen', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73696203, end_position_on_the_genomic_accession=73828313, orientation='plus', exon_count=33, OMIM=[608859], no_hdr0=''),
    135250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135250, CurrentID=0, Status='live', Symbol='RAET1E', Aliases=['LETAL', 'N2DL-4', 'NKG2DL42', 'RL-4', 'ULBP4', 'bA350J20.7', 'RAET1E'], description='retinoic acid early transcript 1E', other_designations='retinoic acid early transcript 1E|NKG2D ligand 4|RAE-1-like transcript 4|UL16-binding protein 4|lymphocyte effector toxicity activation ligand', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149864399, end_position_on_the_genomic_accession=149898353, orientation='minus', exon_count=10, OMIM=[609243], no_hdr0=''),
    135293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135293, CurrentID=0, Status='live', Symbol='PM20D2', Aliases=['ACY1L2'], description='peptidase M20 domain containing 2', other_designations='peptidase M20 domain-containing protein 2|I(2)-alanyl-lysine dipeptidase|aminoacylase-1-like protein 2|beta-alanyl-lysine dipeptidase', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89094818, end_position_on_the_genomic_accession=89165565, orientation='plus', exon_count=13, OMIM=[615913], no_hdr0=''),
    135295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135295, CurrentID=0, Status='live', Symbol='SRSF12', Aliases=['SFRS13B', 'SFRS19', 'SRrp35'], description='serine and arginine rich splicing factor 12', other_designations='serine/arginine-rich splicing factor 12|35 kDa SR repressor protein|SR splicing factor 12|serine-arginine repressor protein (35 kDa)|splicing factor, arginine/serine-rich 13B|splicing factor, arginine/serine-rich 19', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=89095957, end_position_on_the_genomic_accession=89118071, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    135398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135398, CurrentID=0, Status='live', Symbol='C6orf141', Aliases=[], description='chromosome 6 open reading frame 141', other_designations='uncharacterized protein C6orf141', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49550644, end_position_on_the_genomic_accession=49561916, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    135458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135458, CurrentID=0, Status='live', Symbol='HUS1B', Aliases=[], description='HUS1 checkpoint clamp component B', other_designations='checkpoint protein HUS1B|HUS1 checkpoint homolog b|hHUS1B', map_location='6p25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=655939, end_position_on_the_genomic_accession=657100, orientation='minus', exon_count=1, OMIM=[609713], no_hdr0=''),
    135644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135644, CurrentID=0, Status='live', Symbol='TRIM40', Aliases=['RNF35'], description='tripartite motif containing 40', other_designations='E3 ubiquitin ligase TRIM40|RING finger protein 35|probable E3 NEDD8-protein ligase|ring finger RNF35', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30135998, end_position_on_the_genomic_accession=30148773, orientation='plus', exon_count=6, OMIM=[616976], no_hdr0=''),
    135656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135656, CurrentID=0, Status='live', Symbol='MUCL3', Aliases=['C6orf37', 'DPCR1', 'PBLT'], description='mucin like 3', other_designations='mucin-like protein 3|diffuse panbronchiolitis critical region 1|diffuse panbronchiolitis critical region protein 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30940973, end_position_on_the_genomic_accession=30954221, orientation='plus', exon_count=3, OMIM=[613928], no_hdr0=''),
    135886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135886, CurrentID=0, Status='live', Symbol='TMEM270', Aliases=['WBSCR28'], description='transmembrane protein 270', other_designations='transmembrane protein 270|Williams-Beuren syndrome chromosome region 28|Williams-Beuren syndrome critical region 28|williams-Beuren syndrome chromosomal region 28 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73860848, end_position_on_the_genomic_accession=73865892, orientation='plus', exon_count=5, OMIM=[612547], no_hdr0=''),
    135892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135892, CurrentID=0, Status='live', Symbol='TRIM50', Aliases=['TRIM50A'], description='tripartite motif containing 50', other_designations='E3 ubiquitin-protein ligase TRIM50|RING-type E3 ubiquitin transferase TRIM50|tripartite motif-containing 50A|tripartite motif-containing protein 50', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73312536, end_position_on_the_genomic_accession=73328082, orientation='minus', exon_count=8, OMIM=[612548], no_hdr0=''),
    135924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135924, CurrentID=0, Status='live', Symbol='OR9A2', Aliases=[], description='olfactory receptor family 9 subfamily A member 2', other_designations='olfactory receptor 9A2|olfactory receptor OR7-2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143026200, end_position_on_the_genomic_accession=143027132, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    135927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135927, CurrentID=0, Status='live', Symbol='LLCFC1', Aliases=['C7orf34', 'SOF1', 'ctm-1'], description='LLLL and CFNLAS motif containing 1', other_designations='sperm-egg fusion protein LLCFC1|LLLL and CFNLAS motif-containing protein 1|MSSP-binding protein CTM-1|sperm-oocyte fusion required protein 1|uncharacterized protein C7orf34', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142939484, end_position_on_the_genomic_accession=142940868, orientation='plus', exon_count=3, OMIM=[618946], no_hdr0=''),
    135932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135932, CurrentID=0, Status='live', Symbol='TMEM139', Aliases=[], description='transmembrane protein 139', other_designations='transmembrane protein 139', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143284899, end_position_on_the_genomic_accession=143288049, orientation='plus', exon_count=5, OMIM=[616524], no_hdr0=''),
    135935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135935, CurrentID=0, Status='live', Symbol='NOBOX', Aliases=['OG-2', 'OG2', 'OG2X', 'POF5', 'TCAG_12042'], description='NOBOX oogenesis homeobox', other_designations='homeobox protein NOBOX|newborn ovary homeobox-encoding', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144396805, end_position_on_the_genomic_accession=144410422, orientation='minus', exon_count=10, OMIM=[610934], no_hdr0=''),
    135941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135941, CurrentID=0, Status='live', Symbol='OR2A14', Aliases=['OR2A14P', 'OR2A6', 'OST182'], description='olfactory receptor family 2 subfamily A member 14', other_designations='olfactory receptor 2A14|olfactory receptor 2A6|olfactory receptor OR7-12|olfactory receptor, family 2, subfamily A, member 14 pseudogene|olfactory receptor, family 2, subfamily A, member 6', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144123176, end_position_on_the_genomic_accession=144131188, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    135946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135946, CurrentID=0, Status='live', Symbol='OR6B1', Aliases=['OR7-3', 'OR7-9'], description='olfactory receptor family 6 subfamily B member 1', other_designations='olfactory receptor 6B1|olfactory receptor 7-3|olfactory receptor OR7-9', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144000320, end_position_on_the_genomic_accession=144008793, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    135948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=135948, CurrentID=0, Status='live', Symbol='OR2F2', Aliases=['OR7-1'], description='olfactory receptor family 2 subfamily F member 2', other_designations='olfactory receptor 2F2|olfactory receptor 7-1|olfactory receptor OR7-6', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143935233, end_position_on_the_genomic_accession=143936186, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    136051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136051, CurrentID=0, Status='live', Symbol='ZNF786', Aliases=[], description='zinc finger protein 786', other_designations='zinc finger protein 786', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149069641, end_position_on_the_genomic_accession=149090718, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    136227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136227, CurrentID=0, Status='live', Symbol='COL26A1', Aliases=['EMI6', 'EMID2', 'EMU2', 'SH2B'], description='collagen type XXVI alpha 1 chain', other_designations='collagen alpha-1(XXVI) chain|EMI domain containing 2|collagen, type XXVI, alpha 1|emilin and multimerin domain-containing protein 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101362369, end_position_on_the_genomic_accession=101559024, orientation='plus', exon_count=14, OMIM=[608927], no_hdr0=''),
    136242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136242, CurrentID=0, Status='live', Symbol='PRSS37', Aliases=['TRYX2'], description='serine protease 37', other_designations='probable inactive serine protease 37|Peptidase S1 domain-containing protein LOC136242|probable inactive trypsin-X2|protease, serine 37', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141836278, end_position_on_the_genomic_accession=141849725, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    136259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136259, CurrentID=0, Status='live', Symbol='KLF14', Aliases=['BTEB5'], description='Kruppel like factor 14', other_designations='Krueppel-like factor 14|BTE-binding protein 5|basic transcription element-binding protein 5|transcription factor BTEB5', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130730697, end_position_on_the_genomic_accession=130734207, orientation='minus', exon_count=1, OMIM=[609393], no_hdr0=''),
    136263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136263, CurrentID=0, Status='live', Symbol='SSMEM1', Aliases=['C7orf45'], description='serine rich single-pass membrane protein 1', other_designations='serine-rich single-pass membrane protein 1', map_location='7q32.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=130205399, end_position_on_the_genomic_accession=130216869, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    136288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136288, CurrentID=0, Status='live', Symbol='C7orf57', Aliases=[], description='chromosome 7 open reading frame 57', other_designations='uncharacterized protein C7orf57', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=48035522, end_position_on_the_genomic_accession=48061297, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    136306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136306, CurrentID=0, Status='live', Symbol='SVOPL', Aliases=[], description='SVOP like', other_designations='putative transporter SVOPL|SV2 related protein homolog-like', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138591689, end_position_on_the_genomic_accession=138701362, orientation='minus', exon_count=19, OMIM=[611700], no_hdr0=''),
    136319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136319, CurrentID=0, Status='live', Symbol='MTPN', Aliases=['GCDP', 'V-1'], description='myotrophin', other_designations='myotrophin|granule cell differentiation protein|protein V-1', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135926760, end_position_on_the_genomic_accession=135977359, orientation='minus', exon_count=4, OMIM=[606484], no_hdr0=''),
    136332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136332, CurrentID=0, Status='live', Symbol='LRGUK', Aliases=['CFAP246'], description='leucine rich repeats and guanylate kinase domain containing', other_designations='leucine-rich repeat and guanylate kinase domain-containing protein', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134127340, end_position_on_the_genomic_accession=134282475, orientation='plus', exon_count=26, OMIM=[616478], no_hdr0=''),
    136371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136371, CurrentID=0, Status='live', Symbol='ASB10', Aliases=['GLC1F'], description='ankyrin repeat and SOCS box containing 10', other_designations='ankyrin repeat and SOCS box protein 10', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151175698, end_position_on_the_genomic_accession=151187792, orientation='minus', exon_count=7, OMIM=[615054], no_hdr0=''),
    136541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136541, CurrentID=0, Status='live', Symbol='PRSS58', Aliases=['PRSS1', 'TRY1', 'TRYX3', 'UNQ2540'], description='serine protease 58', other_designations='serine protease 58|protease, serine 58|trypsin-X3', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142252143, end_position_on_the_genomic_accession=142258058, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    136647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136647, CurrentID=0, Status='live', Symbol='MPLKIP', Aliases=['ABHS', 'C7orf11', 'ORF20', 'TTD4'], description='M-phase specific PLK1 interacting protein', other_designations='M-phase-specific PLK1-interacting protein|Russell-Silver syndrome region|TTD non-photosensitive 1 protein', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=40126027, end_position_on_the_genomic_accession=40134622, orientation='minus', exon_count=2, OMIM=[609188], no_hdr0=''),
    136853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136853, CurrentID=0, Status='live', Symbol='SSC4D', Aliases=['S4D-SRCRB', 'SRCRB-S4D', 'SRCRB4D'], description='scavenger receptor cysteine rich family member with 4 domains', other_designations='scavenger receptor cysteine-rich domain-containing group B protein|SRCRB4D|four scavenger receptor cysteine-rich domains-containing protein|scavenger receptor cysteine rich domain containing, group B (4 domains)|scavenger receptor cysteine rich family, 4 domains|scavenger receptor cysteine-rich protein SRCRB-S4D', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76389337, end_position_on_the_genomic_accession=76410025, orientation='minus', exon_count=12, OMIM=[607639], no_hdr0=''),
    136895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136895, CurrentID=0, Status='live', Symbol='C7orf31', Aliases=[], description='chromosome 7 open reading frame 31', other_designations='uncharacterized protein C7orf31', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=25134692, end_position_on_the_genomic_accession=25180354, orientation='minus', exon_count=11, OMIM=[616071], no_hdr0=''),
    136991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=136991, CurrentID=0, Status='live', Symbol='ASZ1', Aliases=['ALP1', 'ANKL1', 'C7orf7', 'CT1.19', 'GASZ', 'Orf3'], description='ankyrin repeat, SAM and basic leucine zipper domain containing 1', other_designations='ankyrin repeat, SAM and basic leucine zipper domain-containing protein 1|ankyrin-like 1|ankyrin-like protein 1|germ cell-specific ankyrin, SAM and basic leucine zipper domain-containing protein', map_location='7q31.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=117363222, end_position_on_the_genomic_accession=117427493, orientation='minus', exon_count=13, OMIM=[605797], no_hdr0=''),
    137075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137075, CurrentID=0, Status='live', Symbol='CLDN23', Aliases=['CLDNL', 'hCG1646163'], description='claudin 23', other_designations='claudin-23|2310014B08Rik', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=8701937, end_position_on_the_genomic_accession=8704096, orientation='plus', exon_count=1, OMIM=[609203], no_hdr0=''),
    137209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137209, CurrentID=0, Status='live', Symbol='ZNF572', Aliases=[], description='zinc finger protein 572', other_designations='zinc finger protein 572', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124973295, end_position_on_the_genomic_accession=124979389, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    137362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137362, CurrentID=0, Status='live', Symbol='GOT1L1', Aliases=[], description='glutamic-oxaloacetic transaminase 1 like 1', other_designations='putative aspartate aminotransferase, cytoplasmic 2|glutamate oxaloacetate transaminase 1-like protein 1|transaminase A-like protein 1', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=37933548, end_position_on_the_genomic_accession=37940503, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    137392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137392, CurrentID=0, Status='live', Symbol='CIBAR1', Aliases=['BARMR1', 'FAM92A', 'FAM92A1', 'PAPA9'], description='CBY1 interacting BAR domain containing 1', other_designations='protein FAM92A|family with sequence similarity 92 member A|family with sequence similarity 92 member A1|protein FAM92A1', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=93700550, end_position_on_the_genomic_accession=93731527, orientation='plus', exon_count=15, OMIM=[617273], no_hdr0=''),
    137492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137492, CurrentID=0, Status='live', Symbol='VPS37A', Aliases=['HCRP1', 'PQBP2', 'SPG53'], description='VPS37A subunit of ESCRT-I', other_designations='vacuolar protein sorting-associated protein 37A|ESCRT-I complex subunit VPS37A|VPS37A, ESCRT-I subunit|hepatocellular carcinoma-related protein 1|polyglutamine binding protein 2|vacuolar protein sorting 37 homolog A', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17246903, end_position_on_the_genomic_accession=17333455, orientation='plus', exon_count=15, OMIM=[609927], no_hdr0=''),
    137682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137682, CurrentID=0, Status='live', Symbol='NDUFAF6', Aliases=['C8orf38', 'FRTS5', 'MC1DN17'], description='NADH:ubiquinone oxidoreductase complex assembly factor 6', other_designations='NADH dehydrogenase (ubiquinone) complex I, assembly factor 6|UPF0551 protein C8orf38, mitochondrial|putative phytoene synthase', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94895799, end_position_on_the_genomic_accession=95118496, orientation='plus', exon_count=27, OMIM=[612392], no_hdr0=''),
    137695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137695, CurrentID=0, Status='live', Symbol='TMEM68', Aliases=[], description='transmembrane protein 68', other_designations='transmembrane protein 68', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=55738758, end_position_on_the_genomic_accession=55773378, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    137735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137735, CurrentID=0, Status='live', Symbol='ABRA', Aliases=['STARS'], description='actin binding Rho activating protein', other_designations='actin-binding Rho-activating protein|striated muscle activator of Rho-dependent signaling', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=106759483, end_position_on_the_genomic_accession=106809073, orientation='minus', exon_count=4, OMIM=[609747], no_hdr0=''),
    137797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137797, CurrentID=0, Status='live', Symbol='LYPD2', Aliases=['LYPDC2', 'UNQ430'], description='LY6/PLAUR domain containing 2', other_designations='ly6/PLAUR domain-containing protein 2|RGTR430', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142750150, end_position_on_the_genomic_accession=142752532, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    137814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137814, CurrentID=0, Status='live', Symbol='NKX2-6', Aliases=['CSX2', 'CTHM', 'NKX2F', 'NKX4-2'], description='NK2 homeobox 6', other_designations='homeobox protein Nkx-2.6|NK2 transcription factor related, locus 6|homeobox protein NK2 homolog F|homeobox protein NKX2.6|tinman homolog|tinman paralog', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23701740, end_position_on_the_genomic_accession=23706756, orientation='minus', exon_count=2, OMIM=[611770], no_hdr0=''),
    137835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137835, CurrentID=0, Status='live', Symbol='TMEM71', Aliases=[], description='transmembrane protein 71', other_designations='transmembrane protein 71', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132705839, end_position_on_the_genomic_accession=132775999, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    137868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137868, CurrentID=0, Status='live', Symbol='SGCZ', Aliases=['ZSG1'], description='sarcoglycan zeta', other_designations='zeta-sarcoglycan|zeta-SG', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=14084845, end_position_on_the_genomic_accession=15238431, orientation='minus', exon_count=8, OMIM=[608113], no_hdr0=''),
    137872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137872, CurrentID=0, Status='live', Symbol='ADHFE1', Aliases=['ADH8', 'HMFT2263', 'HOT'], description='alcohol dehydrogenase iron containing 1', other_designations='hydroxyacid-oxoacid transhydrogenase, mitochondrial|Fe-containing alcohol dehydrogenase 1|alcohol dehydrogenase 8|alcohol dehydrogenase iron-containing protein 1', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66432504, end_position_on_the_genomic_accession=66468907, orientation='plus', exon_count=14, OMIM=[611083], no_hdr0=''),
    137886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137886, CurrentID=0, Status='live', Symbol='UBXN2B', Aliases=['p37'], description='UBX domain protein 2B', other_designations='UBX domain-containing protein 2B|NSFL1 cofactor p37|p97 cofactor p37', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=58411361, end_position_on_the_genomic_accession=58451501, orientation='plus', exon_count=9, OMIM=[610686], no_hdr0=''),
    137902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137902, CurrentID=0, Status='live', Symbol='PXDNL', Aliases=['PMR1', 'PRM1', 'VPO2'], description='peroxidasin like', other_designations='peroxidasin-like protein|cardiac peroxidase|cardiovascular peroxidase 2|peroxidasin homolog-like|polysomal ribonuclease 1 homolog|vascular peroxidase 2', map_location='8q11.22-q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=51319575, end_position_on_the_genomic_accession=51809445, orientation='minus', exon_count=25, OMIM=[615904], no_hdr0=''),
    137964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137964, CurrentID=0, Status='live', Symbol='GPAT4', Aliases=['1-AGPAT 6', 'AGPAT6', 'LPAAT-zeta', 'LPAATZ', 'TSARG7'], description='glycerol-3-phosphate acyltransferase 4', other_designations='glycerol-3-phosphate acyltransferase 4|1-AGP acyltransferase 6|1-acyl-sn-glycerol-3-phosphate acyltransferase zeta|1-acylglycerol-3-phosphate O-acyltransferase 6 (lysophosphatidic acid acyltransferase, zeta)|glycerol-3-phosphate acyltransferase 6|lysophosphatidic acid acyltransferase zeta|testis spermatogenesis apoptosis-related protein 7', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41578190, end_position_on_the_genomic_accession=41625001, orientation='plus', exon_count=16, OMIM=[608143], no_hdr0=''),
    137970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137970, CurrentID=0, Status='live', Symbol='UNC5D', Aliases=['PRO34692', 'Unc5h4'], description='unc-5 netrin receptor D', other_designations='netrin receptor UNC5D|netrin receptor Unc5h4|protein unc-5 homolog 4|protein unc-5 homolog D|unc-5 homolog 4|unc-5 homolog D', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=35235475, end_position_on_the_genomic_accession=35796550, orientation='plus', exon_count=21, OMIM=[616466], no_hdr0=''),
    137994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=137994, CurrentID=0, Status='live', Symbol='LETM2', Aliases=['SLC55A2'], description='leucine zipper and EF-hand containing transmembrane protein 2', other_designations='LETM1 domain-containing protein LETM2, mitochondrial|LETM1 and EF-hand domain-containing protein 2|leucine zipper-EF-hand containing transmembrane protein 1-like protein|leucine zipper-EF-hand containing transmembrane protein 2', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38382505, end_position_on_the_genomic_accession=38409527, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    138009 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138009, CurrentID=0, Status='live', Symbol='DCAF4L2', Aliases=['WDR21C'], description='DDB1 and CUL4 associated factor 4 like 2', other_designations='DDB1- and CUL4-associated factor 4-like protein 2|WD repeat domain 21C|WD repeat-containing protein 21C', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=87870747, end_position_on_the_genomic_accession=87874015, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    138046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138046, CurrentID=0, Status='live', Symbol='RALYL', Aliases=['HNRPCL3'], description='RALY RNA binding protein like', other_designations='RNA-binding Raly-like protein|heterogeneous nuclear ribonucleoprotein C-like 3|hnRNP core protein C-like 3', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=84182765, end_position_on_the_genomic_accession=84921844, orientation='plus', exon_count=18, OMIM=[614648], no_hdr0=''),
    138050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138050, CurrentID=0, Status='live', Symbol='HGSNAT', Aliases=['HGNAT', 'MPS3C', 'RP73', 'TMEM76'], description='heparan-alpha-glucosaminide N-acetyltransferase', other_designations='heparan-alpha-glucosaminide N-acetyltransferase|transmembrane protein 76', map_location='8p11.21-p11.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=43140449, end_position_on_the_genomic_accession=43202855, orientation='plus', exon_count=20, OMIM=[610453], no_hdr0=''),
    138065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138065, CurrentID=0, Status='live', Symbol='RNF183', Aliases=[], description='ring finger protein 183', other_designations='E3 ubiquitin-protein ligase RNF183|probable E3 ubiquitin-protein ligase RNF183', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113297093, end_position_on_the_genomic_accession=113303877, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    138151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138151, CurrentID=0, Status='live', Symbol='NACC2', Aliases=['BEND9', 'BTBD14', 'BTBD14A', 'BTBD31', 'NAC-2', 'RBB'], description='NACC family member 2', other_designations='nucleus accumbens-associated protein 2|BEN domain containing 9|BTB (POZ) domain containing 14A|BTB/POZ domain-containing protein 14A|NACC family member 2, BEN and BTB (POZ) domain containing|repressor with BTB domain and BEN domain|transcription repressor with a BTB domain and a BEN domain', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136006537, end_position_on_the_genomic_accession=136095289, orientation='minus', exon_count=7, OMIM=[615786], no_hdr0=''),
    138162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138162, CurrentID=0, Status='live', Symbol='C9orf116', Aliases=['PIERCE1', 'RbEST47'], description='chromosome 9 open reading frame 116', other_designations="UPF0691 protein C9orf116|p53-induced expression 1 in Rb-/- cells|p53-induced expression 1 in Rba^'/a^' cells|p53-induced expression in RB-null cells protein 1|pierce 1", map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135495181, end_position_on_the_genomic_accession=135499869, orientation='minus', exon_count=3, OMIM=[614502], no_hdr0=''),
    138199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138199, CurrentID=0, Status='live', Symbol='CARNMT1', Aliases=['C9orf41', 'UPF0586'], description='carnosine N-methyltransferase 1', other_designations='carnosine N-methyltransferase|UPF0586 protein C9orf41', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=74980790, end_position_on_the_genomic_accession=75028456, orientation='minus', exon_count=13, OMIM=[616552], no_hdr0=''),
    138240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138240, CurrentID=0, Status='live', Symbol='C9orf57', Aliases=[], description='chromosome 9 open reading frame 57', other_designations='uncharacterized protein C9orf57', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=72051376, end_position_on_the_genomic_accession=72060613, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    138241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138241, CurrentID=0, Status='live', Symbol='C9orf85', Aliases=[], description='chromosome 9 open reading frame 85', other_designations='uncharacterized protein C9orf85', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=71911639, end_position_on_the_genomic_accession=71986058, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    138255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138255, CurrentID=0, Status='live', Symbol='C9orf135', Aliases=[], description='chromosome 9 open reading frame 135', other_designations='protein C9orf135|uncharacterized protein C9orf135', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69820804, end_position_on_the_genomic_accession=69906237, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    138307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138307, CurrentID=0, Status='live', Symbol='LCN8', Aliases=['EP17', 'LCN5'], description='lipocalin 8', other_designations='epididymal-specific lipocalin-8|epididymis secretory sperm binding protein|lipocalin 5', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136754386, end_position_on_the_genomic_accession=136758551, orientation='minus', exon_count=8, OMIM=[612902], no_hdr0=''),
    138311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138311, CurrentID=0, Status='live', Symbol='DIPK1B', Aliases=['C9orf136', 'FAM69B', 'pp6977'], description='divergent protein kinase domain 1B', other_designations='divergent protein kinase domain 1B|family with sequence similarity 69 member B|protein FAM69B', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136712572, end_position_on_the_genomic_accession=136724742, orientation='plus', exon_count=7, OMIM=[614543], no_hdr0=''),
    138428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138428, CurrentID=0, Status='live', Symbol='PTRH1', Aliases=['C9orf115', 'PTH1'], description='peptidyl-tRNA hydrolase 1 homolog', other_designations='probable peptidyl-tRNA hydrolase|PTH', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127691923, end_position_on_the_genomic_accession=127715676, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    138429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138429, CurrentID=0, Status='live', Symbol='PIP5KL1', Aliases=['PIPKH'], description='phosphatidylinositol-4-phosphate 5-kinase like 1', other_designations='phosphatidylinositol 4-phosphate 5-kinase-like protein 1|PI(4)P 5-kinase-like protein 1|phosphatidylinositol phosphate kinase homolog|ptdIns(4)P-5-kinase-like protein 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127920881, end_position_on_the_genomic_accession=127931958, orientation='minus', exon_count=10, OMIM=[612865], no_hdr0=''),
    138474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138474, CurrentID=0, Status='live', Symbol='TAF1L', Aliases=['TAF(II)210', 'TAF2A2'], description='TATA-box binding protein associated factor 1 like', other_designations='transcription initiation factor TFIID subunit 1-like|TAF1 RNA polymerase II, TATA box binding protein (TBP)-associated factor, 210kDa-like|TBP-associated factor 1-like|TBP-associated factor 210 kDa|TBP-associated factor RNA polymerase 1-like|transcription initiation factor TFIID 210 kDa subunit', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32629454, end_position_on_the_genomic_accession=32635669, orientation='minus', exon_count=1, OMIM=[607798], no_hdr0=''),
    138639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138639, CurrentID=0, Status='live', Symbol='PTPDC1', Aliases=['PTP9Q22'], description='protein tyrosine phosphatase domain containing 1', other_designations='protein tyrosine phosphatase domain-containing protein 1|protein tyrosine phosphatase PTP9Q22', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94029031, end_position_on_the_genomic_accession=94109856, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    138715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138715, CurrentID=0, Status='live', Symbol='ARID3C', Aliases=[], description='AT-rich interaction domain 3C', other_designations='AT-rich interactive domain-containing protein 3C|ARID domain-containing protein 3C|AT rich interactive domain 3C (BRIGHT-like)|Brightlike', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34621049, end_position_on_the_genomic_accession=34629066, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    138716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138716, CurrentID=0, Status='live', Symbol='RPP25L', Aliases=['C9orf23', 'bA296L22.5'], description='ribonuclease P/MRP subunit p25 like', other_designations='ribonuclease P protein subunit p25-like protein|RNase P protein subunit-like p25|alba-like protein C9orf23|ribonuclease P/MRP 25kDa subunit-like|rpp25-like protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34610495, end_position_on_the_genomic_accession=34612097, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    138724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138724, CurrentID=0, Status='live', Symbol='C9orf131', Aliases=[], description='chromosome 9 open reading frame 131', other_designations='uncharacterized protein C9orf131', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35041095, end_position_on_the_genomic_accession=35045986, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    138799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138799, CurrentID=0, Status='live', Symbol='OR13C5', Aliases=['OR9-11'], description='olfactory receptor family 13 subfamily C member 5', other_designations='olfactory receptor 13C5|olfactory receptor OR9-11', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104598457, end_position_on_the_genomic_accession=104599413, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    138802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138802, CurrentID=0, Status='live', Symbol='OR13C8', Aliases=['OR37H', 'OR9-10'], description='olfactory receptor family 13 subfamily C member 8', other_designations='olfactory receptor 13C8|olfactory receptor OR9-10 pseudogene', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104569168, end_position_on_the_genomic_accession=104570130, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    138803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138803, CurrentID=0, Status='live', Symbol='OR13C3', Aliases=['OR37G', 'OR9-8'], description='olfactory receptor family 13 subfamily C member 3', other_designations='olfactory receptor 13C3|olfactory receptor OR9-8', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104535749, end_position_on_the_genomic_accession=104536723, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    138804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138804, CurrentID=0, Status='live', Symbol='OR13C4', Aliases=['HSHTPCRX17', 'HTPCRX17', 'OR2K1', 'OR37F', 'OR9-7'], description='olfactory receptor family 13 subfamily C member 4', other_designations='olfactory receptor 13C4|olfactory receptor OR9-7|olfactory receptor, family 2, subfamily K, member 1', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104526253, end_position_on_the_genomic_accession=104527209, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    138805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138805, CurrentID=0, Status='live', Symbol='OR13F1', Aliases=['OR9-6'], description='olfactory receptor family 13 subfamily F member 1', other_designations='olfactory receptor 13F1|olfactory receptor OR9-6', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104504263, end_position_on_the_genomic_accession=104505222, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    138881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138881, CurrentID=0, Status='live', Symbol='OR1L8', Aliases=['OR9-24'], description='olfactory receptor family 1 subfamily L member 8', other_designations='olfactory receptor 1L8|olfactory receptor OR9-24', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122546009, end_position_on_the_genomic_accession=122583384, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    138882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138882, CurrentID=0, Status='live', Symbol='OR1N2', Aliases=['OR9-23'], description='olfactory receptor family 1 subfamily N member 2', other_designations='olfactory receptor 1N2|olfactory receptor OR9-23', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122553112, end_position_on_the_genomic_accession=122554214, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    138883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=138883, CurrentID=0, Status='live', Symbol='OR1N1', Aliases=['OR1-26', 'OR1N3', 'OR9-22'], description='olfactory receptor family 1 subfamily N member 1', other_designations='olfactory receptor 1N1|olfactory receptor 1-26|olfactory receptor 1N3|olfactory receptor OR9-22|olfactory receptor, family 1, subfamily N, member 3', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122526358, end_position_on_the_genomic_accession=122527293, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    139065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139065, CurrentID=0, Status='live', Symbol='SLITRK4', Aliases=[], description='SLIT and NTRK like family member 4', other_designations='SLIT and NTRK-like protein 4|slit and trk like gene 4', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=143622790, end_position_on_the_genomic_accession=143636101, orientation='minus', exon_count=6, OMIM=[300562], no_hdr0=''),
    139067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139067, CurrentID=0, Status='live', Symbol='SPANXN3', Aliases=['CT11.8', 'SPANX-N3'], description='SPANX family member N3', other_designations='sperm protein associated with the nucleus on the X chromosome N3|cancer/testis antigen family 11, member 8|nuclear-associated protein SPAN-Xn3', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=143508735, end_position_on_the_genomic_accession=143517475, orientation='minus', exon_count=3, OMIM=[300666], no_hdr0=''),
    139081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139081, CurrentID=0, Status='live', Symbol='MAGEC3', Aliases=['CT7.2', 'HCA2', 'MAGE-C3', 'MAGEC4'], description='MAGE family member C3', other_designations='melanoma-associated antigen C3|MAGE family testis and tumor-specific protein|MAGE-C3 antigen|cancer/testis antigen 7.2|cancer/testis antigen family 7, member 2|hepatocellular carcinoma-associated antigen 2|hepatocellular carcinoma-associated protein HCA2|melanoma antigen family C, 3|melanoma antigen family C3', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141838316, end_position_on_the_genomic_accession=141898142, orientation='plus', exon_count=13, OMIM=[300469], no_hdr0=''),
    139105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139105, CurrentID=0, Status='live', Symbol='BEND2', Aliases=['CXorf20'], description='BEN domain containing 2', other_designations='BEN domain-containing protein 2', map_location='Xp22.13', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=18162931, end_position_on_the_genomic_accession=18220886, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    139135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139135, CurrentID=0, Status='live', Symbol='PASD1', Aliases=['CT63', 'CT64', 'OXTES1'], description='PAS domain containing repressor 1', other_designations='circadian clock protein PASD1|PAS domain containing 1|cancer/testis antigen 63', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151563184, end_position_on_the_genomic_accession=151676739, orientation='plus', exon_count=16, OMIM=[300993], no_hdr0=''),
    139170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139170, CurrentID=0, Status='live', Symbol='DCAF12L1', Aliases=['KIAA1892L', 'WDR40B'], description='DDB1 and CUL4 associated factor 12 like 1', other_designations='DDB1- and CUL4-associated factor 12-like protein 1|WD repeat domain 40B|WD repeat-containing protein 40B', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=126549383, end_position_on_the_genomic_accession=126552814, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    139189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139189, CurrentID=0, Status='live', Symbol='DGKK', Aliases=[], description='diacylglycerol kinase kappa', other_designations='diacylglycerol kinase kappa|142 kDa diacylglycerol kinase|DAG kinase kappa|DGK-kappa|diglyceride kinase kappa', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=50365409, end_position_on_the_genomic_accession=50470851, orientation='minus', exon_count=28, OMIM=[300837], no_hdr0=''),
    139212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139212, CurrentID=0, Status='live', Symbol='DNAAF6', Aliases=['CILD36', 'CXorf41', 'NYSAR97', 'PIH1D3', 'TWISTER'], description='dynein axonemal assembly factor 6', other_designations='dynein axonemal assembly factor 6|dynein assembly factor 6, axonemal|PIH1 domain containing 3|PIH1 domain-containing protein 3|protein PIH1D3|sarcoma antigen NY-SAR-97', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107206611, end_position_on_the_genomic_accession=107244247, orientation='plus', exon_count=8, OMIM=[300933], no_hdr0=''),
    139221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139221, CurrentID=0, Status='live', Symbol='PWWP3B', Aliases=['MUM1L1'], description='PWWP domain containing 3B', other_designations='PWWP domain-containing DNA repair factor 3B|MUM1 like 1|MUM1-like protein 1|PWWP domain-containing protein MUM1L1|melanoma associated antigen (mutated) 1-like 1|mutated melanoma-associated antigen 1-like protein 1', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=106168278, end_position_on_the_genomic_accession=106208961, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    139231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139231, CurrentID=0, Status='live', Symbol='FAM199X', Aliases=['CXorf39'], description='family with sequence similarity 199, X-linked', other_designations='protein FAM199X', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104166453, end_position_on_the_genomic_accession=104195902, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    139285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139285, CurrentID=0, Status='live', Symbol='AMER1', Aliases=['FAM123B', 'OSCS', 'WTX'], description='APC membrane recruitment protein 1', other_designations='APC membrane recruitment protein 1|RP11-403E24.2|Wilms tumor gene on the X chromosome protein|Wilms tumor on the X|adenomatous polyposis coli membrane recruitment 1|family with sequence similarity 123B|protein FAM123B', map_location='Xq11.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=64185117, end_position_on_the_genomic_accession=64205708, orientation='minus', exon_count=2, OMIM=[300647], no_hdr0=''),
    139322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139322, CurrentID=0, Status='live', Symbol='APOOL', Aliases=['CXorf33', 'FAM121A', 'MICOS27', 'Mic27', 'UNQ8193'], description='apolipoprotein O like', other_designations='MICOS complex subunit MIC27|AAIR8193|family with sequence similarity 121A|mitochondrial contact site and cristae organizing system subunit 27', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=85003852, end_position_on_the_genomic_accession=85093315, orientation='plus', exon_count=11, OMIM=[300955], no_hdr0=''),
    139324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139324, CurrentID=0, Status='live', Symbol='HDX', Aliases=['CXorf43', 'D030011N01Rik'], description='highly divergent homeobox', other_designations='highly divergent homeobox', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=84317878, end_position_on_the_genomic_accession=84502578, orientation='minus', exon_count=15, OMIM=[300994], no_hdr0=''),
    139341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139341, CurrentID=0, Status='live', Symbol='FUNDC1', Aliases=[], description='FUN14 domain containing 1', other_designations='FUN14 domain-containing protein 1', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=44523639, end_position_on_the_genomic_accession=44542859, orientation='minus', exon_count=5, OMIM=[300871], no_hdr0=''),
    139378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139378, CurrentID=0, Status='live', Symbol='ADGRG4', Aliases=['GPR112', 'PGR17', 'RP1-299I16'], description='adhesion G protein-coupled receptor G4', other_designations='adhesion G-protein coupled receptor G4|G protein-coupled receptor 112|probable G-protein coupled receptor 112', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=136300963, end_position_on_the_genomic_accession=136416890, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    139411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139411, CurrentID=0, Status='live', Symbol='PTCHD1', Aliases=['AUTSX4'], description='patched domain containing 1', other_designations='patched domain-containing protein 1', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23334369, end_position_on_the_genomic_accession=23404374, orientation='plus', exon_count=4, OMIM=[300828], no_hdr0=''),
    139420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139420, CurrentID=0, Status='live', Symbol='PPP4R3C', Aliases=['FLFL3PP', 'SMEK3P', 'smk1', 'PPP4R3C'], description='protein phosphatase 4 regulatory subunit 3C', other_designations='protein PPP4R3C|Putative SMEK homolog 3|SMEK homolog 3, suppressor of mek1 pseudogene|Serine/threonine-protein phosphatase 4 regulatory subunit 3C pseudogene|protein phosphatase 4 regulatory subunit 3C, pseudogene', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=27460207, end_position_on_the_genomic_accession=27463341, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    139422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139422, CurrentID=0, Status='live', Symbol='MAGEB10', Aliases=[], description='MAGE family member B10', other_designations='melanoma-associated antigen B10|MAGE family testis and tumor-specific protein|MAGE-B10 antigen|melanoma antigen family B, 10|melanoma antigen family B10', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=27807990, end_position_on_the_genomic_accession=27823014, orientation='plus', exon_count=3, OMIM=[300761], no_hdr0=''),
    139425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139425, CurrentID=0, Status='live', Symbol='DCAF8L1', Aliases=['WDR42B'], description='DDB1 and CUL4 associated factor 8 like 1', other_designations='DDB1- and CUL4-associated factor 8-like protein 1|WD repeat domain 42B|WD repeat-containing protein 42B', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=27977992, end_position_on_the_genomic_accession=27981449, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    139562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139562, CurrentID=0, Status='live', Symbol='OTUD6A', Aliases=['DUBA2', 'HSHIN6'], description='OTU deubiquitinase 6A', other_designations='OTU domain-containing protein 6A|HIN-6 protease', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70062457, end_position_on_the_genomic_accession=70064179, orientation='plus', exon_count=1, OMIM=[300714], no_hdr0=''),
    139596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139596, CurrentID=0, Status='live', Symbol='UPRT', Aliases=['FUR1', 'UPP'], description='uracil phosphoribosyltransferase homolog', other_designations='uracil phosphoribosyltransferase homolog|RP11-311P8.3|UMP pyrophosphorylase|UPRTase|uracil phosphoribosyltransferase (FUR1) homolog', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=75156369, end_position_on_the_genomic_accession=75304897, orientation='plus', exon_count=13, OMIM=[300656], no_hdr0=''),
    139599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139599, CurrentID=0, Status='live', Symbol='MAGEE2', Aliases=['HCA3'], description='MAGE family member E2', other_designations='melanoma-associated antigen E2|MAGE-E2 antigen|hepatocellular carcinoma-associated protein 3|hepatocellular carcinoma-associated protein HCA3|melanoma antigen family E, 2|melanoma antigen family E2', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=75782987, end_position_on_the_genomic_accession=75785254, orientation='minus', exon_count=1, OMIM=[300760], no_hdr0=''),
    139604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139604, CurrentID=0, Status='live', Symbol='MAGEB16', Aliases=[], description='MAGE family member B16', other_designations='melanoma-associated antigen B16|MAGE-B16 antigen|melanoma antigen family B, 16 (pseudogene)|melanoma antigen family B16', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=35798342, end_position_on_the_genomic_accession=35803772, orientation='plus', exon_count=3, OMIM=[300762], no_hdr0=''),
    139628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139628, CurrentID=0, Status='live', Symbol='FOXR2', Aliases=['FOXN6'], description='forkhead box R2', other_designations='forkhead box protein R2|forkhead box protein N6', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55623400, end_position_on_the_genomic_accession=55626192, orientation='plus', exon_count=1, OMIM=[300949], no_hdr0=''),
    139716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139716, CurrentID=0, Status='live', Symbol='GAB3', Aliases=[], description='GRB2 associated binding protein 3', other_designations='GRB2-associated-binding protein 3|DOS/Gab family member 3|GRB2-associated binder 3|Gab3 scaffolding protein|growth factor receptor bound protein 2-associated protein 3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154675249, end_position_on_the_genomic_accession=154751566, orientation='minus', exon_count=12, OMIM=[300482], no_hdr0=''),
    139728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139728, CurrentID=0, Status='live', Symbol='PNCK', Aliases=['BSTK3', 'CaMK1b'], description='pregnancy up-regulated nonubiquitous CaM kinase', other_designations='calcium/calmodulin-dependent protein kinase type 1B|caM kinase I beta|caM kinase IB|caM-KI beta|caMKI-beta|pregnancy up-regulated non-ubiquitously-expressed CaM kinase|pregnancy upregulated non-ubiquitously expressed CaM kinase', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153669723, end_position_on_the_genomic_accession=153687771, orientation='minus', exon_count=19, OMIM=[300680], no_hdr0=''),
    139735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139735, CurrentID=0, Status='live', Symbol='ZFP92', Aliases=['ZNF897'], description='ZFP92 zinc finger protein', other_designations='zinc finger protein 92 homolog|zinc finger protein homologous to Zfp92 in mouse', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153411472, end_position_on_the_genomic_accession=153426481, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    139741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139741, CurrentID=0, Status='live', Symbol='ACTRT1', Aliases=['AIP1', 'ARIP1', 'ARPT1', 'HSD27'], description='actin related protein T1', other_designations='actin-related protein T1', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=128050962, end_position_on_the_genomic_accession=128052403, orientation='minus', exon_count=1, OMIM=[300487], no_hdr0=''),
    139760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139760, CurrentID=0, Status='live', Symbol='GPR119', Aliases=['GPCR2'], description='G protein-coupled receptor 119', other_designations='glucose-dependent insulinotropic receptor|G-protein coupled receptor 2', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=130379449, end_position_on_the_genomic_accession=130385674, orientation='minus', exon_count=2, OMIM=[300513], no_hdr0=''),
    139793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139793, CurrentID=0, Status='live', Symbol='PAGE3', Aliases=['CT16.6', 'GAGED1', 'PAGE-3'], description='PAGE family member 3', other_designations='P antigen family member 3|G antigen family D member 1|G antigen, family D, 1|P antigen family, member 3 (prostate associated)|prostate-associated gene 3 protein', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55257601, end_position_on_the_genomic_accession=55264916, orientation='minus', exon_count=5, OMIM=[300739], no_hdr0=''),
    139804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139804, CurrentID=0, Status='live', Symbol='RBMXL3', Aliases=['CXorf55'], description='RBMX like 3', other_designations='RNA-binding motif protein, X-linked-like-3|RNA binding motif protein, X-linked like 3', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=115189410, end_position_on_the_genomic_accession=115192868, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    139818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139818, CurrentID=0, Status='live', Symbol='DOCK11', Aliases=['ACG', 'ZIZ2', 'bB128O4.1'], description='dedicator of cytokinesis 11', other_designations='dedicator of cytokinesis protein 11|Activated Cdc42-associated guanine nucleotide exchange factor, ACG|zizimin-2|zizimin2', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=118495664, end_position_on_the_genomic_accession=118686153, orientation='plus', exon_count=57, OMIM=[300681], no_hdr0=''),
    139886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=139886, CurrentID=0, Status='live', Symbol='SPIN4', Aliases=['TDRD28'], description='spindlin family member 4', other_designations='spindlin-4', map_location='Xq11.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=63347228, end_position_on_the_genomic_accession=63351332, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    140032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140032, CurrentID=0, Status='live', Symbol='RPS4Y2', Aliases=['RPS4Y2P'], description='ribosomal protein S4 Y-linked 2', other_designations='40S ribosomal protein S4, Y isoform 2|40S ribosomal protein S4, Y|ribosomal protein S4, Y-linked 2 pseudogene|small ribosomal subunit protein eS4', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=20756108, end_position_on_the_genomic_accession=20781032, orientation='plus', exon_count=7, OMIM=[400030], no_hdr0=''),
    140258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140258, CurrentID=0, Status='live', Symbol='KRTAP13-1', Aliases=['KAP13.1', 'KRTAP13.1'], description='keratin associated protein 13-1', other_designations='keratin-associated protein 13-1|high sulfur keratin associated protein 13.1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30396031, end_position_on_the_genomic_accession=30396822, orientation='plus', exon_count=1, OMIM=[608718], no_hdr0=''),
    140290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140290, CurrentID=0, Status='live', Symbol='TCP10L', Aliases=['C21orf77', 'LINC00846', 'PRED77', 'TCP10A-1', 'TCP10A-2'], description='t-complex 10 like', other_designations='T-complex protein 10A homolog 1|T-complex protein 10A homolog 2|T-complex protein 10A-1|T-complex protein 10A-2|TCP10-like', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32573721, end_position_on_the_genomic_accession=32585523, orientation='minus', exon_count=5, OMIM=[608365], no_hdr0=''),
    140432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140432, CurrentID=0, Status='live', Symbol='RNF113B', Aliases=['RNF161', 'ZNF183L1', 'bA10G5.1'], description='ring finger protein 113B', other_designations='RING finger protein 113B|zinc finger protein 183-like 1', map_location='13q32.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=98175785, end_position_on_the_genomic_accession=98177269, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    140453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140453, CurrentID=0, Status='live', Symbol='MUC17', Aliases=['MUC-17', 'MUC-3', 'MUC3'], description='mucin 17, cell surface associated', other_designations='mucin-17|membrane mucin MUC17|secreted mucin MUC17|small intestinal mucin MUC3|small intestinal mucin-3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101020081, end_position_on_the_genomic_accession=101058859, orientation='plus', exon_count=13, OMIM=[608424], no_hdr0=''),
    140456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140456, CurrentID=0, Status='live', Symbol='ASB11', Aliases=[], description='ankyrin repeat and SOCS box containing 11', other_designations='ankyrin repeat and SOCS box protein 11|ASB-11|ankyrin repeat and SOCS box containing 11, E3 ubiquitin protein ligase|ankyrin repeat domain-containing SOCS box protein ASB11', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15281697, end_position_on_the_genomic_accession=15315640, orientation='minus', exon_count=8, OMIM=[300626], no_hdr0=''),
    140458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140458, CurrentID=0, Status='live', Symbol='ASB5', Aliases=['ASB-5'], description='ankyrin repeat and SOCS box containing 5', other_designations='ankyrin repeat and SOCS box protein 5|SOCS box protein ASB-5', map_location='4q34.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=176213673, end_position_on_the_genomic_accession=176277571, orientation='minus', exon_count=11, OMIM=[615050], no_hdr0=''),
    140459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140459, CurrentID=0, Status='live', Symbol='ASB6', Aliases=[], description='ankyrin repeat and SOCS box containing 6', other_designations='ankyrin repeat and SOCS box protein 6', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129634605, end_position_on_the_genomic_accession=129642151, orientation='minus', exon_count=6, OMIM=[615051], no_hdr0=''),
    140460 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140460, CurrentID=0, Status='live', Symbol='ASB7', Aliases=[], description='ankyrin repeat and SOCS box containing 7', other_designations='ankyrin repeat and SOCS box protein 7|ASB-7', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=100602589, end_position_on_the_genomic_accession=100651701, orientation='plus', exon_count=6, OMIM=[615052], no_hdr0=''),
    140461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140461, CurrentID=0, Status='live', Symbol='ASB8', Aliases=['PP14212'], description='ankyrin repeat and SOCS box containing 8', other_designations='ankyrin repeat and SOCS box protein 8', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48147789, end_position_on_the_genomic_accession=48157515, orientation='minus', exon_count=7, OMIM=[615053], no_hdr0=''),
    140462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140462, CurrentID=0, Status='live', Symbol='ASB9', Aliases=[], description='ankyrin repeat and SOCS box containing 9', other_designations='ankyrin repeat and SOCS box protein 9|ASB-9|ankyrin repeat and suppressor of cytokine signaling box protein 9|testis tissue sperm-binding protein Li 57p', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=15243987, end_position_on_the_genomic_accession=15270476, orientation='minus', exon_count=8, OMIM=[300890], no_hdr0=''),
    140465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140465, CurrentID=0, Status='live', Symbol='MYL6B', Aliases=['MLC1SA'], description='myosin light chain 6B', other_designations='myosin light chain 6B|myosin alkali light chain 1 slow a|myosin light chain 1 slow a|myosin, light chain 6B, alkali, smooth muscle and non-muscle|myosin, light polypeptide 6B, alkali, smooth muscle and non-muscle|smooth muscle and non-muscle myosin alkali light chain 6B|smooth muscle and nonmuscle myosin light chain alkali 6B', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56152587, end_position_on_the_genomic_accession=56157982, orientation='plus', exon_count=8, OMIM=[609930], no_hdr0=''),
    140467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140467, CurrentID=0, Status='live', Symbol='ZNF358', Aliases=['ZFEND'], description='zinc finger protein 358', other_designations='zinc finger protein 358', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7515286, end_position_on_the_genomic_accession=7521025, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    140469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140469, CurrentID=0, Status='live', Symbol='MYO3B', Aliases=[], description='myosin IIIB', other_designations='myosin-IIIb', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170178147, end_position_on_the_genomic_accession=170655167, orientation='plus', exon_count=43, OMIM=[610040], no_hdr0=''),
    140545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140545, CurrentID=0, Status='live', Symbol='RNF32', Aliases=['FKSG33', 'HSD15', 'LMBR2'], description='ring finger protein 32', other_designations='RING finger protein 32', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=156640202, end_position_on_the_genomic_accession=156678333, orientation='plus', exon_count=17, OMIM=[610241], no_hdr0=''),
    140564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140564, CurrentID=0, Status='live', Symbol='APOBEC3D', Aliases=['A3D', 'A3DEE', 'APOBEC3E', 'ARP6', 'APOBEC3D'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3D', other_designations='DNA dC->dU-editing enzyme APOBEC-3D|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3D|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3E pseudogene|probable DNA dC->dU-editing enzyme APOBEC-3D', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39021127, end_position_on_the_genomic_accession=39033277, orientation='plus', exon_count=7, OMIM=[609900], no_hdr0=''),
    140576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140576, CurrentID=0, Status='live', Symbol='S100A16', Aliases=['AAG13', 'DT1P1A7', 'S100F'], description='S100 calcium binding protein A16', other_designations='protein S100-A16|aging-associated gene 13 protein|aging-associated protein 13|protein S100-F', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153606883, end_position_on_the_genomic_accession=153613137, orientation='minus', exon_count=4, OMIM=[617437], no_hdr0=''),
    140578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140578, CurrentID=0, Status='live', Symbol='CHODL', Aliases=['C21orf68', 'MT75', 'PRED12'], description='chondrolectin', other_designations='chondrolectin|transmembrane protein MT75', map_location='21q21.1', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=17819329, end_position_on_the_genomic_accession=18267371, orientation='plus', exon_count=10, OMIM=[607247], no_hdr0=''),
    140596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140596, CurrentID=0, Status='live', Symbol='DEFB104A', Aliases=['BD-4', 'DEFB-4', 'DEFB104', 'DEFB4', 'hBD-4'], description='defensin beta 104A', other_designations='beta-defensin 104|defensin, beta 4', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7836436, end_position_on_the_genomic_accession=7841242, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    140597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140597, CurrentID=0, Status='live', Symbol='TCEAL2', Aliases=['MY0876G05', 'WEX1', 'my048'], description='transcription elongation factor A like 2', other_designations='transcription elongation factor A protein-like 2|TCEA-like protein 2|transcription elongation factor A (SII)-like 2|transcription elongation factor S-II protein-like 2', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102125679, end_position_on_the_genomic_accession=102127712, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    140606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140606, CurrentID=0, Status='live', Symbol='SELENOM', Aliases=['SELM', 'SEPM'], description='selenoprotein M', other_designations='selenoprotein M|selenoprotein SelM', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31104777, end_position_on_the_genomic_accession=31107568, orientation='minus', exon_count=5, OMIM=[610918], no_hdr0=''),
    140609 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140609, CurrentID=0, Status='live', Symbol='NEK7', Aliases=[], description='NIMA related kinase 7', other_designations='serine/threonine-protein kinase Nek7|NIMA (never in mitosis gene a)-related kinase 7|never in mitosis A-related kinase 7|nimA-related protein kinase 7', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=198156998, end_position_on_the_genomic_accession=198322420, orientation='plus', exon_count=12, OMIM=[606848], no_hdr0=''),
    140612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140612, CurrentID=0, Status='live', Symbol='ZFP28', Aliases=['mkr5'], description='ZFP28 zinc finger protein', other_designations='zinc finger protein 28 homolog|krueppel-like zinc finger factor X6|zfp-28|zinc finger factor X6', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56536790, end_position_on_the_genomic_accession=56559192, orientation='plus', exon_count=10, OMIM=[616798], no_hdr0=''),
    140625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140625, CurrentID=0, Status='live', Symbol='ACTRT2', Aliases=['ARPM2', 'ARPT2', 'Arp-T2', 'HARPM2'], description='actin related protein T2', other_designations='actin-related protein T2|actin-related protein M2|actin-related protein hArpM2', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3021467, end_position_on_the_genomic_accession=3022903, orientation='plus', exon_count=1, OMIM=[608535], no_hdr0=''),
    140628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140628, CurrentID=0, Status='live', Symbol='GATA5', Aliases=['CHTD5', 'GATAS', 'bB379O24.1'], description='GATA binding protein 5', other_designations='transcription factor GATA-5|GATA binding factor-5', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62463497, end_position_on_the_genomic_accession=62475995, orientation='minus', exon_count=8, OMIM=[611496], no_hdr0=''),
    140679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140679, CurrentID=0, Status='live', Symbol='SLC32A1', Aliases=['VGAT', 'VIAAT'], description='solute carrier family 32 member 1', other_designations='vesicular inhibitory amino acid transporter|GABA and glycine transporter|hVIAAT|solute carrier family 32 (GABA vesicular transporter), member 1|vesicular GABA transporter', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38724486, end_position_on_the_genomic_accession=38729372, orientation='plus', exon_count=2, OMIM=[616440], no_hdr0=''),
    140680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140680, CurrentID=0, Status='live', Symbol='C20orf96', Aliases=['dJ1103G7.2'], description='chromosome 20 open reading frame 96', other_designations='uncharacterized protein C20orf96', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=270863, end_position_on_the_genomic_accession=290757, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    140683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140683, CurrentID=0, Status='live', Symbol='BPIFA2', Aliases=['C20orf70', 'PSP', 'SPLUNC2', 'bA49G10.1'], description='BPI fold containing family A member 2', other_designations='BPI fold-containing family A member 2|parotid secretory protein|short palate, lung and nasal epithelium carcinoma-associated protein 2', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33161770, end_position_on_the_genomic_accession=33181412, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    140685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140685, CurrentID=0, Status='live', Symbol='ZBTB46', Aliases=['BTBD4', 'BZEL', 'RINZF', 'ZNF340', 'dJ583P15.7', 'dJ583P15.8'], description='zinc finger and BTB domain containing 46', other_designations='zinc finger and BTB domain-containing protein 46|BTB (POZ) domain containing 4|BTB-ZF protein expressed in effector lymphocytes|BTB/POZ domain-containing protein 4|zinc finger protein 340', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63743670, end_position_on_the_genomic_accession=63832332, orientation='minus', exon_count=14, OMIM=[614639], no_hdr0=''),
    140686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140686, CurrentID=0, Status='live', Symbol='WFDC3', Aliases=['WAP14', 'dJ447F3.3'], description='WAP four-disulfide core domain 3', other_designations='WAP four-disulfide core domain protein 3|protease inhibitor WAP14|putative protease inhibitor WAP14|whey acidic protein 14', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45708860, end_position_on_the_genomic_accession=45791883, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    140687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140687, CurrentID=0, Status='live', Symbol='GCNT7', Aliases=['C20orf105', 'dJ1153D9.2', 'gcnt'], description='glucosaminyl (N-acetyl) transferase family member 7', other_designations='beta-1,3-galactosyl-O-glycosyl-glycoprotein beta-1,6-N-acetylglucosaminyltransferase 7|beta 1,6-N-acetylglucosaminyltransferase', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56491492, end_position_on_the_genomic_accession=56525925, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    140688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140688, CurrentID=0, Status='live', Symbol='NOL4L', Aliases=['C20orf112', 'C20orf113'], description='nucleolar protein 4 like', other_designations='nucleolar protein 4-like', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32443059, end_position_on_the_genomic_accession=32585333, orientation='minus', exon_count=21, OMIM=[618893], no_hdr0=''),
    140689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140689, CurrentID=0, Status='live', Symbol='CBLN4', Aliases=['CBLNL1'], description='cerebellin 4 precursor', other_designations='cerebellin-4|cerebellin precursor-like 1|cerebellin-like glycoprotein 1', map_location='20q13.2', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=55997357, end_position_on_the_genomic_accession=56005519, orientation='minus', exon_count=3, OMIM=[615029], no_hdr0=''),
    140690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140690, CurrentID=0, Status='live', Symbol='CTCFL', Aliases=['BORIS', 'CT27', 'CTCF-T', 'HMGB1L1', 'dJ579F20.2'], description='CCCTC-binding factor like', other_designations='transcriptional repressor CTCFL|BORIS-like protein|brother of the regulator of imprinted sites|cancer/testis antigen 27', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57495965, end_position_on_the_genomic_accession=57525652, orientation='minus', exon_count=16, OMIM=[607022], no_hdr0=''),
    140691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140691, CurrentID=0, Status='live', Symbol='TRIM69', Aliases=['HSD-34', 'HSD34', 'RNF36', 'Trif'], description='tripartite motif containing 69', other_designations='E3 ubiquitin-protein ligase TRIM69|RFP-like domain-containing protein trimless|RING-type E3 ubiquitin transferase TRIM69|ring finger protein 36', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44736528, end_position_on_the_genomic_accession=44767827, orientation='plus', exon_count=7, OMIM=[616017], no_hdr0=''),
    140699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140699, CurrentID=0, Status='live', Symbol='MROH8', Aliases=['C20orf131', 'C20orf132'], description='maestro heat like repeat family member 8', other_designations='protein MROH8|maestro heat-like repeat-containing protein family member 8', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=37101169, end_position_on_the_genomic_accession=37179548, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    140700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140700, CurrentID=0, Status='live', Symbol='SAMD10', Aliases=['C20orf136', 'dJ591C20', 'dJ591C20.7'], description='sterile alpha motif domain containing 10', other_designations='sterile alpha motif domain-containing protein 10|D930033N23Rik|SAM domain-containing protein 10', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63974113, end_position_on_the_genomic_accession=63980788, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    140701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140701, CurrentID=0, Status='live', Symbol='ABHD16B', Aliases=['C20orf135', 'dJ591C20.1'], description='abhydrolase domain containing 16B', other_designations='protein ABHD16B|abhydrolase domain-containing protein 16B|alpha/beta hydrolase domain-containing protein 16B', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=63861498, end_position_on_the_genomic_accession=63862988, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    140706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140706, CurrentID=0, Status='live', Symbol='CCM2L', Aliases=['C20orf160', 'dJ310O13.5'], description='CCM2 like scaffold protein', other_designations='cerebral cavernous malformations 2 protein-like|CCM2 like scaffolding protein|CCM2-like|cerebral cavernous malformation 2-like', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32010379, end_position_on_the_genomic_accession=32032180, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    140707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140707, CurrentID=0, Status='live', Symbol='BRI3BP', Aliases=['BNAS1', 'HCCR-1', 'HCCR-2', 'HCCRBP-1', 'HCCRBP-3', 'KG19'], description='BRI3 binding protein', other_designations='BRI3-binding protein|I3-binding protein|cervical cancer 1 proto-oncogene-binding protein KG19|cervical cancer oncogene binding protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124993645, end_position_on_the_genomic_accession=125051845, orientation='plus', exon_count=4, OMIM=[615627], no_hdr0=''),
    140710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140710, CurrentID=0, Status='live', Symbol='SOGA1', Aliases=['C20orf117', 'KIAA0889', 'SOGA'], description='suppressor of glucose, autophagy associated 1', other_designations='protein SOGA1|SOGA family member 1|suppressor of glucose by autophagy|suppressor of glucose from autophagy|suppressor of glucose, autophagy-associated protein 1', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36777447, end_position_on_the_genomic_accession=36863538, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    140711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140711, CurrentID=0, Status='live', Symbol='TLDC2', Aliases=['C20orf118'], description='TBC/LysM-associated domain containing 2', other_designations='TLD domain-containing protein 2|TBC/LysM-associated domain-containing protein 2', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36873071, end_position_on_the_genomic_accession=36894235, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    140730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140730, CurrentID=0, Status='live', Symbol='RIMS4', Aliases=['C20orf190', 'RIM 4', 'RIM-4', 'RIM4', 'RIM4-gamma', 'RIM4gamma'], description='regulating synaptic membrane exocytosis 4', other_designations='regulating synaptic membrane exocytosis protein 4|RIM4 gamma|rab3-interacting molecule 4', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44751808, end_position_on_the_genomic_accession=44810546, orientation='minus', exon_count=6, OMIM=[611601], no_hdr0=''),
    140731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140731, CurrentID=0, Status='live', Symbol='ANKRD60', Aliases=['C20orf86', 'bA196N14.3'], description='ankyrin repeat domain 60', other_designations='ankyrin repeat domain-containing protein 60', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58216126, end_position_on_the_genomic_accession=58228653, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    140732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140732, CurrentID=0, Status='live', Symbol='SUN5', Aliases=['SPAG4L', 'SPGF16', 'TSARG4', 'dJ726C3.1'], description='Sad1 and UNC84 domain containing 5', other_designations='SUN domain-containing protein 5|epididymis secretory sperm binding protein|sad1 and UNC84 domain-containing protein 5|sperm-associated antigen 4-like protein|testis and spermatogenesis related gene 4|testis and spermatogenesis-related gene 4 protein', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32983773, end_position_on_the_genomic_accession=33004449, orientation='minus', exon_count=15, OMIM=[613942], no_hdr0=''),
    140733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140733, CurrentID=0, Status='live', Symbol='MACROD2', Aliases=['C20orf133', 'C2orf133'], description='mono-ADP ribosylhydrolase 2', other_designations='ADP-ribose glycohydrolase MACROD2|MACRO domain containing 2|MACRO domain-containing protein 2|O-acetyl-ADP-ribose deacetylase MACROD2|[Protein ADP-ribosylaspartate] hydrolase MACROD2|[Protein ADP-ribosylglutamate] hydrolase|[Protein ADP-ribosylglutamate] hydrolase MACROD2', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13995516, end_position_on_the_genomic_accession=16053197, orientation='plus', exon_count=21, OMIM=[611567], no_hdr0=''),
    140735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140735, CurrentID=0, Status='live', Symbol='DYNLL2', Aliases=['DNCL1B', 'Dlc2', 'RSPH22'], description='dynein light chain LC8-type 2', other_designations='dynein light chain 2, cytoplasmic|8 kDa dynein light chain b|DLC8b|radial spoke 22 homolog', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=58083419, end_position_on_the_genomic_accession=58095542, orientation='plus', exon_count=3, OMIM=[608942], no_hdr0=''),
    140738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140738, CurrentID=0, Status='live', Symbol='TMEM37', Aliases=['PR', 'PR1'], description='transmembrane protein 37', other_designations='voltage-dependent calcium channel gamma-like subunit|neuronal voltage-gated calcium channel gamma-like subunit|voltage-dependent calcium channel gamma subunit-like protein', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119429912, end_position_on_the_genomic_accession=119438507, orientation='plus', exon_count=5, OMIM=[618831], no_hdr0=''),
    140739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140739, CurrentID=0, Status='live', Symbol='UBE2F', Aliases=['NCE2'], description='ubiquitin conjugating enzyme E2 F (putative)', other_designations='NEDD8-conjugating enzyme UBE2F|NEDD8 carrier protein UBE2F|NEDD8 protein ligase UBE2F|NEDD8-conjugating enzyme 2|RING-type E3 NEDD8 transferase UBE2F|ubiquitin-conjugating enzyme E2F (putative)', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237967014, end_position_on_the_genomic_accession=238042782, orientation='plus', exon_count=12, OMIM=[617700], no_hdr0=''),
    140766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140766, CurrentID=0, Status='live', Symbol='ADAMTS14', Aliases=[], description='ADAM metallopeptidase with thrombospondin type 1 motif 14', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 14|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 14', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70672506, end_position_on_the_genomic_accession=70762441, orientation='plus', exon_count=25, OMIM=[607506], no_hdr0=''),
    140767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140767, CurrentID=0, Status='live', Symbol='NRSN1', Aliases=['VMP', 'p24'], description='neurensin 1', other_designations='neurensin-1|neuro-p24|vesicular membrain protein p24|vesicular membrane protein of 24 kDa|vesicular membrane protein p24', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24126215, end_position_on_the_genomic_accession=24147530, orientation='plus', exon_count=4, OMIM=[616630], no_hdr0=''),
    140775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140775, CurrentID=0, Status='live', Symbol='SMCR8', Aliases=['DENND8A'], description='SMCR8-C9orf72 complex subunit', other_designations='guanine nucleotide exchange protein SMCR8|Smith-Magenis syndrome chromosome region, candidate 8|smith-Magenis syndrome chromosomal region candidate gene 8 protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18315293, end_position_on_the_genomic_accession=18328056, orientation='plus', exon_count=2, OMIM=[617074], no_hdr0=''),
    140801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140801, CurrentID=0, Status='live', Symbol='RPL10L', Aliases=['RPL10_5_1358'], description='ribosomal protein L10 like', other_designations='60S ribosomal protein L10-like|large ribosomal subunit protein uL16-like', map_location='14q21.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=46651010, end_position_on_the_genomic_accession=46651781, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    140803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140803, CurrentID=0, Status='live', Symbol='TRPM6', Aliases=['CHAK2', 'HMGX', 'HOMG', 'HOMG1', 'HSH'], description='transient receptor potential cation channel subfamily M member 6', other_designations='transient receptor potential cation channel subfamily M member 6|channel kinase 2|melastatin-related TRP cation channel 6', map_location='9q21.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=74722495, end_position_on_the_genomic_accession=74887921, orientation='minus', exon_count=41, OMIM=[607009], no_hdr0=''),
    140807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140807, CurrentID=0, Status='live', Symbol='KRT72', Aliases=['CK-72', 'K6IRS2', 'K6irs', 'K72', 'KRT6', 'KRT6IRS2'], description='keratin 72', other_designations='keratin, type II cytoskeletal 72|cytokeratin-72|keratin 6, inner root sheath, 2|keratin 72, type II|keratin protein K6irs|type II inner root sheath-specific keratin-K6irs2|type-II keratin Kb35', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52585589, end_position_on_the_genomic_accession=52602900, orientation='minus', exon_count=13, OMIM=[608246], no_hdr0=''),
    140809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140809, CurrentID=0, Status='live', Symbol='SRXN1', Aliases=['C20orf139', 'Npn3', 'SRX', 'SRX1'], description='sulfiredoxin 1', other_designations='sulfiredoxin-1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=646615, end_position_on_the_genomic_accession=653200, orientation='minus', exon_count=2, OMIM=[617583], no_hdr0=''),
    140823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140823, CurrentID=0, Status='live', Symbol='ROMO1', Aliases=['C20orf52', 'MTGM', 'MTGMP', 'bA353C18.2'], description='reactive oxygen species modulator 1', other_designations='reactive oxygen species modulator 1|PCM19|ROS modulator 1|epididymis tissue protein Li 175|glyrichin|mitochondrial targeting GXXXG protein|mitochondrial targeting GxxxG motif protein|protein MGR2 homolog', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35699310, end_position_on_the_genomic_accession=35700982, orientation='plus', exon_count=3, OMIM=[618894], no_hdr0=''),
    140825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140825, CurrentID=0, Status='live', Symbol='NEURL2', Aliases=['C20orf163', 'OZZ', 'OZZ-E3'], description='neuralized E3 ubiquitin protein ligase 2', other_designations='neuralized-like protein 2|neuralized homolog 2', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45888634, end_position_on_the_genomic_accession=45891208, orientation='minus', exon_count=2, OMIM=[608597], no_hdr0=''),
    140831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140831, CurrentID=0, Status='live', Symbol='ZSWIM3', Aliases=['C20orf164', 'PPP1R174'], description='zinc finger SWIM-type containing 3', other_designations='zinc finger SWIM domain-containing protein 3|protein phosphatase 1, regulatory subunit 174|zinc finger, SWIM domain containing 3', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45857614, end_position_on_the_genomic_accession=45879122, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    140832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140832, CurrentID=0, Status='live', Symbol='WFDC10A', Aliases=['C20orf146', 'WAP10', 'dJ688G8.3'], description='WAP four-disulfide core domain 10A', other_designations='WAP four-disulfide core domain protein 10A|putative protease inhibitor WAP10A', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45629739, end_position_on_the_genomic_accession=45631196, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    140836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140836, CurrentID=0, Status='live', Symbol='BANF2', Aliases=['BAF-L', 'BAF2', 'BAFL', 'C20orf179'], description='BANF family member 2', other_designations='barrier-to-autointegration factor-like protein|barrier to autointegration factor 2|testis secretory sperm-binding protein Li 212a', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=17693672, end_position_on_the_genomic_accession=17735872, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    140838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140838, CurrentID=0, Status='live', Symbol='NANP', Aliases=['C20orf147', 'HDHD4', 'dJ694B14.3'], description='N-acetylneuraminic acid phosphatase', other_designations='N-acylneuraminate-9-phosphatase|Neu5Ac-9-Pase|haloacid dehalogenase-like hydrolase domain containing 4|haloacid dehalogenase-like hydrolase domain-containing protein 4', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=25612935, end_position_on_the_genomic_accession=25624014, orientation='minus', exon_count=2, OMIM=[610763], no_hdr0=''),
    140850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140850, CurrentID=0, Status='live', Symbol='DEFB127', Aliases=['C20orf73', 'DEF-27', 'DEFB-27', 'DEFB27', 'bA530N10.2', 'hBD-27'], description='defensin beta 127', other_designations='beta-defensin 127|beta-defensin 27', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=157454, end_position_on_the_genomic_accession=159163, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    140856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140856, CurrentID=0, Status='live', Symbol='SCP2D1', Aliases=['C20orf79', 'HSD22', 'dJ1068E13.2'], description='SCP2 sterol binding domain containing 1', other_designations='SCP2 sterol-binding domain-containing protein 1|sterol carrier protein 2-like protein', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18813783, end_position_on_the_genomic_accession=18814378, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    140862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140862, CurrentID=0, Status='live', Symbol='ISM1', Aliases=['C20orf82', 'ISM', 'Isthmin', 'bA149I18.1', 'dJ1077I2.1'], description='isthmin 1', other_designations='isthmin-1|isthmin 1 homolog|isthmin 1, angiogenesis inhibitor', map_location='20p12.1', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=13221274, end_position_on_the_genomic_accession=13326734, orientation='plus', exon_count=8, OMIM=[615793], no_hdr0=''),
    140870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140870, CurrentID=0, Status='live', Symbol='WFDC6', Aliases=['C20orf171', 'HEL-S-295', 'WAP6', 'dJ461P17.11'], description='WAP four-disulfide core domain 6', other_designations='WAP four-disulfide core domain protein 6|epididymis secretory protein Li 295|epididymis secretory sperm binding protein|protease inhibitor WAP6', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45534196, end_position_on_the_genomic_accession=45539482, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    140873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140873, CurrentID=0, Status='live', Symbol='C20orf173', Aliases=['dJ477O4.4'], description='chromosome 20 open reading frame 173', other_designations='uncharacterized protein C20orf173', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35520741, end_position_on_the_genomic_accession=35529846, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    140876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140876, CurrentID=0, Status='live', Symbol='RIPOR3', Aliases=['C20orf175', 'C20orf176', 'FAM65C'], description='RIPOR family member 3', other_designations='RIPOR family member 3|family with sequence similarity 65 member C|protein FAM65C', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50586108, end_position_on_the_genomic_accession=50692004, orientation='minus', exon_count=30, OMIM=[], no_hdr0=''),
    140880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140880, CurrentID=0, Status='live', Symbol='CST11', Aliases=['CST8L', 'CTES2', 'SC13', 'dJ322G13.6'], description='cystatin 11', other_designations='cystatin-11|SC13delta|cystatin-related epididymal-specific protein|epididymis secretory sperm binding protein', map_location='20p11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=23450412, end_position_on_the_genomic_accession=23452876, orientation='minus', exon_count=3, OMIM=[609731], no_hdr0=''),
    140881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140881, CurrentID=0, Status='live', Symbol='DEFB129', Aliases=['C20orf87', 'DEFB-29', 'DEFB29', 'bA530N10.3', 'hBD-29'], description='defensin beta 129', other_designations='beta-defensin 129|beta-defensin 29|epididymis secretory sperm binding protein', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=227258, end_position_on_the_genomic_accession=229886, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    140883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140883, CurrentID=0, Status='live', Symbol='ZNF280B', Aliases=["5'OY11.1", 'D87009.C22.3', 'SUHW2', 'ZNF279', 'ZNF632'], description='zinc finger protein 280B', other_designations='zinc finger protein 280B|suppressor of hairy wing homolog 2|zinc finger protein 279|zinc finger protein 632', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22484421, end_position_on_the_genomic_accession=22509161, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    140885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140885, CurrentID=0, Status='live', Symbol='SIRPA', Aliases=['BIT', 'CD172A', 'MFR', 'MYD-1', 'P84', 'PTPNS1', 'SHPS1', 'SIRP'], description='signal regulatory protein alpha', other_designations='tyrosine-protein phosphatase non-receptor type substrate 1|CD172 antigen-like family member A|brain-immunoglobulin-like molecule with tyrosine-based activation motifs|inhibitory receptor SHPS-1|macrophage fusion receptor|myd-1 antigen|tyrosine phosphatase SHP substrate 1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1894167, end_position_on_the_genomic_accession=1940592, orientation='plus', exon_count=12, OMIM=[602461], no_hdr0=''),
    140886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140886, CurrentID=0, Status='live', Symbol='PABPC5', Aliases=['PABP5'], description='poly(A) binding protein cytoplasmic 5', other_designations='polyadenylate-binding protein 5', map_location='Xq21.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=91434839, end_position_on_the_genomic_accession=91438584, orientation='plus', exon_count=2, OMIM=[300407], no_hdr0=''),
    140890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140890, CurrentID=0, Status='live', Symbol='SREK1', Aliases=['SFRS12', 'SRrp508', 'SRrp86'], description='splicing regulatory glutamic acid and lysine rich protein 1', other_designations='splicing regulatory glutamine/lysine-rich protein 1|serine-arginine-rich splicing regulatory protein 508|serine/arginine-rich-splicing regulatory protein 86|splicing factor, arginine/serine-rich 12|splicing regulatory glutamic acid/lysine-rich protein 1', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=66144300, end_position_on_the_genomic_accession=66183615, orientation='plus', exon_count=15, OMIM=[609268], no_hdr0=''),
    140893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140893, CurrentID=0, Status='live', Symbol='RBBP8NL', Aliases=['C20orf151'], description='RBBP8 N-terminal like', other_designations='RBBP8 N-terminal-like protein', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62410237, end_position_on_the_genomic_accession=62427539, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    140894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140894, CurrentID=0, Status='live', Symbol='CNBD2', Aliases=['C20orf152', 'CNMPD1'], description='cyclic nucleotide binding domain containing 2', other_designations='cyclic nucleotide-binding domain-containing protein 2|cyclic nucleotide (cNMP) binding domain containing 1', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35954561, end_position_on_the_genomic_accession=36030700, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    140901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140901, CurrentID=0, Status='live', Symbol='STK35', Aliases=['CLIK1L1', 'STK35'], description='serine/threonine kinase 35', other_designations='serine/threonine-protein kinase 35|CLIK-1|CLP-36 interacting kinase|CLP-36-interacting kinase 1|PDLIM1-interacting kinase 1|serine threonine kinase 35 long form|serine/threonine-protein kinase 35 L1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2098021, end_position_on_the_genomic_accession=2148555, orientation='plus', exon_count=4, OMIM=[609370], no_hdr0=''),
    140902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140902, CurrentID=0, Status='live', Symbol='R3HDML', Aliases=['dJ881L22.3'], description='R3H domain containing like', other_designations='peptidase inhibitor R3HDML|cysteine-rich secretory protein R3HDML', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=44337043, end_position_on_the_genomic_accession=44351238, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    140947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=140947, CurrentID=0, Status='live', Symbol='DCANP1', Aliases=['C5orf20', 'DCNP1'], description='dendritic cell associated nuclear protein', other_designations='dendritic cell nuclear protein 1', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135444214, end_position_on_the_genomic_accession=135447348, orientation='minus', exon_count=1, OMIM=[609710], no_hdr0=''),
    142678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142678, CurrentID=0, Status='live', Symbol='MIB2', Aliases=['ZZANK1', 'ZZZ5'], description='MIB E3 ubiquitin protein ligase 2', other_designations='E3 ubiquitin-protein ligase MIB2|RING-type E3 ubiquitin transferase MIB2|mind bomb homolog 2|mindbomb E3 ubiquitin protein ligase 2|mindbomb homolog 2|novel zinc finger protein|novelzin|putative NF-kappa-B-activating protein 002N|skeletrophin|zinc finger ZZ type with ankyrin repeat domain protein 1|zinc finger, ZZ type with ankyrin repeat domain 1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1613730, end_position_on_the_genomic_accession=1630605, orientation='plus', exon_count=24, OMIM=[611141], no_hdr0=''),
    142679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142679, CurrentID=0, Status='live', Symbol='DUSP19', Aliases=['DUSP17', 'LMWDSP3', 'SKRP1', 'TS-DSP1'], description='dual specificity phosphatase 19', other_designations='dual specificity protein phosphatase 19|SAPK pathway-regulating phosphatase 1|dual specificity phosphatase TS-DSP1|low molecular weight dual specificity phosphatase 3|protein phosphatase SKRP1|stress-activated protein kinase pathway-regulating phosphatase 1', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=183078747, end_position_on_the_genomic_accession=183100008, orientation='plus', exon_count=4, OMIM=[611437], no_hdr0=''),
    142680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142680, CurrentID=0, Status='live', Symbol='SLC34A3', Aliases=['HHRH', 'NPTIIc'], description='solute carrier family 34 member 3', other_designations='sodium-dependent phosphate transport protein 2C|Na(+)-dependent phosphate cotransporter 2C|Na(+)/Pi cotransporter 2C|naPi-2c|sodium-phosphate transport protein 2C|sodium/inorganic phosphate cotransporter IIC|solute carrier family 34 (sodium phosphate), member 3|solute carrier family 34 (type II sodium/phosphate cotransporter), member 3|type IIc Na+/Pi cotransporter', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137230757, end_position_on_the_genomic_accession=137236555, orientation='plus', exon_count=16, OMIM=[609826], no_hdr0=''),
    142683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142683, CurrentID=0, Status='live', Symbol='ITLN2', Aliases=['HL-2', 'HL2'], description='intelectin 2', other_designations='intelectin-2|endothelial lectin HL-2', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=160945020, end_position_on_the_genomic_accession=160957378, orientation='minus', exon_count=10, OMIM=[609874], no_hdr0=''),
    142684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142684, CurrentID=0, Status='live', Symbol='RAB40A', Aliases=['RAR2', 'RAR2A'], description='RAB40A, member RAS oncogene family', other_designations='ras-related protein Rab-40A|SOCS box-containing protein RAR2A|protein Rar-2', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103499130, end_position_on_the_genomic_accession=103519489, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    142685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142685, CurrentID=0, Status='live', Symbol='ASB15', Aliases=[], description='ankyrin repeat and SOCS box containing 15', other_designations='ankyrin repeat and SOCS box protein 15|epididymis secretory sperm binding protein', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123567003, end_position_on_the_genomic_accession=123639481, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    142686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142686, CurrentID=0, Status='live', Symbol='ASB14', Aliases=[], description='ankyrin repeat and SOCS box containing 14', other_designations='ankyrin repeat and SOCS box protein 14|ankyrin repeat domain-containing SOCS box protein Asb-14', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57268342, end_position_on_the_genomic_accession=57293048, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    142689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142689, CurrentID=0, Status='live', Symbol='ASB12', Aliases=[], description='ankyrin repeat and SOCS box containing 12', other_designations='ankyrin repeat and SOCS box protein 12|ankyrin repeat domain-containing SOCS box protein Asb-12', map_location='Xq11.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=64224194, end_position_on_the_genomic_accession=64230607, orientation='minus', exon_count=3, OMIM=[300891], no_hdr0=''),
    142827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142827, CurrentID=0, Status='live', Symbol='ACSM6', Aliases=['C10orf129', 'bA310E22.3'], description='acyl-CoA synthetase medium chain family member 6', other_designations='acyl-coenzyme A synthetase ACSM6, mitochondrial|AMP-binding enzyme', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95194238, end_position_on_the_genomic_accession=95228929, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    142891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142891, CurrentID=0, Status='live', Symbol='SAMD8', Aliases=['HEL-177', 'SMSr'], description='sterile alpha motif domain containing 8', other_designations='sphingomyelin synthase-related protein 1|CPE synthase|HEL-S-181mP|SAM domain-containing protein 8|ceramide phosphoethanolamine synthase|epididymis luminal protein 177|epididymis secretory sperm binding protein Li 181mP|sphingomyelin synthase related|sterile alpha motif domain-containing protein 8', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75099575, end_position_on_the_genomic_accession=75182123, orientation='plus', exon_count=9, OMIM=[611575], no_hdr0=''),
    142910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142910, CurrentID=0, Status='live', Symbol='LIPJ', Aliases=['LIPL1', 'bA425M17.2'], description='lipase family member J', other_designations='lipase member J|lipase J|lipase-like abhydrolase domain-containing protein 1|lipase-like, ab-hydrolase domain containing 1', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88582907, end_position_on_the_genomic_accession=88623161, orientation='plus', exon_count=15, OMIM=[613921], no_hdr0=''),
    142940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=142940, CurrentID=0, Status='live', Symbol='TRUB1', Aliases=['PUS4'], description='TruB pseudouridine synthase family member 1', other_designations='probable tRNA pseudouridine synthase 1|TruB pseudouridine (psi) synthase family member 1|TruB pseudouridine (psi) synthase homolog 1', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114938195, end_position_on_the_genomic_accession=114977676, orientation='plus', exon_count=8, OMIM=[610726], no_hdr0=''),
    143098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143098, CurrentID=0, Status='live', Symbol='MPP7', Aliases=[], description='membrane palmitoylated protein 7', other_designations='MAGUK p55 subfamily member 7|membrane protein, palmitoylated 7 (MAGUK p55 subfamily member 7)', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=28050993, end_position_on_the_genomic_accession=28303066, orientation='minus', exon_count=22, OMIM=[610973], no_hdr0=''),
    143162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143162, CurrentID=0, Status='live', Symbol='FRMPD2', Aliases=['PDZD5C', 'PDZK4', 'PDZK5C'], description='FERM and PDZ domain containing 2', other_designations='FERM and PDZ domain-containing protein 2|PDZ domain containing 5C|PDZ domain-containing protein 4', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=48156559, end_position_on_the_genomic_accession=48274696, orientation='minus', exon_count=31, OMIM=[613323], no_hdr0=''),
    143187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143187, CurrentID=0, Status='live', Symbol='VTI1A', Aliases=['MMDS3', 'MVti1', 'VTI1RP2', 'Vti1-rp2'], description='vesicle transport through interaction with t-SNAREs 1A', other_designations='vesicle transport through interaction with t-SNAREs homolog 1A|SNARE Vti1a-beta protein|vesicle transport v-SNARE protein Vti1-like 2', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=112446988, end_position_on_the_genomic_accession=112855368, orientation='plus', exon_count=15, OMIM=[614316], no_hdr0=''),
    143241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143241, CurrentID=0, Status='live', Symbol='DYDC1', Aliases=['DPY30D1'], description='DPY30 domain containing 1', other_designations='DPY30 domain-containing protein 1', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80336013, end_position_on_the_genomic_accession=80356787, orientation='minus', exon_count=9, OMIM=[615154], no_hdr0=''),
    143244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143244, CurrentID=0, Status='live', Symbol='EIF5AL1', Aliases=['EIF5A', 'EIF5AP1', 'bA342M3.3', 'eIF-4D', 'eIF-5A', 'eIF-5A-1', 'eIF-5A1'], description='eukaryotic translation initiation factor 5A like 1', other_designations='eukaryotic translation initiation factor 5A-1-like|Eukaryotic translation initiation factor 5A-1|Rev-binding factor|eukaryotic translation initiation factor 5A pseudogene 1', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79512533, end_position_on_the_genomic_accession=79516440, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    143279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143279, CurrentID=0, Status='live', Symbol='HECTD2', Aliases=[], description='HECT domain E3 ubiquitin protein ligase 2', other_designations='probable E3 ubiquitin-protein ligase HECTD2|HECT domain containing E3 ubiquitin protein ligase 2|HECT domain-containing protein 2|HECT-type E3 ubiquitin transferase HECTD2', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91409235, end_position_on_the_genomic_accession=91514820, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    143282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143282, CurrentID=0, Status='live', Symbol='FGFBP3', Aliases=['C10orf13', 'FGF-BP3'], description='fibroblast growth factor binding protein 3', other_designations='fibroblast growth factor-binding protein 3|FGF-binding protein 3|FGFBP-3', map_location='10q23.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=91906584, end_position_on_the_genomic_accession=91909486, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    143379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143379, CurrentID=0, Status='live', Symbol='C10orf82', Aliases=[], description='chromosome 10 open reading frame 82', other_designations='uncharacterized protein C10orf82', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116662211, end_position_on_the_genomic_accession=116670290, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    143384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143384, CurrentID=0, Status='live', Symbol='CACUL1', Aliases=['C10orf46', 'CAC1'], description='CDK2 associated cullin domain 1', other_designations='CDK2-associated and cullin domain-containing protein 1|Cdk-Associated Cullin1|cdk-associated cullin 1|cullin', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=118676411, end_position_on_the_genomic_accession=118754970, orientation='minus', exon_count=9, OMIM=[618764], no_hdr0=''),
    143425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143425, CurrentID=0, Status='live', Symbol='SYT9', Aliases=[], description='synaptotagmin 9', other_designations='synaptotagmin-9|synaptotagmin IX|sytIX', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7238784, end_position_on_the_genomic_accession=7470032, orientation='plus', exon_count=12, OMIM=[613528], no_hdr0=''),
    143458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143458, CurrentID=0, Status='live', Symbol='LDLRAD3', Aliases=['LRAD3'], description='low density lipoprotein receptor class A domain containing 3', other_designations='low-density lipoprotein receptor class A domain-containing protein 3|LDLR class A domain-containing protein 3', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=35944062, end_position_on_the_genomic_accession=36232136, orientation='plus', exon_count=7, OMIM=[617986], no_hdr0=''),
    143471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143471, CurrentID=0, Status='live', Symbol='PSMA8', Aliases=['PSMA7L'], description='proteasome 20S subunit alpha 8', other_designations='proteasome subunit alpha-type 8|alpha4s|proteasome (prosome, macropain) subunit, alpha type, 8|proteasome alpha 4 subunit|proteasome subunit alpha 8|proteasome subunit alpha type 7-like protein variant 1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26133869, end_position_on_the_genomic_accession=26193355, orientation='plus', exon_count=8, OMIM=[617841], no_hdr0=''),
    143496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143496, CurrentID=0, Status='live', Symbol='OR52B4', Aliases=['OR11-3'], description='olfactory receptor family 52 subfamily B member 4', other_designations='olfactory receptor 52B4|olfactory receptor OR11-3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4367263, end_position_on_the_genomic_accession=4368386, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    143501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143501, CurrentID=0, Status='live', Symbol='C11orf40', Aliases=['NOV1'], description='chromosome 11 putative open reading frame 40', other_designations='putative uncharacterized protein C11orf40|ro/SSA1-related protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4571423, end_position_on_the_genomic_accession=4577820, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    143502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143502, CurrentID=0, Status='live', Symbol='OR52I2', Aliases=['OR11-12', 'OR52I1'], description='olfactory receptor family 52 subfamily I member 2', other_designations='olfactory receptor 52I2|olfactory receptor OR11-12', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4586791, end_position_on_the_genomic_accession=4587905, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    143503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143503, CurrentID=0, Status='live', Symbol='OR51E1', Aliases=['D-GPCR', 'DGPCR', 'GPR136', 'GPR164P', 'OR52A3P', 'POGR', 'PSGR2', 'OR51E1'], description='olfactory receptor family 51 subfamily E member 1', other_designations='olfactory receptor 51E1|Dresden-G-protein-coupled receptor|G-protein coupled receptor 164|olfactory receptor 52A3|olfactory receptor OR11-15|olfactory receptor, family 51, subfamily E, member 1 pseudogene|olfactory receptor, family 52, subfamily A, member 3 pseudogene|prostate overexpressed G protein-coupled receptor|prostate-specific G protein-coupled receptor 2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4643982, end_position_on_the_genomic_accession=4655488, orientation='plus', exon_count=2, OMIM=[611267], no_hdr0=''),
    143570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143570, CurrentID=0, Status='live', Symbol='XRRA1', Aliases=[], description='X-ray radiation resistance associated 1', other_designations='X-ray radiation resistance-associated protein 1', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74840910, end_position_on_the_genomic_accession=74949187, orientation='minus', exon_count=20, OMIM=[609788], no_hdr0=''),
    143630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143630, CurrentID=0, Status='live', Symbol='UBQLNL', Aliases=[], description='ubiquilin like', other_designations='ubiquilin-like protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5514393, end_position_on_the_genomic_accession=5516699, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    143662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143662, CurrentID=0, Status='live', Symbol='MUC15', Aliases=['MUC-15', 'PAS3', 'PASIII'], description='mucin 15, cell surface associated', other_designations='mucin-15', map_location='11p14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=26559032, end_position_on_the_genomic_accession=26572263, orientation='minus', exon_count=5, OMIM=[608566], no_hdr0=''),
    143678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143678, CurrentID=0, Status='live', Symbol='C11orf94', Aliases=[], description='chromosome 11 open reading frame 94', other_designations='uncharacterized protein C11orf94', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=45906534, end_position_on_the_genomic_accession=45907271, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    143684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143684, CurrentID=0, Status='live', Symbol='FAM76B', Aliases=[], description='family with sequence similarity 76 member B', other_designations='protein FAM76B', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95768953, end_position_on_the_genomic_accession=95790396, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    143686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143686, CurrentID=0, Status='live', Symbol='SESN3', Aliases=['SEST3'], description='sestrin 3', other_designations='sestrin-3', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95165513, end_position_on_the_genomic_accession=95232536, orientation='minus', exon_count=12, OMIM=[607768], no_hdr0=''),
    143689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143689, CurrentID=0, Status='live', Symbol='PIWIL4', Aliases=['HIWI2', 'MIWI2'], description='piwi like RNA-mediated gene silencing 4', other_designations='piwi-like protein 4|piwi-like 4|testis tissue sperm-binding protein Li 85P', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94567368, end_position_on_the_genomic_accession=94621421, orientation='plus', exon_count=20, OMIM=[610315], no_hdr0=''),
    143872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143872, CurrentID=0, Status='live', Symbol='ARHGAP42', Aliases=['AD031', 'GRAF3', 'TMEM133'], description='Rho GTPase activating protein 42', other_designations='rho GTPase-activating protein 42|rho-type GTPase-activating protein 42|transmembrane protein 133', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=100687288, end_position_on_the_genomic_accession=100993941, orientation='plus', exon_count=29, OMIM=[615936], no_hdr0=''),
    143879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143879, CurrentID=0, Status='live', Symbol='KBTBD3', Aliases=['BKLHD3'], description='kelch repeat and BTB domain containing 3', other_designations='kelch repeat and BTB domain-containing protein 3|BTB and kelch domain containing 3|BTB and kelch domain-containing protein 3|epididymis secretory sperm binding protein|kelch repeat and BTB (POZ) domain containing 3', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=106046801, end_position_on_the_genomic_accession=106077765, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    143884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143884, CurrentID=0, Status='live', Symbol='CWF19L2', Aliases=[], description='CWF19 like cell cycle control factor 2', other_designations='CWF19-like protein 2|CWF19 like 2, cell cycle control', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107326356, end_position_on_the_genomic_accession=107457839, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    143888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143888, CurrentID=0, Status='live', Symbol='POGLUT3', Aliases=['KDELC2'], description='protein O-glucosyltransferase 3', other_designations='protein O-glucosyltransferase 3|KDEL (Lys-Asp-Glu-Leu) containing 2|KDEL motif containing 2|KDEL motif-containing protein 2|protein O-xylosyltransferase POGLUT3', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108472116, end_position_on_the_genomic_accession=108498384, orientation='minus', exon_count=9, OMIM=[618503], no_hdr0=''),
    143903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143903, CurrentID=0, Status='live', Symbol='LAYN', Aliases=[], description='layilin', other_designations='layilin', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111540280, end_position_on_the_genomic_accession=111561745, orientation='plus', exon_count=9, OMIM=[618843], no_hdr0=''),
    143941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=143941, CurrentID=0, Status='live', Symbol='TTC36', Aliases=['HBP21'], description='tetratricopeptide repeat domain 36', other_designations='tetratricopeptide repeat protein 36|HSP70 binding protein 21|TPR repeat protein 36', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118527474, end_position_on_the_genomic_accession=118530993, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    144097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144097, CurrentID=0, Status='live', Symbol='SPINDOC', Aliases=['C11orf84', 'SPIN-DOC'], description='spindlin interactor and repressor of chromatin binding', other_designations='spindlin interactor and repressor of chromatin-binding protein|SPIN1 docking protein|hypothetical protein BC007540|uncharacterized protein C11orf84', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63813374, end_position_on_the_genomic_accession=63827718, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    144100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144100, CurrentID=0, Status='live', Symbol='PLEKHA7', Aliases=[], description='pleckstrin homology domain containing A7', other_designations='pleckstrin homology domain-containing family A member 7|PH domain-containing family A member 7|pleckstrin homology domain containing, family A member 2|pleckstrin homology domain containing, family A member 7|pleckstrin homology domain-containing family A member 6', map_location='11p15.2-p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=16777297, end_position_on_the_genomic_accession=17014423, orientation='minus', exon_count=37, OMIM=[612686], no_hdr0=''),
    144108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144108, CurrentID=0, Status='live', Symbol='SPTY2D1', Aliases=['Spt2'], description='SPT2 chromatin protein domain containing 1', other_designations='protein SPT2 homolog|SPT2 domain-containing protein 1|SPT2, Suppressor of Ty, domain containing 1', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18606401, end_position_on_the_genomic_accession=18634823, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    144110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144110, CurrentID=0, Status='live', Symbol='TMEM86A', Aliases=[], description='transmembrane protein 86A', other_designations='lysoplasmalogenase-like protein TMEM86A', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18698779, end_position_on_the_genomic_accession=18704785, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    144124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144124, CurrentID=0, Status='live', Symbol='OR10A5', Aliases=['JCG6', 'OR10A1', 'OR11-403'], description='olfactory receptor family 10 subfamily A member 5', other_designations='olfactory receptor 10A5|HP3|olfactory receptor 10A1|olfactory receptor 11-403|olfactory receptor OR11-85|olfactory receptor, family 10, subfamily A, member 1|olfactory receptor-like protein JCG6', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6845683, end_position_on_the_genomic_accession=6846636, orientation='plus', exon_count=1, OMIM=[608493], no_hdr0=''),
    144125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144125, CurrentID=0, Status='live', Symbol='OR2AG1', Aliases=['OR11-79', 'OR2AG3'], description='olfactory receptor family 2 subfamily AG member 1', other_designations='olfactory receptor 2AG1|hT3 olfactory receptor|olfactory receptor 2AG3|olfactory receptor OR11-79|olfactory receptor, family 2, subfamily AG, member 3', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6783020, end_position_on_the_genomic_accession=6791558, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    144132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144132, CurrentID=0, Status='live', Symbol='DNHD1', Aliases=['C11orf47', 'CCDC35', 'DHCD1L', 'DNHD1'], description='dynein heavy chain domain 1', other_designations='dynein heavy chain domain-containing protein 1|DNHD1 variant protein|coiled-coil domain containing 35|dynein heavy chain domain 1-like protein', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6497280, end_position_on_the_genomic_accession=6572020, orientation='plus', exon_count=41, OMIM=[617277], no_hdr0=''),
    144165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144165, CurrentID=0, Status='live', Symbol='PRICKLE1', Aliases=['EPM1B', 'RILP'], description='prickle planar cell polarity protein 1', other_designations='prickle-like protein 1|REST (RE-1 silencing transcription factor)/NRSF (neuron-restrictive silencer factor)-interacting LIM domain protein|REST/NRSF interacting LIM domain protein|REST/NRSF-interacting LIM domain protein 1|prickle homolog 1|prickle-like 1', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=42456757, end_position_on_the_genomic_accession=42589755, orientation='minus', exon_count=13, OMIM=[608500], no_hdr0=''),
    144193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144193, CurrentID=0, Status='live', Symbol='AMDHD1', Aliases=['HMFT1272'], description='amidohydrolase domain containing 1', other_designations='probable imidazolonepropionase|amidohydrolase domain-containing protein 1', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=95943331, end_position_on_the_genomic_accession=95968720, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    144195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144195, CurrentID=0, Status='live', Symbol='SLC2A14', Aliases=['GLUT14', 'SLC2A3P3'], description='solute carrier family 2 member 14', other_designations='solute carrier family 2, facilitated glucose transporter member 14|glucose transporter type 14|solute carrier family 2 (facilitated glucose transporter), member 14|solute carrier family 2 (facilitated glucose transporter), member 3 pseudogene 3', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7812514, end_position_on_the_genomic_accession=7891196, orientation='minus', exon_count=21, OMIM=[611039], no_hdr0=''),
    144233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144233, CurrentID=0, Status='live', Symbol='BCDIN3D', Aliases=[], description='BCDIN3 domain containing RNA methyltransferase', other_designations="RNA 5'-monophosphate methyltransferase|BCDIN3 domain containing RNA methyltransfease|BCDIN3 domain-containing protein|pre-miRNA 5'-monophosphate methyltransferase|probable methyltransferase BCDIN3D", map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49836043, end_position_on_the_genomic_accession=49843106, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    144245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144245, CurrentID=0, Status='live', Symbol='ALG10B', Aliases=['ALG10', 'KCR1'], description='ALG10 alpha-1,2-glucosyltransferase B', other_designations='putative Dol-P-Glc:Glc(2)Man(9)GlcNAc(2)-PP-Dol alpha-1,2-glucosyltransferase|ALG10B, alpha-1,2-glucosyltransferase|alpha-1,2-glucosyltransferase ALG10-A|alpha-2-glucosyltransferase ALG10-B|asparagine-linked glycosylation 10 homolog B (yeast, alpha-1,2-glucosyltransferase)|asparagine-linked glycosylation 10, alpha-1,2-glucosyltransferase homolog B|asparagine-linked glycosylation protein 10 homolog B|dolichyl-P-Glc:Glc(2)Man(9)GlcNAc(2)-PP-dolichol alpha-1,2- glucosyltransferase|modifier of the HERG potassium channel|potassium channel regulator 1|putative alpha-1,2-glucosyltransferase ALG10-B', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=38316679, end_position_on_the_genomic_accession=38329725, orientation='plus', exon_count=4, OMIM=[603313], no_hdr0=''),
    144321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144321, CurrentID=0, Status='live', Symbol='GLIPR1L2', Aliases=[], description='GLIPR1 like 2', other_designations='GLIPR1-like protein 2|GLI pathogenesis related 1 like 2', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75391089, end_position_on_the_genomic_accession=75432688, orientation='plus', exon_count=8, OMIM=[610394], no_hdr0=''),
    144347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144347, CurrentID=0, Status='live', Symbol='RFLNA', Aliases=['CFM2', 'FAM101A'], description='refilin A', other_designations='refilin-A|family with sequence similarity 101, member A|filamin-interacting protein FAM101A|protein FAM101A|refilinA|regulator of filamin protein A', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=124289164, end_position_on_the_genomic_accession=124316024, orientation='plus', exon_count=4, OMIM=[615927], no_hdr0=''),
    144348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144348, CurrentID=0, Status='live', Symbol='ZNF664', Aliases=['ZFOC1', 'ZNF176'], description='zinc finger protein 664', other_designations='zinc finger protein 664|zinc finger Organ of Corti 1|zinc finger protein 176|zinc finger protein from organ of Corti', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123973215, end_position_on_the_genomic_accession=124015427, orientation='plus', exon_count=5, OMIM=[617890], no_hdr0=''),
    144363 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144363, CurrentID=0, Status='live', Symbol='ETFRF1', Aliases=['LYRM5'], description='electron transfer flavoprotein regulatory factor 1', other_designations='electron transfer flavoprotein regulatory factor 1|LYR motif containing 5|LYR motif-containing protein 5', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=25195217, end_position_on_the_genomic_accession=25205143, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    144402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144402, CurrentID=0, Status='live', Symbol='CPNE8', Aliases=[], description='copine 8', other_designations='copine-8|copine VIII', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=38652200, end_position_on_the_genomic_accession=38906269, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    144404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144404, CurrentID=0, Status='live', Symbol='TMEM120B', Aliases=[], description='transmembrane protein 120B', other_designations='transmembrane protein 120B', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121712752, end_position_on_the_genomic_accession=121782068, orientation='plus', exon_count=13, OMIM=[616551], no_hdr0=''),
    144406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144406, CurrentID=0, Status='live', Symbol='CFAP251', Aliases=['CaM-IP4', 'SPGF33', 'WDR66'], description='cilia and flagella associated protein 251', other_designations='cilia- and flagella-associated protein 251|WD repeat domain 66|WD repeat-containing protein 66', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121918592, end_position_on_the_genomic_accession=122003919, orientation='plus', exon_count=23, OMIM=[618146], no_hdr0=''),
    144423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144423, CurrentID=0, Status='live', Symbol='GLT1D1', Aliases=[], description='glycosyltransferase 1 domain containing 1', other_designations='glycosyltransferase 1 domain-containing protein 1', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=128853323, end_position_on_the_genomic_accession=128984968, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    144448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144448, CurrentID=0, Status='live', Symbol='TSPAN19', Aliases=[], description='tetraspanin 19', other_designations='tetraspanin-19|putative tetraspanin-19|tspan-19', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=85014311, end_position_on_the_genomic_accession=85036278, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    144453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144453, CurrentID=0, Status='live', Symbol='BEST3', Aliases=['VMD2L3'], description='bestrophin 3', other_designations='bestrophin-3|vitelliform macular dystrophy 2-like 3|vitelliform macular dystrophy 2-like protein 3', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69643508, end_position_on_the_genomic_accession=69699303, orientation='minus', exon_count=14, OMIM=[607337], no_hdr0=''),
    144455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144455, CurrentID=0, Status='live', Symbol='E2F7', Aliases=[], description='E2F transcription factor 7', other_designations='transcription factor E2F7|E2F-7', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=77021251, end_position_on_the_genomic_accession=77065580, orientation='minus', exon_count=14, OMIM=[612046], no_hdr0=''),
    144501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144501, CurrentID=0, Status='live', Symbol='KRT80', Aliases=['KB20'], description='keratin 80', other_designations='keratin, type II cytoskeletal 80|CK-80|K80|cytokeratin-80|keratin 80, type II|keratin b20|type II keratin|type-II keratin Kb20', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52168996, end_position_on_the_genomic_accession=52192014, orientation='minus', exon_count=9, OMIM=[611161], no_hdr0=''),
    144535 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144535, CurrentID=0, Status='live', Symbol='CFAP54', Aliases=['C12orf55', 'C12orf63'], description='cilia and flagella associated protein 54', other_designations='cilia- and flagella-associated protein 54|cilia and flagella associated 54', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=96489577, end_position_on_the_genomic_accession=96875555, orientation='plus', exon_count=69, OMIM=[], no_hdr0=''),
    144568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144568, CurrentID=0, Status='live', Symbol='A2ML1', Aliases=['CPAMD9', 'OMS', 'p170'], description='alpha-2-macroglobulin like 1', other_designations='alpha-2-macroglobulin-like protein 1|C3 and PZP-like, alpha-2-macroglobulin domain containing 9', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8822554, end_position_on_the_genomic_accession=8887202, orientation='plus', exon_count=40, OMIM=[610627], no_hdr0=''),
    144577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144577, CurrentID=0, Status='live', Symbol='KICS2', Aliases=['C12orf66'], description='KICSTOR subunit 2', other_designations='KICSTOR subunit 2|KICSTOR complex protein C12orf66|UPF0536 protein C12orf66', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64186316, end_position_on_the_genomic_accession=64222296, orientation='minus', exon_count=4, OMIM=[617420], no_hdr0=''),
    144608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144608, CurrentID=0, Status='live', Symbol='C12orf60', Aliases=[], description='chromosome 12 open reading frame 60', other_designations='uncharacterized protein C12orf60', map_location='12p13.1-p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14567991, end_position_on_the_genomic_accession=14824415, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    144699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144699, CurrentID=0, Status='live', Symbol='FBXL14', Aliases=['Fbl14'], description='F-box and leucine rich repeat protein 14', other_designations='F-box/LRR-repeat protein 14', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1559641, end_position_on_the_genomic_accession=1594581, orientation='minus', exon_count=4, OMIM=[609081], no_hdr0=''),
    144715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144715, CurrentID=0, Status='live', Symbol='RAD9B', Aliases=[], description='RAD9 checkpoint clamp component B', other_designations='cell cycle checkpoint control protein RAD9B|DNA repair exonuclease rad9 homolog B|RAD9 homolog B', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110501651, end_position_on_the_genomic_accession=110534632, orientation='plus', exon_count=13, OMIM=[608368], no_hdr0=''),
    144717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144717, CurrentID=0, Status='live', Symbol='PHETA1', Aliases=['FAM109A', 'IPIP27A', 'SES1'], description='PH domain containing endocytic trafficking adaptor 1', other_designations='sesquipedalian-1|27 kDa inositol polyphosphate phosphatase-interacting protein A|family with sequence similarity 109 member A|inositol polyphosphate phosphatase-interacting protein A|protein FAM109A', map_location='12q24.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=111360679, end_position_on_the_genomic_accession=111369095, orientation='minus', exon_count=6, OMIM=[614239], no_hdr0=''),
    144809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144809, CurrentID=0, Status='live', Symbol='FAM216B', Aliases=['C13orf30'], description='family with sequence similarity 216 member B', other_designations='protein FAM216B', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=42781584, end_position_on_the_genomic_accession=42791549, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    144811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144811, CurrentID=0, Status='live', Symbol='LACC1', Aliases=['C13orf31', 'FAMIN', 'JUVAR'], description='laccase domain containing 1', other_designations="purine nucleoside phosphorylase LACC1|S-methyl-5'-thioadenosine phosphorylase LACC1|adenosine deaminase LACC1|fatty acid metabolism-immunity nexus|guanosine phosphorylase LACC1|laccase (multicopper oxidoreductase) domain containing 1|laccase domain-containing protein 1", map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=43879178, end_position_on_the_genomic_accession=43893932, orientation='plus', exon_count=10, OMIM=[613409], no_hdr0=''),
    144983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=144983, CurrentID=0, Status='live', Symbol='HNRNPA1L2', Aliases=[], description='heterogeneous nuclear ribonucleoprotein A1 like 2', other_designations='heterogeneous nuclear ribonucleoprotein A1-like 2|hnRNP A1-like 2|hnRNP core protein A1-like 2', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52617525, end_position_on_the_genomic_accession=52643773, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    145173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145173, CurrentID=0, Status='live', Symbol='B3GLCT', Aliases=['B3GALTL', 'B3GTL', 'B3Glc-T', 'Gal-T', 'beta3Glc-T'], description='beta 3-glucosyltransferase', other_designations='beta-1,3-glucosyltransferase|UDP-GAL:beta-GlcNAc beta-1,3-galactosyltransferase-like|beta 1,3-galactosyltransferase-like|beta 3-glycosyltransferase-like', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=31199975, end_position_on_the_genomic_accession=31332276, orientation='plus', exon_count=20, OMIM=[610308], no_hdr0=''),
    145226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145226, CurrentID=0, Status='live', Symbol='RDH12', Aliases=['LCA13', 'RP53', 'SDR7C2'], description='retinol dehydrogenase 12', other_designations='retinol dehydrogenase 12|all-trans and 9-cis retinol dehydrogenase|retinol dehydrogenase 12 (all-trans/9-cis/11-cis)|retinol dehydrogenase 12, all-trans and 9-cis|short chain dehydrogenase/reductase family 7C member 2', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67701886, end_position_on_the_genomic_accession=67734451, orientation='plus', exon_count=9, OMIM=[608830], no_hdr0=''),
    145258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145258, CurrentID=0, Status='live', Symbol='GSC', Aliases=['SAMS'], description='goosecoid homeobox', other_designations='homeobox protein goosecoid', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94768223, end_position_on_the_genomic_accession=94770113, orientation='minus', exon_count=3, OMIM=[138890], no_hdr0=''),
    145264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145264, CurrentID=0, Status='live', Symbol='SERPINA12', Aliases=['OL-64'], description='serpin family A member 12', other_designations='serpin A12|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 12|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 12|vaspin|visceral adipose tissue-derived serine protease inhibitor|visceral adipose-specific SERPIN', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94481651, end_position_on_the_genomic_accession=94517844, orientation='minus', exon_count=9, OMIM=[617471], no_hdr0=''),
    145270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145270, CurrentID=0, Status='live', Symbol='PRIMA1', Aliases=['PRIMA'], description='proline rich membrane anchor 1', other_designations='proline-rich membrane anchor 1|acetylcholinesterase membrane anchor precursor PRiMA', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93718298, end_position_on_the_genomic_accession=93789029, orientation='minus', exon_count=9, OMIM=[613851], no_hdr0=''),
    145282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145282, CurrentID=0, Status='live', Symbol='MIPOL1', Aliases=['CCDC193'], description='mirror-image polydactyly 1', other_designations='mirror-image polydactyly gene 1 protein', map_location='14q13.3-q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=37197930, end_position_on_the_genomic_accession=37579207, orientation='plus', exon_count=29, OMIM=[606850], no_hdr0=''),
    145376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145376, CurrentID=0, Status='live', Symbol='PPP1R36', Aliases=['C14orf50'], description='protein phosphatase 1 regulatory subunit 36', other_designations='protein phosphatase 1 regulatory subunit 36', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64549896, end_position_on_the_genomic_accession=64589386, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    145389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145389, CurrentID=0, Status='live', Symbol='SLC38A6', Aliases=['NAT-1', 'SNAT6'], description='solute carrier family 38 member 6', other_designations='probable sodium-coupled neutral amino acid transporter 6|N system amino acid transporter NAT-1|N-system amino acid transporter 1|Na(+)-coupled neutral amino acid transporter 6', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60981122, end_position_on_the_genomic_accession=61083733, orientation='plus', exon_count=26, OMIM=[616518], no_hdr0=''),
    145407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145407, CurrentID=0, Status='live', Symbol='ARMH4', Aliases=['C14orf37', 'UT2', 'c14_5376'], description='armadillo like helical domain containing 4', other_designations='armadillo-like helical domain-containing protein 4|uncharacterized protein C14orf37|upstream of mTORC2', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57993536, end_position_on_the_genomic_accession=58152305, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    145447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145447, CurrentID=0, Status='live', Symbol='ABHD12B', Aliases=['BEM46L3', 'C14orf29', 'c14_5314'], description='abhydrolase domain containing 12B', other_designations='protein ABHD12B|abhydrolase domain-containing protein 12B|alpha/beta hydrolase domain-containing protein 12B', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=50872053, end_position_on_the_genomic_accession=50904970, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    145482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145482, CurrentID=0, Status='live', Symbol='PTGR2', Aliases=['HEL-S-298', 'PGR2', 'ZADH1'], description='prostaglandin reductase 2', other_designations='prostaglandin reductase 2|15-oxoprostaglandin 13-reductase|15-oxoprostaglandin-delta13-reductase|PRG-2|epididymis secretory protein Li 298|epididymis secretory sperm binding protein|zinc binding alcohol dehydrogenase, domain containing 1|zinc-binding alcohol dehydrogenase domain-containing protein 1', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73851831, end_position_on_the_genomic_accession=73885726, orientation='plus', exon_count=13, OMIM=[608642], no_hdr0=''),
    145483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145483, CurrentID=0, Status='live', Symbol='FAM161B', Aliases=['C14orf44', 'c14_5547'], description='FAM161 centrosomal protein B', other_designations='protein FAM161B|FAM161B, centrosomal protein|family with sequence similarity 161 member B', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73932031, end_position_on_the_genomic_accession=73950291, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    145497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145497, CurrentID=0, Status='live', Symbol='LRRC74A', Aliases=['C14orf166B', 'LRRC74'], description='leucine rich repeat containing 74A', other_designations='leucine-rich repeat-containing protein 74A|leucine rich repeat containing 74|leucine-rich repeat-containing protein 74', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=76826385, end_position_on_the_genomic_accession=76870304, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    145501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145501, CurrentID=0, Status='live', Symbol='ISM2', Aliases=['TAIL1', 'THSD3'], description='isthmin 2', other_designations='isthmin-2|isthmin 2 homolog|thrombospondin and AMOP containing isthmin-like 1|thrombospondin and AMOP domain-containing isthmin-like protein 1|thrombospondin type-1 domain-containing protein 3|thrombospondin, type I, domain containing 3', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77474394, end_position_on_the_genomic_accession=77498816, orientation='minus', exon_count=8, OMIM=[612684], no_hdr0=''),
    145508 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145508, CurrentID=0, Status='live', Symbol='CEP128', Aliases=['C14orf145', 'C14orf61', 'LEDP/132'], description='centrosomal protein 128', other_designations='centrosomal protein of 128 kDa|centrosomal protein 128kDa|lens epithelium-derived protein', map_location='14q31.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=80478321, end_position_on_the_genomic_accession=80959501, orientation='minus', exon_count=32, OMIM=[], no_hdr0=''),
    145553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145553, CurrentID=0, Status='live', Symbol='MDP1', Aliases=['FN6PASE', 'MDP-1'], description='magnesium dependent phosphatase 1', other_designations='magnesium-dependent phosphatase 1|fructosamine-6-phosphatase', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24213943, end_position_on_the_genomic_accession=24216066, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    145567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145567, CurrentID=0, Status='live', Symbol='TTC7B', Aliases=['TTC7L1', 'c14_5685'], description='tetratricopeptide repeat domain 7B', other_designations='tetratricopeptide repeat protein 7B|TPR repeat protein 7-like-1|TPR repeat protein 7B|tetratricopeptide repeat domain 7 like 1|tetratricopeptide repeat protein 7-like-1', map_location='14q32.11', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=90524564, end_position_on_the_genomic_accession=90816479, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    145581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145581, CurrentID=0, Status='live', Symbol='LRFN5', Aliases=['C14orf146', 'FIGLER8', 'SALM5'], description='leucine rich repeat and fibronectin type III domain containing 5', other_designations='leucine-rich repeat and fibronectin type-III domain-containing protein 5|fibronectin type III, immunoglobulin and leucine rich repeat domains 8', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=41606876, end_position_on_the_genomic_accession=41904549, orientation='plus', exon_count=9, OMIM=[612811], no_hdr0=''),
    145645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145645, CurrentID=0, Status='live', Symbol='TERB2', Aliases=['C15orf43'], description='telomere repeat binding bouquet formation protein 2', other_designations='telomere repeats-binding bouquet formation protein 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44956674, end_position_on_the_genomic_accession=44979229, orientation='plus', exon_count=8, OMIM=[617131], no_hdr0=''),
    145741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145741, CurrentID=0, Status='live', Symbol='C2CD4A', Aliases=['FAM148A', 'NLF1'], description='C2 calcium dependent domain containing 4A', other_designations='C2 calcium-dependent domain-containing protein 4A|family with sequence similarity 148, member A|nuclear localized factor 1', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=62066977, end_position_on_the_genomic_accession=62070917, orientation='plus', exon_count=2, OMIM=[610343], no_hdr0=''),
    145748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145748, CurrentID=0, Status='live', Symbol='LYSMD4', Aliases=[], description='LysM domain containing 4', other_designations='lysM and putative peptidoglycan-binding domain-containing protein 4|LysM, putative peptidoglycan-binding, domain containing 4', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99714798, end_position_on_the_genomic_accession=99733458, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    145773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145773, CurrentID=0, Status='live', Symbol='FAM81A', Aliases=[], description='family with sequence similarity 81 member A', other_designations='protein FAM81A', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=59399662, end_position_on_the_genomic_accession=59523555, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    145781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145781, CurrentID=0, Status='live', Symbol='GCOM1', Aliases=['GRINL1A', 'Gcom2', 'MYZAP', 'MYZAP-POLR2M', 'gcom'], description='GCOM1, MYZAP-POLR2M combined locus', other_designations='GRINL1A combined protein|DNA-directed RNA polymerase II subunit GRINL1A|DNA-directed RNA polymerase II subunit M|GRINL1A combined protein Gcom12|GRINL1A complex locus 1|Glutamate receptor-like protein 1A|MYZAP-POLR2M readthrough|NMDAR1 subunit-interacting protein|glutamate receptor, ionotropic, N-methyl D-aspartate-like 1A combined protein|myocardial zonula adherens protein', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=57591904, end_position_on_the_genomic_accession=57717557, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    145788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145788, CurrentID=0, Status='live', Symbol='C15orf65', Aliases=[], description='chromosome 15 open reading frame 65', other_designations='uncharacterized protein C15orf65', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55408495, end_position_on_the_genomic_accession=55418798, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    145814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145814, CurrentID=0, Status='live', Symbol='PGPEP1L', Aliases=[], description='pyroglutamyl-peptidase I like', other_designations='pyroglutamyl-peptidase 1-like protein', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=98968229, end_position_on_the_genomic_accession=99007792, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    145853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145853, CurrentID=0, Status='live', Symbol='C15orf61', Aliases=[], description='chromosome 15 open reading frame 61', other_designations='uncharacterized protein C15orf61', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67521131, end_position_on_the_genomic_accession=67530146, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    145864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145864, CurrentID=0, Status='live', Symbol='HAPLN3', Aliases=['EXLD1', 'HsT19883'], description='hyaluronan and proteoglycan link protein 3', other_designations='hyaluronan and proteoglycan link protein 3|extracellular link domain containing, 1', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=88877294, end_position_on_the_genomic_accession=88895606, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    145873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145873, CurrentID=0, Status='live', Symbol='MESP2', Aliases=['SCDO2', 'bHLHc6'], description='mesoderm posterior bHLH transcription factor 2', other_designations='mesoderm posterior protein 2|class C basic helix-loop-helix protein 6|mesoderm posterior 2 homolog|mesoderm posterior basic helix-loop-helix transcription factor 2', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89776332, end_position_on_the_genomic_accession=89778754, orientation='plus', exon_count=2, OMIM=[605195], no_hdr0=''),
    145942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145942, CurrentID=0, Status='live', Symbol='TMCO5A', Aliases=['TMCO5'], description='transmembrane and coiled-coil domains 5A', other_designations='transmembrane and coiled-coil domain-containing protein 5A|testicular tissue protein Li 205|transmembrane and coiled-coil domains 5', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=37934626, end_position_on_the_genomic_accession=37997541, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    145957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=145957, CurrentID=0, Status='live', Symbol='NRG4', Aliases=['HRG4'], description='neuregulin 4', other_designations='pro-neuregulin-4, membrane-bound isoform|heregulin 4|pro-NRG4', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75933219, end_position_on_the_genomic_accession=76069830, orientation='minus', exon_count=14, OMIM=[610894], no_hdr0=''),
    146050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146050, CurrentID=0, Status='live', Symbol='ZSCAN29', Aliases=['ZNF690', 'Zfp690'], description='zinc finger and SCAN domain containing 29', other_designations='zinc finger and SCAN domain-containing protein 29|KOX31-like zinc finger protein|zinc finger protein 690', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43358175, end_position_on_the_genomic_accession=43371043, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    146057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146057, CurrentID=0, Status='live', Symbol='TTBK2', Aliases=['SCA11', 'TTBK'], description='tau tubulin kinase 2', other_designations='tau-tubulin kinase 2', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42738730, end_position_on_the_genomic_accession=42920995, orientation='minus', exon_count=18, OMIM=[611695], no_hdr0=''),
    146059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146059, CurrentID=0, Status='live', Symbol='CDAN1', Aliases=['CDA1', 'CDAIA', 'DLT', 'PRO1295', 'CDAN1'], description='codanin 1', other_designations='codanin-1|congenital dyserythropoietic anemia, type I|discs lost homolog', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42723544, end_position_on_the_genomic_accession=42737133, orientation='minus', exon_count=28, OMIM=[607465], no_hdr0=''),
    146167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146167, CurrentID=0, Status='live', Symbol='SLC38A8', Aliases=['FVH2'], description='solute carrier family 38 member 8', other_designations='putative sodium-coupled neutral amino acid transporter 8', map_location='16q23.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84009667, end_position_on_the_genomic_accession=84043372, orientation='minus', exon_count=12, OMIM=[615585], no_hdr0=''),
    146177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146177, CurrentID=0, Status='live', Symbol='VWA3A', Aliases=[], description='von Willebrand factor A domain containing 3A', other_designations='von Willebrand factor A domain-containing protein 3A', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22091929, end_position_on_the_genomic_accession=22156966, orientation='plus', exon_count=39, OMIM=[], no_hdr0=''),
    146183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146183, CurrentID=0, Status='live', Symbol='OTOA', Aliases=['CT108', 'DFNB22'], description='otoancorin', other_designations='otoancorin|cancer/testis antigen 108', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21663968, end_position_on_the_genomic_accession=21762625, orientation='plus', exon_count=33, OMIM=[607038], no_hdr0=''),
    146198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146198, CurrentID=0, Status='live', Symbol='ZFP90', Aliases=['FIK', 'NK10', 'ZNF756', 'zfp-90'], description='ZFP90 zinc finger protein', other_designations='zinc finger protein 90 homolog|FOXP3-interacting KRAB domain-containing protein|zinc finger protein 476|zinc finger protein 756', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68530249, end_position_on_the_genomic_accession=68576072, orientation='plus', exon_count=8, OMIM=[609451], no_hdr0=''),
    146206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146206, CurrentID=0, Status='live', Symbol='CARMIL2', Aliases=['CARMIL2b', 'IMD58', 'LRRC16C', 'RLTPR'], description='capping protein regulator and myosin 1 linker 2', other_designations='capping protein, Arp2/3 and myosin-I linker protein 2|F-actin-uncapping protein RLTPR|RGD motif, leucine rich repeats, tropomodulin domain and proline-rich containing|RGD, leucine-rich repeat, tropomodulin and proline-rich containing protein|leucine rich repeat containing 16C|leucine-rich repeat-containing protein 16C', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67645004, end_position_on_the_genomic_accession=67657569, orientation='plus', exon_count=39, OMIM=[610859], no_hdr0=''),
    146212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146212, CurrentID=0, Status='live', Symbol='KCTD19', Aliases=[], description='potassium channel tetramerization domain containing 19', other_designations='BTB/POZ domain-containing protein KCTD19|potassium channel tetramerisation domain containing 19|testicular tissue protein Li 101', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67289432, end_position_on_the_genomic_accession=67326741, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    146223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146223, CurrentID=0, Status='live', Symbol='CMTM4', Aliases=['CKLFSF4'], description='CKLF like MARVEL transmembrane domain containing 4', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 4|chemokine-like factor super family 4|chemokine-like factor superfamily member 4', map_location='16q21-q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66598178, end_position_on_the_genomic_accession=66696743, orientation='minus', exon_count=7, OMIM=[607887], no_hdr0=''),
    146225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146225, CurrentID=0, Status='live', Symbol='CMTM2', Aliases=['CKLFSF2'], description='CKLF like MARVEL transmembrane domain containing 2', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 2|chemokine-like factor superfamily 2|chemokine-like factor superfamily member 2', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66579463, end_position_on_the_genomic_accession=66588275, orientation='plus', exon_count=4, OMIM=[607885], no_hdr0=''),
    146227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146227, CurrentID=0, Status='live', Symbol='BEAN1', Aliases=['BEAN', 'SCA31'], description='brain expressed associated with NEDD4 1', other_designations='protein BEAN1|brain-expressed protein associating with Nedd4 homolog', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66427295, end_position_on_the_genomic_accession=66495288, orientation='plus', exon_count=13, OMIM=[612051], no_hdr0=''),
    146279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146279, CurrentID=0, Status='live', Symbol='TEKT5', Aliases=['CT149'], description='tektin 5', other_designations='tektin-5', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10627501, end_position_on_the_genomic_accession=10694930, orientation='minus', exon_count=7, OMIM=[618686], no_hdr0=''),
    146310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146310, CurrentID=0, Status='live', Symbol='RNF151', Aliases=[], description='ring finger protein 151', other_designations='RING finger protein 151', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1966639, end_position_on_the_genomic_accession=1968963, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    146325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146325, CurrentID=0, Status='live', Symbol='PRR35', Aliases=['C16orf11', 'LA16c-366D1.2'], description='proline rich 35', other_designations='proline-rich protein 35', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=559786, end_position_on_the_genomic_accession=565531, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    146330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146330, CurrentID=0, Status='live', Symbol='FBXL16', Aliases=['C16orf22', 'Fbl16', 'c380A1.1'], description='F-box and leucine rich repeat protein 16', other_designations='F-box/LRR-repeat protein 16', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=692500, end_position_on_the_genomic_accession=707853, orientation='minus', exon_count=7, OMIM=[609082], no_hdr0=''),
    146378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146378, CurrentID=0, Status='live', Symbol='C16orf92', Aliases=['FIMP'], description='chromosome 16 open reading frame 92', other_designations='fertilization-influencing membrane protein|uncharacterized protein C16orf92', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30023198, end_position_on_the_genomic_accession=30027736, orientation='plus', exon_count=6, OMIM=[618911], no_hdr0=''),
    146395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146395, CurrentID=0, Status='live', Symbol='GSG1L', Aliases=['PRO19651'], description='GSG1 like', other_designations='germ cell-specific gene 1-like protein|GSG1-like protein|KTSR5831', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27787528, end_position_on_the_genomic_accession=28063714, orientation='minus', exon_count=10, OMIM=[617161], no_hdr0=''),
    146429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146429, CurrentID=0, Status='live', Symbol='SLC22A31', Aliases=[], description='solute carrier family 22 member 31', other_designations='putative solute carrier family 22 member 31|putative solute carrier family 22 member ENSG00000182157', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89195756, end_position_on_the_genomic_accession=89201678, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    146433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146433, CurrentID=0, Status='live', Symbol='IL34', Aliases=['C16orf77', 'IL-34'], description='interleukin 34', other_designations='interleukin-34', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70579899, end_position_on_the_genomic_accession=70660682, orientation='plus', exon_count=10, OMIM=[612081], no_hdr0=''),
    146434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146434, CurrentID=0, Status='live', Symbol='ZNF597', Aliases=['HIT-4'], description='zinc finger protein 597', other_designations='zinc finger protein 597', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3432414, end_position_on_the_genomic_accession=3443504, orientation='minus', exon_count=4, OMIM=[614685], no_hdr0=''),
    146439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146439, CurrentID=0, Status='live', Symbol='BICDL2', Aliases=['BICDR-2', 'BICDR2', 'CCDC64B'], description='BICD family like cargo adaptor 2', other_designations='BICD family-like cargo adapter 2|BICD-related protein 2|bicaudal D-related protein 2|coiled-coil domain containing 64B|coiled-coil domain-containing protein 64B', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3027682, end_position_on_the_genomic_accession=3036985, orientation='minus', exon_count=11, OMIM=[617003], no_hdr0=''),
    146456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146456, CurrentID=0, Status='live', Symbol='TMED6', Aliases=['PRO34237', 'SPLL9146', 'p24g5'], description='transmembrane p24 trafficking protein 6', other_designations='transmembrane emp24 domain-containing protein 6|p24 family protein gamma-5|p24gamma5|transmembrane emp24 protein transport domain containing 6', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69343250, end_position_on_the_genomic_accession=69351786, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    146540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146540, CurrentID=0, Status='live', Symbol='ZNF785', Aliases=['ZNF688'], description='zinc finger protein 785', other_designations='zinc finger protein 785|Zinc finger protein 688', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30572939, end_position_on_the_genomic_accession=30586038, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    146542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146542, CurrentID=0, Status='live', Symbol='ZNF688', Aliases=[], description='zinc finger protein 688', other_designations='zinc finger protein 688', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30569677, end_position_on_the_genomic_accession=30572495, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    146547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146547, CurrentID=0, Status='live', Symbol='PRSS36', Aliases=[], description='serine protease 36', other_designations='polyserase-2|polyserine protease-2|protease, serine 36', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31138926, end_position_on_the_genomic_accession=31150083, orientation='minus', exon_count=15, OMIM=[610560], no_hdr0=''),
    146556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146556, CurrentID=0, Status='live', Symbol='C16orf89', Aliases=[], description='chromosome 16 open reading frame 89', other_designations='UPF0764 protein C16orf89', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=5042772, end_position_on_the_genomic_accession=5065971, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    146562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146562, CurrentID=0, Status='live', Symbol='DNAAF8', Aliases=['C16orf71'], description='dynein axonemal assembly factor 8', other_designations='dynein axonemal assembly factor 8|dynein axonemal-associated protein 1|uncharacterized protein C16orf71', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4734344, end_position_on_the_genomic_accession=4749396, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    146664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146664, CurrentID=0, Status='live', Symbol='MGAT5B', Aliases=['GnT-IX', 'GnT-VB'], description='alpha-1,6-mannosylglycoprotein 6-beta-N-acetylglucosaminyltransferase B', other_designations='alpha-1,6-mannosylglycoprotein 6-beta-N-acetylglucosaminyltransferase B|N-acetylglucosaminyl-transferase Vb|N-acetylglucosaminyltransferase IX|alpha-mannoside beta-1,6-N-acetylglucosaminyltransferase B|beta(1,6)-N-acetylglucosaminyltransferase V|glcNAc-T Vb|hGnTVb|mannoside acetylglucosaminyltransferase 5B|mannosyl (alpha-1,6-)-glycoprotein beta-1,6-N-acetyl-glucosaminyltransferase, isoenzyme B|mannosyl (alpha-1,6-)-glycoprotein beta-1,6-N-acetyl-glucosaminyltransferase, isozyme B', map_location='17q25.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76868404, end_position_on_the_genomic_accession=76950393, orientation='plus', exon_count=22, OMIM=[612441], no_hdr0=''),
    146691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146691, CurrentID=0, Status='live', Symbol='TOM1L2', Aliases=[], description='target of myb1 like 2 membrane trafficking protein', other_designations='TOM1-like protein 2|target of Myb-like protein 2|target of myb1-like 2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17843508, end_position_on_the_genomic_accession=17972406, orientation='minus', exon_count=16, OMIM=[615519], no_hdr0=''),
    146705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146705, CurrentID=0, Status='live', Symbol='TEPSIN', Aliases=['C17orf56', 'ENTHD2'], description='TEPSIN adaptor related protein complex 4 accessory protein', other_designations='AP-4 complex accessory subunit tepsin|AP-4 accessory protein|ENTH domain containing 2|ENTH domain-containing protein 2|epsin for AP-4|tetra-epsin', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81228277, end_position_on_the_genomic_accession=81239092, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    146712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146712, CurrentID=0, Status='live', Symbol='B3GNTL1', Aliases=['3-Gn-T8', 'B3GNT8', 'BGnT-8', 'beta-1', 'beta3Gn-T8', 'beta3GnTL1'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase like 1', other_designations='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase-like protein 1|BGnT-like protein 1|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 8|beta-1,3-Gn-T8|beta-1,3-N-acetylglucosaminyltransferase 8|beta1,3-N-acetylglucosaminyltransferase-like protein 1|beta3Gn-T-like protein 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82942149, end_position_on_the_genomic_accession=83051845, orientation='minus', exon_count=21, OMIM=[615337], no_hdr0=''),
    146713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146713, CurrentID=0, Status='live', Symbol='RBFOX3', Aliases=['FOX-3', 'FOX3', 'HRNBP3', 'NEUN'], description='RNA binding fox-1 homolog 3', other_designations='RNA binding protein fox-1 homolog 3|RNA binding protein, fox-1 homolog 3|fox-1 homolog C|hexaribonucleotide binding protein 3|neuN antigen|neuronal nuclei antigen', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79089345, end_position_on_the_genomic_accession=79665600, orientation='minus', exon_count=39, OMIM=[616999], no_hdr0=''),
    146722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146722, CurrentID=0, Status='live', Symbol='CD300LF', Aliases=['CD300f', 'CLM-1', 'CLM1', 'IREM-1', 'IREM1', 'IgSF13', 'LMIR3', 'NKIR'], description='CD300 molecule like family member f', other_designations='CMRF35-like molecule 1|CD300 antigen-like family member F|NK inhibitory receptor|immune receptor expressed on myeloid cells 1|immunoglobin superfamily member 13|immunoglobulin superfamily member 13|inhibitory receptor IREM1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74694308, end_position_on_the_genomic_accession=74713000, orientation='minus', exon_count=9, OMIM=[609807], no_hdr0=''),
    146754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146754, CurrentID=0, Status='live', Symbol='DNAH2', Aliases=['DNAHC2', 'DNHD3', 'SPGF45'], description='dynein axonemal heavy chain 2', other_designations='dynein axonemal heavy chain 2|dynein heavy chain 2, axonemal|axonemal beta dynein heavy chain 2|ciliary dynein heavy chain 2|dynein heavy chain domain-containing protein 3|dynein, axonemal, heavy polypeptide 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7717744, end_position_on_the_genomic_accession=7833742, orientation='plus', exon_count=92, OMIM=[603333], no_hdr0=''),
    146760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146760, CurrentID=0, Status='live', Symbol='RTN4RL1', Aliases=['NGRH2', 'NgR3'], description='reticulon 4 receptor like 1', other_designations='reticulon-4 receptor-like 1|Nogo-66 receptor homolog 2|Nogo-66 receptor-related protein 3|nogo receptor-like 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1934677, end_position_on_the_genomic_accession=2025334, orientation='minus', exon_count=2, OMIM=[610461], no_hdr0=''),
    146779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146779, CurrentID=0, Status='live', Symbol='EFCAB3', Aliases=[], description='EF-hand calcium binding domain 3', other_designations='EF-hand calcium-binding domain-containing protein 3', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62370218, end_position_on_the_genomic_accession=62416480, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    146802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146802, CurrentID=0, Status='live', Symbol='SLC47A2', Aliases=['MATE2', 'MATE2-B', 'MATE2-K', 'MATE2K'], description='solute carrier family 47 member 2', other_designations='multidrug and toxin extrusion protein 2|kidney-specific H(+)/organic cation antiporter|solute carrier family 47 (multidrug and toxin extrusion), member 2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19678313, end_position_on_the_genomic_accession=19719598, orientation='minus', exon_count=22, OMIM=[609833], no_hdr0=''),
    146822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146822, CurrentID=0, Status='live', Symbol='CDRT15', Aliases=[], description='CMT1A duplicated region transcript 15', other_designations='CMT1A duplicated region transcript 15 protein', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=14235673, end_position_on_the_genomic_accession=14236862, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    146845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146845, CurrentID=0, Status='live', Symbol='CFAP52', Aliases=['WDR16', 'WDRPUH'], description='cilia and flagella associated protein 52', other_designations='cilia- and flagella-associated protein 52|WD repeat domain 16|WD repeat-containing protein 16|WD40-repeat protein up-regulated in HCC|WD40-repeat protein upregulated in HCC', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9576642, end_position_on_the_genomic_accession=9643447, orientation='plus', exon_count=14, OMIM=[609804], no_hdr0=''),
    146849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146849, CurrentID=0, Status='live', Symbol='CCDC42', Aliases=['CCDC42A'], description='coiled-coil domain containing 42', other_designations='coiled-coil domain-containing protein 42|coiled-coil domain-containing protein 42A', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8729935, end_position_on_the_genomic_accession=8744836, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    146850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146850, CurrentID=0, Status='live', Symbol='PIK3R6', Aliases=['C17orf38', 'HsT41028', 'p84 PIKAP', 'p87(PIKAP)', 'p87PIKAP'], description='phosphoinositide-3-kinase regulatory subunit 6', other_designations='phosphoinositide 3-kinase regulatory subunit 6|PI3Kgamma adapter protein of 87 kDa|p84 PI3K adapter protein|p87 phosphoinositide 3-kinase gamma (PI3Kg) adapter protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8802722, end_position_on_the_genomic_accession=8870003, orientation='minus', exon_count=23, OMIM=[611462], no_hdr0=''),
    146852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146852, CurrentID=0, Status='live', Symbol='ODF4', Aliases=['CT134', 'CT136', 'OPPO1'], description='outer dense fiber of sperm tails 4', other_designations='outer dense fiber protein 4|cancer/testis antigen 134|cancer/testis antigen 136|hOPPO1|outer dense fiber 4|outer dense fiber of sperm tails protein 4|testis-specific protein oppo 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8339840, end_position_on_the_genomic_accession=8346048, orientation='plus', exon_count=4, OMIM=[610097], no_hdr0=''),
    146853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146853, CurrentID=0, Status='live', Symbol='C17orf50', Aliases=[], description='chromosome 17 open reading frame 50', other_designations='uncharacterized protein C17orf50', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35760887, end_position_on_the_genomic_accession=35765079, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    146857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146857, CurrentID=0, Status='live', Symbol='SLFN13', Aliases=['SLFN10', 'hSLFN13'], description='schlafen family member 13', other_designations='schlafen family member 13|schlafen-13', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35435096, end_position_on_the_genomic_accession=35451103, orientation='minus', exon_count=8, OMIM=[614957], no_hdr0=''),
    146861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146861, CurrentID=0, Status='live', Symbol='SLC35G3', Aliases=['AMAC1', 'TMEM21A'], description='solute carrier family 35 member G3', other_designations='solute carrier family 35 member G3|acyl-malonyl-condensing enzyme 1|protein AMAC1|transmembrane protein 21A', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35192520, end_position_on_the_genomic_accession=35194393, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    146862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146862, CurrentID=0, Status='live', Symbol='UNC45B', Aliases=['CMYA4', 'CTRCT43', 'MFM11', 'SMUNC45', 'UNC-45B', 'UNC45'], description='unc-45 myosin chaperone B', other_designations='protein unc-45 homolog B|cardiomyopathy associated 4|striated muscle UNC45|unc-45 homolog B', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35147793, end_position_on_the_genomic_accession=35189345, orientation='plus', exon_count=20, OMIM=[611220], no_hdr0=''),
    146894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146894, CurrentID=0, Status='live', Symbol='CD300LG', Aliases=['CLM-9', 'CLM9', 'NEPMUCIN', 'TREM-4', 'TREM4'], description='CD300 molecule like family member g', other_designations='CMRF35-like molecule 9|CD300 antigen-like family member G|triggering receptor expressed on myeloid cells 4', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43847097, end_position_on_the_genomic_accession=43863639, orientation='plus', exon_count=10, OMIM=[610520], no_hdr0=''),
    146909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146909, CurrentID=0, Status='live', Symbol='KIF18B', Aliases=[], description='kinesin family member 18B', other_designations='kinesin-like protein KIF18B', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44924711, end_position_on_the_genomic_accession=44947773, orientation='minus', exon_count=17, OMIM=[614570], no_hdr0=''),
    146923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146923, CurrentID=0, Status='live', Symbol='RUNDC1', Aliases=['RUND1'], description='RUN domain containing 1', other_designations='RUN domain-containing protein 1', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42980516, end_position_on_the_genomic_accession=42995142, orientation='plus', exon_count=6, OMIM=[619250], no_hdr0=''),
    146956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=146956, CurrentID=0, Status='live', Symbol='EME1', Aliases=['MMS4L', 'SLX2A'], description='essential meiotic structure-specific endonuclease 1', other_designations='crossover junction endonuclease EME1|MMS4 homolog|SLX2 structure-specific endonuclease subunit homolog A|essential meiotic endonuclease 1 homolog 1|essential meiotic endonuclease 1 homolog 2|hMMS4|homolog of yeast EME1 endonuclease', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50373224, end_position_on_the_genomic_accession=50381483, orientation='plus', exon_count=10, OMIM=[610885], no_hdr0=''),
    147007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147007, CurrentID=0, Status='live', Symbol='TMEM199', Aliases=['C17orf32', 'CDG2P', 'VMA12', 'VPH2'], description='transmembrane protein 199', other_designations='transmembrane protein 199', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28357647, end_position_on_the_genomic_accession=28363683, orientation='plus', exon_count=6, OMIM=[616815], no_hdr0=''),
    147011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147011, CurrentID=0, Status='live', Symbol='PROCA1', Aliases=[], description='protein interacting with cyclin A1', other_designations='protein PROCA1|proline-rich cyclin A1-interacting protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28703197, end_position_on_the_genomic_accession=28712065, orientation='minus', exon_count=8, OMIM=[617376], no_hdr0=''),
    147015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147015, CurrentID=0, Status='live', Symbol='DHRS13', Aliases=['SDR7C5'], description='dehydrogenase/reductase 13', other_designations='dehydrogenase/reductase SDR family member 13|dehydrogenase/reductase (SDR family) member 13|short chain dehydrogenase/reductase family 7C member 5', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28897781, end_position_on_the_genomic_accession=28903079, orientation='minus', exon_count=5, OMIM=[616157], no_hdr0=''),
    147040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147040, CurrentID=0, Status='live', Symbol='KCTD11', Aliases=['C17orf36', 'KCASH1', 'REN', 'REN/KCTD11'], description='potassium channel tetramerization domain containing 11', other_designations='BTB/POZ domain-containing protein KCTD11|RING-type E3 ubiquitin transferase subunit KCTD11|potassium channel tetramerization domain-containing protein 11|retinoic acid, EGF, NGF induced gene protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7352162, end_position_on_the_genomic_accession=7354944, orientation='plus', exon_count=1, OMIM=[609848], no_hdr0=''),
    147111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147111, CurrentID=0, Status='live', Symbol='NOTUM', Aliases=['hNOTUM'], description='notum, palmitoleoyl-protein carboxylesterase', other_designations='palmitoleoyl-protein carboxylesterase NOTUM|[Wnt protein] O-palmitoleoyl-L-serine hydrolase|notum pectinacetylesterase homolog|protein notum homolog', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81952507, end_position_on_the_genomic_accession=81961187, orientation='minus', exon_count=11, OMIM=[609847], no_hdr0=''),
    147138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147138, CurrentID=0, Status='live', Symbol='TMC8', Aliases=['EV2', 'EVER2', 'EVIN2'], description='transmembrane channel like 8', other_designations='transmembrane channel-like protein 8|epidermodysplasia verruciformis 2|epidermodysplasia verruciformis protein 2', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78129298, end_position_on_the_genomic_accession=78142968, orientation='plus', exon_count=17, OMIM=[605829], no_hdr0=''),
    147166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147166, CurrentID=0, Status='live', Symbol='TRIM16L', Aliases=['TRIM70'], description='tripartite motif containing 16 like', other_designations='tripartite motif-containing protein 16-like protein|tripartite motif protein 70|tripartite motif-containing protein 70', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18697998, end_position_on_the_genomic_accession=18736119, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    147179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147179, CurrentID=0, Status='live', Symbol='WIPF2', Aliases=['WICH', 'WIRE'], description='WAS/WASL interacting protein family member 2', other_designations='WAS/WASL-interacting protein family member 2|WASP-binding protein|WASP-interacting protein-related protein|WIP- and CR16-homologous protein|WIP-related protein', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40219304, end_position_on_the_genomic_accession=40284136, orientation='plus', exon_count=9, OMIM=[609692], no_hdr0=''),
    147183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147183, CurrentID=0, Status='live', Symbol='KRT25', Aliases=['ARWH3', 'KRT24IRS1A', 'KRT25'], description='keratin 25', other_designations='keratin, type I cytoskeletal 25|CK-25|K25|K25A|cytokeratin-25|keratin 25, type I|keratin-25A|type I inner root sheath specific keratin 25 irs1|type I inner root sheath-specific keratin-K25irs1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40748021, end_position_on_the_genomic_accession=40755542, orientation='minus', exon_count=9, OMIM=[616646], no_hdr0=''),
    147199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147199, CurrentID=0, Status='live', Symbol='SCGB1C1', Aliases=['RYD5'], description='secretoglobin family 1C member 1', other_designations='secretoglobin family 1C member 1|ligand binding protein RYD5|secretoglobin RYD5', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=187881, end_position_on_the_genomic_accession=194575, orientation='plus', exon_count=4, OMIM=[610176], no_hdr0=''),
    147323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147323, CurrentID=0, Status='live', Symbol='STARD6', Aliases=[], description='StAR related lipid transfer domain containing 6', other_designations='stAR-related lipid transfer protein 6|START domain containing 6|START domain-containing protein 6|StAR-related lipid transfer (START) domain containing 6', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54324492, end_position_on_the_genomic_accession=54357858, orientation='minus', exon_count=9, OMIM=[607051], no_hdr0=''),
    147339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147339, CurrentID=0, Status='live', Symbol='C18orf25', Aliases=['ARKL1', 'Ark2N', 'RNF111L1'], description='chromosome 18 open reading frame 25', other_designations='uncharacterized protein C18orf25|ARKadia-like 1|ARKadia-like protein 1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46173553, end_position_on_the_genomic_accession=46266992, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    147372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147372, CurrentID=0, Status='live', Symbol='CCBE1', Aliases=['HKLLS1'], description='collagen and calcium binding EGF domains 1', other_designations='collagen and calcium-binding EGF domain-containing protein 1|full of fluid protein homolog', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59430939, end_position_on_the_genomic_accession=59698181, orientation='minus', exon_count=11, OMIM=[612753], no_hdr0=''),
    147381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147381, CurrentID=0, Status='live', Symbol='CBLN2', Aliases=[], description='cerebellin 2 precursor', other_designations='cerebellin-2', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=72533720, end_position_on_the_genomic_accession=72638485, orientation='minus', exon_count=7, OMIM=[600433], no_hdr0=''),
    147407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147407, CurrentID=0, Status='live', Symbol='SLC25A52', Aliases=['MCART2'], description='solute carrier family 25 member 52', other_designations='mitochondrial nicotinamide adenine dinucleotide transporter SLC25A52|mitochondrial NAD(+) transporter SLC25A52|mitochondrial carrier triple repeat 2|mitochondrial carrier triple repeat protein 2', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31759584, end_position_on_the_genomic_accession=31760880, orientation='minus', exon_count=1, OMIM=[616153], no_hdr0=''),
    147409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147409, CurrentID=0, Status='live', Symbol='DSG4', Aliases=['CDGF13', 'CDHF13', 'HYPT6', 'LAH'], description='desmoglein 4', other_designations='desmoglein-4|cadherin family member 13', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=31376777, end_position_on_the_genomic_accession=31415791, orientation='plus', exon_count=16, OMIM=[607892], no_hdr0=''),
    147463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147463, CurrentID=0, Status='live', Symbol='ANKRD29', Aliases=[], description='ankyrin repeat domain 29', other_designations='ankyrin repeat domain-containing protein 29', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=23598926, end_position_on_the_genomic_accession=23662914, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    147495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147495, CurrentID=0, Status='live', Symbol='APCDD1', Aliases=['B7323', 'DRAPC1', 'FP7019', 'HHS', 'HTS', 'HYPT1'], description='APC down-regulated 1', other_designations='protein APCDD1|adenomatosis polyposis coli down-regulated 1 protein|hypoptrichosis simplex', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=10454635, end_position_on_the_genomic_accession=10489949, orientation='plus', exon_count=6, OMIM=[607479], no_hdr0=''),
    147645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147645, CurrentID=0, Status='live', Symbol='VSIG10L', Aliases=[], description='V-set and immunoglobulin domain containing 10 like', other_designations='V-set and immunoglobulin domain-containing protein 10-like|VSIG10-like protein', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51331541, end_position_on_the_genomic_accession=51342139, orientation='minus', exon_count=10, OMIM=[617740], no_hdr0=''),
    147646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147646, CurrentID=0, Status='live', Symbol='C19orf84', Aliases=[], description='chromosome 19 open reading frame 84', other_designations='uncharacterized protein C19orf84', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51388289, end_position_on_the_genomic_accession=51390591, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    147650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147650, CurrentID=0, Status='live', Symbol='SPACA6', Aliases=['LET7EH', 'LINC00085', 'NCRNA00085P', 'SPACA6'], description='sperm acrosome associated 6', other_designations='sperm acrosome membrane-associated protein 6|BACHELOR-like protein|Let-7e host|long intergenic non-protein coding RNA 85|sperm acrosome associated 6, pseudogene', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51685595, end_position_on_the_genomic_accession=51713157, orientation='plus', exon_count=12, OMIM=[618945], no_hdr0=''),
    147657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147657, CurrentID=0, Status='live', Symbol='ZNF480', Aliases=[], description='zinc finger protein 480', other_designations='zinc finger protein 480', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52297169, end_position_on_the_genomic_accession=52325927, orientation='plus', exon_count=6, OMIM=[613910], no_hdr0=''),
    147658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147658, CurrentID=0, Status='live', Symbol='ZNF534', Aliases=['KRBO3'], description='zinc finger protein 534', other_designations='zinc finger protein 534|KRAB domain only 3|KRAB domain only protein 3', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52429148, end_position_on_the_genomic_accession=52452263, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    147660 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147660, CurrentID=0, Status='live', Symbol='ZNF578', Aliases=[], description='zinc finger protein 578', other_designations='zinc finger protein 578', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52453553, end_position_on_the_genomic_accession=52516882, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    147664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147664, CurrentID=0, Status='live', Symbol='ERVV-1', Aliases=['ENVV1', 'HERV-V1'], description='endogenous retrovirus group V member 1, envelope', other_designations='endogenous retrovirus group V member 1 Env polyprotein|HERV-V_19q13.41 provirus ancestral Env polyprotein 1|endogenous retrovirus group V, member 1|endogenous retrovirus group V, member 2|envelope glycoprotein ENVV1|envelope protein ENVV1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53013921, end_position_on_the_genomic_accession=53016123, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    147670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147670, CurrentID=0, Status='live', Symbol='SMIM17', Aliases=[], description='small integral membrane protein 17', other_designations='small integral membrane protein 17', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56643159, end_position_on_the_genomic_accession=56657247, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    147685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147685, CurrentID=0, Status='live', Symbol='C19orf18', Aliases=[], description='chromosome 19 open reading frame 18', other_designations='uncharacterized protein C19orf18', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57958437, end_position_on_the_genomic_accession=57974534, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    147686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147686, CurrentID=0, Status='live', Symbol='ZNF418', Aliases=[], description='zinc finger protein 418', other_designations='zinc finger protein 418', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57921882, end_position_on_the_genomic_accession=57935403, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    147687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147687, CurrentID=0, Status='live', Symbol='ZNF417', Aliases=[], description='zinc finger protein 417', other_designations='zinc finger protein 417', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57905411, end_position_on_the_genomic_accession=57916592, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    147694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147694, CurrentID=0, Status='live', Symbol='ZNF548', Aliases=[], description='zinc finger protein 548', other_designations='zinc finger protein 548', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57389852, end_position_on_the_genomic_accession=57403497, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    147699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147699, CurrentID=0, Status='live', Symbol='PPM1N', Aliases=[], description='protein phosphatase, Mg2+/Mn2+ dependent 1N (putative)', other_designations='probable protein phosphatase 1N', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45497964, end_position_on_the_genomic_accession=45502694, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    147700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147700, CurrentID=0, Status='live', Symbol='KLC3', Aliases=['KLC2', 'KLC2L', 'KLCt', 'KNS2B'], description='kinesin light chain 3', other_designations='kinesin light chain 3|kinesin light chain 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45340750, end_position_on_the_genomic_accession=45351548, orientation='plus', exon_count=14, OMIM=[601334], no_hdr0=''),
    147710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147710, CurrentID=0, Status='live', Symbol='IGSF23', Aliases=[], description='immunoglobulin superfamily member 23', other_designations='immunoglobulin superfamily member 23', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44612577, end_position_on_the_genomic_accession=44636781, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    147719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147719, CurrentID=0, Status='live', Symbol='LYPD4', Aliases=['SMR'], description='LY6/PLAUR domain containing 4', other_designations='ly6/PLAUR domain-containing protein 4|sperm membrane receptor|testicular tissue protein Li 159', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41833686, end_position_on_the_genomic_accession=41845204, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    147741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147741, CurrentID=0, Status='live', Symbol='ZNF560', Aliases=[], description='zinc finger protein 560', other_designations='zinc finger protein 560', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9445710, end_position_on_the_genomic_accession=9506692, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    147744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147744, CurrentID=0, Status='live', Symbol='TMEM190', Aliases=['MDAC1'], description='transmembrane protein 190', other_designations='transmembrane protein 190', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55376126, end_position_on_the_genomic_accession=55378246, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    147746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147746, CurrentID=0, Status='live', Symbol='HIPK4', Aliases=[], description='homeodomain interacting protein kinase 4', other_designations='homeodomain-interacting protein kinase 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40379271, end_position_on_the_genomic_accession=40390865, orientation='minus', exon_count=4, OMIM=[611712], no_hdr0=''),
    147798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147798, CurrentID=0, Status='live', Symbol='TMC4', Aliases=[], description='transmembrane channel like 4', other_designations='transmembrane channel-like protein 4|testicular tissue protein Li 204', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54160095, end_position_on_the_genomic_accession=54173218, orientation='minus', exon_count=15, OMIM=[617181], no_hdr0=''),
    147807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147807, CurrentID=0, Status='live', Symbol='ZNF524', Aliases=[], description='zinc finger protein 524', other_designations='zinc finger protein 524', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55599772, end_position_on_the_genomic_accession=55603138, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    147808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147808, CurrentID=0, Status='live', Symbol='ZNF784', Aliases=[], description='zinc finger protein 784', other_designations='zinc finger protein 784', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55620741, end_position_on_the_genomic_accession=55624566, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    147837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147837, CurrentID=0, Status='live', Symbol='ZNF563', Aliases=[], description='zinc finger protein 563', other_designations='zinc finger protein 563', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12317477, end_position_on_the_genomic_accession=12347390, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    147841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147841, CurrentID=0, Status='live', Symbol='SPC24', Aliases=['SPBC24'], description='SPC24 component of NDC80 kinetochore complex', other_designations='kinetochore protein Spc24|SPC24, NDC80 kinetochore complex component, homolog|hSpc24|spindle pole body component 24 homolog', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11145493, end_position_on_the_genomic_accession=11155997, orientation='minus', exon_count=6, OMIM=[609394], no_hdr0=''),
    147872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147872, CurrentID=0, Status='live', Symbol='KASH5', Aliases=['CCDC155'], description='KASH domain containing 5', other_designations='protein KASH5|KASH domain-containing protein 5|coiled-coil domain containing 155', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49388218, end_position_on_the_genomic_accession=49418002, orientation='plus', exon_count=24, OMIM=[618125], no_hdr0=''),
    147906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147906, CurrentID=0, Status='live', Symbol='DACT3', Aliases=['DAPPER3', 'RRR1'], description='dishevelled binding antagonist of beta catenin 3', other_designations='dapper homolog 3|antagonist of beta-catenin Dapper homolog 3|arginine-rich region 1 protein|dapper, antagonist of beta-catenin, homolog 3', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46647551, end_position_on_the_genomic_accession=46661182, orientation='minus', exon_count=8, OMIM=[611112], no_hdr0=''),
    147912 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147912, CurrentID=0, Status='live', Symbol='SIX5', Aliases=['BOR2', 'DMAHP'], description='SIX homeobox 5', other_designations='homeobox protein SIX5|DM locus-associated homeodomain protein|dystrophia myotonica-associated homeodomain protein|sine oculis homeobox homolog 5', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45764785, end_position_on_the_genomic_accession=45769252, orientation='minus', exon_count=3, OMIM=[600963], no_hdr0=''),
    147920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147920, CurrentID=0, Status='live', Symbol='IGFL2', Aliases=['UNQ645', 'VPRI645'], description='IGF like family member 2', other_designations='insulin growth factor-like family member 2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46078513, end_position_on_the_genomic_accession=46215362, orientation='plus', exon_count=26, OMIM=[610545], no_hdr0=''),
    147923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147923, CurrentID=0, Status='live', Symbol='ZNF420', Aliases=['APAK'], description='zinc finger protein 420', other_designations='zinc finger protein 420|ATM and p53-associated KZNF protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37007815, end_position_on_the_genomic_accession=37130368, orientation='plus', exon_count=9, OMIM=[617216], no_hdr0=''),
    147929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147929, CurrentID=0, Status='live', Symbol='ZNF565', Aliases=[], description='zinc finger protein 565', other_designations='zinc finger protein 565', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36182060, end_position_on_the_genomic_accession=36245928, orientation='minus', exon_count=10, OMIM=[614275], no_hdr0=''),
    147945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147945, CurrentID=0, Status='live', Symbol='NLRP4', Aliases=['CLR19.5', 'CT58', 'NALP4', 'PAN2', 'PYPAF4', 'RNH2'], description='NLR family pyrin domain containing 4', other_designations='NACHT, LRR and PYD domains-containing protein 4|NACHT, leucine rich repeat and PYD containing 4|PAAD and NACHT-containing protein 2|PYRIN and NACHT-containing protein 2|PYRIN-containing APAF1-like protein 4|cancer/testis antigen 58|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 4|ribonuclease inhibitor 2', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55836540, end_position_on_the_genomic_accession=55881855, orientation='plus', exon_count=10, OMIM=[609645], no_hdr0=''),
    147948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147948, CurrentID=0, Status='live', Symbol='ZNF582', Aliases=[], description='zinc finger protein 582', other_designations='zinc finger protein 582', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56382751, end_position_on_the_genomic_accession=56393585, orientation='minus', exon_count=6, OMIM=[615600], no_hdr0=''),
    147949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147949, CurrentID=0, Status='live', Symbol='ZNF583', Aliases=[], description='zinc finger protein 583', other_designations='zinc finger protein 583|zinc finger protein L3-5', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56404014, end_position_on_the_genomic_accession=56427364, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    147965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147965, CurrentID=0, Status='live', Symbol='FAM98C', Aliases=[], description='family with sequence similarity 98 member C', other_designations='protein FAM98C', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38403093, end_position_on_the_genomic_accession=38409088, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    147968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147968, CurrentID=0, Status='live', Symbol='CAPN12', Aliases=[], description='calpain 12', other_designations='calpain-12|CANP 12|calcium-activated neutral proteinase 12', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38730048, end_position_on_the_genomic_accession=38744474, orientation='minus', exon_count=22, OMIM=[608839], no_hdr0=''),
    147991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=147991, CurrentID=0, Status='live', Symbol='DPY19L3', Aliases=[], description='dpy-19 like C-mannosyltransferase 3', other_designations='probable C-mannosyltransferase DPY19L3|dpy-19 like 3|dpy-19-like 3|dpy-19-like protein 3|protein dpy-19 homolog 3', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32405765, end_position_on_the_genomic_accession=32485890, orientation='plus', exon_count=21, OMIM=[613894], no_hdr0=''),
    148003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148003, CurrentID=0, Status='live', Symbol='LGALS16', Aliases=[], description='galectin 16', other_designations='galectin-16|beta-galactoside-binding lectin|lectin, galactoside-binding, soluble, 16', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39655913, end_position_on_the_genomic_accession=39660647, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    148014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148014, CurrentID=0, Status='live', Symbol='TTC9B', Aliases=[], description='tetratricopeptide repeat domain 9B', other_designations='tetratricopeptide repeat protein 9B|TPR repeat protein 9B', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40216058, end_position_on_the_genomic_accession=40218384, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    148022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148022, CurrentID=0, Status='live', Symbol='TICAM1', Aliases=['IIAE6', 'MyD88-3', 'PRVTIRB', 'TICAM-1', 'TRIF'], description='toll like receptor adaptor molecule 1', other_designations='TIR domain-containing adapter molecule 1|TIR domain containing adaptor inducing interferon-beta|TIR domain-containing adapter protein inducing IFN-beta|proline-rich, vinculin and TIR domain-containing protein B|putative NF-kappa-B-activating protein 502H|toll-interleukin-1 receptor domain-containing adapter protein inducing interferon beta', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4815932, end_position_on_the_genomic_accession=4831712, orientation='minus', exon_count=3, OMIM=[607601], no_hdr0=''),
    148066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148066, CurrentID=0, Status='live', Symbol='ZNRF4', Aliases=['RNF204', 'SPERIZIN', 'Ssrzf1', 'spzn'], description='zinc and ring finger 4', other_designations='E3 ubiquitin-protein ligase ZNRF4|RING finger protein 204|RING-type E3 ubiquitin transferase ZNRF4|nixin|zinc/RING finger protein 4', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5455417, end_position_on_the_genomic_accession=5456856, orientation='plus', exon_count=1, OMIM=[612063], no_hdr0=''),
    148103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148103, CurrentID=0, Status='live', Symbol='ZNF599', Aliases=[], description='zinc finger protein 599', other_designations='zinc finger protein 599', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34758073, end_position_on_the_genomic_accession=34773215, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    148109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148109, CurrentID=0, Status='live', Symbol='FAM187B', Aliases=['TMEM162'], description='family with sequence similarity 187 member B', other_designations='protein FAM187B|transmembrane protein 162', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35224800, end_position_on_the_genomic_accession=35228739, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    148113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148113, CurrentID=0, Status='live', Symbol='CILP2', Aliases=['CLIP-2'], description='cartilage intermediate layer protein 2', other_designations='cartilage intermediate layer protein 2|CILP-2|cartilage intermediate layer protein-like protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19538265, end_position_on_the_genomic_accession=19546659, orientation='plus', exon_count=8, OMIM=[612419], no_hdr0=''),
    148137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148137, CurrentID=0, Status='live', Symbol='PROSER3', Aliases=['C19orf55'], description='proline and serine rich 3', other_designations='proline and serine-rich protein 3', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35758146, end_position_on_the_genomic_accession=35771166, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    148156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148156, CurrentID=0, Status='live', Symbol='ZNF558', Aliases=[], description='zinc finger protein 558', other_designations='zinc finger protein 558', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8806170, end_position_on_the_genomic_accession=8838144, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    148170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148170, CurrentID=0, Status='live', Symbol='CDC42EP5', Aliases=['Borg3', 'CEP5'], description='CDC42 effector protein 5', other_designations='cdc42 effector protein 5|CDC42 effector protein (Rho GTPase binding) 5|binder of Rho GTPases 3', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54465026, end_position_on_the_genomic_accession=54473296, orientation='minus', exon_count=3, OMIM=[609171], no_hdr0=''),
    148198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148198, CurrentID=0, Status='live', Symbol='ZNF98', Aliases=['F7175', 'ZNF739'], description='zinc finger protein 98', other_designations='zinc finger protein 98|zinc finger protein 739|zinc finger protein F7175', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22391019, end_position_on_the_genomic_accession=22422346, orientation='minus', exon_count=4, OMIM=[603980], no_hdr0=''),
    148203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148203, CurrentID=0, Status='live', Symbol='ZNF738', Aliases=[], description='zinc finger protein 738', other_designations='protein ZNF738', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21359000, end_position_on_the_genomic_accession=21388582, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    148206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148206, CurrentID=0, Status='live', Symbol='ZNF714', Aliases=[], description='zinc finger protein 714', other_designations='zinc finger protein 714', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21082203, end_position_on_the_genomic_accession=21125094, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    148213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148213, CurrentID=0, Status='live', Symbol='ZNF681', Aliases=[], description='zinc finger protein 681', other_designations='zinc finger protein 681', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23739195, end_position_on_the_genomic_accession=23758891, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    148223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148223, CurrentID=0, Status='live', Symbol='C19orf25', Aliases=[], description='chromosome 19 open reading frame 25', other_designations='UPF0449 protein C19orf25', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1473201, end_position_on_the_genomic_accession=1479215, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    148229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148229, CurrentID=0, Status='live', Symbol='ATP8B3', Aliases=['ATPIK'], description='ATPase phospholipid transporting 8B3', other_designations='phospholipid-transporting ATPase IK|ATPase, aminophospholipid transporter, class I, type 8B, member 3|ATPase, class I, type 8B, member 3|aminophospholipid translocase ATP8B3|potential phospholipid-transporting ATPase IK|probable phospholipid-transporting ATPase IK', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1782068, end_position_on_the_genomic_accession=1812276, orientation='minus', exon_count=30, OMIM=[605866], no_hdr0=''),
    148252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148252, CurrentID=0, Status='live', Symbol='DIRAS1', Aliases=['Di-Ras1', 'GBTS1', 'RIG'], description='DIRAS family GTPase 1', other_designations='GTP-binding protein Di-Ras1|DIRAS family, GTP-binding RAS-like 1|distinct subgroup of the Ras family member 1|ras-related inhibitor of cell growth|small GTP-binding tumor suppressor 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2714567, end_position_on_the_genomic_accession=2721372, orientation='minus', exon_count=3, OMIM=[607862], no_hdr0=''),
    148254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148254, CurrentID=0, Status='live', Symbol='ZNF555', Aliases=[], description='zinc finger protein 555', other_designations='zinc finger protein 555', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2841475, end_position_on_the_genomic_accession=2860484, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    148266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148266, CurrentID=0, Status='live', Symbol='ZNF569', Aliases=['ZAP1', 'ZNF', 'Zfp74'], description='zinc finger protein 569', other_designations='zinc finger protein 569|DNA-binding protein', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37411146, end_position_on_the_genomic_accession=37469263, orientation='minus', exon_count=10, OMIM=[613904], no_hdr0=''),
    148268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148268, CurrentID=0, Status='live', Symbol='ZNF570', Aliases=[], description='zinc finger protein 570', other_designations='zinc finger protein 570', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37467465, end_position_on_the_genomic_accession=37488652, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    148281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148281, CurrentID=0, Status='live', Symbol='SYT6', Aliases=['sytVI'], description='synaptotagmin 6', other_designations='synaptotagmin-6|synaptotagmin VI', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114089292, end_position_on_the_genomic_accession=114153869, orientation='minus', exon_count=10, OMIM=[607718], no_hdr0=''),
    148304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148304, CurrentID=0, Status='live', Symbol='C1orf74', Aliases=['URLC4'], description='chromosome 1 open reading frame 74', other_designations='UPF0739 protein C1orf74|up-regulated in lung cancer 4', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209779208, end_position_on_the_genomic_accession=209784559, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    148327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148327, CurrentID=0, Status='live', Symbol='CREB3L4', Aliases=['AIBZIP', 'ATCE1', 'CREB3', 'CREB4', 'JAL', 'hJAL'], description='cAMP responsive element binding protein 3 like 4', other_designations='cyclic AMP-responsive element-binding protein 3-like protein 4|CREB-4|androgen-induced basic leucine zipper protein|attaching to CRE-like 1|cAMP responsive element binding protein 1|cAMP-responsive element-binding protein 3-like protein 4|cAMP-responsive element-binding protein 4|cyclic AMP-responsive element-binding protein 4|tisp40|transcript induced in spermiogenesis protein 40', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153967487, end_position_on_the_genomic_accession=153974364, orientation='plus', exon_count=13, OMIM=[607138], no_hdr0=''),
    148345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148345, CurrentID=0, Status='live', Symbol='C1orf127', Aliases=[], description='chromosome 1 open reading frame 127', other_designations='uncharacterized protein C1orf127', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10946473, end_position_on_the_genomic_accession=10982076, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    148362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148362, CurrentID=0, Status='live', Symbol='BROX', Aliases=['C1orf58'], description='BRO1 domain and CAAX motif containing', other_designations='BRO1 domain-containing protein BROX', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222712564, end_position_on_the_genomic_accession=222735196, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    148398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148398, CurrentID=0, Status='live', Symbol='SAMD11', Aliases=['MRS'], description='sterile alpha motif domain containing 11', other_designations='sterile alpha motif domain-containing protein 11|SAM domain-containing protein 11', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=923923, end_position_on_the_genomic_accession=944574, orientation='plus', exon_count=15, OMIM=[616765], no_hdr0=''),
    148418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148418, CurrentID=0, Status='live', Symbol='SAMD13', Aliases=['HSD-41', 'HSD-42'], description='sterile alpha motif domain containing 13', other_designations='sterile alpha motif domain-containing protein 13|SAM domain-containing protein 13|dnaj-like protein (LOC148418)', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84298538, end_position_on_the_genomic_accession=84350798, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    148423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148423, CurrentID=0, Status='live', Symbol='C1orf52', Aliases=['gm117'], description='chromosome 1 open reading frame 52', other_designations='UPF0690 protein C1orf52|BCL10-associated gene protein', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85249953, end_position_on_the_genomic_accession=85259677, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    148479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148479, CurrentID=0, Status='live', Symbol='PHF13', Aliases=['PHF5', 'SPOC1'], description='PHD finger protein 13', other_designations='PHD finger protein 13|PHD zinc finger protein PHF5|survival time-associated PHD finger protein in ovarian cancer 1|survival time-associated PHD protein in ovarian cancer', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6613731, end_position_on_the_genomic_accession=6624030, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    148523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148523, CurrentID=0, Status='live', Symbol='CIART', Aliases=['C1orf51', 'CHRONO', 'GM129'], description='circadian associated repressor of transcription', other_designations='circadian-associated transcriptional repressor|chIP-derived repressor of network oscillator|computationally highlighted repressor of the network oscillator', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150282554, end_position_on_the_genomic_accession=150287093, orientation='plus', exon_count=6, OMIM=[615782], no_hdr0=''),
    148534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148534, CurrentID=0, Status='live', Symbol='TLCD4', Aliases=['TMEM56'], description='TLC domain containing 4', other_designations='TLC domain-containing protein 4|transmembrane protein 56', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=95092517, end_position_on_the_genomic_accession=95197607, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    148545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148545, CurrentID=0, Status='live', Symbol='NBPF4', Aliases=[], description='NBPF member 4', other_designations='neuroblastoma breakpoint family member 4', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108222464, end_position_on_the_genomic_accession=108244076, orientation='minus', exon_count=16, OMIM=[613994], no_hdr0=''),
    148581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148581, CurrentID=0, Status='live', Symbol='UBE2U', Aliases=[], description='ubiquitin conjugating enzyme E2 U', other_designations='ubiquitin-conjugating enzyme E2 U|E2 ubiquitin-conjugating enzyme U|testicular tissue protein Li 216|ubiquitin carrier protein U|ubiquitin conjugating enzyme E2 U (putative)|ubiquitin conjugating enzyme E2U (putative)|ubiquitin-protein ligase U', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=64202802, end_position_on_the_genomic_accession=64267381, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    148641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148641, CurrentID=0, Status='live', Symbol='SLC35F3', Aliases=[], description='solute carrier family 35 member F3', other_designations='putative thiamine transporter SLC35F3', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=233904676, end_position_on_the_genomic_accession=234324511, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    148738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148738, CurrentID=0, Status='live', Symbol='HJV', Aliases=['HFE2', 'HFE2A', 'JH', 'RGMC'], description='hemojuvelin BMP co-receptor', other_designations='hemojuvelin|RGM domain family member C|haemojuvelin|hemochromatosis type 2 (juvenile)|hemochromatosis type 2 protein|hemojuvelin BMP coreceptor|repulsive guidance molecule c', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=146017470, end_position_on_the_genomic_accession=146021735, orientation='minus', exon_count=4, OMIM=[608374], no_hdr0=''),
    148741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148741, CurrentID=0, Status='live', Symbol='ANKRD35', Aliases=[], description='ankyrin repeat domain 35', other_designations='ankyrin repeat domain-containing protein 35', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145866564, end_position_on_the_genomic_accession=145885866, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    148753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148753, CurrentID=0, Status='live', Symbol='FAM163A', Aliases=['C1orf76', 'NDSP'], description='family with sequence similarity 163 member A', other_designations='protein FAM163A|cebelin|neuroblastoma derived secretory protein', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179727763, end_position_on_the_genomic_accession=179816198, orientation='plus', exon_count=12, OMIM=[611727], no_hdr0=''),
    148789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148789, CurrentID=0, Status='live', Symbol='B3GALNT2', Aliases=['B3GalNAc-T2', 'MDDGA11'], description='beta-1,3-N-acetylgalactosaminyltransferase 2', other_designations='UDP-GalNAc:beta-1,3-N-acetylgalactosaminyltransferase 2|UDP-GalNAc:betaGlcNAc beta-1,3-galactosaminyltransferase, polypeptide 2|beta-1,3-GalNAc-T2', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=235440654, end_position_on_the_genomic_accession=235504481, orientation='minus', exon_count=14, OMIM=[610194], no_hdr0=''),
    148808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148808, CurrentID=0, Status='live', Symbol='MFSD4A', Aliases=['MFSD4', 'SLC60A1', 'UNQ3064'], description='major facilitator superfamily domain containing 4A', other_designations='major facilitator superfamily domain-containing protein 4A|major facilitator superfamily domain containing 4|major facilitator superfamily domain-containing protein 4', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205569014, end_position_on_the_genomic_accession=205602918, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    148811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148811, CurrentID=0, Status='live', Symbol='PM20D1', Aliases=['Cps1'], description='peptidase M20 domain containing 1', other_designations='N-fatty-acyl-amino acid synthase/hydrolase PM20D1|peptidase M20 domain-containing protein 1|probable carboxypeptidase PM20D1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205828025, end_position_on_the_genomic_accession=205850132, orientation='minus', exon_count=13, OMIM=[617124], no_hdr0=''),
    148823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148823, CurrentID=0, Status='live', Symbol='GCSAML', Aliases=['C1orf150'], description='germinal center associated signaling and motility like', other_designations='germinal center-associated signaling and motility-like protein', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247507058, end_position_on_the_genomic_accession=247577690, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    148867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148867, CurrentID=0, Status='live', Symbol='SLC30A7', Aliases=['ZNT7', 'ZnT-7', 'ZnTL2'], description='solute carrier family 30 member 7', other_designations='zinc transporter 7|solute carrier family 30 (zinc transporter), member 7|zinc transporter ZnT-7|zinc transporter like 2|znt-like transporter 2', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100896090, end_position_on_the_genomic_accession=100996913, orientation='plus', exon_count=14, OMIM=[611149], no_hdr0=''),
    148870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148870, CurrentID=0, Status='live', Symbol='CCDC27', Aliases=[], description='coiled-coil domain containing 27', other_designations='coiled-coil domain-containing protein 27', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3752398, end_position_on_the_genomic_accession=3771645, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    148930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148930, CurrentID=0, Status='live', Symbol='KNCN', Aliases=['Kino', 'L5'], description='kinocilin', other_designations='kinocilin', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46545641, end_position_on_the_genomic_accession=46551647, orientation='minus', exon_count=4, OMIM=[611455], no_hdr0=''),
    148932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148932, CurrentID=0, Status='live', Symbol='MOB3C', Aliases=['MOB1E', 'MOBKL2C'], description='MOB kinase activator 3C', other_designations='MOB kinase activator 3C|MOB1, Mps One Binder kinase activator-like 2C|mob1 homolog 2C', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46607719, end_position_on_the_genomic_accession=46616811, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    148979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=148979, CurrentID=0, Status='live', Symbol='GLIS1', Aliases=[], description='GLIS family zinc finger 1', other_designations='zinc finger protein GLIS1|GLI-similar 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=53506237, end_position_on_the_genomic_accession=53739171, orientation='minus', exon_count=15, OMIM=[610378], no_hdr0=''),
    149013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149013, CurrentID=0, Status='live', Symbol='NBPF12', Aliases=['COAS1', 'KIAA1245'], description='NBPF member 12', other_designations='neuroblastoma breakpoint family member 12|chomosome one amplified sequence 1 cyclophilin|chromosome 1 amplified sequence 1', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=146938324, end_position_on_the_genomic_accession=146996093, orientation='plus', exon_count=37, OMIM=[608607], no_hdr0=''),
    149018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149018, CurrentID=0, Status='live', Symbol='LELP1', Aliases=[], description='late cornified envelope like proline rich 1', other_designations='late cornified envelope-like proline-rich protein 1|novel small proline rich protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153203430, end_position_on_the_genomic_accession=153205120, orientation='plus', exon_count=2, OMIM=[611042], no_hdr0=''),
    149041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149041, CurrentID=0, Status='live', Symbol='RC3H1', Aliases=['FHL6', 'IMDSHY', 'RNF198', 'ROQUIN'], description='ring finger and CCCH-type domains 1', other_designations='roquin-1|RING finger and C3H zinc finger protein 1|RING finger and CCCH-type zinc finger domain-containing protein 1|RING finger protein 198|probable E3 ubiquitin-protein ligase Roquin', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173931084, end_position_on_the_genomic_accession=174022357, orientation='minus', exon_count=20, OMIM=[609424], no_hdr0=''),
    149069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149069, CurrentID=0, Status='live', Symbol='DCDC2B', Aliases=[], description='doublecortin domain containing 2B', other_designations='doublecortin domain-containing protein 2B', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32208813, end_position_on_the_genomic_accession=32216192, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    149076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149076, CurrentID=0, Status='live', Symbol='ZNF362', Aliases=['RN', 'lin-29'], description='zinc finger protein 362', other_designations='zinc finger protein 362|rotund homolog', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=33256307, end_position_on_the_genomic_accession=33300719, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    149095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149095, CurrentID=0, Status='live', Symbol='DCST1', Aliases=[], description='DC-STAMP domain containing 1', other_designations='E3 ubiquitin-protein ligase DCST1|DC-STAMP domain-containing protein 1|RING-type E3 ubiquitin transferase', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155033806, end_position_on_the_genomic_accession=155050930, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    149111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149111, CurrentID=0, Status='live', Symbol='CNIH3', Aliases=['CNIH-3'], description='cornichon family AMPA receptor auxiliary protein 3', other_designations='protein cornichon homolog 3|cornichon homolog 3', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=224434640, end_position_on_the_genomic_accession=224740554, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    149175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149175, CurrentID=0, Status='live', Symbol='MANEAL', Aliases=[], description='mannosidase endo-alpha like', other_designations='glycoprotein endo-alpha-1,2-mannosidase-like protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37793816, end_position_on_the_genomic_accession=37801133, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    149233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149233, CurrentID=0, Status='live', Symbol='IL23R', Aliases=[], description='interleukin 23 receptor', other_designations='interleukin-23 receptor|IL-23 receptor', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67138639, end_position_on_the_genomic_accession=67259979, orientation='plus', exon_count=13, OMIM=[607562], no_hdr0=''),
    149281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149281, CurrentID=0, Status='live', Symbol='NTMT2', Aliases=['C1orf184', 'HOMT1B', 'METTL11B', 'NTM1B'], description='N-terminal Xaa-Pro-Lys N-methyltransferase 2', other_designations='alpha N-terminal protein methyltransferase 1B|X-Pro-Lys N-terminal protein methyltransferase 1B|methyltransferase like 11B|methyltransferase-like protein 11B', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=170145959, end_position_on_the_genomic_accession=170168866, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    149297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149297, CurrentID=0, Status='live', Symbol='FAM78B', Aliases=[], description='family with sequence similarity 78 member B', other_designations='protein FAM78B', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=166055918, end_position_on_the_genomic_accession=166167001, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    149345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149345, CurrentID=0, Status='live', Symbol='SHISA4', Aliases=['C1orf40', 'TMEM58'], description='shisa family member 4', other_designations='protein shisa-4|shisa homolog 4|transmembrane protein 58', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201888677, end_position_on_the_genomic_accession=201892587, orientation='plus', exon_count=6, OMIM=[617326], no_hdr0=''),
    149371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149371, CurrentID=0, Status='live', Symbol='EXOC8', Aliases=['EXO84', 'Exo84p', 'NEDMISB', 'SEC84'], description='exocyst complex component 8', other_designations='exocyst complex component 8|exocyst complex 84 kDa subunit', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231332753, end_position_on_the_genomic_accession=231337852, orientation='minus', exon_count=1, OMIM=[615283], no_hdr0=''),
    149420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149420, CurrentID=0, Status='live', Symbol='PDIK1L', Aliases=['CLIK1L', 'STK35L2'], description='PDLIM1 interacting kinase 1 like', other_designations='serine/threonine-protein kinase PDIK1L|casein kinase', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26109131, end_position_on_the_genomic_accession=26125555, orientation='plus', exon_count=5, OMIM=[610785], no_hdr0=''),
    149428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149428, CurrentID=0, Status='live', Symbol='BNIPL', Aliases=['BNIP-S', 'BNIP-Salpha', 'BNIP-Sbeta-1', 'BNIPL-2', 'BNIPL1', 'BNIPL2', 'BNIPS', 'PP753', 'BNIPL'], description='BCL2 interacting protein like', other_designations='bcl-2/adenovirus E1B 19 kDa-interacting protein 2-like protein|BCL2/adenovirus E1B 19kD interacting protein like|BNIP-2 similar', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151036321, end_position_on_the_genomic_accession=151047720, orientation='plus', exon_count=12, OMIM=[611275], no_hdr0=''),
    149461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149461, CurrentID=0, Status='live', Symbol='CLDN19', Aliases=['HOMG5'], description='claudin 19', other_designations='claudin-19', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42733093, end_position_on_the_genomic_accession=42740236, orientation='minus', exon_count=4, OMIM=[610036], no_hdr0=''),
    149465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149465, CurrentID=0, Status='live', Symbol='CFAP57', Aliases=['VWS2', 'WDR65'], description='cilia and flagella associated protein 57', other_designations='cilia- and flagella-associated protein 57|WD repeat-containing protein 65', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43172330, end_position_on_the_genomic_accession=43254358, orientation='plus', exon_count=28, OMIM=[614259], no_hdr0=''),
    149466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149466, CurrentID=0, Status='live', Symbol='C1orf210', Aliases=['TEMP'], description='chromosome 1 open reading frame 210', other_designations='type III endosome membrane protein TEMP', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43281877, end_position_on_the_genomic_accession=43285840, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    149473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149473, CurrentID=0, Status='live', Symbol='CCDC24', Aliases=[], description='coiled-coil domain containing 24', other_designations='coiled-coil domain-containing protein 24', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43991599, end_position_on_the_genomic_accession=43996528, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    149478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149478, CurrentID=0, Status='live', Symbol='BTBD19', Aliases=[], description='BTB domain containing 19', other_designations='BTB/POZ domain-containing protein 19|BTB (POZ) domain containing 19|novel BTB domain containing protein', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44807442, end_position_on_the_genomic_accession=44815585, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    149483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149483, CurrentID=0, Status='live', Symbol='CCDC17', Aliases=[], description='coiled-coil domain containing 17', other_designations='coiled-coil domain-containing protein 17', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=45620044, end_position_on_the_genomic_accession=45624787, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    149499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149499, CurrentID=0, Status='live', Symbol='LRRC71', Aliases=['C1orf92'], description='leucine rich repeat containing 71', other_designations='leucine-rich repeat-containing protein 71|leucine-rich repeat-containing protein C10orf92', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156920608, end_position_on_the_genomic_accession=156941240, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    149563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149563, CurrentID=0, Status='live', Symbol='SRARP', Aliases=['C1orf64', 'ERRF'], description='steroid receptor associated and regulated protein', other_designations='steroid receptor-associated and regulated protein|ER-related factor|steroid receptor-regulated protein|uncharacterized protein C1orf64', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16004236, end_position_on_the_genomic_accession=16008807, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    149603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149603, CurrentID=0, Status='live', Symbol='RNF187', Aliases=['RACO-1', 'RACO1'], description='ring finger protein 187', other_designations='E3 ubiquitin-protein ligase RNF187|RING domain AP1 coactivator 1|RING-type E3 ubiquitin transferase RNF187|protein RNF187|ring domain AP-1 co-activator 1', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228487382, end_position_on_the_genomic_accession=228496188, orientation='plus', exon_count=4, OMIM=[613754], no_hdr0=''),
    149628 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149628, CurrentID=0, Status='live', Symbol='PYHIN1', Aliases=['IFIX'], description='pyrin and HIN domain family member 1', other_designations='pyrin and HIN domain-containing protein 1|interferon-inducible protein X', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158931547, end_position_on_the_genomic_accession=158990909, orientation='plus', exon_count=13, OMIM=[612677], no_hdr0=''),
    149643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149643, CurrentID=0, Status='live', Symbol='SPATA45', Aliases=['C1orf227'], description='spermatogenesis associated 45', other_designations='spermatogenesis-associated protein 45|UPF0732 protein C1orf227', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212830141, end_position_on_the_genomic_accession=212847649, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    149647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149647, CurrentID=0, Status='live', Symbol='FAM71A', Aliases=['GARI-L4'], description='family with sequence similarity 71 member A', other_designations='protein FAM71A|Golgi-associated Rab2B interactor-like 4|testis secretory sperm-binding protein Li 209a', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=212624474, end_position_on_the_genomic_accession=212626775, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    149685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149685, CurrentID=0, Status='live', Symbol='ADIG', Aliases=['SMAF1'], description='adipogenin', other_designations='adipogenin|adipogenesis associated|small adipocyte factor 1 (SMAF1)', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38581197, end_position_on_the_genomic_accession=38588463, orientation='plus', exon_count=3, OMIM=[611396], no_hdr0=''),
    149699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149699, CurrentID=0, Status='live', Symbol='GTSF1L', Aliases=['C20orf65', 'FAM112A', 'dJ1028D15.4'], description='gametocyte specific factor 1 like', other_designations='gametocyte-specific factor 1-like|family with sequence similarity 112, member A', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=43726161, end_position_on_the_genomic_accession=43727135, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    149708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149708, CurrentID=0, Status='live', Symbol='WFDC5', Aliases=['PRG5', 'WAP1', 'dJ211D12.5'], description='WAP four-disulfide core domain 5', other_designations='WAP four-disulfide core domain protein 5|p53-responsive gene 5 protein|protease inhibitor WAP1|putative protease inhibitor WAP1', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45109459, end_position_on_the_genomic_accession=45116321, orientation='minus', exon_count=6, OMIM=[605161], no_hdr0=''),
    149840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149840, CurrentID=0, Status='live', Symbol='SHLD1', Aliases=['C20orf196', 'RINN3'], description='shieldin complex subunit 1', other_designations='shieldin complex subunit 1|RINN1-REV7-interacting novel NHEJ regulator 3|shield complex subunit 1|uncharacterized protein C20orf196', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=5750286, end_position_on_the_genomic_accession=5864395, orientation='plus', exon_count=11, OMIM=[618028], no_hdr0=''),
    149951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149951, CurrentID=0, Status='live', Symbol='COMMD7', Aliases=['C20orf92', 'dJ1085F17.3'], description='COMM domain containing 7', other_designations='COMM domain-containing protein 7', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32702691, end_position_on_the_genomic_accession=32743472, orientation='minus', exon_count=9, OMIM=[616703], no_hdr0=''),
    149954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149954, CurrentID=0, Status='live', Symbol='BPIFB4', Aliases=['C20orf186', 'LPLUNC4', 'RY2G5', 'dJ726C3.5'], description='BPI fold containing family B member 4', other_designations='BPI fold-containing family B member 4|ligand-binding protein RY2G5|likely ortholog of rat probable ligand-binding protein RY2G5|long palate, lung and nasal epithelium carcinoma associated 4|long palate, lung and nasal epithelium carcinoma-associated protein 4', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33079643, end_position_on_the_genomic_accession=33111751, orientation='plus', exon_count=18, OMIM=[615718], no_hdr0=''),
    149986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149986, CurrentID=0, Status='live', Symbol='LSM14B', Aliases=['C20orf40', 'FAM61B', 'FT005', 'LSM13', 'RAP55B', 'bA11M20.3'], description='LSM family member 14B', other_designations='protein LSM14 homolog B|LSM14 homolog B|LSM14B, SCD6 homolog B|RNA-associated protein 55B|family with sequence similarity 61, member B|hRAP55B', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62122454, end_position_on_the_genomic_accession=62135378, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    149998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=149998, CurrentID=0, Status='live', Symbol='LIPI', Aliases=['CT17', 'LPDL', 'PLA1C', 'PRED5', 'mPA-PLA1 beta'], description='lipase I', other_designations='lipase member I|LPD lipase|cancer/testis antigen 17|lipase, member I|membrane-associated phosphatidic acid-selective phospholipase A1-beta', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14108812, end_position_on_the_genomic_accession=14210955, orientation='minus', exon_count=12, OMIM=[609252], no_hdr0=''),
    150082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150082, CurrentID=0, Status='live', Symbol='LCA5L', Aliases=['C21orf13'], description='lebercilin LCA5 like', other_designations='lebercilin-like protein|LCA5L, lebercilin like|leber congenital amaurosis 5-like protein', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39405728, end_position_on_the_genomic_accession=39445793, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    150084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150084, CurrentID=0, Status='live', Symbol='IGSF5', Aliases=['GSF5', 'JAM4'], description='immunoglobulin superfamily member 5', other_designations='immunoglobulin superfamily member 5|immunoglobulin superfamily 5 like|junctional adhesion molecule 4', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39632465, end_position_on_the_genomic_accession=39802081, orientation='plus', exon_count=12, OMIM=[610638], no_hdr0=''),
    150094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150094, CurrentID=0, Status='live', Symbol='SIK1', Aliases=['DEE30', 'MSK', 'SIK', 'SIK-1B', 'SNF1LK', 'SIK1'], description='salt inducible kinase 1', other_designations='serine/threonine-protein kinase SIK1|Probable serine/threonine-protein kinase SIK1B|SNF1-like kinase|Salt-inducible kinase 1B|myocardial SNF1-like kinase|salt-inducible protein kinase 1|serine/threonine-protein kinase SNF1-like kinase 1|serine/threonine-protein kinase SNF1LK', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=43414483, end_position_on_the_genomic_accession=43427131, orientation='minus', exon_count=14, OMIM=[605705], no_hdr0=''),
    150159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150159, CurrentID=0, Status='live', Symbol='SLC9B1', Aliases=['NHA1', 'NHEDC1'], description='solute carrier family 9 member B1', other_designations='sodium/hydrogen exchanger 9B1|NHE domain-containing protein 1|Na(+)/H(+) exchanger-like domain-containing protein 1|sodium/hydrogen exchanger-like domain-containing protein 1|solute carrier family 9, subfamily B (NHA1, cation proton antiporter 1), member 1|solute carrier family 9, subfamily B (cation proton antiporter 2), member 1|testicular tissue protein Li 127', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102885049, end_position_on_the_genomic_accession=103019705, orientation='minus', exon_count=15, OMIM=[611527], no_hdr0=''),
    150160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150160, CurrentID=0, Status='live', Symbol='CCT8L2', Aliases=['CESK1'], description='chaperonin containing TCP1 subunit 8 like 2', other_designations='T-complex protein 1 subunit theta-like 2|chaperonin containing TCP1, subunit 8 (theta)-like 2|putative T-complex protein 1 subunit theta-like 2', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=16590751, end_position_on_the_genomic_accession=16592810, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    150165 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150165, CurrentID=0, Status='live', Symbol='XKR3', Aliases=['XRG3', 'XTES'], description='XK related 3', other_designations='XK-related protein 3|X Kell blood group precursor-related family, member 3|X-linked Kx blood group related 3|XK, Kell blood group complex subunit-related family, member 3|expressed in testis|x Kell blood group-related 3', map_location='22q11.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=16783480, end_position_on_the_genomic_accession=16825411, orientation='minus', exon_count=7, OMIM=[611674], no_hdr0=''),
    150209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150209, CurrentID=0, Status='live', Symbol='AIFM3', Aliases=['AIFL'], description='apoptosis inducing factor mitochondria associated 3', other_designations='apoptosis-inducing factor 3|apoptosis-inducing factor like|apoptosis-inducing factor, mitochondrion-associated, 3', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20965172, end_position_on_the_genomic_accession=20981358, orientation='plus', exon_count=22, OMIM=[617298], no_hdr0=''),
    150221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150221, CurrentID=0, Status='live', Symbol='RIMBP3C', Aliases=['RIM-BP3.3', 'RIMBP3.3'], description='RIMS binding protein 3C', other_designations='RIMS-binding protein 3C|RIM-BP3.C|RIMS binding protein 3.3', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21545666, end_position_on_the_genomic_accession=21551461, orientation='minus', exon_count=1, OMIM=[612701], no_hdr0=''),
    150223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150223, CurrentID=0, Status='live', Symbol='YDJC', Aliases=[], description='YdjC chitooligosaccharide deacetylase homolog', other_designations='carbohydrate deacetylase|UPF0249 protein ydjC homolog|YdjC homolog', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21628089, end_position_on_the_genomic_accession=21630022, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    150248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150248, CurrentID=0, Status='live', Symbol='C22orf15', Aliases=['N27C7-3'], description='chromosome 22 open reading frame 15', other_designations='uncharacterized protein C22orf15|protein N27C7-3', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23762523, end_position_on_the_genomic_accession=23765863, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    150274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150274, CurrentID=0, Status='live', Symbol='HSCB', Aliases=['DNAJC20', 'HSC20', 'JAC1'], description='HscB mitochondrial iron-sulfur cluster cochaperone', other_designations='iron-sulfur cluster co-chaperone protein HscB|DnaJ (Hsp40) homolog, subfamily C, member 20|HscB iron-sulfur cluster co-chaperone homolog|HscB mitochondrial iron-sulfur cluster co-chaperone|J-type co-chaperone HSC20|epididymis secretory sperm binding protein|iron-sulfur cluster co-chaperone protein HscB, mitochondrial', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=28741992, end_position_on_the_genomic_accession=28757510, orientation='plus', exon_count=7, OMIM=[608142], no_hdr0=''),
    150275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150275, CurrentID=0, Status='live', Symbol='CCDC117', Aliases=['dJ366L4.1'], description='coiled-coil domain containing 117', other_designations='coiled-coil domain-containing protein 117', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=28772695, end_position_on_the_genomic_accession=28789301, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    150280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150280, CurrentID=0, Status='live', Symbol='HORMAD2', Aliases=['CT46.2'], description='HORMA domain containing 2', other_designations='HORMA domain-containing protein 2', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30080069, end_position_on_the_genomic_accession=30207425, orientation='plus', exon_count=16, OMIM=[618842], no_hdr0=''),
    150290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150290, CurrentID=0, Status='live', Symbol='DUSP18', Aliases=['DSP18', 'DUSP20', 'LMWDSP20'], description='dual specificity phosphatase 18', other_designations='dual specificity protein phosphatase 18|low molecular weight dual specificity phosphatase 20', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30652051, end_position_on_the_genomic_accession=30667887, orientation='minus', exon_count=6, OMIM=[611446], no_hdr0=''),
    150297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150297, CurrentID=0, Status='live', Symbol='C22orf42', Aliases=['dJ90G24.6'], description='chromosome 22 open reading frame 42', other_designations='uncharacterized protein C22orf42', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32149006, end_position_on_the_genomic_accession=32160447, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    150350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150350, CurrentID=0, Status='live', Symbol='ENTHD1', Aliases=['CACNA1I', 'dJ370M22.3'], description='ENTH domain containing 1', other_designations='ENTH domain-containing protein 1|dJ370M22.3 (EPSIN 2B)|epsin-2B', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39743044, end_position_on_the_genomic_accession=39893884, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    150353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150353, CurrentID=0, Status='live', Symbol='DNAJB7', Aliases=['DJ5', 'HSC3'], description='DnaJ heat shock protein family (Hsp40) member B7', other_designations='dnaJ homolog subfamily B member 7|DnaJ (Hsp40) homolog, subfamily B, member 7|novel DnaJ domain protein', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=40859549, end_position_on_the_genomic_accession=40862113, orientation='minus', exon_count=1, OMIM=[611336], no_hdr0=''),
    150356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150356, CurrentID=0, Status='live', Symbol='CHADL', Aliases=['SLRR4B'], description='chondroadherin like', other_designations='chondroadherin-like protein', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41229510, end_position_on_the_genomic_accession=41241771, orientation='minus', exon_count=6, OMIM=[616236], no_hdr0=''),
    150365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150365, CurrentID=0, Status='live', Symbol='MEI1', Aliases=['HYDM3', 'SPATA38'], description='meiotic double-stranded break formation protein 1', other_designations='meiosis inhibitor protein 1|meiosis defective 1|meiosis defective protein 1|meiosis inhibitor 1|spermatogenesis associated 38', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41699503, end_position_on_the_genomic_accession=41799477, orientation='plus', exon_count=34, OMIM=[608797], no_hdr0=''),
    150368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150368, CurrentID=0, Status='live', Symbol='PHETA2', Aliases=['FAM109B', 'IPIP27B', 'Ses2'], description='PH domain containing endocytic trafficking adaptor 2', other_designations='sesquipedalian-2|27 kDa inositol polyphosphate phosphatase interacting protein B|family with sequence similarity 109 member B|inositol polyphosphate phosphatase-interacting protein B', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42074244, end_position_on_the_genomic_accession=42079438, orientation='plus', exon_count=3, OMIM=[614240], no_hdr0=''),
    150372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150372, CurrentID=0, Status='live', Symbol='NFAM1', Aliases=['CNAIP'], description='NFAT activating protein with ITAM motif 1', other_designations='NFAT activation molecule 1|calcineurin/NFAT-activating ITAM-containing protein', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42380407, end_position_on_the_genomic_accession=42437986, orientation='minus', exon_count=9, OMIM=[608740], no_hdr0=''),
    150379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150379, CurrentID=0, Status='live', Symbol='PNPLA5', Aliases=['GS2L', 'dJ388M5', 'dJ388M5.4'], description='patatin like phospholipase domain containing 5', other_designations='patatin-like phospholipase domain-containing protein 5|GS2-like protein', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43879678, end_position_on_the_genomic_accession=43892013, orientation='minus', exon_count=9, OMIM=[611589], no_hdr0=''),
    150383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150383, CurrentID=0, Status='live', Symbol='CDPF1', Aliases=['C22orf40'], description='cysteine rich DPF motif domain containing 1', other_designations='cysteine-rich DPF motif domain-containing protein 1|UPF0595 protein C22orf40', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=46244013, end_position_on_the_genomic_accession=46250780, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    150465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150465, CurrentID=0, Status='live', Symbol='TTL', Aliases=[], description='tubulin tyrosine ligase', other_designations='tubulin--tyrosine ligase|2410003M22Rik', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112482127, end_position_on_the_genomic_accession=112541739, orientation='plus', exon_count=9, OMIM=[608291], no_hdr0=''),
    150468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150468, CurrentID=0, Status='live', Symbol='CKAP2L', Aliases=[], description='cytoskeleton associated protein 2 like', other_designations='cytoskeleton-associated protein 2-like|radial fiber and mitotic spindle protein|radmis', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112736349, end_position_on_the_genomic_accession=112764617, orientation='minus', exon_count=10, OMIM=[616174], no_hdr0=''),
    150472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150472, CurrentID=0, Status='live', Symbol='CBWD2', Aliases=[], description='COBW domain containing 2', other_designations='COBW domain-containing protein 2|cobalamin synthase W domain-containing protein 2|cobalamin synthetase W domain-containing protein 2', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113437691, end_position_on_the_genomic_accession=113496204, orientation='plus', exon_count=19, OMIM=[611079], no_hdr0=''),
    150483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150483, CurrentID=0, Status='live', Symbol='TEKT4', Aliases=[], description='tektin 4', other_designations='tektin-4|epididymis secretory sperm binding protein', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=94871430, end_position_on_the_genomic_accession=94876823, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    150572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150572, CurrentID=0, Status='live', Symbol='SMYD1', Aliases=['BOP', 'KMT3D', 'ZMYND18', 'ZMYND22'], description='SET and MYND domain containing 1', other_designations='histone-lysine N-methyltransferase SMYD1|CD8 beta opposite|SET and MYND domain-containing protein 1|zinc finger, MYND domain containing 18', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88067825, end_position_on_the_genomic_accession=88113384, orientation='plus', exon_count=10, OMIM=[606846], no_hdr0=''),
    150590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150590, CurrentID=0, Status='live', Symbol='C2orf15', Aliases=[], description='chromosome 2 open reading frame 15', other_designations='uncharacterized protein C2orf15', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99141707, end_position_on_the_genomic_accession=99151669, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    150677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150677, CurrentID=0, Status='live', Symbol='OTOS', Aliases=['OTOSP'], description='otospiralin', other_designations='otospiralin', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240138942, end_position_on_the_genomic_accession=240141373, orientation='minus', exon_count=5, OMIM=[607877], no_hdr0=''),
    150678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150678, CurrentID=0, Status='live', Symbol='COPS9', Aliases=['CSNAP', 'MYEOV2'], description='COP9 signalosome subunit 9', other_designations='COP9 signalosome complex subunit 9|CSN acidic protein|helicase/primase complex protein|myeloma overexpressed 2|myeloma-overexpressed gene 2 protein', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240126548, end_position_on_the_genomic_accession=240136802, orientation='minus', exon_count=5, OMIM=[619349], no_hdr0=''),
    150681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150681, CurrentID=0, Status='live', Symbol='OR6B3', Aliases=['OR6B3PQ', 'OR6B3'], description='olfactory receptor family 6 subfamily B member 3', other_designations='olfactory receptor 6B3|olfactory receptor OR2-2|olfactory receptor, family 6, subfamily B, member 3 pseudogene', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240044571, end_position_on_the_genomic_accession=240053521, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    150684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150684, CurrentID=0, Status='live', Symbol='COMMD1', Aliases=['C2orf5', 'MURR1'], description='copper metabolism domain containing 1', other_designations='COMM domain-containing protein 1|copper metabolism (Murr1) domain containing 1|copper metabolism gene MURR1|protein Murr1', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61888391, end_position_on_the_genomic_accession=62136066, orientation='plus', exon_count=8, OMIM=[607238], no_hdr0=''),
    150696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150696, CurrentID=0, Status='live', Symbol='PROM2', Aliases=['PROML2'], description='prominin 2', other_designations='prominin-2|prominin-like protein 2|prominin-related protein', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95274449, end_position_on_the_genomic_accession=95291320, orientation='plus', exon_count=25, OMIM=[617160], no_hdr0=''),
    150709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150709, CurrentID=0, Status='live', Symbol='ANKAR', Aliases=[], description='ankyrin and armadillo repeat containing', other_designations='ankyrin and armadillo repeat-containing protein', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189674292, end_position_on_the_genomic_accession=189763059, orientation='plus', exon_count=29, OMIM=[609803], no_hdr0=''),
    150726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150726, CurrentID=0, Status='live', Symbol='FBXO41', Aliases=['FBX41'], description='F-box protein 41', other_designations='F-box only protein 41', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73254690, end_position_on_the_genomic_accession=73284478, orientation='minus', exon_count=17, OMIM=[609108], no_hdr0=''),
    150737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150737, CurrentID=0, Status='live', Symbol='TTC30B', Aliases=['IFT70', 'IFT70B', 'fleer'], description='tetratricopeptide repeat domain 30B', other_designations='tetratricopeptide repeat protein 30B|TPR repeat protein 30B', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177548998, end_position_on_the_genomic_accession=177552796, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    150763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150763, CurrentID=0, Status='live', Symbol='GPAT2', Aliases=['CT123'], description='glycerol-3-phosphate acyltransferase 2, mitochondrial', other_designations='glycerol-3-phosphate acyltransferase 2, mitochondrial|1-acylglycerol-3-phosphate O-acyltransferase GPAT2|cancer/testis antigen 123', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96021946, end_position_on_the_genomic_accession=96036265, orientation='minus', exon_count=24, OMIM=[616431], no_hdr0=''),
    150771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150771, CurrentID=0, Status='live', Symbol='ITPRIPL1', Aliases=['KIAA1754L'], description='ITPRIP like 1', other_designations='inositol 1,4,5-trisphosphate receptor-interacting protein-like 1|inositol 1,4,5-triphosphate receptor-interacting protein-like 1|inositol 1,4,5-trisphosphate receptor interacting protein-like 1', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96325317, end_position_on_the_genomic_accession=96330507, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    150786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150786, CurrentID=0, Status='live', Symbol='RAB6D', Aliases=['RAB6CL', 'WTH3DI'], description='RAB6D, member RAS oncogene family', other_designations='ras-related protein Rab-6D|RAB6C-like|rab6-like protein WTH3DI', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131360492, end_position_on_the_genomic_accession=131364168, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    150864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150864, CurrentID=0, Status='live', Symbol='FAM117B', Aliases=['ALS2CR13'], description='family with sequence similarity 117 member B', other_designations='protein FAM117B|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 13|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 13 protein', map_location='2q33.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202634969, end_position_on_the_genomic_accession=202769757, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    150921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150921, CurrentID=0, Status='live', Symbol='TCF23', Aliases=['OUT', 'TCF-23', 'bHLHa24'], description='transcription factor 23', other_designations='transcription factor 23|class A basic helix-loop-helix protein 24|class II basic helix-loop-helix protein TCF23', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27148892, end_position_on_the_genomic_accession=27156974, orientation='plus', exon_count=4, OMIM=[609635], no_hdr0=''),
    150946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150946, CurrentID=0, Status='live', Symbol='GAREM2', Aliases=['FAM59B', 'GAREML'], description='GRB2 associated regulator of MAPK1 subtype 2', other_designations='GRB2-associated and regulator of MAPK protein 2|GRB2 associated regulator of MAPK1 2|GRB2 associated, regulator of MAPK1-like|GRB2-associated and regulator of MAPK protein-like|GRB2-associated and regulator of MAPK1-like|family with sequence similarity 59, member B|protein FAM59B', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26173088, end_position_on_the_genomic_accession=26202529, orientation='plus', exon_count=11, OMIM=[617999], no_hdr0=''),
    150962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=150962, CurrentID=0, Status='live', Symbol='PUS10', Aliases=['CCDC139', 'DOBI', 'Hup10'], description='pseudouridine synthase 10', other_designations='tRNA pseudouridine synthase Pus10|coiled-coil domain containing 139|coiled-coil domain-containing protein 139|pseudouridylate synthase 10|psi55 synthase|putative tRNA pseudouridine synthase Pus10|tRNA pseudouridine 55 synthase|tRNA pseudouridylate synthase|tRNA-uridine isomerase', map_location='2p16.1-p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=60940218, end_position_on_the_genomic_accession=61019693, orientation='minus', exon_count=25, OMIM=[612787], no_hdr0=''),
    151011 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151011, CurrentID=0, Status='live', Symbol='SEPTIN10', Aliases=['SEPT10'], description='septin 10', other_designations='septin-10', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109542797, end_position_on_the_genomic_accession=109614205, orientation='minus', exon_count=13, OMIM=[611737], no_hdr0=''),
    151050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151050, CurrentID=0, Status='live', Symbol='KANSL1L', Aliases=['C2orf67', 'MSL1v2'], description='KAT8 regulatory NSL complex subunit 1 like', other_designations='KAT8 regulatory NSL complex subunit 1-like protein|KIAA1267-like|male-specific lethal 1 homolog', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=210021421, end_position_on_the_genomic_accession=210171409, orientation='minus', exon_count=23, OMIM=[613833], no_hdr0=''),
    151056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151056, CurrentID=0, Status='live', Symbol='PLB1', Aliases=['PLB', 'PLB/LIP'], description='phospholipase B1', other_designations='phospholipase B1, membrane-associated|lysophospholipase|phospholipase A2|phospholipase B/lipase|triacylglycerol lipase', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28488578, end_position_on_the_genomic_accession=28644142, orientation='plus', exon_count=69, OMIM=[610179], no_hdr0=''),
    151112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151112, CurrentID=0, Status='live', Symbol='ZSWIM2', Aliases=['MEX', 'ZZZ2'], description='zinc finger SWIM-type containing 2', other_designations='E3 ubiquitin-protein ligase ZSWIM2|MEKK1-related protein X|RING-type E3 ubiquitin transferase ZSWIM2|ZZ-type zinc finger-containing protein 2|zinc finger SWIM domain-containing protein 2|zinc finger, SWIM domain containing 2', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=186827475, end_position_on_the_genomic_accession=186849170, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    151126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151126, CurrentID=0, Status='live', Symbol='ZNF385B', Aliases=['ZNF533'], description='zinc finger protein 385B', other_designations='zinc finger protein 385B|zinc finger protein 533', map_location='2q31.2-q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=179441982, end_position_on_the_genomic_accession=179864550, orientation='minus', exon_count=25, OMIM=[612344], no_hdr0=''),
    151176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151176, CurrentID=0, Status='live', Symbol='ERFE', Aliases=['C1QTNF15', 'CTRP15', 'FAM132B'], description='erythroferrone', other_designations='erythroferrone|complement C1q tumor necrosis factor-related protein 15|family with sequence similarity 132, member B|myonectin|protein FAM132B', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238158970, end_position_on_the_genomic_accession=238168890, orientation='plus', exon_count=8, OMIM=[615099], no_hdr0=''),
    151188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151188, CurrentID=0, Status='live', Symbol='ARL6IP6', Aliases=['AIP-6', 'AIP6', 'PFAAP1'], description='ADP ribosylation factor like GTPase 6 interacting protein 6', other_designations='ADP-ribosylation factor-like protein 6-interacting protein 6|ADP-ribosylation factor GTPase 6 interacting protein 6|ADP-ribosylation factor-like 6 interacting protein 6|ADP-ribosylation-like factor 6 interacting protein 6|ARL-6-interacting protein 6|phosphonoformate immuno-associated protein 1|regulated by phosphonoformate', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=152717648, end_position_on_the_genomic_accession=152762396, orientation='plus', exon_count=11, OMIM=[616495], no_hdr0=''),
    151194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151194, CurrentID=0, Status='live', Symbol='METTL21A', Aliases=['FAM119A', 'HCA557b', 'HSPA-KMT'], description='methyltransferase 21A, HSPA lysine', other_designations='protein N-lysine methyltransferase METTL21A|HSPA lysine methyltransferase|family with sequence similarity 119, member A|heat shock protein 70kDa lysine (K) methyltransferase|hepatocellular carcinoma-associated antigen 557b|methyltransferase like 21A|methyltransferase-like protein 21A', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207580635, end_position_on_the_genomic_accession=207626053, orientation='minus', exon_count=11, OMIM=[615257], no_hdr0=''),
    151195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151195, CurrentID=0, Status='live', Symbol='CCNYL1', Aliases=[], description='cyclin Y like 1', other_designations='cyclin-Y-like protein 1', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207711640, end_position_on_the_genomic_accession=207756174, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    151230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151230, CurrentID=0, Status='live', Symbol='KLHL23', Aliases=['DITHP'], description='kelch like family member 23', other_designations='kelch-like protein 23|kelch-like 23', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169733832, end_position_on_the_genomic_accession=169751878, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    151242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151242, CurrentID=0, Status='live', Symbol='PPP1R1C', Aliases=['IPP5'], description='protein phosphatase 1 regulatory inhibitor subunit 1C', other_designations='protein phosphatase 1 regulatory subunit 1C|PP1 inhibitor protein 5|inhibitor-5 of protein phosphatase 1|protein phosphatase 1 regulatory subunit 1A', map_location='2q31.3-q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=181954480, end_position_on_the_genomic_accession=182131385, orientation='plus', exon_count=9, OMIM=[613240], no_hdr0=''),
    151246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151246, CurrentID=0, Status='live', Symbol='SGO2', Aliases=['SGOL2', 'TRIPIN'], description='shugoshin 2', other_designations='shugoshin 2|shugoshin-like 2', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200510198, end_position_on_the_genomic_accession=200584096, orientation='plus', exon_count=14, OMIM=[612425], no_hdr0=''),
    151254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151254, CurrentID=0, Status='live', Symbol='C2CD6', Aliases=['ALS2CR11'], description='C2 calcium dependent domain containing 6', other_designations='C2 calcium-dependent domain-containing protein 6|amyotrophic lateral sclerosis 2 (juvenile) chromosome region, candidate 11|amyotrophic lateral sclerosis 2 chromosomal region candidate gene 11 protein|amyotrophic lateral sclerosis 2 chromosome region candidate 11|testicular tissue protein Li 16', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=201487421, end_position_on_the_genomic_accession=201619182, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    151258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151258, CurrentID=0, Status='live', Symbol='SLC38A11', Aliases=['AVT2'], description='solute carrier family 38 member 11', other_designations='putative sodium-coupled neutral amino acid transporter 11', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=164894354, end_position_on_the_genomic_accession=164955525, orientation='minus', exon_count=14, OMIM=[616526], no_hdr0=''),
    151295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151295, CurrentID=0, Status='live', Symbol='SLC23A3', Aliases=['E2BP3', 'SVCT3', 'Yspl1'], description='solute carrier family 23 member 3', other_designations='solute carrier family 23 member 3|E2-binding protein 3|HPC E2-binding protein 3|Na(+)/L-ascorbic acid transporter 3|sodium-dependent vitamin C transporter 3|solute carrier family 23 (nucleobase transporters), member 3', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219161465, end_position_on_the_genomic_accession=219170029, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    151306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151306, CurrentID=0, Status='live', Symbol='GPBAR1', Aliases=['BG37', 'GPCR19', 'GPR131', 'M-BAR', 'TGR5'], description='G protein-coupled bile acid receptor 1', other_designations='G-protein coupled bile acid receptor 1|G-protein coupled bile acid receptor BG37|G-protein coupled receptor GPCR19|membrane bile acid receptor|membrane-type receptor for bile acids', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218259496, end_position_on_the_genomic_accession=218263861, orientation='plus', exon_count=3, OMIM=[610147], no_hdr0=''),
    151313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151313, CurrentID=0, Status='live', Symbol='FAHD2B', Aliases=[], description='fumarylacetoacetate hydrolase domain containing 2B', other_designations='fumarylacetoacetate hydrolase domain-containing protein 2B', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97080738, end_position_on_the_genomic_accession=97094882, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    151354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151354, CurrentID=0, Status='live', Symbol='LRATD1', Aliases=['FAM84A', 'NSE1', 'PP11517'], description='LRAT domain containing 1', other_designations='protein LRATD1|family with sequence similarity 84 member A|neurologic sensory protein 1|neurological/sensory 1|protein FAM84A', map_location='2p24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=14632717, end_position_on_the_genomic_accession=14651916, orientation='plus', exon_count=6, OMIM=[611234], no_hdr0=''),
    151393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151393, CurrentID=0, Status='live', Symbol='RMDN2', Aliases=['BLOCK18', 'FAM82A', 'FAM82A1', 'PRO34163', 'PYST9371', 'RMD-2', 'RMD2', 'RMD4'], description='regulator of microtubule dynamics 2', other_designations='regulator of microtubule dynamics protein 2|family with sequence similarity 82, member A|family with sequence similarity 82, member A1|microtubule-associated protein', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37920789, end_position_on_the_genomic_accession=38069246, orientation='plus', exon_count=22, OMIM=[611872], no_hdr0=''),
    151449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151449, CurrentID=0, Status='live', Symbol='GDF7', Aliases=['BMP12'], description='growth differentiation factor 7', other_designations='growth/differentiation factor 7|GDF-7', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=20667144, end_position_on_the_genomic_accession=20679243, orientation='plus', exon_count=2, OMIM=[604651], no_hdr0=''),
    151473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151473, CurrentID=0, Status='live', Symbol='SLC16A14', Aliases=['MCT14'], description='solute carrier family 16 member 14', other_designations='monocarboxylate transporter 14|MCT 14|monocarboxylic acid transporter 14|solute carrier family 16 (monocarboxylic acid transporters), member 14', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=230034976, end_position_on_the_genomic_accession=230068995, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    151516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151516, CurrentID=0, Status='live', Symbol='ASPRV1', Aliases=['ADLI', 'MUNO', 'SASP', 'SASPase', 'Taps'], description='aspartic peptidase retroviral like 1', other_designations='retroviral-like aspartic protease 1|TPA-inducible aspartic proteinase-like protein|skin aspartic protease|skin-specific retroviral-like aspartic protease', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69932717, end_position_on_the_genomic_accession=70087375, orientation='minus', exon_count=18, OMIM=[611765], no_hdr0=''),
    151525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151525, CurrentID=0, Status='live', Symbol='WDSUB1', Aliases=['UBOX6', 'WDSAM1'], description='WD repeat, sterile alpha motif and U-box domain containing 1', other_designations='WD repeat, SAM and U-box domain-containing protein 1', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159235793, end_position_on_the_genomic_accession=159286793, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    151531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151531, CurrentID=0, Status='live', Symbol='UPP2', Aliases=['UDRPASE2', 'UP2', 'UPASE2'], description='uridine phosphorylase 2', other_designations='uridine phosphorylase 2|UPase 2|liver-specific uridine phosphorylase|urdPase 2', map_location='2q24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=157995179, end_position_on_the_genomic_accession=158136154, orientation='plus', exon_count=13, OMIM=[617340], no_hdr0=''),
    151556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151556, CurrentID=0, Status='live', Symbol='GPR155', Aliases=['DEP.7', 'DEPDC3', 'PGR22'], description='G protein-coupled receptor 155', other_designations='integral membrane protein GPR155|G-protein coupled receptor PGR22', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174431571, end_position_on_the_genomic_accession=174494001, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    151613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151613, CurrentID=0, Status='live', Symbol='TTC14', Aliases=['DRDL5813', 'PRO19630'], description='tetratricopeptide repeat domain 14', other_designations='tetratricopeptide repeat protein 14|TPR repeat protein 14', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=180602163, end_position_on_the_genomic_accession=180618329, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    151636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151636, CurrentID=0, Status='live', Symbol='DTX3L', Aliases=['BBAP', 'RNF143'], description='deltex E3 ubiquitin ligase 3L', other_designations='E3 ubiquitin-protein ligase DTX3L|B-lymphoma- and BAL-associated protein|RING-type E3 ubiquitin transferase DTX3L|deltex 3 like, E3 ubiquitin ligase|deltex 3-like|rhysin-2|rhysin2', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122564338, end_position_on_the_genomic_accession=122575203, orientation='plus', exon_count=5, OMIM=[613143], no_hdr0=''),
    151647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151647, CurrentID=0, Status='live', Symbol='TAFA4', Aliases=['FAM19A4', 'TAFA-4'], description='TAFA chemokine like family member 4', other_designations='chemokine-like protein TAFA-4|family with sequence similarity 19 (chemokine (C-C motif)-like), member A4|family with sequence similarity 19 member A4, C-C motif chemokine like|protein FAM19A4', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=68731766, end_position_on_the_genomic_accession=68932610, orientation='minus', exon_count=6, OMIM=[617498], no_hdr0=''),
    151648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151648, CurrentID=0, Status='live', Symbol='SGO1', Aliases=['CAID', 'NY-BR-85', 'SGO', 'SGOL1'], description='shugoshin 1', other_designations='shugoshin 1|serologically defined breast cancer antigen NY-BR-85|shugoshin 1AB protein|shugoshin 1CD protein|shugoshin 1EF protein|shugoshin 1GH protein|shugoshin 1KL protein', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=20160593, end_position_on_the_genomic_accession=20188143, orientation='minus', exon_count=11, OMIM=[609168], no_hdr0=''),
    151649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151649, CurrentID=0, Status='live', Symbol='PP2D1', Aliases=['C3orf48'], description='protein phosphatase 2C like domain containing 1', other_designations='protein phosphatase 2C-like domain-containing protein 1', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=19979961, end_position_on_the_genomic_accession=20012264, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    151651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151651, CurrentID=0, Status='live', Symbol='EFHB', Aliases=['CFAP21'], description='EF-hand domain family member B', other_designations='EF-hand domain-containing family member B|cilia and flagella associated protein 21', map_location='3p24.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=19879472, end_position_on_the_genomic_accession=19947514, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    151742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151742, CurrentID=0, Status='live', Symbol='PPM1L', Aliases=['PP2C-epsilon', 'PP2CE', 'PPM1-LIKE'], description='protein phosphatase, Mg2+/Mn2+ dependent 1L', other_designations='protein phosphatase 1L|PP2C epsilon', map_location='3q25.33-q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160755532, end_position_on_the_genomic_accession=161078902, orientation='plus', exon_count=9, OMIM=[611931], no_hdr0=''),
    151790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151790, CurrentID=0, Status='live', Symbol='WDR49', Aliases=[], description='WD repeat domain 49', other_designations='WD repeat-containing protein 49', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=167478684, end_position_on_the_genomic_accession=167657923, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    151827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151827, CurrentID=0, Status='live', Symbol='LRRC34', Aliases=[], description='leucine rich repeat containing 34', other_designations='leucine-rich repeat-containing protein 34', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169793003, end_position_on_the_genomic_accession=169812904, orientation='minus', exon_count=11, OMIM=[619037], no_hdr0=''),
    151835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151835, CurrentID=0, Status='live', Symbol='CPNE9', Aliases=[], description='copine family member 9', other_designations='copine-9|copine IX|copine family member IX|copine-like protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9703833, end_position_on_the_genomic_accession=9729908, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    151871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151871, CurrentID=0, Status='live', Symbol='DPPA2', Aliases=['CT100', 'ECAT15-2', 'PESCRG1'], description='developmental pluripotency associated 2', other_designations='developmental pluripotency-associated protein 2|cancer/testis antigen 100|embryonic stem cell (ESC) associated transcript 15-2|pluripotent embryonic stem cell-related gene 1 protein', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=109293788, end_position_on_the_genomic_accession=109316589, orientation='minus', exon_count=11, OMIM=[614445], no_hdr0=''),
    151887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151887, CurrentID=0, Status='live', Symbol='CCDC80', Aliases=['CL2', 'DRO1', 'LINC01279', 'SSG1', 'URB', 'okuribin'], description='coiled-coil domain containing 80', other_designations='coiled-coil domain-containing protein 80|TCONS_00006930|down-regulated by oncogenes protein 1|long intergenic non-protein coding RNA 1279|nuclear envelope protein okuribin|steroid sensitive gene 1|up-regulated in BRS-3 deficient mouse homolog', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112596797, end_position_on_the_genomic_accession=112641143, orientation='minus', exon_count=8, OMIM=[608298], no_hdr0=''),
    151888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151888, CurrentID=0, Status='live', Symbol='BTLA', Aliases=['BTLA1', 'CD272'], description='B and T lymphocyte associated', other_designations='B- and T-lymphocyte attenuator|B- and T-lymphocyte-associated protein', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112463030, end_position_on_the_genomic_accession=112499757, orientation='minus', exon_count=6, OMIM=[607925], no_hdr0=''),
    151903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151903, CurrentID=0, Status='live', Symbol='CCDC12', Aliases=[], description='coiled-coil domain containing 12', other_designations='coiled-coil domain-containing protein 12', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46916310, end_position_on_the_genomic_accession=46982083, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    151963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151963, CurrentID=0, Status='live', Symbol='MB21D2', Aliases=['C3orf59'], description='Mab-21 domain containing 2', other_designations='protein MB21D2|mab-21 domain-containing protein 2', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=192796815, end_position_on_the_genomic_accession=192917856, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    151987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=151987, CurrentID=0, Status='live', Symbol='PPP4R2', Aliases=['PP4R2'], description='protein phosphatase 4 regulatory subunit 2', other_designations='serine/threonine-protein phosphatase 4 regulatory subunit 2', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=72996743, end_position_on_the_genomic_accession=73069198, orientation='plus', exon_count=12, OMIM=[613822], no_hdr0=''),
    152002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152002, CurrentID=0, Status='live', Symbol='XXYLT1', Aliases=['C3orf21'], description='xyloside xylosyltransferase 1', other_designations='xyloside xylosyltransferase 1|UDP-xylose:alpha-xyloside alpha-1,3-xylosyltransferase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195066970, end_position_on_the_genomic_accession=195271159, orientation='minus', exon_count=11, OMIM=[614552], no_hdr0=''),
    152006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152006, CurrentID=0, Status='live', Symbol='RNF38', Aliases=[], description='ring finger protein 38', other_designations='E3 ubiquitin-protein ligase RNF38|RING-type E3 ubiquitin transferase RNF38', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36336398, end_position_on_the_genomic_accession=36487384, orientation='minus', exon_count=19, OMIM=[612488], no_hdr0=''),
    152007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152007, CurrentID=0, Status='live', Symbol='GLIPR2', Aliases=['C9orf19', 'GAPR-1', 'GAPR1'], description='GLI pathogenesis related 2', other_designations='Golgi-associated plant pathogenesis-related protein 1|17kD fetal brain protein|gliPR 2|glioma pathogenesis-related protein 2|golgi-associated PR-1 protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=36136536, end_position_on_the_genomic_accession=36163913, orientation='plus', exon_count=9, OMIM=[607141], no_hdr0=''),
    152015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152015, CurrentID=0, Status='live', Symbol='ROPN1B', Aliases=[], description='rhophilin associated tail protein 1B', other_designations='ropporin-1B|AKAP-binding sperm protein ropporin|rhophilin-associated protein 1B|ropporin, rhophilin associated protein 1B|testis tissue sperm-binding protein Li 83P', map_location='3q21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=125969161, end_position_on_the_genomic_accession=125983454, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    152065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152065, CurrentID=0, Status='live', Symbol='C3orf22', Aliases=[], description='chromosome 3 open reading frame 22', other_designations='uncharacterized protein C3orf22', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126524439, end_position_on_the_genomic_accession=126558965, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    152098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152098, CurrentID=0, Status='live', Symbol='ZCWPW2', Aliases=['ZCW2'], description='zinc finger CW-type and PWWP domain containing 2', other_designations='zinc finger CW-type PWWP domain protein 2|zinc finger CW-type and PWWP domain 2|zinc finger, CW type with PWWP domain 2', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=28348721, end_position_on_the_genomic_accession=28526358, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    152100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152100, CurrentID=0, Status='live', Symbol='CMC1', Aliases=['C3orf68'], description='C-X9-C motif containing 1', other_designations='COX assembly mitochondrial protein homolog|C-x(9)-C motif containing 1|COX assembly mitochondrial protein 1 homolog|CX9C mitochondrial protein required for full expression of COX 1|cmc1p|mitochondrial metallochaperone-like protein', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=28241593, end_position_on_the_genomic_accession=28325142, orientation='plus', exon_count=15, OMIM=[615166], no_hdr0=''),
    152110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152110, CurrentID=0, Status='live', Symbol='NEK10', Aliases=['CILD44'], description='NIMA related kinase 10', other_designations='serine/threonine-protein kinase Nek10|NIMA (never in mitosis gene a)- related kinase 10|never in mitosis A-related kinase 10|nimA-related protein kinase 10', map_location='3p24.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=27106484, end_position_on_the_genomic_accession=27369460, orientation='minus', exon_count=47, OMIM=[618726], no_hdr0=''),
    152137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152137, CurrentID=0, Status='live', Symbol='CCDC50', Aliases=['C3orf6', 'DFNA44', 'YMER'], description='coiled-coil domain containing 50', other_designations='coiled-coil domain-containing protein 50|protein Ymer', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=191329082, end_position_on_the_genomic_accession=191398659, orientation='plus', exon_count=13, OMIM=[611051], no_hdr0=''),
    152138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152138, CurrentID=0, Status='live', Symbol='PYDC2', Aliases=['POP2', 'cPOP2'], description='pyrin domain containing 2', other_designations='pyrin domain-containing protein 2|cellular POP2|pyrin-only protein 2', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=191461163, end_position_on_the_genomic_accession=191461456, orientation='plus', exon_count=1, OMIM=[615701], no_hdr0=''),
    152185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152185, CurrentID=0, Status='live', Symbol='SPICE1', Aliases=['CCDC52', 'SPICE'], description='spindle and centriole associated protein 1', other_designations='spindle and centriole-associated protein 1|coiled-coil domain-containing protein 52', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113442718, end_position_on_the_genomic_accession=113515156, orientation='minus', exon_count=18, OMIM=[613447], no_hdr0=''),
    152189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152189, CurrentID=0, Status='live', Symbol='CMTM8', Aliases=['CKLFSF8', 'CKLFSF8-V2'], description='CKLF like MARVEL transmembrane domain containing 8', other_designations='CKLF-like MARVEL transmembrane domain-containing protein 8|chemokine-like factor superfamily member 8', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=32238680, end_position_on_the_genomic_accession=32370321, orientation='plus', exon_count=7, OMIM=[607891], no_hdr0=''),
    152206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152206, CurrentID=0, Status='live', Symbol='CCDC13', Aliases=[], description='coiled-coil domain containing 13', other_designations='coiled-coil domain-containing protein 13', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42704118, end_position_on_the_genomic_accession=42773253, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    152217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152217, CurrentID=0, Status='live', Symbol='NCBP2AS2', Aliases=['HIAR', 'KRASIM', 'NCBP2-AS2'], description='NCBP2 antisense 2 (head to head)', other_designations='protein NCBP2AS2|KRAS-interacting microprotein|NCBP2 antisense RNA 2 (head to head)|NCBP2 antisense gene protein 2|hypoxia-induced angiogenesis regulator', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196942674, end_position_on_the_genomic_accession=196943543, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    152273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152273, CurrentID=0, Status='live', Symbol='FGD5', Aliases=['ZFYVE23'], description='FYVE, RhoGEF and PH domain containing 5', other_designations='FYVE, RhoGEF and PH domain-containing protein 5|zinc finger FYVE domain-containing protein 23', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=14818962, end_position_on_the_genomic_accession=14934571, orientation='plus', exon_count=20, OMIM=[614788], no_hdr0=''),
    152330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152330, CurrentID=0, Status='live', Symbol='CNTN4', Aliases=['AXCAM', 'BIG-2'], description='contactin 4', other_designations='contactin-4|axonal-associated cell adhesion molecule|brain-derived immunoglobulin superfamily protein 2|neural cell adhesion protein BIG-2', map_location='3p26.3-p26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=2098866, end_position_on_the_genomic_accession=3059080, orientation='plus', exon_count=34, OMIM=[607280], no_hdr0=''),
    152404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152404, CurrentID=0, Status='live', Symbol='IGSF11', Aliases=['BT-IgSF', 'CT119', 'CXADRL1', 'Igsf13', 'VSIG3'], description='immunoglobulin superfamily member 11', other_designations='immunoglobulin superfamily member 11|CXADR like 1|V-set and immunoglobulin domain containing 3|V-set and immunoglobulin domain-containing protein 3|brain and testis-specific immunoglobin superfamily protein|brain and testis-specific immunoglobulin superfamily protein|cancer/testis antigen 119', map_location='3q13.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=118900557, end_position_on_the_genomic_accession=119146064, orientation='minus', exon_count=15, OMIM=[608351], no_hdr0=''),
    152405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152405, CurrentID=0, Status='live', Symbol='TEX55', Aliases=['C3orf30', 'TSCPA'], description='testis expressed 55', other_designations='testis-specific expressed protein 55|Testis-specific conserved, cAMP-dependent type II PK anchoring protein|uncharacterized protein C3orf30', map_location='3q13.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=119146165, end_position_on_the_genomic_accession=119151456, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    152485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152485, CurrentID=0, Status='live', Symbol='ZNF827', Aliases=[], description='zinc finger protein 827', other_designations='zinc finger protein 827', map_location='4q31.21-q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145757627, end_position_on_the_genomic_accession=145938823, orientation='minus', exon_count=19, OMIM=[617962], no_hdr0=''),
    152503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152503, CurrentID=0, Status='live', Symbol='SH3D19', Aliases=['EBP', 'EVE1', 'Eve-1', 'Kryn', 'SH3P19'], description='SH3 domain containing 19', other_designations='SH3 domain-containing protein 19|ADAM-binding protein Eve-1|EEN-binding protein|SH3 domain protein D19', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=151120281, end_position_on_the_genomic_accession=151325605, orientation='minus', exon_count=24, OMIM=[608674], no_hdr0=''),
    152518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152518, CurrentID=0, Status='live', Symbol='NFXL1', Aliases=['CDZFP', 'HOZFP', 'OZFP', 'URCC5'], description='nuclear transcription factor, X-box binding like 1', other_designations='NF-X1-type zinc finger protein NFXL1|cytoplasm-distribution zinc finger protein|ovarian zinc finger protein|up-regulated in colon cancer 5', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=47847233, end_position_on_the_genomic_accession=47914667, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    152519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152519, CurrentID=0, Status='live', Symbol='NIPAL1', Aliases=['NPAL1', 'SLC57A3'], description='NIPA like domain containing 1', other_designations='magnesium transporter NIPA3|NIPA-like protein 1|non-imprinted in Prader-Willi/Angelman syndrome region protein 3', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48016772, end_position_on_the_genomic_accession=48040173, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    152559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152559, CurrentID=0, Status='live', Symbol='PAQR3', Aliases=['RKTG'], description='progestin and adipoQ receptor family member 3', other_designations='progestin and adipoQ receptor family member 3|Raf kinase trapping to Golgi|progestin and adipoQ receptor family member III', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=78887225, end_position_on_the_genomic_accession=78939438, orientation='minus', exon_count=15, OMIM=[614577], no_hdr0=''),
    152573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152573, CurrentID=0, Status='live', Symbol='SHISA3', Aliases=['hShisa3'], description='shisa family member 3', other_designations='protein shisa-3 homolog|shisa homolog 3', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=42397488, end_position_on_the_genomic_accession=42402487, orientation='plus', exon_count=2, OMIM=[617325], no_hdr0=''),
    152579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152579, CurrentID=0, Status='live', Symbol='SCFD2', Aliases=['STXBP1L1'], description='sec1 family domain containing 2', other_designations='sec1 family domain-containing protein 2|syntaxin binding protein 1-like 1', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52872630, end_position_on_the_genomic_accession=53366106, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    152586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152586, CurrentID=0, Status='live', Symbol='MGAT4D', Aliases=['GnT1IP'], description='MGAT4 family member D', other_designations='alpha-1,3-mannosyl-glycoprotein 4-beta-N-acetylglucosaminyltransferase-like protein MGAT4D|GlcNAcT-I Inhibitory Protein|N-acetylglucosaminyltransferase MGAT1 inhibitory protein|glycosyltransferase 54 domain containing 1|glycosyltransferase 54 domain-containing protein|mannosyl (alpha-1,3-)-glycoprotein beta-1,4-N-acetylglucosaminyltransferase family, member D', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140442257, end_position_on_the_genomic_accession=140499046, orientation='minus', exon_count=14, OMIM=[610310], no_hdr0=''),
    152687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152687, CurrentID=0, Status='live', Symbol='ZNF595', Aliases=[], description='zinc finger protein 595', other_designations='zinc finger protein 595', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=53276, end_position_on_the_genomic_accession=88208, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    152789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152789, CurrentID=0, Status='live', Symbol='JAKMIP1', Aliases=['Gababrbp', 'JAMIP1', 'MARLIN1'], description='janus kinase and microtubule interacting protein 1', other_designations='janus kinase and microtubule-interacting protein 1|GABA-B receptor-binding protein|Jak and microtubule interacting protein 1|marlin-1|multiple alpha-helices and RNA-linker protein 1|multiple coiled-coil GABABR1-binding protein', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=6024925, end_position_on_the_genomic_accession=6200555, orientation='minus', exon_count=25, OMIM=[611195], no_hdr0=''),
    152815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152815, CurrentID=0, Status='live', Symbol='THAP6', Aliases=[], description='THAP domain containing 6', other_designations='THAP domain-containing protein 6', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75513944, end_position_on_the_genomic_accession=75547328, orientation='plus', exon_count=11, OMIM=[612535], no_hdr0=''),
    152816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152816, CurrentID=0, Status='live', Symbol='ODAPH', Aliases=['AI2A4', 'C4orf26'], description='odontogenesis associated phosphoprotein', other_designations='odontogenesis associated phosphoprotein|amelogenesis imperfecta type IIA4|uncharacterized protein C4orf26', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=75554997, end_position_on_the_genomic_accession=75565893, orientation='plus', exon_count=6, OMIM=[614829], no_hdr0=''),
    152831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152831, CurrentID=0, Status='live', Symbol='KLB', Aliases=['BKL'], description='klotho beta', other_designations='beta-klotho|b-Klotho|betaKlotho|klotho beta like|klotho beta-like protein', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39406930, end_position_on_the_genomic_accession=39451533, orientation='plus', exon_count=5, OMIM=[611135], no_hdr0=''),
    152877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152877, CurrentID=0, Status='live', Symbol='FAM53A', Aliases=['DNTNP'], description='family with sequence similarity 53 member A', other_designations='protein FAM53A|dorsal neural-tube nuclear protein', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1574055, end_position_on_the_genomic_accession=1684313, orientation='minus', exon_count=9, OMIM=[617229], no_hdr0=''),
    152926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152926, CurrentID=0, Status='live', Symbol='PPM1K', Aliases=['BDP', 'MSUDMV', 'PP2Ckappa', 'PP2Cm', 'PTMP', 'UG0882E07'], description='protein phosphatase, Mg2+/Mn2+ dependent 1K', other_designations='protein phosphatase 1K, mitochondrial|PP2C domain-containing protein phosphatase 1K|PP2C-kappa|PP2C-type mitochondrial phosphoprotein phosphatase|branched-chain I+/--ketoacid dehydrogenase phosphatase|branched-chain alpha-ketoacid dehydrogenase phosphatase|protein phosphatase 2C kappa', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88257617, end_position_on_the_genomic_accession=88284670, orientation='minus', exon_count=11, OMIM=[611065], no_hdr0=''),
    152940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152940, CurrentID=0, Status='live', Symbol='C4orf45', Aliases=[], description='chromosome 4 open reading frame 45', other_designations='uncharacterized protein C4orf45', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158893134, end_position_on_the_genomic_accession=159082883, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    152992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=152992, CurrentID=0, Status='live', Symbol='TRMT44', Aliases=['C4orf23', 'METTL19', 'TRM44'], description='tRNA methyltransferase 44 homolog', other_designations='probable tRNA (uracil-O(2)-)-methyltransferase|methyltransferase like 19|methyltransferase-like protein 19', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=8440774, end_position_on_the_genomic_accession=8512531, orientation='plus', exon_count=18, OMIM=[614309], no_hdr0=''),
    153020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153020, CurrentID=0, Status='live', Symbol='RASGEF1B', Aliases=['GPIG4'], description='RasGEF domain family member 1B', other_designations='ras-GEF domain-containing family member 1B|GPI gamma-4', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=81426393, end_position_on_the_genomic_accession=81471907, orientation='minus', exon_count=15, OMIM=[614532], no_hdr0=''),
    153090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153090, CurrentID=0, Status='live', Symbol='DAB2IP', Aliases=['AF9Q34', 'AIP-1', 'AIP1', 'DIP1/2'], description='DAB2 interacting protein', other_designations='disabled homolog 2-interacting protein|ASK-interacting protein 1|ASK1-interacting protein 1|DAB2 interaction protein|DOC-2/DAB2 interactive protein|nGAP-like protein', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121566883, end_position_on_the_genomic_accession=121785530, orientation='plus', exon_count=28, OMIM=[609205], no_hdr0=''),
    153129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153129, CurrentID=0, Status='live', Symbol='SLC38A9', Aliases=['URLC11'], description='solute carrier family 38 member 9', other_designations='sodium-coupled neutral amino acid transporter 9|putative sodium-coupled neutral amino acid transporter 9|up-regulated in lung cancer 11', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55625845, end_position_on_the_genomic_accession=55712343, orientation='minus', exon_count=21, OMIM=[616203], no_hdr0=''),
    153201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153201, CurrentID=0, Status='live', Symbol='SLC36A2', Aliases=['PAT2', 'TRAMD1'], description='solute carrier family 36 member 2', other_designations='proton-coupled amino acid transporter 2|solute carrier family 36 (proton/amino acid symporter), member 2|tramdorin-1', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151314972, end_position_on_the_genomic_accession=151347583, orientation='minus', exon_count=12, OMIM=[608331], no_hdr0=''),
    153218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153218, CurrentID=0, Status='live', Symbol='SPINK13', Aliases=['HBVDNAPTP1', 'HESPINTOR', 'LiESP6', 'SPINK5L3'], description='serine peptidase inhibitor Kazal type 13', other_designations='serine protease inhibitor Kazal-type 13|Hepatitis B Virus (HBV) DNA polymerase transactivated protein 1|hepatitis B virus DNA polymerase transactivated human serine protease inhibitor|hepatitis B virus DNA polymerase transactivated serine protease inhibitor|serine peptidase inhibitor, Kazal type 13 (putative)|serine protease inhibitor Kazal-type 5-like 3', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148268794, end_position_on_the_genomic_accession=148286255, orientation='plus', exon_count=6, OMIM=[615205], no_hdr0=''),
    153222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153222, CurrentID=0, Status='live', Symbol='CREBRF', Aliases=['C5orf41', 'LRF'], description='CREB3 regulatory factor', other_designations='CREB3 regulatory factor|UPF0474 protein C5orf41|adult retina protein|luman recruitment factor|luman-recruiting factor|luman/CREB3 recruitment factor', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=173056349, end_position_on_the_genomic_accession=173139284, orientation='plus', exon_count=10, OMIM=[617109], no_hdr0=''),
    153241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153241, CurrentID=0, Status='live', Symbol='CEP120', Aliases=['CCDC100', 'JBTS31', 'SRTD13'], description='centrosomal protein 120', other_designations='centrosomal protein of 120 kDa|centrosomal protein 120kDa|coiled-coil domain-containing protein 100', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=123344890, end_position_on_the_genomic_accession=123423842, orientation='minus', exon_count=25, OMIM=[613446], no_hdr0=''),
    153328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153328, CurrentID=0, Status='live', Symbol='SLC25A48', Aliases=[], description='solute carrier family 25 member 48', other_designations='solute carrier family 25 member 48|CTC-321K16.1', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135579172, end_position_on_the_genomic_accession=135888637, orientation='plus', exon_count=17, OMIM=[616150], no_hdr0=''),
    153339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153339, CurrentID=0, Status='live', Symbol='TMEM167A', Aliases=['TMEM167'], description='transmembrane protein 167A', other_designations='protein kish-A|transmembrane protein 167', map_location='5q14.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=83052846, end_position_on_the_genomic_accession=83077394, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    153364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153364, CurrentID=0, Status='live', Symbol='MBLAC2', Aliases=[], description='metallo-beta-lactamase domain containing 2', other_designations='metallo-beta-lactamase domain-containing protein 2', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=90458209, end_position_on_the_genomic_accession=90474771, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    153396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153396, CurrentID=0, Status='live', Symbol='TMEM161B', Aliases=['FLB3342', 'PRO1313'], description='transmembrane protein 161B', other_designations='transmembrane protein 161B', map_location='5q14.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=88179300, end_position_on_the_genomic_accession=88268906, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    153443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153443, CurrentID=0, Status='live', Symbol='SRFBP1', Aliases=['BUD22', 'P49', 'Rlb1', 'STRAP', 'p49/STRAP'], description='serum response factor binding protein 1', other_designations='serum response factor-binding protein 1|BUD22 homolog|SRF-dependent transcription regulation-associated protein', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=121961975, end_position_on_the_genomic_accession=122075624, orientation='plus', exon_count=9, OMIM=[610479], no_hdr0=''),
    153478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153478, CurrentID=0, Status='live', Symbol='PLEKHG4B', Aliases=[], description='pleckstrin homology and RhoGEF domain containing G4B', other_designations='pleckstrin homology domain-containing family G member 4B|PH domain-containing family G member 4B|pleckstrin homology domain containing, family G (with RhoGef domain) member 4B', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=92110, end_position_on_the_genomic_accession=189966, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    153527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153527, CurrentID=0, Status='live', Symbol='ZMAT2', Aliases=['Ptg-12', 'Snu23'], description='zinc finger matrin-type 2', other_designations='zinc finger matrin-type protein 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140700447, end_position_on_the_genomic_accession=140706686, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    153562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153562, CurrentID=0, Status='live', Symbol='MARVELD2', Aliases=['DFNB49', 'MARVD2', 'MRVLDC2', 'Tric'], description='MARVEL domain containing 2', other_designations='MARVEL domain-containing protein 2|MARVEL (membrane-associating) domain containing 2|tricellulin', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69415116, end_position_on_the_genomic_accession=69444330, orientation='plus', exon_count=9, OMIM=[610572], no_hdr0=''),
    153572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153572, CurrentID=0, Status='live', Symbol='IRX2', Aliases=['IRXA2'], description='iroquois homeobox 2', other_designations='iroquois-class homeodomain protein IRX-2|homeodomain protein IRXA2|iroquois homeobox protein 2', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=2707930, end_position_on_the_genomic_accession=2751677, orientation='minus', exon_count=12, OMIM=[606198], no_hdr0=''),
    153579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153579, CurrentID=0, Status='live', Symbol='BTNL9', Aliases=['BTN3', 'BTN8', 'VDLS1900'], description='butyrophilin like 9', other_designations='butyrophilin-like protein 9|butyrophilin 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181039872, end_position_on_the_genomic_accession=181061525, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    153642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153642, CurrentID=0, Status='live', Symbol='ARSK', Aliases=['TSULF'], description='arylsulfatase family member K', other_designations='arylsulfatase K|ASK|telethon sulfatase', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95555101, end_position_on_the_genomic_accession=95605102, orientation='plus', exon_count=9, OMIM=[610011], no_hdr0=''),
    153643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153643, CurrentID=0, Status='live', Symbol='FAM81B', Aliases=[], description='family with sequence similarity 81 member B', other_designations='protein FAM81B', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95384796, end_position_on_the_genomic_accession=95450441, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    153657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153657, CurrentID=0, Status='live', Symbol='TTC23L', Aliases=['MC25-1'], description='tetratricopeptide repeat domain 23 like', other_designations='tetratricopeptide repeat protein 23-like', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=34839164, end_position_on_the_genomic_accession=34925682, orientation='plus', exon_count=27, OMIM=[616344], no_hdr0=''),
    153733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153733, CurrentID=0, Status='live', Symbol='CCDC112', Aliases=['MBC1'], description='coiled-coil domain containing 112', other_designations='coiled-coil domain-containing protein 112|mutated in bladder cancer 1|mutated in bladder cancer protein 1', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115267190, end_position_on_the_genomic_accession=115296755, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    153743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153743, CurrentID=0, Status='live', Symbol='PPP1R2B', Aliases=['PPP1R2P3'], description='PPP1R2 family member B', other_designations='protein phosphatase inhibitor 2 family member B|protein phosphatase 1 regulatory inhibitor subunit 2 pseudogene 3|protein phosphatase 1, regulatory subunit 2 pseudogene 3|protein phosphatase inhibitor 2-like protein 3', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=156850295, end_position_on_the_genomic_accession=156852528, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    153745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153745, CurrentID=0, Status='live', Symbol='FAM71B', Aliases=[], description='family with sequence similarity 71 member B', other_designations='protein FAM71B|testicular tissue protein Li 68', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157161846, end_position_on_the_genomic_accession=157166264, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    153768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153768, CurrentID=0, Status='live', Symbol='PRELID2', Aliases=[], description='PRELI domain containing 2', other_designations='PRELI domain-containing protein 2|CTC-806A22.1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=145587325, end_position_on_the_genomic_accession=145835369, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    153769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153769, CurrentID=0, Status='live', Symbol='SH3RF2', Aliases=['HEPP1', 'POSHER', 'PPP1R39', 'RNF158'], description='SH3 domain containing ring finger 2', other_designations='E3 ubiquitin-protein ligase SH3RF2|POSH-eliminating RING protein|RING finger protein 158|RING-type E3 ubiquitin transferase SH3RF2|SH3 domain-containing RING finger protein 2|heart protein phosphatase 1-binding protein|phosphatase 1 binding protein|protein phosphatase 1 regulatory subunit 39|putative E3 ubiquitin-protein ligase SH3RF2', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=145936570, end_position_on_the_genomic_accession=146081773, orientation='plus', exon_count=11, OMIM=[613377], no_hdr0=''),
    153770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153770, CurrentID=0, Status='live', Symbol='PLAC8L1', Aliases=[], description='PLAC8 like 1', other_designations='PLAC8-like protein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=146084149, end_position_on_the_genomic_accession=146105577, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    153830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153830, CurrentID=0, Status='live', Symbol='RNF145', Aliases=[], description='ring finger protein 145', other_designations='RING finger protein 145', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=159157409, end_position_on_the_genomic_accession=159210053, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    153918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=153918, CurrentID=0, Status='live', Symbol='ZC2HC1B', Aliases=['C6orf94', 'FAM164B', 'dJ468K18.5'], description='zinc finger C2HC-type containing 1B', other_designations='zinc finger C2HC domain-containing protein 1B|family with sequence similarity 164, member B|protein FAM164B', map_location='6q24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=143864474, end_position_on_the_genomic_accession=143938343, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    154007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154007, CurrentID=0, Status='live', Symbol='SNRNP48', Aliases=['C6orf151', 'dJ336K20B.1', 'dJ512B11.2'], description='small nuclear ribonucleoprotein U11/U12 subunit 48', other_designations='U11/U12 small nuclear ribonucleoprotein 48 kDa protein|U11-48K|U11/U12 snRNP 48 kDa protein|U11/U12 snRNP 48K|U11/U12-48K|small nuclear ribonucleoprotein 48kDa (U11/U12)|small nuclear ribonucleoprotein, U11/U12 48KDa subunit', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7590198, end_position_on_the_genomic_accession=7611967, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    154043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154043, CurrentID=0, Status='live', Symbol='CNKSR3', Aliases=['CNK3', 'CNK3/IPCEF1', 'MAGI1'], description='CNKSR family member 3', other_designations='connector enhancer of kinase suppressor of ras 3|CNK homolog protein 3|connector enhancer of KSR 3|maguin-like protein|membrane associated guanylate kinase, WW and PDZ domain containing 1|membrane-associated guanylate kinase-interacting protein-like 1', map_location='6q25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=154387515, end_position_on_the_genomic_accession=154510685, orientation='minus', exon_count=15, OMIM=[617476], no_hdr0=''),
    154064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154064, CurrentID=0, Status='live', Symbol='RAET1L', Aliases=['ULBP6'], description='retinoic acid early transcript 1L', other_designations='UL16-binding protein 6|UL16 binding protein 6|retinoic acid early transcript 1L protein', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150018334, end_position_on_the_genomic_accession=150025532, orientation='minus', exon_count=5, OMIM=[611047], no_hdr0=''),
    154075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154075, CurrentID=0, Status='live', Symbol='SAMD3', Aliases=[], description='sterile alpha motif domain containing 3', other_designations='sterile alpha motif domain-containing protein 3|SAM domain-containing protein 3', map_location='6q23.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=130133203, end_position_on_the_genomic_accession=130365868, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    154091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154091, CurrentID=0, Status='live', Symbol='SLC2A12', Aliases=['GLUT12', 'GLUT8'], description='solute carrier family 2 member 12', other_designations='solute carrier family 2, facilitated glucose transporter member 12|GLUT-12|glucose transporter type 12|solute carrier family 2 (facilitated glucose transporter), member 12', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=133987581, end_position_on_the_genomic_accession=134052651, orientation='minus', exon_count=7, OMIM=[610372], no_hdr0=''),
    154141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154141, CurrentID=0, Status='live', Symbol='MBOAT1', Aliases=['LPEAT1', 'LPLAT', 'LPLAT 1', 'LPSAT', 'OACT1', 'dJ434O11.1'], description='membrane bound O-acyltransferase domain containing 1', other_designations='lysophospholipid acyltransferase 1|1-acylglycerophosphocholine O-acyltransferase|1-acylglycerophosphoethanolamine O-acyltransferase|1-acylglycerophosphoserine O-acyltransferase|1-acylglycerophosphoserine O-acyltransferase MBOAT1|O-acyltransferase (membrane bound) domain containing 1|O-acyltransferase domain-containing protein 1|lyso-PS acyltransferase|lysophosphatidylethanolamine acyltransferase 1|lysophosphatidylserine acyltransferase|membrane-bound O-acyltransferase domain-containing protein 1', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=20099684, end_position_on_the_genomic_accession=20212469, orientation='minus', exon_count=15, OMIM=[611732], no_hdr0=''),
    154150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154150, CurrentID=0, Status='live', Symbol='HDGFL1', Aliases=['HRP-1', 'Hdgfrp1', 'PWWP1', 'dJ309H15.1'], description='HDGF like 1', other_designations='hepatoma-derived growth factor-like protein 1|HDGF (hepatoma-derived growth factor) like|PWWP domain containing 1|PWWP domain-containing protein 1|hepatoma derived growth factor-like 1|testicular tissue protein Li 84', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=22569566, end_position_on_the_genomic_accession=22571666, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    154197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154197, CurrentID=0, Status='live', Symbol='PNLDC1', Aliases=['HsPNLDC1', 'Trimmer'], description='PARN like ribonuclease domain containing exonuclease 1', other_designations='poly(A)-specific ribonuclease PNLDC1|PARN like, ribonuclease domain containing 1|PARN-like domain-containing protein 1|poly(A)-specific ribonuclease (PARN)-like domain containing 1|poly(A)-specific ribonuclease PARN-like domain-containing protein 1|poly(A)-specific ribonuclease domain-containing protein 1', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159799422, end_position_on_the_genomic_accession=159820704, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    154214 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154214, CurrentID=0, Status='live', Symbol='RNF217', Aliases=['C6orf172', 'IBRDC1', 'OSTL', 'dJ84N20.1'], description='ring finger protein 217', other_designations='probable E3 ubiquitin-protein ligase RNF217|IBR domain containing 1|opposite STL', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=124962406, end_position_on_the_genomic_accession=125092634, orientation='plus', exon_count=17, OMIM=[618592], no_hdr0=''),
    154215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154215, CurrentID=0, Status='live', Symbol='NKAIN2', Aliases=['FAM77B', 'NKAIP2', 'TCBA', 'TCBA1'], description='sodium/potassium transporting ATPase interacting 2', other_designations='sodium/potassium-transporting ATPase subunit beta-1-interacting protein 2|Na(+)/K(+)-transporting ATPase subunit beta-1-interacting protein 2|Na+/K+ transporting ATPase interacting 2|T-cell lymphoma breakpoint-associated target protein 1', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=123803842, end_position_on_the_genomic_accession=124825652, orientation='plus', exon_count=11, OMIM=[609758], no_hdr0=''),
    154288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154288, CurrentID=0, Status='live', Symbol='KHDC3L', Aliases=['C6orf221', 'ECAT1', 'HYDM2'], description='KH domain containing 3 like, subcortical maternal complex member', other_designations='KH domain-containing protein 3|ES cell-associated transcript 1 protein|KHDC3-like protein', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73362658, end_position_on_the_genomic_accession=73364171, orientation='plus', exon_count=3, OMIM=[611687], no_hdr0=''),
    154313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154313, CurrentID=0, Status='live', Symbol='CFAP206', Aliases=['C6orf165', 'dJ382I10.1'], description='cilia and flagella associated protein 206', other_designations='cilia- and flagella-associated protein 206|UPF0704 protein C6orf165', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87407972, end_position_on_the_genomic_accession=87464465, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    154467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154467, CurrentID=0, Status='live', Symbol='CCDC167', Aliases=['C6orf129', 'HSPC265'], description='coiled-coil domain containing 167', other_designations='coiled-coil domain-containing protein 167|transmembrane and coiled-coil domain-containing protein C6orf129', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37482938, end_position_on_the_genomic_accession=37499893, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    154661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154661, CurrentID=0, Status='live', Symbol='RUNDC3B', Aliases=['RPIB9', 'RPIP9'], description='RUN domain containing 3B', other_designations='RUN domain-containing protein 3B|Rap2 binding protein 9|Rap2-interacting protein 9|rap2-binding protein 9', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=87627656, end_position_on_the_genomic_accession=87832296, orientation='plus', exon_count=15, OMIM=[617295], no_hdr0=''),
    154664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154664, CurrentID=0, Status='live', Symbol='ABCA13', Aliases=[], description='ATP binding cassette subfamily A member 13', other_designations='ATP-binding cassette sub-family A member 13|ATP binding cassette transporter A13|ATP-binding cassette sub-family A member 13 variant 2|ATP-binding cassette sub-family A member 13 variant 3|ATP-binding cassette, sub-family A (ABC1), member 13', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=48171424, end_position_on_the_genomic_accession=48647497, orientation='plus', exon_count=75, OMIM=[607807], no_hdr0=''),
    154743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154743, CurrentID=0, Status='live', Symbol='BMT2', Aliases=['C7orf60', 'SAMTOR'], description='base methyltransferase of 25S rRNA 2 homolog', other_designations='S-adenosylmethionine sensor upstream of mTORC1|UPF0532 protein C7orf60|probable methyltransferase BMT2 homolog|probable methyltransferase BTM2 homolog', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=112819147, end_position_on_the_genomic_accession=112939875, orientation='minus', exon_count=5, OMIM=[617855], no_hdr0=''),
    154790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154790, CurrentID=0, Status='live', Symbol='CLEC2L', Aliases=[], description='C-type lectin domain family 2 member L', other_designations='C-type lectin domain family 2 member L', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139523685, end_position_on_the_genomic_accession=139544991, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    154791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154791, CurrentID=0, Status='live', Symbol='FMC1', Aliases=['C7orf55', 'HSPC268'], description='formation of mitochondrial complex V assembly factor 1 homolog', other_designations='protein FMC1 homolog|ATP synthase assembly factor FMC1, mitochondrial|UPF0562 protein C7orf55|formation of mitochondrial complexes 1 homolog', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139340472, end_position_on_the_genomic_accession=139346328, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    154796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154796, CurrentID=0, Status='live', Symbol='AMOT', Aliases=[], description='angiomotin', other_designations='angiomotin', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=112774877, end_position_on_the_genomic_accession=112840945, orientation='minus', exon_count=16, OMIM=[300410], no_hdr0=''),
    154807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154807, CurrentID=0, Status='live', Symbol='VKORC1L1', Aliases=[], description='vitamin K epoxide reductase complex subunit 1 like 1', other_designations='vitamin K epoxide reductase complex subunit 1-like protein 1|VKORC1-like protein 1', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=65865772, end_position_on_the_genomic_accession=65959558, orientation='plus', exon_count=5, OMIM=[608838], no_hdr0=''),
    154810 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154810, CurrentID=0, Status='live', Symbol='AMOTL1', Aliases=['JEAP'], description='angiomotin like 1', other_designations='angiomotin-like protein 1|junction-enriched and associated protein', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94706418, end_position_on_the_genomic_accession=94876748, orientation='plus', exon_count=19, OMIM=[614657], no_hdr0=''),
    154865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154865, CurrentID=0, Status='live', Symbol='IQUB', Aliases=[], description='IQ motif and ubiquitin domain containing', other_designations='IQ and ubiquitin-like domain-containing protein', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123452193, end_position_on_the_genomic_accession=123534645, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    154881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=154881, CurrentID=0, Status='live', Symbol='KCTD7', Aliases=['CLN14', 'EPM3'], description='potassium channel tetramerization domain containing 7', other_designations='BTB/POZ domain-containing protein KCTD7|potassium channel tetramerisation domain containing 7', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=66628881, end_position_on_the_genomic_accession=66643229, orientation='plus', exon_count=4, OMIM=[611725], no_hdr0=''),
    155006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155006, CurrentID=0, Status='live', Symbol='TMEM213', Aliases=[], description='transmembrane protein 213', other_designations='transmembrane protein 213', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=138797487, end_position_on_the_genomic_accession=138806759, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    155038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155038, CurrentID=0, Status='live', Symbol='GIMAP8', Aliases=['IAN-9', 'IAN6', 'IAN9', 'IANT'], description='GTPase, IMAP family member 8', other_designations='GTPase IMAP family member 8|human immune associated nucleotide 6|immune-associated nucleotide-binding protein 9', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150450630, end_position_on_the_genomic_accession=150479395, orientation='plus', exon_count=6, OMIM=[616962], no_hdr0=''),
    155051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155051, CurrentID=0, Status='live', Symbol='CRYGN', Aliases=[], description='crystallin gamma N', other_designations='gamma-crystallin N|gamma-N-crystallin|gammaN-crystallin', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151428832, end_position_on_the_genomic_accession=151448790, orientation='minus', exon_count=7, OMIM=[609603], no_hdr0=''),
    155054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155054, CurrentID=0, Status='live', Symbol='ZNF425', Aliases=[], description='zinc finger protein 425', other_designations='zinc finger protein 425', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149102784, end_position_on_the_genomic_accession=149126324, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    155061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155061, CurrentID=0, Status='live', Symbol='ZNF746', Aliases=['PARIS'], description='zinc finger protein 746', other_designations='zinc finger protein 746|parkin-interacting substrate|parkin-interacting sustrate', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149472696, end_position_on_the_genomic_accession=149497809, orientation='minus', exon_count=8, OMIM=[613914], no_hdr0=''),
    155066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155066, CurrentID=0, Status='live', Symbol='ATP6V0E2', Aliases=['ATP6V0E2L', 'C7orf32'], description='ATPase H+ transporting V0 subunit e2', other_designations='V-type proton ATPase subunit e 2|H+-ATPase e2 subunit|V-ATPase subunit e 2|V-ATPase subunit e1|lysosomal 9 kDa H(+)-transporting ATPase V0 subunit e2|vacuolar proton pump subunit e 2|vacuolar proton-ATPase subunit', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149872964, end_position_on_the_genomic_accession=149880713, orientation='plus', exon_count=6, OMIM=[611019], no_hdr0=''),
    155184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155184, CurrentID=0, Status='live', Symbol='SLC2A7', Aliases=['GLUT-7', 'GLUT7', 'hGLUT7'], description='solute carrier family 2 member 7', other_designations='solute carrier family 2, facilitated glucose transporter member 7|glucose transporter type 7|intestinal facilitative glucose transporter 7|solute carrier family 2 (facilitated glucose transporter), member 7', map_location='1p36.23', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=8992534, end_position_on_the_genomic_accession=9026423, orientation='minus', exon_count=14, OMIM=[610371], no_hdr0=''),
    155185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155185, CurrentID=0, Status='live', Symbol='AMZ1', Aliases=[], description='archaelysin family metallopeptidase 1', other_designations='archaemetzincin-1|archeobacterial metalloproteinase-like protein 1|metalloproteinase-like protein', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2679522, end_position_on_the_genomic_accession=2765187, orientation='plus', exon_count=12, OMIM=[615168], no_hdr0=''),
    155368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155368, CurrentID=0, Status='live', Symbol='METTL27', Aliases=['WBSCR27'], description='methyltransferase like 27', other_designations='methyltransferase-like protein 27|Williams Beuren syndrome chromosome region 27|williams-Beuren syndrome chromosomal region 27 protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73834590, end_position_on_the_genomic_accession=73842527, orientation='minus', exon_count=8, OMIM=[612546], no_hdr0=''),
    155382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155382, CurrentID=0, Status='live', Symbol='VPS37D', Aliases=['WBSCR24'], description='VPS37D subunit of ESCRT-I', other_designations='vacuolar protein sorting-associated protein 37D|ESCRT-I complex subunit VPS37D|VPS37D, ESCRT-I subunit|Williams Beuren syndrome chromosome region 24|Williams-Beuren syndrome critical region protein 24|vacuolar protein sorting 37 homolog D|vacuolar protein sorting 37D|williams-Beuren syndrome chromosomal region 24 protein|williams-Beuren syndrome region protein 24', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73665346, end_position_on_the_genomic_accession=73672110, orientation='plus', exon_count=5, OMIM=[610039], no_hdr0=''),
    155435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155435, CurrentID=0, Status='live', Symbol='RBM33', Aliases=['PRR8'], description='RNA binding motif protein 33', other_designations='RNA-binding protein 33|hypothetical protein MGC20460|proline rich 8|proline-rich protein 8', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155644494, end_position_on_the_genomic_accession=155781485, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    155465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=155465, CurrentID=0, Status='live', Symbol='AGR3', Aliases=['AG-3', 'AG3', 'BCMP11', 'HAG3', 'PDIA18', 'hAG-3'], description='anterior gradient 3, protein disulphide isomerase family member', other_designations='anterior gradient protein 3|anterior gradient homolog 3|anterior gradient protein 3 homolog|breast cancer membrane protein 11|protein disulfide isomerase family A, member 18', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16854711, end_position_on_the_genomic_accession=16881983, orientation='minus', exon_count=10, OMIM=[609482], no_hdr0=''),
    157285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157285, CurrentID=0, Status='live', Symbol='PRAG1', Aliases=['NACK', 'PEAK2', 'PRAGMIN', 'SGK223'], description='PEAK1 related, kinase-activating pseudokinase 1', other_designations='inactive tyrosine-protein kinase PRAG1|PEAK family member 2|Pragmin, RND2 effector protein|homolog of rat pragma of Rnd2|sugen kinase 223|tyrosine-protein kinase PRAG1|tyrosine-protein kinase SgK223', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=8317736, end_position_on_the_genomic_accession=8386439, orientation='minus', exon_count=8, OMIM=[617344], no_hdr0=''),
    157310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157310, CurrentID=0, Status='live', Symbol='PEBP4', Aliases=['CORK-1', 'CORK1', 'GWTM1933', 'HEL-S-300', 'PEBP-4', 'PRO4408', 'hPEBP4'], description='phosphatidylethanolamine binding protein 4', other_designations='phosphatidylethanolamine-binding protein 4|cousin-of-RKIP 1 protein|epididymis secretory protein Li 300|epididymis secretory sperm binding protein|protein cousin-of-RKIP 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22713251, end_position_on_the_genomic_accession=22941077, orientation='minus', exon_count=9, OMIM=[612473], no_hdr0=''),
    157313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157313, CurrentID=0, Status='live', Symbol='CDCA2', Aliases=['PPP1R81', 'Repo-Man'], description='cell division cycle associated 2', other_designations='cell division cycle-associated protein 2|protein phosphatase 1, regulatory subunit 81|recruits PP1 onto mitotic chromatin at anaphase protein', map_location='8p21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=25458557, end_position_on_the_genomic_accession=25511308, orientation='plus', exon_count=18, OMIM=[618785], no_hdr0=''),
    157378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157378, CurrentID=0, Status='live', Symbol='TMEM65', Aliases=[], description='transmembrane protein 65', other_designations='transmembrane protein 65', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=124306189, end_position_on_the_genomic_accession=124372701, orientation='minus', exon_count=7, OMIM=[616609], no_hdr0=''),
    157506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157506, CurrentID=0, Status='live', Symbol='RDH10', Aliases=['SDR16C4'], description='retinol dehydrogenase 10', other_designations='retinol dehydrogenase 10|retinol dehydrogenase 10 (all-trans)|short chain dehydrogenase/reductase family 16C member 4', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73294602, end_position_on_the_genomic_accession=73325281, orientation='plus', exon_count=6, OMIM=[607599], no_hdr0=''),
    157567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157567, CurrentID=0, Status='live', Symbol='ANKRD46', Aliases=['ANK-S', 'GENX-115279'], description='ankyrin repeat domain 46', other_designations='ankyrin repeat domain-containing protein 46|ankyrin repeat small protein', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100509752, end_position_on_the_genomic_accession=100559759, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    157570 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157570, CurrentID=0, Status='live', Symbol='ESCO2', Aliases=['2410004I17Rik', 'EFO2', 'EFO2p', 'JHS', 'RBS', 'hEFO2'], description='establishment of sister chromatid cohesion N-acetyltransferase 2', other_designations='N-acetyltransferase ESCO2|ECO1 homolog 2|establishment factor-like protein 2', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27771949, end_position_on_the_genomic_accession=27812430, orientation='plus', exon_count=14, OMIM=[609353], no_hdr0=''),
    157574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157574, CurrentID=0, Status='live', Symbol='FBXO16', Aliases=['FBX16'], description='F-box protein 16', other_designations='F-box only protein 16', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28428412, end_position_on_the_genomic_accession=28490229, orientation='minus', exon_count=9, OMIM=[608519], no_hdr0=''),
    157638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157638, CurrentID=0, Status='live', Symbol='LRATD2', Aliases=['BCMP101', 'FAM84B', 'NSE2'], description='LRAT domain containing 2', other_designations='protein LRATD2|breast cancer membrane protein 101|breast cancer membrane-associated protein 101|family with sequence similarity 84 member B|neurological/sensory 2|protein FAM84B', map_location='8q24.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=126552443, end_position_on_the_genomic_accession=126558498, orientation='minus', exon_count=3, OMIM=[609483], no_hdr0=''),
    157657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157657, CurrentID=0, Status='live', Symbol='CFAP418', Aliases=['BBS21', 'C8orf37', 'CORD16', 'FAP418', 'MOT25', 'RP64', 'smalltalk'], description='cilia and flagella associated protein 418', other_designations='protein C8orf37|Bardet-Biedl syndrome 21', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=95244913, end_position_on_the_genomic_accession=95269201, orientation='minus', exon_count=6, OMIM=[614477], no_hdr0=''),
    157680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157680, CurrentID=0, Status='live', Symbol='VPS13B', Aliases=['CHS1', 'COH1'], description='vacuolar protein sorting 13 homolog B', other_designations='vacuolar protein sorting-associated protein 13B', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=99013274, end_position_on_the_genomic_accession=99877580, orientation='plus', exon_count=65, OMIM=[607817], no_hdr0=''),
    157695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157695, CurrentID=0, Status='live', Symbol='TDRP', Aliases=['C8orf42', 'Inm011', 'TDRP2', 'TDRP'], description='testis development related protein', other_designations='testis development-related protein', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=489946, end_position_on_the_genomic_accession=545780, orientation='minus', exon_count=4, OMIM=[619049], no_hdr0=''),
    157697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157697, CurrentID=0, Status='live', Symbol='ERICH1', Aliases=['HSPC319'], description='glutamate rich 1', other_designations='glutamate-rich protein 1', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=614742, end_position_on_the_genomic_accession=731224, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    157724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157724, CurrentID=0, Status='live', Symbol='SLC7A13', Aliases=['AGT-1', 'AGT1', 'XAT2'], description='solute carrier family 7 member 13', other_designations='solute carrier family 7 member 13|X-amino acid transporter 2|amino acid transporter XAT2|sodium-independent aspartate/glutamate transporter 1|solute carrier family 7 (anionic amino acid transporter), member 13|solute carrier family 7, (cationic amino acid transporter, y+ system) member 13', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86213909, end_position_on_the_genomic_accession=86230381, orientation='minus', exon_count=4, OMIM=[617256], no_hdr0=''),
    157753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157753, CurrentID=0, Status='live', Symbol='TMEM74', Aliases=['NET36'], description='transmembrane protein 74', other_designations='transmembrane protein 74', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=108606850, end_position_on_the_genomic_accession=108787594, orientation='minus', exon_count=5, OMIM=[613935], no_hdr0=''),
    157769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157769, CurrentID=0, Status='live', Symbol='FAM91A1', Aliases=[], description='family with sequence similarity 91 member A1', other_designations='protein FAM91A1|skeletal muscle cells re-entry induced', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123768439, end_position_on_the_genomic_accession=123815452, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    157773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157773, CurrentID=0, Status='live', Symbol='C8orf48', Aliases=[], description='chromosome 8 open reading frame 48', other_designations='uncharacterized protein C8orf48', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=13566869, end_position_on_the_genomic_accession=13568288, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    157777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157777, CurrentID=0, Status='live', Symbol='MCMDC2', Aliases=['C8orf45'], description='minichromosome maintenance domain containing 2', other_designations='minichromosome maintenance domain-containing protein 2|MCM domain-containing protein 2|MCM domain-containing protein C8orf45', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66870757, end_position_on_the_genomic_accession=66926436, orientation='plus', exon_count=19, OMIM=[617545], no_hdr0=''),
    157807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157807, CurrentID=0, Status='live', Symbol='CLVS1', Aliases=['C6orf212L', 'CRALBPL', 'RLBP1L1'], description='clavesin 1', other_designations='clavesin-1|clathrin vesicle-associated Sec14 protein 1|retinaldehyde-binding protein 1-like 1', map_location='8q12.2-q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=60964833, end_position_on_the_genomic_accession=61501629, orientation='plus', exon_count=11, OMIM=[611292], no_hdr0=''),
    157848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157848, CurrentID=0, Status='live', Symbol='NKX6-3', Aliases=['NKX6.3'], description='NK6 homeobox 3', other_designations='homeobox protein Nkx-6.3|NK6 transcription factor related, locus 3', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=41645177, end_position_on_the_genomic_accession=41650817, orientation='minus', exon_count=4, OMIM=[610772], no_hdr0=''),
    157855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157855, CurrentID=0, Status='live', Symbol='KCNU1', Aliases=['KCNMC1', 'KCa5', 'KCa5.1', 'Kcnma3', 'Slo3'], description='potassium calcium-activated channel subfamily U member 1', other_designations='potassium channel subfamily U member 1|Calcium-activated potassium channel subunit alpha-3|Calcium-activated potassium channel, subfamily M subunit alpha-3|Slowpoke homolog 3|potassium channel, subfamily U, member 1', map_location='8p11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=36784374, end_position_on_the_genomic_accession=36936125, orientation='plus', exon_count=30, OMIM=[615215], no_hdr0=''),
    157869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157869, CurrentID=0, Status='live', Symbol='SBSPON', Aliases=['C8orf84', 'RPESP'], description='somatomedin B and thrombospondin type 1 domain containing', other_designations='somatomedin-B and thrombospondin type-1 domain-containing protein|RPE-spondin', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73063077, end_position_on_the_genomic_accession=73093178, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    157922 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=157922, CurrentID=0, Status='live', Symbol='CAMSAP1', Aliases=[], description='calmodulin regulated spectrin associated protein 1', other_designations='calmodulin-regulated spectrin-associated protein 1|epididymis secretory sperm binding protein', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135808487, end_position_on_the_genomic_accession=135907551, orientation='minus', exon_count=19, OMIM=[613774], no_hdr0=''),
    158038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158038, CurrentID=0, Status='live', Symbol='LINGO2', Aliases=['LERN3', 'LRRN6C'], description='leucine rich repeat and Ig domain containing 2', other_designations='leucine-rich repeat and immunoglobulin-like domain-containing nogo receptor-interacting protein 2|leucine rich repeat neuronal 6C|leucine-rich repeat neuronal protein 3|leucine-rich repeat neuronal protein 6C', map_location='9p21.2-p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27937617, end_position_on_the_genomic_accession=29215243, orientation='minus', exon_count=16, OMIM=[609793], no_hdr0=''),
    158046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158046, CurrentID=0, Status='live', Symbol='NXNL2', Aliases=['C9orf121', 'RDCVF2', 'RdCVF2L'], description='nucleoredoxin like 2', other_designations='nucleoredoxin-like protein 2|rod-derived cone viability factor 2', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=88535088, end_position_on_the_genomic_accession=88584510, orientation='plus', exon_count=7, OMIM=[615299], no_hdr0=''),
    158055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158055, CurrentID=0, Status='live', Symbol='C9orf163', Aliases=[], description='chromosome 9 putative open reading frame 163', other_designations='uncharacterized protein C9orf163', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136483010, end_position_on_the_genomic_accession=136486067, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    158056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158056, CurrentID=0, Status='live', Symbol='MAMDC4', Aliases=['AEGP', 'EDTB'], description='MAM domain containing 4', other_designations='apical endosomal glycoprotein|MAM domain-containing protein 4|apical early endosomal glycoprotein|endotubin', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136852346, end_position_on_the_genomic_accession=136860799, orientation='plus', exon_count=27, OMIM=[617208], no_hdr0=''),
    158062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158062, CurrentID=0, Status='live', Symbol='LCN6', Aliases=['LCN5', 'UNQ643', 'hLcn5'], description='lipocalin 6', other_designations='epididymal-specific lipocalin-6|epididymal-specific lipocalin LCN6|epididymis secretory sperm binding protein|lipocalin 5', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136744017, end_position_on_the_genomic_accession=136748525, orientation='minus', exon_count=7, OMIM=[609379], no_hdr0=''),
    158067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158067, CurrentID=0, Status='live', Symbol='AK8', Aliases=['AK 8', 'C9orf98', 'DDX31'], description='adenylate kinase 8', other_designations='adenylate kinase 8|ATP-AMP transphosphorylase 8|putative adenylate kinase-like protein C9orf98', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132725574, end_position_on_the_genomic_accession=132879046, orientation='minus', exon_count=18, OMIM=[615365], no_hdr0=''),
    158131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158131, CurrentID=0, Status='live', Symbol='OR1Q1', Aliases=['HSTPCR106', 'OR1Q2', 'OR1Q3', 'OR9-25', 'OR9-A', 'OST226', 'OST226OR9-A', 'TPCR106'], description='olfactory receptor family 1 subfamily Q member 1', other_designations='olfactory receptor 1Q1|olfactory receptor 1Q2|olfactory receptor 1Q3|olfactory receptor 9-A|olfactory receptor OR9-25|olfactory receptor TPCR106|olfactory receptor, family 1, subfamily Q, member 2|olfactory receptor, family 1, subfamily Q, member 3', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122614738, end_position_on_the_genomic_accession=122615682, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    158135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158135, CurrentID=0, Status='live', Symbol='TTLL11', Aliases=['C9orf148', 'C9orf20-IT1', 'bA244O19.1', 'TTLL11'], description='tubulin tyrosine ligase like 11', other_designations='tubulin polyglutamylase TTLL11|TTLL11 intronic transcript 1|TTLL11 intronic transcript 1 (non-protein coding)|tubulin tyrosine ligase like11|tubulin tyrosine ligase-like family, member 11|tubulin--tyrosine ligase-like protein 11', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121815674, end_position_on_the_genomic_accession=122093418, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    158158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158158, CurrentID=0, Status='live', Symbol='RASEF', Aliases=['RAB45'], description='RAS and EF-hand domain containing', other_designations='ras and EF-hand domain-containing protein|ras-related protein Rab-45', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=82979589, end_position_on_the_genomic_accession=83063172, orientation='minus', exon_count=18, OMIM=[611344], no_hdr0=''),
    158219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158219, CurrentID=0, Status='live', Symbol='TTC39B', Aliases=['C9orf52'], description='tetratricopeptide repeat domain 39B', other_designations='tetratricopeptide repeat protein 39B|TPR repeat protein 39B', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=15163622, end_position_on_the_genomic_accession=15307360, orientation='minus', exon_count=27, OMIM=[613574], no_hdr0=''),
    158234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158234, CurrentID=0, Status='live', Symbol='TRMT10B', Aliases=['RG9MTD3', 'bA3J10.9'], description='tRNA methyltransferase 10B', other_designations='tRNA methyltransferase 10 homolog B|RNA (guanine-9-) methyltransferase domain containing 3|RNA (guanine-9-)-methyltransferase domain-containing protein 3|tRNA (guanine(9)-N(1))-methyltransferase TRMT10B', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37753204, end_position_on_the_genomic_accession=37780459, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    158248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158248, CurrentID=0, Status='live', Symbol='TTC16', Aliases=[], description='tetratricopeptide repeat domain 16', other_designations='tetratricopeptide repeat protein 16|TPR repeat protein 16', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127716064, end_position_on_the_genomic_accession=127731590, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    158293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158293, CurrentID=0, Status='live', Symbol='FAM120AOS', Aliases=['C9orf10OS'], description='family with sequence similarity 120A opposite strand', other_designations='uncharacterized protein FAM120AOS|FAM120A opposite strand protein', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93443332, end_position_on_the_genomic_accession=93453601, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    158297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158297, CurrentID=0, Status='live', Symbol='SAXO1', Aliases=['C9orf138', 'FAM154A'], description='stabilizer of axonemal microtubules 1', other_designations='stabilizer of axonemal microtubules 1|4930500O09Rik|family with sequence similarity 154, member A|protein FAM154A', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=18927650, end_position_on_the_genomic_accession=19049506, orientation='minus', exon_count=9, OMIM=[616292], no_hdr0=''),
    158326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158326, CurrentID=0, Status='live', Symbol='FREM1', Aliases=['BNAR', 'C9orf143', 'C9orf145', 'C9orf154', 'MOTA', 'TILRR', 'TRIGNO2'], description='FRAS1 related extracellular matrix 1', other_designations='FRAS1-related extracellular matrix protein 1|extracellular matrix protein QBRICK', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=14734666, end_position_on_the_genomic_accession=14911653, orientation='minus', exon_count=48, OMIM=[608944], no_hdr0=''),
    158358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158358, CurrentID=0, Status='live', Symbol='KIAA2026', Aliases=[], description='KIAA2026', other_designations='uncharacterized protein KIAA2026', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5860254, end_position_on_the_genomic_accession=6008489, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    158376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158376, CurrentID=0, Status='live', Symbol='SPAAR', Aliases=['LINC00961', 'SPAR'], description='small regulatory polypeptide of amino acid response', other_designations='small regulatory polypeptide of amino acid response|long intergenic non-protein coding RNA 961|small regulatory polypeptide of amino acids response', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35909490, end_position_on_the_genomic_accession=35911686, orientation='plus', exon_count=2, OMIM=[617627], no_hdr0=''),
    158399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158399, CurrentID=0, Status='live', Symbol='ZNF483', Aliases=['ZKSCAN16', 'ZSCAN48'], description='zinc finger protein 483', other_designations='zinc finger protein 483|zinc finger protein HIT-10|zinc finger protein with KRAB and SCAN domains 16', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111525159, end_position_on_the_genomic_accession=111578136, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    158401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158401, CurrentID=0, Status='live', Symbol='SHOC1', Aliases=['C9orf84', 'MZIP2', 'ZIP2', 'ZIP2H'], description='shortage in chiasmata 1', other_designations='protein shortage in chiasmata 1 ortholog|protein ZIP2 homolog|uncharacterized protein C9orf84', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111686171, end_position_on_the_genomic_accession=111795949, orientation='minus', exon_count=32, OMIM=[618038], no_hdr0=''),
    158405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158405, CurrentID=0, Status='live', Symbol='KIAA1958', Aliases=[], description='KIAA1958', other_designations='uncharacterized protein KIAA1958', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112486827, end_position_on_the_genomic_accession=112669397, orientation='plus', exon_count=6, OMIM=[617390], no_hdr0=''),
    158427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158427, CurrentID=0, Status='live', Symbol='TSTD2', Aliases=['C9orf97'], description='thiosulfate sulfurtransferase like domain containing 2', other_designations='thiosulfate sulfurtransferase/rhodanese-like domain-containing protein 2|PP4189|rhodanese domain-containing protein 2|rhodanese like domain containing 2|thiosulfate sulfurtransferase (rhodanese)-like domain containing 2', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97600080, end_position_on_the_genomic_accession=97633368, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    158431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158431, CurrentID=0, Status='live', Symbol='ZNF782', Aliases=[], description='zinc finger protein 782', other_designations='zinc finger protein 782', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96815628, end_position_on_the_genomic_accession=96876698, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    158471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158471, CurrentID=0, Status='live', Symbol='PRUNE2', Aliases=['BMCC1', 'BNIPXL', 'C9orf65', 'KIAA0367'], description='prune homolog 2 with BCH domain', other_designations='protein prune homolog 2|BCH motif-containing molecule at the carboxyl terminal region 1|BNIP2 motif containing molecule at the carboxyl terminal region 1|BNIP2 motif-containing molecule at the C-terminal region 1|olfaxin|truncated PRUNE2', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=76611376, end_position_on_the_genomic_accession=76906220, orientation='minus', exon_count=25, OMIM=[610691], no_hdr0=''),
    158506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158506, CurrentID=0, Status='live', Symbol='CBLL2', Aliases=['CT138', 'HAKAIL', 'ZNF645'], description='Cbl proto-oncogene like 2', other_designations='E3 ubiquitin-protein ligase CBLL2|E3 ubiquitin ligase|E3 ubiquitin-protein ligase ZNF645|RING-type E3 ubiquitin transferase ZNF645|c-Cbl-like protein 2|cbl proto-oncogene-like protein 2|zinc finger protein 645', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=22272913, end_position_on_the_genomic_accession=22274461, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    158511 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158511, CurrentID=0, Status='live', Symbol='CSAG1', Aliases=['CSAGE', 'CT24.1'], description='chondrosarcoma associated gene 1', other_designations='putative chondrosarcoma-associated gene 1 protein|cancer/testis antigen 24.1|cancer/testis antigen CSAGE|cancer/testis antigen family 24, member 1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152727484, end_position_on_the_genomic_accession=152733721, orientation='minus', exon_count=5, OMIM=[300944], no_hdr0=''),
    158521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158521, CurrentID=0, Status='live', Symbol='FMR1NB', Aliases=['CT37', 'NY-SAR-35', 'NYSAR35'], description='FMR1 neighbor', other_designations='fragile X mental retardation 1 neighbor protein|cancer/testis antigen 37|sarcoma antigen NY-SAR-35', map_location='Xq27.3-q28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=147981337, end_position_on_the_genomic_accession=148026665, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    158584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158584, CurrentID=0, Status='live', Symbol='FAAH2', Aliases=['AMDD'], description='fatty acid amide hydrolase 2', other_designations='fatty-acid amide hydrolase 2|amidase domain containing|amidase domain-containing protein|anandamide amidohydrolase 2|oleamide hydrolase 2', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57121861, end_position_on_the_genomic_accession=57489196, orientation='plus', exon_count=19, OMIM=[300654], no_hdr0=''),
    158586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158586, CurrentID=0, Status='live', Symbol='ZXDB', Aliases=['ZNF905', 'dJ83L6.1'], description='zinc finger X-linked duplicated B', other_designations='zinc finger X-linked protein ZXDB', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57592011, end_position_on_the_genomic_accession=57597477, orientation='plus', exon_count=1, OMIM=[300236], no_hdr0=''),
    158724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158724, CurrentID=0, Status='live', Symbol='FAM47A', Aliases=[], description='family with sequence similarity 47 member A', other_designations='protein FAM47A', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=34129752, end_position_on_the_genomic_accession=34132314, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    158747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158747, CurrentID=0, Status='live', Symbol='MOSPD2', Aliases=[], description='motile sperm domain containing 2', other_designations='motile sperm domain-containing protein 2', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=14873421, end_position_on_the_genomic_accession=14922327, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    158763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158763, CurrentID=0, Status='live', Symbol='ARHGAP36', Aliases=[], description='Rho GTPase activating protein 36', other_designations='rho GTPase-activating protein 36', map_location='Xq26.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=131058346, end_position_on_the_genomic_accession=131089885, orientation='plus', exon_count=13, OMIM=[300937], no_hdr0=''),
    158787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158787, CurrentID=0, Status='live', Symbol='RIBC1', Aliases=['2610028I09Rik'], description='RIB43A domain with coiled-coils 1', other_designations='RIB43A-like with coiled-coils protein 1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=53422873, end_position_on_the_genomic_accession=53431115, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    158798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158798, CurrentID=0, Status='live', Symbol='AKAP14', Aliases=['AKAP28', 'PRKA14'], description='A-kinase anchoring protein 14', other_designations='A-kinase anchor protein 14|A kinase (PRKA) anchor protein 14|A-kinase anchor protein 28 kDa|A-kinase anchoring protein 28|AKAP 28|AKAP-14|protein kinase A-anchoring protein 14', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119895893, end_position_on_the_genomic_accession=119920716, orientation='plus', exon_count=7, OMIM=[300462], no_hdr0=''),
    158800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158800, CurrentID=0, Status='live', Symbol='RHOXF1', Aliases=['OTEX', 'PEPP1'], description='Rhox homeobox family member 1', other_designations='rhox homeobox family member 1|PEPP subfamily gene 1|ovary-, testis- and epididymis-expressed gene protein|paired-like homeobox protein PEPP-1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120109049, end_position_on_the_genomic_accession=120117651, orientation='minus', exon_count=4, OMIM=[300446], no_hdr0=''),
    158809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158809, CurrentID=0, Status='live', Symbol='MAGEB6', Aliases=['CT3.4', 'MAGE-B6A', 'MAGEB6'], description='MAGE family member B6', other_designations='melanoma-associated antigen B6|MAGE-B6 antigen|cancer/testis antigen 3.4|cancer/testis antigen family 3, member 4|melanoma antigen family B, 6|melanoma antigen family B6', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=26192440, end_position_on_the_genomic_accession=26195646, orientation='plus', exon_count=2, OMIM=[300467], no_hdr0=''),
    158830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158830, CurrentID=0, Status='live', Symbol='CXorf65', Aliases=[], description='chromosome X open reading frame 65', other_designations='uncharacterized protein CXorf65', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71103249, end_position_on_the_genomic_accession=71106973, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    158833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158833, CurrentID=0, Status='live', Symbol='AWAT1', Aliases=['DGA2', 'DGAT2L3'], description='acyl-CoA wax alcohol acyltransferase 1', other_designations='acyl-CoA wax alcohol acyltransferase 1|diacyl-glycerol acyltransferase 2|diacylglycerol O-acyltransferase 2-like 3|diacylglycerol O-acyltransferase 2-like protein 3|diacylglycerol acyltransferase 2|long-chain-alcohol O-fatty-acyltransferase 1', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70233489, end_position_on_the_genomic_accession=70240661, orientation='plus', exon_count=6, OMIM=[300924], no_hdr0=''),
    158835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158835, CurrentID=0, Status='live', Symbol='AWAT2', Aliases=['ARAT', 'DC4', 'DGAT2L4', 'MFAT', 'WS'], description='acyl-CoA wax alcohol acyltransferase 2', other_designations='acyl-CoA wax alcohol acyltransferase 2|11-cis-RE-synthase|11-cis-specific retinyl-ester synthase|acyl-CoA retinol O-fatty-acyltransferase|diacylglycerol O-acyltransferase 2-like protein 4|diacylglycerol O-acyltransferase candidate 4|long-chain-alcohol O-fatty-acyltransferase 2|multifunctional O-acyltransferase|retinol O-fatty-acyltransferase', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70040542, end_position_on_the_genomic_accession=70049970, orientation='minus', exon_count=8, OMIM=[300925], no_hdr0=''),
    158866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158866, CurrentID=0, Status='live', Symbol='ZDHHC15', Aliases=['DHHC15', 'MRX91'], description='zinc finger DHHC-type palmitoyltransferase 15', other_designations='palmitoyltransferase ZDHHC15|DHHC-15|acyltransferase ZDHHC15|zinc finger DHHC domain-containing protein 15|zinc finger DHHC-type containing 15|zinc finger, DHHC domain containing 15', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=75368427, end_position_on_the_genomic_accession=75523259, orientation='minus', exon_count=15, OMIM=[300576], no_hdr0=''),
    158880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158880, CurrentID=0, Status='live', Symbol='USP51', Aliases=[], description='ubiquitin specific peptidase 51', other_designations='ubiquitin carboxyl-terminal hydrolase 51|deubiquitinating enzyme 51|ubiquitin thioesterase 51|ubiquitin thiolesterase 51|ubiquitin-specific-processing protease 51', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55484524, end_position_on_the_genomic_accession=55489875, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    158931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158931, CurrentID=0, Status='live', Symbol='TCEAL6', Aliases=['Tceal3', 'WEX2'], description='transcription elongation factor A like 6', other_designations='transcription elongation factor A protein-like 6|TCEA-like protein 6|transcription elongation factor A (SII)-like 3|transcription elongation factor A (SII)-like 6|transcription elongation factor S-II protein-like 6', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102138502, end_position_on_the_genomic_accession=102142481, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    158983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=158983, CurrentID=0, Status='live', Symbol='H2BW1', Aliases=['H2BFWT', 'TH2B-175'], description='H2B.W histone 1', other_designations='histone H2B type W-T|H2B histone family member W, testis specific', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104011147, end_position_on_the_genomic_accession=104013708, orientation='minus', exon_count=3, OMIM=[300507], no_hdr0=''),
    159013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159013, CurrentID=0, Status='live', Symbol='CXorf38', Aliases=[], description='chromosome X open reading frame 38', other_designations='uncharacterized protein CXorf38', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=40626921, end_position_on_the_genomic_accession=40647678, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    159090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159090, CurrentID=0, Status='live', Symbol='PABIR2', Aliases=['FAM122B', 'SPACIA2'], description='PABIR family member 2', other_designations='PABIR family member 2|family with sequence similarity 122B|protein FAM122B|synoviocyte proliferation associated in collagen-induced arthritis 2', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134769566, end_position_on_the_genomic_accession=134797217, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    159091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159091, CurrentID=0, Status='live', Symbol='PABIR3', Aliases=['FAM122C'], description='PABIR family member 3', other_designations='PABIR family member 1|family with sequence similarity 122C|protein FAM122C', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134796364, end_position_on_the_genomic_accession=134864771, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    159119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159119, CurrentID=0, Status='live', Symbol='HSFY2', Aliases=['HSF2L', 'HSFY'], description='heat shock transcription factor Y-linked 2', other_designations='heat shock transcription factor, Y-linked|heat shock transcription factor 2-like protein', map_location='Yq11.222', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=18731440, end_position_on_the_genomic_accession=18790735, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    159163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159163, CurrentID=0, Status='live', Symbol='RBMY1F', Aliases=['YRRM2'], description='RNA binding motif protein Y-linked family 1 member F', other_designations='RNA-binding motif protein, Y chromosome, family 1 member F/J|y chromosome RNA recognition motif 2', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=22162885, end_position_on_the_genomic_accession=22183008, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    159195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159195, CurrentID=0, Status='live', Symbol='USP54', Aliases=['C10orf29', 'bA137L10.3', 'bA137L10.4'], description='ubiquitin specific peptidase 54', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 54|inactive ubiquitin-specific peptidase 54|ubiquitin specific protease 54|ubiquitin specific proteinase 54', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73497538, end_position_on_the_genomic_accession=73626906, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    159296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159296, CurrentID=0, Status='live', Symbol='NKX2-3', Aliases=['CSX3', 'NK2.3', 'NKX2.3', 'NKX2C', 'NKX4-3'], description='NK2 homeobox 3', other_designations='homeobox protein Nkx-2.3|NK2 transcription factor related, locus 3|homeobox protein NK-2 homolog C', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=99532942, end_position_on_the_genomic_accession=99536524, orientation='plus', exon_count=3, OMIM=[606727], no_hdr0=''),
    159371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159371, CurrentID=0, Status='live', Symbol='SLC35G1', Aliases=['C10orf60', 'POST', 'TMEM20'], description='solute carrier family 35 member G1', other_designations='solute carrier family 35 member G1|partner of STIM1|transmembrane protein 20', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93893951, end_position_on_the_genomic_accession=93914271, orientation='plus', exon_count=6, OMIM=[617167], no_hdr0=''),
    159686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159686, CurrentID=0, Status='live', Symbol='CFAP58', Aliases=['C10orf80', 'CCDC147', 'SPGF49', 'bA127L20.4', 'bA127L20.5', 'bA554P13.1'], description='cilia and flagella associated protein 58', other_designations='cilia- and flagella-associated protein 58|coiled-coil domain containing 147|coiled-coil domain-containing protein 147', map_location='10q25.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=104353833, end_position_on_the_genomic_accession=104455102, orientation='plus', exon_count=18, OMIM=[619129], no_hdr0=''),
    159963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159963, CurrentID=0, Status='live', Symbol='SLC5A12', Aliases=['SMCT2'], description='solute carrier family 5 member 12', other_designations='sodium-coupled monocarboxylate transporter 2|electroneutral sodium monocarboxylate cotransporter|low-affinity sodium-lactate cotransporter|sodium-iodide related cotransporter|solute carrier family 5 (sodium/glucose cotransporter), member 12|solute carrier family 5 (sodium/monocarboxylate cotransporter), member 12', map_location='11p14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=26667020, end_position_on_the_genomic_accession=26723356, orientation='minus', exon_count=18, OMIM=[612455], no_hdr0=''),
    159989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=159989, CurrentID=0, Status='live', Symbol='DEUP1', Aliases=['CCDC67'], description='deuterosome assembly protein 1', other_designations='deuterosome assembly protein 1|coiled-coil domain containing 67|coiled-coil domain-containing protein 67|deuterosome protein 1', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93329079, end_position_on_the_genomic_accession=93438470, orientation='plus', exon_count=21, OMIM=[617148], no_hdr0=''),
    160065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160065, CurrentID=0, Status='live', Symbol='PATE1', Aliases=['PATE'], description='prostate and testis expressed 1', other_designations='prostate and testis expressed protein 1|expressed in prostate and testis', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125746279, end_position_on_the_genomic_accession=125749867, orientation='plus', exon_count=5, OMIM=[606861], no_hdr0=''),
    160140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160140, CurrentID=0, Status='live', Symbol='C11orf65', Aliases=['MFI'], description='chromosome 11 open reading frame 65', other_designations='protein MFI|mitochondrial fission factor interactor|uncharacterized protein C11orf65', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=108308519, end_position_on_the_genomic_accession=108469832, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    160287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160287, CurrentID=0, Status='live', Symbol='LDHAL6A', Aliases=['LDH6A'], description='lactate dehydrogenase A like 6A', other_designations='L-lactate dehydrogenase A-like 6A|LDHA-like protein 6A', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18455856, end_position_on_the_genomic_accession=18479601, orientation='plus', exon_count=8, OMIM=[618928], no_hdr0=''),
    160298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160298, CurrentID=0, Status='live', Symbol='C11orf42', Aliases=[], description='chromosome 11 open reading frame 42', other_designations='uncharacterized protein C11orf42', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6201905, end_position_on_the_genomic_accession=6226783, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    160335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160335, CurrentID=0, Status='live', Symbol='TMTC2', Aliases=['IBDBP1'], description='transmembrane O-mannosyltransferase targeting cadherins 2', other_designations='protein O-mannosyl-transferase TMTC2|transmembrane and TPR repeat-containing protein 2|transmembrane and tetratricopeptide repeat containing 2', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=82686906, end_position_on_the_genomic_accession=83134868, orientation='plus', exon_count=13, OMIM=[615856], no_hdr0=''),
    160364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160364, CurrentID=0, Status='live', Symbol='CLEC12A', Aliases=['CD371', 'CLL-1', 'CLL1', 'DCAL-2', 'MICL'], description='C-type lectin domain family 12 member A', other_designations='C-type lectin domain family 12 member A|C-type lectin protein CLL-1|C-type lectin-like molecule-1|dendritic cell-associated lectin 2|myeloid inhibitory C-type lectin-like receptor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9951268, end_position_on_the_genomic_accession=9995209, orientation='plus', exon_count=12, OMIM=[612088], no_hdr0=''),
    160418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160418, CurrentID=0, Status='live', Symbol='TMTC3', Aliases=['LIS8', 'SMILE'], description='transmembrane O-mannosyltransferase targeting cadherins 3', other_designations='protein O-mannosyl-transferase TMTC3|transmembrane and TPR repeat-containing protein 3|transmembrane and tetratricopeptide repeat containing 3', map_location='12q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=88142307, end_position_on_the_genomic_accession=88199887, orientation='plus', exon_count=15, OMIM=[617218], no_hdr0=''),
    160419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160419, CurrentID=0, Status='live', Symbol='C12orf50', Aliases=[], description='chromosome 12 open reading frame 50', other_designations='uncharacterized protein C12orf50', map_location='12q21.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=87980035, end_position_on_the_genomic_accession=88030212, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    160428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160428, CurrentID=0, Status='live', Symbol='ALDH1L2', Aliases=['mtFDH'], description='aldehyde dehydrogenase 1 family member L2', other_designations='mitochondrial 10-formyltetrahydrofolate dehydrogenase|10-formyltetrahydrofolate dehydrogenase ALDH1L2|aldehyde dehydrogenase family 1 member L2, mitochondrial|mitochondrial 10-FTHFDH|probable 10-formyltetrahydrofolate dehydrogenase ALDH1L2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=105019784, end_position_on_the_genomic_accession=105084609, orientation='minus', exon_count=27, OMIM=[613584], no_hdr0=''),
    160492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160492, CurrentID=0, Status='live', Symbol='LMNTD1', Aliases=['IFLTD1', 'LMNARS1', 'PAS1C1'], description='lamin tail domain containing 1', other_designations='lamin tail domain-containing protein 1|intermediate filament tail domain containing 1|intermediate filament tail domain-containing protein 1', map_location='12p12.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=25476082, end_position_on_the_genomic_accession=25648604, orientation='minus', exon_count=24, OMIM=[617254], no_hdr0=''),
    160518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160518, CurrentID=0, Status='live', Symbol='DENND5B', Aliases=[], description='DENN domain containing 5B', other_designations='DENN domain-containing protein 5B|DENN/MADD domain containing 5B|rab6IP1-like protein', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31382226, end_position_on_the_genomic_accession=31591136, orientation='minus', exon_count=26, OMIM=[617279], no_hdr0=''),
    160622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160622, CurrentID=0, Status='live', Symbol='TAMALIN', Aliases=['GRASP'], description='trafficking regulator and scaffold protein tamalin', other_designations='protein TAMALIN|GRP1 (general receptor for phosphoinositides 1)-associated scaffold protein|general receptor for phosphoinositides 1 associated scaffold protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52006946, end_position_on_the_genomic_accession=52015889, orientation='plus', exon_count=10, OMIM=[612027], no_hdr0=''),
    160728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160728, CurrentID=0, Status='live', Symbol='SLC5A8', Aliases=['AIT', 'SMCT', 'SMCT1'], description='solute carrier family 5 member 8', other_designations='sodium-coupled monocarboxylate transporter 1|apical iodide transporter|electrogenic sodium monocarboxylate cotransporter|sodium iodide-related cotransporter|solute carrier family 5 (iodide transporter), member 8|solute carrier family 5 (sodium/monocarboxylate cotransporter), member 8', map_location='12q23.1-q23.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=101155493, end_position_on_the_genomic_accession=101210238, orientation='minus', exon_count=17, OMIM=[608044], no_hdr0=''),
    160760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160760, CurrentID=0, Status='live', Symbol='PPTC7', Aliases=['TA-PP2C', 'TAPP2C'], description='protein phosphatase targeting COQ7', other_designations='protein phosphatase PTC7 homolog|PTC7 protein phosphatase homolog', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110533245, end_position_on_the_genomic_accession=110583318, orientation='minus', exon_count=7, OMIM=[609668], no_hdr0=''),
    160762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160762, CurrentID=0, Status='live', Symbol='CCDC63', Aliases=['ODA5'], description='coiled-coil domain containing 63', other_designations='coiled-coil domain-containing protein 63|outer row dynein assembly 5 homolog', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110844489, end_position_on_the_genomic_accession=110907535, orientation='plus', exon_count=16, OMIM=[617969], no_hdr0=''),
    160777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160777, CurrentID=0, Status='live', Symbol='CCDC60', Aliases=[], description='coiled-coil domain containing 60', other_designations='coiled-coil domain-containing protein 60', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119334729, end_position_on_the_genomic_accession=119541047, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    160851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160851, CurrentID=0, Status='live', Symbol='DGKH', Aliases=['DGKeta'], description='diacylglycerol kinase eta', other_designations='diacylglycerol kinase eta|DAG kinase eta|diglyceride kinase eta', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=42040070, end_position_on_the_genomic_accession=42256584, orientation='plus', exon_count=38, OMIM=[604071], no_hdr0=''),
    160857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160857, CurrentID=0, Status='live', Symbol='CCDC122', Aliases=[], description='coiled-coil domain containing 122', other_designations='coiled-coil domain-containing protein 122', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=43821959, end_position_on_the_genomic_accession=43880023, orientation='minus', exon_count=13, OMIM=[613408], no_hdr0=''),
    160897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=160897, CurrentID=0, Status='live', Symbol='GPR180', Aliases=['ITR'], description='G protein-coupled receptor 180', other_designations='integral membrane protein GPR180|intimal thickness-related receptor', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=94601857, end_position_on_the_genomic_accession=94634661, orientation='plus', exon_count=9, OMIM=[607787], no_hdr0=''),
    161003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161003, CurrentID=0, Status='live', Symbol='STOML3', Aliases=['Epb7.2l', 'SRO'], description='stomatin like 3', other_designations='stomatin-like protein 3|EPB72-like 3|SLP-3|erythrocyte band 7 integral membrane protein|protein 7.2B|stomatin (EPB72)-like 3', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=38965925, end_position_on_the_genomic_accession=38990831, orientation='minus', exon_count=8, OMIM=[608327], no_hdr0=''),
    161142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161142, CurrentID=0, Status='live', Symbol='FAM71D', Aliases=['C14orf54'], description='family with sequence similarity 71 member D', other_designations='protein FAM71D', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67188365, end_position_on_the_genomic_accession=67228558, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    161145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161145, CurrentID=0, Status='live', Symbol='TMEM229B', Aliases=['C14orf83'], description='transmembrane protein 229B', other_designations='transmembrane protein 229B', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=67470269, end_position_on_the_genomic_accession=67533850, orientation='minus', exon_count=8, OMIM=[619022], no_hdr0=''),
    161176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161176, CurrentID=0, Status='live', Symbol='SYNE3', Aliases=['C14orf139', 'C14orf49', 'KASH3', 'LINC00341', 'NCRNA00341', 'NET53', 'Nesp3'], description='spectrin repeat containing nuclear envelope family member 3', other_designations='nesprin-3|KASH domain-containing protein 3|long intergenic non-protein coding RNA 341|nuclear envelope spectrin repeat protein 3|uncharacterized protein C14orf113', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=95407266, end_position_on_the_genomic_accession=95516650, orientation='minus', exon_count=22, OMIM=[610861], no_hdr0=''),
    161198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161198, CurrentID=0, Status='live', Symbol='CLEC14A', Aliases=['C14orf27', 'CEG1', 'EGFR-5'], description='C-type lectin domain containing 14A', other_designations='C-type lectin domain family 14 member A|ClECT and EGF-like domain containing protein|epidermal growth factor receptor 5', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=38254000, end_position_on_the_genomic_accession=38256093, orientation='minus', exon_count=1, OMIM=[616845], no_hdr0=''),
    161247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161247, CurrentID=0, Status='live', Symbol='FITM1', Aliases=['FIT1'], description='fat storage inducing transmembrane protein 1', other_designations='fat storage-inducing transmembrane protein 1|fat-inducing protein 1|fat-inducing transcript 1', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24130659, end_position_on_the_genomic_accession=24132847, orientation='plus', exon_count=2, OMIM=[612028], no_hdr0=''),
    161253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161253, CurrentID=0, Status='live', Symbol='REM2', Aliases=[], description='RRAD and GEM like GTPase 2', other_designations='GTP-binding protein REM 2|RAS (RAD and GEM)-like GTP binding 2|RAS-like GTP binding 2|Rad and Gem-related 2 (rat homolog)|rad and Gem-like GTP-binding protein 2', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=22883165, end_position_on_the_genomic_accession=22887678, orientation='plus', exon_count=5, OMIM=[616955], no_hdr0=''),
    161291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161291, CurrentID=0, Status='live', Symbol='TMEM30B', Aliases=['CDC50B'], description='transmembrane protein 30B', other_designations='cell cycle control protein 50B|P4-ATPase flippase complex beta subunit TMEM30B', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=61277370, end_position_on_the_genomic_accession=61281338, orientation='minus', exon_count=1, OMIM=[611029], no_hdr0=''),
    161357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161357, CurrentID=0, Status='live', Symbol='MDGA2', Aliases=['MAMDC1', 'c14_5286'], description='MAM domain containing glycosylphosphatidylinositol anchor 2', other_designations='MAM domain-containing glycosylphosphatidylinositol anchor protein 2|MAM domain containing 1', map_location='14q21.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=46836518, end_position_on_the_genomic_accession=47675605, orientation='minus', exon_count=23, OMIM=[611128], no_hdr0=''),
    161394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161394, CurrentID=0, Status='live', Symbol='SAMD15', Aliases=['C14orf174', 'FAM15A'], description='sterile alpha motif domain containing 15', other_designations='sterile alpha motif domain-containing protein 15|SAM domain-containing protein 15|SAM domain-containing protein C14orf174|family with sequence similarity 15, member A', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77377379, end_position_on_the_genomic_accession=77392163, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    161424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161424, CurrentID=0, Status='live', Symbol='NOP9', Aliases=['C14orf21'], description='NOP9 nucleolar protein', other_designations='nucleolar protein 9|NOP9 nucleolar protein homolog|pumilio domain-containing protein C14orf21', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24299850, end_position_on_the_genomic_accession=24309124, orientation='plus', exon_count=11, OMIM=[618308], no_hdr0=''),
    161436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161436, CurrentID=0, Status='live', Symbol='EML5', Aliases=['EMAP-2', 'EMAP-5', 'FAP16'], description='EMAP like 5', other_designations='echinoderm microtubule-associated protein-like 5|echinoderm microtubule associated protein like 5', map_location='14q31.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=88612148, end_position_on_the_genomic_accession=88792953, orientation='minus', exon_count=48, OMIM=[618119], no_hdr0=''),
    161497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161497, CurrentID=0, Status='live', Symbol='STRC', Aliases=['DFNB16'], description='stereocilin', other_designations='stereocilin', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43599563, end_position_on_the_genomic_accession=43618800, orientation='minus', exon_count=29, OMIM=[606440], no_hdr0=''),
    161502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161502, CurrentID=0, Status='live', Symbol='CFAP161', Aliases=['C15orf26'], description='cilia and flagella associated protein 161', other_designations='cilia- and flagella-associated protein 161', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=81099408, end_position_on_the_genomic_accession=81149179, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    161514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161514, CurrentID=0, Status='live', Symbol='TBC1D21', Aliases=['MgcRabGAP'], description='TBC1 domain family member 21', other_designations='TBC1 domain family member 21|male germ cell-specific expressed, containing a RabGAP domain', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73873556, end_position_on_the_genomic_accession=73912166, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    161582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161582, CurrentID=0, Status='live', Symbol='DNAAF4', Aliases=['CILD25', 'DYX1', 'DYX1C1', 'DYXC1', 'EKN1', 'RD'], description='dynein axonemal assembly factor 4', other_designations='dynein axonemal assembly factor 4|dynein assembly factor 4, axonemal|dyslexia susceptibility 1 candidate 1|dyslexia susceptibility 1 candidate gene 1 protein', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55417755, end_position_on_the_genomic_accession=55508234, orientation='minus', exon_count=11, OMIM=[608706], no_hdr0=''),
    161725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161725, CurrentID=0, Status='live', Symbol='OTUD7A', Aliases=['C15orf16', 'C16ORF15', 'CEZANNE2', 'OTUD7'], description='OTU deubiquitinase 7A', other_designations='OTU domain-containing protein 7A|OTU domain-containing 7A|cezanne 2|zinc finger protein Cezanne 2', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=31475398, end_position_on_the_genomic_accession=31870673, orientation='minus', exon_count=14, OMIM=[612024], no_hdr0=''),
    161742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161742, CurrentID=0, Status='live', Symbol='SPRED1', Aliases=['LGSS', 'NFLS', 'PPP1R147', 'hSpred1', 'spred-1'], description='sprouty related EVH1 domain containing 1', other_designations='sprouty-related, EVH1 domain-containing protein 1|protein phosphatase 1, regulatory subunit 147|suppressor of Ras/MAPK activation', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=38252087, end_position_on_the_genomic_accession=38357249, orientation='plus', exon_count=9, OMIM=[609291], no_hdr0=''),
    161753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161753, CurrentID=0, Status='live', Symbol='ODF3L1', Aliases=[], description='outer dense fiber of sperm tails 3 like 1', other_designations='outer dense fiber protein 3-like protein 1', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75722896, end_position_on_the_genomic_accession=75727688, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    161779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161779, CurrentID=0, Status='live', Symbol='PGBD4', Aliases=[], description='piggyBac transposable element derived 4', other_designations='piggyBac transposable element-derived protein 4', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34102083, end_position_on_the_genomic_accession=34108686, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    161823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161823, CurrentID=0, Status='live', Symbol='ADAL', Aliases=['HsMAPDA'], description='adenosine deaminase like', other_designations='adenosine deaminase-like protein|N6-mAMP deaminase|N6-methyl-AMP aminohydrolase', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43330341, end_position_on_the_genomic_accession=43354569, orientation='plus', exon_count=15, OMIM=[619346], no_hdr0=''),
    161829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161829, CurrentID=0, Status='live', Symbol='EXD1', Aliases=['EXDL1'], description="exonuclease 3'-5' domain containing 1", other_designations="piRNA biogenesis protein EXD1|exonuclease 3'-5' domain-containing protein 1|exonuclease 3'-5' domain-like-containing protein 1|inactive exonuclease EXD1", map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41182728, end_position_on_the_genomic_accession=41231074, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    161835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161835, CurrentID=0, Status='live', Symbol='FSIP1', Aliases=['HSD10'], description='fibrous sheath interacting protein 1', other_designations='fibrous sheath-interacting protein 1', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=39597281, end_position_on_the_genomic_accession=39782841, orientation='minus', exon_count=17, OMIM=[615795], no_hdr0=''),
    161882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161882, CurrentID=0, Status='live', Symbol='ZFPM1', Aliases=['FOG', 'FOG1', 'ZC2HC11A', 'ZNF408', 'ZNF89A'], description='zinc finger protein, FOG family member 1', other_designations='zinc finger protein ZFPM1|FOG-1|friend of GATA 1|friend of GATA protein 1|zinc finger protein 89A|zinc finger protein, multitype 1', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88451782, end_position_on_the_genomic_accession=88537031, orientation='plus', exon_count=14, OMIM=[601950], no_hdr0=''),
    161931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=161931, CurrentID=0, Status='live', Symbol='ADAD2', Aliases=['TENRL'], description='adenosine deaminase domain containing 2', other_designations='adenosine deaminase domain-containing protein 2', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=84191157, end_position_on_the_genomic_accession=84197166, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    162073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162073, CurrentID=0, Status='live', Symbol='ITPRIPL2', Aliases=[], description='ITPRIP like 2', other_designations='inositol 1,4,5-trisphosphate receptor-interacting protein-like 2|inositol 1,4,5-triphosphate receptor-interacting protein-like 2|inositol 1,4,5-trisphosphate receptor interacting protein like 2', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19113964, end_position_on_the_genomic_accession=19121629, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    162083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162083, CurrentID=0, Status='live', Symbol='C16orf82', Aliases=['TNT'], description='chromosome 16 open reading frame 82', other_designations='protein TNT', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27066927, end_position_on_the_genomic_accession=27069166, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    162239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162239, CurrentID=0, Status='live', Symbol='ZFP1', Aliases=['ZNF475'], description='ZFP1 zinc finger protein', other_designations='zinc finger protein 1 homolog|zinc finger protein 475', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75126285, end_position_on_the_genomic_accession=75172234, orientation='plus', exon_count=10, OMIM=[617230], no_hdr0=''),
    162282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162282, CurrentID=0, Status='live', Symbol='ANKFN1', Aliases=[], description='ankyrin repeat and fibronectin type III domain containing 1', other_designations='ankyrin repeat and fibronectin type-III domain-containing protein 1', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56110935, end_position_on_the_genomic_accession=56517016, orientation='plus', exon_count=32, OMIM=[], no_hdr0=''),
    162333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162333, CurrentID=0, Status='live', Symbol='MARCHF10', Aliases=['MARCH-X', 'MARCH10', 'RNF190'], description='membrane associated ring-CH-type finger 10', other_designations='probable E3 ubiquitin-protein ligase MARCHF10|RING-type E3 ubiquitin transferase MARCH10|RING-type E3 ubiquitin transferase MARCHF10|membrane associated ring finger 10|membrane-associated RING finger protein 10|membrane-associated RING-CH protein X|membrane-associated ring finger (C3HC4) 10, E3 ubiquitin protein ligase|probable E3 ubiquitin-protein ligase MARCH10|ring finger protein 190|testis secretory sperm-binding protein Li 228n', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62701314, end_position_on_the_genomic_accession=62808346, orientation='minus', exon_count=17, OMIM=[613337], no_hdr0=''),
    162387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162387, CurrentID=0, Status='live', Symbol='MFSD6L', Aliases=[], description='major facilitator superfamily domain containing 6 like', other_designations='major facilitator superfamily domain-containing protein 6-like', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8797110, end_position_on_the_genomic_accession=8799365, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    162394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162394, CurrentID=0, Status='live', Symbol='SLFN5', Aliases=[], description='schlafen family member 5', other_designations='schlafen family member 5', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35243072, end_position_on_the_genomic_accession=35273655, orientation='plus', exon_count=5, OMIM=[614952], no_hdr0=''),
    162417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162417, CurrentID=0, Status='live', Symbol='NAGS', Aliases=['AGAS', 'ARGA'], description='N-acetylglutamate synthase', other_designations='N-acetylglutamate synthase, mitochondrial|amino-acid acetyltransferase', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44004546, end_position_on_the_genomic_accession=44009068, orientation='plus', exon_count=7, OMIM=[608300], no_hdr0=''),
    162427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162427, CurrentID=0, Status='live', Symbol='RETREG3', Aliases=['FAM134C'], description='reticulophagy regulator family member 3', other_designations='reticulophagy regulator 3|family with sequence similarity 134 member C|protein FAM134C', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42579508, end_position_on_the_genomic_accession=42609427, orientation='minus', exon_count=10, OMIM=[616498], no_hdr0=''),
    162461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162461, CurrentID=0, Status='live', Symbol='TMEM92', Aliases=[], description='transmembrane protein 92', other_designations='transmembrane protein 92', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50271406, end_position_on_the_genomic_accession=50281485, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    162466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162466, CurrentID=0, Status='live', Symbol='PHOSPHO1', Aliases=[], description='phosphoethanolamine/phosphocholine phosphatase 1', other_designations='phosphoethanolamine/phosphocholine phosphatase|phosphatase, orphan 1', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49223366, end_position_on_the_genomic_accession=49230787, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    162494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162494, CurrentID=0, Status='live', Symbol='RHBDL3', Aliases=['RHBDL4', 'VRHO'], description='rhomboid like 3', other_designations='rhomboid-related protein 3|rhomboid, veinlet-like 3|rhomboid, veinlet-like 4|ventrhoid transmembrane protein', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=32265832, end_position_on_the_genomic_accession=32324661, orientation='plus', exon_count=12, OMIM=[619017], no_hdr0=''),
    162514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162514, CurrentID=0, Status='live', Symbol='TRPV3', Aliases=['FNEPPK2', 'OLMS', 'OLMS1', 'VRL3'], description='transient receptor potential cation channel subfamily V member 3', other_designations='transient receptor potential cation channel subfamily V member 3|VRL-3|vanilloid receptor-like 3|vanilloid receptor-related osmotically activated channel protein', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3510502, end_position_on_the_genomic_accession=3557812, orientation='minus', exon_count=18, OMIM=[607066], no_hdr0=''),
    162515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162515, CurrentID=0, Status='live', Symbol='SLC16A11', Aliases=['MCT 11', 'MCT11'], description='solute carrier family 16 member 11', other_designations='monocarboxylate transporter 11|monocarboxylic acid transporter 11|solute carrier family 16 (monocarboxylic acid transporters), member 11', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7041621, end_position_on_the_genomic_accession=7044411, orientation='minus', exon_count=5, OMIM=[615765], no_hdr0=''),
    162517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162517, CurrentID=0, Status='live', Symbol='FBXO39', Aliases=['CT144', 'FBOX39', 'Fbx39'], description='F-box protein 39', other_designations='F-box only protein 39', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6776215, end_position_on_the_genomic_accession=6787646, orientation='plus', exon_count=4, OMIM=[609106], no_hdr0=''),
    162540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162540, CurrentID=0, Status='live', Symbol='SPPL2C', Aliases=['IMP5'], description='signal peptide peptidase like 2C', other_designations='signal peptide peptidase-like 2C|IMP-5|SPP-like 2C|intramembrane protease 5', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45844881, end_position_on_the_genomic_accession=45847067, orientation='plus', exon_count=1, OMIM=[608284], no_hdr0=''),
    162605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162605, CurrentID=0, Status='live', Symbol='KRT28', Aliases=['K25IRS4', 'KRT25D'], description='keratin 28', other_designations='keratin, type I cytoskeletal 28|CK-28|K25D|K28|cytokeratin-28|keratin 28, type I|keratin-25D|type I inner root sheath specific keratin 25 irs4|type I inner root sheath-specific keratin-K25irs4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40792196, end_position_on_the_genomic_accession=40799959, orientation='minus', exon_count=8, OMIM=[616677], no_hdr0=''),
    162655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162655, CurrentID=0, Status='live', Symbol='ZNF519', Aliases=['HsT2362'], description='zinc finger protein 519', other_designations='zinc finger protein 519', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=14071121, end_position_on_the_genomic_accession=14132435, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    162681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162681, CurrentID=0, Status='live', Symbol='C18orf54', Aliases=['LAS2'], description='chromosome 18 open reading frame 54', other_designations='lung adenoma susceptibility protein 2', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54357906, end_position_on_the_genomic_accession=54382035, orientation='plus', exon_count=9, OMIM=[613258], no_hdr0=''),
    162962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162962, CurrentID=0, Status='live', Symbol='ZNF836', Aliases=[], description='zinc finger protein 836', other_designations='zinc finger protein 836', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52154050, end_position_on_the_genomic_accession=52171664, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    162963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162963, CurrentID=0, Status='live', Symbol='ZNF610', Aliases=[], description='zinc finger protein 610', other_designations='zinc finger protein 610|zink finger protein', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52336243, end_position_on_the_genomic_accession=52367778, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    162966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162966, CurrentID=0, Status='live', Symbol='ZNF600', Aliases=['KR-ZNF1'], description='zinc finger protein 600', other_designations='zinc finger protein 600|zinc finger protein KR-ZNF1', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52764164, end_position_on_the_genomic_accession=52786825, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    162967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162967, CurrentID=0, Status='live', Symbol='ZNF320', Aliases=['ZFPL'], description='zinc finger protein 320', other_designations='zinc finger protein 320|zinc finger gene 320|zinc finger protein like', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52859491, end_position_on_the_genomic_accession=52897727, orientation='minus', exon_count=16, OMIM=[606427], no_hdr0=''),
    162968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162968, CurrentID=0, Status='live', Symbol='ZNF497', Aliases=[], description='zinc finger protein 497', other_designations='zinc finger protein 497|zinc finger-like protein', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58354357, end_position_on_the_genomic_accession=58362751, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    162972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162972, CurrentID=0, Status='live', Symbol='ZNF550', Aliases=[], description='zinc finger protein 550', other_designations='zinc finger protein 550', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57541836, end_position_on_the_genomic_accession=57561512, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    162979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162979, CurrentID=0, Status='live', Symbol='ZNF296', Aliases=['ZFP296', 'ZNF342'], description='zinc finger protein 296', other_designations='zinc finger protein 296|zinc finger protein 342', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45071500, end_position_on_the_genomic_accession=45076478, orientation='minus', exon_count=3, OMIM=[613226], no_hdr0=''),
    162989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162989, CurrentID=0, Status='live', Symbol='DEDD2', Aliases=['FLAME-3', 'FLAME3'], description='death effector domain containing 2', other_designations='DNA-binding death effector domain-containing protein 2|DED-containing protein FLAME-3|FADD-like anti-apoptotic molecule 3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42198598, end_position_on_the_genomic_accession=42220152, orientation='minus', exon_count=8, OMIM=[617078], no_hdr0=''),
    162993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162993, CurrentID=0, Status='live', Symbol='ZNF846', Aliases=[], description='zinc finger protein 846', other_designations='zinc finger protein 846', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9751993, end_position_on_the_genomic_accession=9786160, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    162998 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=162998, CurrentID=0, Status='live', Symbol='OR7D2', Aliases=['HTPCRH03', 'OR19-10', 'OR19-4'], description='olfactory receptor family 7 subfamily D member 2', other_designations='olfactory receptor 7D2|olfactory receptor 19-4|olfactory receptor OR19-10', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9178979, end_position_on_the_genomic_accession=9188818, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    163033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163033, CurrentID=0, Status='live', Symbol='ZNF579', Aliases=[], description='zinc finger protein 579', other_designations='zinc finger protein 579', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55576774, end_position_on_the_genomic_accession=55580848, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    163049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163049, CurrentID=0, Status='live', Symbol='ZNF791', Aliases=[], description='zinc finger protein 791', other_designations='zinc finger protein 791', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12610920, end_position_on_the_genomic_accession=12633834, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    163050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163050, CurrentID=0, Status='live', Symbol='ZNF564', Aliases=[], description='zinc finger protein 564', other_designations='zinc finger protein 564', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12525373, end_position_on_the_genomic_accession=12551482, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    163051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163051, CurrentID=0, Status='live', Symbol='ZNF709', Aliases=[], description='zinc finger protein 709', other_designations='zinc finger protein 709', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12461184, end_position_on_the_genomic_accession=12484816, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    163059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163059, CurrentID=0, Status='live', Symbol='ZNF433', Aliases=[], description='zinc finger protein 433', other_designations='zinc finger protein 433', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12014715, end_position_on_the_genomic_accession=12035679, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    163071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163071, CurrentID=0, Status='live', Symbol='ZNF114', Aliases=[], description='zinc finger protein 114', other_designations='zinc finger protein 114|zinc finger protein 114 (Y18)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48270081, end_position_on_the_genomic_accession=48287608, orientation='plus', exon_count=9, OMIM=[603996], no_hdr0=''),
    163081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163081, CurrentID=0, Status='live', Symbol='ZNF567', Aliases=[], description='zinc finger protein 567', other_designations='zinc finger protein 567', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36666934, end_position_on_the_genomic_accession=36723355, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    163087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163087, CurrentID=0, Status='live', Symbol='ZNF383', Aliases=['HSD17', 'Zfp383'], description='zinc finger protein 383', other_designations='zinc finger protein 383', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37217243, end_position_on_the_genomic_accession=37248740, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    163115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163115, CurrentID=0, Status='live', Symbol='ZNF781', Aliases=[], description='zinc finger protein 781', other_designations='zinc finger protein 781', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37667751, end_position_on_the_genomic_accession=37692315, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    163126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163126, CurrentID=0, Status='live', Symbol='EID2', Aliases=['CRI2', 'EID-2'], description='EP300 interacting inhibitor of differentiation 2', other_designations='EP300-interacting inhibitor of differentiation 2|CREBBP/EP300 inhibitor 2|CREBBP/EP300 inhibitory protein 2|E1A like inhibitor of differentiation 2|EID-1-like inhibitor of differentiation 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39538707, end_position_on_the_genomic_accession=39540161, orientation='minus', exon_count=1, OMIM=[609773], no_hdr0=''),
    163131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163131, CurrentID=0, Status='live', Symbol='ZNF780B', Aliases=['ZNF779'], description='zinc finger protein 780B', other_designations='zinc finger protein 780B|zinc finger protein 779', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40028260, end_position_on_the_genomic_accession=40064448, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    163154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163154, CurrentID=0, Status='live', Symbol='PRR22', Aliases=[], description='proline rich 22', other_designations='proline-rich protein 22', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5782960, end_position_on_the_genomic_accession=5784746, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    163175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163175, CurrentID=0, Status='live', Symbol='LGI4', Aliases=['AMC1', 'AMCNMY', 'LGIL3'], description='leucine rich repeat LGI family member 4', other_designations='leucine-rich repeat LGI family member 4|LGI1-like protein 3|leucine-rich glioma-inactivated gene 4|leucine-rich glioma-inactivated protein 4', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35124513, end_position_on_the_genomic_accession=35135059, orientation='minus', exon_count=11, OMIM=[608303], no_hdr0=''),
    163183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163183, CurrentID=0, Status='live', Symbol='SYNE4', Aliases=['C19orf46', 'DFNB76', 'KASH4', 'Nesp4'], description='spectrin repeat containing nuclear envelope family member 4', other_designations='nesprin-4|KASH domain-containing protein 4|deafness, autosomal recessive 76|nuclear envelope spectrin repeat protein 4', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36003307, end_position_on_the_genomic_accession=36008813, orientation='minus', exon_count=8, OMIM=[615535], no_hdr0=''),
    163223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163223, CurrentID=0, Status='live', Symbol='ZNF676', Aliases=[], description='zinc finger protein 676', other_designations='zinc finger protein 676', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22179089, end_position_on_the_genomic_accession=22196951, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    163227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163227, CurrentID=0, Status='live', Symbol='ZNF100', Aliases=[], description='zinc finger protein 100', other_designations='zinc finger protein 100|zinc finger protein 100 (Y1)', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21722771, end_position_on_the_genomic_accession=21767579, orientation='minus', exon_count=5, OMIM=[603982], no_hdr0=''),
    163255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163255, CurrentID=0, Status='live', Symbol='ZNF540', Aliases=['Nbla10512'], description='zinc finger protein 540', other_designations='zinc finger protein 540|CTD-3064H18.6|putative protein product of Nbla10512', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37551374, end_position_on_the_genomic_accession=37614179, orientation='plus', exon_count=6, OMIM=[613903], no_hdr0=''),
    163259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163259, CurrentID=0, Status='live', Symbol='DENND2C', Aliases=['dJ1156J9.1'], description='DENN domain containing 2C', other_designations='DENN domain-containing protein 2C|DENN/MADD domain containing 2C|RP5-1156J9.1', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=114582850, end_position_on_the_genomic_accession=114670049, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    163351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163351, CurrentID=0, Status='live', Symbol='GBP6', Aliases=[], description='guanylate binding protein family member 6', other_designations='guanylate-binding protein 6|GBP-6|GTP-binding protein 6|guanine nucleotide-binding protein 6', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89364059, end_position_on_the_genomic_accession=89388160, orientation='plus', exon_count=11, OMIM=[612467], no_hdr0=''),
    163404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163404, CurrentID=0, Status='live', Symbol='PLPPR5', Aliases=['LPPR5', 'PAP2', 'PAP2D', 'PRG5'], description='phospholipid phosphatase related 5', other_designations='phospholipid phosphatase-related protein type 5|PRG-5|lipid phosphate phosphatase-related protein type 5|phosphatidic acid phosphatase 2d|phosphatidic acid phosphatase type 2|phosphatidic acid phosphatase type 2d|plasticity-related gene 5 protein|plasticity-related protein 5', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=98890245, end_position_on_the_genomic_accession=99006130, orientation='minus', exon_count=8, OMIM=[617287], no_hdr0=''),
    163479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163479, CurrentID=0, Status='live', Symbol='FNDC7', Aliases=[], description='fibronectin type III domain containing 7', other_designations='fibronectin type III domain-containing protein 7', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108712908, end_position_on_the_genomic_accession=108742749, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    163486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163486, CurrentID=0, Status='live', Symbol='DENND1B', Aliases=['C1ORF18', 'C1orf218', 'FAM31B'], description='DENN domain containing 1B', other_designations='DENN domain-containing protein 1B|DENN/MADD domain containing 1B|connecdenn 2|family with sequence similarity 31, member B', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197504748, end_position_on_the_genomic_accession=197782138, orientation='minus', exon_count=30, OMIM=[613292], no_hdr0=''),
    163589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163589, CurrentID=0, Status='live', Symbol='TDRD5', Aliases=['TUDOR3'], description='tudor domain containing 5', other_designations='tudor domain-containing protein 5|testicular tissue protein Li 194', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179591613, end_position_on_the_genomic_accession=179691272, orientation='plus', exon_count=20, OMIM=[617748], no_hdr0=''),
    163590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163590, CurrentID=0, Status='live', Symbol='TOR1AIP2', Aliases=['IFRG15', 'LULL1', 'NET9'], description='torsin 1A interacting protein 2', other_designations='torsin-1A-interacting protein 2|interferon alpha responsive protein|15 kDa interferon-responsive protein|interferon responsive gene 15|lumenal domain like LAP1|torsin A interacting protein 2', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=179839976, end_position_on_the_genomic_accession=179877803, orientation='minus', exon_count=10, OMIM=[614513], no_hdr0=''),
    163688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163688, CurrentID=0, Status='live', Symbol='CALML6', Aliases=['CAGLP'], description='calmodulin like 6', other_designations='calmodulin-like protein 6|EF-hand protein|calglandulin-like protein', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1913751, end_position_on_the_genomic_accession=1917296, orientation='plus', exon_count=6, OMIM=[610171], no_hdr0=''),
    163702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163702, CurrentID=0, Status='live', Symbol='IFNLR1', Aliases=['CRF2/12', 'IFNLR', 'IL-28R1', 'IL28RA', 'LICR2'], description='interferon lambda receptor 1', other_designations='interferon lambda receptor 1|CRF2-12|IFN-lambda receptor 1|IFN-lambda-R1|IL-28 receptor subunit alpha|IL-28R-alpha|IL-28RA|class II cytokine receptor CRF2/12|cytokine receptor class-II member 12|cytokine receptor family 2 member 12|interleukin 28 alpha receptor|interleukin 28 receptor A|interleukin 28 receptor, alpha (interferon, lambda receptor)|interleukin or cytokine receptor 2|interleukin-28 receptor subunit alpha|likely interleukin or cytokine receptor 2', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24154156, end_position_on_the_genomic_accession=24187295, orientation='minus', exon_count=9, OMIM=[607404], no_hdr0=''),
    163732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163732, CurrentID=0, Status='live', Symbol='CITED4', Aliases=[], description='Cbp/p300 interacting transactivator with Glu/Asp rich carboxy-terminal domain 4', other_designations='cbp/p300-interacting transactivator 4|MRG-2|MSG1-related protein 2|transcriptional co-activator 4', map_location='1p35-p34', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40861054, end_position_on_the_genomic_accession=40862363, orientation='minus', exon_count=1, OMIM=[606815], no_hdr0=''),
    163747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163747, CurrentID=0, Status='live', Symbol='LEXM', Aliases=['C1orf177', 'LEM'], description='lymphocyte expansion molecule', other_designations='lymphocyte expansion molecule', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54806063, end_position_on_the_genomic_accession=54842252, orientation='plus', exon_count=14, OMIM=[616446], no_hdr0=''),
    163778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163778, CurrentID=0, Status='live', Symbol='SPRR4', Aliases=[], description='small proline rich protein 4', other_designations='small proline-rich protein 4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152968755, end_position_on_the_genomic_accession=152972602, orientation='plus', exon_count=4, OMIM=[616363], no_hdr0=''),
    163782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163782, CurrentID=0, Status='live', Symbol='KANK4', Aliases=['ANKRD38', 'dJ1078M7.1'], description='KN motif and ankyrin repeat domains 4', other_designations='KN motif and ankyrin repeat domain-containing protein 4|ankyrin repeat domain 38|ankyrin repeat domain-containing protein 38|kidney ankyrin repeat-containing protein 4', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=62236165, end_position_on_the_genomic_accession=62319434, orientation='minus', exon_count=12, OMIM=[614612], no_hdr0=''),
    163786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163786, CurrentID=0, Status='live', Symbol='SASS6', Aliases=['MCPH14', 'SAS-6', 'SAS6'], description='SAS-6 centriolar assembly protein', other_designations='spindle assembly abnormal protein 6 homolog', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=100082632, end_position_on_the_genomic_accession=100132930, orientation='minus', exon_count=18, OMIM=[609321], no_hdr0=''),
    163859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163859, CurrentID=0, Status='live', Symbol='SDE2', Aliases=['C1orf55', 'dJ671D7.1'], description='SDE2 telomere maintenance homolog', other_designations='replication stress response regulator SDE2|UPF0667 protein C1orf55|protein SDE2 homolog', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=225982702, end_position_on_the_genomic_accession=225999343, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    163882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163882, CurrentID=0, Status='live', Symbol='CNST', Aliases=['C1orf71', 'PPP1R64'], description='consortin, connexin sorting protein', other_designations='consortin|protein phosphatase 1, regulatory subunit 64', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=246566338, end_position_on_the_genomic_accession=246668595, orientation='plus', exon_count=14, OMIM=[613439], no_hdr0=''),
    163933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=163933, CurrentID=0, Status='live', Symbol='FAM43B', Aliases=[], description='family with sequence similarity 43 member B', other_designations='protein FAM43B', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20552573, end_position_on_the_genomic_accession=20555020, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    164045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164045, CurrentID=0, Status='live', Symbol='HFM1', Aliases=['MER3', 'POF9', 'SEC63D1', 'Si-11', 'Si-11-6', 'helicase'], description='helicase for meiosis 1', other_designations='probable ATP-dependent DNA helicase HFM1|HFM1, ATP dependent DNA helicase homolog|SEC63 domain-containing protein 1|helicase-like protein HFM1', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=91260766, end_position_on_the_genomic_accession=91408008, orientation='minus', exon_count=44, OMIM=[615684], no_hdr0=''),
    164091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164091, CurrentID=0, Status='live', Symbol='PAQR7', Aliases=['MPRA', 'PGLP', 'mSR'], description='progestin and adipoQ receptor family member 7', other_designations='membrane progestin receptor alpha|2310021M12Rik|mPR alpha|membrane progesterone P4 receptor alpha|membrane progesterone receptor alpha|progesterone and adipoQ receptor family member 7|progestin and adipoQ receptor family member VII', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=25861484, end_position_on_the_genomic_accession=25876707, orientation='minus', exon_count=5, OMIM=[607779], no_hdr0=''),
    164118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164118, CurrentID=0, Status='live', Symbol='TTC24', Aliases=[], description='tetratricopeptide repeat domain 24', other_designations='tetratricopeptide repeat protein 24|TPR repeat protein 24', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156579723, end_position_on_the_genomic_accession=156587719, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    164127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164127, CurrentID=0, Status='live', Symbol='CCDC185', Aliases=['C1orf65'], description='coiled-coil domain containing 185', other_designations='coiled-coil domain-containing protein 185', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223393415, end_position_on_the_genomic_accession=223395465, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    164153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164153, CurrentID=0, Status='live', Symbol='UBL4B', Aliases=[], description='ubiquitin like 4B', other_designations='ubiquitin-like protein 4B', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110112443, end_position_on_the_genomic_accession=110113947, orientation='plus', exon_count=1, OMIM=[611127], no_hdr0=''),
    164237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164237, CurrentID=0, Status='live', Symbol='WFDC13', Aliases=['C20orf138', 'WAP13', 'dJ601O1.3'], description='WAP four-disulfide core domain 13', other_designations='WAP four-disulfide core domain protein 13|protease inhibitor WAP13|protein WFDC13', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45702038, end_position_on_the_genomic_accession=45708817, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    164284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164284, CurrentID=0, Status='live', Symbol='APCDD1L', Aliases=[], description='APC down-regulated 1 like', other_designations='protein APCDD1-like|adenomatosis polyposis coli down-regulated 1 like', map_location='20q13.32', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=58459101, end_position_on_the_genomic_accession=58515399, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    164312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164312, CurrentID=0, Status='live', Symbol='LRRN4', Aliases=['C20orf75', 'NLRR-4', 'NLRR4', 'dJ1056H1.1'], description='leucine rich repeat neuronal 4', other_designations='leucine-rich repeat neuronal protein 4|neuronal leucine-rich repeat protein 4', map_location='20p12.3', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=6038066, end_position_on_the_genomic_accession=6054060, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    164395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164395, CurrentID=0, Status='live', Symbol='TTLL9', Aliases=['C20orf125'], description='tubulin tyrosine ligase like 9', other_designations='probable tubulin polyglutamylase TTLL9|tubulin tyrosine ligase-like family, member 9|tubulin--tyrosine ligase-like protein 9', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31870634, end_position_on_the_genomic_accession=31945000, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    164592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164592, CurrentID=0, Status='live', Symbol='CCDC116', Aliases=[], description='coiled-coil domain containing 116', other_designations='coiled-coil domain-containing protein 116', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21632121, end_position_on_the_genomic_accession=21637329, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    164633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164633, CurrentID=0, Status='live', Symbol='CABP7', Aliases=['CALN2'], description='calcium binding protein 7', other_designations='calcium-binding protein 7|calneuron 2|calneuron II', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=29720003, end_position_on_the_genomic_accession=29731833, orientation='plus', exon_count=5, OMIM=[618759], no_hdr0=''),
    164656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164656, CurrentID=0, Status='live', Symbol='TMPRSS6', Aliases=['IRIDA', 'MT2'], description='transmembrane serine protease 6', other_designations='transmembrane protease serine 6|matriptase-2|membrane-bound mosaic serine proteinase matriptase-2|transmembrane protease, serine 6|type II transmembrane serine protease 6', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=37065436, end_position_on_the_genomic_accession=37110625, orientation='minus', exon_count=23, OMIM=[609862], no_hdr0=''),
    164668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164668, CurrentID=0, Status='live', Symbol='APOBEC3H', Aliases=['A3H', 'ARP-10', 'ARP10'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3H', other_designations='DNA dC->dU-editing enzyme APOBEC-3H|APOBEC-related protein 10|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3H', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39097203, end_position_on_the_genomic_accession=39104067, orientation='plus', exon_count=6, OMIM=[610976], no_hdr0=''),
    164684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164684, CurrentID=0, Status='live', Symbol='WBP2NL', Aliases=['GRAMD7', 'PAWP'], description='WBP2 N-terminal like', other_designations='postacrosomal sheath WW domain-binding protein|WW domain-binding protein 2-like', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41995103, end_position_on_the_genomic_accession=42059402, orientation='plus', exon_count=10, OMIM=[610981], no_hdr0=''),
    164714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164714, CurrentID=0, Status='live', Symbol='TTLL8', Aliases=[], description='tubulin tyrosine ligase like 8', other_designations='protein monoglycylase TTLL8|tubulin tyrosine ligase-like family, member 8|tubulin--tyrosine ligase-like protein 8', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50018575, end_position_on_the_genomic_accession=50058227, orientation='minus', exon_count=16, OMIM=[619193], no_hdr0=''),
    164781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164781, CurrentID=0, Status='live', Symbol='DAW1', Aliases=['ODA16', 'WDR69'], description='dynein assembly factor with WD repeats 1', other_designations='dynein assembly factor with WDR repeat domains 1|WD repeat domain 69|WD repeat-containing protein 69|outer row dynein assembly 16 homolog|outer row dynein assembly protein 16 homolog|testis tissue sperm-binding protein Li 93mP', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=227871631, end_position_on_the_genomic_accession=227924347, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    164832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=164832, CurrentID=0, Status='live', Symbol='LONRF2', Aliases=['RNF192'], description='LON peptidase N-terminal domain and ring finger 2', other_designations='LON peptidase N-terminal domain and RING finger protein 2|RING finger protein 192|neuroblastoma apoptosis-related protease', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=100271875, end_position_on_the_genomic_accession=100322501, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    165055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165055, CurrentID=0, Status='live', Symbol='CCDC138', Aliases=[], description='coiled-coil domain containing 138', other_designations='coiled-coil domain-containing protein 138', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108786733, end_position_on_the_genomic_accession=108885485, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    165082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165082, CurrentID=0, Status='live', Symbol='ADGRF3', Aliases=['GPR113', 'PGR23'], description='adhesion G protein-coupled receptor F3', other_designations='adhesion G-protein coupled receptor F3|G protein-coupled receptor 113|G protein-coupled receptor PGR23|probable G-protein coupled receptor 113|seven transmembrane helix receptor', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26308173, end_position_on_the_genomic_accession=26346789, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    165100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165100, CurrentID=0, Status='live', Symbol='TEX44', Aliases=['C2orf57'], description='testis expressed 44', other_designations='testis-expressed protein 44|uncharacterized protein C2orf57', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231592864, end_position_on_the_genomic_accession=231594276, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    165140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165140, CurrentID=0, Status='live', Symbol='OXER1', Aliases=['GPCR', 'GPR170', 'TG1019'], description='oxoeicosanoid receptor 1', other_designations='oxoeicosanoid receptor 1|5-oxo-ETE G-protein coupled receptor|5-oxo-ETE acid G-protein-coupled receptor 1|G-protein coupled receptor 170|G-protein coupled receptor R527|G-protein coupled receptor TG1019|OXE receptor|oxoeicosanoid (OXE) receptor 1', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42762499, end_position_on_the_genomic_accession=42764135, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    165186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165186, CurrentID=0, Status='live', Symbol='TOGARAM2', Aliases=['FAM179A'], description='TOG array regulator of axonemal microtubules 2', other_designations='TOG array regulator of axonemal microtubules protein 2|crescerin-2|family with sequence similarity 179 member A|protein FAM179A', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28981298, end_position_on_the_genomic_accession=29052230, orientation='plus', exon_count=27, OMIM=[], no_hdr0=''),
    165215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165215, CurrentID=0, Status='live', Symbol='FAM171B', Aliases=['KIAA1946'], description='family with sequence similarity 171 member B', other_designations='protein FAM171B', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=186694060, end_position_on_the_genomic_accession=186765959, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    165257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165257, CurrentID=0, Status='live', Symbol='C1QL2', Aliases=['C1QTNF10', 'CTRP10'], description='complement C1q like 2', other_designations='complement C1q-like protein 2|C1q and tumor necrosis factor-related protein 10|C1q-domain containing protein|C1q/TNF-related protein 10|complement component 1, q subcomponent-like 2', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119156243, end_position_on_the_genomic_accession=119158751, orientation='minus', exon_count=2, OMIM=[614330], no_hdr0=''),
    165324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165324, CurrentID=0, Status='live', Symbol='UBXN2A', Aliases=['UBXD4'], description='UBX domain protein 2A', other_designations='UBX domain-containing protein 2A|UBX domain containing 4|UBX domain-containing protein 4', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=23927172, end_position_on_the_genomic_accession=24004909, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    165530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165530, CurrentID=0, Status='live', Symbol='CLEC4F', Aliases=['CLECSF13', 'KCLR'], description='C-type lectin domain family 4 member F', other_designations='C-type lectin domain family 4 member F|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 13', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70808643, end_position_on_the_genomic_accession=70825235, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    165545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165545, CurrentID=0, Status='live', Symbol='DQX1', Aliases=[], description='DEAQ-box RNA dependent ATPase 1', other_designations='ATP-dependent RNA helicase DQX1|DEAQ RNA-dependent ATPase DQX1|DEAQ box polypeptide 1 (RNA-dependent ATPase)', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74518131, end_position_on_the_genomic_accession=74526231, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    165631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165631, CurrentID=0, Status='live', Symbol='PARP15', Aliases=['ARTD7', 'BAL3', 'pART7'], description='poly(ADP-ribose) polymerase family member 15', other_designations='protein mono-ADP-ribosyltransferase PARP15|ADP-ribosyltransferase diphtheria toxin-like 7|B-aggressive lymphoma 3|B-aggressive lymphoma protein 3|PARP-15|poly [ADP-ribose] polymerase 15', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=122575926, end_position_on_the_genomic_accession=122639047, orientation='plus', exon_count=14, OMIM=[612066], no_hdr0=''),
    165679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165679, CurrentID=0, Status='live', Symbol='SPTSSB', Aliases=['ADMP', 'C3orf57', 'SSSPTB'], description='serine palmitoyltransferase small subunit B', other_designations='serine palmitoyltransferase small subunit B|androgen down regulated in mouse prostate|likely ortholog of androgen down regulated gene expressed in mouse prostate|small subunit of serine palmitoyltransferase B', map_location='3q26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=161344784, end_position_on_the_genomic_accession=161373228, orientation='minus', exon_count=6, OMIM=[610412], no_hdr0=''),
    165721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165721, CurrentID=0, Status='live', Symbol='DNAJB8', Aliases=['CT156', 'DJ6'], description='DnaJ heat shock protein family (Hsp40) member B8', other_designations='dnaJ homolog subfamily B member 8|DnaJ (Hsp40) homolog, subfamily B, member 8|testicular tissue protein Li 56', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=128462434, end_position_on_the_genomic_accession=128467075, orientation='minus', exon_count=2, OMIM=[611337], no_hdr0=''),
    165829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165829, CurrentID=0, Status='live', Symbol='GPR156', Aliases=['GABABL', 'PGR28'], description='G protein-coupled receptor 156', other_designations='probable G-protein coupled receptor 156|G protein-coupled receptor PGR28|GABAB-related G-protein coupled receptor', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120165478, end_position_on_the_genomic_accession=120285222, orientation='minus', exon_count=15, OMIM=[610464], no_hdr0=''),
    165904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165904, CurrentID=0, Status='live', Symbol='XIRP1', Aliases=['CMYA1', 'Xin'], description='xin actin binding repeat containing 1', other_designations='xin actin-binding repeat-containing protein 1|cardiomyopathy associated 1|cardiomyopathy-associated protein 1', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39183214, end_position_on_the_genomic_accession=39192621, orientation='minus', exon_count=2, OMIM=[609777], no_hdr0=''),
    165918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=165918, CurrentID=0, Status='live', Symbol='RNF168', Aliases=['RIDL', 'hRNF168'], description='ring finger protein 168', other_designations='E3 ubiquitin-protein ligase RNF168|RING-type E3 ubiquitin transferase RNF168|ring finger protein 168, E3 ubiquitin protein ligase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196468783, end_position_on_the_genomic_accession=196503768, orientation='minus', exon_count=6, OMIM=[612688], no_hdr0=''),
    166012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166012, CurrentID=0, Status='live', Symbol='CHST13', Aliases=['C4ST3'], description='carbohydrate sulfotransferase 13', other_designations='carbohydrate sulfotransferase 13|C4ST-3|carbohydrate (chondroitin 4) sulfotransferase 13|chondroitin 4-O-sulfotransferase 3|chondroitin 4-sulfotransferase 3', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126524155, end_position_on_the_genomic_accession=126543291, orientation='plus', exon_count=3, OMIM=[610124], no_hdr0=''),
    166336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166336, CurrentID=0, Status='live', Symbol='PRICKLE2', Aliases=['EPM5'], description='prickle planar cell polarity protein 2', other_designations='prickle-like protein 2|prickle homolog 2', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=64092236, end_position_on_the_genomic_accession=64445476, orientation='minus', exon_count=15, OMIM=[608501], no_hdr0=''),
    166348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166348, CurrentID=0, Status='live', Symbol='KBTBD12', Aliases=['KLHDC6'], description='kelch repeat and BTB domain containing 12', other_designations='kelch repeat and BTB domain-containing protein 12|kelch domain containing 6|kelch domain-containing protein 6|kelch repeat and BTB (POZ) domain containing 12', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127915232, end_position_on_the_genomic_accession=127987677, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    166378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166378, CurrentID=0, Status='live', Symbol='SPATA5', Aliases=['AFG2', 'EHLMRS', 'SPAF'], description='spermatogenesis associated 5', other_designations='ATPase family protein 2 homolog|ATPase family gene 2 homolog|spermatogenesis associated factor SPAF|spermatogenesis-associated factor protein|spermatogenesis-associated protein 5', map_location='4q28.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122923070, end_position_on_the_genomic_accession=123319433, orientation='plus', exon_count=22, OMIM=[613940], no_hdr0=''),
    166379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166379, CurrentID=0, Status='live', Symbol='BBS12', Aliases=['C4orf24'], description='Bardet-Biedl syndrome 12', other_designations='Bardet-Biedl syndrome 12 protein|truncated Bardet-Biedl syndrome 12 protein', map_location='4q27', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=122700437, end_position_on_the_genomic_accession=122744943, orientation='plus', exon_count=4, OMIM=[610683], no_hdr0=''),
    166614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166614, CurrentID=0, Status='live', Symbol='DCLK2', Aliases=['CL2', 'CLICK-II', 'CLICK2', 'CLIK2', 'DCAMKL2', 'DCDC3', 'DCDC3B', 'DCK2'], description='doublecortin like kinase 2', other_designations='serine/threonine-protein kinase DCLK2|CaMK-like CREB regulatory kinase 2|doublecortin and CaM kinase-like 2|doublecortin domain-containing protein 3B|doublecortin-like and CAM kinase-like 2', map_location='4q31.23-q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=150078445, end_position_on_the_genomic_accession=150257449, orientation='plus', exon_count=20, OMIM=[613166], no_hdr0=''),
    166647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166647, CurrentID=0, Status='live', Symbol='ADGRA3', Aliases=['GPR125', 'PGR21', 'TEM5L'], description='adhesion G protein-coupled receptor A3', other_designations='adhesion G protein-coupled receptor A3|G-protein coupled receptor 125|probable G-protein coupled receptor 125', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=22387376, end_position_on_the_genomic_accession=22516066, orientation='minus', exon_count=21, OMIM=[612303], no_hdr0=''),
    166655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166655, CurrentID=0, Status='live', Symbol='TRIM60', Aliases=['RNF129', 'RNF33'], description='tripartite motif containing 60', other_designations='tripartite motif-containing protein 60|ring finger protein 129|ring finger protein 33', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165031953, end_position_on_the_genomic_accession=165041821, orientation='plus', exon_count=4, OMIM=[619416], no_hdr0=''),
    166752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166752, CurrentID=0, Status='live', Symbol='FREM3', Aliases=[], description='FRAS1 related extracellular matrix 3', other_designations='FRAS1-related extracellular matrix protein 3', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=143577302, end_position_on_the_genomic_accession=143700675, orientation='minus', exon_count=8, OMIM=[608946], no_hdr0=''),
    166785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166785, CurrentID=0, Status='live', Symbol='MMAA', Aliases=['cblA'], description='metabolism of cobalamin associated A', other_designations='methylmalonic aciduria type A protein, mitochondrial|methylmalonic aciduria (cobalamin deficiency) cblA type|mutant adenosylcobalamin', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145619385, end_position_on_the_genomic_accession=145660033, orientation='plus', exon_count=8, OMIM=[607481], no_hdr0=''),
    166793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166793, CurrentID=0, Status='live', Symbol='ZBTB49', Aliases=['ZNF509'], description='zinc finger and BTB domain containing 49', other_designations='zinc finger and BTB domain-containing protein 49|zinc finger protein 509', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=4290197, end_position_on_the_genomic_accession=4321786, orientation='plus', exon_count=8, OMIM=[616238], no_hdr0=''),
    166815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166815, CurrentID=0, Status='live', Symbol='TIGD2', Aliases=['HEL106'], description='tigger transposable element derived 2', other_designations='tigger transposable element-derived protein 2|epididymis luminal protein 106', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=89111169, end_position_on_the_genomic_accession=89114901, orientation='plus', exon_count=3, OMIM=[612973], no_hdr0=''),
    166824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166824, CurrentID=0, Status='live', Symbol='RASSF6', Aliases=[], description='Ras association domain family member 6', other_designations='ras association domain-containing protein 6|Ras association (RalGDS/AF-6) domain family 6|Ras association (RalGDS/AF-6) domain family member 6|putative RAS binding protein', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73571550, end_position_on_the_genomic_accession=73620631, orientation='minus', exon_count=17, OMIM=[612620], no_hdr0=''),
    166863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166863, CurrentID=0, Status='live', Symbol='RBM46', Aliases=['CT68'], description='RNA binding motif protein 46', other_designations='probable RNA-binding protein 46|cancer/testis antigen 68', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=154781249, end_position_on_the_genomic_accession=154828813, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    166929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166929, CurrentID=0, Status='live', Symbol='SGMS2', Aliases=['CDL', 'SMS2'], description='sphingomyelin synthase 2', other_designations='phosphatidylcholine:ceramide cholinephosphotransferase 2|SM synthase', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=107823645, end_position_on_the_genomic_accession=107915047, orientation='plus', exon_count=11, OMIM=[611574], no_hdr0=''),
    166968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166968, CurrentID=0, Status='live', Symbol='MIER3', Aliases=[], description='MIER family member 3', other_designations='mesoderm induction early response protein 3|mesoderm induction early response 1, family member 3|mi-er3', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=56919602, end_position_on_the_genomic_accession=56952123, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    166979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=166979, CurrentID=0, Status='live', Symbol='CDC20B', Aliases=['G6VTS76519'], description='cell division cycle 20B', other_designations='cell division cycle protein 20 homolog B|CDC20 cell division cycle 20 homolog B|CDC20-like protein|cell division cycle 20 homolog B', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55112971, end_position_on_the_genomic_accession=55173177, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    167127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167127, CurrentID=0, Status='live', Symbol='UGT3A2', Aliases=[], description='UDP glycosyltransferase family 3 member A2', other_designations='UDP-glucuronosyltransferase 3A2|UDP glycosyltransferase 3 family, polypeptide A2|UDPGT 3A2', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36035021, end_position_on_the_genomic_accession=36071358, orientation='minus', exon_count=9, OMIM=[616384], no_hdr0=''),
    167153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167153, CurrentID=0, Status='live', Symbol='TENT2', Aliases=['APD4', 'GLD2', 'PAPD4', 'TUT2'], description='terminal nucleotidyltransferase 2', other_designations='poly(A) RNA polymerase GLD2|PAP associated domain containing 4|PAP-associated domain-containing protein 4|TUTase 2|poly(A) RNA polymerase D4, non-canonical|terminal uridylyltransferase 2', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79612421, end_position_on_the_genomic_accession=79688246, orientation='plus', exon_count=23, OMIM=[614121], no_hdr0=''),
    167227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167227, CurrentID=0, Status='live', Symbol='DCP2', Aliases=['NUDT20'], description='decapping mRNA 2', other_designations='m7GpppN-mRNA hydrolase|DCP2 decapping enzyme homolog|hDpc|mRNA-decapping enzyme 2|nudix (nucleoside diphosphate linked moiety X)-type motif 20', map_location='5q22.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=112976702, end_position_on_the_genomic_accession=113022195, orientation='plus', exon_count=12, OMIM=[609844], no_hdr0=''),
    167359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167359, CurrentID=0, Status='live', Symbol='NIM1K', Aliases=['NIM1'], description='NIM1 serine/threonine protein kinase', other_designations='serine/threonine-protein kinase NIM1', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43192225, end_position_on_the_genomic_accession=43280850, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    167410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167410, CurrentID=0, Status='live', Symbol='LIX1', Aliases=['C5orf11', 'Lft'], description='limb and CNS expressed 1', other_designations='protein limb expression 1 homolog|Lix1 homolog|Lowfat homolog|limb expression 1', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=97091867, end_position_on_the_genomic_accession=97142611, orientation='minus', exon_count=6, OMIM=[610466], no_hdr0=''),
    167465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167465, CurrentID=0, Status='live', Symbol='ZNF366', Aliases=['DC-SCRIPT', 'DCSCRIPT'], description='zinc finger protein 366', other_designations='zinc finger protein 366|dendritic cell-specific transcript protein', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=72439903, end_position_on_the_genomic_accession=72507410, orientation='minus', exon_count=5, OMIM=[610159], no_hdr0=''),
    167555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167555, CurrentID=0, Status='live', Symbol='FAM151B', Aliases=['UNQ9217'], description='family with sequence similarity 151 member B', other_designations='protein FAM151B|AASA9217', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80488069, end_position_on_the_genomic_accession=80542563, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    167681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167681, CurrentID=0, Status='live', Symbol='PRSS35', Aliases=['C6orf158', 'dJ223E3.1'], description='serine protease 35', other_designations='inactive serine protease 35|protease, serine 35', map_location='6q14.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=83512534, end_position_on_the_genomic_accession=83525704, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    167691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167691, CurrentID=0, Status='live', Symbol='LCA5', Aliases=['C6orf152'], description='lebercilin LCA5', other_designations='lebercilin|LCA5, lebercilin|epididymis secretory sperm binding protein|leber congenital amaurosis 5 protein', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=79484991, end_position_on_the_genomic_accession=79537430, orientation='minus', exon_count=9, OMIM=[611408], no_hdr0=''),
    167826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167826, CurrentID=0, Status='live', Symbol='OLIG3', Aliases=['Bhlhb7', 'bHLHe20'], description='oligodendrocyte transcription factor 3', other_designations='oligodendrocyte transcription factor 3|class B basic helix-loop-helix protein 7|class E basic helix-loop-helix protein 20|oligo3', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=137492199, end_position_on_the_genomic_accession=137494394, orientation='minus', exon_count=1, OMIM=[609323], no_hdr0=''),
    167838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=167838, CurrentID=0, Status='live', Symbol='TXLNB', Aliases=['C6orf198', 'LST001', 'MDP77', 'dJ522B19.2'], description='taxilin beta', other_designations='beta-taxilin|muscle-derived protein 77', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=139159162, end_position_on_the_genomic_accession=139324029, orientation='minus', exon_count=18, OMIM=[611438], no_hdr0=''),
    168002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168002, CurrentID=0, Status='live', Symbol='DACT2', Aliases=['C6orf116', 'DAPPER2', 'DPR2', 'bA503C24.7'], description='dishevelled binding antagonist of beta catenin 2', other_designations='dapper homolog 2|dapper antagonist of catenin 2|dapper homolog 2, antagonist of beta-catenin|dapper, antagonist of beta-catenin, homolog 2', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=168292830, end_position_on_the_genomic_accession=168319777, orientation='minus', exon_count=8, OMIM=[608966], no_hdr0=''),
    168090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168090, CurrentID=0, Status='live', Symbol='C6orf118', Aliases=['bA85G2.1', 'dJ416F21.2'], description='chromosome 6 open reading frame 118', other_designations='uncharacterized protein C6orf118', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=165279403, end_position_on_the_genomic_accession=165309647, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    168374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168374, CurrentID=0, Status='live', Symbol='ZNF92', Aliases=['HEL-203', 'HPF12', 'HTF12', 'TF12'], description='zinc finger protein 92', other_designations='zinc finger protein 92|epididymis luminal protein 203|zinc finger protein HTF12', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=65373855, end_position_on_the_genomic_accession=65401136, orientation='plus', exon_count=5, OMIM=[603974], no_hdr0=''),
    168391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168391, CurrentID=0, Status='live', Symbol='GALNTL5', Aliases=['GALNACT19', 'GALNT15', 'GalNAc-T5L'], description='polypeptide N-acetylgalactosaminyltransferase like 5', other_designations='inactive polypeptide N-acetylgalactosaminyltransferase-like protein 5|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 15|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase-like 5|galNAc-T15|polypeptide GalNAc transferase 15|polypeptide GalNAc transferase-like 5|pp-GaNTase 15|protein-UDP acetylgalactosaminyltransferase 15|putative polypeptide N-acetylgalactosaminyltransferase-like protein 5|testis tissue sperm-binding protein Li 61n', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151956406, end_position_on_the_genomic_accession=152019929, orientation='plus', exon_count=16, OMIM=[615133], no_hdr0=''),
    168400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168400, CurrentID=0, Status='live', Symbol='DDX53', Aliases=['CAGE', 'CT26'], description='DEAD-box helicase 53', other_designations='DEAD box protein 53|DEAD (Asp-Glu-Ala-Asp) box polypeptide 53|DEAD-box protein CAGE|cancer-associated gene protein|cancer/testis antigen 26|probable ATP-dependent RNA helicase DDX53', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=22999960, end_position_on_the_genomic_accession=23003589, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    168417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168417, CurrentID=0, Status='live', Symbol='ZNF679', Aliases=[], description='zinc finger protein 679', other_designations='zinc finger protein 679|hypothetical protein MGC42415', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64228474, end_position_on_the_genomic_accession=64266931, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    168433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168433, CurrentID=0, Status='live', Symbol='RNF133', Aliases=[], description='ring finger protein 133', other_designations='E3 ubiquitin-protein ligase RNF133|RING-type E3 ubiquitin transferase RNF133', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122697735, end_position_on_the_genomic_accession=122699117, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    168448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168448, CurrentID=0, Status='live', Symbol='CDC14C', Aliases=['CDC14B2', 'CDC14Bretro'], description='cell division cycle 14C', other_designations='dual specificity protein phosphatase CDC14C|CDC14 cell division cycle 14 homolog C', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=48924547, end_position_on_the_genomic_accession=48927454, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    168451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168451, CurrentID=0, Status='live', Symbol='THAP5', Aliases=[], description='THAP domain containing 5', other_designations='THAP domain-containing protein 5', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=108562132, end_position_on_the_genomic_accession=108569768, orientation='minus', exon_count=4, OMIM=[612534], no_hdr0=''),
    168455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168455, CurrentID=0, Status='live', Symbol='CCDC71L', Aliases=['C7orf74'], description='coiled-coil domain containing 71 like', other_designations='coiled-coil domain-containing protein 71L', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=106654360, end_position_on_the_genomic_accession=106661158, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    168507 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168507, CurrentID=0, Status='live', Symbol='PKD1L1', Aliases=['HTX8', 'PRO19563'], description='polycystin 1 like 1, transient receptor potential channel interacting', other_designations='polycystic kidney disease protein 1-like 1|PC1-like 1 protein|polycystic kidney disease 1 like 1|polycystin-1L1', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=47774603, end_position_on_the_genomic_accession=47958913, orientation='minus', exon_count=59, OMIM=[609721], no_hdr0=''),
    168537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168537, CurrentID=0, Status='live', Symbol='GIMAP7', Aliases=['IAN7', 'hIAN7'], description='GTPase, IMAP family member 7', other_designations='GTPase IMAP family member 7|IAN-7|immune associated nucleotide|immune-associated nucleotide-binding protein 7|immunity-associated nucleotide 7 protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150514872, end_position_on_the_genomic_accession=150521073, orientation='plus', exon_count=2, OMIM=[616961], no_hdr0=''),
    168544 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168544, CurrentID=0, Status='live', Symbol='ZNF467', Aliases=['EZI', 'Zfp467'], description='zinc finger protein 467', other_designations='zinc finger protein 467|zinc finger protein EZI', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149764182, end_position_on_the_genomic_accession=149776323, orientation='minus', exon_count=9, OMIM=[614040], no_hdr0=''),
    168620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168620, CurrentID=0, Status='live', Symbol='BHLHA15', Aliases=['BHLHB8', 'MIST1'], description='basic helix-loop-helix family member a15', other_designations='class A basic helix-loop-helix protein 15|MIST-1|basic helix-loop-helix domain containing, class B, 8|class B basic helix-loop-helix protein 8|class II bHLH protein MIST1|muscle, intestine and stomach expression 1', map_location='7q21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98211439, end_position_on_the_genomic_accession=98215457, orientation='plus', exon_count=2, OMIM=[608606], no_hdr0=''),
    168667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168667, CurrentID=0, Status='live', Symbol='BMPER', Aliases=['CRIM3', 'CV-2', 'CV2'], description='BMP binding endothelial regulator', other_designations='BMP-binding endothelial regulator protein|BMP-binding endothelial regulator precursor protein|bone morphogenetic protein-binding endothelial cell precursor-derived regulator|crossveinless 2', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=33904915, end_position_on_the_genomic_accession=34156427, orientation='plus', exon_count=16, OMIM=[608699], no_hdr0=''),
    168850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168850, CurrentID=0, Status='live', Symbol='ZNF800', Aliases=[], description='zinc finger protein 800', other_designations='zinc finger protein 800', map_location='7q31.33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=127342871, end_position_on_the_genomic_accession=127392798, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    168975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=168975, CurrentID=0, Status='live', Symbol='CNBD1', Aliases=[], description='cyclic nucleotide binding domain containing 1', other_designations='cyclic nucleotide-binding domain-containing protein 1', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86866415, end_position_on_the_genomic_accession=87428652, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    169026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169026, CurrentID=0, Status='live', Symbol='SLC30A8', Aliases=['ZNT8', 'ZnT-8'], description='solute carrier family 30 member 8', other_designations='zinc transporter 8|solute carrier family 30 (zinc transporter), member 8|zinc transporter ZnT-8', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=116950217, end_position_on_the_genomic_accession=117176714, orientation='plus', exon_count=13, OMIM=[611145], no_hdr0=''),
    169044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169044, CurrentID=0, Status='live', Symbol='COL22A1', Aliases=[], description='collagen type XXII alpha 1 chain', other_designations='collagen alpha-1(XXII) chain', map_location='8q24.23-q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=138588235, end_position_on_the_genomic_accession=138914087, orientation='minus', exon_count=70, OMIM=[610026], no_hdr0=''),
    169166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169166, CurrentID=0, Status='live', Symbol='SNX31', Aliases=[], description='sorting nexin 31', other_designations='sorting nexin-31', map_location='8q22.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100572874, end_position_on_the_genomic_accession=100663410, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    169200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169200, CurrentID=0, Status='live', Symbol='TMEM64', Aliases=[], description='transmembrane protein 64', other_designations='transmembrane protein 64', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90621995, end_position_on_the_genomic_accession=90646083, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    169270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169270, CurrentID=0, Status='live', Symbol='ZNF596', Aliases=[], description='zinc finger protein 596', other_designations='zinc finger protein 596', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=232137, end_position_on_the_genomic_accession=247340, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    169355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169355, CurrentID=0, Status='live', Symbol='IDO2', Aliases=['INDOL1'], description='indoleamine 2,3-dioxygenase 2', other_designations='indoleamine 2,3-dioxygenase 2|indoleamine 2,3-dioxygenase-like 1 protein|indoleamine 2,3-dioxygenase-like protein 1|indoleamine-pyrrole 2,3 dioxygenase-like 1|indoleamine-pyrrole 2,3-dioxygenase-like protein 1', map_location='8p11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=39934651, end_position_on_the_genomic_accession=40016392, orientation='plus', exon_count=11, OMIM=[612129], no_hdr0=''),
    169436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169436, CurrentID=0, Status='live', Symbol='STKLD1', Aliases=['C9orf96', 'SgK071', 'Sk521'], description='serine/threonine kinase like domain containing 1', other_designations='serine/threonine kinase-like domain-containing protein STKLD1|probable inactive protein kinase-like protein SgK071|serine/threonine kinase-like domain-containing protein 1|sugen kinase 071', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133376366, end_position_on_the_genomic_accession=133406096, orientation='plus', exon_count=19, OMIM=[618530], no_hdr0=''),
    169522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169522, CurrentID=0, Status='live', Symbol='KCNV2', Aliases=['KV11.1', 'Kv8.2', 'RCD3B'], description='potassium voltage-gated channel modifier subfamily V member 2', other_designations='potassium voltage-gated channel subfamily V member 2|potassium channel, subfamily V, member 2|potassium channel, voltage gated modifier subfamily V, member 2|voltage-gated potassium channel subunit Kv8.2', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=2717510, end_position_on_the_genomic_accession=2730037, orientation='plus', exon_count=2, OMIM=[607604], no_hdr0=''),
    169611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169611, CurrentID=0, Status='live', Symbol='OLFML2A', Aliases=['PRO34319'], description='olfactomedin like 2A', other_designations='olfactomedin-like protein 2A|photomedin-1', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124777133, end_position_on_the_genomic_accession=124814885, orientation='plus', exon_count=9, OMIM=[615899], no_hdr0=''),
    169693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169693, CurrentID=0, Status='live', Symbol='TMEM252', Aliases=['C9orf71'], description='transmembrane protein 252', other_designations='transmembrane protein 252|transmembrane protein C9orf71', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68536580, end_position_on_the_genomic_accession=68540883, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    169714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169714, CurrentID=0, Status='live', Symbol='QSOX2', Aliases=['QSCN6L1', 'SOXN'], description='quiescin sulfhydryl oxidase 2', other_designations='sulfhydryl oxidase 2|neuroblastoma-derived sulfhydryl oxidase|quiescin Q6 sulfhydryl oxidase 2|quiescin Q6-like 1|quiescin Q6-like protein 1|thiol oxidase 2', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136206333, end_position_on_the_genomic_accession=136245812, orientation='minus', exon_count=12, OMIM=[612860], no_hdr0=''),
    169792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169792, CurrentID=0, Status='live', Symbol='GLIS3', Aliases=['NDH', 'ZNF515'], description='GLIS family zinc finger 3', other_designations='zinc finger protein GLIS3|GLI-similar 3|OK/KNS-cl.4|zinc finger protein 515', map_location='9p24.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=3824127, end_position_on_the_genomic_accession=4310694, orientation='minus', exon_count=19, OMIM=[610192], no_hdr0=''),
    169834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169834, CurrentID=0, Status='live', Symbol='ZNF883', Aliases=[], description='zinc finger protein 883', other_designations='zinc finger protein 883', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112997120, end_position_on_the_genomic_accession=113012192, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    169841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169841, CurrentID=0, Status='live', Symbol='ZNF169', Aliases=[], description='zinc finger protein 169', other_designations='zinc finger protein 169', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=94259298, end_position_on_the_genomic_accession=94303967, orientation='plus', exon_count=7, OMIM=[603404], no_hdr0=''),
    169966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169966, CurrentID=0, Status='live', Symbol='TENT5D', Aliases=['CT1.26', 'CT112', 'FAM46D'], description='terminal nucleotidyltransferase 5D', other_designations='terminal nucleotidyltransferase 5D|cancer/testis antigen 112|family with sequence similarity 46 member D|non-canonical poly(A) polymerase FAM46D|protein FAM46D|putative nucleotidyltransferase FAM46D', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=80335439, end_position_on_the_genomic_accession=80446885, orientation='plus', exon_count=5, OMIM=[300976], no_hdr0=''),
    169981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=169981, CurrentID=0, Status='live', Symbol='SPIN3', Aliases=['SPIN-3', 'TDRD27', 'bA445O16.1'], description='spindlin family member 3', other_designations='spindlin-3|bA445O16.1 (DXF34)|spindlin-like protein 3', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=56975120, end_position_on_the_genomic_accession=56995801, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    170062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170062, CurrentID=0, Status='live', Symbol='FAM47B', Aliases=[], description='family with sequence similarity 47 member B', other_designations='protein FAM47B', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=34942796, end_position_on_the_genomic_accession=34944915, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    170067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170067, CurrentID=0, Status='live', Symbol='SUPT20HL2', Aliases=['FAM48B1', 'FAM48B2'], description='SUPT20H like 2', other_designations='putative transcription factor SPT20 homolog-like 2|SPT20 homolog, SAGA complex component-like 2|family with sequence similarity 48, member B1|family with sequence similarity 48, member B2|putative protein FAM48B2|suppressor of Ty 20 homolog-like 2', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24308210, end_position_on_the_genomic_accession=24314069, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    170082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170082, CurrentID=0, Status='live', Symbol='TCEANC', Aliases=[], description='transcription elongation factor A N-terminal and central domain containing', other_designations='transcription elongation factor A N-terminal and central domain-containing protein|TFIIS central domain-containing protein 1|TFS2-M domain-containing protein 1|transcription elongation factor A (SII) N-terminal and central domain containing', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13653110, end_position_on_the_genomic_accession=13665409, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    170261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170261, CurrentID=0, Status='live', Symbol='ZCCHC12', Aliases=['PNMA7A', 'SIZN', 'SIZN1'], description='zinc finger CCHC-type containing 12', other_designations='zinc finger CCHC domain-containing protein 12|paraneoplastic Ma antigen family member 7A|smad-interacting zinc finger protein 1|zinc finger, CCHC domain containing 12', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=118823824, end_position_on_the_genomic_accession=118826968, orientation='plus', exon_count=4, OMIM=[300701], no_hdr0=''),
    170302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170302, CurrentID=0, Status='live', Symbol='ARX', Aliases=['CT121', 'EIEE1', 'ISSX', 'MRX29', 'MRX32', 'MRX33', 'MRX36', 'MRX38', 'MRX43', 'MRX54', 'MRX76', 'MRX87', 'MRXS1', 'PRTS'], description='aristaless related homeobox', other_designations='homeobox protein ARX|aristaless-related homeobox, X-linked|cancer/testis antigen 121', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=25003694, end_position_on_the_genomic_accession=25015965, orientation='minus', exon_count=5, OMIM=[300382], no_hdr0=''),
    170370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170370, CurrentID=0, Status='live', Symbol='FAM170B', Aliases=['C10orf73'], description='family with sequence similarity 170 member B', other_designations='protein FAM170B|acrosome-related protein|putative protein FAM170B', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49131154, end_position_on_the_genomic_accession=49134021, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    170371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170371, CurrentID=0, Status='live', Symbol='TMEM273', Aliases=['C10orf128'], description='transmembrane protein 273', other_designations='transmembrane protein 273', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49154728, end_position_on_the_genomic_accession=49188580, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    170384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170384, CurrentID=0, Status='live', Symbol='FUT11', Aliases=['FUCTXI'], description='fucosyltransferase 11', other_designations='alpha-(1,3)-fucosyltransferase 11|alpha (1,3) fucosyltransferase|fuc-TXI|fucT-XI|fucosyltransferase XI|galactoside 3-L-fucosyltransferase 11', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73772276, end_position_on_the_genomic_accession=73779104, orientation='plus', exon_count=4, OMIM=[616932], no_hdr0=''),
    170392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170392, CurrentID=0, Status='live', Symbol='OIT3', Aliases=['LZP'], description='oncoprotein induced transcript 3', other_designations='oncoprotein-induced transcript 3 protein|liver-specific ZP domain-containing protein|liver-specific zona pellucida domain-containing protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=72893739, end_position_on_the_genomic_accession=72933036, orientation='plus', exon_count=9, OMIM=[609330], no_hdr0=''),
    170394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170394, CurrentID=0, Status='live', Symbol='PWWP2B', Aliases=['PWWP2', 'bA432J24.1', 'pp8607'], description='PWWP domain containing 2B', other_designations='PWWP domain-containing protein 2B|PWWP domain containing 2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132397196, end_position_on_the_genomic_accession=132417863, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    170463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170463, CurrentID=0, Status='live', Symbol='SSBP4', Aliases=[], description='single stranded DNA binding protein 4', other_designations='single-stranded DNA-binding protein 4', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=18418719, end_position_on_the_genomic_accession=18434562, orientation='plus', exon_count=20, OMIM=[607391], no_hdr0=''),
    170482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170482, CurrentID=0, Status='live', Symbol='CLEC4C', Aliases=['BDCA-2', 'BDCA2', 'CD303', 'CLECSF11', 'CLECSF7', 'DLEC', 'HECL', 'PRO34150'], description='C-type lectin domain family 4 member C', other_designations='C-type lectin domain family 4 member C|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 11|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 7|C-type lectin superfamily member 7|blood dendritic cell antigen 2 protein|dendritic cell lectin b|dendritic lectin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7729245, end_position_on_the_genomic_accession=7751600, orientation='minus', exon_count=8, OMIM=[606677], no_hdr0=''),
    170487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170487, CurrentID=0, Status='live', Symbol='ACTL10', Aliases=['C20orf134', 'dJ63M2.2'], description='actin like 10', other_designations='actin-like protein 10', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33666943, end_position_on_the_genomic_accession=33668525, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    170506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170506, CurrentID=0, Status='live', Symbol='DHX36', Aliases=['DDX36', 'G4R1', 'MLEL1', 'RHAU'], description='DEAH-box helicase 36', other_designations='ATP-dependent DNA/RNA helicase DHX36|ATP-dependent RNA helicase DHX36|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 36|DEAD/H box polypeptide 36|DEAH (Asp-Glu-Ala-His) box polypeptide 36|DEAH box protein 36|G4 resolvase-1|MLE-like protein 1|RNA helicase associated with AU-rich element ARE|RNA helicase associated with AU-rich element protein|probable ATP-dependent RNA helicase DHX36', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=154272546, end_position_on_the_genomic_accession=154324487, orientation='minus', exon_count=25, OMIM=[612767], no_hdr0=''),
    170572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170572, CurrentID=0, Status='live', Symbol='HTR3C', Aliases=[], description='5-hydroxytryptamine receptor 3C', other_designations='5-hydroxytryptamine receptor 3C|5-HT3-C|5-HT3C|5-hydroxytryptamine (serotonin) receptor 3, family member C|5-hydroxytryptamine (serotonin) receptor 3C, ionotropic|5-hydroxytryptamine receptor 3 subunit C|serotonin receptor 3C', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184053047, end_position_on_the_genomic_accession=184060673, orientation='plus', exon_count=9, OMIM=[610121], no_hdr0=''),
    170575 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170575, CurrentID=0, Status='live', Symbol='GIMAP1', Aliases=['HIMAP1', 'IAN2', 'IMAP1', 'IMAP38'], description='GTPase, IMAP family member 1', other_designations='GTPase IMAP family member 1|immune-associated nucleotide-binding protein 2|immunity associated protein 1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150716613, end_position_on_the_genomic_accession=150724284, orientation='plus', exon_count=3, OMIM=[608084], no_hdr0=''),
    170589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170589, CurrentID=0, Status='live', Symbol='GPHA2', Aliases=['A2', 'GPA2', 'ZSIG51'], description='glycoprotein hormone subunit alpha 2', other_designations='glycoprotein hormone alpha-2|cysteine knot protein|glycoprotein alpha 2|glycoprotein hormone alpha 2|putative secreted protein Zsig51|thyrostimulin subunit alpha', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64934471, end_position_on_the_genomic_accession=64938131, orientation='minus', exon_count=6, OMIM=[609651], no_hdr0=''),
    170591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170591, CurrentID=0, Status='live', Symbol='S100Z', Aliases=['Gm625', 'S100-zeta'], description='S100 calcium binding protein Z', other_designations='protein S100-Z|S100 calcium binding protein, zeta', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=76849953, end_position_on_the_genomic_accession=76952882, orientation='plus', exon_count=11, OMIM=[610103], no_hdr0=''),
    170622 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170622, CurrentID=0, Status='live', Symbol='COMMD6', Aliases=['Acrg'], description='COMM domain containing 6', other_designations='COMM domain-containing protein 6|Acrg embryonic lethality minimal region ortholog', map_location='13q22.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=75525214, end_position_on_the_genomic_accession=75549439, orientation='minus', exon_count=6, OMIM=[612377], no_hdr0=''),
    170626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170626, CurrentID=0, Status='live', Symbol='XAGE3', Aliases=['CT12.3a', 'CT12.3b', 'GAGED4', 'PLAC6', 'XAGE-3', 'pp9012'], description='X antigen family member 3', other_designations='X antigen family member 3|CT12.3|G antigen, family D, 4|cancer/testis antigen 12.3|cancer/testis antigen family 12, member 3a|cancer/testis antigen family 12, member 3b|g antigen family D member 4|placenta-specific 6|placenta-specific gene 6 protein|protein XAGE-3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52862528, end_position_on_the_genomic_accession=52868140, orientation='minus', exon_count=7, OMIM=[300740], no_hdr0=''),
    170627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170627, CurrentID=0, Status='live', Symbol='XAGE5', Aliases=['CT12.5', 'GAGED5', 'XAGE-5'], description='X antigen family member 5', other_designations='X antigen family member 5|G antigen, family D, 5|cancer/testis antigen 12.5|cancer/testis antigen family 12, member 5|g antigen family D member 5|protein XAGE-5', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52811287, end_position_on_the_genomic_accession=52818301, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    170679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170679, CurrentID=0, Status='live', Symbol='PSORS1C1', Aliases=['C6orf16', 'SEEK1'], description='psoriasis susceptibility 1 candidate 1', other_designations='psoriasis susceptibility 1 candidate gene 1 protein|epididymis secretory sperm binding protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31114800, end_position_on_the_genomic_accession=31140092, orientation='plus', exon_count=6, OMIM=[613525], no_hdr0=''),
    170680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170680, CurrentID=0, Status='live', Symbol='PSORS1C2', Aliases=['C6orf17', 'SPR1'], description='psoriasis susceptibility 1 candidate 2', other_designations='psoriasis susceptibility 1 candidate gene 2 protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31137534, end_position_on_the_genomic_accession=31139066, orientation='minus', exon_count=2, OMIM=[613526], no_hdr0=''),
    170685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170685, CurrentID=0, Status='live', Symbol='NUDT10', Aliases=['APS2', 'DIPP3-alpha', 'DIPP3a'], description='nudix hydrolase 10', other_designations="diphosphoinositol polyphosphate phosphohydrolase 3-alpha|diadenosine 5',5'''-P1,P6-hexaphosphate hydrolase 3-alpha|diadenosine hexaphosphate hydrolase (AMP-forming)|nucleoside diphosphate-linked moiety X motif 10|nudix (nucleoside diphosphate linked moiety X)-type motif 10|nudix motif 10", map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51332231, end_position_on_the_genomic_accession=51337525, orientation='plus', exon_count=3, OMIM=[300527], no_hdr0=''),
    170689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170689, CurrentID=0, Status='live', Symbol='ADAMTS15', Aliases=[], description='ADAM metallopeptidase with thrombospondin type 1 motif 15', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 15|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 15, preproprotein|metalloprotease disintegrin 15 with thrombospondin domains', map_location='11q24.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130448645, end_position_on_the_genomic_accession=130478215, orientation='plus', exon_count=10, OMIM=[607509], no_hdr0=''),
    170690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170690, CurrentID=0, Status='live', Symbol='ADAMTS16', Aliases=['ADAMTS16s'], description='ADAM metallopeptidase with thrombospondin type 1 motif 16', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 16|ADAM-TS 16|ADAM-TS16|ADAMTS-16|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 16', map_location='5p15.32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=5140330, end_position_on_the_genomic_accession=5320304, orientation='plus', exon_count=23, OMIM=[607510], no_hdr0=''),
    170691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170691, CurrentID=0, Status='live', Symbol='ADAMTS17', Aliases=['WMS4'], description='ADAM metallopeptidase with thrombospondin type 1 motif 17', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 17|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 17', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=99971437, end_position_on_the_genomic_accession=100342924, orientation='minus', exon_count=32, OMIM=[607511], no_hdr0=''),
    170692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170692, CurrentID=0, Status='live', Symbol='ADAMTS18', Aliases=['ADAMTS21', 'KNO2', 'MMCAT'], description='ADAM metallopeptidase with thrombospondin type 1 motif 18', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 18|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 18|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 21|disintegrin and metalloprotease-like protein', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77282128, end_position_on_the_genomic_accession=77435034, orientation='minus', exon_count=23, OMIM=[607512], no_hdr0=''),
    170712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170712, CurrentID=0, Status='live', Symbol='COX7B2', Aliases=[], description='cytochrome c oxidase subunit 7B2', other_designations='cytochrome c oxidase subunit 7B2, mitochondrial|cytochrome c oxidase polypeptide VIIb2|cytochrome c oxidase subunit VIIb2', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=46734827, end_position_on_the_genomic_accession=46909266, orientation='minus', exon_count=8, OMIM=[609811], no_hdr0=''),
    170825 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170825, CurrentID=0, Status='live', Symbol='GSX2', Aliases=['DMJDS2', 'GSH2'], description='GS homeobox 2', other_designations='GS homeobox 2|genetic-screened homeobox 2|homeobox protein GSH-2', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=54100163, end_position_on_the_genomic_accession=54102498, orientation='plus', exon_count=2, OMIM=[616253], no_hdr0=''),
    170850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170850, CurrentID=0, Status='live', Symbol='KCNG3', Aliases=['KV10.1', 'KV6.3'], description='potassium voltage-gated channel modifier subfamily G member 3', other_designations='potassium voltage-gated channel subfamily G member 3|potassium channel, voltage gated modifier subfamily G, member 3|potassium voltage-gated channel, subfamily G, member 3|voltage-gated potassium channel 6.3|voltage-gated potassium channel Kv10.1|voltage-gated potassium channel subunit Kv10.1|voltage-gated potassium channel subunit Kv6.3|voltage-gated potassium channel subunit Kv6.4', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=42442017, end_position_on_the_genomic_accession=42493982, orientation='minus', exon_count=2, OMIM=[606767], no_hdr0=''),
    170954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170954, CurrentID=0, Status='live', Symbol='PPP1R18', Aliases=['HKMT1098', 'KIAA1949'], description='protein phosphatase 1 regulatory subunit 18', other_designations='phostensin|protein phosphatase 1 F-actin cytoskeleton targeting subunit', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30676389, end_position_on_the_genomic_accession=30687207, orientation='minus', exon_count=4, OMIM=[610990], no_hdr0=''),
    170958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170958, CurrentID=0, Status='live', Symbol='ZNF525', Aliases=[], description='zinc finger protein 525', other_designations='zinc finger protein 525', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53365705, end_position_on_the_genomic_accession=53386590, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    170959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170959, CurrentID=0, Status='live', Symbol='ZNF431', Aliases=[], description='zinc finger protein 431', other_designations='zinc finger protein 431', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21142009, end_position_on_the_genomic_accession=21196053, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    170960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170960, CurrentID=0, Status='live', Symbol='ZNF721', Aliases=[], description='zinc finger protein 721', other_designations='zinc finger protein 721', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=439988, end_position_on_the_genomic_accession=499156, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    170961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=170961, CurrentID=0, Status='live', Symbol='ANKRD24', Aliases=[], description='ankyrin repeat domain 24', other_designations='ankyrin repeat domain-containing protein 24', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4182618, end_position_on_the_genomic_accession=4224814, orientation='plus', exon_count=31, OMIM=[], no_hdr0=''),
    171017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171017, CurrentID=0, Status='live', Symbol='ZNF384', Aliases=['CAGH1', 'CAGH1A', 'CIZ', 'ERDA2', 'NMP4', 'NP', 'TNRC1'], description='zinc finger protein 384', other_designations='zinc finger protein 384|CAG repeat protein 1|Cas-interacting zinc finger protein|expanded repeat domain, CAG/CTG 2|nuclear matrix transcription factor 4|trinucleotide repeat-containing gene 1 protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6666477, end_position_on_the_genomic_accession=6689572, orientation='minus', exon_count=17, OMIM=[609951], no_hdr0=''),
    171019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171019, CurrentID=0, Status='live', Symbol='ADAMTS19', Aliases=[], description='ADAM metallopeptidase with thrombospondin type 1 motif 19', other_designations='A disintegrin and metalloproteinase with thrombospondin motifs 19|a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif, 19', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=129460281, end_position_on_the_genomic_accession=129738683, orientation='plus', exon_count=26, OMIM=[607513], no_hdr0=''),
    171023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171023, CurrentID=0, Status='live', Symbol='ASXL1', Aliases=['BOPS', 'MDS'], description='ASXL transcriptional regulator 1', other_designations='polycomb group protein ASXL1|additional sex combs like 1, transcriptional regulator|additional sex combs like transcriptional regulator 1|putative Polycomb group protein ASXL1', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32358062, end_position_on_the_genomic_accession=32439319, orientation='plus', exon_count=18, OMIM=[612990], no_hdr0=''),
    171024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171024, CurrentID=0, Status='live', Symbol='SYNPO2', Aliases=[], description='synaptopodin 2', other_designations='synaptopodin-2|genethonin-2|myopodin', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=118850681, end_position_on_the_genomic_accession=119061247, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    171169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171169, CurrentID=0, Status='live', Symbol='SPACA4', Aliases=['SAMP14'], description='sperm acrosome associated 4', other_designations='sperm acrosome membrane-associated protein 4|sperm acrosomal membrane protein 14|sperm acrosomal membrane-associated protein 14|testicular tissue protein Li 167', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48606742, end_position_on_the_genomic_accession=48607714, orientation='plus', exon_count=1, OMIM=[609932], no_hdr0=''),
    171177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171177, CurrentID=0, Status='live', Symbol='RHOV', Aliases=['ARHV', 'CHP', 'WRCH2'], description='ras homolog family member V', other_designations='rho-related GTP-binding protein RhoV|CDC42-like GTPase 2|GTP-binding protein-like 2|Rho GTPase-like protein ARHV|WRCH-2|WRCH1-related GTPase|Wnt-1 regulated Cdc42 homolog 2|Wnt-1 responsive Cdc42 homolog 2|ras homolog gene family, member V', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40872214, end_position_on_the_genomic_accession=40874234, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    171222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171222, CurrentID=0, Status='live', Symbol='UBE2L5', Aliases=['UBCH7N2P', 'UBE2L5'], description='ubiquitin conjugating enzyme E2 L5', other_designations='ubiquitin-conjugating enzyme E2 L5|ubiquitin-protein ligase L5', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=30422493, end_position_on_the_genomic_accession=30429758, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    171389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171389, CurrentID=0, Status='live', Symbol='NLRP6', Aliases=['AVR', 'CLR11.4', 'NALP6', 'NAVR', 'NAVR/AVR', 'PAN3', 'PYPAF5'], description='NLR family pyrin domain containing 6', other_designations='NACHT, LRR and PYD domains-containing protein 6|NACHT, leucine rich repeat and PYD containing 6|PYRIN-containing APAF1-like protein 5|angiotensin II/vasopressin receptor|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 6', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=278365, end_position_on_the_genomic_accession=285942, orientation='plus', exon_count=9, OMIM=[609650], no_hdr0=''),
    171392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171392, CurrentID=0, Status='live', Symbol='ZNF675', Aliases=['TBZF', 'TIZ'], description='zinc finger protein 675', other_designations='zinc finger protein 675|TRAF6 inhibitory zinc finger|TRAF6-binding zinc finger protein|TRAF6-inhibitory zinc finger protein', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23652801, end_position_on_the_genomic_accession=23687212, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    171425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171425, CurrentID=0, Status='live', Symbol='CLYBL', Aliases=['CLB'], description='citramalyl-CoA lyase', other_designations='citramalyl-CoA lyase, mitochondrial|(3S)-malyl-CoA thioesterase|beta-methylmalate synthase|citrate lyase beta like|citrate lyase subunit beta-like protein, mitochondrial|malate synthase', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99606690, end_position_on_the_genomic_accession=99909444, orientation='plus', exon_count=12, OMIM=[609686], no_hdr0=''),
    171482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171482, CurrentID=0, Status='live', Symbol='FAM9A', Aliases=['TEX39A'], description='family with sequence similarity 9 member A', other_designations='protein FAM9A|testis expressed 39A', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=8790795, end_position_on_the_genomic_accession=8801383, orientation='minus', exon_count=10, OMIM=[300477], no_hdr0=''),
    171483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171483, CurrentID=0, Status='live', Symbol='FAM9B', Aliases=['TEX39B'], description='family with sequence similarity 9 member B', other_designations='protein FAM9B|testis expressed 39B', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=9024232, end_position_on_the_genomic_accession=9034127, orientation='minus', exon_count=10, OMIM=[300478], no_hdr0=''),
    171484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171484, CurrentID=0, Status='live', Symbol='FAM9C', Aliases=['TEX39C'], description='family with sequence similarity 9 member C', other_designations='protein FAM9C|testis expressed 39C', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=13035617, end_position_on_the_genomic_accession=13044793, orientation='minus', exon_count=9, OMIM=[300479], no_hdr0=''),
    171546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171546, CurrentID=0, Status='live', Symbol='SPTSSA', Aliases=['C14orf147', 'SSSPTA'], description='serine palmitoyltransferase small subunit A', other_designations='serine palmitoyltransferase small subunit A|small subunit of serine palmitoyltransferase A', map_location='14q13.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=34432788, end_position_on_the_genomic_accession=34462240, orientation='minus', exon_count=2, OMIM=[613540], no_hdr0=''),
    171558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171558, CurrentID=0, Status='live', Symbol='PTCRA', Aliases=['PT-ALPHA', 'PTA'], description='pre T cell antigen receptor alpha', other_designations='pre T-cell antigen receptor alpha|pT-alpha-TCR|pre-T-cell receptor alpha chain', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42915597, end_position_on_the_genomic_accession=42925838, orientation='plus', exon_count=6, OMIM=[606817], no_hdr0=''),
    171568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171568, CurrentID=0, Status='live', Symbol='POLR3H', Aliases=['C25', 'RPC22.9', 'RPC8'], description='RNA polymerase III subunit H', other_designations='DNA-directed RNA polymerase III subunit RPC8|DNA-directed RNA polymerase III subunit 22.9 kDa polypeptide|DNA-directed RNA polymerase III subunit H|RNA nucleotidyltransferase (DNA-directed)|RNA polymerase III subunit C8|polymerase (RNA) III (DNA directed) polypeptide H (22.9kD)|polymerase (RNA) III subunit H', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41525799, end_position_on_the_genomic_accession=41544606, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    171586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=171586, CurrentID=0, Status='live', Symbol='ABHD3', Aliases=['LABH3'], description='abhydrolase domain containing 3, phospholipase', other_designations='phospholipase ABHD3|abhydrolase domain-containing protein 3|alpha/beta hydrolase domain containing protein 3|lung alpha/beta hydrolase 3', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=21650901, end_position_on_the_genomic_accession=21704793, orientation='minus', exon_count=12, OMIM=[612197], no_hdr0=''),
    192111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192111, CurrentID=0, Status='live', Symbol='PGAM5', Aliases=['BXLBV68'], description='PGAM family member 5, mitochondrial serine/threonine protein phosphatase', other_designations='serine/threonine-protein phosphatase PGAM5, mitochondrial|Bcl-XL-binding protein v68|PGAM family member 5, serine/threonine protein phosphatase, mitochondrial|phosphoglycerate mutase family member 5', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132710842, end_position_on_the_genomic_accession=132722734, orientation='plus', exon_count=7, OMIM=[614939], no_hdr0=''),
    192134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192134, CurrentID=0, Status='live', Symbol='B3GNT6', Aliases=['B3Gn-T6', 'BGnT-6', 'beta-1', '3-Gn-T6', 'beta3Gn-T6'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 6', other_designations='acetylgalactosaminyl-O-glycosyl-glycoprotein beta-1,3-N-acetylglucosaminyltransferase|beta-1,3-N-acetylglucosaminyltransferase 6|beta-1,3-N-acetylglucosaminyltransferase protein|core 3 synthase', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77034398, end_position_on_the_genomic_accession=77041973, orientation='plus', exon_count=2, OMIM=[615315], no_hdr0=''),
    192286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192286, CurrentID=0, Status='live', Symbol='HIGD2A', Aliases=['RCF1b'], description='HIG1 hypoxia inducible domain family member 2A', other_designations='HIG1 domain family member 2A, mitochondrial|HIG1 domain family, member 2A|RCF1 homolog B', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176388751, end_position_on_the_genomic_accession=176389761, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    192666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192666, CurrentID=0, Status='live', Symbol='KRT24', Aliases=['K24', 'KA24'], description='keratin 24', other_designations='keratin, type I cytoskeletal 24|CK-24|cytokeratin-24|keratin 24, type I|type I keratin-24', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40694246, end_position_on_the_genomic_accession=40703752, orientation='minus', exon_count=9, OMIM=[607742], no_hdr0=''),
    192668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192668, CurrentID=0, Status='live', Symbol='CYS1', Aliases=[], description='cystin 1', other_designations='cystin-1|cilia-associated protein', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10056473, end_position_on_the_genomic_accession=10080411, orientation='minus', exon_count=3, OMIM=[618713], no_hdr0=''),
    192669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192669, CurrentID=0, Status='live', Symbol='AGO3', Aliases=['EIF2C3'], description='argonaute RISC catalytic component 3', other_designations='protein argonaute-3|argonaute 3, RISC catalytic component|eukaryotic translation initiation factor 2C, 3|hAgo3', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35925683, end_position_on_the_genomic_accession=36072500, orientation='plus', exon_count=25, OMIM=[607355], no_hdr0=''),
    192670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192670, CurrentID=0, Status='live', Symbol='AGO4', Aliases=['EIF2C4'], description='argonaute RISC component 4', other_designations='protein argonaute-4|argonaute 4, RISC catalytic component|argonaute RISC catalytic component 4|eukaryotic translation initiation factor 2C, 4', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35807630, end_position_on_the_genomic_accession=35857890, orientation='plus', exon_count=22, OMIM=[607356], no_hdr0=''),
    192683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=192683, CurrentID=0, Status='live', Symbol='SCAMP5', Aliases=[], description='secretory carrier membrane protein 5', other_designations='secretory carrier-associated membrane protein 5|hSCAMP5', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74995562, end_position_on_the_genomic_accession=75021495, orientation='plus', exon_count=11, OMIM=[613766], no_hdr0=''),
    195814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=195814, CurrentID=0, Status='live', Symbol='SDR16C5', Aliases=['EPHD-2', 'RDH#2', 'RDH-E2', 'RDHE2', 'retSDR2'], description='short chain dehydrogenase/reductase family 16C member 5', other_designations='epidermal retinol dehydrogenase 2|epidermal retinal dehydrogenase 2|retinal short chain dehydrogenase reductase|retinal short-chain dehydrogenase reductase 2', map_location='8q12.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=56300005, end_position_on_the_genomic_accession=56320560, orientation='minus', exon_count=8, OMIM=[608989], no_hdr0=''),
    195827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=195827, CurrentID=0, Status='live', Symbol='PRXL2C', Aliases=['AAED1', 'C9orf21'], description='peroxiredoxin like 2C', other_designations='peroxiredoxin-like 2C|AhpC/TSA antioxidant enzyme domain containing 1|UPF0308 protein C9orf21|ahpC/TSA antioxidant enzyme domain-containing protein 1|thioredoxin-like protein AAED1', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96639577, end_position_on_the_genomic_accession=96655331, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    195828 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=195828, CurrentID=0, Status='live', Symbol='ZNF367', Aliases=['AFF29', 'CDC14B', 'ZFF29'], description='zinc finger protein 367', other_designations='zinc finger protein 367|C2H2 zinc finger protein ZFF29|C2H2 zinc finger protein ZFF29a|CDC14 cell division cycle 14 homolog B', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96385941, end_position_on_the_genomic_accession=96418639, orientation='minus', exon_count=6, OMIM=[610160], no_hdr0=''),
    195977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=195977, CurrentID=0, Status='live', Symbol='ANTXRL', Aliases=[], description='ANTXR like', other_designations='anthrax toxin receptor-like|anthrax toxin receptor like', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46286997, end_position_on_the_genomic_accession=46330419, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    196051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196051, CurrentID=0, Status='live', Symbol='PLPP4', Aliases=['DPPL2', 'PPAPDC1', 'PPAPDC1A'], description='phospholipid phosphatase 4', other_designations='phospholipid phosphatase 4|diacylglycerol pyrophosphate like 2|diacylglycerol pyrophosphate phosphatase-like 2|phosphatidate phosphatase PPAPDC1A|phosphatidic acid phosphatase type 2 domain containing 1A|phosphatidic acid phosphatase type 2 domain-containing protein 1A', map_location='10q26.12', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=120456954, end_position_on_the_genomic_accession=120600123, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    196074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196074, CurrentID=0, Status='live', Symbol='METTL15', Aliases=['METT5D1'], description='methyltransferase like 15', other_designations='12S rRNA N4-methylcytidine (m4C) methyltransferase|12S rRNA m4C methyltransferase|methyltransferase 5 domain containing 1|methyltransferase 5 domain-containing protein 1|methyltransferase-like protein 15|probable S-adenosyl-L-methionine-dependent methyltransferase METT5D1|probable methyltransferase-like protein 15|putative S-adenosyl-L-methionine-dependent methyltransferase METT5D1', map_location='11p14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=28108251, end_position_on_the_genomic_accession=28527041, orientation='plus', exon_count=19, OMIM=[618711], no_hdr0=''),
    196264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196264, CurrentID=0, Status='live', Symbol='MPZL3', Aliases=[], description='myelin protein zero like 3', other_designations='myelin protein zero-like protein 3', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118226690, end_position_on_the_genomic_accession=118252365, orientation='minus', exon_count=8, OMIM=[611707], no_hdr0=''),
    196294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196294, CurrentID=0, Status='live', Symbol='IMMP1L', Aliases=['IMMP1', 'IMP1', 'IMP1-LIKE'], description='inner mitochondrial membrane peptidase subunit 1', other_designations='mitochondrial inner membrane protease subunit 1|IMP1 inner mitochondrial membrane peptidase-like', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=31432401, end_position_on_the_genomic_accession=31509644, orientation='minus', exon_count=11, OMIM=[612323], no_hdr0=''),
    196335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196335, CurrentID=0, Status='live', Symbol='OR56B4', Aliases=['OR11-67'], description='olfactory receptor family 56 subfamily B member 4', other_designations='olfactory receptor 56B4|olfactory receptor OR11-67', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6107684, end_position_on_the_genomic_accession=6108835, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    196374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196374, CurrentID=0, Status='live', Symbol='KRT78', Aliases=['CK-78', 'K5B', 'K78', 'Kb40'], description='keratin 78', other_designations='keratin, type II cytoskeletal 78|cytokeratin-78|keratin 78, type II|keratin-5b|type-II keratin Kb40', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52837804, end_position_on_the_genomic_accession=52848994, orientation='minus', exon_count=10, OMIM=[611159], no_hdr0=''),
    196383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196383, CurrentID=0, Status='live', Symbol='RILPL2', Aliases=['RLP2'], description='Rab interacting lysosomal protein like 2', other_designations='RILP-like protein 2|p40phox-binding protein|rab-interacting lysosomal protein-like 2', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123409890, end_position_on_the_genomic_accession=123436684, orientation='minus', exon_count=5, OMIM=[614093], no_hdr0=''),
    196385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196385, CurrentID=0, Status='live', Symbol='DNAH10', Aliases=[], description='dynein axonemal heavy chain 10', other_designations='dynein axonemal heavy chain 10|dynein heavy chain 10, axonemal|axonemal beta dynein heavy chain 10|ciliary dynein heavy chain 10|dynein, axonemal, heavy polypeptide 10', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123761995, end_position_on_the_genomic_accession=123935720, orientation='plus', exon_count=79, OMIM=[605884], no_hdr0=''),
    196394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196394, CurrentID=0, Status='live', Symbol='AMN1', Aliases=[], description='antagonist of mitotic exit network 1 homolog', other_designations='protein AMN1 homolog', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31671137, end_position_on_the_genomic_accession=31729174, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    196403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196403, CurrentID=0, Status='live', Symbol='DTX3', Aliases=['RNF154', 'deltex3'], description='deltex E3 ubiquitin ligase 3', other_designations='probable E3 ubiquitin-protein ligase DTX3|RING finger protein 154|RING-type E3 ubiquitin transferase DTX3|deltex 3, E3 ubiquitin ligase|deltex homolog 3|protein deltex-3', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57604327, end_position_on_the_genomic_accession=57609802, orientation='plus', exon_count=8, OMIM=[613142], no_hdr0=''),
    196410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196410, CurrentID=0, Status='live', Symbol='METTL7B', Aliases=['ALDI'], description='methyltransferase like 7B', other_designations='methyltransferase-like protein 7B|associated with lipid droplets 1', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55681736, end_position_on_the_genomic_accession=55684611, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    196441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196441, CurrentID=0, Status='live', Symbol='ZFC3H1', Aliases=['CCDC131', 'CSRC2', 'PSRC2'], description='zinc finger C3H1-type containing', other_designations='zinc finger C3H1 domain-containing protein|coiled-coil domain containing 131|coiled-coil domain-containing protein 131|proline/serine-rich coiled-coil 2|proline/serine-rich coiled-coil protein 2', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=71609599, end_position_on_the_genomic_accession=71663848, orientation='minus', exon_count=35, OMIM=[], no_hdr0=''),
    196446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196446, CurrentID=0, Status='live', Symbol='MYRFL', Aliases=['C12orf15', 'C12orf28', 'bcm1377'], description='myelin regulatory factor like', other_designations='myelin regulatory factor-like protein', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69824518, end_position_on_the_genomic_accession=69959097, orientation='plus', exon_count=31, OMIM=[], no_hdr0=''),
    196463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196463, CurrentID=0, Status='live', Symbol='PLBD2', Aliases=['P76'], description='phospholipase B domain containing 2', other_designations='putative phospholipase B-like 2|76 kDa protein|LAMA-like protein 2|PLB homolog 2|lamina ancestor homolog 2|mannose-6-phosphate protein associated protein p76|phospholipase B domain-containing protein 2|phospholipase B-like 2 32 kDa form|phospholipase B-like 2 45 kDa form', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113358576, end_position_on_the_genomic_accession=113391629, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    196472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196472, CurrentID=0, Status='live', Symbol='FAM71C', Aliases=[], description='family with sequence similarity 71 member C', other_designations='protein FAM71C', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=99647753, end_position_on_the_genomic_accession=99650114, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    196477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196477, CurrentID=0, Status='live', Symbol='CCER1', Aliases=['C12orf12'], description='coiled-coil glutamate rich protein 1', other_designations='coiled-coil domain-containing glutamate-rich protein 1', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=90952215, end_position_on_the_genomic_accession=90955176, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    196483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196483, CurrentID=0, Status='live', Symbol='EEF2KMT', Aliases=['EFM3', 'FAM86A', 'SB153', 'eEF2-KMT'], description='eukaryotic elongation factor 2 lysine methyltransferase', other_designations='protein-lysine N-methyltransferase EEF2KMT|eEF2-lysine methyltransferase|family with sequence similarity 86, member A|protein FAM86A|putative protein N-methyltransferase FAM86A', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=5084284, end_position_on_the_genomic_accession=5097795, orientation='minus', exon_count=9, OMIM=[615263], no_hdr0=''),
    196500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196500, CurrentID=0, Status='live', Symbol='PIANP', Aliases=['C12orf53', 'LEDA1', 'PANP', 'leda-1'], description='PILR alpha associated neural protein', other_designations='PILR alpha-associated neural protein|PILR-associating neural protein|liver endothelial differentiation-associated protein-1|paired immunoglobin-like type 2 receptor-associating neural protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=6689705, end_position_on_the_genomic_accession=6700815, orientation='minus', exon_count=8, OMIM=[616065], no_hdr0=''),
    196513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196513, CurrentID=0, Status='live', Symbol='DCP1B', Aliases=['DCP1'], description='decapping mRNA 1B', other_designations='mRNA-decapping enzyme 1B|DCP1 decapping enzyme homolog B|decapping enzyme hDcp1b', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1941591, end_position_on_the_genomic_accession=2004457, orientation='minus', exon_count=11, OMIM=[609843], no_hdr0=''),
    196527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196527, CurrentID=0, Status='live', Symbol='ANO6', Aliases=['BDPLT7', 'SCTS', 'TMEM16F'], description='anoctamin 6', other_designations='anoctamin-6|SCAN channel|small-conductance calcium-activated nonselective cation channel|transmembrane protein 16F', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=45216033, end_position_on_the_genomic_accession=45440404, orientation='plus', exon_count=23, OMIM=[608663], no_hdr0=''),
    196528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196528, CurrentID=0, Status='live', Symbol='ARID2', Aliases=['BAF200', 'CSS6', 'p200'], description='AT-rich interaction domain 2', other_designations='AT-rich interactive domain-containing protein 2|ARID domain-containing protein 2|AT rich interactive domain 2 (ARID, RFX-like)|BRG1-associated factor 200|zinc finger protein with activation potential|zipzap/p200', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=45729706, end_position_on_the_genomic_accession=45908037, orientation='plus', exon_count=24, OMIM=[609539], no_hdr0=''),
    196541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196541, CurrentID=0, Status='live', Symbol='METTL21C', Aliases=['C13orf39'], description='methyltransferase 21C, AARS1 lysine', other_designations='protein-lysine methyltransferase METTL21C|methyltransferase like 21C|methyltransferase-like protein 21C', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102678782, end_position_on_the_genomic_accession=102704311, orientation='minus', exon_count=5, OMIM=[615259], no_hdr0=''),
    196740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196740, CurrentID=0, Status='live', Symbol='VSTM4', Aliases=['C10orf72'], description='V-set and transmembrane domain containing 4', other_designations='V-set and transmembrane domain-containing protein 4', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49014236, end_position_on_the_genomic_accession=49129118, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    196743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196743, CurrentID=0, Status='live', Symbol='PAOX', Aliases=['PAO'], description='polyamine oxidase', other_designations='peroxisomal N(1)-acetyl-spermine/spermidine oxidase|peroxisomal N1-acetyl-spermine/spermidine oxidase|polyamine oxidase (exo-N4-amino)', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133379262, end_position_on_the_genomic_accession=133391694, orientation='plus', exon_count=8, OMIM=[615853], no_hdr0=''),
    196792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196792, CurrentID=0, Status='live', Symbol='FAM24B', Aliases=[], description='family with sequence similarity 24 member B', other_designations='protein FAM24B', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122849078, end_position_on_the_genomic_accession=122879641, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    196883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196883, CurrentID=0, Status='live', Symbol='ADCY4', Aliases=['AC4'], description='adenylate cyclase 4', other_designations='adenylate cyclase type 4|ATP pyrophosphate-lyase 4|adenylate cyclase type IV|adenylyl cyclase 4', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24318359, end_position_on_the_genomic_accession=24335071, orientation='minus', exon_count=26, OMIM=[600292], no_hdr0=''),
    196951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196951, CurrentID=0, Status='live', Symbol='FAM227B', Aliases=['C15orf33'], description='family with sequence similarity 227 member B', other_designations='protein FAM227B', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=49326970, end_position_on_the_genomic_accession=49620931, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    196996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=196996, CurrentID=0, Status='live', Symbol='GRAMD2A', Aliases=['GRAMD2'], description='GRAM domain containing 2A', other_designations='GRAM domain-containing protein 2A|GRAM domain containing 2|GRAM domain-containing protein 2', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72159806, end_position_on_the_genomic_accession=72197814, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    197021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197021, CurrentID=0, Status='live', Symbol='LCTL', Aliases=['KLG', 'KLPH'], description='lactase like', other_designations='lactase-like protein|KL lactase phlorizin hydrolase|klotho gamma|klotho/lactase-phlorizin hydrolase-related protein', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=66547532, end_position_on_the_genomic_accession=66565998, orientation='minus', exon_count=14, OMIM=[617060], no_hdr0=''),
    197131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197131, CurrentID=0, Status='live', Symbol='UBR1', Aliases=['JBS'], description='ubiquitin protein ligase E3 component n-recognin 1', other_designations='E3 ubiquitin-protein ligase UBR1|E3a ligase|N-recognin-1|RING-type E3 ubiquitin transferase UBR1|ubiquitin ligase E3 alpha-I|ubiquitin-protein ligase E3-alpha|ubiquitin-protein ligase E3-alpha-1|ubiquitin-protein ligase E3-alpha-I', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42942897, end_position_on_the_genomic_accession=43106038, orientation='minus', exon_count=47, OMIM=[605981], no_hdr0=''),
    197135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197135, CurrentID=0, Status='live', Symbol='PATL2', Aliases=['OOMD4', 'Pat1a', 'hPat1a'], description='PAT1 homolog 2', other_designations='protein PAT1 homolog 2|PAT1-like protein 2|protein PAT1 homolog a|protein associated with topoisomerase II homolog 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=44665732, end_position_on_the_genomic_accession=44711406, orientation='minus', exon_count=23, OMIM=[614661], no_hdr0=''),
    197257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197257, CurrentID=0, Status='live', Symbol='LDHD', Aliases=['DLACD', 'DLD'], description='lactate dehydrogenase D', other_designations='probable D-lactate dehydrogenase, mitochondrial|D-lactate dehydrogenase', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75111864, end_position_on_the_genomic_accession=75116795, orientation='minus', exon_count=10, OMIM=[607490], no_hdr0=''),
    197258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197258, CurrentID=0, Status='live', Symbol='FCSK', Aliases=['1110046B12Rik', 'CDGF2', 'FUK'], description='fucose kinase', other_designations='L-fucose kinase|fucokinase', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70454590, end_position_on_the_genomic_accession=70480274, orientation='plus', exon_count=27, OMIM=[608675], no_hdr0=''),
    197259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197259, CurrentID=0, Status='live', Symbol='MLKL', Aliases=['hMLKL'], description='mixed lineage kinase domain like pseudokinase', other_designations='mixed lineage kinase domain-like protein', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74671855, end_position_on_the_genomic_accession=74700889, orientation='minus', exon_count=12, OMIM=[615153], no_hdr0=''),
    197320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197320, CurrentID=0, Status='live', Symbol='ZNF778', Aliases=[], description='zinc finger protein 778', other_designations='zinc finger protein 778', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89202112, end_position_on_the_genomic_accession=89237141, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    197322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197322, CurrentID=0, Status='live', Symbol='ACSF3', Aliases=[], description='acyl-CoA synthetase family member 3', other_designations='malonate--CoA ligase ACSF3, mitochondrial|acyl-CoA synthetase family member 3, mitochondrial|malonyl-CoA synthetase', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89093847, end_position_on_the_genomic_accession=89160556, orientation='plus', exon_count=18, OMIM=[614245], no_hdr0=''),
    197335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197335, CurrentID=0, Status='live', Symbol='WDR90', Aliases=['C16orf15', 'C16orf16', 'C16orf17', 'C16orf18', 'C16orf19', 'POC16'], description='WD repeat domain 90', other_designations='WD repeat-containing protein 90', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=649363, end_position_on_the_genomic_accession=667833, orientation='plus', exon_count=42, OMIM=[618290], no_hdr0=''),
    197342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197342, CurrentID=0, Status='live', Symbol='EME2', Aliases=['SLX2B', 'gs125'], description='essential meiotic structure-specific endonuclease subunit 2', other_designations='probable crossover junction endonuclease EME2|SLX2 structure-specific endonuclease subunit homolog B|essential meiotic endonuclease 1 homolog 2|homolog of yeast EME1 endonuclease 2', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1772810, end_position_on_the_genomic_accession=1781702, orientation='plus', exon_count=8, OMIM=[610886], no_hdr0=''),
    197358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197358, CurrentID=0, Status='live', Symbol='NLRC3', Aliases=['CLR16.2', 'NOD3'], description='NLR family CARD domain containing 3', other_designations='NLR family CARD domain-containing protein 3|CARD15-like protein|NACHT, LRR and CARD domains-containing protein 3|NOD-like receptor C3|caterpiller protein 16.2|nucleotide-binding oligomerization domain, leucine rich repeat and CARD domain containing 3', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3539033, end_position_on_the_genomic_accession=3577782, orientation='minus', exon_count=26, OMIM=[615648], no_hdr0=''),
    197370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197370, CurrentID=0, Status='live', Symbol='NSMCE1', Aliases=['NSE1'], description='NSE1 homolog, SMC5-SMC6 complex component', other_designations='non-structural maintenance of chromosomes element 1 homolog|non-SMC element 1 homolog', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=27224994, end_position_on_the_genomic_accession=27268772, orientation='minus', exon_count=11, OMIM=[617263], no_hdr0=''),
    197407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=197407, CurrentID=0, Status='live', Symbol='ZNF48', Aliases=['ZNF553'], description='zinc finger protein 48', other_designations='zinc finger protein 48|zinc finger protein 553', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30378312, end_position_on_the_genomic_accession=30400108, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    198437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=198437, CurrentID=0, Status='live', Symbol='LKAAEAR1', Aliases=['C20orf201'], description='LKAAEAR motif containing 1', other_designations='protein LKAAEAR1|LKAAEAR motif-containing protein 1', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64083375, end_position_on_the_genomic_accession=64084956, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    199221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199221, CurrentID=0, Status='live', Symbol='DZIP1L', Aliases=['DZIP2', 'PKD5'], description='DAZ interacting zinc finger protein 1 like', other_designations='zinc finger protein DZIP1L|DAZ interacting protein 1-like|DAZ-interacting protein 1-like protein', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138061990, end_position_on_the_genomic_accession=138115862, orientation='minus', exon_count=25, OMIM=[617570], no_hdr0=''),
    199223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199223, CurrentID=0, Status='live', Symbol='TTC21A', Aliases=['IFT139A', 'SPGF37', 'STI2'], description='tetratricopeptide repeat domain 21A', other_designations='tetratricopeptide repeat protein 21A|TPR domain containing STI2|TPR repeat protein 21A|stress-inducible protein 2|testicular tissue protein Li 212', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=39107680, end_position_on_the_genomic_accession=39139009, orientation='plus', exon_count=30, OMIM=[611430], no_hdr0=''),
    199675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199675, CurrentID=0, Status='live', Symbol='MCEMP1', Aliases=['C19orf59'], description='mast cell expressed membrane protein 1', other_designations='mast cell-expressed membrane protein 1|epididymis secretory sperm binding protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7677090, end_position_on_the_genomic_accession=7679829, orientation='plus', exon_count=7, OMIM=[609565], no_hdr0=''),
    199692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199692, CurrentID=0, Status='live', Symbol='ZNF627', Aliases=[], description='zinc finger protein 627', other_designations='zinc finger protein 627', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11575255, end_position_on_the_genomic_accession=11619161, orientation='plus', exon_count=6, OMIM=[612248], no_hdr0=''),
    199699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199699, CurrentID=0, Status='live', Symbol='DAND5', Aliases=['CER2', 'CERL2', 'CKTSF1B3', 'COCO', 'CRL2', 'DANTE', 'GREM3', 'SP1'], description='DAN domain BMP antagonist family member 5', other_designations='DAN domain family member 5|DAN domain family member 5, BMP antagonist|DAN domain family, member 5|cerberus 2|cerberus-like 2|cerberus-like protein 2|cerl-2|cysteine knot superfamily 1, BMP antagonist 3|gremlin-3', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12969576, end_position_on_the_genomic_accession=12974760, orientation='plus', exon_count=2, OMIM=[609068], no_hdr0=''),
    199704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199704, CurrentID=0, Status='live', Symbol='ZNF585A', Aliases=['Zfp27'], description='zinc finger protein 585A', other_designations='zinc finger protein 585A', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37145540, end_position_on_the_genomic_accession=37172695, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    199713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199713, CurrentID=0, Status='live', Symbol='NLRP7', Aliases=['CLR19.4', 'HYDM', 'NALP7', 'NOD12', 'PAN7', 'PYPAF3'], description='NLR family pyrin domain containing 7', other_designations='NACHT, LRR and PYD domains-containing protein 7|NACHT, LRR and PYD containing protein 7|NACHT, leucine rich repeat and PYD containing 7|PYRIN-containing Apaf1-like protein 3|nucleotide-binding oligomerization domain protein 12|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 7', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54923509, end_position_on_the_genomic_accession=54965184, orientation='minus', exon_count=13, OMIM=[609661], no_hdr0=''),
    199720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199720, CurrentID=0, Status='live', Symbol='GGN', Aliases=[], description='gametogenetin', other_designations='gametogenetin', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38384267, end_position_on_the_genomic_accession=38388603, orientation='minus', exon_count=5, OMIM=[609966], no_hdr0=''),
    199731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199731, CurrentID=0, Status='live', Symbol='CADM4', Aliases=['IGSF4C', 'NECL4', 'Necl-4', 'TSLL2', 'synCAM4'], description='cell adhesion molecule 4', other_designations='cell adhesion molecule 4|TSLC1-like 2|TSLC1-like protein 2|immunoglobulin superfamily member 4C|nectin-like 4|nectin-like protein 4', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43622368, end_position_on_the_genomic_accession=43641984, orientation='minus', exon_count=10, OMIM=[609744], no_hdr0=''),
    199745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199745, CurrentID=0, Status='live', Symbol='THAP8', Aliases=[], description='THAP domain containing 8', other_designations='THAP domain-containing protein 8', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36034984, end_position_on_the_genomic_accession=36054762, orientation='minus', exon_count=5, OMIM=[612536], no_hdr0=''),
    199746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199746, CurrentID=0, Status='live', Symbol='U2AF1L4', Aliases=['U2AF1-RS3', 'U2AF1L3', 'U2AF1L3V1', 'U2AF1RS3', 'U2af26'], description='U2 small nuclear RNA auxiliary factor 1 like 4', other_designations='splicing factor U2AF 26 kDa subunit|U2 auxiliary factor 26|U2 small nuclear RNA auxiliary factor 1-like 3|U2 small nuclear RNA auxiliary factor 1-like protein 3|U2 small nuclear RNA auxiliary factor 1-like protein 4|U2(RNU2) small nuclear RNA auxiliary factor 1-like 3|U2(RNU2) small nuclear RNA auxiliary factor 1-like protein 3|U2AF1-like 4|U2AF1-like protein 3', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35742464, end_position_on_the_genomic_accession=35745418, orientation='minus', exon_count=10, OMIM=[601080], no_hdr0=''),
    199777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199777, CurrentID=0, Status='live', Symbol='ZNF626', Aliases=[], description='zinc finger protein 626', other_designations='zinc finger protein 626|CTC-513N18.7', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20619939, end_position_on_the_genomic_accession=20661571, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    199786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199786, CurrentID=0, Status='live', Symbol='NIBAN3', Aliases=['BCNP1', 'FAM129C'], description='niban apoptosis regulator 3', other_designations='protein Niban 3|B-cell novel protein 1|family with sequence similarity 129 member C|niban-like protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17523301, end_position_on_the_genomic_accession=17556755, orientation='plus', exon_count=18, OMIM=[609967], no_hdr0=''),
    199800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199800, CurrentID=0, Status='live', Symbol='ADM5', Aliases=['AM5', 'C19orf76'], description='adrenomedullin 5 (putative)', other_designations='putative adrenomedullin-5-like protein|adrenomedullin 5 homolog (pig)', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49689594, end_position_on_the_genomic_accession=49690575, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    199834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199834, CurrentID=0, Status='live', Symbol='LCE4A', Aliases=['LEP8', 'SPRL4A'], description='late cornified envelope 4A', other_designations='late cornified envelope protein 4A|late envelope protein 8|small proline rich-like (epidermal differentiation complex) 4A|small proline-rich-like epidermal differentiation complex protein 4A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152708160, end_position_on_the_genomic_accession=152709434, orientation='plus', exon_count=2, OMIM=[612618], no_hdr0=''),
    199857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199857, CurrentID=0, Status='live', Symbol='ALG14', Aliases=['CMS15', 'IDDEBF', 'MEPCA'], description='ALG14 UDP-N-acetylglucosaminyltransferase subunit', other_designations='UDP-N-acetylglucosamine transferase subunit ALG14 homolog', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=94974405, end_position_on_the_genomic_accession=95072974, orientation='minus', exon_count=8, OMIM=[612866], no_hdr0=''),
    199870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199870, CurrentID=0, Status='live', Symbol='FAM76A', Aliases=[], description='family with sequence similarity 76 member A', other_designations='protein FAM76A', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27725961, end_position_on_the_genomic_accession=27763116, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    199920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199920, CurrentID=0, Status='live', Symbol='FYB2', Aliases=['ARAP', 'C1orf168'], description='FYN binding protein 2', other_designations='FYN-binding protein 2|RP4-758N20.2|activation-dependent, raft-recruited ADAP-like phosphoprotein|uncharacterized protein C1orf168', map_location='1p32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=56718789, end_position_on_the_genomic_accession=56831986, orientation='minus', exon_count=27, OMIM=[618478], no_hdr0=''),
    199953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199953, CurrentID=0, Status='live', Symbol='TMEM201', Aliases=['Ima1', 'NET5', 'SAMP1'], description='transmembrane protein 201', other_designations='transmembrane protein 201|RP13-15M17.2|spindle-associated membrane protein 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=9588843, end_position_on_the_genomic_accession=9614877, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    199964 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199964, CurrentID=0, Status='live', Symbol='TMEM61', Aliases=[], description='transmembrane protein 61', other_designations='transmembrane protein 61', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54980614, end_position_on_the_genomic_accession=54992293, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    199974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199974, CurrentID=0, Status='live', Symbol='CYP4Z1', Aliases=['CYP4A20'], description='cytochrome P450 family 4 subfamily Z member 1', other_designations='cytochrome P450 4Z1|CYPIVZ1|cytochrome P450, family 4, subfamily Z, polypeptide 1|laurate 7-monooxygenase', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47055525, end_position_on_the_genomic_accession=47118320, orientation='plus', exon_count=13, OMIM=[618953], no_hdr0=''),
    199990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=199990, CurrentID=0, Status='live', Symbol='FAAP20', Aliases=['C1orf86', 'FP7162'], description='FA core complex associated protein 20', other_designations='Fanconi anemia core complex-associated protein 20|FANCA-associated protein of 20 kDa|Fanconi anemia core complex associated protein 20|Fanconi anemia-associated protein of 20 kDa', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2184457, end_position_on_the_genomic_accession=2212720, orientation='minus', exon_count=18, OMIM=[615183], no_hdr0=''),
    200008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200008, CurrentID=0, Status='live', Symbol='CDCP2', Aliases=[], description='CUB domain containing protein 2', other_designations='CUB domain-containing protein 2', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54132687, end_position_on_the_genomic_accession=54153181, orientation='minus', exon_count=7, OMIM=[612320], no_hdr0=''),
    200010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200010, CurrentID=0, Status='live', Symbol='SLC5A9', Aliases=['SGLT4'], description='solute carrier family 5 member 9', other_designations='sodium/glucose cotransporter 4|Na(+)/glucose cotransporter 4|hSGLT4|solute carrier family 5 (sodium/glucose cotransporter), member 9|solute carrier family 5 (sodium/sugar cotransporter), member 9', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=48221113, end_position_on_the_genomic_accession=48248644, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    200014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200014, CurrentID=0, Status='live', Symbol='CC2D1B', Aliases=['Lgd1'], description='coiled-coil and C2 domain containing 1B', other_designations='coiled-coil and C2 domain-containing protein 1B|FRE under dual repression-binding protein 2|five prime repressor element under dual repression-binding protein 2|freud-2', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52348437, end_position_on_the_genomic_accession=52366291, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    200030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200030, CurrentID=0, Status='live', Symbol='NBPF11', Aliases=['NBPF24'], description='NBPF member 11', other_designations='neuroblastoma breakpoint family member 11|neuroblastoma breakpoint family, member 24', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148102151, end_position_on_the_genomic_accession=148152281, orientation='minus', exon_count=27, OMIM=[614001], no_hdr0=''),
    200035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200035, CurrentID=0, Status='live', Symbol='NUDT17', Aliases=[], description='nudix hydrolase 17', other_designations='nucleoside diphosphate-linked moiety X motif 17|nudix (nucleoside diphosphate linked moiety X)-type motif 17|nudix motif 17', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145844985, end_position_on_the_genomic_accession=145848954, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    200081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200081, CurrentID=0, Status='live', Symbol='TXLNA', Aliases=['IL14', 'TXLN'], description='taxilin alpha', other_designations='alpha-taxilin|interleukin 14', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32179669, end_position_on_the_genomic_accession=32198285, orientation='plus', exon_count=11, OMIM=[608676], no_hdr0=''),
    200132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200132, CurrentID=0, Status='live', Symbol='DYNLT5', Aliases=['TCTEX1D1'], description='dynein light chain Tctex-type family member 5', other_designations='dynein light chain Tctex-type 5|Tctex1 domain containing 1|tctex1 domain-containing protein 1', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=66752147, end_position_on_the_genomic_accession=66779051, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    200150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200150, CurrentID=0, Status='live', Symbol='PLD5', Aliases=['PLDC'], description='phospholipase D family member 5', other_designations='inactive phospholipase D5|inactive PLD 5|inactive choline phosphatase 5|inactive phosphatidylcholine-hydrolyzing phospholipase D5', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=242082986, end_position_on_the_genomic_accession=242530546, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    200159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200159, CurrentID=0, Status='live', Symbol='C1orf100', Aliases=[], description='chromosome 1 open reading frame 100', other_designations='uncharacterized protein C1orf100', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244352062, end_position_on_the_genomic_accession=244389896, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    200162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200162, CurrentID=0, Status='live', Symbol='SPAG17', Aliases=['CT143', 'PF6', 'SPGF55'], description='sperm associated antigen 17', other_designations='sperm-associated antigen 17|projection protein PF6 homolog', map_location='1p12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=117953590, end_position_on_the_genomic_accession=118185228, orientation='minus', exon_count=56, OMIM=[616554], no_hdr0=''),
    200172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200172, CurrentID=0, Status='live', Symbol='SLFNL1', Aliases=[], description='schlafen like 1', other_designations='schlafen-like protein 1|testicular tissue protein Li 173', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=41015597, end_position_on_the_genomic_accession=41024704, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    200185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200185, CurrentID=0, Status='live', Symbol='KRTCAP2', Aliases=['KCP2'], description='keratinocyte associated protein 2', other_designations='keratinocyte-associated protein 2|KCP-2|dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit KCP2|keratinocytes associated protein 2|oligosaccharyl transferase subunit KCP2', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155169408, end_position_on_the_genomic_accession=155173304, orientation='minus', exon_count=5, OMIM=[619029], no_hdr0=''),
    200186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200186, CurrentID=0, Status='live', Symbol='CRTC2', Aliases=['TORC-2', 'TORC2'], description='CREB regulated transcription coactivator 2', other_designations='CREB-regulated transcription coactivator 2|transducer of regulated cAMP response element-binding protein (CREB) 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153947675, end_position_on_the_genomic_accession=153958643, orientation='minus', exon_count=16, OMIM=[608972], no_hdr0=''),
    200205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200205, CurrentID=0, Status='live', Symbol='IBA57', Aliases=['C1orf69', 'MMDS3', 'SPG74'], description='iron-sulfur cluster assembly factor IBA57', other_designations='putative transferase CAF17, mitochondrial|IBA57 homolog, iron-sulfur cluster assembly|IBA57, iron-sulfur cluster assembly homolog|iron-sulfur cluster assembly factor for biotin synthase- and aconitase-like mitochondrial proteins, with a mass of 57kDa|putative transferase C1orf69, mitochondrial', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=228165804, end_position_on_the_genomic_accession=228182257, orientation='plus', exon_count=4, OMIM=[615316], no_hdr0=''),
    200232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200232, CurrentID=0, Status='live', Symbol='FAM209A', Aliases=['C20orf106', 'dJ1153D9.3'], description='family with sequence similarity 209 member A', other_designations='protein FAM209A|uncharacterized protein C20orf106', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56524744, end_position_on_the_genomic_accession=56533590, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    200312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200312, CurrentID=0, Status='live', Symbol='RNF215', Aliases=[], description='ring finger protein 215', other_designations='RING finger protein 215', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30378821, end_position_on_the_genomic_accession=30387411, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    200315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200315, CurrentID=0, Status='live', Symbol='APOBEC3A', Aliases=['A3A', 'ARP3', 'PHRBN', 'bK150C2.1'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3A', other_designations='DNA dC->dU-editing enzyme APOBEC-3A|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 3A|phorbolin-1|probable DNA dC->dU-editing enzyme APOBEC-3A', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38957609, end_position_on_the_genomic_accession=38963184, orientation='plus', exon_count=5, OMIM=[607109], no_hdr0=''),
    200316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200316, CurrentID=0, Status='live', Symbol='APOBEC3F', Aliases=['A3F', 'ARP8', 'BK150C2.4.MRNA', 'KA6'], description='apolipoprotein B mRNA editing enzyme catalytic subunit 3F', other_designations='DNA dC->dU-editing enzyme APOBEC-3F|apolipoprotein B editing enzyme catalytic polypeptide-like 3F|apolipoprotein B mRNA editing enzyme cytidine deaminase|apolipoprotein B mRNA-editing enzyme catalytic polypeptide-like 3F|induced upon T-cell activation', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=39019081, end_position_on_the_genomic_accession=39055972, orientation='plus', exon_count=9, OMIM=[608993], no_hdr0=''),
    200350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200350, CurrentID=0, Status='live', Symbol='FOXD4L1', Aliases=['FOXD5', 'bA395L14.1'], description='forkhead box D4 like 1', other_designations='forkhead box protein D4-like 1|FOXD4-like 1', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=113499084, end_position_on_the_genomic_accession=113501150, orientation='plus', exon_count=1, OMIM=[611084], no_hdr0=''),
    200373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200373, CurrentID=0, Status='live', Symbol='CFAP221', Aliases=['FAP221', 'PCDP1'], description='cilia and flagella associated protein 221', other_designations='cilia- and flagella-associated protein 221|flagellar associated protein 221 homolog|primary ciliary dyskinesia 1 homolog|primary ciliary dyskinesia protein 1', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=119544392, end_position_on_the_genomic_accession=119660321, orientation='plus', exon_count=32, OMIM=[618704], no_hdr0=''),
    200403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200403, CurrentID=0, Status='live', Symbol='VWA3B', Aliases=['SCAR22'], description='von Willebrand factor A domain containing 3B', other_designations='von Willebrand factor A domain-containing protein 3B|VWA domain-containing protein 3B', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98087167, end_position_on_the_genomic_accession=98330682, orientation='plus', exon_count=37, OMIM=[614884], no_hdr0=''),
    200407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200407, CurrentID=0, Status='live', Symbol='CREG2', Aliases=[], description='cellular repressor of E1A stimulated genes 2', other_designations='protein CREG2', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101345550, end_position_on_the_genomic_accession=101387970, orientation='minus', exon_count=5, OMIM=[618540], no_hdr0=''),
    200424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200424, CurrentID=0, Status='live', Symbol='TET3', Aliases=['BEFAHRS', 'hCG_40738'], description='tet methylcytosine dioxygenase 3', other_designations='methylcytosine dioxygenase TET3|probable methylcytosine dioxygenase TET3|putative methylcytosine dioxygenase|ten-eleven translocation 3|tet oncogene family member 3', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73982036, end_position_on_the_genomic_accession=74135394, orientation='plus', exon_count=17, OMIM=[613555], no_hdr0=''),
    200504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200504, CurrentID=0, Status='live', Symbol='GKN2', Aliases=['BRICD1B', 'GDDR', 'PRO813', 'TFIZ1', 'VLTI465'], description='gastrokine 2', other_designations='gastrokine-2|BRICHOS domain containing 1B|blottin|down-regulated in gastric cancer GDDR|trefoil factor interactions(z) 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68945232, end_position_on_the_genomic_accession=68952893, orientation='minus', exon_count=6, OMIM=[618589], no_hdr0=''),
    200523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200523, CurrentID=0, Status='live', Symbol='TEX37', Aliases=['C2orf51', 'TSC21'], description='testis expressed 37', other_designations='testis-expressed sequence 37 protein|Testis-Specific Conserved gene 21kDa|protein TSC21|testis tissue sperm-binding protein Li 93mP|testis-specific conserved protein of 21 kDa', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88524619, end_position_on_the_genomic_accession=88529585, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    200539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200539, CurrentID=0, Status='live', Symbol='ANKRD23', Aliases=['DARP', 'MARP3'], description='ankyrin repeat domain 23', other_designations='ankyrin repeat domain-containing protein 23|diabetes related ankyrin repeat protein|muscle ankyrin repeat protein 3', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96837912, end_position_on_the_genomic_accession=96844021, orientation='minus', exon_count=9, OMIM=[610736], no_hdr0=''),
    200558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200558, CurrentID=0, Status='live', Symbol='APLF', Aliases=['APFL', 'C2orf13', 'PALF', 'Xip1', 'ZCCHH1'], description='aprataxin and PNKP like factor', other_designations='aprataxin and PNK-like factor|PNK and APTX-like FHA domain-containing protein|PNK and APTX-like FHA protein|XRCC1-interacting protein 1|aprataxin- and PNK-like factor|apurinic-apyrimidinic endonuclease APLF|zinc finger, CX5CX6HX5H motif containing 1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68467585, end_position_on_the_genomic_accession=68580162, orientation='plus', exon_count=10, OMIM=[611035], no_hdr0=''),
    200576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200576, CurrentID=0, Status='live', Symbol='PIKFYVE', Aliases=['CFD', 'FAB1', 'HEL37', 'PIP5K', 'PIP5K3', 'ZFYVE29'], description='phosphoinositide kinase, FYVE-type zinc finger containing', other_designations='1-phosphatidylinositol 3-phosphate 5-kinase|PIPkin-III|epididymis luminal protein 37|phosphatidylinositol 3-phosphate 5-kinase type III|phosphatidylinositol-3-phosphate/phosphatidylinositol 5-kinase, type III|phosphoinositide kinase, FYVE finger containing|serine-protein kinase PIKFYVE|type III PIP kinase|zinc finger, FYVE domain containing 29', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208266178, end_position_on_the_genomic_accession=208358747, orientation='plus', exon_count=43, OMIM=[609414], no_hdr0=''),
    200634 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200634, CurrentID=0, Status='live', Symbol='KRTCAP3', Aliases=['KCP3'], description='keratinocyte associated protein 3', other_designations='keratinocyte-associated protein 3|keratinocytes associated protein 3', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27442381, end_position_on_the_genomic_accession=27446481, orientation='plus', exon_count=8, OMIM=[619261], no_hdr0=''),
    200726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200726, CurrentID=0, Status='live', Symbol='FAM237A', Aliases=[], description='family with sequence similarity 237 member A', other_designations='protein FAM237A', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206642487, end_position_on_the_genomic_accession=206649365, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    200728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200728, CurrentID=0, Status='live', Symbol='TMEM17', Aliases=[], description='transmembrane protein 17', other_designations='transmembrane protein 17', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=62452778, end_position_on_the_genomic_accession=62511894, orientation='minus', exon_count=10, OMIM=[614950], no_hdr0=''),
    200734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200734, CurrentID=0, Status='live', Symbol='SPRED2', Aliases=['Spred-2'], description='sprouty related EVH1 domain containing 2', other_designations='sprouty-related, EVH1 domain-containing protein 2|sprouty protein with EVH-1 domain 2, related sequence', map_location='2p14', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=65307425, end_position_on_the_genomic_accession=65432599, orientation='minus', exon_count=10, OMIM=[609292], no_hdr0=''),
    200765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200765, CurrentID=0, Status='live', Symbol='TIGD1', Aliases=['EEYORE'], description='tigger transposable element derived 1', other_designations='tigger transposable element-derived protein 1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232543883, end_position_on_the_genomic_accession=232550557, orientation='minus', exon_count=1, OMIM=[612972], no_hdr0=''),
    200844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200844, CurrentID=0, Status='live', Symbol='CFAP20DC', Aliases=['C3orf67'], description='CFAP20 domain containing', other_designations='protein CFAP20DC|uncharacterized protein C3orf67', map_location='3p14.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58716417, end_position_on_the_genomic_accession=59050045, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    200845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200845, CurrentID=0, Status='live', Symbol='KCTD6', Aliases=['KCASH3'], description='potassium channel tetramerization domain containing 6', other_designations='BTB/POZ domain-containing protein KCTD6|potassium channel tetramerisation domain containing 6|potassium channel tetramerization domain-containing protein 6', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58492096, end_position_on_the_genomic_accession=58502360, orientation='plus', exon_count=4, OMIM=[618791], no_hdr0=''),
    200879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200879, CurrentID=0, Status='live', Symbol='LIPH', Aliases=['AH', 'ARWH2', 'HYPT7', 'LAH2', 'LPDLR', 'PLA1B', 'mPA-PLA1'], description='lipase H', other_designations='lipase member H|LPD lipase-related protein|lipase, member H|mPA-PLA1 alpha|membrane-associated phosphatidic acid-selective phospholipase A1-alpha|membrane-bound phosphatidic acid-selective phospholipase A1|phospholipase A(1)|phospholipase A1 member B', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185506262, end_position_on_the_genomic_accession=185552661, orientation='minus', exon_count=12, OMIM=[607365], no_hdr0=''),
    200894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200894, CurrentID=0, Status='live', Symbol='ARL13B', Aliases=['ARL2L1', 'JBTS8'], description='ADP ribosylation factor like GTPase 13B', other_designations='ADP-ribosylation factor-like protein 13B|ADP-ribosylation factor-like 13B|ADP-ribosylation factor-like 2-like 1|ARL2-like protein 1', map_location='3q11.1-q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=93980147, end_position_on_the_genomic_accession=94055678, orientation='plus', exon_count=14, OMIM=[608922], no_hdr0=''),
    200895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200895, CurrentID=0, Status='live', Symbol='DHFR2', Aliases=['DHFRL1', 'DHFRP4'], description='dihydrofolate reductase 2', other_designations='dihydrofolate reductase 2, mitochondrial|dihydrofolate reductase like 1|dihydrofolate reductase pseudogene 4|dihydrofolate reductase, mitochondrial|dihydrofolate reductase-like protein 1', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=94057922, end_position_on_the_genomic_accession=94063389, orientation='minus', exon_count=3, OMIM=[616588], no_hdr0=''),
    200909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200909, CurrentID=0, Status='live', Symbol='HTR3D', Aliases=['5HT3D'], description='5-hydroxytryptamine receptor 3D', other_designations='5-hydroxytryptamine receptor 3D|5-hydroxytryptamine (serotonin) receptor 3 family member D|5-hydroxytryptamine (serotonin) receptor 3D, ionotropic|5-hydroxytryptamine receptor 3 subunit D|serotonin 5-HT-3D receptor|serotonin receptor 3D', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184031544, end_position_on_the_genomic_accession=184039369, orientation='plus', exon_count=10, OMIM=[610122], no_hdr0=''),
    200916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200916, CurrentID=0, Status='live', Symbol='RPL22L1', Aliases=[], description='ribosomal protein L22 like 1', other_designations='60S ribosomal protein L22-like 1|large ribosomal subunit protein eL22-like 1', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=170864875, end_position_on_the_genomic_accession=170870195, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    200931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200931, CurrentID=0, Status='live', Symbol='SLC51A', Aliases=['OSTA', 'OSTalpha'], description='solute carrier family 51 subunit alpha', other_designations='organic solute transporter subunit alpha|OST-alpha|organic solute transporter alpha|organic solute transporter, alpha subunit|solute carrier family 51 alpha subunit', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196216534, end_position_on_the_genomic_accession=196233427, orientation='plus', exon_count=9, OMIM=[612084], no_hdr0=''),
    200933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200933, CurrentID=0, Status='live', Symbol='FBXO45', Aliases=['Fbx45'], description='F-box protein 45', other_designations='F-box/SPRY domain-containing protein 1|F-box only protein 45|hFbxo45', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196568660, end_position_on_the_genomic_accession=196589059, orientation='plus', exon_count=3, OMIM=[609112], no_hdr0=''),
    200942 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200942, CurrentID=0, Status='live', Symbol='KLHDC8B', Aliases=['CHL'], description='kelch domain containing 8B', other_designations='kelch domain-containing protein 8B', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49171120, end_position_on_the_genomic_accession=49176487, orientation='plus', exon_count=6, OMIM=[613169], no_hdr0=''),
    200958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200958, CurrentID=0, Status='live', Symbol='MUC20', Aliases=['MUC-20'], description='mucin 20, cell surface associated', other_designations='mucin-20|transmembrane mucin MUC20S', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195720978, end_position_on_the_genomic_accession=195733551, orientation='plus', exon_count=4, OMIM=[610360], no_hdr0=''),
    200959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=200959, CurrentID=0, Status='live', Symbol='GABRR3', Aliases=[], description='gamma-aminobutyric acid type A receptor subunit rho3', other_designations='gamma-aminobutyric acid receptor subunit rho-3|GABA(A) receptor subunit rho-3|GABA(C) receptor|gamma-aminobutyric acid (GABA) A receptor, rho 3|gamma-aminobutyric acid type A receptor rho3 subunit', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=97985102, end_position_on_the_genomic_accession=98035315, orientation='minus', exon_count=10, OMIM=[618668], no_hdr0=''),
    201134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201134, CurrentID=0, Status='live', Symbol='CEP112', Aliases=['CCDC46', 'MACOCO', 'SPGF44'], description='centrosomal protein 112', other_designations='centrosomal protein of 112 kDa|centrosomal protein 112kDa|coiled-coil domain-containing protein 46', map_location='17q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=65635537, end_position_on_the_genomic_accession=66192133, orientation='minus', exon_count=37, OMIM=[618980], no_hdr0=''),
    201140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201140, CurrentID=0, Status='live', Symbol='DHRS7C', Aliases=['SDR32C2'], description='dehydrogenase/reductase 7C', other_designations='dehydrogenase/reductase SDR family member 7C|dehydrogenase/reductase (SDR family) member 7C|short-chain dehydrogenase/reductase family 32C member 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9771438, end_position_on_the_genomic_accession=9791592, orientation='minus', exon_count=6, OMIM=[616161], no_hdr0=''),
    201158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201158, CurrentID=0, Status='live', Symbol='TVP23C', Aliases=['FAM18B2'], description='trans-golgi network vesicle protein 23 homolog C', other_designations='Golgi apparatus membrane protein TVP23 homolog C|family with sequence similarity 18, member B2|protein FAM18B2', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15502264, end_position_on_the_genomic_accession=15563483, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    201161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201161, CurrentID=0, Status='live', Symbol='CENPV', Aliases=['3110013H01Rik', 'CENP-V', 'PRR6', 'p30'], description='centromere protein V', other_designations='centromere protein V|nuclear protein p30|proline rich 6|proline-rich protein 6', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16342537, end_position_on_the_genomic_accession=16353469, orientation='minus', exon_count=5, OMIM=[608139], no_hdr0=''),
    201163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201163, CurrentID=0, Status='live', Symbol='FLCN', Aliases=['BHD', 'DENND8B', 'FLCL'], description='folliculin', other_designations='folliculin|BHD skin lesion fibrofolliculoma protein|birt-Hogg-Dube syndrome protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17206946, end_position_on_the_genomic_accession=17237188, orientation='minus', exon_count=18, OMIM=[607273], no_hdr0=''),
    201164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201164, CurrentID=0, Status='live', Symbol='PLD6', Aliases=['ZUC'], description='phospholipase D family member 6', other_designations='mitochondrial cardiolipin hydrolase|PLD 6|choline phosphatase 6|mitoPLD|mitochondrial phospholipase|phosphatidylcholine-hydrolyzing phospholipase D6|phospholipase D6|protein zucchini homolog', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=17200990, end_position_on_the_genomic_accession=17206905, orientation='minus', exon_count=2, OMIM=[614960], no_hdr0=''),
    201176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201176, CurrentID=0, Status='live', Symbol='ARHGAP27', Aliases=['CAMGAP1', 'PP905', 'SH3D20', 'SH3P20'], description='Rho GTPase activating protein 27', other_designations='rho GTPase-activating protein 27|CIN85-associated multi-domain-containing Rho GTPase-activating protein 1|SH3 domain containing 20|SH3 domain-containing protein 20|rho-type GTPase-activating protein 27', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45393908, end_position_on_the_genomic_accession=45432870, orientation='minus', exon_count=26, OMIM=[610591], no_hdr0=''),
    201181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201181, CurrentID=0, Status='live', Symbol='ZNF385C', Aliases=[], description='zinc finger protein 385C', other_designations='zinc finger protein 385C|CTD-2132N18.2|CTD-2132N18.4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42025576, end_position_on_the_genomic_accession=42098473, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    201191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201191, CurrentID=0, Status='live', Symbol='SAMD14', Aliases=[], description='sterile alpha motif domain containing 14', other_designations='sterile alpha motif domain-containing protein 14|SAM domain-containing protein 14', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=50110040, end_position_on_the_genomic_accession=50130160, orientation='minus', exon_count=14, OMIM=[619233], no_hdr0=''),
    201229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201229, CurrentID=0, Status='live', Symbol='LYRM9', Aliases=['C17orf108', 'HSD24'], description='LYR motif containing 9', other_designations='LYR motif-containing protein 9|UPF0631 protein C17orf108', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=27878317, end_position_on_the_genomic_accession=27894746, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    201232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201232, CurrentID=0, Status='live', Symbol='SLC16A13', Aliases=['MCT13'], description='solute carrier family 16 member 13', other_designations='monocarboxylate transporter 13|MCT 13|monocarboxylic acid transporter 13|solute carrier family 16 (monocarboxylic acid transporters), member 13', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7036015, end_position_on_the_genomic_accession=7040117, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    201243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201243, CurrentID=0, Status='live', Symbol='SPEM2', Aliases=['C17orf74'], description='SPEM family member 2', other_designations='uncharacterized protein SPEM2|uncharacterized protein C17orf74', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7424874, end_position_on_the_genomic_accession=7427568, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    201254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201254, CurrentID=0, Status='live', Symbol='CENPX', Aliases=['CENP-X', 'D9', 'FAAP10', 'MHF2', 'STRA13'], description='centromere protein X', other_designations='centromere protein X|FANCM associated histone fold protein 2|FANCM-interacting histone fold protein 2|Fanconi anemia-associated polypeptide of 10 kDa|retinoic acid-inducible gene D9 protein homolog|stimulated by retinoic acid 13 homolog|stimulated by retinoic acid gene 13 protein homolog', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82018703, end_position_on_the_genomic_accession=82022930, orientation='minus', exon_count=4, OMIM=[615128], no_hdr0=''),
    201255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201255, CurrentID=0, Status='live', Symbol='LRRC45', Aliases=[], description='leucine rich repeat containing 45', other_designations='leucine-rich repeat-containing protein 45', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82023252, end_position_on_the_genomic_accession=82031151, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    201266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201266, CurrentID=0, Status='live', Symbol='SLC39A11', Aliases=['C17orf26', 'ZIP-11', 'ZIP11'], description='solute carrier family 39 member 11', other_designations='zinc transporter ZIP11|Zrt- and Irt-like protein 11|solute carrier family 39 (metal ion transporter), member 11', map_location='17q24.3-q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=72645949, end_position_on_the_genomic_accession=73092714, orientation='minus', exon_count=21, OMIM=[616508], no_hdr0=''),
    201292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201292, CurrentID=0, Status='live', Symbol='TRIM65', Aliases=['4732463G12Rik'], description='tripartite motif containing 65', other_designations='tripartite motif-containing protein 65', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75880379, end_position_on_the_genomic_accession=75897008, orientation='minus', exon_count=8, OMIM=[619408], no_hdr0=''),
    201294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201294, CurrentID=0, Status='live', Symbol='UNC13D', Aliases=['FHL3', 'HLH3', 'HPLH3', 'Munc13-4'], description='unc-13 homolog D', other_designations='protein unc-13 homolog D', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75827225, end_position_on_the_genomic_accession=75844404, orientation='minus', exon_count=32, OMIM=[608897], no_hdr0=''),
    201299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201299, CurrentID=0, Status='live', Symbol='RDM1', Aliases=['RAD52B'], description='RAD52 motif containing 1', other_designations='RAD52 motif-containing protein 1|RAD52 homolog B|RAD52 motif 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35918080, end_position_on_the_genomic_accession=35931821, orientation='minus', exon_count=8, OMIM=[612896], no_hdr0=''),
    201305 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201305, CurrentID=0, Status='live', Symbol='SPNS3', Aliases=['SLC62A3', 'SLC63A3'], description='sphingolipid transporter 3 (putative)', other_designations='protein spinster homolog 3|SPNS sphingolipid transporter 3 (putative)|spinster homolog 3', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4433940, end_position_on_the_genomic_accession=4488204, orientation='plus', exon_count=15, OMIM=[611701], no_hdr0=''),
    201456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201456, CurrentID=0, Status='live', Symbol='FBXO15', Aliases=['FBX15'], description='F-box protein 15', other_designations='F-box only protein 15', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74073343, end_position_on_the_genomic_accession=74147834, orientation='minus', exon_count=15, OMIM=[609093], no_hdr0=''),
    201475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201475, CurrentID=0, Status='live', Symbol='RAB12', Aliases=[], description='RAB12, member RAS oncogene family', other_designations='ras-related protein Rab-12|putative Ras-related protein Rab-12', map_location='18p11.22', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=8609428, end_position_on_the_genomic_accession=8639383, orientation='plus', exon_count=9, OMIM=[616448], no_hdr0=''),
    201501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201501, CurrentID=0, Status='live', Symbol='ZBTB7C', Aliases=['APM-1', 'APM1', 'ZBTB36', 'ZNF857C'], description='zinc finger and BTB domain containing 7C', other_designations='zinc finger and BTB domain-containing protein 7C|B230208J24Rik|affected by papillomavirus DNA integration in ME180 cells protein 1|zinc finger and BTB domain containing 36|zinc finger and BTB domain-containing protein 36|zinc finger protein 857C', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=48026672, end_position_on_the_genomic_accession=48412639, orientation='minus', exon_count=19, OMIM=[616591], no_hdr0=''),
    201514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201514, CurrentID=0, Status='live', Symbol='ZNF584', Aliases=[], description='zinc finger protein 584', other_designations='zinc finger protein 584', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58401472, end_position_on_the_genomic_accession=58431396, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    201516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201516, CurrentID=0, Status='live', Symbol='ZSCAN4', Aliases=['ZNF494'], description='zinc finger and SCAN domain containing 4', other_designations='zinc finger and SCAN domain-containing protein 4|zinc finger protein 494', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57651476, end_position_on_the_genomic_accession=57679152, orientation='plus', exon_count=8, OMIM=[613419], no_hdr0=''),
    201562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201562, CurrentID=0, Status='live', Symbol='HACD2', Aliases=['PTPLB'], description='3-hydroxyacyl-CoA dehydratase 2', other_designations='very-long-chain (3R)-3-hydroxyacyl-CoA dehydratase 2|protein tyrosine phosphatase-like (proline instead of catalytic arginine), member b|protein-tyrosine phosphatase-like member B|very-long-chain (3R)-3-hydroxyacyl-[acyl-carrier protein] dehydratase 2', map_location='3q21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=123491548, end_position_on_the_genomic_accession=123585099, orientation='minus', exon_count=13, OMIM=[615939], no_hdr0=''),
    201595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201595, CurrentID=0, Status='live', Symbol='STT3B', Aliases=['CDG1X', 'SIMP', 'STT3-B'], description='STT3 oligosaccharyltransferase complex catalytic subunit B', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit STT3B|STT3, subunit of the oligosaccharyltransferase complex, homolog B|STT3B, catalytic subunit of the oligosaccharyltransferase complex|STT3B, subunit of the oligosaccharyltransferase complex (catalytic)|dolichyl-diphosphooligosaccharide protein glycotransferase|homolog of yeast STT3|oligosaccharyl transferase subunit STT3B|source of immunodominant MHC-associated peptides homolog', map_location='3p23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=31532638, end_position_on_the_genomic_accession=31637621, orientation='plus', exon_count=18, OMIM=[608605], no_hdr0=''),
    201625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201625, CurrentID=0, Status='live', Symbol='DNAH12', Aliases=['DHC3', 'DLP12', 'DLP3L', 'DNAH7L', 'DNAHC12', 'DNAHC3', 'DNHD2', 'HDHC3', 'HL-19', 'HL19', 'DNAH12'], description='dynein axonemal heavy chain 12', other_designations='dynein axonemal heavy chain 12|dynein heavy chain 12, axonemal|axonemal beta dynein heavy chain 12|axonemal dynein heavy chain isotype3|ciliary dynein heavy chain 12|dynein heavy chain domain-containing protein 2|dynein, axonemal, heavy polypeptide 12|dynein, heavy chain-5', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57293699, end_position_on_the_genomic_accession=57545203, orientation='minus', exon_count=77, OMIM=[603340], no_hdr0=''),
    201626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201626, CurrentID=0, Status='live', Symbol='PDE12', Aliases=["2'-PDE", '2-PDE'], description='phosphodiesterase 12', other_designations="2',5'-phosphodiesterase 12|2'-phosphodiesterase|mitochondrial deadenylase", map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57556274, end_position_on_the_genomic_accession=57656495, orientation='plus', exon_count=4, OMIM=[616519], no_hdr0=''),
    201627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201627, CurrentID=0, Status='live', Symbol='DENND6A', Aliases=['AFI1A', 'FAM116A'], description='DENN domain containing 6A', other_designations='protein DENND6A|DENN domain-containing protein 6A|DENN/MADD domain containing 6A|family with sequence similarity 116, member A|protein FAM116A', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57625454, end_position_on_the_genomic_accession=57693118, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    201633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201633, CurrentID=0, Status='live', Symbol='TIGIT', Aliases=['VSIG9', 'VSTM3', 'WUCAM'], description='T cell immunoreceptor with Ig and ITIM domains', other_designations='T-cell immunoreceptor with Ig and ITIM domains|V-set and immunoglobulin domain containing 9|V-set and immunoglobulin domain-containing protein 9|V-set and transmembrane domain containing 3|V-set and transmembrane domain-containing protein 3|VSIG9, VSTM3|Washington University cell adhesion molecule', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=114291102, end_position_on_the_genomic_accession=114329747, orientation='plus', exon_count=6, OMIM=[612859], no_hdr0=''),
    201725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201725, CurrentID=0, Status='live', Symbol='C4orf46', Aliases=['RCDG1'], description='chromosome 4 open reading frame 46', other_designations='renal cancer differentiation gene 1 protein', map_location='4q32.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=158666675, end_position_on_the_genomic_accession=158672056, orientation='minus', exon_count=3, OMIM=[616210], no_hdr0=''),
    201780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201780, CurrentID=0, Status='live', Symbol='SLC10A4', Aliases=['P4'], description='solute carrier family 10 member 4', other_designations='sodium/bile acid cotransporter 4|Na(+)/bile acid cotransporter 4|bile acid transporter SLC10A4|solute carrier family 10 (sodium/bile acid cotransporter family), member 4', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48483343, end_position_on_the_genomic_accession=48489526, orientation='plus', exon_count=3, OMIM=[618563], no_hdr0=''),
    201798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201798, CurrentID=0, Status='live', Symbol='TIGD4', Aliases=[], description='tigger transposable element derived 4', other_designations='tigger transposable element-derived protein 4', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=152768716, end_position_on_the_genomic_accession=152779778, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    201799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201799, CurrentID=0, Status='live', Symbol='TMEM154', Aliases=[], description='transmembrane protein 154', other_designations='transmembrane protein 154', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=152618628, end_position_on_the_genomic_accession=152680023, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    201895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201895, CurrentID=0, Status='live', Symbol='SMIM14', Aliases=['C4orf34'], description='small integral membrane protein 14', other_designations='small integral membrane protein 14', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=39546336, end_position_on_the_genomic_accession=39638865, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    201931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201931, CurrentID=0, Status='live', Symbol='TMEM192', Aliases=[], description='transmembrane protein 192', other_designations='transmembrane protein 192', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=165070608, end_position_on_the_genomic_accession=165112913, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    201965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201965, CurrentID=0, Status='live', Symbol='RWDD4', Aliases=['FAM28AA', 'RWDD4'], description='RWD domain containing 4', other_designations='RWD domain-containing protein 4|RWD domain containing 4A|RWD domain-containing protein 4A|family with sequence similarity 28, member A', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183639635, end_position_on_the_genomic_accession=183659218, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    201973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=201973, CurrentID=0, Status='live', Symbol='PRIMPOL', Aliases=['CCDC111', 'MYP22', 'Primpol1'], description='primase and DNA directed polymerase', other_designations='DNA-directed primase/polymerase protein|coiled-coil domain-containing protein 111|hPrimpol1', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=184649672, end_position_on_the_genomic_accession=184694952, orientation='plus', exon_count=16, OMIM=[615421], no_hdr0=''),
    202018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202018, CurrentID=0, Status='live', Symbol='TAPT1', Aliases=['CMVFR', 'OCLSBG'], description='transmembrane anterior posterior transformation 1', other_designations='transmembrane anterior posterior transformation protein 1 homolog|cytomegalovirus partial fusion receptor', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=16160505, end_position_on_the_genomic_accession=16226477, orientation='minus', exon_count=17, OMIM=[612758], no_hdr0=''),
    202051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202051, CurrentID=0, Status='live', Symbol='SPATA24', Aliases=['CCDC161', 'T6441'], description='spermatogenesis associated 24', other_designations='spermatogenesis-associated protein 24|coiled-coil domain containing 161|testis protein T6441 homolog', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139395269, end_position_on_the_genomic_accession=139404204, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    202052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202052, CurrentID=0, Status='live', Symbol='DNAJC18', Aliases=[], description='DnaJ heat shock protein family (Hsp40) member C18', other_designations='dnaJ homolog subfamily C member 18|DnaJ (Hsp40) homolog, subfamily C, member 18', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139410203, end_position_on_the_genomic_accession=139439525, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    202134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202134, CurrentID=0, Status='live', Symbol='FAM153B', Aliases=[], description='family with sequence similarity 153 member B', other_designations='protein FAM153B', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176063055, end_position_on_the_genomic_accession=176127142, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    202151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202151, CurrentID=0, Status='live', Symbol='RANBP3L', Aliases=[], description='RAN binding protein 3 like', other_designations='ran-binding protein 3-like', map_location='5p13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=36246913, end_position_on_the_genomic_accession=36301902, orientation='minus', exon_count=15, OMIM=[616391], no_hdr0=''),
    202243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202243, CurrentID=0, Status='live', Symbol='CCDC125', Aliases=['KENAE'], description='coiled-coil domain containing 125', other_designations='coiled-coil domain-containing protein 125', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69273087, end_position_on_the_genomic_accession=69333070, orientation='minus', exon_count=17, OMIM=[613781], no_hdr0=''),
    202309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202309, CurrentID=0, Status='live', Symbol='GAPT', Aliases=['C5orf29'], description='GRB2 binding adaptor protein, transmembrane', other_designations='protein GAPT|GRB2-binding transmembrane adaptor|growth factor receptor-bound protein 2-binding adapter protein, transmembrane', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=58491435, end_position_on_the_genomic_accession=58497090, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    202333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202333, CurrentID=0, Status='live', Symbol='CMYA5', Aliases=['C5orf10', 'SPRYD2', 'TRIM76'], description='cardiomyopathy associated 5', other_designations='cardiomyopathy-associated protein 5|2310076E16Rik|SPRY domain-containing protein 2|dystrobrevin-binding protein 2|genethonin-3|myospryn|tripartite motif-containing 76|tripartite motif-containing protein 76', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79689339, end_position_on_the_genomic_accession=79800226, orientation='plus', exon_count=14, OMIM=[612193], no_hdr0=''),
    202374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202374, CurrentID=0, Status='live', Symbol='STK32A', Aliases=['YANK1'], description='serine/threonine kinase 32A', other_designations='serine/threonine-protein kinase 32A|A930015B13Rik|CTB-108O6.2|yet another novel kinase 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147234963, end_position_on_the_genomic_accession=147401996, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    202500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202500, CurrentID=0, Status='live', Symbol='TCTE1', Aliases=['D6S46', 'DRC5', 'FAP155'], description='t-complex-associated-testis-expressed 1', other_designations='dynein regulatory complex subunit 5|T-complex-associated testis-expressed protein 1|tcte-1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44278734, end_position_on_the_genomic_accession=44297805, orientation='minus', exon_count=8, OMIM=[186975], no_hdr0=''),
    202559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202559, CurrentID=0, Status='live', Symbol='KHDRBS2', Aliases=['SLM-1', 'SLM1'], description='KH RNA binding domain containing, signal transduction associated 2', other_designations='KH domain-containing, RNA-binding, signal transduction-associated protein 2|KH domain containing, RNA binding, signal transduction associated 2|Sam68-like mammalian protein 1', map_location='6q11.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=61542670, end_position_on_the_genomic_accession=62286225, orientation='minus', exon_count=27, OMIM=[610487], no_hdr0=''),
    202658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202658, CurrentID=0, Status='live', Symbol='TRIM39-RPP21', Aliases=['TRIM39R'], description='TRIM39-RPP21 readthrough', other_designations='TRIM39-RPP21 protein|Rpp21 domain-containing TRIM protein|TRIM39-RPP21 read-through transcript', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30329311, end_position_on_the_genomic_accession=30346858, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    202865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202865, CurrentID=0, Status='live', Symbol='C7orf33', Aliases=[], description='chromosome 7 open reading frame 33', other_designations='uncharacterized protein C7orf33', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=148590766, end_position_on_the_genomic_accession=148615860, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    202915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=202915, CurrentID=0, Status='live', Symbol='TMEM184A', Aliases=['SDMG1'], description='transmembrane protein 184A', other_designations='transmembrane protein 184A|sexually dimorphic, expressed in male gonads 1', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1542235, end_position_on_the_genomic_accession=1556205, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    203054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203054, CurrentID=0, Status='live', Symbol='ADCK5', Aliases=[], description='aarF domain containing kinase 5', other_designations='uncharacterized aarF domain-containing protein kinase 5', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144373762, end_position_on_the_genomic_accession=144393242, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    203062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203062, CurrentID=0, Status='live', Symbol='TSNARE1', Aliases=[], description='t-SNARE domain containing 1', other_designations='t-SNARE domain-containing protein 1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142212080, end_position_on_the_genomic_accession=142403291, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    203068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203068, CurrentID=0, Status='live', Symbol='TUBB', Aliases=['CDCBM6', 'CSCSC1', 'M40', 'OK/SW-cl.561', 'TUBB5', 'TUBB'], description='tubulin beta class I', other_designations='tubulin beta chain|beta Ib tubulin|epididymis secretory sperm binding protein|tubulin beta-1 chain|tubulin beta-5 chain|tubulin, beta polypeptide', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30720352, end_position_on_the_genomic_accession=30725422, orientation='plus', exon_count=6, OMIM=[191130], no_hdr0=''),
    203069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203069, CurrentID=0, Status='live', Symbol='R3HCC1', Aliases=[], description='R3H domain and coiled-coil containing 1', other_designations='R3H and coiled-coil domain-containing protein 1', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=23288092, end_position_on_the_genomic_accession=23296279, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    203074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203074, CurrentID=0, Status='live', Symbol='PRSS55', Aliases=['CT153', 'T-SP1', 'TSP1', 'UNQ9391'], description='serine protease 55', other_designations='serine protease 55|probable serine protease UNQ9391/PRO34284|protease, serine 55|testis serine protease 1|tryptophan/serine protease', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10525484, end_position_on_the_genomic_accession=10554166, orientation='plus', exon_count=10, OMIM=[615144], no_hdr0=''),
    203076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203076, CurrentID=0, Status='live', Symbol='C8orf74', Aliases=[], description='chromosome 8 open reading frame 74', other_designations='uncharacterized protein C8orf74', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10672628, end_position_on_the_genomic_accession=10700593, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    203100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203100, CurrentID=0, Status='live', Symbol='HTRA4', Aliases=[], description='HtrA serine peptidase 4', other_designations='serine protease HTRA4|high-temperature requirement factor A4|probable serine protease HTRA4', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=38974149, end_position_on_the_genomic_accession=38988663, orientation='plus', exon_count=11, OMIM=[610700], no_hdr0=''),
    203102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203102, CurrentID=0, Status='live', Symbol='ADAM32', Aliases=[], description='ADAM metallopeptidase domain 32', other_designations='disintegrin and metalloproteinase domain-containing protein 32|a disintegrin and metalloprotease domain 32|a disintegrin and metalloproteinase domain 32|metalloproteinase 12-like protein|testicular tissue protein Li 13', map_location='8p11.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=39107529, end_position_on_the_genomic_accession=39284917, orientation='plus', exon_count=27, OMIM=[618602], no_hdr0=''),
    203111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203111, CurrentID=0, Status='live', Symbol='ERICH5', Aliases=['C8orf47'], description='glutamate rich 5', other_designations='glutamate-rich protein 5', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=98064568, end_position_on_the_genomic_accession=98093609, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    203190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203190, CurrentID=0, Status='live', Symbol='LGI3', Aliases=['LGIL4'], description='leucine rich repeat LGI family member 3', other_designations='leucine-rich repeat LGI family member 3|LGI1-like protein 4|leucine-rich glioma-inactivated protein 3', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22146830, end_position_on_the_genomic_accession=22156806, orientation='minus', exon_count=8, OMIM=[608302], no_hdr0=''),
    203197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203197, CurrentID=0, Status='live', Symbol='TMEM268', Aliases=['C9orf91'], description='transmembrane protein 268', other_designations='transmembrane protein 268|transmembrane protein C9orf91', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114603897, end_position_on_the_genomic_accession=114646422, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    203228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203228, CurrentID=0, Status='live', Symbol='C9orf72', Aliases=['ALSFTD', 'DENND9', 'DENNL72', 'FTDALS', 'FTDALS1'], description='C9orf72-SMCR8 complex subunit', other_designations='guanine nucleotide exchange C9orf72|protein C9orf72', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=27546546, end_position_on_the_genomic_accession=27573866, orientation='minus', exon_count=12, OMIM=[614260], no_hdr0=''),
    203238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203238, CurrentID=0, Status='live', Symbol='CCDC171', Aliases=['C9orf93', 'bA536D16.1', 'bA778P13.1'], description='coiled-coil domain containing 171', other_designations='coiled-coil domain-containing protein 171|myosin tail domain containing protein', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=15552874, end_position_on_the_genomic_accession=16062431, orientation='plus', exon_count=44, OMIM=[], no_hdr0=''),
    203245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203245, CurrentID=0, Status='live', Symbol='NAIF1', Aliases=['C9orf90', 'bA379C10.2'], description='nuclear apoptosis inducing factor 1', other_designations='nuclear apoptosis-inducing factor 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128061233, end_position_on_the_genomic_accession=128067867, orientation='minus', exon_count=3, OMIM=[610673], no_hdr0=''),
    203259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203259, CurrentID=0, Status='live', Symbol='FAM219A', Aliases=['C9orf25'], description='family with sequence similarity 219 member A', other_designations='protein FAM219A|uncharacterized protein C9orf25', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34398184, end_position_on_the_genomic_accession=34458570, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    203260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203260, CurrentID=0, Status='live', Symbol='CCDC107', Aliases=['PSEC0222'], description='coiled-coil domain containing 107', other_designations='coiled-coil domain-containing protein 107', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35658292, end_position_on_the_genomic_accession=35661511, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    203286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203286, CurrentID=0, Status='live', Symbol='ANKS6', Aliases=['ANKRD14', 'NPHP16', 'PKDR1', 'SAMD6'], description='ankyrin repeat and sterile alpha motif domain containing 6', other_designations='ankyrin repeat and SAM domain-containing protein 6|SAM domain-containing protein 6|ankyrin repeat domain 14|samCystin', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=98732009, end_position_on_the_genomic_accession=98796555, orientation='minus', exon_count=19, OMIM=[615370], no_hdr0=''),
    203328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203328, CurrentID=0, Status='live', Symbol='SUSD3', Aliases=[], description='sushi domain containing 3', other_designations='sushi domain-containing protein 3', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=93058701, end_position_on_the_genomic_accession=93085138, orientation='plus', exon_count=10, OMIM=[616429], no_hdr0=''),
    203413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203413, CurrentID=0, Status='live', Symbol='CT83', Aliases=['CXorf61', 'KK-LC-1', 'KKLC1'], description='cancer/testis antigen 83', other_designations='kita-kyushu lung cancer antigen 1', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=116461686, end_position_on_the_genomic_accession=116462976, orientation='minus', exon_count=2, OMIM=[300625], no_hdr0=''),
    203427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203427, CurrentID=0, Status='live', Symbol='SLC25A43', Aliases=[], description='solute carrier family 25 member 43', other_designations='solute carrier family 25 member 43', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119399326, end_position_on_the_genomic_accession=119454478, orientation='plus', exon_count=9, OMIM=[300641], no_hdr0=''),
    203430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203430, CurrentID=0, Status='live', Symbol='RTL3', Aliases=['Mar3', 'Mart3', 'SIRH9', 'ZCCHC5', 'ZHC5'], description='retrotransposon Gag like 3', other_designations='retrotransposon Gag-like protein 3|Sushi-Ichi retrotransposon homolog 9|mammalian retrotransposon-derived 3|zinc finger CCHC domain-containing protein 5|zinc finger CCHC-type containing 5|zinc finger, CCHC domain containing 5', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=78656068, end_position_on_the_genomic_accession=78659328, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    203447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203447, CurrentID=0, Status='live', Symbol='NRK', Aliases=['NESK'], description='Nik related kinase', other_designations='nik-related protein kinase', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=105821942, end_position_on_the_genomic_accession=105958610, orientation='plus', exon_count=30, OMIM=[300791], no_hdr0=''),
    203522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203522, CurrentID=0, Status='live', Symbol='INTS6L', Aliases=['DDX26B'], description='integrator complex subunit 6 like', other_designations='integrator complex subunit 6-like|DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 26B|protein DDX26B', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135520630, end_position_on_the_genomic_accession=135582510, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    203523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203523, CurrentID=0, Status='live', Symbol='ZNF449', Aliases=['ZSCAN19'], description='zinc finger protein 449', other_designations='zinc finger protein 449|zinc finger and SCAN domain-containing protein 19', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135344770, end_position_on_the_genomic_accession=135363413, orientation='plus', exon_count=8, OMIM=[300627], no_hdr0=''),
    203547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203547, CurrentID=0, Status='live', Symbol='VMA21', Aliases=['MEAX', 'XMEA'], description='vacuolar ATPase assembly factor VMA21', other_designations='vacuolar ATPase assembly integral membrane protein VMA21|VMA21 vacuolar H+-ATPase homolog|VMA21, vacuolar ATPase assembly factor|myopathy with excessive autophagy protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=151396595, end_position_on_the_genomic_accession=151409364, orientation='plus', exon_count=4, OMIM=[300913], no_hdr0=''),
    203562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203562, CurrentID=0, Status='live', Symbol='TMEM31', Aliases=[], description='transmembrane protein 31', other_designations='transmembrane protein 31|testicular secretory protein Li 58', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103710909, end_position_on_the_genomic_accession=103714032, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    203569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203569, CurrentID=0, Status='live', Symbol='PAGE2', Aliases=['CT16.4', 'GAGEC2', 'GAGEE2', 'PAGE-2'], description='PAGE family member 2', other_designations='P antigen family member 2|G antigen family C 2|G antigen, family E, 2|P antigen family, member 2 (prostate associated)|g antigen family E member 2|prostate-associated gene 2 protein', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55089018, end_position_on_the_genomic_accession=55092842, orientation='plus', exon_count=6, OMIM=[300738], no_hdr0=''),
    203611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203611, CurrentID=0, Status='live', Symbol='CDY2B', Aliases=['CDY'], description='chromodomain Y-linked 2B', other_designations='testis-specific chromodomain protein Y 2|Y chromosome chromodomain protein 2B|chromodomain protein, Y chromosome, 2 related|chromodomain protein, Y-linked, 2B|testis-specific chromodomain protein Y protein 2 related', map_location='Yq11.222', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=17878260, end_position_on_the_genomic_accession=17880220, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    203859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=203859, CurrentID=0, Status='live', Symbol='ANO5', Aliases=['GDD1', 'LGMD2L', 'LGMDR12', 'TMEM16E'], description='anoctamin 5', other_designations='anoctamin-5|gnathodiaphyseal dysplasia 1 protein|integral membrane protein GDD1|transmembrane protein 16E', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22192485, end_position_on_the_genomic_accession=22283357, orientation='plus', exon_count=23, OMIM=[608662], no_hdr0=''),
    204219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204219, CurrentID=0, Status='live', Symbol='CERS3', Aliases=['ARCI9', 'LASS3'], description='ceramide synthase 3', other_designations='ceramide synthase 3|LAG1 homolog, ceramide synthase 3|LAG1 longevity assurance homolog 3|dihydroceramide synthase 3|sphingosine N-acyltransferase CERS3', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=100400395, end_position_on_the_genomic_accession=100544982, orientation='minus', exon_count=17, OMIM=[615276], no_hdr0=''),
    204474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204474, CurrentID=0, Status='live', Symbol='PDILT', Aliases=['PDIA7'], description='protein disulfide isomerase like, testis expressed', other_designations='protein disulfide-isomerase-like protein of the testis|protein disulfide isomerase family A, member 7', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20359171, end_position_on_the_genomic_accession=20404742, orientation='minus', exon_count=12, OMIM=[618588], no_hdr0=''),
    204801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204801, CurrentID=0, Status='live', Symbol='NLRP11', Aliases=['CLR19.6', 'NALP11', 'NOD17', 'PAN10', 'PYPAF6', 'PYPAF7'], description='NLR family pyrin domain containing 11', other_designations='NACHT, LRR and PYD domains-containing protein 11|NACHT, leucine rich repeat and PYD containing 11|PAAD- and NACHT-containing protein 10B|PAAD-and NACHT domain-containing protein 10|PYRIN-containing APAF1-like protein 6|nucleotide-binding oligomerization domain protein 17|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 11', map_location='19q13.42-q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55785399, end_position_on_the_genomic_accession=55836575, orientation='minus', exon_count=13, OMIM=[609664], no_hdr0=''),
    204851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204851, CurrentID=0, Status='live', Symbol='HIPK1', Aliases=['Myak', 'Nbak2'], description='homeodomain interacting protein kinase 1', other_designations='homeodomain-interacting protein kinase 1|homeodomain interacting protein kinase 1-like protein|nuclear body associated kinase 2b|nuclear body-associated kinase 2', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113929324, end_position_on_the_genomic_accession=113977869, orientation='plus', exon_count=22, OMIM=[608003], no_hdr0=''),
    204962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=204962, CurrentID=0, Status='live', Symbol='SLC44A5', Aliases=['CTL5'], description='solute carrier family 44 member 5', other_designations='choline transporter-like protein 5', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75202129, end_position_on_the_genomic_accession=75724261, orientation='minus', exon_count=32, OMIM=[], no_hdr0=''),
    205147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205147, CurrentID=0, Status='live', Symbol='AMER3', Aliases=['FAM123C'], description='APC membrane recruitment protein 3', other_designations='APC membrane recruitment protein 3|family with sequence similarity 123C|protein FAM123C', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130754475, end_position_on_the_genomic_accession=130768134, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    205251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205251, CurrentID=0, Status='live', Symbol='MTLN', Aliases=['LEMP', 'LINC00116', 'MOXI', 'MPM', 'NCRNA00116', 'SMIM37'], description='mitoregulin', other_designations='mitoregulin|lncRNA encoded micropeptide|long intergenic non-protein coding RNA 116|micropeptide in mitochondria|micropeptide regulator of beta-oxidation|small integral membrane protein 37', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110211529, end_position_on_the_genomic_accession=110212547, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    205327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205327, CurrentID=0, Status='live', Symbol='C2orf69', Aliases=['COXPD53'], description='chromosome 2 open reading frame 69', other_designations='UPF0565 protein C2orf69', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=199911293, end_position_on_the_genomic_accession=199928273, orientation='plus', exon_count=2, OMIM=[619219], no_hdr0=''),
    205428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205428, CurrentID=0, Status='live', Symbol='DIPK2A', Aliases=['C3orf58', 'DIA1', 'GoPro49', 'HASF'], description='divergent protein kinase domain 2A', other_designations='divergent protein kinase domain 2A|Golgi Protein of 49 kDa|Golgi protein GoPro49|UPF0672 protein C3orf58|deleted in autism 1|deleted in autism protein 1|hypoxia and AKT-induced stem cell factor|hypoxia and Akt induced stem cell factor', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=143971798, end_position_on_the_genomic_accession=143992368, orientation='plus', exon_count=4, OMIM=[612200], no_hdr0=''),
    205564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205564, CurrentID=0, Status='live', Symbol='SENP5', Aliases=[], description='SUMO specific peptidase 5', other_designations='sentrin-specific protease 5|SUMO1/sentrin specific peptidase 5|SUMO1/sentrin specific protease 5|sentrin/SUMO-specific protease SENP5', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196867897, end_position_on_the_genomic_accession=196934714, orientation='plus', exon_count=11, OMIM=[612845], no_hdr0=''),
    205717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205717, CurrentID=0, Status='live', Symbol='USF3', Aliases=['KIAA2018'], description='upstream transcription factor family member 3', other_designations='basic helix-loop-helix domain-containing protein USF3', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113648385, end_position_on_the_genomic_accession=113696657, orientation='minus', exon_count=7, OMIM=[617568], no_hdr0=''),
    205860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=205860, CurrentID=0, Status='live', Symbol='TRIML2', Aliases=['SPRYD6'], description='tripartite motif family like 2', other_designations='probable E3 ubiquitin-protein ligase TRIML2|RING-type E3 ubiquitin transferase TRIML2|SPRY domain-containing protein 6|tripartite motif family-like protein 2', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=188091255, end_position_on_the_genomic_accession=188109603, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    206338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=206338, CurrentID=0, Status='live', Symbol='LVRN', Aliases=['APQ', 'AQPEP', 'TAQPEP'], description='laeverin', other_designations='aminopeptidase Q|AP-Q|CHL2 antigen', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115962475, end_position_on_the_genomic_accession=116027606, orientation='plus', exon_count=20, OMIM=[610046], no_hdr0=''),
    206358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=206358, CurrentID=0, Status='live', Symbol='SLC36A1', Aliases=['Dct1', 'LYAAT1', 'PAT1', 'TRAMD3'], description='solute carrier family 36 member 1', other_designations='proton-coupled amino acid transporter 1|lysosomal amino acid transporter 1|proton/amino acid transporter 1|solute carrier family 36 (proton/amino acid symporter), member 1', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151411344, end_position_on_the_genomic_accession=151556318, orientation='plus', exon_count=27, OMIM=[606561], no_hdr0=''),
    206412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=206412, CurrentID=0, Status='live', Symbol='C6orf163', Aliases=[], description='chromosome 6 open reading frame 163', other_designations='uncharacterized protein C6orf163', map_location='6q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87344813, end_position_on_the_genomic_accession=87365463, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    207063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=207063, CurrentID=0, Status='live', Symbol='DHRSX', Aliases=['CXorf11', 'DHRS5X', 'DHRS5YY', 'DHRSY', 'SDR46C1', 'SDR7C6', 'DHRSX'], description='dehydrogenase/reductase X-linked', other_designations='dehydrogenase/reductase SDR family member on chromosome X|dehydrogenase/reductase (SDR family) X chromosome|dehydrogenase/reductase (SDR family) X-linked|dehydrogenase/reductase (SDR family) Y-linked|short chain dehydrogenase/reductase family 46C member 1|short chain dehydrogenase/reductase family 7C member 6', map_location='Xp22.33 and Yp11.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=2219506, end_position_on_the_genomic_accession=2500976, orientation='minus', exon_count=7, OMIM=[301034], no_hdr0=''),
    219285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219285, CurrentID=0, Status='live', Symbol='SAMD9L', Aliases=['ATXPC', 'C7orf6', 'DRIF2', 'M7MLS1', 'UEF1'], description='sterile alpha motif domain containing 9 like', other_designations='sterile alpha motif domain-containing protein 9-like|SAM domain-containing protein 9-like', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93130056, end_position_on_the_genomic_accession=93148385, orientation='minus', exon_count=6, OMIM=[611170], no_hdr0=''),
    219287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219287, CurrentID=0, Status='live', Symbol='AMER2', Aliases=['FAM123A'], description='APC membrane recruitment protein 2', other_designations='APC membrane recruitment protein 2|family with sequence similarity 123A|protein FAM123A', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=25161679, end_position_on_the_genomic_accession=25172451, orientation='minus', exon_count=3, OMIM=[614659], no_hdr0=''),
    219293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219293, CurrentID=0, Status='live', Symbol='ATAD3C', Aliases=[], description='ATPase family AAA domain containing 3C', other_designations='ATPase family AAA domain-containing protein 3C|ATPase family, AAA domain containing 3A', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1449689, end_position_on_the_genomic_accession=1470163, orientation='plus', exon_count=12, OMIM=[617227], no_hdr0=''),
    219333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219333, CurrentID=0, Status='live', Symbol='USP12', Aliases=['UBH1L1', 'USP12'], description='ubiquitin specific peptidase 12', other_designations='ubiquitin carboxyl-terminal hydrolase 12|deubiquitinating enzyme 12|ubiquitin specific protease 12 like 1|ubiquitin thioesterase 12|ubiquitin thiolesterase 12|ubiquitin-hydrolyzing enzyme 1|ubiquitin-specific-processing protease 12', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27066154, end_position_on_the_genomic_accession=27171811, orientation='minus', exon_count=10, OMIM=[603091], no_hdr0=''),
    219348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219348, CurrentID=0, Status='live', Symbol='PLAC9', Aliases=[], description='placenta associated 9', other_designations='placenta-specific protein 9|placenta specific 9', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80131661, end_position_on_the_genomic_accession=80145359, orientation='plus', exon_count=5, OMIM=[612857], no_hdr0=''),
    219402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219402, CurrentID=0, Status='live', Symbol='MTIF3', Aliases=['IF3mt'], description='mitochondrial translational initiation factor 3', other_designations='translation initiation factor IF-3, mitochondrial|IF-3(Mt)', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27435639, end_position_on_the_genomic_accession=27450897, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    219409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219409, CurrentID=0, Status='live', Symbol='GSX1', Aliases=['GSH1', 'Gsh-1'], description='GS homeobox 1', other_designations='GS homeobox 1|GS homeo box protein 1|genomic screened homeo box 1|homeobox protein Gsh-1', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27792483, end_position_on_the_genomic_accession=27794768, orientation='plus', exon_count=2, OMIM=[616542], no_hdr0=''),
    219417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219417, CurrentID=0, Status='live', Symbol='OR8U1', Aliases=[], description='olfactory receptor family 8 subfamily U member 1', other_designations='olfactory receptor 8U1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56375624, end_position_on_the_genomic_accession=56376553, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219428, CurrentID=0, Status='live', Symbol='OR4C16', Aliases=['OR11-135'], description='olfactory receptor family 4 subfamily C member 16', other_designations='olfactory receptor 4C16|olfactory receptor OR11-135', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55572128, end_position_on_the_genomic_accession=55573060, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219429, CurrentID=0, Status='live', Symbol='OR4C11', Aliases=['OR11-136P', 'OR4C11'], description='olfactory receptor family 4 subfamily C member 11', other_designations='olfactory receptor 4C11|olfactory receptor OR11-136|olfactory receptor, family 4, subfamily C, member 11 pseudogene', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55602360, end_position_on_the_genomic_accession=55607645, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    219431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219431, CurrentID=0, Status='live', Symbol='OR4S2', Aliases=['OR11-137P', 'OST725', 'OR4S2'], description='olfactory receptor family 4 subfamily S member 2', other_designations='olfactory receptor 4S2|olfactory receptor OR11-137|olfactory receptor, family 4, subfamily S, member 2 pseudogene', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55648327, end_position_on_the_genomic_accession=55652854, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219432, CurrentID=0, Status='live', Symbol='OR4C6', Aliases=['OR11-138'], description='olfactory receptor family 4 subfamily C member 6', other_designations='olfactory receptor 4C6|olfactory receptor OR11-138', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55662201, end_position_on_the_genomic_accession=55666096, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219436, CurrentID=0, Status='live', Symbol='OR5D14', Aliases=['OR11-141', 'OR11-150'], description='olfactory receptor family 5 subfamily D member 14', other_designations='olfactory receptor 5D14|olfactory receptor OR11-141|olfactory receptor OR11-150', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55795556, end_position_on_the_genomic_accession=55796500, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219437, CurrentID=0, Status='live', Symbol='OR5L1', Aliases=['OR11-151', 'OST262'], description='olfactory receptor family 5 subfamily L member 1', other_designations='olfactory receptor 5L1|olfactory receptor OR11-151', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55811367, end_position_on_the_genomic_accession=55812476, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219438, CurrentID=0, Status='live', Symbol='OR5D18', Aliases=['OR11-143'], description='olfactory receptor family 5 subfamily D member 18', other_designations='olfactory receptor 5D18|olfactory receptor OR11-143|olfactory receptor OR11-152', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55819630, end_position_on_the_genomic_accession=55820571, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219447, CurrentID=0, Status='live', Symbol='OR5AS1', Aliases=['OR11-168'], description='olfactory receptor family 5 subfamily AS member 1', other_designations='olfactory receptor 5AS1|olfactory receptor OR11-168', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56027654, end_position_on_the_genomic_accession=56038191, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219453, CurrentID=0, Status='live', Symbol='OR8K5', Aliases=['OR11-174'], description='olfactory receptor family 8 subfamily K member 5', other_designations='olfactory receptor 8K5|olfactory receptor OR11-174', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56159394, end_position_on_the_genomic_accession=56160317, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219464, CurrentID=0, Status='live', Symbol='OR5T2', Aliases=['OR11-177'], description='olfactory receptor family 5 subfamily T member 2', other_designations='olfactory receptor 5T2|olfactory receptor OR11-177', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56231282, end_position_on_the_genomic_accession=56234255, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219469, CurrentID=0, Status='live', Symbol='OR8H1', Aliases=['OR11-180'], description='olfactory receptor family 8 subfamily H member 1', other_designations='olfactory receptor 8H1|olfactory receptor OR11-180', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56288462, end_position_on_the_genomic_accession=56292254, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219473, CurrentID=0, Status='live', Symbol='OR8K3', Aliases=['OR11-181'], description='olfactory receptor family 8 subfamily K member 3 (gene/pseudogene)', other_designations='olfactory receptor 8K3|olfactory receptor OR11-181|olfactory receptor, family 8, subfamily K, member 3', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56315144, end_position_on_the_genomic_accession=56320639, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    219477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219477, CurrentID=0, Status='live', Symbol='OR8J1', Aliases=['OR11-183'], description='olfactory receptor family 8 subfamily J member 1', other_designations='olfactory receptor 8J1|olfactory receptor OR11-183', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56354291, end_position_on_the_genomic_accession=56361511, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219479, CurrentID=0, Status='live', Symbol='OR8U3', Aliases=['OR11-185', 'OR5R1', 'OR5R1P'], description='olfactory receptor family 8 subfamily U member 3', other_designations='olfactory receptor 8U3|olfactory receptor 5R1|olfactory receptor OR11-185|olfactory receptor family 5 subfamily R member 1|olfactory receptor, family 5, subfamily R, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56417258, end_position_on_the_genomic_accession=56418232, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219482, CurrentID=0, Status='live', Symbol='OR5M3', Aliases=['OR11-191'], description='olfactory receptor family 5 subfamily M member 3', other_designations='olfactory receptor 5M3|olfactory receptor OR11-191', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56469274, end_position_on_the_genomic_accession=56473352, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219484, CurrentID=0, Status='live', Symbol='OR5M8', Aliases=['OR11-194'], description='olfactory receptor family 5 subfamily M member 8', other_designations='olfactory receptor 5M8|olfactory receptor OR11-194', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56490435, end_position_on_the_genomic_accession=56491370, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219487, CurrentID=0, Status='live', Symbol='OR5M11', Aliases=['OR11-199'], description='olfactory receptor family 5 subfamily M member 11', other_designations='olfactory receptor 5M11|olfactory receptor OR11-199 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56542340, end_position_on_the_genomic_accession=56543257, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219493, CurrentID=0, Status='live', Symbol='OR5AR1', Aliases=['OR11-209'], description='olfactory receptor family 5 subfamily AR member 1', other_designations='olfactory receptor 5AR1|olfactory receptor OR11-209', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56663686, end_position_on_the_genomic_accession=56664618, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219527, CurrentID=0, Status='live', Symbol='LRRC55', Aliases=[], description='leucine rich repeat containing 55', other_designations='leucine-rich repeat-containing protein 55|BK channel auxiliary gamma subunit LRRC55|BK channel auxilliary gamma snit LRRC55', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57181953, end_position_on_the_genomic_accession=57191717, orientation='plus', exon_count=2, OMIM=[615213], no_hdr0=''),
    219537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219537, CurrentID=0, Status='live', Symbol='SMTNL1', Aliases=['CHASM'], description='smoothelin like 1', other_designations='smoothelin-like protein 1|calponin homology-associated smooth muscle protein', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57537595, end_position_on_the_genomic_accession=57550272, orientation='plus', exon_count=8, OMIM=[613664], no_hdr0=''),
    219539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219539, CurrentID=0, Status='live', Symbol='YPEL4', Aliases=[], description='yippee like 4', other_designations='protein yippee-like 4', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57645087, end_position_on_the_genomic_accession=57649912, orientation='minus', exon_count=6, OMIM=[609725], no_hdr0=''),
    219541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219541, CurrentID=0, Status='live', Symbol='MED19', Aliases=['DT2P1G7', 'LCMR1AS', 'MED19'], description='mediator complex subunit 19', other_designations='mediator of RNA polymerase II transcription subunit 19|lung cancer metastasis-related protein 1|mediator of RNA polymerase II transcription, subunit 19 homolog|putative mediator subunit MED19AS protein', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57703709, end_position_on_the_genomic_accession=57712323, orientation='minus', exon_count=5, OMIM=[612385], no_hdr0=''),
    219557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219557, CurrentID=0, Status='live', Symbol='TEX47', Aliases=['C7orf62'], description='testis expressed 47', other_designations='testis-expressed protein 47|uncharacterized protein C7orf62', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=88794106, end_position_on_the_genomic_accession=88797937, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219578, CurrentID=0, Status='live', Symbol='ZNF804B', Aliases=[], description='zinc finger protein 804B', other_designations='zinc finger protein 804B|zinc finger 804B', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=88759700, end_position_on_the_genomic_accession=89338528, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    219595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219595, CurrentID=0, Status='live', Symbol='FOLH1B', Aliases=['FOLH2', 'FOLHP', 'GCP3', 'GCPIII', 'PSM', 'PSMA-LIKE', 'PSMAL'], description='folate hydrolase 1B', other_designations='putative N-acetylated-alpha-linked acidic dipeptidase|N-acetylated-alpha-linked-acidic dipeptidase|NAALADase|cell growth-inhibiting gene 26 protein|folate hydrolase 2|folate hydrolase pseudogene|glutamate carboxypeptidase III|prostate-specific membrane antigen-like protein|putative folate hydrolase 1B', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89637580, end_position_on_the_genomic_accession=89698718, orientation='plus', exon_count=19, OMIM=[609020], no_hdr0=''),
    219621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219621, CurrentID=0, Status='live', Symbol='CABCOCO1', Aliases=['C10orf107'], description='ciliary associated calcium binding coiled-coil 1', other_designations='ciliary-associated calcium-binding coiled-coil protein 1|uncharacterized protein C10orf107', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=61662929, end_position_on_the_genomic_accession=61766766, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    219623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219623, CurrentID=0, Status='live', Symbol='TMEM26', Aliases=[], description='transmembrane protein 26', other_designations='transmembrane protein 26', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=61406642, end_position_on_the_genomic_accession=61453381, orientation='minus', exon_count=10, OMIM=[617803], no_hdr0=''),
    219654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219654, CurrentID=0, Status='live', Symbol='ZCCHC24', Aliases=['C10orf56', 'Z3CXXC8'], description='zinc finger CCHC-type containing 24', other_designations='zinc finger CCHC domain-containing protein 24|zinc finger, 3CxxC-type 8|zinc finger, CCHC domain containing 24', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79382325, end_position_on_the_genomic_accession=79445624, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    219670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219670, CurrentID=0, Status='live', Symbol='ENKUR', Aliases=['C10orf63', 'CFAP106'], description='enkurin, TRPC channel interacting protein', other_designations='enkurin', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=24981985, end_position_on_the_genomic_accession=25062327, orientation='minus', exon_count=9, OMIM=[611025], no_hdr0=''),
    219681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219681, CurrentID=0, Status='live', Symbol='ARMC3', Aliases=['CT81', 'KU-CT-1'], description='armadillo repeat containing 3', other_designations='armadillo repeat-containing protein 3|beta-catenin-like protein|cancer/testis antigen 81', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22928028, end_position_on_the_genomic_accession=23038527, orientation='plus', exon_count=22, OMIM=[611226], no_hdr0=''),
    219699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219699, CurrentID=0, Status='live', Symbol='UNC5B', Aliases=['UNC5H2', 'p53RDL1'], description='unc-5 netrin receptor B', other_designations='netrin receptor UNC5B|p53-regulated receptor for death and life protein 1|protein unc-5 homolog 2|protein unc-5 homolog B|transmembrane receptor Unc5H2|unc-5 homolog 2|unc-5 homolog B', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71212535, end_position_on_the_genomic_accession=71302879, orientation='plus', exon_count=20, OMIM=[607870], no_hdr0=''),
    219736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219736, CurrentID=0, Status='live', Symbol='STOX1', Aliases=['C10orf24'], description='storkhead box 1', other_designations='storkhead-box protein 1|winged-helix domain-containing protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68827531, end_position_on_the_genomic_accession=68895942, orientation='plus', exon_count=6, OMIM=[609397], no_hdr0=''),
    219738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219738, CurrentID=0, Status='live', Symbol='FAM241B', Aliases=['C10orf35'], description='family with sequence similarity 241 member B', other_designations='protein FAM241B|uncharacterized protein C10orf35', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=69630241, end_position_on_the_genomic_accession=69633599, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    219743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219743, CurrentID=0, Status='live', Symbol='TYSND1', Aliases=['NET41'], description='trypsin like peroxisomal matrix peptidase 1', other_designations='peroxisomal leader peptide-processing protease|peroxisomal cysteine endopeptidase|peroxisomal matrix protein-processing protease|peroxisome leader peptide-processing protease|trypsin domain containing 1|trypsin domain-containing protein 1', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70137981, end_position_on_the_genomic_accession=70146700, orientation='minus', exon_count=6, OMIM=[611017], no_hdr0=''),
    219749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219749, CurrentID=0, Status='live', Symbol='ZNF25', Aliases=['KOX19', 'Zfp9'], description='zinc finger protein 25', other_designations='zinc finger protein 25|zinc finger protein 25 (KOX 19)|zinc finger protein KOX19', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=37949573, end_position_on_the_genomic_accession=37976647, orientation='minus', exon_count=13, OMIM=[194528], no_hdr0=''),
    219770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219770, CurrentID=0, Status='live', Symbol='GJD4', Aliases=['CX40.1'], description='gap junction protein delta 4', other_designations='gap junction delta-4 protein|connexin-40.1|connexin40.1|gap junction protein, delta 4, 40.1kDa', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=35605341, end_position_on_the_genomic_accession=35608935, orientation='plus', exon_count=2, OMIM=[611922], no_hdr0=''),
    219771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219771, CurrentID=0, Status='live', Symbol='CCNY', Aliases=['C10orf9', 'CBCP1', 'CCNX', 'CFP1'], description='cyclin Y', other_designations='cyclin-Y|cyc-Y|cyclin box protein 1|cyclin fold protein 1|cyclin-X|cyclin-box carrying protein 1', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=35247025, end_position_on_the_genomic_accession=35572667, orientation='plus', exon_count=14, OMIM=[612786], no_hdr0=''),
    219790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219790, CurrentID=0, Status='live', Symbol='RTKN2', Aliases=['PLEKHK1', 'bA531F24.1'], description='rhotekin 2', other_designations='rhotekin-2|PH domain-containing family K member 1|pleckstrin homology domain-containing family K member 1', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=62159131, end_position_on_the_genomic_accession=62268879, orientation='minus', exon_count=18, OMIM=[618450], no_hdr0=''),
    219793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219793, CurrentID=0, Status='live', Symbol='TBATA', Aliases=['C10orf27', 'SPATIAL'], description='thymus, brain and testes associated', other_designations='protein TBATA|stromal protein associated with thymii and lymph node homolog|thymus, brain and testes-associated protein', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=70771237, end_position_on_the_genomic_accession=70785401, orientation='minus', exon_count=19, OMIM=[612640], no_hdr0=''),
    219844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219844, CurrentID=0, Status='live', Symbol='HYLS1', Aliases=['HLS'], description='HYLS1 centriolar and ciliogenesis associated', other_designations='hydrolethalus syndrome protein 1|hydrolethalus syndrome 1', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125883614, end_position_on_the_genomic_accession=125900646, orientation='plus', exon_count=5, OMIM=[610693], no_hdr0=''),
    219854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219854, CurrentID=0, Status='live', Symbol='TMEM218', Aliases=[], description='transmembrane protein 218', other_designations='transmembrane protein 218', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125094389, end_position_on_the_genomic_accession=125111759, orientation='minus', exon_count=8, OMIM=[619285], no_hdr0=''),
    219855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219855, CurrentID=0, Status='live', Symbol='SLC37A2', Aliases=['SPX2', 'pp11662'], description='solute carrier family 37 member 2', other_designations='glucose-6-phosphate exchanger SLC37A2|solute carrier family 37 (glucose-6-phosphate transporter), member 2|solute carrier family 37 (glycerol-3-phosphate transporter), member 2|sugar phosphate exchanger 2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125063067, end_position_on_the_genomic_accession=125090516, orientation='plus', exon_count=19, OMIM=[619136], no_hdr0=''),
    219858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219858, CurrentID=0, Status='live', Symbol='OR8B12', Aliases=['OR11-317'], description='olfactory receptor family 8 subfamily B member 12', other_designations='olfactory receptor 8B12|olfactory receptor OR11-317', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124542722, end_position_on_the_genomic_accession=124543654, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219865, CurrentID=0, Status='live', Symbol='OR8G5', Aliases=['OR11-298P', 'OR8G6', 'OR8G5'], description='olfactory receptor family 8 subfamily G member 5', other_designations='olfactory receptor 8G5|olfactory receptor 8G6|olfactory receptor OR11-298|olfactory receptor, family 8, subfamily G, member 5 pseudogene|olfactory receptor, family 8, subfamily G, member 6', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124256376, end_position_on_the_genomic_accession=124266224, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219869, CurrentID=0, Status='live', Symbol='OR10G8', Aliases=['OR11-274', 'OR11-282'], description='olfactory receptor family 10 subfamily G member 8', other_designations='olfactory receptor 10G8|olfactory receptor OR11-274 pseudogene|olfactory receptor OR11-282', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124026798, end_position_on_the_genomic_accession=124030634, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219870, CurrentID=0, Status='live', Symbol='OR10G9', Aliases=['OR10G10P'], description='olfactory receptor family 10 subfamily G member 9', other_designations='olfactory receptor 10G9|olfactory receptor 10G10|olfactory receptor OR11-272', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124023013, end_position_on_the_genomic_accession=124023948, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219873, CurrentID=0, Status='live', Symbol='OR10S1', Aliases=['OR11-279'], description='olfactory receptor family 10 subfamily S member 1', other_designations='olfactory receptor 10S1|olfactory receptor OR11-279', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123976696, end_position_on_the_genomic_accession=123977691, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219874, CurrentID=0, Status='live', Symbol='OR6T1', Aliases=['OR11-277'], description='olfactory receptor family 6 subfamily T member 1', other_designations='olfactory receptor 6T1|olfactory receptor OR11-277', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123941474, end_position_on_the_genomic_accession=123943844, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219875, CurrentID=0, Status='live', Symbol='OR4D5', Aliases=['OR11-276'], description='olfactory receptor family 4 subfamily D member 5', other_designations='olfactory receptor 4D5|olfactory receptor OR11-276', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123939617, end_position_on_the_genomic_accession=123940573, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219899, CurrentID=0, Status='live', Symbol='TBCEL', Aliases=['El', 'LRRC35'], description='tubulin folding cofactor E like', other_designations='tubulin-specific chaperone cofactor E-like protein|E-like|catastrophin|leucine rich repeat containing 35|leucine-rich repeat-containing protein 35|tubulin-specific chaperone e-like', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=121024102, end_position_on_the_genomic_accession=121090776, orientation='plus', exon_count=9, OMIM=[610451], no_hdr0=''),
    219902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219902, CurrentID=0, Status='live', Symbol='TLCD5', Aliases=['TMEM136'], description='TLC domain containing 5', other_designations='TLC domain-containing protein 5|transmembrane protein 136', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120325299, end_position_on_the_genomic_accession=120333686, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    219927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219927, CurrentID=0, Status='live', Symbol='MRPL21', Aliases=['L21mt', 'MRP-L21'], description='mitochondrial ribosomal protein L21', other_designations='39S ribosomal protein L21, mitochondrial|mitochondrial large ribosomal subunit protein bL21m', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=68891276, end_position_on_the_genomic_accession=68903832, orientation='minus', exon_count=7, OMIM=[611834], no_hdr0=''),
    219931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219931, CurrentID=0, Status='live', Symbol='TPCN2', Aliases=['SHEP10', 'TPC2'], description='two pore segment channel 2', other_designations='two pore calcium channel protein 2|voltage-dependent calcium channel protein TPC2', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69048932, end_position_on_the_genomic_accession=69090597, orientation='plus', exon_count=25, OMIM=[612163], no_hdr0=''),
    219938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219938, CurrentID=0, Status='live', Symbol='SPATA19', Aliases=['CT132', 'SPAS1', 'spergen1'], description='spermatogenesis associated 19', other_designations='spermatogenesis-associated protein 19, mitochondrial|cancer/testis antigen 132|spergen-1|spermatogenic cell-specific gene 1 protein|spermatogenic specific-gene1|testis secretory sperm-binding protein Li 243mP', map_location='11q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=133835930, end_position_on_the_genomic_accession=133845533, orientation='minus', exon_count=8, OMIM=[609805], no_hdr0=''),
    219952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219952, CurrentID=0, Status='live', Symbol='OR6Q1', Aliases=['OR11-226'], description='olfactory receptor family 6 subfamily Q member 1', other_designations='olfactory receptor 6Q1|olfactory receptor OR11-226', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58030953, end_position_on_the_genomic_accession=58031906, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219954, CurrentID=0, Status='live', Symbol='OR9I1', Aliases=['OR11-228'], description='olfactory receptor family 9 subfamily I member 1', other_designations='olfactory receptor 9I1|olfactory receptor OR11-228', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58116742, end_position_on_the_genomic_accession=58125530, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    219956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219956, CurrentID=0, Status='live', Symbol='OR9Q1', Aliases=[], description='olfactory receptor family 9 subfamily Q member 1', other_designations='olfactory receptor 9Q1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58023881, end_position_on_the_genomic_accession=58181616, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    219957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219957, CurrentID=0, Status='live', Symbol='OR9Q2', Aliases=['OR9Q2P'], description='olfactory receptor family 9 subfamily Q member 2', other_designations='olfactory receptor 9Q2|olfactory receptor, family 9, subfamily Q, member 2 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58189070, end_position_on_the_genomic_accession=58194053, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219958, CurrentID=0, Status='live', Symbol='OR1S2', Aliases=['OR11-231'], description='olfactory receptor family 1 subfamily S member 2', other_designations='olfactory receptor 1S2|olfactory receptor OR11-231', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58203204, end_position_on_the_genomic_accession=58204181, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219959, CurrentID=0, Status='live', Symbol='OR1S1', Aliases=['OR11-232', 'OST034'], description='olfactory receptor family 1 subfamily S member 1', other_designations='olfactory receptor 1S1|olfactory receptor OR11-232', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58212720, end_position_on_the_genomic_accession=58216084, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219960, CurrentID=0, Status='live', Symbol='OR10Q1', Aliases=['OR11-233'], description='olfactory receptor family 10 subfamily Q member 1', other_designations='olfactory receptor 10Q1|olfactory receptor OR11-233', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58227882, end_position_on_the_genomic_accession=58228918, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219965, CurrentID=0, Status='live', Symbol='OR5B17', Aliases=['OR11-237', 'OR5B20P'], description='olfactory receptor family 5 subfamily B member 17', other_designations='olfactory receptor 5B17|olfactory receptor 5B20|olfactory receptor OR11-237|olfactory receptor, family 5, subfamily B, member 20 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58358124, end_position_on_the_genomic_accession=58359069, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219968, CurrentID=0, Status='live', Symbol='OR5B21', Aliases=[], description='olfactory receptor family 5 subfamily B member 21', other_designations='olfactory receptor 5B21', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58506807, end_position_on_the_genomic_accession=58508105, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    219970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219970, CurrentID=0, Status='live', Symbol='GLYATL2', Aliases=['BXMAS2-10', 'GATF-B'], description='glycine-N-acyltransferase like 2', other_designations='glycine N-acyltransferase-like protein 2|acyl-CoA:glycine N-acyltransferase-like protein 2|glycine acyltransferase family-B', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58834065, end_position_on_the_genomic_accession=58905840, orientation='minus', exon_count=9, OMIM=[614762], no_hdr0=''),
    219972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219972, CurrentID=0, Status='live', Symbol='MPEG1', Aliases=['IMD77', 'MPG1', 'MPS1', 'Mpg-1', 'P-2'], description='macrophage expressed 1', other_designations='macrophage-expressed gene 1 protein|macrophage expressed gene 1|macrophage gene 1 protein|perforin 2', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59208510, end_position_on_the_genomic_accession=59212927, orientation='minus', exon_count=1, OMIM=[610390], no_hdr0=''),
    219981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219981, CurrentID=0, Status='live', Symbol='OR5A2', Aliases=[], description='olfactory receptor family 5 subfamily A member 2', other_designations='olfactory receptor 5A2|olfactory receptor OR11-248', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59416969, end_position_on_the_genomic_accession=59426413, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    219982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219982, CurrentID=0, Status='live', Symbol='OR5A1', Aliases=['OR11-249P', 'OST181', 'OR5A1'], description='olfactory receptor family 5 subfamily A member 1', other_designations='olfactory receptor 5A1|olfactory receptor OR11-249|olfactory receptor, family 5, subfamily A, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59436469, end_position_on_the_genomic_accession=59451380, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    219983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219983, CurrentID=0, Status='live', Symbol='OR4D6', Aliases=['OR11-250'], description='olfactory receptor family 4 subfamily D member 6', other_designations='olfactory receptor 4D6|olfactory receptor OR11-250', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59456961, end_position_on_the_genomic_accession=59457905, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219986, CurrentID=0, Status='live', Symbol='OR4D11', Aliases=['OR4D11P'], description='olfactory receptor family 4 subfamily D member 11', other_designations='olfactory receptor 4D11|olfactory receptor OR11-252 pseudogene|olfactory receptor, family 4, subfamily D, member 11 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59503576, end_position_on_the_genomic_accession=59504511, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    219988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219988, CurrentID=0, Status='live', Symbol='PATL1', Aliases=['Pat1b', 'hPat1b'], description='PAT1 homolog 1, processing body mRNA decay factor', other_designations='protein PAT1 homolog 1|PAT1-like protein 1|protein PAT1 homolog b|protein associated with topoisomerase II homolog 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59636716, end_position_on_the_genomic_accession=59669037, orientation='minus', exon_count=19, OMIM=[614660], no_hdr0=''),
    219990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219990, CurrentID=0, Status='live', Symbol='OOSP2', Aliases=['OOSP2A', 'PLAC1L', 'TMEM122'], description='oocyte secreted protein 2', other_designations='oocyte-secreted protein 2|placenta-specific 1-like protein|testicular tissue protein Li 142|transmembrane protein 122', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60040409, end_position_on_the_genomic_accession=60048044, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    219995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=219995, CurrentID=0, Status='live', Symbol='MS4A15', Aliases=[], description='membrane spanning 4-domains A15', other_designations='membrane-spanning 4-domains subfamily A member 15', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60756867, end_position_on_the_genomic_accession=60776733, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    220001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220001, CurrentID=0, Status='live', Symbol='VWCE', Aliases=['URG11', 'VWC1'], description='von Willebrand factor C and EGF domains', other_designations='von Willebrand factor C and EGF domain-containing protein|HBV X protein up-regulated gene 11 protein|HBxAg up-regulated gene 11 protein', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61258286, end_position_on_the_genomic_accession=61295316, orientation='minus', exon_count=21, OMIM=[611115], no_hdr0=''),
    220002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220002, CurrentID=0, Status='live', Symbol='CYB561A3', Aliases=['CYBASC3', 'LCYTB'], description='cytochrome b561 family member A3', other_designations='lysosomal membrane ascorbate-dependent ferrireductase CYB561A3|cytochrome b ascorbate-dependent protein 3|cytochrome b, ascorbate dependent 3|lysosomal cytochrome b', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61348745, end_position_on_the_genomic_accession=61362283, orientation='minus', exon_count=8, OMIM=[618757], no_hdr0=''),
    220004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220004, CurrentID=0, Status='live', Symbol='PPP1R32', Aliases=['C11orf66', 'IIIG9'], description='protein phosphatase 1 regulatory subunit 32', other_designations='protein phosphatase 1 regulatory subunit 32', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61481120, end_position_on_the_genomic_accession=61490928, orientation='plus', exon_count=14, OMIM=[619047], no_hdr0=''),
    220032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220032, CurrentID=0, Status='live', Symbol='GDPD4', Aliases=['GDE6'], description='glycerophosphodiester phosphodiesterase domain containing 4', other_designations='glycerophosphodiester phosphodiesterase domain-containing protein 4|GDPD domain containing protein|glycerophosphodiester phosphodiesterase 6|ugpQ', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77216558, end_position_on_the_genomic_accession=77301699, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    220042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220042, CurrentID=0, Status='live', Symbol='DDIAS', Aliases=['C11orf82', 'noxin'], description='DNA damage induced apoptosis suppressor', other_designations='DNA damage-induced apoptosis suppressor protein|nitric oxide-inducible gene protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=82901735, end_position_on_the_genomic_accession=82934659, orientation='plus', exon_count=8, OMIM=[618045], no_hdr0=''),
    220047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220047, CurrentID=0, Status='live', Symbol='CCDC83', Aliases=['CT148', 'HSD9', 'KP-CoT-23'], description='coiled-coil domain containing 83', other_designations='coiled-coil domain-containing protein 83', map_location='11q14.1-q14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85855066, end_position_on_the_genomic_accession=85920017, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    220064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220064, CurrentID=0, Status='live', Symbol='LTO1', Aliases=['CIAB1', 'ORAOV1', 'TAOS1'], description='LTO1 maturation factor of ABCE1', other_designations='protein LTO1 homolog|LTO1, ABCE1 maturation factor|oral cancer overexpressed 1|oral cancer overexpressed protein 1-A|oral cancer-overexpressed protein 1|tumor-amplified and overexpressed sequence 1', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69665563, end_position_on_the_genomic_accession=69675354, orientation='minus', exon_count=5, OMIM=[607224], no_hdr0=''),
    220074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220074, CurrentID=0, Status='live', Symbol='LRTOMT', Aliases=['CFAP111', 'DFNB63', 'LRRC51'], description='leucine rich transmembrane and O-methyltransferase domain containing', other_designations='transmembrane O-methyltransferase|leucine rich transmembrane and 0-methyltransferase domain containing', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72080850, end_position_on_the_genomic_accession=72110782, orientation='plus', exon_count=9, OMIM=[612414], no_hdr0=''),
    220081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220081, CurrentID=0, Status='live', Symbol='ERICH6B', Aliases=['FAM194B'], description='glutamate rich 6B', other_designations='glutamate-rich protein 6B|family with sequence similarity 194, member B|protein FAM194B', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45541203, end_position_on_the_genomic_accession=45615739, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    220082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220082, CurrentID=0, Status='live', Symbol='CBY2', Aliases=['NURIT', 'SPERT'], description='chibby family member 2', other_designations='protein chibby homolog 2|novel leucine zipper testicular protein|spermatid associated|spermatid flower-like structure protein|spermatid-associated protein|testicular tissue protein Li 182|testis-specific leucine zipper protein nurit', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45701030, end_position_on_the_genomic_accession=45714559, orientation='plus', exon_count=5, OMIM=[618614], no_hdr0=''),
    220107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220107, CurrentID=0, Status='live', Symbol='DLEU7', Aliases=[], description='deleted in lymphocytic leukemia 7', other_designations='leukemia-associated protein 7', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=50711026, end_position_on_the_genomic_accession=50843945, orientation='minus', exon_count=4, OMIM=[618634], no_hdr0=''),
    220108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220108, CurrentID=0, Status='live', Symbol='FAM124A', Aliases=[], description='family with sequence similarity 124 member A', other_designations='protein FAM124A|family with sequence similarity 124A', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51222367, end_position_on_the_genomic_accession=51284241, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    220134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220134, CurrentID=0, Status='live', Symbol='SKA1', Aliases=['C18orf24'], description='spindle and kinetochore associated complex subunit 1', other_designations='spindle and kinetochore-associated protein 1|spindle and KT (kinetochore) associated 1', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50375046, end_position_on_the_genomic_accession=50394168, orientation='plus', exon_count=7, OMIM=[616673], no_hdr0=''),
    220136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220136, CurrentID=0, Status='live', Symbol='CFAP53', Aliases=['CCDC11', 'HTX6'], description='cilia and flagella associated protein 53', other_designations='cilia- and flagella-associated protein 53|coiled-coil domain containing 11', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=50227193, end_position_on_the_genomic_accession=50266495, orientation='minus', exon_count=9, OMIM=[614759], no_hdr0=''),
    220164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220164, CurrentID=0, Status='live', Symbol='DOK6', Aliases=['DOK5L', 'HsT3226'], description='docking protein 6', other_designations='docking protein 6|downstream of tyrosine kinase 6', map_location='18q22.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=69400888, end_position_on_the_genomic_accession=69849087, orientation='plus', exon_count=10, OMIM=[611402], no_hdr0=''),
    220202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220202, CurrentID=0, Status='live', Symbol='ATOH7', Aliases=['Math5', 'NCRNA', 'PHPVAR', 'RNANC', 'bHLHa13'], description='atonal bHLH transcription factor 7', other_designations='protein atonal homolog 7|atonal homolog 7|atonal homolog bHLH transcription factor 7|class A basic helix-loop-helix protein 13|helix-loop-helix protein hATH-5', map_location='10q21.3-q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=68230595, end_position_on_the_genomic_accession=68232113, orientation='minus', exon_count=1, OMIM=[609875], no_hdr0=''),
    220213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220213, CurrentID=0, Status='live', Symbol='OTUD1', Aliases=['DUBA7', 'OTDC1'], description='OTU deubiquitinase 1', other_designations='OTU domain-containing protein 1|DUBA-7|OTU domain containing 1', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=23439075, end_position_on_the_genomic_accession=23442377, orientation='plus', exon_count=1, OMIM=[612022], no_hdr0=''),
    220296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220296, CurrentID=0, Status='live', Symbol='HEPACAM', Aliases=['GlialCAM', 'HEPN1', 'MLC2A', 'MLC2B'], description='hepatic and glial cell adhesion molecule', other_designations='hepatocyte cell adhesion molecule|Putative cancer susceptibility gene HEPN1 protein|protein hepaCAM', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124919205, end_position_on_the_genomic_accession=124936412, orientation='minus', exon_count=7, OMIM=[611642], no_hdr0=''),
    220323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220323, CurrentID=0, Status='live', Symbol='OAF', Aliases=['NS5ATP13TP2'], description='out at first homolog', other_designations='out at first protein homolog|HCV NS5A-transactivated protein 13 target protein 2|OAF homolog', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=120211032, end_position_on_the_genomic_accession=120230334, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    220359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220359, CurrentID=0, Status='live', Symbol='TIGD3', Aliases=[], description='tigger transposable element derived 3', other_designations='tigger transposable element-derived protein 3', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65354751, end_position_on_the_genomic_accession=65357613, orientation='plus', exon_count=2, OMIM=[619084], no_hdr0=''),
    220382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220382, CurrentID=0, Status='live', Symbol='FAM181B', Aliases=[], description='family with sequence similarity 181 member B', other_designations='protein FAM181B', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=82729940, end_position_on_the_genomic_accession=82733864, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    220388 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220388, CurrentID=0, Status='live', Symbol='CCDC89', Aliases=[], description='coiled-coil domain containing 89', other_designations='coiled-coil domain-containing protein 89|bc8 orange-interacting protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=85683848, end_position_on_the_genomic_accession=85686195, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    220416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220416, CurrentID=0, Status='live', Symbol='LRRC63', Aliases=[], description='leucine rich repeat containing 63', other_designations='leucine-rich repeat-containing protein 63', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=46211919, end_position_on_the_genomic_accession=46277115, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    220441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220441, CurrentID=0, Status='live', Symbol='RNF152', Aliases=[], description='ring finger protein 152', other_designations='E3 ubiquitin-protein ligase RNF152|RING-type E3 ubiquitin transferase RNF152', map_location='18q21.33', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=61808067, end_position_on_the_genomic_accession=61894420, orientation='minus', exon_count=6, OMIM=[616512], no_hdr0=''),
    220869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220869, CurrentID=0, Status='live', Symbol='CBWD5', Aliases=['CBWD3', 'DC36'], description='COBW domain containing 5', other_designations='COBW domain-containing protein 5|COBW domain-containing protein 3|COBW-like placental protein|Cobalamin synthase W domain-containing protein 3|cobalamin synthase W domain-containing protein 5|cobalamin synthetase W domain-containing protein 5|dopamine responsive protein', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=65666374, end_position_on_the_genomic_accession=65734041, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    220929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220929, CurrentID=0, Status='live', Symbol='ZNF438', Aliases=['bA330O11.1'], description='zinc finger protein 438', other_designations='zinc finger protein 438', map_location='10p11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=30841254, end_position_on_the_genomic_accession=31032407, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    220963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220963, CurrentID=0, Status='live', Symbol='SLC16A9', Aliases=['C10orf36', 'MCT9'], description='solute carrier family 16 member 9', other_designations='monocarboxylate transporter 9|MCT 9|monocarboxylic acid transporter 9|solute carrier family 16 (monocarboxylic acid transporters), member 9', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=59650764, end_position_on_the_genomic_accession=59710079, orientation='minus', exon_count=10, OMIM=[614242], no_hdr0=''),
    220965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220965, CurrentID=0, Status='live', Symbol='FAM13C', Aliases=['FAM13C1'], description='family with sequence similarity 13 member C', other_designations='protein FAM13C|family with sequence similarity 13, member C1', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=59245933, end_position_on_the_genomic_accession=59363181, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    220972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220972, CurrentID=0, Status='live', Symbol='MARCHF8', Aliases=['CMIR', 'MARCH-VIII', 'MARCH8', 'MIR', 'RNF178', 'c-MIR'], description='membrane associated ring-CH-type finger 8', other_designations='E3 ubiquitin-protein ligase MARCHF8|E3 ubiquitin-protein ligase MARCH8|RING finger protein 178|RING-type E3 ubiquitin transferase MARCH8|RING-type E3 ubiquitin transferase MARCHF8|c-mir, cellular modulator of immune recognition|cellular modulator of immune recognition (c-MIR)|membrane associated ring finger 8|membrane-associated RING finger protein 8|membrane-associated RING-CH protein VIII|membrane-associated ring finger (C3HC4) 8, E3 ubiquitin protein ligase', map_location='10q11.21-q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45454585, end_position_on_the_genomic_accession=45594907, orientation='minus', exon_count=13, OMIM=[613335], no_hdr0=''),
    220988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220988, CurrentID=0, Status='live', Symbol='HNRNPA3', Aliases=['2610510D13Rik', 'D10S102', 'FBRNP', 'HNRPA3'], description='heterogeneous nuclear ribonucleoprotein A3', other_designations='heterogeneous nuclear ribonucleoprotein A3|epididymis secretory sperm binding protein', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=177212694, end_position_on_the_genomic_accession=177223959, orientation='plus', exon_count=12, OMIM=[605372], no_hdr0=''),
    220992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=220992, CurrentID=0, Status='live', Symbol='ZNF485', Aliases=[], description='zinc finger protein 485', other_designations='zinc finger protein 485|Zinc finger protein 93 (Zinc finger protein HTF34)', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43606438, end_position_on_the_genomic_accession=43620173, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    221002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221002, CurrentID=0, Status='live', Symbol='RASGEF1A', Aliases=['CG4853'], description='RasGEF domain family member 1A', other_designations='ras-GEF domain-containing family member 1A|CG4853 gene product', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43194535, end_position_on_the_genomic_accession=43267065, orientation='minus', exon_count=15, OMIM=[614531], no_hdr0=''),
    221035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221035, CurrentID=0, Status='live', Symbol='REEP3', Aliases=['C10orf74', 'Yip2b'], description='receptor accessory protein 3', other_designations='receptor expression-enhancing protein 3', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=63521353, end_position_on_the_genomic_accession=63625128, orientation='plus', exon_count=10, OMIM=[609348], no_hdr0=''),
    221037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221037, CurrentID=0, Status='live', Symbol='JMJD1C', Aliases=['KDM3C', 'TRIP-8', 'TRIP8'], description='jumonji domain containing 1C', other_designations='probable JmjC domain-containing histone demethylation protein 2C|TR-interacting protein 8|thyroid hormone receptor interactor 8|thyroid receptor-interacting protein 8', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=63167221, end_position_on_the_genomic_accession=63521890, orientation='minus', exon_count=30, OMIM=[604503], no_hdr0=''),
    221044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221044, CurrentID=0, Status='live', Symbol='UCMA', Aliases=['C10orf49', 'GRP', 'GRP/UCMA'], description='upper zone of growth plate and cartilage matrix associated', other_designations='unique cartilage matrix-associated protein|Gla-rich protein', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13221766, end_position_on_the_genomic_accession=13234374, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    221061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221061, CurrentID=0, Status='live', Symbol='FAM171A1', Aliases=['APCN', 'C10orf38'], description='family with sequence similarity 171 member A1', other_designations='protein FAM171A1|astroprincin', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15211643, end_position_on_the_genomic_accession=15374532, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    221074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221074, CurrentID=0, Status='live', Symbol='SLC39A12', Aliases=['LZT-Hs8', 'ZIP-12', 'bA570F3.1'], description='solute carrier family 39 member 12', other_designations='zinc transporter ZIP12|LIV-1 subfamily of ZIP zinc transporter 8|solute carrier family 39 (metal ion transporter), member 12|solute carrier family 39 (zinc transporter), member 12|zrt- and Irt-like protein 12', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17951918, end_position_on_the_genomic_accession=18043285, orientation='plus', exon_count=13, OMIM=[608734], no_hdr0=''),
    221078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221078, CurrentID=0, Status='live', Symbol='NSUN6', Aliases=['4933414E04Rik', 'ARL5B-AS1', 'NOPD1'], description='NOP2/Sun RNA methyltransferase 6', other_designations='tRNA (cytosine(72)-C(5))-methyltransferase NSUN6|ARL5B antisense RNA 1|NOL1/NOP2/Sun and PUA domain-containing protein 1|NOL1/NOP2/Sun domain family, member 6|NOP2/Sun RNA methyltransferase family member 6|NOP2/Sun domain family, member 6|nucleolar protein (NOL1/NOP2/sun) and PUA domains 1|putative methyltransferase NSUN6', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=18512582, end_position_on_the_genomic_accession=18659264, orientation='minus', exon_count=19, OMIM=[617199], no_hdr0=''),
    221079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221079, CurrentID=0, Status='live', Symbol='ARL5B', Aliases=['ARL8'], description='ADP ribosylation factor like GTPase 5B', other_designations='ADP-ribosylation factor-like protein 5B|ADP-ribosylation factor-like 5B|ADP-ribosylation factor-like 8|ADP-ribosylation factor-like protein 8|ADP-ribosylation-like factor 8', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=18659335, end_position_on_the_genomic_accession=18681639, orientation='plus', exon_count=7, OMIM=[608909], no_hdr0=''),
    221091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221091, CurrentID=0, Status='live', Symbol='LRRN4CL', Aliases=[], description='LRRN4 C-terminal like', other_designations='LRRN4 C-terminal-like protein', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62686406, end_position_on_the_genomic_accession=62689530, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    221092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221092, CurrentID=0, Status='live', Symbol='HNRNPUL2', Aliases=['HNRPUL2', 'SAF-A2'], description='heterogeneous nuclear ribonucleoprotein U like 2', other_designations='heterogeneous nuclear ribonucleoprotein U-like protein 2|scaffold-attachment factor A2', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62712630, end_position_on_the_genomic_accession=62727457, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    221120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221120, CurrentID=0, Status='live', Symbol='ALKBH3', Aliases=['ABH3', 'DEPC-1', 'DEPC1', 'PCA1', 'hABH3'], description='alkB homolog 3, alpha-ketoglutarate dependent dioxygenase', other_designations='alpha-ketoglutarate-dependent dioxygenase alkB homolog 3|alkB homolog 3, alpha-ketoglutaratedependent dioxygenase|alkB, alkylation repair homolog 3|alkylated DNA repair protein alkB homolog 3|prostate cancer antigen-1', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=43880831, end_position_on_the_genomic_accession=43920274, orientation='plus', exon_count=10, OMIM=[610603], no_hdr0=''),
    221143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221143, CurrentID=0, Status='live', Symbol='EEF1AKMT1', Aliases=['ESP13', 'N6AMT2'], description='EEF1A lysine methyltransferase 1', other_designations='EEF1A lysine methyltransferase 1|N-6 adenine-specific DNA methyltransferase 2 (putative)|eukaryotic translation elongation factor 1 alpha lysine methyltransferase 1|n(6)-adenine-specific DNA methyltransferase 2|protein-lysine N-methyltransferase N6AMT2', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=20728731, end_position_on_the_genomic_accession=20773961, orientation='minus', exon_count=6, OMIM=[617793], no_hdr0=''),
    221150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221150, CurrentID=0, Status='live', Symbol='SKA3', Aliases=['C13orf3', 'RAMA1'], description='spindle and kinetochore associated complex subunit 3', other_designations='spindle and kinetochore-associated protein 3', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21153595, end_position_on_the_genomic_accession=21176565, orientation='minus', exon_count=9, OMIM=[619247], no_hdr0=''),
    221154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221154, CurrentID=0, Status='live', Symbol='MICU2', Aliases=['1110008L20Rik', 'EFHA1'], description='mitochondrial calcium uptake 2', other_designations='calcium uptake protein 2, mitochondrial|EF hand domain family A1|EF hand domain family, member A1|EF-hand domain-containing family member A1|Smhs2 homolog', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21492691, end_position_on_the_genomic_accession=21604205, orientation='minus', exon_count=13, OMIM=[610632], no_hdr0=''),
    221178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221178, CurrentID=0, Status='live', Symbol='SPATA13', Aliases=['ARHGEF29', 'ASEF2'], description='spermatogenesis associated 13', other_designations='spermatogenesis-associated protein 13|APC-stimulated guanine nucleotide exchange factor 2|adenomatous polyposis coli stimulated exchange factor 2', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23979802, end_position_on_the_genomic_accession=24307069, orientation='plus', exon_count=20, OMIM=[613324], no_hdr0=''),
    221184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221184, CurrentID=0, Status='live', Symbol='CPNE2', Aliases=['COPN2', 'CPN2'], description='copine 2', other_designations='copine-2|copine II', map_location='16q13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57092583, end_position_on_the_genomic_accession=57148369, orientation='plus', exon_count=16, OMIM=[604206], no_hdr0=''),
    221188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221188, CurrentID=0, Status='live', Symbol='ADGRG5', Aliases=['GPR114', 'PGR27'], description='adhesion G protein-coupled receptor G5', other_designations='adhesion G-protein coupled receptor G5|G protein-coupled receptor 114|G protein-coupled receptor PGR27|probable G-protein coupled receptor 114', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57529339, end_position_on_the_genomic_accession=57578182, orientation='plus', exon_count=13, OMIM=[616965], no_hdr0=''),
    221191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221191, CurrentID=0, Status='live', Symbol='PRSS54', Aliases=['CT67', 'KLKBL4'], description='serine protease 54', other_designations='inactive serine protease 54|cancer/testis antigen 67|plasma kallikrein-like protein 4|protease, serine 54|testis tissue sperm-binding protein Li 40a', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=58279997, end_position_on_the_genomic_accession=58295025, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    221223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221223, CurrentID=0, Status='live', Symbol='CES5A', Aliases=['CAUXIN', 'CES4C1', 'CES5', 'CES7', 'HEL126'], description='carboxylesterase 5A', other_designations='carboxylesterase 5A|carboxylesterase 5|carboxylesterase 7|carboxylesterase-like urinary excreted protein homolog|epididymis luminal protein 126', map_location='16q12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=55846154, end_position_on_the_genomic_accession=55956031, orientation='minus', exon_count=15, OMIM=[618678], no_hdr0=''),
    221264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221264, CurrentID=0, Status='live', Symbol='AK9', Aliases=['AK 9', 'AKD1', 'AKD2', 'C6orf199', 'C6orf224', 'dJ70A9.1'], description='adenylate kinase 9', other_designations='adenylate kinase 9|adenylate kinase domain containing 1|adenylate kinase domain containing 2', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109492855, end_position_on_the_genomic_accession=109691202, orientation='minus', exon_count=49, OMIM=[615358], no_hdr0=''),
    221294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221294, CurrentID=0, Status='live', Symbol='NT5DC1', Aliases=['C6orf200', 'LP2642', 'NT5C2L1'], description="5'-nucleotidase domain containing 1", other_designations="5'-nucleotidase domain-containing protein 1|5'-nucleotidase, cytosolic II-like 1 protein", map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116100833, end_position_on_the_genomic_accession=116249497, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    221301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221301, CurrentID=0, Status='live', Symbol='CALHM4', Aliases=['C6orf78', 'FAM26D'], description='calcium homeostasis modulator family member 4', other_designations='calcium homeostasis modulator protein 4|family with sequence similarity 26 member D|protein FAM26D', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116529021, end_position_on_the_genomic_accession=116561127, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    221302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221302, CurrentID=0, Status='live', Symbol='ZUP1', Aliases=['C6orf113', 'DUB', 'ZUFSP'], description='zinc finger containing ubiquitin peptidase 1', other_designations='zinc finger-containing ubiquitin peptidase 1|lys-63-specific deubiquitinase ZUFSP|ubiquitin carboxyl-terminal hydrolase ZUFSP|zinc finger with UFM1-specific peptidase domain protein', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116635618, end_position_on_the_genomic_accession=116668766, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    221303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221303, CurrentID=0, Status='live', Symbol='FAM162B', Aliases=['C6orf189', 'bA86F4.2'], description='family with sequence similarity 162 member B', other_designations='protein FAM162B', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116752197, end_position_on_the_genomic_accession=116765719, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    221322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221322, CurrentID=0, Status='live', Symbol='TBC1D32', Aliases=['BROMI', 'C6orf170', 'C6orf171'], description='TBC1 domain family member 32', other_designations='protein broad-minded|broad-minded homolog', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=121079494, end_position_on_the_genomic_accession=121335384, orientation='minus', exon_count=45, OMIM=[615867], no_hdr0=''),
    221336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221336, CurrentID=0, Status='live', Symbol='BEND6', Aliases=['C6orf65'], description='BEN domain containing 6', other_designations='BEN domain-containing protein 6', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=56954981, end_position_on_the_genomic_accession=57027652, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    221357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221357, CurrentID=0, Status='live', Symbol='GSTA5', Aliases=[], description='glutathione S-transferase alpha 5', other_designations='glutathione S-transferase A5|GST class-alpha member 5|glutathione S-transferase A5-5', map_location='6p12.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=52831692, end_position_on_the_genomic_accession=52846245, orientation='minus', exon_count=7, OMIM=[607605], no_hdr0=''),
    221391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221391, CurrentID=0, Status='live', Symbol='OPN5', Aliases=['GPR136', 'GRP136', 'PGR12', 'TMEM13'], description='opsin 5', other_designations='opsin-5|G-protein coupled receptor 136|neuropsin|transmembrane protein 13', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47782037, end_position_on_the_genomic_accession=47831088, orientation='plus', exon_count=12, OMIM=[609042], no_hdr0=''),
    221393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221393, CurrentID=0, Status='live', Symbol='ADGRF4', Aliases=['GPR115', 'PGR18'], description='adhesion G protein-coupled receptor F4', other_designations='adhesion G protein-coupled receptor F4|G-protein coupled receptor PGR18|probable G-protein coupled receptor 115|seven transmembrane helix receptor', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47698580, end_position_on_the_genomic_accession=47722014, orientation='plus', exon_count=10, OMIM=[614268], no_hdr0=''),
    221395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221395, CurrentID=0, Status='live', Symbol='ADGRF5', Aliases=['GPR116', 'KPG_001'], description='adhesion G protein-coupled receptor F5', other_designations='adhesion G protein-coupled receptor F5|G-protein coupled receptor 116|Ig-Hepta homolog|probable G-protein coupled receptor 116', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46852522, end_position_on_the_genomic_accession=46954954, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    221400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221400, CurrentID=0, Status='live', Symbol='TDRD6', Aliases=['CT41.2', 'NY-CO-45', 'SPATA36', 'TDR2', 'bA446F17.4'], description='tudor domain containing 6', other_designations='tudor domain-containing protein 6|antigen NY-CO-45|cancer/testis antigen 41.2|spermatogenesis associated 36', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46680268, end_position_on_the_genomic_accession=46704319, orientation='plus', exon_count=5, OMIM=[611200], no_hdr0=''),
    221409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221409, CurrentID=0, Status='live', Symbol='SPATS1', Aliases=['DDIP', 'SPATA8', 'SRSP1'], description='spermatogenesis associated serine rich 1', other_designations='spermatogenesis-associated serine-rich protein 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44342650, end_position_on_the_genomic_accession=44380179, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    221421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221421, CurrentID=0, Status='live', Symbol='RSPH9', Aliases=['C6orf206', 'CILD12', 'MRPS18AL1'], description='radial spoke head component 9', other_designations='radial spoke head protein 9 homolog|radial spoke head 9 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43645030, end_position_on_the_genomic_accession=43672600, orientation='plus', exon_count=7, OMIM=[612648], no_hdr0=''),
    221424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221424, CurrentID=0, Status='live', Symbol='LRRC73', Aliases=['C6orf154'], description='leucine rich repeat containing 73', other_designations='leucine-rich repeat-containing protein 73', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43506965, end_position_on_the_genomic_accession=43510346, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    221443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221443, CurrentID=0, Status='live', Symbol='OARD1', Aliases=['C6orf130', 'TARG1', 'dJ34B21.3'], description='O-acyl-ADP-ribose deacylase 1', other_designations='ADP-ribose glycohydrolase OARD1|O-acetyl-ADP-ribose deacetylase 1|O-acetyl-ADP-ribose deacetylase C6orf130|[Protein ADP-ribosylglutamate] hydrolase OARD1|terminal ADP-ribose protein glycohydrolase 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41064772, end_position_on_the_genomic_accession=41097787, orientation='minus', exon_count=9, OMIM=[614393], no_hdr0=''),
    221458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221458, CurrentID=0, Status='live', Symbol='KIF6', Aliases=['C6orf102', 'dJ1043E3.1', 'dJ137F1.4', 'dJ188D3.1'], description='kinesin family member 6', other_designations='kinesin-like protein KIF6', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=39329990, end_position_on_the_genomic_accession=39725408, orientation='minus', exon_count=28, OMIM=[613919], no_hdr0=''),
    221468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221468, CurrentID=0, Status='live', Symbol='TMEM217', Aliases=['C6orf128', 'dJ355M6.2'], description='transmembrane protein 217', other_designations='transmembrane protein 217', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37212181, end_position_on_the_genomic_accession=37259034, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    221472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221472, CurrentID=0, Status='live', Symbol='FGD2', Aliases=['ZFYVE4'], description='FYVE, RhoGEF and PH domain containing 2', other_designations='FYVE, RhoGEF and PH domain-containing protein 2|FGD1 family, member 2|FLJ00276 protein|epididymis secretory sperm binding protein|zinc finger FYVE domain-containing protein 4', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37005655, end_position_on_the_genomic_accession=37029072, orientation='plus', exon_count=20, OMIM=[605091], no_hdr0=''),
    221476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221476, CurrentID=0, Status='live', Symbol='PI16', Aliases=['CD364', 'CRISP9', 'MSMBBP', 'PSPBP'], description='peptidase inhibitor 16', other_designations='peptidase inhibitor 16|PSP94-binding protein|cysteine-rich secretory protein 9|microseminoprotein, beta-binding protein|protease inhibitor 16', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36948296, end_position_on_the_genomic_accession=36964837, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    221477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221477, CurrentID=0, Status='live', Symbol='C6orf89', Aliases=['BRAP', 'PS1TP5TP1'], description='chromosome 6 open reading frame 89', other_designations='bombesin receptor-activated protein C6orf89|amfion', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36834886, end_position_on_the_genomic_accession=36928964, orientation='plus', exon_count=17, OMIM=[616642], no_hdr0=''),
    221481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221481, CurrentID=0, Status='live', Symbol='ARMC12', Aliases=['C6orf81'], description='armadillo repeat containing 12', other_designations='armadillo repeat-containing protein 12', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35733726, end_position_on_the_genomic_accession=35749079, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    221491 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221491, CurrentID=0, Status='live', Symbol='SMIM29', Aliases=['C6orf1', 'LBH'], description='small integral membrane protein 29', other_designations='small integral membrane protein 29|uncharacterized protein C6orf1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34246395, end_position_on_the_genomic_accession=34249006, orientation='minus', exon_count=5, OMIM=[611419], no_hdr0=''),
    221496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221496, CurrentID=0, Status='live', Symbol='LEMD2', Aliases=['CTRCT42', 'LEM2', 'MARUPS', 'NET25', 'dJ482C21.1'], description='LEM domain nuclear envelope protein 2', other_designations='LEM domain-containing protein 2|LEM domain containing 2|hLEM2|lamina-associated polypeptide-emerin-MAN1 domain containing 2', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33771213, end_position_on_the_genomic_accession=33794274, orientation='minus', exon_count=10, OMIM=[616312], no_hdr0=''),
    221504 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221504, CurrentID=0, Status='live', Symbol='ZBTB9', Aliases=['ZNF919'], description='zinc finger and BTB domain containing 9', other_designations='zinc finger and BTB domain-containing protein 9', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33454576, end_position_on_the_genomic_accession=33457544, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    221527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221527, CurrentID=0, Status='live', Symbol='ZBTB12', Aliases=['Bat9', 'C6orf46', 'D6S59E', 'G10', 'NG35'], description='zinc finger and BTB domain containing 12', other_designations='zinc finger and BTB domain-containing protein 12|HLA-B-associated transcript 9', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31899194, end_position_on_the_genomic_accession=31902331, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    221545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221545, CurrentID=0, Status='live', Symbol='C6orf136', Aliases=[], description='chromosome 6 open reading frame 136', other_designations='uncharacterized protein C6orf136', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30647133, end_position_on_the_genomic_accession=30653207, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    221613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221613, CurrentID=0, Status='live', Symbol='H2AC1', Aliases=['H2AA', 'H2AFR', 'HIST1H2AA', 'TH2A', 'bA317E16.2'], description='H2A clustered histone 1', other_designations='histone H2A type 1-A|H2A histone family, member R|histone 1, H2aa|histone H2A/r|histone cluster 1 H2A family member a|histone cluster 1, H2aa', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25726063, end_position_on_the_genomic_accession=25726562, orientation='minus', exon_count=1, OMIM=[613499], no_hdr0=''),
    221656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221656, CurrentID=0, Status='live', Symbol='KDM1B', Aliases=['AOF1', 'C6orf193', 'LSD2'], description='lysine demethylase 1B', other_designations='lysine-specific histone demethylase 1B|flavin-containing amine oxidase domain-containing protein 1|lysine (K)-specific demethylase 1B|lysine-specific histone demethylase 2', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=18155388, end_position_on_the_genomic_accession=18223854, orientation='plus', exon_count=23, OMIM=[613081], no_hdr0=''),
    221662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221662, CurrentID=0, Status='live', Symbol='RBM24', Aliases=['RNPC6', 'dJ259A10.1'], description='RNA binding motif protein 24', other_designations='RNA-binding protein 24|RNA-binding region (RNP1, RRM) containing 6|RNA-binding region-containing protein 6', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17281361, end_position_on_the_genomic_accession=17293875, orientation='plus', exon_count=7, OMIM=[617603], no_hdr0=''),
    221687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221687, CurrentID=0, Status='live', Symbol='RNF182', Aliases=[], description='ring finger protein 182', other_designations='E3 ubiquitin-protein ligase RNF182|RING-type E3 ubiquitin transferase RNF182', map_location='6p23', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13924446, end_position_on_the_genomic_accession=13980310, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    221692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221692, CurrentID=0, Status='live', Symbol='PHACTR1', Aliases=['DEE70', 'EIEE70', 'RPEL', 'RPEL1', 'dJ257A7.2'], description='phosphatase and actin regulator 1', other_designations='phosphatase and actin regulator 1|RPEL repeat containing 1', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=12716635, end_position_on_the_genomic_accession=13290462, orientation='plus', exon_count=22, OMIM=[608723], no_hdr0=''),
    221710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221710, CurrentID=0, Status='live', Symbol='SMIM13', Aliases=['C6orf228'], description='small integral membrane protein 13', other_designations='small integral membrane protein 13|UPF0766 protein C6orf228', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=11093834, end_position_on_the_genomic_accession=11138733, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    221711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221711, CurrentID=0, Status='live', Symbol='SYCP2L', Aliases=['C6orf177', 'NO145', 'dJ62D2.1'], description='synaptonemal complex protein 2 like', other_designations='synaptonemal complex protein 2-like|145 kDa nucleolar protein homolog|SCP-2-like', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10887052, end_position_on_the_genomic_accession=10974309, orientation='plus', exon_count=30, OMIM=[616799], no_hdr0=''),
    221749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221749, CurrentID=0, Status='live', Symbol='PXDC1', Aliases=['C6orf145'], description='PX domain containing 1', other_designations='PX domain-containing protein 1|PX domain-containing protein C6orf145', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3722604, end_position_on_the_genomic_accession=3752297, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    221785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221785, CurrentID=0, Status='live', Symbol='ZSCAN25', Aliases=['ZNF498'], description='zinc finger and SCAN domain containing 25', other_designations='zinc finger and SCAN domain-containing protein 25|zinc finger protein 498', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99616608, end_position_on_the_genomic_accession=99738689, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    221786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221786, CurrentID=0, Status='live', Symbol='FAM200A', Aliases=['C7orf38'], description='family with sequence similarity 200 member A', other_designations='protein FAM200A', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99546295, end_position_on_the_genomic_accession=99559395, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    221806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221806, CurrentID=0, Status='live', Symbol='VWDE', Aliases=[], description='von Willebrand factor D and EGF domains', other_designations='von Willebrand factor D and EGF domain-containing protein', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=12330885, end_position_on_the_genomic_accession=12403903, orientation='minus', exon_count=33, OMIM=[], no_hdr0=''),
    221823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221823, CurrentID=0, Status='live', Symbol='PRPS1L1', Aliases=['PRPS1', 'PRPS3', 'PRPSL', 'PRS-III'], description='phosphoribosyl pyrophosphate synthetase 1 like 1', other_designations='ribose-phosphate pyrophosphokinase 3|PRPS1-like 1|phosphoribosyl pyrophosphate synthase 1-like 1|phosphoribosyl pyrophosphate synthase III|phosphoribosylpyrophosphate synthetase subunit III|ribose-phosphate diphosphokinase catalytic chain III|ribose-phosphate pyrophosphokinase III', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=18026770, end_position_on_the_genomic_accession=18027846, orientation='minus', exon_count=1, OMIM=[611566], no_hdr0=''),
    221830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221830, CurrentID=0, Status='live', Symbol='POLR1F', Aliases=['A43', 'RPA43', 'TWISTNB'], description='RNA polymerase I subunit F', other_designations='DNA-directed RNA polymerase I subunit RPA43|DNA-directed RNA polymerase I subunit F|twist neighbor protein', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=19695461, end_position_on_the_genomic_accession=19709037, orientation='minus', exon_count=4, OMIM=[608312], no_hdr0=''),
    221833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221833, CurrentID=0, Status='live', Symbol='SP8', Aliases=['BTD'], description='Sp8 transcription factor', other_designations='transcription factor Sp8|specificity protein 8', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=20782279, end_position_on_the_genomic_accession=20786886, orientation='minus', exon_count=3, OMIM=[608306], no_hdr0=''),
    221895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221895, CurrentID=0, Status='live', Symbol='JAZF1', Aliases=['TIP27', 'ZNF802'], description='JAZF zinc finger 1', other_designations='juxtaposed with another zinc finger protein 1|TAK1-interacting protein 27|juxtaposed with another zinc finger gene 1|zinc finger protein 802', map_location='7p15.2-p15.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=27830573, end_position_on_the_genomic_accession=28180795, orientation='minus', exon_count=6, OMIM=[606246], no_hdr0=''),
    221908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221908, CurrentID=0, Status='live', Symbol='PPP1R35', Aliases=['C7orf47'], description='protein phosphatase 1 regulatory subunit 35', other_designations='protein phosphatase 1 regulatory subunit 35|UPF0683 protein C7orf47', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100435282, end_position_on_the_genomic_accession=100436615, orientation='minus', exon_count=5, OMIM=[618937], no_hdr0=''),
    221914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221914, CurrentID=0, Status='live', Symbol='GPC2', Aliases=[], description='glypican 2', other_designations='glypican-2|cerebroglycan proteoglycan|glypican proteoglycan 2, cerebroglycan proteoglycan', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100169606, end_position_on_the_genomic_accession=100177381, orientation='minus', exon_count=10, OMIM=[618446], no_hdr0=''),
    221927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221927, CurrentID=0, Status='live', Symbol='BRAT1', Aliases=['BAAT1', 'C7orf27', 'NEDCAS', 'RMFSL'], description='BRCA1 associated ATM activator 1', other_designations='BRCA1-associated ATM activator 1|BRCA1-associated protein required for ATM activation protein 1|HEAT repeat-containing protein C7orf27', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2537810, end_position_on_the_genomic_accession=2555753, orientation='minus', exon_count=16, OMIM=[614506], no_hdr0=''),
    221935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221935, CurrentID=0, Status='live', Symbol='SDK1', Aliases=[], description='sidekick cell adhesion molecule 1', other_designations='protein sidekick-1|sidekick homolog 1, cell adhesion molecule', map_location='7p22.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=3301252, end_position_on_the_genomic_accession=4269000, orientation='plus', exon_count=49, OMIM=[607216], no_hdr0=''),
    221937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221937, CurrentID=0, Status='live', Symbol='FOXK1', Aliases=['FOXK1L'], description='forkhead box K1', other_designations='forkhead box protein K1|MNF|myocyte nuclear factor', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=4682295, end_position_on_the_genomic_accession=4771442, orientation='plus', exon_count=9, OMIM=[616302], no_hdr0=''),
    221938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221938, CurrentID=0, Status='live', Symbol='MMD2', Aliases=['PAQR10'], description='monocyte to macrophage differentiation associated 2', other_designations='monocyte to macrophage differentiation factor 2|monocyte-to-macrophage differentiation-associated protein 2|progestin and adipoQ receptor family member 10|progestin and adipoQ receptor family member X', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=4892245, end_position_on_the_genomic_accession=4959187, orientation='minus', exon_count=10, OMIM=[614581], no_hdr0=''),
    221955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221955, CurrentID=0, Status='live', Symbol='DAGLB', Aliases=['DAGLBETA', 'KCCR13L'], description='diacylglycerol lipase beta', other_designations='diacylglycerol lipase-beta|DAGL-beta|DGL-beta|PUFA-specific triacylglycerol lipase|sn1-specific diacylglycerol lipase beta', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6409129, end_position_on_the_genomic_accession=6447954, orientation='minus', exon_count=15, OMIM=[614016], no_hdr0=''),
    221960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221960, CurrentID=0, Status='live', Symbol='CCZ1B', Aliases=['C7orf28A', 'C7orf28B', 'CCZ1', 'H_NH0577018.2'], description='CCZ1 homolog B, vacuolar protein trafficking and biogenesis associated', other_designations='vacuolar fusion protein CCZ1 homolog B|CCZ1 homolog, vacuolar protein trafficking and biogenesis associated B|CCZ1 vacuolar protein trafficking and biogenesis associated B|CCZ1 vacuolar protein trafficking and biogenesis associated homolog B|H_DJ1163J12.2', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6798937, end_position_on_the_genomic_accession=6826275, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    221981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=221981, CurrentID=0, Status='live', Symbol='THSD7A', Aliases=[], description='thrombospondin type 1 domain containing 7A', other_designations='thrombospondin type-1 domain-containing protein 7A|thrombospondin, type I, domain containing 7A', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=11370365, end_position_on_the_genomic_accession=11832198, orientation='minus', exon_count=30, OMIM=[612249], no_hdr0=''),
    222008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222008, CurrentID=0, Status='live', Symbol='VSTM2A', Aliases=['VSTM2'], description='V-set and transmembrane domain containing 2A', other_designations='V-set and transmembrane domain-containing protein 2A|V-set and transmembrane domain containing 2|hypothetical protein MGC33530', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=54542064, end_position_on_the_genomic_accession=54571072, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    222068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222068, CurrentID=0, Status='live', Symbol='TMED4', Aliases=['ERS25', 'GMP25iso', 'HNLF', 'p24a3', 'p24alpha3'], description='transmembrane p24 trafficking protein 4', other_designations='transmembrane emp24 domain-containing protein 4|endoplasmic reticulum stress-response protein 25 kDa|p24 family protein alpha-3|putative NF-kappa-B-activating protein 156|putative NFkB activating protein HNLF|transmembrane emp24 protein transport domain containing 4', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=44577894, end_position_on_the_genomic_accession=44582231, orientation='minus', exon_count=5, OMIM=[612038], no_hdr0=''),
    222166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222166, CurrentID=0, Status='live', Symbol='MTURN', Aliases=['C7orf41', 'Ells1'], description='maturin, neural progenitor differentiation regulator homolog', other_designations='maturin|UPF0452 protein C7orf41|maturin neural progenitor differentiation regulator protein homolog|protein Ells1', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30134986, end_position_on_the_genomic_accession=30162764, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    222171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222171, CurrentID=0, Status='live', Symbol='PRR15', Aliases=[], description='proline rich 15', other_designations='proline-rich protein 15', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=29563835, end_position_on_the_genomic_accession=29567300, orientation='plus', exon_count=3, OMIM=[618344], no_hdr0=''),
    222183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222183, CurrentID=0, Status='live', Symbol='SRRM3', Aliases=[], description='serine/arginine repetitive matrix 3', other_designations='serine/arginine repetitive matrix protein 3|SRRM2-like protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76201896, end_position_on_the_genomic_accession=76287287, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    222194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222194, CurrentID=0, Status='live', Symbol='RSBN1L', Aliases=[], description='round spermatid basic protein 1 like', other_designations='lysine-specific demethylase RSBN1L|round spermatid basic protein 1-like protein', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77696459, end_position_on_the_genomic_accession=77783022, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    222223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222223, CurrentID=0, Status='live', Symbol='ELAPOR2', Aliases=['EIG121L', 'KIAA1324L'], description='endosome-lysosome associated apoptosis and autophagy regulator family member 2', other_designations='endosome/lysosome-associated apoptosis and autophagy regulator family member 2|EIG121-like|KIAA1324 like|UPF0577 protein KIAA1324-like|estrogen-induced gene 121-like protein', map_location='7q21.12', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=86876906, end_position_on_the_genomic_accession=87059714, orientation='minus', exon_count=26, OMIM=[614048], no_hdr0=''),
    222229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222229, CurrentID=0, Status='live', Symbol='LRWD1', Aliases=['CENP-33', 'ORCA'], description='leucine rich repeats and WD repeat domain containing 1', other_designations='leucine-rich repeat and WD repeat-containing protein 1|ORC-associated protein|centromere protein 33|origin recognition complex-associated protein|testicular tissue protein Li 4', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102464984, end_position_on_the_genomic_accession=102473168, orientation='plus', exon_count=15, OMIM=[615167], no_hdr0=''),
    222234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222234, CurrentID=0, Status='live', Symbol='FAM185A', Aliases=[], description='family with sequence similarity 185 member A', other_designations='protein FAM185A', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102748999, end_position_on_the_genomic_accession=102850723, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    222235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222235, CurrentID=0, Status='live', Symbol='FBXL13', Aliases=['CFAP169', 'DRC6', 'Fbl13'], description='F-box and leucine rich repeat protein 13', other_designations='dynein regulatory complex subunit 6|F-box/LRR-repeat protein 13|cilia and flagella associated protein 169', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102810966, end_position_on_the_genomic_accession=103075216, orientation='minus', exon_count=31, OMIM=[609080], no_hdr0=''),
    222236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222236, CurrentID=0, Status='live', Symbol='NAPEPLD', Aliases=['C7orf18', 'FMP30', 'NAPE-PLD'], description='N-acyl phosphatidylethanolamine phospholipase D', other_designations='N-acyl-phosphatidylethanolamine-hydrolyzing phospholipase D|NAPE-hydrolyzing phospholipase D', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103099776, end_position_on_the_genomic_accession=103150001, orientation='minus', exon_count=18, OMIM=[612334], no_hdr0=''),
    222255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222255, CurrentID=0, Status='live', Symbol='ATXN7L1', Aliases=['ATXN7L4'], description='ataxin 7 like 1', other_designations='ataxin-7-like protein 1|ataxin 7-like 4|ataxin-7-like protein 4', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105604772, end_position_on_the_genomic_accession=105876599, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    222256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222256, CurrentID=0, Status='live', Symbol='CDHR3', Aliases=['CDH28'], description='cadherin related family member 3', other_designations='cadherin-related family member 3|cadherin-like protein 28', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105876750, end_position_on_the_genomic_accession=106036432, orientation='plus', exon_count=24, OMIM=[615610], no_hdr0=''),
    222389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222389, CurrentID=0, Status='live', Symbol='BEND7', Aliases=['C10orf30'], description='BEN domain containing 7', other_designations='BEN domain-containing protein 7', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=13438481, end_position_on_the_genomic_accession=13529014, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    222484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222484, CurrentID=0, Status='live', Symbol='LNX2', Aliases=['PDZRN1'], description='ligand of numb-protein X 2', other_designations='ligand of Numb protein X 2|PDZ domain containing ring finger 1|PDZ domain-containing RING finger protein 1|numb-binding protein 2', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27545913, end_position_on_the_genomic_accession=27621106, orientation='minus', exon_count=11, OMIM=[609733], no_hdr0=''),
    222487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222487, CurrentID=0, Status='live', Symbol='ADGRG3', Aliases=['GPR97', 'PB99', 'PGR26'], description='adhesion G protein-coupled receptor G3', other_designations='adhesion G protein-coupled receptor G3|G protein-coupled receptor 97|G-protein coupled receptor PGR26|probable G-protein coupled receptor 97', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57663998, end_position_on_the_genomic_accession=57689378, orientation='plus', exon_count=13, OMIM=[618441], no_hdr0=''),
    222537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222537, CurrentID=0, Status='live', Symbol='HS3ST5', Aliases=['3-OST-5', '3OST5', 'HS3OST5', 'NBLA04021'], description='heparan sulfate-glucosamine 3-sulfotransferase 5', other_designations='heparan sulfate glucosamine 3-O-sulfotransferase 5|h3-OST-5|heparan sulfate (glucosamine) 3-O-sulfotransferase 5|heparan sulfate 3-O-sulfotransferase 5|heparan sulfate 3-OST-5|heparan sulfate D-glucosaminyl 3-O-sulfotransferase 5', map_location='6q21-q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=114055586, end_position_on_the_genomic_accession=114343023, orientation='minus', exon_count=10, OMIM=[609407], no_hdr0=''),
    222545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222545, CurrentID=0, Status='live', Symbol='GPRC6A', Aliases=['GPCR', 'bA86F4.3'], description='G protein-coupled receptor class C group 6 member A', other_designations='G-protein coupled receptor family C group 6 member A|G protein-coupled receptor, family C, group 6, member A|G-protein coupled receptor GPCR33|predicted with SOSUI analysis|seven transmembrane helix receptor', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116788512, end_position_on_the_genomic_accession=116831128, orientation='minus', exon_count=8, OMIM=[613572], no_hdr0=''),
    222546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222546, CurrentID=0, Status='live', Symbol='RFX6', Aliases=['MTCHRS', 'MTFS', 'RFXDC1', 'dJ955L16.1'], description='regulatory factor X6', other_designations='DNA-binding protein RFX6|regulatory factor X domain-containing protein 1|regulatory factor X, 6', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116877218, end_position_on_the_genomic_accession=116932163, orientation='plus', exon_count=20, OMIM=[612659], no_hdr0=''),
    222553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222553, CurrentID=0, Status='live', Symbol='SLC35F1', Aliases=['C6orf169', 'dJ230I3.1'], description='solute carrier family 35 member F1', other_designations='solute carrier family 35 member F1', map_location='6q22.2-q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117907226, end_position_on_the_genomic_accession=118317676, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    222584 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222584, CurrentID=0, Status='live', Symbol='FAM83B', Aliases=['C6orf143'], description='family with sequence similarity 83 member B', other_designations='protein FAM83B', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=54846323, end_position_on_the_genomic_accession=54945099, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    222611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222611, CurrentID=0, Status='live', Symbol='ADGRF2', Aliases=['GPR111', 'PGR20', 'hGPCR35'], description='adhesion G protein-coupled receptor F2', other_designations='adhesion G-protein coupled receptor F2|G protein-coupled receptor 111|probable G-protein coupled receptor 111', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47656472, end_position_on_the_genomic_accession=47697794, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    222642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222642, CurrentID=0, Status='live', Symbol='TSPO2', Aliases=['BZRPL1'], description='translocator protein 2', other_designations='translocator protein 2|benzodiazapine receptor (peripheral)-like 1|peripheral-type benzodiazepine receptor-like protein 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41041344, end_position_on_the_genomic_accession=41044337, orientation='plus', exon_count=6, OMIM=[619409], no_hdr0=''),
    222643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222643, CurrentID=0, Status='live', Symbol='UNC5CL', Aliases=['MUXA', 'ZUD'], description='unc-5 family C-terminal like', other_designations='UNC5C-like protein|ZU5 and death domain containing|protein unc-5 homolog C-like|unc-5 homolog C-like', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41026895, end_position_on_the_genomic_accession=41039221, orientation='minus', exon_count=9, OMIM=[617464], no_hdr0=''),
    222658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222658, CurrentID=0, Status='live', Symbol='KCTD20', Aliases=['C6orf69', 'dJ108K11.3'], description='potassium channel tetramerization domain containing 20', other_designations='BTB/POZ domain-containing protein KCTD20|potassium channel tetramerisation domain containing 20', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36442772, end_position_on_the_genomic_accession=36491143, orientation='plus', exon_count=11, OMIM=[615932], no_hdr0=''),
    222659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222659, CurrentID=0, Status='live', Symbol='PXT1', Aliases=['STEPP'], description='peroxisomal testis enriched protein 1', other_designations='peroxisomal testis-specific protein 1|peroxisomal, testis specific 1|small testis-specific peroxisomal protein', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36390551, end_position_on_the_genomic_accession=36442854, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    222662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222662, CurrentID=0, Status='live', Symbol='LHFPL5', Aliases=['DFNB67', 'TMHS', 'dJ510O8.8'], description='LHFPL tetraspan subfamily member 5', other_designations='LHFPL tetraspan subfamily member 5 protein|LHFP-like protein 5|lipoma HMGIC fusion partner-like 5 protein|tetraspan membrane protein of hair cell stereocilia', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35805352, end_position_on_the_genomic_accession=35824070, orientation='plus', exon_count=4, OMIM=[609427], no_hdr0=''),
    222663 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222663, CurrentID=0, Status='live', Symbol='SCUBE3', Aliases=['CEGF3', 'SSFSC2'], description='signal peptide, CUB domain and EGF like domain containing 3', other_designations='signal peptide, CUB and EGF-like domain-containing protein 3|CUB domain and EGF-like repeat containing 3', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35213956, end_position_on_the_genomic_accession=35253079, orientation='plus', exon_count=24, OMIM=[614708], no_hdr0=''),
    222696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222696, CurrentID=0, Status='live', Symbol='ZSCAN23', Aliases=['ZNF390', 'ZNF453', 'dJ29K1.3', 'dJ29K1.3.1'], description='zinc finger and SCAN domain containing 23', other_designations='zinc finger and SCAN domain-containing protein 23|zinc finger protein 390|zinc finger protein 453', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28425516, end_position_on_the_genomic_accession=28443554, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    222698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222698, CurrentID=0, Status='live', Symbol='NKAPL', Aliases=['C6orf194', 'bA424I5.1'], description='NFKB activating protein like', other_designations='NKAP-like protein', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28259297, end_position_on_the_genomic_accession=28260958, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    222826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222826, CurrentID=0, Status='live', Symbol='FAM217A', Aliases=['C6orf146'], description='family with sequence similarity 217 member A', other_designations='protein FAM217A|uncharacterized protein C6orf146', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4050333, end_position_on_the_genomic_accession=4087344, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    222865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222865, CurrentID=0, Status='live', Symbol='TMEM130', Aliases=[], description='transmembrane protein 130', other_designations='transmembrane protein 130', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=98846490, end_position_on_the_genomic_accession=98870014, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    222894 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222894, CurrentID=0, Status='live', Symbol='FERD3L', Aliases=['N-TWIST', 'NATO3', 'NTWIST', 'PTFB', 'bHLHa31'], description='Fer3 like bHLH transcription factor', other_designations='fer3-like protein|basic helix-loop-helix protein N-twist|class A basic helix-loop-helix protein 31|nephew of atonal 3|neuronal twist|pancreas-specific transcription factor b', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=19144782, end_position_on_the_genomic_accession=19145421, orientation='minus', exon_count=1, OMIM=[617578], no_hdr0=''),
    222950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222950, CurrentID=0, Status='live', Symbol='NYAP1', Aliases=['C7orf51'], description='neuronal tyrosine phosphorylated phosphoinositide-3-kinase adaptor 1', other_designations='neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adapter 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100483927, end_position_on_the_genomic_accession=100494802, orientation='plus', exon_count=7, OMIM=[615477], no_hdr0=''),
    222962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222962, CurrentID=0, Status='live', Symbol='SLC29A4', Aliases=['ENT4', 'PMAT'], description='solute carrier family 29 member 4', other_designations='equilibrative nucleoside transporter 4|plasma membrane monoamine transporter|solute carrier family 29 (equilibrative nucleoside transporter), member 4|solute carrier family 29 (nucleoside transporters), member 4', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5274311, end_position_on_the_genomic_accession=5306912, orientation='plus', exon_count=12, OMIM=[609149], no_hdr0=''),
    222967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=222967, CurrentID=0, Status='live', Symbol='RSPH10B', Aliases=[], description='radial spoke head 10 homolog B', other_designations='radial spoke head 10 homolog B2|radial spoke head 10 homolog B', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5926136, end_position_on_the_genomic_accession=5970850, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    223075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=223075, CurrentID=0, Status='live', Symbol='ITPRID1', Aliases=['CCDC129'], description='ITPR interacting domain containing 1', other_designations='protein ITPRID1|ITPR-interacting domain-containing protein 1|coiled-coil domain containing 129|coiled-coil domain-containing protein 129', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31514090, end_position_on_the_genomic_accession=31658720, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    223082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=223082, CurrentID=0, Status='live', Symbol='ZNRF2', Aliases=['RNF202'], description='zinc and ring finger 2', other_designations='E3 ubiquitin-protein ligase ZNRF2|RING finger protein 202|RING-type E3 ubiquitin transferase ZNRF2|protein Ells2|zinc and ring finger 2, E3 ubiquitin protein ligase|zinc finger/RING finger 2|zinc/RING finger protein 2', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30284597, end_position_on_the_genomic_accession=30367689, orientation='plus', exon_count=6, OMIM=[612061], no_hdr0=''),
    223117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=223117, CurrentID=0, Status='live', Symbol='SEMA3D', Aliases=['Sema-Z2', 'coll-2'], description='semaphorin 3D', other_designations='semaphorin-3D|collapsin 2|sema domain, immunoglobulin domain (Ig), short basic domain, secreted, (semaphorin) 3D', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=84995192, end_position_on_the_genomic_accession=85250243, orientation='minus', exon_count=25, OMIM=[609907], no_hdr0=''),
    225689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=225689, CurrentID=0, Status='live', Symbol='MAPK15', Aliases=['ERK7', 'ERK8'], description='mitogen-activated protein kinase 15', other_designations='mitogen-activated protein kinase 15|ERK-7|ERK-8|MAP kinase 15|MAPK 15|extracellular regulated kinase 8 delta|extracellular signal-regulated kinase 7|extracellular signal-regulated kinase 8', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143716305, end_position_on_the_genomic_accession=143722458, orientation='plus', exon_count=14, OMIM=[618616], no_hdr0=''),
    245711 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245711, CurrentID=0, Status='live', Symbol='SPDYA', Aliases=['RINGO3', 'RINGOA', 'SPDY1', 'SPY1'], description='speedy/RINGO cell cycle regulator family member A', other_designations='speedy protein A|RINGO A|epididymis secretory sperm binding protein|hSpy/Ringo A|rapid inducer of G2/M progression in oocytes A|speedy homolog A|speedy-1', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=28810834, end_position_on_the_genomic_accession=28850610, orientation='plus', exon_count=8, OMIM=[614029], no_hdr0=''),
    245802 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245802, CurrentID=0, Status='live', Symbol='MS4A6E', Aliases=[], description='membrane spanning 4-domains A6E', other_designations='membrane-spanning 4-domains subfamily A member 6E|membrane-spanning 4-domains, subfamily A, member 6E', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60327255, end_position_on_the_genomic_accession=60349072, orientation='plus', exon_count=8, OMIM=[608402], no_hdr0=''),
    245806 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245806, CurrentID=0, Status='live', Symbol='VGLL2', Aliases=['VGL2', 'VITO1'], description='vestigial like family member 2', other_designations='transcription cofactor vestigial-like protein 2|Vestigial and Tondu related protein 1|vestigial like 2', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117265558, end_position_on_the_genomic_accession=117273565, orientation='plus', exon_count=4, OMIM=[609979], no_hdr0=''),
    245812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245812, CurrentID=0, Status='live', Symbol='CNPY4', Aliases=['PRAT4B'], description='canopy FGF signaling regulator 4', other_designations='protein canopy homolog 4|PRotein Associated with Tlr4|canopy 4 homolog', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100119634, end_position_on_the_genomic_accession=100125508, orientation='plus', exon_count=6, OMIM=[610047], no_hdr0=''),
    245908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245908, CurrentID=0, Status='live', Symbol='DEFB105A', Aliases=['BD-5', 'DEFB-5', 'DEFB105'], description='defensin beta 105A', other_designations='beta-defensin 105|beta defensin 5|defensin, beta 5', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7821004, end_position_on_the_genomic_accession=7823880, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    245909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245909, CurrentID=0, Status='live', Symbol='DEFB106A', Aliases=['BD-6', 'DEFB-6', 'DEFB106'], description='defensin beta 106A', other_designations='beta-defensin 106|beta-defensin 6|defensin, beta 6', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7825139, end_position_on_the_genomic_accession=7829053, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    245910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245910, CurrentID=0, Status='live', Symbol='DEFB107A', Aliases=['BD-7', 'DEFB-7', 'DEFB107'], description='defensin beta 107A', other_designations='beta-defensin 107|beta-defensin 7|defensin, beta 7', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7811720, end_position_on_the_genomic_accession=7815716, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245911, CurrentID=0, Status='live', Symbol='DEFB108B', Aliases=['DEFB-8', 'hBD-8'], description='defensin beta 108B', other_designations='beta-defensin 108B|beta-defensin 8|defensin, beta 8', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71833200, end_position_on_the_genomic_accession=71837710, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    245913 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245913, CurrentID=0, Status='live', Symbol='DEFB110', Aliases=['DEFB-10', 'DEFB-11', 'DEFB111'], description='defensin beta 110', other_designations='beta-defensin 110|beta-defensin 10|beta-defensin 11|beta-defensin 111|defensin, beta 10|defensin, beta 110 locus', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=50009138, end_position_on_the_genomic_accession=50021994, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    245915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245915, CurrentID=0, Status='live', Symbol='DEFB112', Aliases=['DEFB-12'], description='defensin beta 112', other_designations='beta-defensin 112|beta-defensin 12|defensin, beta 12', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=50042099, end_position_on_the_genomic_accession=50049929, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245927, CurrentID=0, Status='live', Symbol='DEFB113', Aliases=['DEFB-13'], description='defensin beta 113', other_designations='beta-defensin 113|beta-defensin 13|defensin, beta 13', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49968677, end_position_on_the_genomic_accession=49969625, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245928, CurrentID=0, Status='live', Symbol='DEFB114', Aliases=['DEFB-14', 'DEFB14'], description='defensin beta 114', other_designations='beta-defensin 114|beta-defensin 14|defensin, beta 14', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49960249, end_position_on_the_genomic_accession=49964164, orientation='minus', exon_count=2, OMIM=[615243], no_hdr0=''),
    245929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245929, CurrentID=0, Status='live', Symbol='DEFB115', Aliases=['DEFB-15'], description='defensin beta 115', other_designations='beta-defensin 115|beta-defensin 15|defensin, beta 15', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31257664, end_position_on_the_genomic_accession=31259632, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    245930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245930, CurrentID=0, Status='live', Symbol='DEFB116', Aliases=['DEFB-16'], description='defensin beta 116', other_designations='beta-defensin 116|beta-defensin 16|defensin, beta 16', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31303212, end_position_on_the_genomic_accession=31308585, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245932, CurrentID=0, Status='live', Symbol='DEFB119', Aliases=['DEFB-19', 'DEFB-20', 'DEFB120', 'DEFB20', 'ESC42-RELA', 'ESC42-RELB'], description='defensin beta 119', other_designations='beta-defensin 119|defensin, beta 120|defensin, beta 19|defensin, beta 20', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31377163, end_position_on_the_genomic_accession=31390649, orientation='minus', exon_count=5, OMIM=[615997], no_hdr0=''),
    245934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245934, CurrentID=0, Status='live', Symbol='DEFB121', Aliases=['DEFB21', 'ESC42RELC'], description='defensin beta 121', other_designations='beta-defensin 121|beta-defensin 21|defensin, beta 21|epididymis secretory sperm binding protein', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31404845, end_position_on_the_genomic_accession=31418522, orientation='minus', exon_count=5, OMIM=[616075], no_hdr0=''),
    245936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245936, CurrentID=0, Status='live', Symbol='DEFB123', Aliases=['DEFB-23', 'DEFB23', 'ESC42-RELD'], description='defensin beta 123', other_designations='beta-defensin 123|beta defensin 23|specific to testis and epididymis', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31440632, end_position_on_the_genomic_accession=31450257, orientation='plus', exon_count=2, OMIM=[616076], no_hdr0=''),
    245937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245937, CurrentID=0, Status='live', Symbol='DEFB124', Aliases=['DEFB-24'], description='defensin beta 124', other_designations='beta-defensin 124|beta-defensin 24|defensin, beta 24', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31465471, end_position_on_the_genomic_accession=31475127, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    245938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245938, CurrentID=0, Status='live', Symbol='DEFB125', Aliases=['DEFB-25'], description='defensin beta 125', other_designations='beta-defensin 125|beta defensin 25', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=87672, end_position_on_the_genomic_accession=97094, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    245939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245939, CurrentID=0, Status='live', Symbol='DEFB128', Aliases=['DEFB-28', 'DEFB28', 'hBD-28'], description='defensin beta 128', other_designations='beta-defensin 128|beta-defensin 28|defensin, beta 28', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=187853, end_position_on_the_genomic_accession=189711, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245940, CurrentID=0, Status='live', Symbol='DEFB130A', Aliases=['DEFB-30', 'DEFB130', 'DEFB130L', 'DEFB30'], description='defensin beta 130A', other_designations='beta-defensin 130A|beta-defensin 130|beta-defensin 30|defensin beta 130|defensin, beta 30', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12310962, end_position_on_the_genomic_accession=12318316, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    245972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245972, CurrentID=0, Status='live', Symbol='ATP6V0D2', Aliases=['ATP6D2', 'VMA6'], description='ATPase H+ transporting V0 subunit d2', other_designations='V-type proton ATPase subunit d 2|ATPase, H+ transporting, lysosomal 38kDa, V0 subunit d2|V-ATPase subunit d 2|vacuolar proton pump subunit d 2', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=86098910, end_position_on_the_genomic_accession=86154225, orientation='plus', exon_count=8, OMIM=[618072], no_hdr0=''),
    245973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=245973, CurrentID=0, Status='live', Symbol='ATP6V1C2', Aliases=['ATP6C2', 'VMA5'], description='ATPase H+ transporting V1 subunit C2', other_designations='V-type proton ATPase subunit C 2|ATPase, H+ transporting, lysosomal 42kDa, V1 subunit C2|V-ATPase C2 subunit|vacuolar proton pump subunit C 2', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=10720973, end_position_on_the_genomic_accession=10785110, orientation='plus', exon_count=18, OMIM=[618070], no_hdr0=''),
    246100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246100, CurrentID=0, Status='live', Symbol='CTAG1A', Aliases=['CT6.1', 'ESO1', 'LAGE-2', 'LAGE2A', 'NY-ESO-1'], description='cancer/testis antigen 1A', other_designations='cancer/testis antigen 1|New York Esophageal Squamous Cell Carcinoma 1|autoimmunogenic cancer/testis antigen NY-ESO-1|cancer/testis antigen 1-A|cancer/testis antigen 6.1|l antigen family member 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154585133, end_position_on_the_genomic_accession=154586816, orientation='plus', exon_count=3, OMIM=[300657], no_hdr0=''),
    246175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246175, CurrentID=0, Status='live', Symbol='CNOT6L', Aliases=['CCR4b'], description='CCR4-NOT transcription complex subunit 6 like', other_designations='CCR4-NOT transcription complex subunit 6-like|carbon catabolite repressor protein 4 homolog B', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=77713387, end_position_on_the_genomic_accession=77820269, orientation='minus', exon_count=18, OMIM=[618069], no_hdr0=''),
    246176 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246176, CurrentID=0, Status='live', Symbol='GAS2L2', Aliases=['CILD41', 'GAR17'], description='growth arrest specific 2 like 2', other_designations='GAS2-like protein 2|GAS2-related protein on chromosome 17', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35744511, end_position_on_the_genomic_accession=35753239, orientation='minus', exon_count=6, OMIM=[611398], no_hdr0=''),
    246181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246181, CurrentID=0, Status='live', Symbol='AKR7L', Aliases=['AFAR3', 'AFB1-AR 3', 'AFB1-AR3', 'AKR7A4'], description='aldo-keto reductase family 7 like (gene/pseudogene)', other_designations='aflatoxin B1 aldehyde reductase member 4|AFB1 aldehyde reductase 3|aldo-keto reductase family 7 pseudogene|aldo-keto reductase family 7-like|aldoketoreductase 7-like', map_location='1p35-p36.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19265982, end_position_on_the_genomic_accession=19274122, orientation='minus', exon_count=7, OMIM=[608478], no_hdr0=''),
    246184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246184, CurrentID=0, Status='live', Symbol='CDC26', Aliases=['ANAPC12', 'APC12', 'C9orf17'], description='cell division cycle 26', other_designations='anaphase-promoting complex subunit CDC26|CDC26 subunit of anaphase promoting complex|anaphase-promoting complex subunit 12|cell division cycle 26 homolog|cell division cycle protein 26 homolog', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113266992, end_position_on_the_genomic_accession=113275579, orientation='minus', exon_count=5, OMIM=[614533], no_hdr0=''),
    246213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246213, CurrentID=0, Status='live', Symbol='SLC17A8', Aliases=['DFNA25', 'VGLUT3'], description='solute carrier family 17 member 8', other_designations='vesicular glutamate transporter 3|solute carrier family 17 (sodium-dependent inorganic phosphate cotransporter), member 8|solute carrier family 17 (vesicular glutamate transporter), member 8', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100357074, end_position_on_the_genomic_accession=100422055, orientation='plus', exon_count=12, OMIM=[607557], no_hdr0=''),
    246243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246243, CurrentID=0, Status='live', Symbol='RNASEH1', Aliases=['H1RNA', 'PEOB2', 'RNH1'], description='ribonuclease H1', other_designations='ribonuclease H1|ribonuclease H type II', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3531813, end_position_on_the_genomic_accession=3558367, orientation='minus', exon_count=15, OMIM=[604123], no_hdr0=''),
    246269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246269, CurrentID=0, Status='live', Symbol='AFG1L', Aliases=['AFG1', 'LACE1', 'c222389'], description='AFG1 like ATPase', other_designations='AFG1-like ATPase|ATPase family gene 1 homolog|CG8520 gene product|lactation elevated 1|lactation elevated protein 1', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=108294881, end_position_on_the_genomic_accession=108526001, orientation='plus', exon_count=19, OMIM=[617469], no_hdr0=''),
    246329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246329, CurrentID=0, Status='live', Symbol='STAC3', Aliases=['MYPBB', 'NAM'], description='SH3 and cysteine rich domain 3', other_designations='SH3 and cysteine-rich domain-containing protein 3', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=57243453, end_position_on_the_genomic_accession=57251188, orientation='minus', exon_count=12, OMIM=[615521], no_hdr0=''),
    246330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246330, CurrentID=0, Status='live', Symbol='PELI3', Aliases=[], description='pellino E3 ubiquitin protein ligase family member 3', other_designations='E3 ubiquitin-protein ligase pellino homolog 3|RING-type E3 ubiquitin transferase pellino homolog 3|pellino homolog 3|protein pellino homolog 3', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66466327, end_position_on_the_genomic_accession=66477337, orientation='plus', exon_count=10, OMIM=[609827], no_hdr0=''),
    246721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246721, CurrentID=0, Status='live', Symbol='POLR2J2', Aliases=['HRPB11B', 'POLR2J3', 'RPB11b1', 'RPB11b2'], description='RNA polymerase II subunit J2', other_designations='DNA-directed RNA polymerase II subunit RPB11-b1|DNA directed RNA polymerase II polypeptide J-related|DNA-directed RNA polymerase II subunit J2|DNA-directed RNA polymerase II subunit J3|DNA-directed RNA polymerase II subunit RPB11-b2|RNA polymerase II subunit B11-b1|RNA polymerase II subunit B11-b2|polymerase (RNA) II (DNA directed) polypeptide J2|polymerase (RNA) II subunit J2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102636748, end_position_on_the_genomic_accession=102671735, orientation='minus', exon_count=9, OMIM=[609881], no_hdr0=''),
    246744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246744, CurrentID=0, Status='live', Symbol='STH', Aliases=['MAPTIT'], description='saitohin', other_designations='saitohin|microtubule-associated protein tau (MAPT) intronic transcript', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45999250, end_position_on_the_genomic_accession=45999694, orientation='plus', exon_count=1, OMIM=[607067], no_hdr0=''),
    246777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246777, CurrentID=0, Status='live', Symbol='SPESP1', Aliases=['ESP', 'SP-ESP'], description='sperm equatorial segment protein 1', other_designations='sperm equatorial segment protein 1|equatorial segment protein|glycosylated 38 kDa sperm protein C-7/8', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=68930525, end_position_on_the_genomic_accession=68946811, orientation='plus', exon_count=2, OMIM=[609399], no_hdr0=''),
    246778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=246778, CurrentID=0, Status='live', Symbol='IL27', Aliases=['IL-27', 'IL-27AA', 'IL27p28', 'IL30', 'p28', 'IL27'], description='interleukin 27', other_designations='interleukin-27 subunit alpha|IL-27 p28 subunit|IL-27 subunit alpha|IL-27-A|IL27-A|interleukin-30', map_location='16p12.1-p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28499362, end_position_on_the_genomic_accession=28526730, orientation='minus', exon_count=6, OMIM=[608273], no_hdr0=''),
    252839 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=252839, CurrentID=0, Status='live', Symbol='TMEM9', Aliases=['DERM4A', 'TMEM9'], description='transmembrane protein 9', other_designations='proton-transporting V-type ATPase complex assembly regulator TMEM9|dermal papilla-derived protein 4|v-ATPase assembly regulator TMEM9', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201134772, end_position_on_the_genomic_accession=201171625, orientation='minus', exon_count=7, OMIM=[616877], no_hdr0=''),
    252884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=252884, CurrentID=0, Status='live', Symbol='ZNF396', Aliases=['ZSCAN14'], description='zinc finger protein 396', other_designations='zinc finger protein 396|zinc finger and SCAN domain-containing protein 14', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35366694, end_position_on_the_genomic_accession=35377337, orientation='minus', exon_count=6, OMIM=[609600], no_hdr0=''),
    252969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=252969, CurrentID=0, Status='live', Symbol='NEIL2', Aliases=['NEH2', 'NEI2'], description='nei like DNA glycosylase 2', other_designations='endonuclease 8-like 2|DNA glycosylase/AP lyase Neil2|DNA-(apurinic or apyrimidinic site) lyase Neil2|nei endonuclease VIII-like 2|nei homolog 2|nei-like protein 2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11769710, end_position_on_the_genomic_accession=11787345, orientation='plus', exon_count=6, OMIM=[608933], no_hdr0=''),
    252983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=252983, CurrentID=0, Status='live', Symbol='STXBP4', Aliases=['Synip'], description='syntaxin binding protein 4', other_designations='syntaxin-binding protein 4|STX4-interacting protein|syntaxin 4 interacting protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=54968728, end_position_on_the_genomic_accession=55173632, orientation='plus', exon_count=21, OMIM=[610415], no_hdr0=''),
    252995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=252995, CurrentID=0, Status='live', Symbol='FNDC5', Aliases=['FRCP2', 'irisin'], description='fibronectin type III domain containing 5', other_designations='fibronectin type III domain-containing protein 5|fibronectin type III repeat-containing protein 2', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32862268, end_position_on_the_genomic_accession=32872484, orientation='minus', exon_count=7, OMIM=[611906], no_hdr0=''),
    253012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253012, CurrentID=0, Status='live', Symbol='HEPACAM2', Aliases=['MIKI'], description='HEPACAM family member 2', other_designations='HEPACAM family member 2|mitotic kinetics regulator', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=93188534, end_position_on_the_genomic_accession=93232293, orientation='minus', exon_count=13, OMIM=[614133], no_hdr0=''),
    253017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253017, CurrentID=0, Status='live', Symbol='TECRL', Aliases=['CPVT3', 'GPSN2L', 'SRD5A2L2', 'TERL'], description='trans-2,3-enoyl-CoA reductase like', other_designations='trans-2,3-enoyl-CoA reductase-like|glycoprotein, synaptic 2-like|steroid 5 alpha-reductase 2-like 2|steroid 5-alpha-reductase 2-like 2 protein', map_location='4q13.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=64276298, end_position_on_the_genomic_accession=64409510, orientation='minus', exon_count=15, OMIM=[617242], no_hdr0=''),
    253143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253143, CurrentID=0, Status='live', Symbol='PRR14L', Aliases=['C22orf30'], description='proline rich 14 like', other_designations='protein PRR14L|proline rich 14-like protein', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=31681347, end_position_on_the_genomic_accession=31750132, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    253152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253152, CurrentID=0, Status='live', Symbol='EPHX4', Aliases=['ABHD7', 'EH4', 'EPHXRP'], description='epoxide hydrolase 4', other_designations='epoxide hydrolase 4|abhydrolase domain containing 7|abhydrolase domain-containing protein 7|epoxide hydrolase-related protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92029985, end_position_on_the_genomic_accession=92063538, orientation='plus', exon_count=7, OMIM=[617401], no_hdr0=''),
    253175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253175, CurrentID=0, Status='live', Symbol='CDY1B', Aliases=['CDY'], description='chromodomain Y-linked 1B', other_designations='testis-specific chromodomain protein Y 1|chromodomain protein, Y chromosome, 1, centromeric|chromodomain protein, Y-linked, 1B|testis-specific chromodomain protein on Y, centromeric', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=24044620, end_position_on_the_genomic_accession=24048030, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    253190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253190, CurrentID=0, Status='live', Symbol='SERHL2', Aliases=['dJ222E13.1'], description='serine hydrolase like 2', other_designations='serine hydrolase-like protein 2|testis secretory sperm-binding protein Li 216e', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42553850, end_position_on_the_genomic_accession=42574382, orientation='plus', exon_count=13, OMIM=[619045], no_hdr0=''),
    253260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253260, CurrentID=0, Status='live', Symbol='RICTOR', Aliases=['AVO3', 'PIA', 'hAVO3'], description='RPTOR independent companion of MTOR complex 2', other_designations='rapamycin-insensitive companion of mTOR|AVO3 homolog|TORC2-specific protein AVO3|pianissimo', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=38937920, end_position_on_the_genomic_accession=39074421, orientation='minus', exon_count=41, OMIM=[609022], no_hdr0=''),
    253314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253314, CurrentID=0, Status='live', Symbol='EIF4E1B', Aliases=[], description='eukaryotic translation initiation factor 4E family member 1B', other_designations='eukaryotic translation initiation factor 4E type 1B', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176630675, end_position_on_the_genomic_accession=176646644, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    253430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253430, CurrentID=0, Status='live', Symbol='IPMK', Aliases=[], description='inositol polyphosphate multikinase', other_designations='inositol polyphosphate multikinase|inositol 1,3,4,6-tetrakisphosphate 5-kinase', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=58191517, end_position_on_the_genomic_accession=58269961, orientation='minus', exon_count=7, OMIM=[609851], no_hdr0=''),
    253461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253461, CurrentID=0, Status='live', Symbol='ZBTB38', Aliases=['CIBZ', 'PPP1R171', 'ZNF921'], description='zinc finger and BTB domain containing 38', other_designations='zinc finger and BTB domain-containing protein 38|protein phosphatase 1, regulatory subunit 171', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=141324186, end_position_on_the_genomic_accession=141449792, orientation='plus', exon_count=27, OMIM=[612218], no_hdr0=''),
    253512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253512, CurrentID=0, Status='live', Symbol='SLC25A30', Aliases=['KMCP1'], description='solute carrier family 25 member 30', other_designations='kidney mitochondrial carrier protein 1', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45393316, end_position_on_the_genomic_accession=45434016, orientation='minus', exon_count=14, OMIM=[610793], no_hdr0=''),
    253558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253558, CurrentID=0, Status='live', Symbol='LCLAT1', Aliases=['1AGPAT8', 'AGPAT8', 'ALCAT1', 'HSRG1849', 'LYCAT', 'UNQ1849'], description='lysocardiolipin acyltransferase 1', other_designations='lysocardiolipin acyltransferase 1|1-AGP acyltransferase 8|1-AGPAT 8|1-acylglycerol-3-phosphate O-acyltransferase 8|acyl-CoA:lysocardiolipin acyltransferase 1', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=30447241, end_position_on_the_genomic_accession=30644225, orientation='plus', exon_count=11, OMIM=[614241], no_hdr0=''),
    253559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253559, CurrentID=0, Status='live', Symbol='CADM2', Aliases=['IGSF4D', 'NECL3', 'Necl-3', 'SynCAM 2', 'synCAM2'], description='cell adhesion molecule 2', other_designations='cell adhesion molecule 2|immunoglobulin superfamily member 4D|nectin-like 3|nectin-like protein 3|synaptic cell adhesion molecule 2', map_location='3p12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=84958989, end_position_on_the_genomic_accession=86074429, orientation='plus', exon_count=14, OMIM=[609938], no_hdr0=''),
    253582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253582, CurrentID=0, Status='live', Symbol='TMEM244', Aliases=['C6orf191', 'bA174C7.4'], description='transmembrane protein 244', other_designations='transmembrane protein 244|putative transmembrane protein C6orf191', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=129831244, end_position_on_the_genomic_accession=129861514, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    253635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253635, CurrentID=0, Status='live', Symbol='GPATCH11', Aliases=['CCDC75', 'CENP-Y', 'CENPY'], description='G-patch domain containing 11', other_designations='G patch domain-containing protein 11|centromere protein Y|coiled-coil domain containing 75|coiled-coil domain-containing protein 75|g patch domain-containing protein 11', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37084518, end_position_on_the_genomic_accession=37099244, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    253639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253639, CurrentID=0, Status='live', Symbol='ZNF620', Aliases=[], description='zinc finger protein 620', other_designations='zinc finger protein 620', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40502604, end_position_on_the_genomic_accession=40518736, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    253650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253650, CurrentID=0, Status='live', Symbol='ANKRD18A', Aliases=[], description='ankyrin repeat domain 18A', other_designations='ankyrin repeat domain-containing protein 18A', map_location='9p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=38566260, end_position_on_the_genomic_accession=38620655, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    253714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253714, CurrentID=0, Status='live', Symbol='MMS22L', Aliases=['C6orf167', 'dJ39B17.2'], description='MMS22 like, DNA repair protein', other_designations='protein MMS22-like', map_location='6q16.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=97142161, end_position_on_the_genomic_accession=97283437, orientation='minus', exon_count=31, OMIM=[615614], no_hdr0=''),
    253725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253725, CurrentID=0, Status='live', Symbol='WASHC2C', Aliases=['FAM21A', 'FAM21C', 'VPEF'], description='WASH complex subunit 2C', other_designations='WASH complex subunit 2C|WASH complex subunit FAM21C|family with sequence similarity 21 member C|vaccinia virus penetration factor', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45727043, end_position_on_the_genomic_accession=45792964, orientation='plus', exon_count=38, OMIM=[613631], no_hdr0=''),
    253738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253738, CurrentID=0, Status='live', Symbol='EBF3', Aliases=['COE3', 'EBF-3', 'HADDS', 'O/E-2', 'OE-2'], description='EBF transcription factor 3', other_designations='transcription factor COE3|early B cell factor 3|olf-1/EBF-like 2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=129835233, end_position_on_the_genomic_accession=129964274, orientation='minus', exon_count=18, OMIM=[607407], no_hdr0=''),
    253769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253769, CurrentID=0, Status='live', Symbol='WDR27', Aliases=[], description='WD repeat domain 27', other_designations='WD repeat-containing protein 27', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169426420, end_position_on_the_genomic_accession=169702063, orientation='minus', exon_count=44, OMIM=[], no_hdr0=''),
    253782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253782, CurrentID=0, Status='live', Symbol='CERS6', Aliases=['CERS5', 'LASS6'], description='ceramide synthase 6', other_designations='ceramide synthase 6|LAG1 homolog, ceramide synthase 6|longevity assurance homolog 6', map_location='2q24.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=168455862, end_position_on_the_genomic_accession=168775134, orientation='plus', exon_count=15, OMIM=[615336], no_hdr0=''),
    253827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253827, CurrentID=0, Status='live', Symbol='MSRB3', Aliases=['DFNB74'], description='methionine sulfoxide reductase B3', other_designations='methionine-R-sulfoxide reductase B3|methionine-R-sulfoxide reductase B3, mitochondrial', map_location='12q14.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=65278593, end_position_on_the_genomic_accession=65466907, orientation='plus', exon_count=11, OMIM=[613719], no_hdr0=''),
    253832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253832, CurrentID=0, Status='live', Symbol='ZDHHC20', Aliases=['4933421L13Rik', 'DHHC-20', 'DHHC20'], description='zinc finger DHHC-type palmitoyltransferase 20', other_designations='palmitoyltransferase ZDHHC20|DHHC domain-containing cysteine-rich protein 20|acyltransferase ZDHHC20|probable palmitoyltransferase ZDHHC20|zinc finger DHHC domain-containing protein 20|zinc finger DHHC-type containing 20', map_location='13q12.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=21372571, end_position_on_the_genomic_accession=21459346, orientation='minus', exon_count=20, OMIM=[617972], no_hdr0=''),
    253935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253935, CurrentID=0, Status='live', Symbol='ANGPTL5', Aliases=[], description='angiopoietin like 5', other_designations='angiopoietin-related protein 5|angiopoietin-like protein 5', map_location='11q22.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=101890674, end_position_on_the_genomic_accession=101917050, orientation='minus', exon_count=9, OMIM=[607666], no_hdr0=''),
    253943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253943, CurrentID=0, Status='live', Symbol='YTHDF3', Aliases=['DF3'], description='YTH N6-methyladenosine RNA binding protein 3', other_designations='YTH domain-containing family protein 3|YTH N(6)-methyladenosine RNA binding protein 3|YTH domain family protein 3|YTH domain family, member 3', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=63168553, end_position_on_the_genomic_accession=63212788, orientation='plus', exon_count=8, OMIM=[618669], no_hdr0=''),
    253959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253959, CurrentID=0, Status='live', Symbol='RALGAPA1', Aliases=['GARNL1', 'GRIPE', 'NEDHRIT', 'RalGAPalpha1', 'TULIP1', 'p240'], description='Ral GTPase activating protein catalytic subunit alpha 1', other_designations='ral GTPase-activating protein subunit alpha-1|GAP-related interacting protein to E12|GTPase activating Rap/RanGAP domain-like 1|Ral GTPase activating protein catalytic alpha subunit 1|Ral GTPase activating protein, alpha subunit 1 (catalytic)|tuberin-like protein 1', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35538356, end_position_on_the_genomic_accession=35809295, orientation='minus', exon_count=49, OMIM=[608884], no_hdr0=''),
    253980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253980, CurrentID=0, Status='live', Symbol='KCTD13', Aliases=['BACURD1', 'FKSG86', 'PDIP1', 'POLDIP1', 'hBACURD1'], description='potassium channel tetramerization domain containing 13', other_designations='BTB/POZ domain-containing adapter for CUL3-mediated RhoA degradation protein 1|BTB/POZ domain-containing protein KCTD13|CTD-2574D22.4|TNFAIP1-like protein|polymerase delta-interacting protein 1|potassium channel tetramerisation domain containing 13', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29906335, end_position_on_the_genomic_accession=29926226, orientation='minus', exon_count=9, OMIM=[608947], no_hdr0=''),
    253982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=253982, CurrentID=0, Status='live', Symbol='ASPHD1', Aliases=[], description='aspartate beta-hydroxylase domain containing 1', other_designations='aspartate beta-hydroxylase domain-containing protein 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29900392, end_position_on_the_genomic_accession=29920688, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    254013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254013, CurrentID=0, Status='live', Symbol='ETFBKMT', Aliases=['C12orf72', 'ETFB-KMT', 'METTL20'], description='electron transfer flavoprotein subunit beta lysine methyltransferase', other_designations='electron transfer flavoprotein beta subunit lysine methyltransferase|ETFB lysine methyltransferase|methyltransferase like 20|methyltransferase-like protein 20|protein N-lysine methyltransferase METTL20', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31647160, end_position_on_the_genomic_accession=31673114, orientation='plus', exon_count=8, OMIM=[615256], no_hdr0=''),
    254042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254042, CurrentID=0, Status='live', Symbol='METAP1D', Aliases=['MAP 1D', 'MAP1D', 'MetAP 1D', 'Metap1l'], description='methionyl aminopeptidase type 1D, mitochondrial', other_designations='methionine aminopeptidase 1D, mitochondrial|CDS of metAP-3 within PCR fragment|metAP 1D|peptidase M 1D', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=171999953, end_position_on_the_genomic_accession=172082430, orientation='plus', exon_count=11, OMIM=[610267], no_hdr0=''),
    254048 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254048, CurrentID=0, Status='live', Symbol='UBN2', Aliases=[], description='ubinuclein 2', other_designations='ubinuclein-2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139228408, end_position_on_the_genomic_accession=139329421, orientation='plus', exon_count=20, OMIM=[613841], no_hdr0=''),
    254050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254050, CurrentID=0, Status='live', Symbol='LRRC43', Aliases=[], description='leucine rich repeat containing 43', other_designations='leucine-rich repeat-containing protein 43', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122167719, end_position_on_the_genomic_accession=122203471, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    254065 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254065, CurrentID=0, Status='live', Symbol='BRWD3', Aliases=['BRODL', 'MRX93'], description='bromodomain and WD repeat domain containing 3', other_designations='bromodomain and WD repeat-containing protein 3|bromo domain-containing protein disrupted in leukemia|novel WD repeat domain protein', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=80669503, end_position_on_the_genomic_accession=80809877, orientation='minus', exon_count=42, OMIM=[300553], no_hdr0=''),
    254102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254102, CurrentID=0, Status='live', Symbol='EHBP1L1', Aliases=[], description='EH domain binding protein 1 like 1', other_designations='EH domain-binding protein 1-like protein 1|tangerin', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65576034, end_position_on_the_genomic_accession=65592650, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    254122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254122, CurrentID=0, Status='live', Symbol='SNX32', Aliases=['SNX6B'], description='sorting nexin 32', other_designations='sorting nexin-32|sorting nexin-6B', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65833640, end_position_on_the_genomic_accession=65855169, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    254158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254158, CurrentID=0, Status='live', Symbol='CXorf58', Aliases=[], description='chromosome X open reading frame 58', other_designations='putative uncharacterized protein CXorf58', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=23907932, end_position_on_the_genomic_accession=23939520, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    254170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254170, CurrentID=0, Status='live', Symbol='FBXO33', Aliases=['BMND12', 'Fbx33', 'c14_5247'], description='F-box protein 33', other_designations='F-box only protein 33', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=39397684, end_position_on_the_genomic_accession=39432433, orientation='minus', exon_count=4, OMIM=[609103], no_hdr0=''),
    254173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254173, CurrentID=0, Status='live', Symbol='TTLL10', Aliases=['TTLL5'], description='tubulin tyrosine ligase like 10', other_designations='inactive polyglycylase TTLL10|tubulin tyrosine ligase-like family, member 10|tubulin tyrosine ligase-like family, member 5|tubulin--tyrosine ligase-like protein 10', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1173709, end_position_on_the_genomic_accession=1197936, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    254187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254187, CurrentID=0, Status='live', Symbol='TSGA10IP', Aliases=['FAM161C'], description='testis specific 10 interacting protein', other_designations='testis-specific protein 10-interacting protein|tsga10-interacting protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65945445, end_position_on_the_genomic_accession=65960437, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    254225 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254225, CurrentID=0, Status='live', Symbol='RNF169', Aliases=[], description='ring finger protein 169', other_designations='E3 ubiquitin-protein ligase RNF169|RING-type E3 ubiquitin transferase RNF169', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74748849, end_position_on_the_genomic_accession=74842413, orientation='plus', exon_count=6, OMIM=[618650], no_hdr0=''),
    254228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254228, CurrentID=0, Status='live', Symbol='CALHM5', Aliases=['C6orf188', 'FAM26E', 'dJ493F7.3'], description='calcium homeostasis modulator family member 5', other_designations='calcium homeostasis modulator protein 5|family with sequence similarity 26 member E|protein FAM26E', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116511639, end_position_on_the_genomic_accession=116524788, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    254240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254240, CurrentID=0, Status='live', Symbol='BPIFC', Aliases=['BPIL2'], description='BPI fold containing family C', other_designations='BPI fold-containing family C protein|BPI-like 2|bactericidal/permeability-increasing protein-like 2', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=32413845, end_position_on_the_genomic_accession=32464465, orientation='minus', exon_count=19, OMIM=[614109], no_hdr0=''),
    254251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254251, CurrentID=0, Status='live', Symbol='LCORL', Aliases=['MLR1'], description='ligand dependent nuclear receptor corepressor like', other_designations='ligand-dependent nuclear receptor corepressor-like protein|LCOR-like protein|MBLK1-related protein|transcription factor MLR1', map_location='4p15.31', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17841187, end_position_on_the_genomic_accession=18023287, orientation='minus', exon_count=13, OMIM=[611799], no_hdr0=''),
    254263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254263, CurrentID=0, Status='live', Symbol='CNIH2', Aliases=['CNIH-2', 'Cnil'], description='cornichon family AMPA receptor auxiliary protein 2', other_designations='protein cornichon homolog 2|cornichon homolog 2', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66278175, end_position_on_the_genomic_accession=66284206, orientation='plus', exon_count=6, OMIM=[611288], no_hdr0=''),
    254268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254268, CurrentID=0, Status='live', Symbol='AKNAD1', Aliases=['C1orf62'], description='AKNA domain containing 1', other_designations='protein AKNAD1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108815901, end_position_on_the_genomic_accession=108858244, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    254272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254272, CurrentID=0, Status='live', Symbol='TBC1D28', Aliases=[], description='TBC1 domain family member 28', other_designations='TBC1 domain family member 28', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18634434, end_position_on_the_genomic_accession=18644431, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    254295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254295, CurrentID=0, Status='live', Symbol='PHYHD1', Aliases=[], description='phytanoyl-CoA dioxygenase domain containing 1', other_designations='phytanoyl-CoA dioxygenase domain-containing protein 1', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128920982, end_position_on_the_genomic_accession=128942041, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    254359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254359, CurrentID=0, Status='live', Symbol='ZDHHC24', Aliases=[], description='zinc finger DHHC-type containing 24', other_designations='probable palmitoyltransferase ZDHHC24|DHHC-24|zinc finger DHHC domain-containing protein 24|zinc finger, DHHC domain containing 24', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66520625, end_position_on_the_genomic_accession=66546184, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    254394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254394, CurrentID=0, Status='live', Symbol='MCM9', Aliases=['C6orf61', 'MCMDC1', 'ODG4', 'dJ329L24.1', 'dJ329L24.3'], description='minichromosome maintenance 9 homologous recombination repair factor', other_designations='DNA helicase MCM9|DNA replication licensing factor MCM9|mini-chromosome maintenance deficient domain-containing protein 1|minichromosome maintenance complex component 9', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=118813455, end_position_on_the_genomic_accession=118935159, orientation='minus', exon_count=18, OMIM=[610098], no_hdr0=''),
    254427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254427, CurrentID=0, Status='live', Symbol='PROSER2', Aliases=['C10orf47'], description='proline and serine rich 2', other_designations='proline and serine-rich protein 2', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=11823341, end_position_on_the_genomic_accession=11872277, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    254428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254428, CurrentID=0, Status='live', Symbol='SLC41A1', Aliases=['MgtE'], description='solute carrier family 41 member 1', other_designations='solute carrier family 41 member 1|solute carrier family 41 (magnesium transporter), member 1', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205789095, end_position_on_the_genomic_accession=205813759, orientation='minus', exon_count=12, OMIM=[610801], no_hdr0=''),
    254439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254439, CurrentID=0, Status='live', Symbol='C11orf86', Aliases=[], description='chromosome 11 open reading frame 86', other_designations='uncharacterized protein C11orf86', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66975304, end_position_on_the_genomic_accession=66977009, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    254528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254528, CurrentID=0, Status='live', Symbol='MEIOB', Aliases=['C16orf73', 'SPGF22', 'gs129'], description='meiosis specific with OB-fold', other_designations='meiosis-specific with OB domain-containing protein|meiosis specific with OB domains', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1833986, end_position_on_the_genomic_accession=1872164, orientation='minus', exon_count=14, OMIM=[617670], no_hdr0=''),
    254531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254531, CurrentID=0, Status='live', Symbol='LPCAT4', Aliases=['AGPAT7', 'AYTL3', 'LPAAT-eta', 'LPEAT2'], description='lysophosphatidylcholine acyltransferase 4', other_designations='lysophospholipid acyltransferase LPCAT4|1-AGP acyltransferase 7|1-AGPAT 7|1-acylglycerol-3-phosphate O-acyltransferase 7 (lysophosphatidic acid acyltransferase, eta)|1-acylglycerophosphocholine O-acyltransferase|1-acylglycerophosphoserine O-acyltransferase|1-alkenylglycerophosphoethanolamine O-acyltransferase|1-alkylglycerophosphocholine O-acetyltransferase|PLSC domain containing protein|acyl-CoA:lysophosphatidylethanolamine acyltransferase 2|acyltransferase-like 3|lysophosphatidylethanolamine acyltransferase 2|plasmalogen synthase', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34358633, end_position_on_the_genomic_accession=34367196, orientation='minus', exon_count=16, OMIM=[612039], no_hdr0=''),
    254552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254552, CurrentID=0, Status='live', Symbol='NUDT8', Aliases=[], description='nudix hydrolase 8', other_designations='nucleoside diphosphate-linked moiety X motif 8|nucleoside diphosphate-linked moiety X motif 8, mitochondrial|nudix (nucleoside diphosphate linked moiety X)-type motif 8|nudix motif 8', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67621421, end_position_on_the_genomic_accession=67629937, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    254773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254773, CurrentID=0, Status='live', Symbol='LYG2', Aliases=['LYGA2', 'LYGH', 'LYSG2'], description='lysozyme g2', other_designations='lysozyme g-like protein 2|lysozyme G-like 2', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=99242246, end_position_on_the_genomic_accession=99260015, orientation='minus', exon_count=7, OMIM=[616547], no_hdr0=''),
    254778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254778, CurrentID=0, Status='live', Symbol='VXN', Aliases=['C8orf46'], description='vexin', other_designations='vexin|uncharacterized protein C8orf46', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66493566, end_position_on_the_genomic_accession=66518524, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    254783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254783, CurrentID=0, Status='live', Symbol='OR6C74', Aliases=[], description='olfactory receptor family 6 subfamily C member 74', other_designations='olfactory receptor 6C74', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55244114, end_position_on_the_genomic_accession=55256625, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    254786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254786, CurrentID=0, Status='live', Symbol='OR6C3', Aliases=['OST709'], description='olfactory receptor family 6 subfamily C member 3', other_designations='olfactory receptor 6C3|HSA8', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55330043, end_position_on_the_genomic_accession=55332636, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    254827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254827, CurrentID=0, Status='live', Symbol='NAALADL2', Aliases=[], description='N-acetylated alpha-linked acidic dipeptidase like 2', other_designations='inactive N-acetylated-alpha-linked acidic dipeptidase-like protein 2|N-acetylated alpha-linked acidic dipeptidase 2|NAALADase L2|glutamate carboxypeptidase II-type non-peptidase homologue', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=174438534, end_position_on_the_genomic_accession=175810548, orientation='plus', exon_count=29, OMIM=[608806], no_hdr0=''),
    254863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254863, CurrentID=0, Status='live', Symbol='TMEM256', Aliases=['C17orf61'], description='transmembrane protein 256', other_designations='transmembrane protein 256|UPF0451 protein C17orf61', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7402975, end_position_on_the_genomic_accession=7404097, orientation='minus', exon_count=4, OMIM=[617779], no_hdr0=''),
    254879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254879, CurrentID=0, Status='live', Symbol='OR2T6', Aliases=['OR2T6P', 'OR2T9', 'OST703'], description='olfactory receptor family 2 subfamily T member 6', other_designations='olfactory receptor 2T6|olfactory receptor 2T9|olfactory receptor, family 2, subfamily T, member 6 pseudogene|seven transmembrane helix receptor', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248375746, end_position_on_the_genomic_accession=248391811, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    254887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254887, CurrentID=0, Status='live', Symbol='ZDHHC23', Aliases=['DHHC-23', 'NIDD'], description='zinc finger DHHC-type palmitoyltransferase 23', other_designations='palmitoyltransferase ZDHHC23|zinc finger DHHC domain-containing protein 23|zinc finger DHHC-type containing 23', map_location='3q13.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=113947901, end_position_on_the_genomic_accession=113998002, orientation='plus', exon_count=11, OMIM=[617334], no_hdr0=''),
    254910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254910, CurrentID=0, Status='live', Symbol='LCE5A', Aliases=['LEP18', 'SPRL5A'], description='late cornified envelope 5A', other_designations='late cornified envelope protein 5A|late envelope protein 18|small proline rich-like (epidermal differentiation complex) 5A|small proline-rich-like epidermal differentiation complex protein 5A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152510803, end_position_on_the_genomic_accession=152512177, orientation='plus', exon_count=2, OMIM=[612619], no_hdr0=''),
    254950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254950, CurrentID=0, Status='live', Symbol='KRTAP15-1', Aliases=['KAP15.1'], description='keratin associated protein 15-1', other_designations='keratin-associated protein 15-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30440275, end_position_on_the_genomic_accession=30440869, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    254956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254956, CurrentID=0, Status='live', Symbol='MORN5', Aliases=['C9orf113', 'C9orf18'], description='MORN repeat containing 5', other_designations='MORN repeat-containing protein 5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122159908, end_position_on_the_genomic_accession=122200083, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    254973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=254973, CurrentID=0, Status='live', Symbol='OR1L4', Aliases=['OR1L5', 'OR9-29', 'OR9-E', 'OST046'], description='olfactory receptor family 1 subfamily L member 4', other_designations='olfactory receptor 1L4|olfactory receptor 1L5|olfactory receptor 9-E|olfactory receptor OR9-29|olfactory receptor, family 1, subfamily L, member 5', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122723990, end_position_on_the_genomic_accession=122724925, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    255022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255022, CurrentID=0, Status='live', Symbol='CALHM1', Aliases=['FAM26C'], description='calcium homeostasis modulator 1', other_designations='calcium homeostasis modulator protein 1|family with sequence similarity 26, member C', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103453240, end_position_on_the_genomic_accession=103458900, orientation='minus', exon_count=2, OMIM=[612234], no_hdr0=''),
    255027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255027, CurrentID=0, Status='live', Symbol='MPV17L', Aliases=['M-LPH', 'MLPH1', 'MLPH21', 'MPV17L'], description='MPV17 mitochondrial inner membrane protein like', other_designations='mpv17-like protein|M-LP homolog|MPV17 mitochondrial membrane protein-like|Mpv17-like protein type 1|Mpv17-like protein type 2', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15395569, end_position_on_the_genomic_accession=15413271, orientation='plus', exon_count=5, OMIM=[618100], no_hdr0=''),
    255043 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255043, CurrentID=0, Status='live', Symbol='TMEM86B', Aliases=[], description='transmembrane protein 86B', other_designations='lysoplasmalogenase|alkenylglycerophosphocholine hydrolase|alkenylglycerophosphoethanolamine hydrolase', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55226638, end_position_on_the_genomic_accession=55228763, orientation='minus', exon_count=3, OMIM=[617806], no_hdr0=''),
    255057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255057, CurrentID=0, Status='live', Symbol='CBARP', Aliases=['BARP', 'C19orf26', 'DOS'], description='CACN subunit beta associated regulatory protein', other_designations='voltage-dependent calcium channel beta subunit-associated regulatory protein|CACN beta subunit associated regulatory protein|VGCC beta-anchoring and -regulatory protein|calcium channel, voltage-dependent, beta subunit associated regulatory protein|downstream of Stk11|protein Dos', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1228287, end_position_on_the_genomic_accession=1238512, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    255061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255061, CurrentID=0, Status='live', Symbol='TAC4', Aliases=['EK', 'HK-1', 'HK1', 'PPT-C'], description='tachykinin precursor 4', other_designations='tachykinin-4|endokinin|preprotachykinin-C|tachykinin 4 (hemokinin)', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=49838300, end_position_on_the_genomic_accession=49848069, orientation='minus', exon_count=5, OMIM=[607833], no_hdr0=''),
    255101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255101, CurrentID=0, Status='live', Symbol='CFAP65', Aliases=['CCDC108', 'SPGF40'], description='cilia and flagella associated protein 65', other_designations='cilia- and flagella-associated protein 65|coiled-coil domain containing 108', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219002846, end_position_on_the_genomic_accession=219043142, orientation='minus', exon_count=36, OMIM=[614270], no_hdr0=''),
    255104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255104, CurrentID=0, Status='live', Symbol='TMCO4', Aliases=[], description='transmembrane and coiled-coil domains 4', other_designations='transmembrane and coiled-coil domain-containing protein 4', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19682213, end_position_on_the_genomic_accession=19800385, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    255119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255119, CurrentID=0, Status='live', Symbol='CFAP299', Aliases=['C4orf22'], description='cilia and flagella associated protein 299', other_designations='cilia- and flagella-associated protein 299|uncharacterized protein C4orf22', map_location='4q21.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=80321265, end_position_on_the_genomic_accession=80963756, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    255189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255189, CurrentID=0, Status='live', Symbol='PLA2G4F', Aliases=['PLA2G4FZ'], description='phospholipase A2 group IVF', other_designations='cytosolic phospholipase A2 zeta|cPLA2-zeta', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42139034, end_position_on_the_genomic_accession=42156636, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    255220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255220, CurrentID=0, Status='live', Symbol='TXNDC8', Aliases=['SPTRX-3', 'SPTRX3', 'TRX6', 'bA427L11.2'], description='thioredoxin domain containing 8', other_designations='thioredoxin domain-containing protein 8|sperm-specific thioredoxin 3|spermatid-specific thioredoxin-3|spermatocyte/spermatid-specific thioredoxin-3|thioredoxin 6|thioredoxin domain containing 8 (spermatozoa)', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110300900, end_position_on_the_genomic_accession=110337887, orientation='minus', exon_count=10, OMIM=[617789], no_hdr0=''),
    255231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255231, CurrentID=0, Status='live', Symbol='MCOLN2', Aliases=['TRP-ML2', 'TRPML2'], description='mucolipin TRP cation channel 2', other_designations='mucolipin-2|mucolipin 2|transient receptor potential channel mucolipin 2', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84925583, end_position_on_the_genomic_accession=84997113, orientation='minus', exon_count=16, OMIM=[607399], no_hdr0=''),
    255239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255239, CurrentID=0, Status='live', Symbol='ANKK1', Aliases=['PKK2', 'sgK288'], description='ankyrin repeat and kinase domain containing 1', other_designations='ankyrin repeat and protein kinase domain-containing protein 1|X-kinase|protein kinase PKK2|sugen kinase 288', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113386014, end_position_on_the_genomic_accession=113400416, orientation='plus', exon_count=10, OMIM=[608774], no_hdr0=''),
    255252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255252, CurrentID=0, Status='live', Symbol='LRRC57', Aliases=[], description='leucine rich repeat containing 57', other_designations='leucine-rich repeat-containing protein 57', map_location='15q15.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42528332, end_position_on_the_genomic_accession=42548799, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    255275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255275, CurrentID=0, Status='live', Symbol='MYADML2', Aliases=[], description='myeloid associated differentiation marker like 2', other_designations='myeloid-associated differentiation marker-like protein 2', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81939645, end_position_on_the_genomic_accession=81947233, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    255308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255308, CurrentID=0, Status='live', Symbol='EIF2S3B', Aliases=['EIF2S3L', 'eIF-2gA', 'eIF2gA'], description='eukaryotic translation initiation factor 2 subunit gamma B', other_designations='eukaryotic translation initiation factor 2 subunit 3B|eIF-2-gamma2|eukaryotic translation initiation factor 2, subunit 3 gamma, 52kDa|putative eukaryotic translation initiation factor 2 subunit 3-like protein', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10505890, end_position_on_the_genomic_accession=10523135, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    255313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255313, CurrentID=0, Status='live', Symbol='CT47A11', Aliases=['CT47.11'], description='cancer/testis antigen family 47 member A11', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 11', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120933840, end_position_on_the_genomic_accession=120937260, orientation='minus', exon_count=4, OMIM=[300592], no_hdr0=''),
    255324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255324, CurrentID=0, Status='live', Symbol='EPGN', Aliases=['ALGV3072', 'EPG', 'PRO9904'], description='epithelial mitogen', other_designations='epigen|epithelial mitogen homolog', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74307585, end_position_on_the_genomic_accession=74316789, orientation='plus', exon_count=6, OMIM=[618717], no_hdr0=''),
    255349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255349, CurrentID=0, Status='live', Symbol='TMEM211', Aliases=['bA9F11.1'], description='transmembrane protein 211', other_designations='transmembrane protein 211', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24934773, end_position_on_the_genomic_accession=24946694, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    255374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255374, CurrentID=0, Status='live', Symbol='MBLAC1', Aliases=[], description='metallo-beta-lactamase domain containing 1', other_designations='metallo-beta-lactamase domain-containing protein 1', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100126720, end_position_on_the_genomic_accession=100128495, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    255394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255394, CurrentID=0, Status='live', Symbol='TCP11L2', Aliases=[], description='t-complex 11 like 2', other_designations='T-complex protein 11-like protein 2|t-complex 11, testis-specific-like 2', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=106302026, end_position_on_the_genomic_accession=106347455, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    255403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255403, CurrentID=0, Status='live', Symbol='ZNF718', Aliases=[], description='zinc finger protein 718', other_designations='zinc finger protein 718', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=124246, end_position_on_the_genomic_accession=202306, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    255411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255411, CurrentID=0, Status='live', Symbol='TEX49', Aliases=['LINC00935'], description='testis expressed 49', other_designations='testis-expressed protein 49|long intergenic non-protein coding RNA 935', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48727407, end_position_on_the_genomic_accession=48770126, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    255426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255426, CurrentID=0, Status='live', Symbol='RASGEF1C', Aliases=[], description='RasGEF domain family member 1C', other_designations='ras-GEF domain-containing family member 1C', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180100795, end_position_on_the_genomic_accession=180209211, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    255488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255488, CurrentID=0, Status='live', Symbol='RNF144B', Aliases=['IBRDC2', 'PIR2', 'bA528A10.3', 'p53RFP'], description='ring finger protein 144B', other_designations='E3 ubiquitin-protein ligase RNF144B|IBR domain containing 2|IBR domain-containing protein 2|p53-inducible RING finger protein', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=18387329, end_position_on_the_genomic_accession=18468870, orientation='plus', exon_count=8, OMIM=[618869], no_hdr0=''),
    255520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255520, CurrentID=0, Status='live', Symbol='ELMOD2', Aliases=['9830169G11Rik'], description='ELMO domain containing 2', other_designations='ELMO domain-containing protein 2|ELMO/CED-12 domain containing 2', map_location='4q31.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=140524146, end_position_on_the_genomic_accession=140553770, orientation='plus', exon_count=12, OMIM=[610196], no_hdr0=''),
    255626 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255626, CurrentID=0, Status='live', Symbol='H2BC1', Aliases=['H2BFU', 'HIST1H2BA', 'STBP', 'TH2B', 'TSH2B', 'TSH2B.1', 'bA317E16.3', 'hTSH2B'], description='H2B clustered histone 1', other_designations='histone H2B type 1-A|H2B histone family, member U, (testis-specific)|histone 1, H2ba|histone H2B, testis|histone cluster 1 H2B family member a|histone cluster 1, H2ba|testis-specific histone H2B', map_location='6p22.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=25726777, end_position_on_the_genomic_accession=25727345, orientation='plus', exon_count=1, OMIM=[609904], no_hdr0=''),
    255631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255631, CurrentID=0, Status='live', Symbol='COL24A1', Aliases=[], description='collagen type XXIV alpha 1 chain', other_designations='collagen alpha-1(XXIV) chain|collagen, type XXIV, alpha 1', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=85728507, end_position_on_the_genomic_accession=86156987, orientation='minus', exon_count=66, OMIM=[610025], no_hdr0=''),
    255649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255649, CurrentID=0, Status='live', Symbol='OOSP1', Aliases=[], description='oocyte secreted protein 1', other_designations='putative oocyte-secreted protein 1 homolog', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59942879, end_position_on_the_genomic_accession=59995845, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    255725 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255725, CurrentID=0, Status='live', Symbol='OR52B2', Aliases=['OR11-70'], description='olfactory receptor family 52 subfamily B member 2', other_designations='olfactory receptor 52B2|olfactory receptor OR11-70', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6169355, end_position_on_the_genomic_accession=6170326, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    255738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255738, CurrentID=0, Status='live', Symbol='PCSK9', Aliases=['FH3', 'FHCL3', 'HCHOLA3', 'LDLCQ1', 'NARC-1', 'NARC1', 'PC9'], description='proprotein convertase subtilisin/kexin type 9', other_designations='proprotein convertase subtilisin/kexin type 9|convertase subtilisin/kexin type 9 preproprotein|neural apoptosis regulated convertase 1|subtilisin/kexin-like protease PC9', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=55039548, end_position_on_the_genomic_accession=55064852, orientation='plus', exon_count=13, OMIM=[607786], no_hdr0=''),
    255743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255743, CurrentID=0, Status='live', Symbol='NPNT', Aliases=['EGFL6L', 'POEM'], description='nephronectin', other_designations='nephronectin|preosteoblast EGF-like repeat protein with MAM domain', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=105895453, end_position_on_the_genomic_accession=105971671, orientation='plus', exon_count=14, OMIM=[610306], no_hdr0=''),
    255758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255758, CurrentID=0, Status='live', Symbol='DYNLT2B', Aliases=['SRTD17', 'TCTEX1D2'], description='dynein light chain Tctex-type 2B', other_designations='dynein light chain Tctex-type protein 2B|Tctex1 domain containing 2|tctex1 domain-containing protein 2', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196291219, end_position_on_the_genomic_accession=196318240, orientation='minus', exon_count=5, OMIM=[617353], no_hdr0=''),
    255762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255762, CurrentID=0, Status='live', Symbol='PDZD9', Aliases=['C16orf65'], description='PDZ domain containing 9', other_designations='PDZ domain-containing protein 9|PDZ domain-containing protein C16orf65', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21957540, end_position_on_the_genomic_accession=22001136, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    255783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255783, CurrentID=0, Status='live', Symbol='INAFM1', Aliases=['PRR24'], description='InaF motif containing 1', other_designations='putative transmembrane protein INAFM1|inaF-motif-containing protein 1|proline rich 24|proline-rich protein 24', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47274423, end_position_on_the_genomic_accession=47275723, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    255798 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255798, CurrentID=0, Status='live', Symbol='SMCO1', Aliases=['C3orf43'], description='single-pass membrane protein with coiled-coil domains 1', other_designations='single-pass membrane and coiled-coil domain-containing protein 1', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196506879, end_position_on_the_genomic_accession=196520956, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    255809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255809, CurrentID=0, Status='live', Symbol='C19orf38', Aliases=['HIDE1'], description='chromosome 19 open reading frame 38', other_designations='protein HIDE1|Highly expressed in immature dendritic cell transcript 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10836558, end_position_on_the_genomic_accession=10869796, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    255877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255877, CurrentID=0, Status='live', Symbol='BCL6B', Aliases=['BAZF', 'ZBTB28', 'ZNF62'], description='BCL6B transcription repressor', other_designations='B-cell CLL/lymphoma 6 member B protein|B cell CLL/lymphoma 6B|B-cell CLL/lymphoma 6, member B (zinc finger protein)|bcl6-associated zinc finger protein|zinc finger protein 62', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7023050, end_position_on_the_genomic_accession=7029644, orientation='plus', exon_count=9, OMIM=[608992], no_hdr0=''),
    255919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255919, CurrentID=0, Status='live', Symbol='CNEP1R1', Aliases=['C16orf69', 'NEP1-R1', 'NEP1R1', 'TMEM188', 'TMP125'], description='CTD nuclear envelope phosphatase 1 regulatory subunit 1', other_designations='nuclear envelope phosphatase-regulatory subunit 1|nuclear envelope phosphatase 1-regulatory subunit 1|transmembrane protein 188', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=50025225, end_position_on_the_genomic_accession=50037081, orientation='plus', exon_count=7, OMIM=[616869], no_hdr0=''),
    255928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255928, CurrentID=0, Status='live', Symbol='SYT14', Aliases=['SCAR11', 'sytXIV'], description='synaptotagmin 14', other_designations='synaptotagmin-14|synaptotagmin XIV', map_location='1q32.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=209938165, end_position_on_the_genomic_accession=210171389, orientation='plus', exon_count=13, OMIM=[610949], no_hdr0=''),
    255967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=255967, CurrentID=0, Status='live', Symbol='PAN3', Aliases=[], description='poly(A) specific ribonuclease subunit PAN3', other_designations='PAN2-PAN3 deadenylation complex subunit PAN3|PAB-dependent poly(A)-specific ribonuclease subunit 3|PAB-dependent poly(A)-specific ribonuclease subunit PAN3|PAB1P-dependent poly(A)-nuclease|PAB1P-dependent poly(A)-specific ribonuclease|PABP-dependent poly(A) nuclease 3|PABP1-dependent poly A-specific ribonuclease subunit PAN3|PAN deadenylation complex subunit 3|PAN3 poly(A) specific ribonuclease subunit homolog|poly(A)-nuclease deadenylation complex subunit 3', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28135021, end_position_on_the_genomic_accession=28295335, orientation='plus', exon_count=25, OMIM=[617448], no_hdr0=''),
    256006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256006, CurrentID=0, Status='live', Symbol='ANKRD31', Aliases=[], description='ankyrin repeat domain 31', other_designations='ankyrin repeat domain-containing protein 31|putative ankyrin repeat domain-containing protein 31', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75068297, end_position_on_the_genomic_accession=75236922, orientation='minus', exon_count=28, OMIM=[618423], no_hdr0=''),
    256051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256051, CurrentID=0, Status='live', Symbol='ZNF549', Aliases=[], description='zinc finger protein 549', other_designations='zinc finger protein 549', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57527356, end_position_on_the_genomic_accession=57540876, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    256076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256076, CurrentID=0, Status='live', Symbol='COL6A5', Aliases=['COL29A1', 'VWA4'], description='collagen type VI alpha 5 chain', other_designations='collagen alpha-5(VI) chain|collagen, type VI, alpha 5|collagen, type XXIX, alpha 1|von Willebrand factor A domain-containing protein 4', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130345642, end_position_on_the_genomic_accession=130484846, orientation='plus', exon_count=44, OMIM=[611916], no_hdr0=''),
    256126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256126, CurrentID=0, Status='live', Symbol='SYCE2', Aliases=['CESC1'], description='synaptonemal complex central element protein 2', other_designations='synaptonemal complex central element protein 2', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12898229, end_position_on_the_genomic_accession=12919674, orientation='minus', exon_count=6, OMIM=[611487], no_hdr0=''),
    256130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256130, CurrentID=0, Status='live', Symbol='TMEM196', Aliases=[], description='transmembrane protein 196', other_designations='transmembrane protein 196', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=19719315, end_position_on_the_genomic_accession=19774431, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    256144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256144, CurrentID=0, Status='live', Symbol='OR4C3', Aliases=['OR11-98'], description='olfactory receptor family 4 subfamily C member 3', other_designations='olfactory receptor 4C3|olfactory receptor OR11-98', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48324920, end_position_on_the_genomic_accession=48325955, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    256148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256148, CurrentID=0, Status='live', Symbol='OR4S1', Aliases=['OR11-100'], description='olfactory receptor family 4 subfamily S member 1', other_designations='olfactory receptor 4S1|olfactory receptor OR11-100', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48306223, end_position_on_the_genomic_accession=48307152, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    256158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256158, CurrentID=0, Status='live', Symbol='HMCN2', Aliases=[], description='hemicentin 2', other_designations='hemicentin-2', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130265742, end_position_on_the_genomic_accession=130434123, orientation='plus', exon_count=102, OMIM=[], no_hdr0=''),
    256223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256223, CurrentID=0, Status='live', Symbol='CDRT15L2', Aliases=[], description='CMT1A duplicated region transcript 15 like 2', other_designations='CMT1A duplicated region transcript 15 protein-like protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=20579724, end_position_on_the_genomic_accession=20580911, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    256227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256227, CurrentID=0, Status='live', Symbol='STEAP1B', Aliases=[], description='STEAP family member 1B', other_designations='STEAP family member 1B|STEAP family protein MGC87042', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=22419444, end_position_on_the_genomic_accession=22500188, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    256281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256281, CurrentID=0, Status='live', Symbol='NUDT14', Aliases=['UGPP', 'UGPPase'], description='nudix hydrolase 14', other_designations='uridine diphosphate glucose pyrophosphatase NUDT14|UDP-sugar diphosphatase|UDPG pyrophosphatase|nudix (nucleoside diphosphate linked moiety X)-type motif 14', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105172939, end_position_on_the_genomic_accession=105181312, orientation='minus', exon_count=6, OMIM=[609219], no_hdr0=''),
    256297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256297, CurrentID=0, Status='live', Symbol='PTF1A', Aliases=['PACA', 'PAGEN2', 'PTF1-p48', 'bHLHa29', 'p48'], description='pancreas associated transcription factor 1a', other_designations='pancreas transcription factor 1 subunit alpha|bHLH transcription factor p48|class A basic helix-loop-helix protein 29|class II bHLH protein PTF1A|exocrine pancreas-specific transcription factor p48|p48 DNA-binding subunit of transcription factor PTF1|pancreas specific transcription factor, 1a', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=23192312, end_position_on_the_genomic_accession=23194245, orientation='plus', exon_count=2, OMIM=[607194], no_hdr0=''),
    256302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256302, CurrentID=0, Status='live', Symbol='NATD1', Aliases=['C17orf103', 'Gtlf3b'], description='N-acetyltransferase domain containing 1', other_designations='protein NATD1|N-acetyltransferase domain-containing protein 1|gene trap locus F3b|protein GTLF3B|transcript expressed during hematopoiesis 2', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21238870, end_position_on_the_genomic_accession=21253410, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    256309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256309, CurrentID=0, Status='live', Symbol='CCDC110', Aliases=['CT52', 'KM-HN-1', 'KMHN1'], description='coiled-coil domain containing 110', other_designations='coiled-coil domain-containing protein 110|cancer/testis antigen 52|cancer/testis antigen KM-HN-1', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185445182, end_position_on_the_genomic_accession=185471752, orientation='minus', exon_count=13, OMIM=[609488], no_hdr0=''),
    256329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256329, CurrentID=0, Status='live', Symbol='LMNTD2', Aliases=['C11orf35'], description='lamin tail domain containing 2', other_designations='lamin tail domain-containing protein 2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=554850, end_position_on_the_genomic_accession=560780, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    256356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256356, CurrentID=0, Status='live', Symbol='GK5', Aliases=[], description='glycerol kinase 5', other_designations='putative glycerol kinase 5|ATP:glycerol 3-phosphotransferase 5|GK 5|glycerokinase 5|glycerol kinase 5 (putative)', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142157527, end_position_on_the_genomic_accession=142225592, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    256364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256364, CurrentID=0, Status='live', Symbol='EML3', Aliases=['ELP95', 'EMAP3', 'EMAP95'], description='EMAP like 3', other_designations='echinoderm microtubule-associated protein-like 3|EMAP-3|echinoderm microtubule associated protein like 3', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62602218, end_position_on_the_genomic_accession=62612775, orientation='minus', exon_count=23, OMIM=[618118], no_hdr0=''),
    256369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256369, CurrentID=0, Status='live', Symbol='CCDC197', Aliases=['C14orf48', 'LINC00521', 'c14_5713'], description='coiled-coil domain containing 197', other_designations='uncharacterized protein CCDC197|coiled-coil domain-containing protein 197|long intergenic non-protein coding RNA 521', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93997207, end_position_on_the_genomic_accession=94011695, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    256380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256380, CurrentID=0, Status='live', Symbol='SCML4', Aliases=['dJ47M23.1'], description='Scm polycomb group protein like 4', other_designations='sex comb on midleg-like protein 4|sex comb on midleg like 4', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=107697297, end_position_on_the_genomic_accession=107845959, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    256394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256394, CurrentID=0, Status='live', Symbol='SERPINA11', Aliases=[], description='serpin family A member 11', other_designations='serpin A11|antiproteinase-like 2|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 11|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 11', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94442438, end_position_on_the_genomic_accession=94452857, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    256435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256435, CurrentID=0, Status='live', Symbol='ST6GALNAC3', Aliases=['PRO7177', 'SIAT7C', 'ST6GALNACIII', 'STY'], description='ST6 N-acetylgalactosaminide alpha-2,6-sialyltransferase 3', other_designations='alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase 3|GalNAc alpha-2,6-sialyltransferase III|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltran|ST6 (alpha-N-acetyl-neuraminyl-2,3-beta-galactosyl-1,3)-N-acetylgalactosaminide alpha-2,6-sialyltransferase 3|ST6 GalNAc alpha-2,6-sialyltransferase 3|alpha-N-acetylgalactosaminide alpha-2,6-sialyltransferase III|sialyltransferase 7 ((alpha-N-acetylneuraminyl-2,3-beta-galactosyl-1,3)-N-acetyl galactosaminide alpha-2,6-sialyltransferase) C|sialyltransferase 7C', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=76074734, end_position_on_the_genomic_accession=76637339, orientation='plus', exon_count=10, OMIM=[610133], no_hdr0=''),
    256471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256471, CurrentID=0, Status='live', Symbol='MFSD8', Aliases=['CCMD', 'CLN7'], description='major facilitator superfamily domain containing 8', other_designations='major facilitator superfamily domain-containing protein 8|ceroid-lipofuscinosis, neuronal 7, late infantile', map_location='4q28.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=127917732, end_position_on_the_genomic_accession=127965988, orientation='minus', exon_count=13, OMIM=[611124], no_hdr0=''),
    256472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256472, CurrentID=0, Status='live', Symbol='TMEM151A', Aliases=['TMEM151'], description='transmembrane protein 151A', other_designations='transmembrane protein 151A|transmembrane protein 151', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66291894, end_position_on_the_genomic_accession=66296664, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    256536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256536, CurrentID=0, Status='live', Symbol='TCERG1L', Aliases=[], description='transcription elongation regulator 1 like', other_designations='transcription elongation regulator 1-like protein|5730476P14Rik', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=131092391, end_position_on_the_genomic_accession=131311721, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    256586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256586, CurrentID=0, Status='live', Symbol='LYSMD2', Aliases=[], description='LysM domain containing 2', other_designations='lysM and putative peptidoglycan-binding domain-containing protein 2|LysM, putative peptidoglycan-binding, domain containing 2', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51723011, end_position_on_the_genomic_accession=51751451, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    256643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256643, CurrentID=0, Status='live', Symbol='BCLAF3', Aliases=['CXorf23'], description='BCLAF1 and THRAP3 family member 3', other_designations='BCLAF1 and THRAP3 family member 3|uncharacterized protein CXorf23', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=19912860, end_position_on_the_genomic_accession=19991061, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    256646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256646, CurrentID=0, Status='live', Symbol='NUTM1', Aliases=['C15orf55', 'FAM22H', 'NUT'], description='NUT midline carcinoma family member 1', other_designations='NUT family member 1|nuclear protein in testis', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34343315, end_position_on_the_genomic_accession=34357735, orientation='plus', exon_count=8, OMIM=[608963], no_hdr0=''),
    256691 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256691, CurrentID=0, Status='live', Symbol='MAMDC2', Aliases=[], description='MAM domain containing 2', other_designations='MAM domain-containing protein 2|MAM domain-containing proteoglycan|mamcan', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=70043581, end_position_on_the_genomic_accession=70226972, orientation='plus', exon_count=16, OMIM=[612879], no_hdr0=''),
    256710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256710, CurrentID=0, Status='live', Symbol='GLIPR1L1', Aliases=['ALKN2972', 'PRO7434'], description='GLIPR1 like 1', other_designations='GLIPR1-like protein 1|GLI pathogenesis related 1 like 1', map_location='12q21.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=75331834, end_position_on_the_genomic_accession=75370560, orientation='plus', exon_count=7, OMIM=[610395], no_hdr0=''),
    256714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256714, CurrentID=0, Status='live', Symbol='MAP7D2', Aliases=[], description='MAP7 domain containing 2', other_designations='MAP7 domain-containing protein 2|MAP7 domain containing 2 brain|MAP7 domain containing 2 protein varaint 1|MAP7 domain containing 2 protein varaint 2|MAP7 domain-containing protein 2 brain specific variant 1|MAP7 domain-containing protein 2 brain specific variant 2', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=20006713, end_position_on_the_genomic_accession=20116907, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    256764 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256764, CurrentID=0, Status='live', Symbol='WDR72', Aliases=['AI2A3'], description='WD repeat domain 72', other_designations='WD repeat-containing protein 72', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=53513741, end_position_on_the_genomic_accession=53762878, orientation='minus', exon_count=26, OMIM=[613214], no_hdr0=''),
    256815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256815, CurrentID=0, Status='live', Symbol='C10orf67', Aliases=['C10orf115', 'LINC01552'], description='chromosome 10 open reading frame 67', other_designations='uncharacterized protein C10orf67, mitochondrial|long intergenic non-protein coding RNA 1552', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=23201916, end_position_on_the_genomic_accession=23345216, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    256892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256892, CurrentID=0, Status='live', Symbol='OR51F1', Aliases=['OR11-21P', 'OR51F1'], description='olfactory receptor family 51 subfamily F member 1', other_designations='olfactory receptor 51F1|olfactory receptor OR11-21 pseudogene|olfactory receptor, family 51, subfamily F, member 1 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4768979, end_position_on_the_genomic_accession=4769938, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    256933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256933, CurrentID=0, Status='live', Symbol='NPB', Aliases=['L7', 'PPL7', 'PPNPB'], description='neuropeptide B', other_designations='neuropeptide B|prepro-NPB|preproneuropeptide B|preproprotein L7', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81902238, end_position_on_the_genomic_accession=81902905, orientation='plus', exon_count=2, OMIM=[607996], no_hdr0=''),
    256949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256949, CurrentID=0, Status='live', Symbol='KANK3', Aliases=['ANKRD47'], description='KN motif and ankyrin repeat domains 3', other_designations='KN motif and ankyrin repeat domain-containing protein 3|ankyrin repeat domain 47|ankyrin repeat domain-containing protein 47|kidney ankyrin repeat-containing protein 3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8322584, end_position_on_the_genomic_accession=8343262, orientation='minus', exon_count=14, OMIM=[614611], no_hdr0=''),
    256957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256957, CurrentID=0, Status='live', Symbol='HEATR9', Aliases=['C17orf66'], description='HEAT repeat containing 9', other_designations='protein HEATR9|HEAT repeat-containing protein 9', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35854946, end_position_on_the_genomic_accession=35868891, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    256979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256979, CurrentID=0, Status='live', Symbol='SUN3', Aliases=['SUNC1'], description='Sad1 and UNC84 domain containing 3', other_designations='SUN domain-containing protein 3|Sad1 and UNC84 domain containing 1|hypothetical protein MGC33329|sad1/unc-84 domain-containing protein 1', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=47987148, end_position_on_the_genomic_accession=48035899, orientation='minus', exon_count=14, OMIM=[618984], no_hdr0=''),
    256987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=256987, CurrentID=0, Status='live', Symbol='SERINC5', Aliases=['C5orf12', 'TPO1'], description='serine incorporator 5', other_designations='serine incorporator 5', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80111225, end_position_on_the_genomic_accession=80256048, orientation='minus', exon_count=17, OMIM=[614551], no_hdr0=''),
    257019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257019, CurrentID=0, Status='live', Symbol='FRMD3', Aliases=['4.1O', 'EPB41L4O', 'EPB41LO', 'P410'], description='FERM domain containing 3', other_designations='FERM domain-containing protein 3|band 4.1-like protein 4|band 4.1-like protein 4O|ovary type protein 4.1|protein 4.1O', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83242992, end_position_on_the_genomic_accession=83585797, orientation='minus', exon_count=22, OMIM=[607619], no_hdr0=''),
    257044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257044, CurrentID=0, Status='live', Symbol='CATSPERE', Aliases=['C10orf101', 'C1orf101'], description='catsper channel auxiliary subunit epsilon', other_designations='cation channel sperm-associated protein subunit epsilon|catSper-epsilon|catSperepsilon|uncharacterized protein C1orf101', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=244452013, end_position_on_the_genomic_accession=244640504, orientation='plus', exon_count=31, OMIM=[617510], no_hdr0=''),
    257062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257062, CurrentID=0, Status='live', Symbol='CATSPERD', Aliases=['TMEM146'], description='cation channel sperm associated auxiliary subunit delta', other_designations='cation channel sperm-associated protein subunit delta|catSper-delta|catSperdelta|catsper channel auxiliary subunit delta|transmembrane protein 146', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5720156, end_position_on_the_genomic_accession=5778734, orientation='plus', exon_count=25, OMIM=[617490], no_hdr0=''),
    257068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257068, CurrentID=0, Status='live', Symbol='PLCXD2', Aliases=[], description='phosphatidylinositol specific phospholipase C X domain containing 2', other_designations='PI-PLC X domain-containing protein 2', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=111674676, end_position_on_the_genomic_accession=111846447, orientation='plus', exon_count=5, OMIM=[617015], no_hdr0=''),
    257101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257101, CurrentID=0, Status='live', Symbol='ZNF683', Aliases=['Hobit'], description='zinc finger protein 683', other_designations='tissue-resident T-cell transcription regulator protein ZNF683|homolog of Blimp-1 in T cells|homolog of Blimp-1 in T-cell|hypothetical protein MGC33414', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26361632, end_position_on_the_genomic_accession=26374536, orientation='minus', exon_count=10, OMIM=[616775], no_hdr0=''),
    257106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257106, CurrentID=0, Status='live', Symbol='ARHGAP30', Aliases=[], description='Rho GTPase activating protein 30', other_designations='rho GTPase-activating protein 30|rho-type GTPase-activating protein 30', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161046942, end_position_on_the_genomic_accession=161069971, orientation='minus', exon_count=12, OMIM=[614264], no_hdr0=''),
    257144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257144, CurrentID=0, Status='live', Symbol='GCSAM', Aliases=['GCAT2', 'GCET2', 'HGAL'], description='germinal center associated signaling and motility', other_designations='germinal center-associated signaling and motility protein|germinal center B-cell-expressed transcript 2 protein|germinal center expressed transcript 2|germinal center-associated lymphoma protein|human germinal center-associated lymphoma', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112120839, end_position_on_the_genomic_accession=112133956, orientation='minus', exon_count=7, OMIM=[607792], no_hdr0=''),
    257160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257160, CurrentID=0, Status='live', Symbol='RNF214', Aliases=[], description='ring finger protein 214', other_designations='RING finger protein 214', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117232671, end_position_on_the_genomic_accession=117286454, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    257169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257169, CurrentID=0, Status='live', Symbol='C9orf43', Aliases=[], description='chromosome 9 open reading frame 43', other_designations='uncharacterized protein C9orf43', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=113410644, end_position_on_the_genomic_accession=113429690, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    257177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257177, CurrentID=0, Status='live', Symbol='CFAP126', Aliases=['C1orf192', 'Flattop', 'Fltp'], description='cilia and flagella associated protein 126', other_designations='protein Flattop|UPF0740 protein C1orf192', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161364733, end_position_on_the_genomic_accession=161367876, orientation='minus', exon_count=5, OMIM=[616119], no_hdr0=''),
    257194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257194, CurrentID=0, Status='live', Symbol='NEGR1', Aliases=['DMML2433', 'IGLON4', 'KILON', 'Ntra'], description='neuronal growth regulator 1', other_designations='neuronal growth regulator 1|IgLON family member 4|a kindred of IgLON|neurotractin', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=71395943, end_position_on_the_genomic_accession=72282539, orientation='minus', exon_count=10, OMIM=[613173], no_hdr0=''),
    257202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257202, CurrentID=0, Status='live', Symbol='GPX6', Aliases=['GPX5p', 'GPXP3', 'GPx-6', 'GSHPx-6', 'dJ1186N24', 'dJ1186N24.1'], description='glutathione peroxidase 6', other_designations='glutathione peroxidase 6|glutathione peroxidase 6 (olfactory)|selenoprotein GPX6', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28503296, end_position_on_the_genomic_accession=28515793, orientation='minus', exon_count=5, OMIM=[607913], no_hdr0=''),
    257218 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257218, CurrentID=0, Status='live', Symbol='SHPRH', Aliases=['bA545I5.2'], description='SNF2 histone linker PHD RING helicase', other_designations='E3 ubiquitin-protein ligase SHPRH|2610103K11Rik|RING-type E3 ubiquitin transferase SHPRH|SNF2 histone linker PHD RING helicase, E3 ubiquitin protein ligase|SNF2, histone-linker, PHD and RING finger domain-containing helicase', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=145857838, end_position_on_the_genomic_accession=145964358, orientation='minus', exon_count=37, OMIM=[608048], no_hdr0=''),
    257236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257236, CurrentID=0, Status='live', Symbol='CCDC96', Aliases=[], description='coiled-coil domain containing 96', other_designations='coiled-coil domain-containing protein 96', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7040849, end_position_on_the_genomic_accession=7043001, orientation='minus', exon_count=1, OMIM=[619347], no_hdr0=''),
    257240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257240, CurrentID=0, Status='live', Symbol='KLHL34', Aliases=[], description='kelch like family member 34', other_designations='kelch-like protein 34|RP11-450P7.3|kelch-like 34', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21654690, end_position_on_the_genomic_accession=21658330, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    257313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257313, CurrentID=0, Status='live', Symbol='UTS2B', Aliases=['U-IIB', 'U2B', 'UIIB', 'URP', 'UTS2D'], description='urotensin 2B', other_designations='urotensin-2B|prepro-URP|urotensin 2 domain containing|urotensin II-related peptide|urotensin IIB|urotensin-2 domain-containing protein', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=191266465, end_position_on_the_genomic_accession=191330526, orientation='minus', exon_count=11, OMIM=[618134], no_hdr0=''),
    257364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257364, CurrentID=0, Status='live', Symbol='SNX33', Aliases=['SH3PX3', 'SH3PXD3C', 'SNX30'], description='sorting nexin 33', other_designations='sorting nexin-33|SH3 and PX domain containing 3|SH3 and PX domain-containing protein 3', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75647912, end_position_on_the_genomic_accession=75662301, orientation='plus', exon_count=2, OMIM=[619107], no_hdr0=''),
    257397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257397, CurrentID=0, Status='live', Symbol='TAB3', Aliases=['MAP3K7IP3', 'NAP1'], description='TGF-beta activated kinase 1 (MAP3K7) binding protein 3', other_designations='TGF-beta-activated kinase 1 and MAP3K7-binding protein 3|NF-kappa-B-activating protein 1|NFkB activating protein 1|TAB-3|TAK1-binding protein 3|TGF-beta activated kinase 1 and MAP3K7 binding protein 3|TGF-beta-activated kinase 1-binding protein 3|mitogen-activated protein kinase kinase kinase 7 interacting protein 3', map_location='Xp21.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=30827442, end_position_on_the_genomic_accession=30889391, orientation='minus', exon_count=15, OMIM=[300480], no_hdr0=''),
    257407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257407, CurrentID=0, Status='live', Symbol='C2orf72', Aliases=[], description='chromosome 2 open reading frame 72', other_designations='uncharacterized protein C2orf72', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=231037523, end_position_on_the_genomic_accession=231049719, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    257415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257415, CurrentID=0, Status='live', Symbol='FAM133B', Aliases=[], description='family with sequence similarity 133 member B', other_designations='protein FAM133B', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92560758, end_position_on_the_genomic_accession=92590390, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    257629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=257629, CurrentID=0, Status='live', Symbol='ANKS4B', Aliases=['HARP'], description='ankyrin repeat and sterile alpha motif domain containing 4B', other_designations='ankyrin repeat and SAM domain-containing protein 4B|harmonin-interacting ankyrin-repeat containing protein', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21233699, end_position_on_the_genomic_accession=21253850, orientation='plus', exon_count=2, OMIM=[609901], no_hdr0=''),
    258010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=258010, CurrentID=0, Status='live', Symbol='SVIP', Aliases=[], description='small VCP interacting protein', other_designations='small VCP/p97-interacting protein', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22812429, end_position_on_the_genomic_accession=22829865, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    259173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259173, CurrentID=0, Status='live', Symbol='ALS2CL', Aliases=['RN49018'], description='ALS2 C-terminal like', other_designations='ALS2 C-terminal-like protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46668995, end_position_on_the_genomic_accession=46693693, orientation='minus', exon_count=32, OMIM=[612402], no_hdr0=''),
    259197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259197, CurrentID=0, Status='live', Symbol='NCR3', Aliases=['1C7', 'CD337', 'LY117', 'MALS', 'NKp30'], description='natural cytotoxicity triggering receptor 3', other_designations='natural cytotoxicity triggering receptor 3|NK-p30|activating NK-A1 receptor|activating natural killer receptor p30|lymphocyte antigen 117|natural killer cell p30-related protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31588895, end_position_on_the_genomic_accession=31593024, orientation='minus', exon_count=6, OMIM=[611550], no_hdr0=''),
    259215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259215, CurrentID=0, Status='live', Symbol='LY6G6F', Aliases=['C6orf21', 'G6f', 'LY6G6', 'LY6G6D', 'NG32'], description='lymphocyte antigen 6 family member G6F', other_designations='lymphocyte antigen 6 complex locus protein G6f|lymphocyte antigen 6 complex, locus G6D|lymphocyte antigen 6 complex, locus G6F', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31706866, end_position_on_the_genomic_accession=31710679, orientation='plus', exon_count=6, OMIM=[611404], no_hdr0=''),
    259217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259217, CurrentID=0, Status='live', Symbol='HSPA12A', Aliases=[], description='heat shock protein family A (Hsp70) member 12A', other_designations='heat shock 70 kDa protein 12A|heat shock 70kD protein 12A|heat shock 70kDa protein 12A', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116671192, end_position_on_the_genomic_accession=116853272, orientation='minus', exon_count=17, OMIM=[610701], no_hdr0=''),
    259230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259230, CurrentID=0, Status='live', Symbol='SGMS1', Aliases=['MOB', 'MOB1', 'SMS1', 'TMEM23', 'hmob33'], description='sphingomyelin synthase 1', other_designations='phosphatidylcholine:ceramide cholinephosphotransferase 1|medulla oblongata-derived protein|protein Mob|transmembrane protein 23', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50305600, end_position_on_the_genomic_accession=50623956, orientation='minus', exon_count=15, OMIM=[611573], no_hdr0=''),
    259232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259232, CurrentID=0, Status='live', Symbol='NALCN', Aliases=['CLIFAHDD', 'CanIon', 'IHPRF', 'IHPRF1', 'INNFD', 'VGCNL1', 'bA430M15.1'], description='sodium leak channel, non-selective', other_designations='sodium leak channel non-selective protein|four repeat voltage-gated ion channel|voltage gated channel like 1', map_location='13q32.3-q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=101053774, end_position_on_the_genomic_accession=101417206, orientation='minus', exon_count=48, OMIM=[611549], no_hdr0=''),
    259236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259236, CurrentID=0, Status='live', Symbol='TMIE', Aliases=['DFNB6'], description='transmembrane inner ear', other_designations='transmembrane inner ear expressed protein|transmembrane inner ear protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46693778, end_position_on_the_genomic_accession=46710886, orientation='plus', exon_count=5, OMIM=[607237], no_hdr0=''),
    259239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259239, CurrentID=0, Status='live', Symbol='WFDC11', Aliases=['WAP11'], description='WAP four-disulfide core domain 11', other_designations='protein WFDC11|protease inhibitor WAP11', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45648563, end_position_on_the_genomic_accession=45670239, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    259240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259240, CurrentID=0, Status='live', Symbol='WFDC9', Aliases=['WAP9', 'dJ688G8.2'], description='WAP four-disulfide core domain 9', other_designations='protein WFDC9', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45607939, end_position_on_the_genomic_accession=45631284, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    259249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259249, CurrentID=0, Status='live', Symbol='MRGPRX1', Aliases=['GPCR', 'MGRG2', 'MRGX1', 'SNSR4'], description='MAS related GPR family member X1', other_designations='mas-related G-protein coupled receptor member X1|G protein-coupled receptor MRGX1|G protein-coupled receptor SNSR3|MAS-related GPR, member X1|Mas-related G protein-coupled receptor G2|sensory neuron-specific G-protein coupled receptor 3/4', map_location='11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18933499, end_position_on_the_genomic_accession=18939414, orientation='minus', exon_count=2, OMIM=[607227], no_hdr0=''),
    259266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259266, CurrentID=0, Status='live', Symbol='ASPM', Aliases=['ASP', 'Calmbp1', 'MCPH5'], description='assembly factor for spindle microtubules', other_designations='abnormal spindle-like microcephaly-associated protein|abnormal spindle microtubule assembly|asp (abnormal spindle) homolog, microcephaly associated', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197084127, end_position_on_the_genomic_accession=197146669, orientation='minus', exon_count=28, OMIM=[605481], no_hdr0=''),
    259282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259282, CurrentID=0, Status='live', Symbol='BOD1L1', Aliases=['BOD1L', 'FAM44A'], description='biorientation of chromosomes in cell division 1 like 1', other_designations='biorientation of chromosomes in cell division protein 1-like 1|biorientation of chromosomes in cell division 1-like|family with sequence similarity 44, member A', map_location='4p15.33', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=13568738, end_position_on_the_genomic_accession=13627725, orientation='minus', exon_count=28, OMIM=[616746], no_hdr0=''),
    259285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259285, CurrentID=0, Status='live', Symbol='TAS2R39', Aliases=['T2R39', 'T2R57'], description='taste 2 receptor member 39', other_designations='taste receptor type 2 member 39|taste receptor type 2 member 57|taste receptor, type 2, member 39', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143183419, end_position_on_the_genomic_accession=143184435, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    259286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259286, CurrentID=0, Status='live', Symbol='TAS2R40', Aliases=['GPR60', 'T2R40', 'T2R58'], description='taste 2 receptor member 40', other_designations='taste receptor type 2 member 40|G-protein coupled receptor 60|taste receptor type 2 member 58|taste receptor, type 2, member 40', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143222037, end_position_on_the_genomic_accession=143223079, orientation='plus', exon_count=1, OMIM=[613964], no_hdr0=''),
    259287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259287, CurrentID=0, Status='live', Symbol='TAS2R41', Aliases=['T2R41', 'T2R59'], description='taste 2 receptor member 41', other_designations='taste receptor type 2 member 41|taste receptor type 2 member 59|taste receptor, type 2, member 41', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143477873, end_position_on_the_genomic_accession=143478796, orientation='plus', exon_count=1, OMIM=[613965], no_hdr0=''),
    259289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259289, CurrentID=0, Status='live', Symbol='TAS2R43', Aliases=['T2R43', 'T2R52'], description='taste 2 receptor member 43', other_designations='taste receptor type 2 member 43|taste receptor type 2 member 52|taste receptor, type 2, member 43', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11091287, end_position_on_the_genomic_accession=11092313, orientation='minus', exon_count=1, OMIM=[612668], no_hdr0=''),
    259290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259290, CurrentID=0, Status='live', Symbol='TAS2R31', Aliases=['T2R31', 'T2R44', 'T2R53', 'TAS2R44'], description='taste 2 receptor member 31', other_designations='taste receptor type 2 member 31|taste receptor type 2 member 44|taste receptor type 2 member 53|taste receptor, type 2, member 31', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11030387, end_position_on_the_genomic_accession=11031407, orientation='minus', exon_count=1, OMIM=[612669], no_hdr0=''),
    259291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259291, CurrentID=0, Status='live', Symbol='TAS2R45', Aliases=['GPR59', 'T2R45', 'ZG24P'], description='taste 2 receptor member 45', other_designations='taste receptor type 2 member 45|G-protein coupled receptor 59|taste receptor, type 2, member 45', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[613967], no_hdr0=''),
    259292 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259292, CurrentID=0, Status='live', Symbol='TAS2R46', Aliases=['T2R46', 'T2R54'], description='taste 2 receptor member 46', other_designations='taste receptor type 2 member 46|taste receptor type 2 member 54|taste receptor, type 2, member 46', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11061365, end_position_on_the_genomic_accession=11062294, orientation='minus', exon_count=1, OMIM=[612774], no_hdr0=''),
    259293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259293, CurrentID=0, Status='live', Symbol='TAS2R30', Aliases=['T2R30', 'T2R47', 'TAS2R47'], description='taste 2 receptor member 30', other_designations='taste receptor type 2 member 30|taste receptor T2R47|taste receptor type 2 member 47|taste receptor, type 2, member 30|type 2 taste receptor member 30|type 2 taste receptor member 47', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11133285, end_position_on_the_genomic_accession=11134244, orientation='minus', exon_count=1, OMIM=[613963], no_hdr0=''),
    259294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259294, CurrentID=0, Status='live', Symbol='TAS2R19', Aliases=['MSTP058', 'T2R19', 'T2R23', 'T2R48', 'TAS2R23', 'TAS2R48'], description='taste 2 receptor member 19', other_designations='taste receptor type 2 member 19|taste receptor, type 2, member 19|taste receptor, type 2, member 23|taste receptor, type 2, member 48', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11021619, end_position_on_the_genomic_accession=11022620, orientation='minus', exon_count=1, OMIM=[613961], no_hdr0=''),
    259295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259295, CurrentID=0, Status='live', Symbol='TAS2R20', Aliases=['T2R20', 'T2R49', 'T2R56', 'TAS2R49'], description='taste 2 receptor member 20', other_designations='taste receptor type 2 member 20|taste receptor type 2 member 56|taste receptor, type 2, member 49', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10995961, end_position_on_the_genomic_accession=10998304, orientation='minus', exon_count=1, OMIM=[613962], no_hdr0=''),
    259296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259296, CurrentID=0, Status='live', Symbol='TAS2R50', Aliases=['T2R50', 'T2R51', 'TAS2R51'], description='taste 2 receptor member 50', other_designations='taste receptor type 2 member 50|taste receptor type 2 member 51|taste receptor, type 2, member 50', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10985913, end_position_on_the_genomic_accession=10986912, orientation='minus', exon_count=1, OMIM=[609627], no_hdr0=''),
    259307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259307, CurrentID=0, Status='live', Symbol='IL4I1', Aliases=['FIG1', 'LAAO', 'LAO', 'hIL4I1'], description='interleukin 4 induced 1', other_designations='L-amino-acid oxidase|Fig-1 protein|IL4-induced protein 1|interleukin four induced 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49889654, end_position_on_the_genomic_accession=49929504, orientation='minus', exon_count=12, OMIM=[609742], no_hdr0=''),
    259308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=259308, CurrentID=0, Status='live', Symbol='FAM205A', Aliases=['C9orf144B'], description='family with sequence similarity 205 member A', other_designations='protein FAM205A|transmembrane protein C9orf144B', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34723053, end_position_on_the_genomic_accession=34729488, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    260293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260293, CurrentID=0, Status='live', Symbol='CYP4X1', Aliases=['CYPIVX1'], description='cytochrome P450 family 4 subfamily X member 1', other_designations='cytochrome P450 4X1|cytochrome P450, family 4, subfamily X, polypeptide 1', map_location='1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46961364, end_position_on_the_genomic_accession=47055432, orientation='plus', exon_count=15, OMIM=[614999], no_hdr0=''),
    260334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260334, CurrentID=0, Status='live', Symbol='TUBB8B', Aliases=['TUBB8P12'], description='tubulin beta 8B', other_designations='tubulin beta 8B|HSA18p11 beta-tubulin 4Q pseudogene|Tubulin beta-8 chain-like protein LOC260334|tubulin beta 8 pseudogene 12', map_location='18p11.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47085, end_position_on_the_genomic_accession=73539, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    260425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260425, CurrentID=0, Status='live', Symbol='MAGI3', Aliases=['MAGI-3', 'dJ730K3.2'], description='membrane associated guanylate kinase, WW and PDZ domain containing 3', other_designations='membrane-associated guanylate kinase, WW and PDZ domain-containing protein 3|membrane-associated guanylate kinase inverted 3|membrane-associated guanylate kinase-related 3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113390474, end_position_on_the_genomic_accession=113685923, orientation='plus', exon_count=23, OMIM=[615943], no_hdr0=''),
    260429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260429, CurrentID=0, Status='live', Symbol='PRSS33', Aliases=['EOS'], description='serine protease 33', other_designations='serine protease 33|protease, serine 33|serine protease EOS', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2783953, end_position_on_the_genomic_accession=2787915, orientation='minus', exon_count=8, OMIM=[613797], no_hdr0=''),
    260434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260434, CurrentID=0, Status='live', Symbol='PYDC1', Aliases=['ASC2', 'POP1', 'PYC1', 'cPOP1'], description='pyrin domain containing 1', other_designations='pyrin domain-containing protein 1|PAAD-only protein 1|PYD (pyrin domain) containing 1|cellular POP1|pyrin-only protein 1', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31215962, end_position_on_the_genomic_accession=31217135, orientation='minus', exon_count=2, OMIM=[615700], no_hdr0=''),
    260436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=260436, CurrentID=0, Status='live', Symbol='FDCSP', Aliases=['C4orf7', 'FDC-SP'], description='follicular dendritic cell secreted protein', other_designations='follicular dendritic cell secreted peptide|FDC secreted protein', map_location='4q13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70226124, end_position_on_the_genomic_accession=70235252, orientation='plus', exon_count=5, OMIM=[607241], no_hdr0=''),
    261726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=261726, CurrentID=0, Status='live', Symbol='TIPRL', Aliases=['TIP', 'TIP411', 'TIPRL'], description='TOR signaling pathway regulator', other_designations='TIP41-like protein|TIP41, TOR signaling pathway regulator-like|putative MAPK-activating protein PM10|type 2A-interacting protein', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168178962, end_position_on_the_genomic_accession=168202109, orientation='plus', exon_count=8, OMIM=[611807], no_hdr0=''),
    261729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=261729, CurrentID=0, Status='live', Symbol='STEAP2', Aliases=['IPCA1', 'PCANAP1', 'PUMPCn', 'STAMP1', 'STMP'], description='STEAP2 metalloreductase', other_designations='metalloreductase STEAP2|STEAP family member 2, metalloreductase|SixTransMembrane Protein of Prostate 1|prostate cancer-associated protein 1|protein up-regulated in metastatic prostate cancer|protein upregulated in metastatic prostate cancer|six transmembrane epithelial antigen of the prostate 2|six-transmembrane epithelial antigen of prostate 2', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90211740, end_position_on_the_genomic_accession=90243408, orientation='plus', exon_count=9, OMIM=[605094], no_hdr0=''),
    261734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=261734, CurrentID=0, Status='live', Symbol='NPHP4', Aliases=['POC10', 'SLSN4'], description='nephrocystin 4', other_designations='nephrocystin-4|POC10 centriolar protein homolog|nephroretinin', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=5862810, end_position_on_the_genomic_accession=5992425, orientation='minus', exon_count=37, OMIM=[607215], no_hdr0=''),
    266629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266629, CurrentID=0, Status='live', Symbol='SEC14L3', Aliases=['TAP2'], description='SEC14 like lipid binding 3', other_designations='SEC14-like protein 3|SEC14-like 3|SEC14p-like protein TAP2|tocopherol-associated protein 2', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30447661, end_position_on_the_genomic_accession=30472017, orientation='minus', exon_count=15, OMIM=[612824], no_hdr0=''),
    266655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266655, CurrentID=0, Status='live', Symbol='BRD3OS', Aliases=['LINC00094', 'LP2477', 'NCRNA00094'], description='BRD3 opposite strand', other_designations='putative uncharacterized protein BRD3OS|BRD3 opposite strand protein|long intergenic non-protein coding RNA 94', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=134025481, end_position_on_the_genomic_accession=134031587, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    266661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266661, CurrentID=0, Status='live', Symbol='TAS2R22', Aliases=['T2R22'], description='taste 2 receptor member 22 pseudogene', other_designations='taste receptor, type 2, member 22', map_location='', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    266665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266665, CurrentID=0, Status='live', Symbol='TAS2R33', Aliases=['T2R33'], description='taste 2 receptor member 33', other_designations='taste receptor, type 2, member 33', map_location='', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    266666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266666, CurrentID=0, Status='live', Symbol='TAS2R36', Aliases=['T2R36'], description='taste 2 receptor member 36', other_designations='taste receptor, type 2, member 36', map_location='', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    266667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266667, CurrentID=0, Status='live', Symbol='TAS2R37', Aliases=['T2R37'], description='taste 2 receptor member 37 pseudogene', other_designations='taste receptor, type 2, member 37', map_location='', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    266675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266675, CurrentID=0, Status='live', Symbol='BEST4', Aliases=['VMD2L2'], description='bestrophin 4', other_designations='bestrophin-4|vitelliform macular dystrophy 2-like 2|vitelliform macular dystrophy 2-like protein 2', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44782145, end_position_on_the_genomic_accession=44792828, orientation='minus', exon_count=12, OMIM=[607336], no_hdr0=''),
    266722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266722, CurrentID=0, Status='live', Symbol='HS6ST3', Aliases=['HS6ST-3'], description='heparan sulfate 6-O-sulfotransferase 3', other_designations='heparan-sulfate 6-O-sulfotransferase 3', map_location='13q32.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=96090107, end_position_on_the_genomic_accession=96839562, orientation='plus', exon_count=4, OMIM=[609401], no_hdr0=''),
    266727 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266727, CurrentID=0, Status='live', Symbol='MDGA1', Aliases=['GPIM', 'MAMDC3'], description='MAM domain containing glycosylphosphatidylinositol anchor 1', other_designations='MAM domain-containing glycosylphosphatidylinositol anchor protein 1|GPI and MAM protein|MAM domain-containing protein 3|glycosylphosphatidylinositol-MAM', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=37630679, end_position_on_the_genomic_accession=37697883, orientation='minus', exon_count=18, OMIM=[609626], no_hdr0=''),
    266740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266740, CurrentID=0, Status='live', Symbol='MAGEA2B', Aliases=['CT1.2', 'MAGE2'], description='MAGE family member A2B', other_designations='melanoma-associated antigen 2|MAGE-2 antigen|cancer/testis antigen 1.2|melanoma antigen 2|melanoma antigen family A, 2B|melanoma antigen family A2B|melanoma antigen, family A, 2, copy b', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152714586, end_position_on_the_genomic_accession=152718607, orientation='plus', exon_count=7, OMIM=[300549], no_hdr0=''),
    266743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266743, CurrentID=0, Status='live', Symbol='NPAS4', Aliases=['Le-PAS', 'NXF', 'PASD10', 'bHLHe79'], description='neuronal PAS domain protein 4', other_designations='neuronal PAS domain-containing protein 4|HLH-PAS transcription factor NXF|PAS domain-containing protein 10|class E basic helix-loop-helix protein 79|neuronal PAS4', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66408922, end_position_on_the_genomic_accession=66426707, orientation='plus', exon_count=12, OMIM=[608554], no_hdr0=''),
    266747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266747, CurrentID=0, Status='live', Symbol='RGL4', Aliases=['Rgr'], description='ral guanine nucleotide dissociation stimulator like 4', other_designations='ral-GDS-related protein|Ral-GDS related protein Rgr|RalGDS related oncogene|ralGDS-like 4', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23691013, end_position_on_the_genomic_accession=23699168, orientation='plus', exon_count=13, OMIM=[612214], no_hdr0=''),
    266811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266811, CurrentID=0, Status='live', Symbol='NPSA', Aliases=[], description='novel prostate-specific antigen', other_designations='novel prostate-specific antigen', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    266812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266812, CurrentID=0, Status='live', Symbol='NAP1L5', Aliases=['DRLM'], description='nucleosome assembly protein 1 like 5', other_designations='nucleosome assembly protein 1-like 5|down-regulated in liver malignancy', map_location='4q21-q22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88695913, end_position_on_the_genomic_accession=88697829, orientation='minus', exon_count=1, OMIM=[612203], no_hdr0=''),
    266977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=266977, CurrentID=0, Status='live', Symbol='ADGRF1', Aliases=['GPR110', 'KPG_012', 'PGR19', 'hGPCR36'], description='adhesion G protein-coupled receptor F1', other_designations='adhesion G-protein coupled receptor F1|G protein-coupled receptor 110|G protein-coupled receptor PGR19|G-protein coupled receptor KPG_012|probable G-protein coupled receptor 110|seven transmembrane helix receptor', map_location='6', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46997708, end_position_on_the_genomic_accession=47042350, orientation='minus', exon_count=16, OMIM=[617430], no_hdr0=''),
    267002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=267002, CurrentID=0, Status='live', Symbol='PGBD2', Aliases=[], description='piggyBac transposable element derived 2', other_designations='piggyBac transposable element-derived protein 2', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248873827, end_position_on_the_genomic_accession=248919146, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    267004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=267004, CurrentID=0, Status='live', Symbol='PGBD3', Aliases=[], description='piggyBac transposable element derived 3', other_designations='piggyBac transposable element-derived protein 3', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49515105, end_position_on_the_genomic_accession=49524281, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    267012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=267012, CurrentID=0, Status='live', Symbol='DAOA', Aliases=['LG72', 'SG72'], description='D-amino acid oxidase activator', other_designations='D-amino acid oxidase activator|schizophrenia- and bipolar disorder-associated protein G72', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=105465867, end_position_on_the_genomic_accession=105491034, orientation='plus', exon_count=7, OMIM=[607408], no_hdr0=''),
    267020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=267020, CurrentID=0, Status='live', Symbol='ATP5MGL', Aliases=['ATP5K2', 'ATP5L2'], description='ATP synthase membrane subunit g like', other_designations='putative ATP synthase subunit g 2, mitochondrial|ATP synthase membrane subunit g-like protein|ATP synthase subunit g 2, mitochondrial|ATP synthase, H+ transporting, mitochondrial F0 complex, subunit G2 pseudogene|ATP synthase, H+ transporting, mitochondrial F1F0, subunit g|ATP synthase, H+ transporting, mitochondrial Fo complex subunit G2|ATPase subunit g 2', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=42639803, end_position_on_the_genomic_accession=42640601, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    280636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=280636, CurrentID=0, Status='live', Symbol='SELENOH', Aliases=['C11orf31', 'C17orf10', 'SELH'], description='selenoprotein H', other_designations='selenoprotein H', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57741491, end_position_on_the_genomic_accession=57743550, orientation='plus', exon_count=4, OMIM=[607914], no_hdr0=''),
    280658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=280658, CurrentID=0, Status='live', Symbol='SSX7', Aliases=[], description='SSX family member 7', other_designations='protein SSX7|synovial sarcoma, X breakpoint 7', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52644061, end_position_on_the_genomic_accession=52654900, orientation='minus', exon_count=9, OMIM=[300542], no_hdr0=''),
    280664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=280664, CurrentID=0, Status='live', Symbol='WFDC10B', Aliases=['WAP12'], description='WAP four-disulfide core domain 10B', other_designations='protein WFDC10B|protease inhibitor WAP12', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45684651, end_position_on_the_genomic_accession=45708899, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    282616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282616, CurrentID=0, Status='live', Symbol='IFNL2', Aliases=['IFNL2a', 'IFNL3a', 'IL-28A', 'IL28A'], description='interferon lambda 2', other_designations='interferon lambda-2|IFN-lambda-2|cytokine Zcyto20|interleukin 28A (interferon, lambda 2)|interleukin-28A', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39268396, end_position_on_the_genomic_accession=39270188, orientation='plus', exon_count=6, OMIM=[607401], no_hdr0=''),
    282617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282617, CurrentID=0, Status='live', Symbol='IFNL3', Aliases=['IFN-lambda-3', 'IFN-lambda-4', 'IL-28B', 'IL-28C', 'IL28B', 'IL28C'], description='interferon lambda 3', other_designations='interferon lambda-3|cytokine Zcyto22|interferon, lambda 4|interleukin-28B|interleukin-28C', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39243455, end_position_on_the_genomic_accession=39245250, orientation='minus', exon_count=6, OMIM=[607402], no_hdr0=''),
    282618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282618, CurrentID=0, Status='live', Symbol='IFNL1', Aliases=['IL-29', 'IL29'], description='interferon lambda 1', other_designations='interferon lambda-1|IFN-lambda-1|cytokine Zcyto21|interleukin 29 (interferon, lambda 1)|interleukin-29', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39296407, end_position_on_the_genomic_accession=39298673, orientation='plus', exon_count=5, OMIM=[607403], no_hdr0=''),
    282679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282679, CurrentID=0, Status='live', Symbol='AQP11', Aliases=['AQPX1'], description='aquaporin 11', other_designations='aquaporin-11|AQP-11', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=77589953, end_position_on_the_genomic_accession=77610356, orientation='plus', exon_count=3, OMIM=[609914], no_hdr0=''),
    282763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282763, CurrentID=0, Status='live', Symbol='OR51B5', Aliases=["HOR5'Beta5", 'OR11-37'], description='olfactory receptor family 51 subfamily B member 5', other_designations="olfactory receptor 51B5|odorant receptor HOR5'beta5|olfactory receptor OR11-37", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5340318, end_position_on_the_genomic_accession=5505652, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    282770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282770, CurrentID=0, Status='live', Symbol='OR10AG1', Aliases=['OR11-160'], description='olfactory receptor family 10 subfamily AG member 1', other_designations='olfactory receptor 10AG1|olfactory receptor OR11-160', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55965755, end_position_on_the_genomic_accession=55969945, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    282775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282775, CurrentID=0, Status='live', Symbol='OR5J2', Aliases=['OR11-266'], description='olfactory receptor family 5 subfamily J member 2', other_designations='olfactory receptor 5J2|olfactory receptor OR11-266', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56176618, end_position_on_the_genomic_accession=56177556, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    282808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282808, CurrentID=0, Status='live', Symbol='RAB40AL', Aliases=['MRXSMP', 'RAR2', 'RLGP'], description='RAB40A like', other_designations='ras-related protein Rab-40A-like|RAB40A, member RAS oncogene family-like|Ras like GTPase|SOCS box containing protein RAR2|ras-like GTPase', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102937272, end_position_on_the_genomic_accession=102938300, orientation='plus', exon_count=1, OMIM=[300405], no_hdr0=''),
    282809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282809, CurrentID=0, Status='live', Symbol='POC1B', Aliases=['CORD20', 'PIX1', 'TUWD12', 'WDR51B'], description='POC1 centriolar protein B', other_designations='POC1 centriolar protein homolog B|WD repeat-containing protein 51B|proteome of centriole protein 1B', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=89419718, end_position_on_the_genomic_accession=89526047, orientation='minus', exon_count=13, OMIM=[614784], no_hdr0=''),
    282890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282890, CurrentID=0, Status='live', Symbol='ZNF311', Aliases=['zf31'], description='zinc finger protein 311', other_designations='zinc finger protein 311|zinc finger protein zfp31', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28994785, end_position_on_the_genomic_accession=29005668, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    282966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282966, CurrentID=0, Status='live', Symbol='C10orf53', Aliases=[], description='chromosome 10 open reading frame 53', other_designations='UPF0728 protein C10orf53', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49679651, end_position_on_the_genomic_accession=49710261, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    282969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282969, CurrentID=0, Status='live', Symbol='FUOM', Aliases=['C10orf125', 'FUCU', 'FucM'], description='fucose mutarotase', other_designations='fucose mutarotase|protein fucU homolog', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133352773, end_position_on_the_genomic_accession=133358031, orientation='minus', exon_count=7, OMIM=[617725], no_hdr0=''),
    282973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282973, CurrentID=0, Status='live', Symbol='JAKMIP3', Aliases=['C10orf14', 'C10orf39', 'Jamip3', 'NECC2', 'bA140A10.5'], description='Janus kinase and microtubule interacting protein 3', other_designations='janus kinase and microtubule-interacting protein 3|neuroendocrine long coiled-coil 2|neuroendocrine long coiled-coil protein 2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132036068, end_position_on_the_genomic_accession=132184858, orientation='plus', exon_count=31, OMIM=[611198], no_hdr0=''),
    282974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282974, CurrentID=0, Status='live', Symbol='STK32C', Aliases=['PKE', 'YANK3'], description='serine/threonine kinase 32C', other_designations='serine/threonine-protein kinase 32C|PKE protein kinase|testicular tissue protein Li 187|yet another novel kinase 3', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=132207482, end_position_on_the_genomic_accession=132332559, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    282991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282991, CurrentID=0, Status='live', Symbol='BLOC1S2', Aliases=['BLOS2', 'BORCS2', 'CEAP', 'CEAP11'], description='biogenesis of lysosomal organelles complex 1 subunit 2', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 2|11 kDa centrosome associated protein|BLOC-1 subunit 2|centrosomal 10 kDa protein|centrosome protein oncogene', map_location='10q24.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=100273278, end_position_on_the_genomic_accession=100286692, orientation='minus', exon_count=6, OMIM=[609768], no_hdr0=''),
    282996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=282996, CurrentID=0, Status='live', Symbol='RBM20', Aliases=[], description='RNA binding motif protein 20', other_designations='RNA-binding protein 20|probable RNA-binding protein 20|truncated RNA binding motif protein 20', map_location='10q25.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=110641933, end_position_on_the_genomic_accession=110839471, orientation='plus', exon_count=16, OMIM=[613171], no_hdr0=''),
    283008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283008, CurrentID=0, Status='live', Symbol='NUTM2E', Aliases=['FAM22E'], description='NUT family member 2E', other_designations='nUT family member 2E|family with sequence similarity 22, member E', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79826739, end_position_on_the_genomic_accession=79850878, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    283078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283078, CurrentID=0, Status='live', Symbol='MKX', Aliases=['C10orf48', 'IFRX', 'IRXL1'], description='mohawk homeobox', other_designations='homeobox protein Mohawk|Iroquois family related homeodomain protein|iroquois homeobox protein-like 1', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27672874, end_position_on_the_genomic_accession=27745819, orientation='minus', exon_count=10, OMIM=[601332], no_hdr0=''),
    283092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283092, CurrentID=0, Status='live', Symbol='OR4C13', Aliases=[], description='olfactory receptor family 4 subfamily C member 13', other_designations='olfactory receptor 4C13|olfactory receptor OR11-260', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=49952391, end_position_on_the_genomic_accession=49953419, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    283093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283093, CurrentID=0, Status='live', Symbol='OR4C12', Aliases=['OR11-259'], description='olfactory receptor family 4 subfamily C member 12', other_designations='olfactory receptor 4C12|olfactory receptor OR11-259|seven transmembrane helix receptor', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=49981473, end_position_on_the_genomic_accession=49982535, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283106, CurrentID=0, Status='live', Symbol='CSNK2A3', Aliases=['CSNK2A1P'], description='casein kinase 2 alpha 3', other_designations='casein kinase II subunit alpha 3|casein kinase 2, alpha 1 polypeptide pseudogene|casein kinase 2, alpha 3 polypeptide', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=11351942, end_position_on_the_genomic_accession=11353250, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283111, CurrentID=0, Status='live', Symbol='OR51V1', Aliases=['OR11-36', 'OR51A12'], description='olfactory receptor family 51 subfamily V member 1', other_designations="olfactory receptor 51V1|odorant receptor HOR3'beta1|olfactory receptor 51A12|olfactory receptor OR11-36", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5199735, end_position_on_the_genomic_accession=5200682, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283116, CurrentID=0, Status='live', Symbol='TRIM49B', Aliases=[], description='tripartite motif containing 49B', other_designations='putative tripartite motif-containing protein 49B|RING finger protein 18B|tripartite motif-containing protein', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=49028823, end_position_on_the_genomic_accession=49038155, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    283129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283129, CurrentID=0, Status='live', Symbol='MAJIN', Aliases=['C11orf85'], description='membrane anchored junction protein', other_designations='membrane-anchored junction protein', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64938230, end_position_on_the_genomic_accession=64972108, orientation='minus', exon_count=12, OMIM=[617130], no_hdr0=''),
    283130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283130, CurrentID=0, Status='live', Symbol='SLC25A45', Aliases=[], description='solute carrier family 25 member 45', other_designations='solute carrier family 25 member 45', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65375192, end_position_on_the_genomic_accession=65383701, orientation='minus', exon_count=11, OMIM=[610825], no_hdr0=''),
    283149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283149, CurrentID=0, Status='live', Symbol='BCL9L', Aliases=['B9L', 'BCL9-2', 'DLNB11'], description='BCL9 like', other_designations='B-cell CLL/lymphoma 9-like protein|B cell CLL/lymphoma 9 like|B-cell lymphoma 9-like protein|BCL9-like protein|nuclear co-factor of beta-catenin signalling|protein BCL9-2', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118896136, end_position_on_the_genomic_accession=118926071, orientation='minus', exon_count=13, OMIM=[609004], no_hdr0=''),
    283150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283150, CurrentID=0, Status='live', Symbol='FOXR1', Aliases=['DLNB13', 'FOXN5'], description='forkhead box R1', other_designations='forkhead box protein R1|forkhead box R1 variant 1|forkhead box R1 variant 2|forkhead box protein N5', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118971398, end_position_on_the_genomic_accession=118981601, orientation='plus', exon_count=6, OMIM=[615755], no_hdr0=''),
    283152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283152, CurrentID=0, Status='live', Symbol='CCDC153', Aliases=[], description='coiled-coil domain containing 153', other_designations='coiled-coil domain-containing protein 153', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=119190254, end_position_on_the_genomic_accession=119195841, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    283159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283159, CurrentID=0, Status='live', Symbol='OR8D1', Aliases=['JCG9', 'OR8D3', 'OST004', 'PDJ9J14'], description='olfactory receptor family 8 subfamily D member 1', other_designations='olfactory receptor 8D1|olfactory receptor 8D3|olfactory receptor OR11-301|olfactory receptor, family 8, subfamily D, member 3|olfactory receptor-like protein JCG9|olfactory-like receptor JCG9', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124302831, end_position_on_the_genomic_accession=124313949, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    283160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283160, CurrentID=0, Status='live', Symbol='OR8D2', Aliases=['JCG2'], description='olfactory receptor family 8 subfamily D member 2', other_designations='olfactory receptor 8D2|olfactory receptor OR11-303|olfactory receptor-like protein JCG2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124319262, end_position_on_the_genomic_accession=124320197, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283162, CurrentID=0, Status='live', Symbol='OR8B4', Aliases=['OR11-315P', 'OR8B4'], description='olfactory receptor family 8 subfamily B member 4', other_designations='olfactory receptor 8B4|olfactory receptor OR11-315|olfactory receptor, family 8, subfamily B, member 4 pseudogene', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124423942, end_position_on_the_genomic_accession=124424871, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283189, CurrentID=0, Status='live', Symbol='OR9G4', Aliases=['OR11-216'], description='olfactory receptor family 9 subfamily G member 4', other_designations='olfactory receptor 9G4|olfactory receptor OR11-216', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56741223, end_position_on_the_genomic_accession=56748697, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    283208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283208, CurrentID=0, Status='live', Symbol='P4HA3', Aliases=[], description='prolyl 4-hydroxylase subunit alpha 3', other_designations='prolyl 4-hydroxylase subunit alpha-3|4-PH alpha-3|C-P4H alpha III|collagen prolyl 4-hydroxylase alpha(III)|procollagen-proline, 2-oxoglutarate 4-dioxygenase (proline 4-hydroxylase), alpha polypeptide III|prolyl 4-hydroxylase, alpha polypeptide III', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74259923, end_position_on_the_genomic_accession=74311654, orientation='minus', exon_count=15, OMIM=[608987], no_hdr0=''),
    283209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283209, CurrentID=0, Status='live', Symbol='PGM2L1', Aliases=['BM32A', 'PMMLP'], description='phosphoglucomutase 2 like 1', other_designations='glucose 1,6-bisphosphate synthase', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74330316, end_position_on_the_genomic_accession=74398751, orientation='minus', exon_count=15, OMIM=[611610], no_hdr0=''),
    283212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283212, CurrentID=0, Status='live', Symbol='KLHL35', Aliases=[], description='kelch like family member 35', other_designations='kelch-like protein 35|kelch-like 35', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75422394, end_position_on_the_genomic_accession=75433203, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    283219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283219, CurrentID=0, Status='live', Symbol='KCTD21', Aliases=['KCASH2'], description='potassium channel tetramerization domain containing 21', other_designations='BTB/POZ domain-containing protein KCTD21|potassium channel tetramerisation domain containing 21|potassium channel tetramerization domain-containing protein 21', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78171243, end_position_on_the_genomic_accession=78188626, orientation='minus', exon_count=5, OMIM=[618790], no_hdr0=''),
    283229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283229, CurrentID=0, Status='live', Symbol='CRACR2B', Aliases=['EFCAB4A'], description='calcium release activated channel regulator 2B', other_designations='EF-hand calcium-binding domain-containing protein 4A|CRAC channel regulator 2B|CRAC regulator 2B|Ca2+ release-activated Ca2+ (CRAC) channel regulator 2B|EF-hand calcium binding domain 4A|calcium release-activated calcium channel regulator 2B', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=825558, end_position_on_the_genomic_accession=831991, orientation='plus', exon_count=11, OMIM=[614177], no_hdr0=''),
    283232 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283232, CurrentID=0, Status='live', Symbol='TMEM80', Aliases=[], description='transmembrane protein 80', other_designations='transmembrane protein 80', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=695585, end_position_on_the_genomic_accession=705028, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    283234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283234, CurrentID=0, Status='live', Symbol='CCDC88B', Aliases=['BRLZ', 'CCDC88', 'HKRP3', 'gipie'], description='coiled-coil domain containing 88B', other_designations='coiled-coil domain-containing protein 88B|78 kDa glucose-regulated protein [GRP78]-interacting protein induced by ER stress|GRP78-interacting protein induced by ER stress|brain leucine zipper domain-containing protein|brain leucine zipper protein|coiled-coil domain containing 88|hook-related protein 3', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64340203, end_position_on_the_genomic_accession=64357534, orientation='plus', exon_count=29, OMIM=[611205], no_hdr0=''),
    283237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283237, CurrentID=0, Status='live', Symbol='TTC9C', Aliases=[], description='tetratricopeptide repeat domain 9C', other_designations='tetratricopeptide repeat protein 9C|TPR repeat protein 9C', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62728117, end_position_on_the_genomic_accession=62738636, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    283238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283238, CurrentID=0, Status='live', Symbol='SLC22A24', Aliases=['NET46'], description='solute carrier family 22 member 24', other_designations='steroid transmembrane transporter SLC22A24', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63079940, end_position_on_the_genomic_accession=63144221, orientation='minus', exon_count=10, OMIM=[611698], no_hdr0=''),
    283248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283248, CurrentID=0, Status='live', Symbol='RCOR2', Aliases=[], description='REST corepressor 2', other_designations='REST corepressor 2', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63911230, end_position_on_the_genomic_accession=63917164, orientation='minus', exon_count=12, OMIM=[616019], no_hdr0=''),
    283254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283254, CurrentID=0, Status='live', Symbol='HARBI1', Aliases=['C11orf77'], description='harbinger transposase derived 1', other_designations='putative nuclease HARBI1|harbinger transposase-derived nuclease', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=46602861, end_position_on_the_genomic_accession=46617894, orientation='minus', exon_count=8, OMIM=[615086], no_hdr0=''),
    283284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283284, CurrentID=0, Status='live', Symbol='IGSF22', Aliases=['IGFN2'], description='immunoglobulin superfamily member 22', other_designations='immunoglobulin superfamily member 22', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18704311, end_position_on_the_genomic_accession=18726939, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    283297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283297, CurrentID=0, Status='live', Symbol='OR10A4', Aliases=['JCG5P', 'OR10A4'], description='olfactory receptor family 10 subfamily A member 4', other_designations='olfactory receptor 10A4|hP2 olfactory receptor|olfactory receptor OR11-87|olfactory receptor, family 10, subfamily A, member 4 pseudogene|olfactory receptor-like protein JCG5', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6876625, end_position_on_the_genomic_accession=6877619, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    283298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283298, CurrentID=0, Status='live', Symbol='OLFML1', Aliases=['MVAL564', 'UNQ564'], description='olfactomedin like 1', other_designations='olfactomedin-like protein 1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7485506, end_position_on_the_genomic_accession=7511377, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    283310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283310, CurrentID=0, Status='live', Symbol='OTOGL', Aliases=['C12orf64', 'DFNB84B'], description='otogelin like', other_designations='otogelin-like protein', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80099537, end_position_on_the_genomic_accession=80380880, orientation='plus', exon_count=68, OMIM=[614925], no_hdr0=''),
    283316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283316, CurrentID=0, Status='live', Symbol='CD163L1', Aliases=['CD163B', 'M160', 'SCARI2', 'WC1'], description='CD163 molecule like 1', other_designations='scavenger receptor cysteine-rich type 1 protein M160|CD163 antigen B|CD163 antigen-like 1', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7320510, end_position_on_the_genomic_accession=7444153, orientation='minus', exon_count=27, OMIM=[606079], no_hdr0=''),
    283337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283337, CurrentID=0, Status='live', Symbol='ZNF740', Aliases=['Zfp740'], description='zinc finger protein 740', other_designations='zinc finger protein 740|oriLyt TD-element-binding protein 7', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53180715, end_position_on_the_genomic_accession=53195142, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    283349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283349, CurrentID=0, Status='live', Symbol='RASSF3', Aliases=['RASSF5'], description='Ras association domain family member 3', other_designations='ras association domain-containing protein 3|Ras association (RalGDS/AF-6) domain family 3|Ras association (RalGDS/AF-6) domain family member 3', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=64610495, end_position_on_the_genomic_accession=64697567, orientation='plus', exon_count=8, OMIM=[607019], no_hdr0=''),
    283358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283358, CurrentID=0, Status='live', Symbol='B4GALNT3', Aliases=[], description='beta-1,4-N-acetyl-galactosaminyltransferase 3', other_designations='beta-1,4-N-acetylgalactosaminyltransferase 3|B4GalNAcT3|Beta4GalNAc-T3|N-acetyl-beta-glucosaminyl-glycoprotein 4-beta-N- acetylgalactosaminyltransferase|N-acetyl-beta-glucosaminyl-glycoprotein 4-beta-N-acetylgalactosaminyltransferase 2|NGalNAc-T2|beta-1,4-N-acetyl-galactosaminyl transferase 3|beta-1,4-N-acetylgalactosaminyltransferase III|beta4GalNAcT3', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=459939, end_position_on_the_genomic_accession=563509, orientation='plus', exon_count=20, OMIM=[612220], no_hdr0=''),
    283365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283365, CurrentID=0, Status='live', Symbol='OR6C6', Aliases=[], description='olfactory receptor family 6 subfamily C member 6', other_designations='olfactory receptor 6C6', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55293988, end_position_on_the_genomic_accession=55296569, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    283373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283373, CurrentID=0, Status='live', Symbol='ANKRD52', Aliases=['ANKRD33'], description='ankyrin repeat domain 52', other_designations='serine/threonine-protein phosphatase 6 regulatory ankyrin repeat subunit C|CVWG5837|PP6-ARS-C|ankyrin repeat domain 33|ankyrin repeat domain-containing protein 52|protein phosphatase 6 ankyrin repeat subunit C|serine/threonine-protein phosphatase 6 regulatory subunit ARS-C', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56237807, end_position_on_the_genomic_accession=56258391, orientation='minus', exon_count=29, OMIM=[], no_hdr0=''),
    283375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283375, CurrentID=0, Status='live', Symbol='SLC39A5', Aliases=['LZT-Hs7', 'MYP24', 'ZIP5'], description='solute carrier family 39 member 5', other_designations='zinc transporter ZIP5|solute carrier family 39 (metal ion transporter), member 5|solute carrier family 39 (zinc transporter), member 5|zrt- and Irt-like protein 5', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56230036, end_position_on_the_genomic_accession=56237850, orientation='plus', exon_count=13, OMIM=[608730], no_hdr0=''),
    283377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283377, CurrentID=0, Status='live', Symbol='SPRYD4', Aliases=[], description='SPRY domain containing 4', other_designations='SPRY domain-containing protein 4', map_location='12q13.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=56468578, end_position_on_the_genomic_accession=56479708, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    283383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283383, CurrentID=0, Status='live', Symbol='ADGRD1', Aliases=['GPR133', 'PGR25'], description='adhesion G protein-coupled receptor D1', other_designations='adhesion G-protein coupled receptor D1|G-protein coupled receptor 133|G-protein coupled receptor PGR25|probable G-protein coupled receptor 133', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=130953907, end_position_on_the_genomic_accession=131141469, orientation='plus', exon_count=30, OMIM=[613639], no_hdr0=''),
    283385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283385, CurrentID=0, Status='live', Symbol='MORN3', Aliases=[], description='MORN repeat containing 3', other_designations='MORN repeat-containing protein 3|membrane occupation and recognition nexus repeat containing protein', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=121648742, end_position_on_the_genomic_accession=121672650, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    283417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283417, CurrentID=0, Status='live', Symbol='DPY19L2', Aliases=['SPATA34', 'SPGF9'], description='dpy-19 like 2', other_designations='probable C-mannosyltransferase DPY19L2|protein dpy-19 homolog 2|spermatogenesis associated 34', map_location='12q14.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=63558913, end_position_on_the_genomic_accession=63669201, orientation='minus', exon_count=31, OMIM=[613893], no_hdr0=''),
    283420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283420, CurrentID=0, Status='live', Symbol='CLEC9A', Aliases=['CD370', 'DNGR-1', 'DNGR1', 'UNQ9341'], description='C-type lectin domain containing 9A', other_designations='C-type lectin domain family 9 member A|HEEE9341', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10030682, end_position_on_the_genomic_accession=10066031, orientation='plus', exon_count=9, OMIM=[612252], no_hdr0=''),
    283431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283431, CurrentID=0, Status='live', Symbol='GAS2L3', Aliases=['G2L3'], description='growth arrest specific 2 like 3', other_designations='GAS2-like protein 3|growth arrest-specific protein 2-like 3', map_location='12q23.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=100573668, end_position_on_the_genomic_accession=100628288, orientation='plus', exon_count=14, OMIM=[617224], no_hdr0=''),
    283446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283446, CurrentID=0, Status='live', Symbol='MYO1H', Aliases=[], description='myosin IH', other_designations='unconventional myosin-Ih|myosin-1H|myosin-Ih', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109388277, end_position_on_the_genomic_accession=109448371, orientation='plus', exon_count=32, OMIM=[614636], no_hdr0=''),
    283450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283450, CurrentID=0, Status='live', Symbol='HECTD4', Aliases=['C12ord51', 'C12orf51', 'HEEL', 'POTAGE'], description='HECT domain E3 ubiquitin protein ligase 4', other_designations='probable E3 ubiquitin-protein ligase HECTD4|AF-1 specific protein phosphatase|HECT domain containing E3 ubiquitin protein ligase 4|HECT domain-containing protein 4|HECT-type E3 ubiquitin transferase HECTD4|probable E3 ubiquitin-protein ligase C12orf51|transmembrane protein C12orf51', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=112160195, end_position_on_the_genomic_accession=112382431, orientation='minus', exon_count=76, OMIM=[], no_hdr0=''),
    283455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283455, CurrentID=0, Status='live', Symbol='KSR2', Aliases=[], description='kinase suppressor of ras 2', other_designations='kinase suppressor of Ras 2', map_location='12q24.22-q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=117453012, end_position_on_the_genomic_accession=117968990, orientation='minus', exon_count=26, OMIM=[610737], no_hdr0=''),
    283459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283459, CurrentID=0, Status='live', Symbol='GATC', Aliases=['15E1.2', 'COXPD42'], description='glutamyl-tRNA amidotransferase subunit C', other_designations='glutamyl-tRNA(Gln) amidotransferase subunit C, mitochondrial|glu-AdT subunit C|glutamyl-tRNA(Gln) amidotransferase, subunit C homolog', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=120446444, end_position_on_the_genomic_accession=120463749, orientation='plus', exon_count=5, OMIM=[617210], no_hdr0=''),
    283461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283461, CurrentID=0, Status='live', Symbol='C12orf40', Aliases=['HEL-206', 'HEL-S-94'], description='chromosome 12 open reading frame 40', other_designations='uncharacterized protein C12orf40|epididymis luminal protein 206|epididymis secretory protein Li 94', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=39626183, end_position_on_the_genomic_accession=39908300, orientation='plus', exon_count=22, OMIM=[], no_hdr0=''),
    283463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283463, CurrentID=0, Status='live', Symbol='MUC19', Aliases=['MUC-19'], description='mucin 19, oligomeric', other_designations='mucin-19', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=40393394, end_position_on_the_genomic_accession=40570757, orientation='plus', exon_count=171, OMIM=[612170], no_hdr0=''),
    283464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283464, CurrentID=0, Status='live', Symbol='GXYLT1', Aliases=['GLT8D3'], description='glucoside xylosyltransferase 1', other_designations='glucoside xylosyltransferase 1|glycosyltransferase 8 domain containing 3|glycosyltransferase 8 domain-containing protein 3', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=42081845, end_position_on_the_genomic_accession=42144874, orientation='minus', exon_count=9, OMIM=[613321], no_hdr0=''),
    283471 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283471, CurrentID=0, Status='live', Symbol='TMPRSS12', Aliases=['CT151'], description='transmembrane serine protease 12', other_designations='transmembrane protease serine 12|testicular tissue protein Li 208|transmembrane (C-terminal) protease, serine 12|transmembrane protease, serine 12', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50842926, end_position_on_the_genomic_accession=50887884, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    283489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283489, CurrentID=0, Status='live', Symbol='CHAMP1', Aliases=['C13orf8', 'CAMP', 'CHAMP', 'MRD40', 'ZNF828'], description='chromosome alignment maintaining phosphoprotein 1', other_designations='chromosome alignment-maintaining phosphoprotein 1|zinc finger protein 828', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=114314503, end_position_on_the_genomic_accession=114327322, orientation='plus', exon_count=3, OMIM=[616327], no_hdr0=''),
    283514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283514, CurrentID=0, Status='live', Symbol='SIAH3', Aliases=[], description='siah E3 ubiquitin protein ligase family member 3', other_designations='seven in absentia homolog 3|siah-3', map_location='13q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45777242, end_position_on_the_genomic_accession=45851753, orientation='minus', exon_count=2, OMIM=[615609], no_hdr0=''),
    283518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283518, CurrentID=0, Status='live', Symbol='KCNRG', Aliases=['DLTET'], description='potassium channel regulator', other_designations='potassium channel regulatory protein|putative potassium channel regulatory protein', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=50015444, end_position_on_the_genomic_accession=50020922, orientation='plus', exon_count=3, OMIM=[607947], no_hdr0=''),
    283521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283521, CurrentID=0, Status='live', Symbol='TMEM272', Aliases=['LINC00282', 'NCRNA00282'], description='transmembrane protein 272', other_designations='transmembrane protein 272|long intergenic non-protein coding RNA 282', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51813347, end_position_on_the_genomic_accession=51845177, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    283537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283537, CurrentID=0, Status='live', Symbol='SLC46A3', Aliases=['FKSG16'], description='solute carrier family 46 member 3', other_designations='solute carrier family 46 member 3', map_location='13q12.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=28700080, end_position_on_the_genomic_accession=28718970, orientation='minus', exon_count=6, OMIM=[616764], no_hdr0=''),
    283554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283554, CurrentID=0, Status='live', Symbol='GPR137C', Aliases=['TM7SF1L2'], description='G protein-coupled receptor 137C', other_designations='integral membrane protein GPR137C|G protein-coupled receptor TM7SF1L2|transmembrane 7 superfamily member 1-like 2 protein', map_location='14q22.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=52552836, end_position_on_the_genomic_accession=52637713, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    283571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283571, CurrentID=0, Status='live', Symbol='PROX2', Aliases=['PROX-2'], description='prospero homeobox 2', other_designations='prospero homeobox protein 2|homeobox prospero-like protein PROX2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74853033, end_position_on_the_genomic_accession=74876663, orientation='minus', exon_count=8, OMIM=[615094], no_hdr0=''),
    283576 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283576, CurrentID=0, Status='live', Symbol='ZDHHC22', Aliases=['C14orf59'], description='zinc finger DHHC-type palmitoyltransferase 22', other_designations='palmitoyltransferase ZDHHC22|DHHC-22|putative palmitoyltransferase ZDHHC22|zinc finger DHHC domain-containing protein 22|zinc finger DHHC-type containing 22|zinc finger, DHHC domain containing 22', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77131270, end_position_on_the_genomic_accession=77146265, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    283578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283578, CurrentID=0, Status='live', Symbol='TMED8', Aliases=['FAM15B'], description='transmembrane p24 trafficking protein family member 8', other_designations='protein TMED8|family with sequence similarity 15, member B|transmembrane emp24 domain containing 8|transmembrane emp24 protein transport domain containing 8', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77335021, end_position_on_the_genomic_accession=77377094, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    283600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283600, CurrentID=0, Status='live', Symbol='SLC25A47', Aliases=['C14orf68', 'HDCMP', 'HDMCP', 'HMFN1655'], description='solute carrier family 25 member 47', other_designations='solute carrier family 25 member 47|HCC-down-regulated mitochondrial carrier protein|hepatocellular carcinoma down-regulated mitochondrial carrier protein|hepatocellular carcinoma-downregulated mitochondrial carrier protein', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100323339, end_position_on_the_genomic_accession=100330421, orientation='plus', exon_count=6, OMIM=[609911], no_hdr0=''),
    283617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283617, CurrentID=0, Status='live', Symbol='OR4K3', Aliases=['OR14-10P', 'OR4K3'], description='olfactory receptor family 4 subfamily K member 3 (gene/pseudogene)', other_designations='olfactory receptor 4K3|olfactory receptor OR14-14|olfactory receptor, family 4, subfamily K, member 3 pseudogene', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19868197, end_position_on_the_genomic_accession=19869173, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    283629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283629, CurrentID=0, Status='live', Symbol='TSSK4', Aliases=['C14orf20', 'STK22E', 'TSK-4', 'TSK4', 'TSSK5'], description='testis specific serine kinase 4', other_designations='testis-specific serine/threonine-protein kinase 4|serine/threonine kinase 22E|serine/threonine-protein kinase 22E', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24205524, end_position_on_the_genomic_accession=24208362, orientation='plus', exon_count=4, OMIM=[610711], no_hdr0=''),
    283635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283635, CurrentID=0, Status='live', Symbol='FAM177A1', Aliases=['C14orf24'], description='family with sequence similarity 177 member A1', other_designations='protein FAM177A1', map_location='14q13.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=35044907, end_position_on_the_genomic_accession=35083383, orientation='plus', exon_count=8, OMIM=[619181], no_hdr0=''),
    283638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283638, CurrentID=0, Status='live', Symbol='CEP170B', Aliases=['CEP170R', 'FAM68C', 'KIAA0284'], description='centrosomal protein 170B', other_designations='centrosomal protein of 170 kDa protein B|Cep170-related', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104865268, end_position_on_the_genomic_accession=104896757, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    283643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283643, CurrentID=0, Status='live', Symbol='TEDC1', Aliases=['C14orf80'], description='tubulin epsilon and delta complex 1', other_designations='tubulin epsilon and delta complex protein 1|uncharacterized protein C14orf80', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105489855, end_position_on_the_genomic_accession=105499248, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    283652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283652, CurrentID=0, Status='live', Symbol='SLC24A5', Aliases=['JSX', 'NCKX5', 'OCA6', 'SHEP4'], description='solute carrier family 24 member 5', other_designations='sodium/potassium/calcium exchanger 5|Na(+)/K(+)/Ca(2+)-exchange protein 5|ion transporter JSX|oculocutaneous albinism 6 (autosomal recessive)|solute carrier family 24 (sodium/potassium/calcium exchanger), member 5', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48120990, end_position_on_the_genomic_accession=48142672, orientation='plus', exon_count=11, OMIM=[609802], no_hdr0=''),
    283659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283659, CurrentID=0, Status='live', Symbol='PRTG', Aliases=['IGDCC5'], description='protogenin', other_designations='protogenin|immunoglobulin superfamily, DCC subclass, member 5|protogenin homolog (Gallus gallus)|shen-dan', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55611540, end_position_on_the_genomic_accession=55743152, orientation='minus', exon_count=23, OMIM=[613261], no_hdr0=''),
    283677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283677, CurrentID=0, Status='live', Symbol='REC114', Aliases=['C15orf60', 'CT147', 'OOMD10'], description='REC114 meiotic recombination protein', other_designations='meiotic recombination protein REC114|meiotic recombination protein REC114-like', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73443164, end_position_on_the_genomic_accession=73560013, orientation='plus', exon_count=6, OMIM=[618421], no_hdr0=''),
    283685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283685, CurrentID=0, Status='live', Symbol='GOLGA6L2', Aliases=['CT105'], description='golgin A6 family like 2', other_designations='golgin subfamily A member 6-like protein 2|cancer/testis antigen 105|golgi autoantigen, golgin subfamily a, 6-like 2', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23439038, end_position_on_the_genomic_accession=23447243, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    283694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283694, CurrentID=0, Status='live', Symbol='OR4N4', Aliases=['OR15-1', 'OR15-5'], description='olfactory receptor family 4 subfamily N member 4', other_designations='olfactory receptor 4N4|olfactory receptor OR15-1|olfactory receptor OR15-5', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22094522, end_position_on_the_genomic_accession=22095862, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    283726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283726, CurrentID=0, Status='live', Symbol='SAXO2', Aliases=['FAM154B'], description='stabilizer of axonemal microtubules 2', other_designations='stabilizer of axonemal microtubules 2|family with sequence similarity 154, member B|protein FAM154B', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82262818, end_position_on_the_genomic_accession=82284930, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    283742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283742, CurrentID=0, Status='live', Symbol='FAM98B', Aliases=[], description='family with sequence similarity 98 member B', other_designations='protein FAM98B', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=38454127, end_position_on_the_genomic_accession=38487710, orientation='plus', exon_count=8, OMIM=[616142], no_hdr0=''),
    283748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283748, CurrentID=0, Status='live', Symbol='PLA2G4D', Aliases=['cPLA2delta'], description='phospholipase A2 group IVD', other_designations='cytosolic phospholipase A2 delta|cPLA2-delta|phospholipase A2 delta, cytosolic|phospholipase A2, group IVD (cytosolic)', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=42067009, end_position_on_the_genomic_accession=42094562, orientation='minus', exon_count=21, OMIM=[612864], no_hdr0=''),
    283767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283767, CurrentID=0, Status='live', Symbol='GOLGA6L1', Aliases=[], description='golgin A6 family like 1', other_designations='golgin subfamily A member 6-like protein 1|golgi autoantigen, golgin subfamily a, 6-like 1', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23127066, end_position_on_the_genomic_accession=23136822, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    283768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283768, CurrentID=0, Status='live', Symbol='GOLGA8G', Aliases=['GOLGA8F'], description='golgin A8 family member G', other_designations='putative golgin subfamily A member 8F/8G|golgi autoantigen, golgin subfamily a, 8G', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28519611, end_position_on_the_genomic_accession=28533014, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    283807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283807, CurrentID=0, Status='live', Symbol='FBXL22', Aliases=['Fbl22'], description='F-box and leucine rich repeat protein 22', other_designations='F-box and leucine-rich protein 22|F-box/LRR-repeat protein 22', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=63597387, end_position_on_the_genomic_accession=63603432, orientation='plus', exon_count=2, OMIM=[609088], no_hdr0=''),
    283820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283820, CurrentID=0, Status='live', Symbol='NOMO2', Aliases=['Nomo', 'PM5'], description='NODAL modulator 2', other_designations='nodal modulator 2|pM5 protein 2|pM5 protein, centromeric copy', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18499927, end_position_on_the_genomic_accession=18562143, orientation='minus', exon_count=33, OMIM=[609158], no_hdr0=''),
    283847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283847, CurrentID=0, Status='live', Symbol='TERB1', Aliases=['CCDC79'], description='telomere repeat binding bouquet formation protein 1', other_designations='telomere repeats-binding bouquet formation protein 1|coiled-coil domain-containing protein 79', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66754410, end_position_on_the_genomic_accession=66801611, orientation='minus', exon_count=22, OMIM=[617332], no_hdr0=''),
    283848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283848, CurrentID=0, Status='live', Symbol='CES4A', Aliases=['CES6', 'CES8'], description='carboxylesterase 4A', other_designations='carboxylesterase 4A|carboxylesterase 6|carboxylesterase 8 (putative)', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66988589, end_position_on_the_genomic_accession=67010417, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    283849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283849, CurrentID=0, Status='live', Symbol='EXOC3L1', Aliases=['EXOC3L'], description='exocyst complex component 3 like 1', other_designations='exocyst complex component 3-like protein|protein Jiangli', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67184379, end_position_on_the_genomic_accession=67190136, orientation='minus', exon_count=14, OMIM=[614117], no_hdr0=''),
    283869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283869, CurrentID=0, Status='live', Symbol='NPW', Aliases=['L8', 'L8C', 'PPL8', 'PPNPW'], description='neuropeptide W', other_designations='neuropeptide W|hPPL8|prepro-neuropeptide W|preproprotein L8', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2019785, end_position_on_the_genomic_accession=2020755, orientation='plus', exon_count=2, OMIM=[607997], no_hdr0=''),
    283870 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283870, CurrentID=0, Status='live', Symbol='BRICD5', Aliases=['C16orf79'], description='BRICHOS domain containing 5', other_designations='BRICHOS domain-containing protein 5|BRICHOS domain-containing protein C16orf79', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2209253, end_position_on_the_genomic_accession=2210863, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    283871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283871, CurrentID=0, Status='live', Symbol='PGP', Aliases=['AUM', 'G3PPase', 'PGP'], description='phosphoglycolate phosphatase', other_designations='glycerol-3-phosphate phosphatase|aspartate-based ubiquitous Mg(2+)-dependent phosphatase', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2211593, end_position_on_the_genomic_accession=2214840, orientation='minus', exon_count=2, OMIM=[172280], no_hdr0=''),
    283897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283897, CurrentID=0, Status='live', Symbol='C16orf54', Aliases=[], description='chromosome 16 open reading frame 54', other_designations='transmembrane protein C16orf54', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29742463, end_position_on_the_genomic_accession=29745990, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    283899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283899, CurrentID=0, Status='live', Symbol='INO80E', Aliases=['CCDC95'], description='INO80 complex subunit E', other_designations='INO80 complex subunit E|coiled-coil domain containing 95|coiled-coil domain-containing protein 95', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29995690, end_position_on_the_genomic_accession=30005791, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    283927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283927, CurrentID=0, Status='live', Symbol='NUDT7', Aliases=[], description='nudix hydrolase 7', other_designations='peroxisomal coenzyme A diphosphatase NUDT7|nudix (nucleoside diphosphate linked moiety X)-type motif 7', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77722514, end_position_on_the_genomic_accession=77742260, orientation='plus', exon_count=6, OMIM=[609231], no_hdr0=''),
    283933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283933, CurrentID=0, Status='live', Symbol='ZNF843', Aliases=[], description='zinc finger protein 843', other_designations='zinc finger protein 843', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31435434, end_position_on_the_genomic_accession=31443160, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    283948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283948, CurrentID=0, Status='live', Symbol='NHLRC4', Aliases=[], description='NHL repeat containing 4', other_designations='NHL-repeat-containing protein 4', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=567005, end_position_on_the_genomic_accession=569495, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    283951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283951, CurrentID=0, Status='live', Symbol='C16orf91', Aliases=['CCSMST1', 'URLC5', 'gs103'], description='chromosome 16 open reading frame 91', other_designations='protein CCSMST1|cattle cerebrum and skeletal muscle-specific protein 1 family member|up-regulated in lung cancer 5', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1419752, end_position_on_the_genomic_accession=1420747, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    283953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283953, CurrentID=0, Status='live', Symbol='TMEM114', Aliases=[], description='transmembrane protein 114', other_designations='transmembrane protein 114', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8526552, end_position_on_the_genomic_accession=8590511, orientation='minus', exon_count=8, OMIM=[611579], no_hdr0=''),
    283971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283971, CurrentID=0, Status='live', Symbol='CLEC18C', Aliases=['MRCL', 'MRCL3'], description='C-type lectin domain family 18 member C', other_designations='C-type lectin domain family 18 member C|mannose receptor-like 3|mannose receptor-like protein 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=70173322, end_position_on_the_genomic_accession=70187147, orientation='plus', exon_count=15, OMIM=[616573], no_hdr0=''),
    283985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283985, CurrentID=0, Status='live', Symbol='FADS6', Aliases=['FP18279'], description='fatty acid desaturase 6', other_designations='fatty acid desaturase 6|fatty acid desaturase domain family, member 6', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74877302, end_position_on_the_genomic_accession=74893803, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    283987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283987, CurrentID=0, Status='live', Symbol='HID1', Aliases=['17orf28', 'C17orf28', 'DMC1', 'HID-1'], description='HID1 domain containing', other_designations='protein HID1|HID1 domain-containing protein|UPF0663 transmembrane protein C17orf28|down-regulated in multiple cancers 1|downregulated in multiple cancer 1|protein hid-1 homolog', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74950742, end_position_on_the_genomic_accession=74972763, orientation='minus', exon_count=19, OMIM=[605752], no_hdr0=''),
    283989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283989, CurrentID=0, Status='live', Symbol='TSEN54', Aliases=['PCH2A', 'PCH4', 'PCH5', 'SEN54L', 'sen54'], description='tRNA splicing endonuclease subunit 54', other_designations='tRNA-splicing endonuclease subunit Sen54|SEN54 homolog|TSEN54 tRNA splicing endonuclease subunit|hsSen54|tRNA-intron endonuclease Sen54', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75516528, end_position_on_the_genomic_accession=75524735, orientation='plus', exon_count=11, OMIM=[608755], no_hdr0=''),
    283991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283991, CurrentID=0, Status='live', Symbol='UBALD2', Aliases=['FAM100B'], description='UBA like domain containing 2', other_designations='UBA-like domain-containing protein 2|family with sequence similarity 100, member B|protein FAM100B', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76265348, end_position_on_the_genomic_accession=76271298, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    283999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=283999, CurrentID=0, Status='live', Symbol='TMEM235', Aliases=['ARGM1'], description='transmembrane protein 235', other_designations='transmembrane protein 235|transmembrane protein ENSP00000364084', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78231293, end_position_on_the_genomic_accession=78242849, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    284001 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284001, CurrentID=0, Status='live', Symbol='CCDC57', Aliases=[], description='coiled-coil domain containing 57', other_designations='coiled-coil domain-containing protein 57', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82101458, end_position_on_the_genomic_accession=82212892, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    284004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284004, CurrentID=0, Status='live', Symbol='HEXD', Aliases=['HEXDC'], description='hexosaminidase D', other_designations='hexosaminidase D|N-acetyl-beta-galactosaminidase|beta-N-acetylhexosaminidase|beta-hexosaminidase D|hexosaminidase (glycosyl hydrolase family 20, catalytic domain) containing|hexosaminidase D, cytosolic|hexosaminidase domain-containing protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82418347, end_position_on_the_genomic_accession=82442645, orientation='plus', exon_count=16, OMIM=[616864], no_hdr0=''),
    284013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284013, CurrentID=0, Status='live', Symbol='VMO1', Aliases=['ERGA6350', 'PRO21055'], description='vitelline membrane outer layer 1 homolog', other_designations='vitelline membrane outer layer protein 1 homolog', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4785285, end_position_on_the_genomic_accession=4786364, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    284018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284018, CurrentID=0, Status='live', Symbol='C17orf58', Aliases=[], description='chromosome 17 open reading frame 58', other_designations='UPF0450 protein C17orf58', map_location='17q24.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=67991099, end_position_on_the_genomic_accession=67996469, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    284021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284021, CurrentID=0, Status='live', Symbol='MILR1', Aliases=['Allergin-1', 'C17orf60', 'MCA-32', 'MCA32'], description='mast cell immunoglobulin like receptor 1', other_designations='allergin-1|allergy inhibitory receptor 1|mast cell antigen 32|probable mast cell antigen 32 homolog', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64449006, end_position_on_the_genomic_accession=64496469, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    284023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284023, CurrentID=0, Status='live', Symbol='RNF227', Aliases=['LINC02581'], description='ring finger protein 227', other_designations='RING finger protein 227|long intergenic non-protein coding RNA 2581', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7913324, end_position_on_the_genomic_accession=7916318, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    284040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284040, CurrentID=0, Status='live', Symbol='CDRT4', Aliases=[], description='CMT1A duplicated region transcript 4', other_designations='CMT1A duplicated region transcript 4 protein', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15436015, end_position_on_the_genomic_accession=15467621, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    284058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284058, CurrentID=0, Status='live', Symbol='KANSL1', Aliases=['CENP-36', 'KDVS', 'KIAA1267', 'MSL1v1', 'NSL1', 'hMSL1v1'], description='KAT8 regulatory NSL complex subunit 1', other_designations='KAT8 regulatory NSL complex subunit 1|MLL1/MLL complex subunit KANSL1|MSL1 homolog 1|NSL complex protein NSL1|centromere protein 36|male-specific lethal 1 homolog|non-specific lethal 1 homolog', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46027335, end_position_on_the_genomic_accession=46225370, orientation='minus', exon_count=20, OMIM=[612452], no_hdr0=''),
    284067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284067, CurrentID=0, Status='live', Symbol='CFAP97D1', Aliases=['C17orf105'], description='CFAP97 domain containing 1', other_designations='sperm axonemal maintenance protein CFAP97D1|CFAP97 domain-containing protein 1|uncharacterized protein C17orf105', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43780435, end_position_on_the_genomic_accession=43787620, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    284069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284069, CurrentID=0, Status='live', Symbol='FAM171A2', Aliases=[], description='family with sequence similarity 171 member A2', other_designations='protein FAM171A2', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44353215, end_position_on_the_genomic_accession=44363853, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    284071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284071, CurrentID=0, Status='live', Symbol='MEIOC', Aliases=['C17orf104'], description='meiosis specific with coiled-coil domain', other_designations='meiosis-specific coiled-coil domain-containing protein MEIOC|meiosis-specific with coiled-coil domain protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44656417, end_position_on_the_genomic_accession=44677086, orientation='plus', exon_count=9, OMIM=[616934], no_hdr0=''),
    284076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284076, CurrentID=0, Status='live', Symbol='TTLL6', Aliases=['TTL.6'], description='tubulin tyrosine ligase like 6', other_designations='tubulin polyglutamylase TTLL6|tubulin tyrosine ligase-like family member 6|tubulin--tyrosine ligase-like protein 6', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48762234, end_position_on_the_genomic_accession=48817247, orientation='minus', exon_count=19, OMIM=[610849], no_hdr0=''),
    284086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284086, CurrentID=0, Status='live', Symbol='NEK8', Aliases=['JCK', 'NEK12A', 'NPHP9', 'RHPD2'], description='NIMA related kinase 8', other_designations='serine/threonine-protein kinase Nek8|NIMA (never in mitosis gene a)- related kinase 8|NIMA-family kinase NEK8|NIMA-related kinase 12a|nephrocystin 9|never in mitosis A-related kinase 8|nimA-related protein kinase 8|nima-related protein kinase 12a|serine/thrionine-protein kinase NEK8', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28728788, end_position_on_the_genomic_accession=28743455, orientation='plus', exon_count=15, OMIM=[609799], no_hdr0=''),
    284098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284098, CurrentID=0, Status='live', Symbol='PIGW', Aliases=['Gwt1', 'HPMRS5'], description='phosphatidylinositol glycan anchor biosynthesis class W', other_designations='phosphatidylinositol-glycan biosynthesis class W protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36534987, end_position_on_the_genomic_accession=36539303, orientation='plus', exon_count=2, OMIM=[610275], no_hdr0=''),
    284099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284099, CurrentID=0, Status='live', Symbol='C17orf78', Aliases=[], description='chromosome 17 open reading frame 78', other_designations='uncharacterized protein C17orf78', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37375332, end_position_on_the_genomic_accession=37392708, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    284106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284106, CurrentID=0, Status='live', Symbol='CISD3', Aliases=['MiNT', 'Miner2'], description='CDGSH iron sulfur domain 3', other_designations='CDGSH iron-sulfur domain-containing protein 3, mitochondrial|mitoNEET related 2|mitoNEET-related protein 2|mitochondrial inner NEET protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38730341, end_position_on_the_genomic_accession=38735605, orientation='plus', exon_count=4, OMIM=[611933], no_hdr0=''),
    284110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284110, CurrentID=0, Status='live', Symbol='GSDMA', Aliases=['FKSG9', 'GSDM', 'GSDM1'], description='gasdermin A', other_designations='gasdermin-A|gasdermin-1', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39962973, end_position_on_the_genomic_accession=39977768, orientation='plus', exon_count=14, OMIM=[611218], no_hdr0=''),
    284111 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284111, CurrentID=0, Status='live', Symbol='SLC13A5', Aliases=['DEE25', 'EIEE25', 'INDY', 'NACT', 'mIndy'], description='solute carrier family 13 member 5', other_designations='solute carrier family 13 member 5|Na(+)/citrate cotransporter|Na+-coupled citrate transporter protein|sodium-dependent dicarboxylate transporter|solute carrier family 13 (sodium-dependent citrate transporter), member 5', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6684719, end_position_on_the_genomic_accession=6713400, orientation='minus', exon_count=12, OMIM=[608305], no_hdr0=''),
    284114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284114, CurrentID=0, Status='live', Symbol='TMEM102', Aliases=['CBAP'], description='transmembrane protein 102', other_designations='transmembrane protein 102|common beta-chain associated protein', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7435435, end_position_on_the_genomic_accession=7437679, orientation='plus', exon_count=3, OMIM=[613936], no_hdr0=''),
    284119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284119, CurrentID=0, Status='live', Symbol='CAVIN1', Aliases=['CAVIN', 'CGL4', 'FKSG13', 'PTRF', 'cavin-1'], description='caveolae associated protein 1', other_designations='caveolae-associated protein 1|RNA polymerase I and transcript release factor|TTF-I interacting peptide 12|congenital generalized lipodystrophy 4|polymerase I and transcript release factor', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42402449, end_position_on_the_genomic_accession=42423269, orientation='minus', exon_count=3, OMIM=[603198], no_hdr0=''),
    284129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284129, CurrentID=0, Status='live', Symbol='SLC26A11', Aliases=[], description='solute carrier family 26 member 11', other_designations='sodium-independent sulfate anion transporter|solute carrier family 26 (anion exchanger), member 11', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80220287, end_position_on_the_genomic_accession=80253502, orientation='plus', exon_count=20, OMIM=[610117], no_hdr0=''),
    284131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284131, CurrentID=0, Status='live', Symbol='ENDOV', Aliases=[], description='endonuclease V', other_designations='endonuclease V|hEndoV|inosine-specific endoribonuclease', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80415117, end_position_on_the_genomic_accession=80438086, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    284161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284161, CurrentID=0, Status='live', Symbol='GDPD1', Aliases=['GDE4'], description='glycerophosphodiester phosphodiesterase domain containing 1', other_designations='lysophospholipase D GDPD1|glycerophosphodiester phosphodiesterase 4|glycerophosphodiester phosphodiesterase domain-containing protein 1', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59220470, end_position_on_the_genomic_accession=59275970, orientation='plus', exon_count=12, OMIM=[616317], no_hdr0=''),
    284184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284184, CurrentID=0, Status='live', Symbol='NDUFAF8', Aliases=['C17orf89', 'MC1DN34'], description='NADH:ubiquinone oxidoreductase complex assembly factor 8', other_designations='NADH dehydrogenase [ubiquinone] 1 alpha subcomplex assembly factor 8', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81239311, end_position_on_the_genomic_accession=81241310, orientation='plus', exon_count=4, OMIM=[618461], no_hdr0=''),
    284194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284194, CurrentID=0, Status='live', Symbol='LGALS9B', Aliases=[], description='galectin 9B', other_designations='galectin-9B|gal-9B|galectin-9 like|galectin-9 pseudogene|galectin-9-like protein A|lectin, galactoside-binding, soluble, 9B', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=20449395, end_position_on_the_genomic_accession=20467539, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    284207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284207, CurrentID=0, Status='live', Symbol='METRNL', Aliases=[], description='meteorin like, glial cell differentiation regulator', other_designations='meteorin-like protein|cometin|meteorin, glial cell differentiation regulator-like|subfatin', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=83079609, end_position_on_the_genomic_accession=83095122, orientation='plus', exon_count=7, OMIM=[616241], no_hdr0=''),
    284217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284217, CurrentID=0, Status='live', Symbol='LAMA1', Aliases=['LAMA', 'PTBHS', 'S-LAM-alpha'], description='laminin subunit alpha 1', other_designations='laminin subunit alpha-1|S-LAM alpha|S-laminin subunit alpha|laminin A chain|laminin, alpha 1|laminin-3 subunit alpha', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=6941742, end_position_on_the_genomic_accession=7117797, orientation='minus', exon_count=63, OMIM=[150320], no_hdr0=''),
    284252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284252, CurrentID=0, Status='live', Symbol='KCTD1', Aliases=['C18orf5'], description='potassium channel tetramerization domain containing 1', other_designations='BTB/POZ domain-containing protein KCTD1', map_location='18q11.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=26454910, end_position_on_the_genomic_accession=26657473, orientation='minus', exon_count=10, OMIM=[613420], no_hdr0=''),
    284254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284254, CurrentID=0, Status='live', Symbol='DYNAP', Aliases=['C18orf26'], description='dynactin associated protein', other_designations='dynactin-associated protein', map_location='18q21.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=54532713, end_position_on_the_genomic_accession=54599544, orientation='plus', exon_count=7, OMIM=[619421], no_hdr0=''),
    284257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284257, CurrentID=0, Status='live', Symbol='BOD1L2', Aliases=['BOD1P', 'FAM44C'], description='biorientation of chromosomes in cell division 1 like 2', other_designations='biorientation of chromosomes in cell division protein 1-like 2|biorientation of chromosomes in cell division 1 pseudogene|biorientation of chromosomes in cell division protein 1 pseudogene|family with sequence similarity 44, member C|putative biorientation of chromosomes in cell division protein 1 pseudogene|putative biorientation of chromosomes in cell division protein 1-like 2|putative protein FAM44C', map_location='18q21.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=57147087, end_position_on_the_genomic_accession=57150410, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    284266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284266, CurrentID=0, Status='live', Symbol='SIGLEC15', Aliases=['CD33L3', 'HsT1361', 'SIGLEC-15'], description='sialic acid binding Ig like lectin 15', other_designations='sialic acid-binding Ig-like lectin 15|CD33 antigen-like 3|CD33 molecule-like 3', map_location='18q12.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=45825675, end_position_on_the_genomic_accession=45844094, orientation='plus', exon_count=6, OMIM=[618105], no_hdr0=''),
    284273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284273, CurrentID=0, Status='live', Symbol='ZADH2', Aliases=['PRG-3'], description='zinc binding alcohol dehydrogenase domain containing 2', other_designations='prostaglandin reductase 3|zinc-binding alcohol dehydrogenase domain-containing protein 2', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=75195108, end_position_on_the_genomic_accession=75209506, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    284274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284274, CurrentID=0, Status='live', Symbol='SMIM21', Aliases=['C18orf62'], description='small integral membrane protein 21', other_designations='small integral membrane protein 21', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=75409476, end_position_on_the_genomic_accession=75455653, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    284293 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284293, CurrentID=0, Status='live', Symbol='HMSD', Aliases=['ACC-6', 'ACC6', 'C18orf53', 'HSMD-v'], description='histocompatibility minor serpin domain containing', other_designations='serpin-like protein HMSD|minor histocompatibility protein HMSD', map_location='18q22.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=63949259, end_position_on_the_genomic_accession=63969329, orientation='plus', exon_count=6, OMIM=[612086], no_hdr0=''),
    284297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284297, CurrentID=0, Status='live', Symbol='SSC5D', Aliases=['S5D-SRCRB'], description='scavenger receptor cysteine rich family member with 5 domains', other_designations='soluble scavenger receptor cysteine-rich domain-containing protein SSC5D|scavenger receptor cysteine rich domain containing (5 domains)|scavenger receptor cysteine rich family, 5 domains|scavenger receptor cysteine-rich glycoprotein|soluble scavenger protein with 5 SRCR domains|soluble scavenger with 5 domains', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55488436, end_position_on_the_genomic_accession=55519099, orientation='plus', exon_count=15, OMIM=[618194], no_hdr0=''),
    284306 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284306, CurrentID=0, Status='live', Symbol='ZNF547', Aliases=['MIP-2A', 'SEDLP1', 'TRAPPC2.19', 'TRAPPC2B', 'TRAPPC2P1'], description='zinc finger protein 547', other_designations='zinc finger protein 547|MBP-1-interacting protein 2A|Trafficking protein particle complex subunit 2B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57363551, end_position_on_the_genomic_accession=57379565, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    284307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284307, CurrentID=0, Status='live', Symbol='ZIK1', Aliases=['ZNF762'], description='zinc finger protein interacting with K protein 1', other_designations='zinc finger protein interacting with ribonucleoprotein K|zinc finger protein 762|zinc finger protein interacting with K protein 1 homolog', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57583642, end_position_on_the_genomic_accession=57593890, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    284309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284309, CurrentID=0, Status='live', Symbol='ZNF776', Aliases=[], description='zinc finger protein 776', other_designations='zinc finger protein 776', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57746815, end_position_on_the_genomic_accession=57758148, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    284312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284312, CurrentID=0, Status='live', Symbol='ZSCAN1', Aliases=['MZF-1', 'ZNF915'], description='zinc finger and SCAN domain containing 1', other_designations='zinc finger and SCAN domain-containing protein 1|zinc finger with SCAN domain 1', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58033989, end_position_on_the_genomic_accession=58058907, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    284323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284323, CurrentID=0, Status='live', Symbol='ZNF780A', Aliases=['ZNF780'], description='zinc finger protein 780A', other_designations='zinc finger protein 780A', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40069008, end_position_on_the_genomic_accession=40091706, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    284325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284325, CurrentID=0, Status='live', Symbol='C19orf54', Aliases=[], description='chromosome 19 open reading frame 54', other_designations='UPF0692 protein C19orf54', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=40740856, end_position_on_the_genomic_accession=40751372, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    284338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284338, CurrentID=0, Status='live', Symbol='PRR19', Aliases=[], description='proline rich 19', other_designations='proline-rich protein 19', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42302132, end_position_on_the_genomic_accession=42310821, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    284339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284339, CurrentID=0, Status='live', Symbol='TMEM145', Aliases=[], description='transmembrane protein 145', other_designations='transmembrane protein 145', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42313309, end_position_on_the_genomic_accession=42325064, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    284340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284340, CurrentID=0, Status='live', Symbol='CXCL17', Aliases=['DMC', 'Dcip1', 'UNQ473', 'VCC-1', 'VCC1'], description='C-X-C motif chemokine ligand 17', other_designations='C-X-C motif chemokine 17|6-Cys CXCL17|VEGF co-regulated chemokine 1|VEGF coregulated chemokine 1|chemokine (C-X-C motif) ligand 17|dendritic cell and monocyte chemokine-like protein', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42428278, end_position_on_the_genomic_accession=42442946, orientation='minus', exon_count=4, OMIM=[611387], no_hdr0=''),
    284346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284346, CurrentID=0, Status='live', Symbol='ZNF575', Aliases=[], description='zinc finger protein 575', other_designations='zinc finger protein 575', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43531574, end_position_on_the_genomic_accession=43536090, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    284348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284348, CurrentID=0, Status='live', Symbol='LYPD5', Aliases=['PRO4356'], description='LY6/PLAUR domain containing 5', other_designations='ly6/PLAUR domain-containing protein 5|metastasis-associated protein', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43795927, end_position_on_the_genomic_accession=43820634, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    284349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284349, CurrentID=0, Status='live', Symbol='ZNF283', Aliases=['HZF19', 'HZF41'], description='zinc finger protein 283', other_designations='zinc finger protein 283|zinc finger protein 41|zinc finger protein HZF19', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43827292, end_position_on_the_genomic_accession=43853286, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    284352 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284352, CurrentID=0, Status='live', Symbol='PPP1R37', Aliases=['LRRC68'], description='protein phosphatase 1 regulatory subunit 37', other_designations='protein phosphatase 1 regulatory subunit 37|leucine rich repeat containing 68|leucine-rich repeat-containing protein 68', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45093173, end_position_on_the_genomic_accession=45147286, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    284353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284353, CurrentID=0, Status='live', Symbol='NKPD1', Aliases=[], description='NTPase KAP family P-loop domain containing 1', other_designations='NTPase KAP family P-loop domain-containing protein 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45149744, end_position_on_the_genomic_accession=45162831, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    284355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284355, CurrentID=0, Status='live', Symbol='TPRX1', Aliases=['TPRX'], description='tetrapeptide repeat homeobox 1', other_designations='tetra-peptide repeat homeobox protein 1|CRX like homeobox 2|tetra-peptide repeat homeobox 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47801243, end_position_on_the_genomic_accession=47803604, orientation='minus', exon_count=2, OMIM=[611166], no_hdr0=''),
    284358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284358, CurrentID=0, Status='live', Symbol='MAMSTR', Aliases=['MASTR'], description='MEF2 activating motif and SAP domain containing transcriptional regulator', other_designations='MEF2-activating motif and SAP domain-containing transcriptional regulator|MEF2-activating SAP transcriptional regulatory protein|likely ortholog of MEF2-activating SAP transcriptional regulator', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48712441, end_position_on_the_genomic_accession=48719898, orientation='minus', exon_count=10, OMIM=[610349], no_hdr0=''),
    284359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284359, CurrentID=0, Status='live', Symbol='IZUMO1', Aliases=['IZUMO', 'OBF'], description='izumo sperm-egg fusion 1', other_designations='izumo sperm-egg fusion protein 1|oocyte binding/fusion factor|sperm-specific protein Izumo', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48740852, end_position_on_the_genomic_accession=48746909, orientation='minus', exon_count=10, OMIM=[609278], no_hdr0=''),
    284361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284361, CurrentID=0, Status='live', Symbol='EMC10', Aliases=['C19orf63', 'HSM1', 'HSS1', 'NEDDFAS'], description='ER membrane protein complex subunit 10', other_designations='ER membrane protein complex subunit 10|UPF0510 protein INM02|hematopoietic signal peptide-containing membrane domain-containing 1|hematopoietic signal peptide-containing secreted 1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50476483, end_position_on_the_genomic_accession=50505905, orientation='plus', exon_count=10, OMIM=[614545], no_hdr0=''),
    284366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284366, CurrentID=0, Status='live', Symbol='KLK9', Aliases=['KLK-L3', 'KLKL3'], description='kallikrein related peptidase 9', other_designations='kallikrein-9|kallikrein-like protein 3', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51002508, end_position_on_the_genomic_accession=51009592, orientation='minus', exon_count=5, OMIM=[605504], no_hdr0=''),
    284369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284369, CurrentID=0, Status='live', Symbol='SIGLECL1', Aliases=['C19orf75', 'SIGLEC23P', 'SIGLECP7'], description='SIGLEC family like 1', other_designations='SIGLEC family-like protein 1|sialic acid binding Ig-like lectin, pseudogene 7', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51246332, end_position_on_the_genomic_accession=51269330, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    284370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284370, CurrentID=0, Status='live', Symbol='ZNF615', Aliases=[], description='zinc finger protein 615', other_designations='zinc finger protein 615', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51991332, end_position_on_the_genomic_accession=52008221, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    284371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284371, CurrentID=0, Status='live', Symbol='ZNF841', Aliases=[], description='zinc finger protein 841', other_designations='zinc finger protein 841', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52050028, end_position_on_the_genomic_accession=52095780, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    284382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284382, CurrentID=0, Status='live', Symbol='ACTL9', Aliases=['HSD21', 'SPGF53'], description='actin like 9', other_designations='actin-like protein 9|testicular tissue protein Li 15|testicular tissue protein Li 9', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8697400, end_position_on_the_genomic_accession=8698795, orientation='minus', exon_count=1, OMIM=[619251], no_hdr0=''),
    284383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284383, CurrentID=0, Status='live', Symbol='OR2Z1', Aliases=['OR19-4', 'OR2Z2'], description='olfactory receptor family 2 subfamily Z member 1', other_designations='olfactory receptor 2Z1|olfactory receptor 2Z2|olfactory receptor OR19-4|olfactory receptor, family 2, subfamily Z, member 2', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8721634, end_position_on_the_genomic_accession=8732160, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    284390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284390, CurrentID=0, Status='live', Symbol='ZNF763', Aliases=['ZNF', 'ZNF440L'], description='zinc finger protein 763', other_designations='zinc finger protein 763|DNA-binding protein|zinc finger protein 440 like', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11965040, end_position_on_the_genomic_accession=11980617, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    284391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284391, CurrentID=0, Status='live', Symbol='ZNF844', Aliases=[], description='zinc finger protein 844', other_designations='zinc finger protein 844', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12064731, end_position_on_the_genomic_accession=12081565, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    284402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284402, CurrentID=0, Status='live', Symbol='SCGB2B2', Aliases=['SCGB4A2', 'SCGBL'], description='secretoglobin family 2B member 2', other_designations='secretoglobin family 2B member 2|secretoglobin-like protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34585529, end_position_on_the_genomic_accession=34677159, orientation='minus', exon_count=9, OMIM=[615063], no_hdr0=''),
    284403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284403, CurrentID=0, Status='live', Symbol='WDR62', Aliases=['C19orf14', 'MCPH2'], description='WD repeat domain 62', other_designations='WD repeat-containing protein 62|microcephaly, primary autosomal recessive 2|truncated WDR62', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36054881, end_position_on_the_genomic_accession=36111145, orientation='plus', exon_count=35, OMIM=[613583], no_hdr0=''),
    284406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284406, CurrentID=0, Status='live', Symbol='ZFP82', Aliases=['ZNF545'], description='ZFP82 zinc finger protein', other_designations='zinc finger protein 82 homolog|zinc finger protein 545|zinc finger protein 85', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36383120, end_position_on_the_genomic_accession=36418644, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    284415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284415, CurrentID=0, Status='live', Symbol='VSTM1', Aliases=['SIRL-1', 'SIRL1', 'UNQ3033'], description='V-set and transmembrane domain containing 1', other_designations='V-set and transmembrane domain-containing protein 1|LAIR homolog|OSCAR-like transcript-1|signal inhibitory receptor on leukocytes-1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54040825, end_position_on_the_genomic_accession=54063966, orientation='minus', exon_count=13, OMIM=[616804], no_hdr0=''),
    284417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284417, CurrentID=0, Status='live', Symbol='TMEM150B', Aliases=['DRAM3', 'TMEM224', 'TTN2'], description='transmembrane protein 150B', other_designations='modulator of macroautophagy TMEM150B|DRAM-Related/Associated Member 3|hCG1651476|protein DRAM-3|tentonin 2|transmembrane protein 224|transmembrane protein LOC284417', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55308869, end_position_on_the_genomic_accession=55334043, orientation='minus', exon_count=12, OMIM=[617291], no_hdr0=''),
    284418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284418, CurrentID=0, Status='live', Symbol='FAM71E2', Aliases=['C19orf16'], description='family with sequence similarity 71 member E2', other_designations='protein FAM71E2|putative protein FAM71E2', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55354908, end_position_on_the_genomic_accession=55363260, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    284422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284422, CurrentID=0, Status='live', Symbol='SMIM24', Aliases=['C19orf77', 'HSPC323', 'MARDI'], description='small integral membrane protein 24', other_designations='small integral membrane protein 24|MAP17-related dimer|transmembrane protein C19orf77|transmembrane protein HSPC323', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3473986, end_position_on_the_genomic_accession=3480525, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    284427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284427, CurrentID=0, Status='live', Symbol='SLC25A41', Aliases=['APC4', 'SCaMC-3L'], description='solute carrier family 25 member 41', other_designations='mitochondrial carrier protein SCaMC-3L|SCaMC-3-like|mitochondrial ATP-Mg/Pi carrier protein SLC25A41|small calcium-binding mitochondrial carrier protein 3-like', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6426037, end_position_on_the_genomic_accession=6436267, orientation='minus', exon_count=10, OMIM=[610822], no_hdr0=''),
    284428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284428, CurrentID=0, Status='live', Symbol='MBD3L5', Aliases=[], description='methyl-CpG binding domain protein 3 like 5', other_designations='putative methyl-CpG-binding domain protein 3-like 5|MBD3-like protein 5', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7030578, end_position_on_the_genomic_accession=7033011, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    284433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284433, CurrentID=0, Status='live', Symbol='OR10H5', Aliases=['OR19-25', 'OR19-26'], description='olfactory receptor family 10 subfamily H member 5', other_designations='olfactory receptor 10H5|olfactory receptor OR19-25|olfactory receptor OR19-26', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=15787661, end_position_on_the_genomic_accession=15800357, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    284434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284434, CurrentID=0, Status='live', Symbol='NWD1', Aliases=[], description='NACHT and WD repeat domain containing 1', other_designations='NACHT domain- and WD repeat-containing protein 1|NACHT and WD repeat domain-containing protein 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=16719526, end_position_on_the_genomic_accession=16817963, orientation='plus', exon_count=22, OMIM=[616250], no_hdr0=''),
    284439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284439, CurrentID=0, Status='live', Symbol='SLC25A42', Aliases=['MECREN'], description='solute carrier family 25 member 42', other_designations='mitochondrial coenzyme A transporter SLC25A42', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19063994, end_position_on_the_genomic_accession=19113030, orientation='plus', exon_count=10, OMIM=[610823], no_hdr0=''),
    284443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284443, CurrentID=0, Status='live', Symbol='ZNF493', Aliases=[], description='zinc finger protein 493', other_designations='zinc finger protein 493', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21397133, end_position_on_the_genomic_accession=21427577, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    284451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284451, CurrentID=0, Status='live', Symbol='ODF3L2', Aliases=['C19orf19'], description='outer dense fiber of sperm tails 3 like 2', other_designations='outer dense fiber protein 3-like protein 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=463346, end_position_on_the_genomic_accession=491624, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    284459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284459, CurrentID=0, Status='live', Symbol='ZNF875', Aliases=['HKR1'], description='zinc finger protein 875', other_designations='zinc finger protein 875|HKR1, GLI-Kruppel zinc finger family member|Krueppel-related zinc finger protein 1|oncogene HKR1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37312837, end_position_on_the_genomic_accession=37364455, orientation='plus', exon_count=18, OMIM=[165250], no_hdr0=''),
    284467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284467, CurrentID=0, Status='live', Symbol='TAFA3', Aliases=['FAM19A3', 'TAFA-3'], description='TAFA chemokine like family member 3', other_designations='chemokine-like protein TAFA-3|family with sequence similarity 19 (chemokine (C-C motif)-like), member A3|family with sequence similarity 19 member A3, C-C motif chemokine like|protein FAM19A3', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112718905, end_position_on_the_genomic_accession=112727235, orientation='plus', exon_count=6, OMIM=[617497], no_hdr0=''),
    284485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284485, CurrentID=0, Status='live', Symbol='RIIAD1', Aliases=['C1orf230', 'NCRNA00166'], description='regulatory subunit of type II PKA R-subunit domain containing 1', other_designations='RIIa domain-containing protein 1|RIIa domain-containing protein C1orf230|RIIa domain-containing protein ENSP00000357824|regulatory subunit of type II PKA R-subunit (RIIa) domain containing 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151721522, end_position_on_the_genomic_accession=151729805, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    284486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284486, CurrentID=0, Status='live', Symbol='THEM5', Aliases=['ACOT15'], description='thioesterase superfamily member 5', other_designations='acyl-coenzyme A thioesterase THEM5|acyl-CoA thioesterase THEM5|acyl-coenzyme A thioesterase 15', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151847101, end_position_on_the_genomic_accession=151853712, orientation='minus', exon_count=6, OMIM=[615653], no_hdr0=''),
    284498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284498, CurrentID=0, Status='live', Symbol='C1orf167', Aliases=[], description='chromosome 1 open reading frame 167', other_designations='uncharacterized protein C1orf167', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11762188, end_position_on_the_genomic_accession=11790223, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    284521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284521, CurrentID=0, Status='live', Symbol='OR2L13', Aliases=['OR2L14'], description='olfactory receptor family 2 subfamily L member 13', other_designations='olfactory receptor 2L13|olfactory receptor 2L14|olfactory receptor, family 2, subfamily L, member 14', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247937177, end_position_on_the_genomic_accession=248101163, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    284525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284525, CurrentID=0, Status='live', Symbol='SLC9C2', Aliases=['SLC9A11'], description='solute carrier family 9 member C2 (putative)', other_designations='sodium/hydrogen exchanger 11|NHE-11|Na(+)/H(+) exchanger 11|solute carrier family 9, member 11', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173500460, end_position_on_the_genomic_accession=173603072, orientation='minus', exon_count=29, OMIM=[], no_hdr0=''),
    284532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284532, CurrentID=0, Status='live', Symbol='OR14A16', Aliases=['OR5AT1'], description='olfactory receptor family 14 subfamily A member 16', other_designations='olfactory receptor 14A16|olfactory receptor 5AT1|olfactory receptor OR1-45|olfactory receptor, family 5, subfamily AT, member 1', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247814660, end_position_on_the_genomic_accession=247824119, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    284541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284541, CurrentID=0, Status='live', Symbol='CYP4A22', Aliases=[], description='cytochrome P450 family 4 subfamily A member 22', other_designations='cytochrome P450 4A22|CYPIVA22|cytochrome P450 4A22K|cytochrome P450, family 4, subfamily A, polypeptide 22|fatty acid omega-hydroxylase|lauric acid omega-hydroxylase|long-chain fatty acid omega-monooxygenase', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47137441, end_position_on_the_genomic_accession=47149738, orientation='plus', exon_count=12, OMIM=[615341], no_hdr0=''),
    284546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284546, CurrentID=0, Status='live', Symbol='C1orf185', Aliases=[], description='chromosome 1 open reading frame 185', other_designations='uncharacterized protein C1orf185', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=51102188, end_position_on_the_genomic_accession=51152283, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    284565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284565, CurrentID=0, Status='live', Symbol='NBPF15', Aliases=['AB14', 'AG3', 'NBPF16'], description='NBPF member 15', other_designations='neuroblastoma breakpoint family member 15|neuroblastoma breakpoint family, member 16', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=144421390, end_position_on_the_genomic_accession=144461669, orientation='minus', exon_count=28, OMIM=[610414, 614005], no_hdr0=''),
    284611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284611, CurrentID=0, Status='live', Symbol='FAM102B', Aliases=['SYM-3B'], description='family with sequence similarity 102 member B', other_designations='protein FAM102B|sym-3 homolog B', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108560100, end_position_on_the_genomic_accession=108639322, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    284612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284612, CurrentID=0, Status='live', Symbol='SYPL2', Aliases=['MG29'], description='synaptophysin like 2', other_designations='synaptophysin-like protein 2|mitsugumin 29', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109466478, end_position_on_the_genomic_accession=109482142, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    284613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284613, CurrentID=0, Status='live', Symbol='CYB561D1', Aliases=[], description='cytochrome b561 family member D1', other_designations='probable transmembrane reductase CYB561D1|cytochrome b561 domain-containing protein 1|cytochrome b-561 domain containing 1', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109493606, end_position_on_the_genomic_accession=109500441, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    284615 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284615, CurrentID=0, Status='live', Symbol='ANKRD34A', Aliases=['ANKRD34'], description='ankyrin repeat domain 34A', other_designations='ankyrin repeat domain-containing protein 34A|ankyrin repeat domain 34', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145959441, end_position_on_the_genomic_accession=145964575, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    284654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284654, CurrentID=0, Status='live', Symbol='RSPO1', Aliases=['CRISTIN3', 'RSPO'], description='R-spondin 1', other_designations='R-spondin-1|R-spondin homolog|roof plate-specific spondin-1', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37611350, end_position_on_the_genomic_accession=37634906, orientation='minus', exon_count=8, OMIM=[609595], no_hdr0=''),
    284656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284656, CurrentID=0, Status='live', Symbol='EPHA10', Aliases=[], description='EPH receptor A10', other_designations='ephrin type-A receptor 10|EphA10s protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=37713888, end_position_on_the_genomic_accession=37765120, orientation='minus', exon_count=23, OMIM=[611123], no_hdr0=''),
    284680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284680, CurrentID=0, Status='live', Symbol='SPATA46', Aliases=['C1orf111', 'HSD20', 'TEKT2BP2'], description='spermatogenesis associated 46', other_designations='spermatogenesis-associated protein 46|uncharacterized protein C1orf111', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162373203, end_position_on_the_genomic_accession=162376962, orientation='minus', exon_count=4, OMIM=[617257], no_hdr0=''),
    284695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284695, CurrentID=0, Status='live', Symbol='ZNF326', Aliases=['ZAN75', 'ZIRD', 'Zfp326', 'dJ871E2.1'], description='zinc finger protein 326', other_designations='DBIRD complex subunit ZNF326|ZNF-protein interacting with nuclear mRNPs and DBC1|zinc finger protein interacting with mRNPs and DBC1', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89995100, end_position_on_the_genomic_accession=90035533, orientation='plus', exon_count=12, OMIM=[614601], no_hdr0=''),
    284697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284697, CurrentID=0, Status='live', Symbol='BTBD8', Aliases=['KIAA1107'], description='BTB domain containing 8', other_designations='BTB/POZ domain-containing protein 8|AP2-interacting clathrin-endocytosis protein|APache|BTB (POZ) domain containing 8|double BTB/POZ domain containing protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92080345, end_position_on_the_genomic_accession=92188509, orientation='plus', exon_count=19, OMIM=[617945], no_hdr0=''),
    284716 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284716, CurrentID=0, Status='live', Symbol='RIMKLA', Aliases=['FAM80A', 'NAAGS', 'NAAGS-II', 'NAAGS2'], description='ribosomal modification protein rimK like family member A', other_designations='N-acetylaspartylglutamate synthase A|N-acetylaspartyl-glutamate synthetase A|N-acetylaspartylglutamate synthetase II|N-acetylaspartylglutamylglutamate synthase A|NAAG synthetase A|RP11-157D18.1|family with sequence similarity 80, member A|ribosomal protein S6 modification-like protein A', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42380792, end_position_on_the_genomic_accession=42425813, orientation='plus', exon_count=5, OMIM=[618949], no_hdr0=''),
    284723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284723, CurrentID=0, Status='live', Symbol='SLC25A34', Aliases=[], description='solute carrier family 25 member 34', other_designations='solute carrier family 25 member 34', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15735088, end_position_on_the_genomic_accession=15741392, orientation='plus', exon_count=6, OMIM=[610817], no_hdr0=''),
    284739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284739, CurrentID=0, Status='live', Symbol='C20orf204', Aliases=['LINC00176', 'NCRNA00176', 'PRR17'], description='chromosome 20 open reading frame 204', other_designations='uncharacterized protein C20orf204|long intergenic non-protein coding RNA 176|proline rich 17|putative proline-rich protein 17', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=64033709, end_position_on_the_genomic_accession=64039001, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    284759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284759, CurrentID=0, Status='live', Symbol='SIRPB2', Aliases=['PTPN1L', 'PTPNS1L3', 'dJ776F14.2'], description='signal regulatory protein beta 2', other_designations='signal-regulatory protein beta-2|SIRP-beta-2|protein tyrosine phosphatase non-receptor type substrate protein|protein tyrosine phosphatase, non-receptor type substrate 1-like 3', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1474578, end_position_on_the_genomic_accession=1491762, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    284805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284805, CurrentID=0, Status='live', Symbol='C20orf203', Aliases=[], description='chromosome 20 open reading frame 203', other_designations='uncharacterized protein C20orf203|alugen', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32631625, end_position_on_the_genomic_accession=32673941, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    284827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284827, CurrentID=0, Status='live', Symbol='KRTAP13-4', Aliases=['KAP13.4'], description='keratin associated protein 13-4', other_designations='keratin-associated protein 13-4', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30430254, end_position_on_the_genomic_accession=30430898, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    284904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284904, CurrentID=0, Status='live', Symbol='SEC14L4', Aliases=['TAP3'], description='SEC14 like lipid binding 4', other_designations='SEC14-like protein 4|SEC14-like 4|SEC14p-like protein TAP3|tocopherol-associated protein 3', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30488150, end_position_on_the_genomic_accession=30505711, orientation='minus', exon_count=14, OMIM=[612825], no_hdr0=''),
    284948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284948, CurrentID=0, Status='live', Symbol='SH2D6', Aliases=[], description='SH2 domain containing 6', other_designations='SH2 domain-containing protein 6', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85418714, end_position_on_the_genomic_accession=85437029, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    284958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284958, CurrentID=0, Status='live', Symbol='NT5DC4', Aliases=[], description="5'-nucleotidase domain containing 4", other_designations="5'-nucleotidase domain-containing protein 4", map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112717245, end_position_on_the_genomic_accession=112743174, orientation='plus', exon_count=25, OMIM=[], no_hdr0=''),
    284992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284992, CurrentID=0, Status='live', Symbol='CCDC150', Aliases=[], description='coiled-coil domain containing 150', other_designations='coiled-coil domain-containing protein 150', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196639632, end_position_on_the_genomic_accession=196733668, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    284996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=284996, CurrentID=0, Status='live', Symbol='RNF149', Aliases=['DNAPTP2'], description='ring finger protein 149', other_designations='E3 ubiquitin-protein ligase RNF149|DNA polymerase-transactivated protein 2|RING-type E3 ubiquitin transferase RNF149', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101271213, end_position_on_the_genomic_accession=101308701, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    285016 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285016, CurrentID=0, Status='live', Symbol='ALKAL2', Aliases=['AUGA', 'FAM150B', 'PRO1097', 'RGPG542'], description='ALK and LTK ligand 2', other_designations='ALK and LTK ligand 2|AUG-alpha|augmentor alpha|augmentor-beta|family with sequence similarity 150 member B|protein FAM150B', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=279558, end_position_on_the_genomic_accession=288872, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    285025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285025, CurrentID=0, Status='live', Symbol='CCDC141', Aliases=['CAMDI'], description='coiled-coil domain containing 141', other_designations='coiled-coil domain-containing protein 141|coiled-coil protein associated with myosin II and DISC1', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178825308, end_position_on_the_genomic_accession=179050137, orientation='minus', exon_count=28, OMIM=[616031], no_hdr0=''),
    285051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285051, CurrentID=0, Status='live', Symbol='STPG4', Aliases=['C2orf61', 'GSE'], description='sperm-tail PG-rich repeat containing 4', other_designations='protein STPG4|gonad-specific expression gene protein|sperm-tail PG-rich repeat-containing protein 4|uncharacterized protein C2orf61', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=47086991, end_position_on_the_genomic_accession=47155308, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    285093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285093, CurrentID=0, Status='live', Symbol='RTP5', Aliases=['C2orf85', 'CXXC11', 'Z3CXXC5'], description='receptor transporter protein 5 (putative)', other_designations='receptor-transporting protein 5|3CxxC-type zinc finger protein 5|CXXC finger protein 11|CXXC-type zinc finger protein 11|receptor (chemosensory) transporter protein 5 (putative)|zinc finger, 3CxxC-type 5', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241869729, end_position_on_the_genomic_accession=241873823, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    285095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285095, CurrentID=0, Status='live', Symbol='FAM240C', Aliases=[], description='family with sequence similarity 240 member C', other_designations='protein FAM240C', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241893988, end_position_on_the_genomic_accession=241902585, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    285126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285126, CurrentID=0, Status='live', Symbol='DNAJC5G', Aliases=['CSP-gamma'], description='DnaJ heat shock protein family (Hsp40) member C5 gamma', other_designations='dnaJ homolog subfamily C member 5G|DnaJ (Hsp40) homolog, subfamily C, member 5 gamma|cysteine string protein-gamma|gamma-CSP|gamma-cysteine string protein', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27275427, end_position_on_the_genomic_accession=27281499, orientation='plus', exon_count=7, OMIM=[613946], no_hdr0=''),
    285141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285141, CurrentID=0, Status='live', Symbol='ERICH2', Aliases=[], description='glutamate rich 2', other_designations='glutamate-rich protein 2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170770042, end_position_on_the_genomic_accession=170798977, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    285148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285148, CurrentID=0, Status='live', Symbol='IAH1', Aliases=[], description='isoamyl acetate hydrolyzing esterase 1 (putative)', other_designations='isoamyl acetate-hydrolyzing esterase 1 homolog|testicular tissue protein Li 92', map_location='2p25.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=9474532, end_position_on_the_genomic_accession=9512403, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    285172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285172, CurrentID=0, Status='live', Symbol='FAM126B', Aliases=['HYCC2'], description='family with sequence similarity 126 member B', other_designations='protein FAM126B', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=200973718, end_position_on_the_genomic_accession=201071671, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    285175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285175, CurrentID=0, Status='live', Symbol='UNC80', Aliases=['C2orf21', 'UNC-80'], description='unc-80 homolog, NALCN channel complex subunit', other_designations='protein unc-80 homolog|unc-80 homolog, NALCN activator', map_location='2q34', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=209771832, end_position_on_the_genomic_accession=209999299, orientation='plus', exon_count=68, OMIM=[612636], no_hdr0=''),
    285180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285180, CurrentID=0, Status='live', Symbol='RUFY4', Aliases=['ZFYVE31'], description='RUN and FYVE domain containing 4', other_designations='RUN and FYVE domain-containing protein 4', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218034934, end_position_on_the_genomic_accession=218090584, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    285190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285190, CurrentID=0, Status='live', Symbol='RGPD4', Aliases=['RGP4'], description='RANBP2 like and GRIP domain containing 4', other_designations='ranBP2-like and GRIP domain-containing protein 4', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=107826892, end_position_on_the_genomic_accession=107892544, orientation='plus', exon_count=28, OMIM=[612707], no_hdr0=''),
    285193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285193, CurrentID=0, Status='live', Symbol='DUSP28', Aliases=['DUSP26', 'VHP'], description='dual specificity phosphatase 28', other_designations='dual specificity phosphatase 28', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240559239, end_position_on_the_genomic_accession=240565256, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    285195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285195, CurrentID=0, Status='live', Symbol='SLC9A9', Aliases=['AUTS16', 'NHE9'], description='solute carrier family 9 member A9', other_designations='sodium/hydrogen exchanger 9|Na(+)/H(+) exchanger 9|putative protein product of Nbla00118|sodium/proton exchanger NHE9|solute carrier family 9 (sodium/hydrogen exchanger)|solute carrier family 9, subfamily A (NHE9, cation proton antiporter 9), member 9', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=143265222, end_position_on_the_genomic_accession=143848492, orientation='minus', exon_count=20, OMIM=[608396], no_hdr0=''),
    285203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285203, CurrentID=0, Status='live', Symbol='EOGT', Aliases=['AER61', 'AOS4', 'C3orf641', 'EOGT'], description='EGF domain specific O-linked N-acetylglucosamine transferase', other_designations='EGF domain-specific O-linked N-acetylglucosamine transferase|AER61 glycosyltransferase|EGF domain-specific O-linked N-acetylglucosamine (GlcNAc) transferase|EGF-O-GlcNAc transferase|extracellular O-linked N-acetylglucosamine transferase', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=68975220, end_position_on_the_genomic_accession=69013961, orientation='minus', exon_count=21, OMIM=[614789], no_hdr0=''),
    285220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285220, CurrentID=0, Status='live', Symbol='EPHA6', Aliases=['EHK-2', 'EHK2', 'EK12', 'EPA6', 'HEK12', 'PRO57066'], description='EPH receptor A6', other_designations='ephrin type-A receptor 6|EPH homology kinase 2|EPH-like kinase 12|ephrin receptor EphA6', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=96814581, end_position_on_the_genomic_accession=97761532, orientation='plus', exon_count=35, OMIM=[600066], no_hdr0=''),
    285231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285231, CurrentID=0, Status='live', Symbol='FBXW12', Aliases=['FBW12', 'FBXO12', 'FBXO35'], description='F-box and WD repeat domain containing 12', other_designations='F-box/WD repeat-containing protein 12|F-box and WD-40 domain protein 12|F-box and WD-40 domain-containing protein 12|F-box only protein 35|F-box- and WD40-repeat-containing protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48372219, end_position_on_the_genomic_accession=48394830, orientation='plus', exon_count=11, OMIM=[609075], no_hdr0=''),
    285237 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285237, CurrentID=0, Status='live', Symbol='C3orf38', Aliases=[], description='chromosome 3 open reading frame 38', other_designations='uncharacterized protein C3orf38|dense incisors', map_location='3p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=88149959, end_position_on_the_genomic_accession=88157966, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    285242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285242, CurrentID=0, Status='live', Symbol='HTR3E', Aliases=['5-HT3-E', '5-HT3E', '5-HT3c1'], description='5-hydroxytryptamine receptor 3E', other_designations='5-hydroxytryptamine receptor 3E|5-hydroxytryptamine (serotonin) receptor 3, family member E|5-hydroxytryptamine (serotonin) receptor 3E, ionotropic|5-hydroxytryptamine receptor 3 subunit E', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184097064, end_position_on_the_genomic_accession=184106995, orientation='plus', exon_count=9, OMIM=[610123], no_hdr0=''),
    285267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285267, CurrentID=0, Status='live', Symbol='ZNF619', Aliases=[], description='zinc finger protein 619', other_designations='zinc finger protein 619', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40477122, end_position_on_the_genomic_accession=40491053, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    285268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285268, CurrentID=0, Status='live', Symbol='ZNF621', Aliases=[], description='zinc finger protein 621', other_designations='zinc finger protein 621', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=40523854, end_position_on_the_genomic_accession=40539974, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    285282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285282, CurrentID=0, Status='live', Symbol='RABL3', Aliases=['PNCA5'], description='RAB, member of RAS oncogene family like 3', other_designations='rab-like protein 3', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=120684938, end_position_on_the_genomic_accession=120742680, orientation='minus', exon_count=10, OMIM=[618542], no_hdr0=''),
    285311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285311, CurrentID=0, Status='live', Symbol='C3orf56', Aliases=[], description='chromosome 3 open reading frame 56', other_designations='putative uncharacterized protein C3orf56', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127193131, end_position_on_the_genomic_accession=127198185, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    285313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285313, CurrentID=0, Status='live', Symbol='IGSF10', Aliases=['CMF608'], description='immunoglobulin superfamily member 10', other_designations='immunoglobulin superfamily member 10|calvaria mechanical force protein 608', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151435051, end_position_on_the_genomic_accession=151619926, orientation='minus', exon_count=13, OMIM=[617351], no_hdr0=''),
    285315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285315, CurrentID=0, Status='live', Symbol='C3orf33', Aliases=['AC3-33'], description='chromosome 3 open reading frame 33', other_designations='protein C3orf33|AP-1 activity suppressor', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155762617, end_position_on_the_genomic_accession=155806278, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    285331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285331, CurrentID=0, Status='live', Symbol='CCDC66', Aliases=[], description='coiled-coil domain containing 66', other_designations='coiled-coil domain-containing protein 66', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=56557125, end_position_on_the_genomic_accession=56621837, orientation='plus', exon_count=23, OMIM=[619287], no_hdr0=''),
    285335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285335, CurrentID=0, Status='live', Symbol='SLC9C1', Aliases=['NHE', 'NHE-10', 'SLC9A10', 'sperm-NHE'], description='solute carrier family 9 member C1', other_designations='sodium/hydrogen exchanger 10|solute carrier family 9, member 10|solute carrier family 9, subfamily C (Na+-transporting carboxylic acid decarboxylase), member 1|sperm-specific Na(+)/H(+) exchanger|sperm-specific sodium proton exchanger', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112140898, end_position_on_the_genomic_accession=112294258, orientation='minus', exon_count=32, OMIM=[612738], no_hdr0=''),
    285343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285343, CurrentID=0, Status='live', Symbol='TCAIM', Aliases=['C3orf23', 'TOAG-1', 'TOAG1'], description='T cell activation inhibitor, mitochondrial', other_designations='T-cell activation inhibitor, mitochondrial|tolerance associated gene-1 protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44337465, end_position_on_the_genomic_accession=44409448, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    285346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285346, CurrentID=0, Status='live', Symbol='ZNF852', Aliases=[], description='zinc finger protein 852', other_designations='zinc finger protein 852|putative zinc finger protein 852', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44491766, end_position_on_the_genomic_accession=44510617, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    285349 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285349, CurrentID=0, Status='live', Symbol='ZNF660', Aliases=[], description='zinc finger protein 660', other_designations='zinc finger protein 660', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44584964, end_position_on_the_genomic_accession=44599694, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    285362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285362, CurrentID=0, Status='live', Symbol='SUMF1', Aliases=['AAPA3037', 'FGE', 'UNQ3037'], description='sulfatase modifying factor 1', other_designations='formylglycine-generating enzyme|C-alpha-formylglycine-generating enzyme 1|FGly-generating enzyme', map_location='3p26.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=4034714, end_position_on_the_genomic_accession=4467270, orientation='minus', exon_count=15, OMIM=[607939], no_hdr0=''),
    285367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285367, CurrentID=0, Status='live', Symbol='RPUSD3', Aliases=[], description='RNA pseudouridine synthase D3', other_designations='mitochondrial mRNA pseudouridine synthase RPUSD3|RNA pseudouridylate synthase domain containing 3|RNA pseudouridylate synthase domain-containing protein 3', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9836253, end_position_on_the_genomic_accession=9844059, orientation='minus', exon_count=10, OMIM=[617759], no_hdr0=''),
    285368 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285368, CurrentID=0, Status='live', Symbol='PRRT3', Aliases=[], description='proline rich transmembrane protein 3', other_designations='proline-rich transmembrane protein 3', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9945542, end_position_on_the_genomic_accession=9952408, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    285381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285381, CurrentID=0, Status='live', Symbol='DPH3', Aliases=['DELGIP', 'DELGIP1', 'DESR1A', 'KTI11', 'ZCSL2', 'DPH3'], description='diphthamide biosynthesis 3', other_designations='DPH3 homolog|CSL-type zinc finger-containing protein 2|DPH3 homolog (KTI11, S. cerevisiae)|DPH3, KTI11 homolog|DPH3A, KTI11 homolog A|Del-GEF interacting protein|deafness locus putative guanine nucleotide exchange factor interacting protein 1|delGEF-interacting protein 1|diphtheria toxin and Pseudomonas exotoxin A sensitivity required gene 1|zinc finger, CSL domain containing 2|zinc finger, CSL-type containing 2', map_location='3p25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=16257061, end_position_on_the_genomic_accession=16264943, orientation='minus', exon_count=3, OMIM=[608959], no_hdr0=''),
    285382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285382, CurrentID=0, Status='live', Symbol='C3orf70', Aliases=[], description='chromosome 3 open reading frame 70', other_designations='UPF0524 protein C3orf70', map_location='3q27.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=185076838, end_position_on_the_genomic_accession=185153060, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    285386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285386, CurrentID=0, Status='live', Symbol='TPRG1', Aliases=['FAM79B'], description='tumor protein p63 regulated 1', other_designations='tumor protein p63-regulated gene 1 protein|family with sequence similarity 79, member B', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=189000779, end_position_on_the_genomic_accession=189325304, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    285423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285423, CurrentID=0, Status='live', Symbol='IQCM', Aliases=[], description='IQ motif containing M', other_designations='IQ domain-containing protein M|iQ domain-containing protein M', map_location='4q31.23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=149351691, end_position_on_the_genomic_accession=149815861, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    285429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285429, CurrentID=0, Status='live', Symbol='DCAF4L1', Aliases=['WDR21B'], description='DDB1 and CUL4 associated factor 4 like 1', other_designations='DDB1- and CUL4-associated factor 4-like protein 1|WD repeat domain 21B|WD repeat-containing protein 21B', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=41981756, end_position_on_the_genomic_accession=41986465, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    285440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285440, CurrentID=0, Status='live', Symbol='CYP4V2', Aliases=['BCD', 'CYP4AH1'], description='cytochrome P450 family 4 subfamily V member 2', other_designations='cytochrome P450 4V2|cytochrome P450, family 4, subfamily V, polypeptide 2|docosahexaenoic acid omega-hydroxylase CYP4V2|long-chain fatty acid omega-monooxygenase', map_location='4q35.1-q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=186191567, end_position_on_the_genomic_accession=186213463, orientation='plus', exon_count=11, OMIM=[608614], no_hdr0=''),
    285489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285489, CurrentID=0, Status='live', Symbol='DOK7', Aliases=['C4orf25', 'CMS10', 'CMS1B', 'FADS3'], description='docking protein 7', other_designations='protein Dok-7|downstream of tyrosine kinase 7', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3463306, end_position_on_the_genomic_accession=3501482, orientation='plus', exon_count=12, OMIM=[610285], no_hdr0=''),
    285498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285498, CurrentID=0, Status='live', Symbol='RNF212', Aliases=['ZHP3'], description='ring finger protein 212', other_designations='probable E3 SUMO-protein ligase RNF212|probable E3 SUMO-protein transferase RNF212', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=1056248, end_position_on_the_genomic_accession=1113794, orientation='minus', exon_count=17, OMIM=[612041], no_hdr0=''),
    285513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285513, CurrentID=0, Status='live', Symbol='GPRIN3', Aliases=['GRIN3'], description='GPRIN family member 3', other_designations='G protein-regulated inducer of neurite outgrowth 3', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=89236383, end_position_on_the_genomic_accession=89307800, orientation='minus', exon_count=3, OMIM=[611241], no_hdr0=''),
    285521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285521, CurrentID=0, Status='live', Symbol='COX18', Aliases=['COX18HS'], description='cytochrome c oxidase assembly factor COX18', other_designations='cytochrome c oxidase assembly protein COX18, mitochondrial|COX18, cytochrome c oxidase assembly factor|cytochrome c oxidase assembly homolog 18|cytochrome c oxidase assembly protein 18|mitochondrial inner membrane protein COX18', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=73052362, end_position_on_the_genomic_accession=73069777, orientation='minus', exon_count=6, OMIM=[610428], no_hdr0=''),
    285525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285525, CurrentID=0, Status='live', Symbol='YIPF7', Aliases=['FinGER9'], description='Yip1 domain family member 7', other_designations='protein YIPF7|YIP1 family member 7|five-pass transmembrane protein localizing in the Golgi apparatus and the endoplasmic reticulum 9', map_location='4p12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=44619578, end_position_on_the_genomic_accession=44656868, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    285527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285527, CurrentID=0, Status='live', Symbol='FRYL', Aliases=['AF4p12', 'KIAA0826', 'MOR2'], description='FRY like transcription coactivator', other_designations='protein furry homolog-like|ALL1-fused gene from chromosome 4p12 protein|FRY-like|furry homolog-like|furry-like|mor2 cell polarity protein homolog', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48497357, end_position_on_the_genomic_accession=48780323, orientation='minus', exon_count=69, OMIM=[], no_hdr0=''),
    285533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285533, CurrentID=0, Status='live', Symbol='RNF175', Aliases=[], description='ring finger protein 175', other_designations='RING finger protein 175', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=153710160, end_position_on_the_genomic_accession=153760983, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    285550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285550, CurrentID=0, Status='live', Symbol='FAM200B', Aliases=['C4orf53'], description='family with sequence similarity 200 member B', other_designations='protein FAM200B|Putative protein FAM200B', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=15651521, end_position_on_the_genomic_accession=15690447, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    285555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285555, CurrentID=0, Status='live', Symbol='STPG2', Aliases=['C4orf37'], description='sperm tail PG-rich repeat containing 2', other_designations='sperm-tail PG-rich repeat-containing protein 2', map_location='4q22.3-q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=97184113, end_position_on_the_genomic_accession=98143486, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    285556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285556, CurrentID=0, Status='live', Symbol='C4orf54', Aliases=['FOPV'], description='chromosome 4 open reading frame 54', other_designations='uncharacterized protein C4orf54|familial obliterative portal venopathy', map_location='4q23', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=99636529, end_position_on_the_genomic_accession=99657828, orientation='minus', exon_count=4, OMIM=[617881], no_hdr0=''),
    285588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285588, CurrentID=0, Status='live', Symbol='EFCAB9', Aliases=[], description='EF-hand calcium binding domain 9', other_designations='EF-hand calcium-binding domain-containing protein 9', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172194172, end_position_on_the_genomic_accession=172203454, orientation='plus', exon_count=4, OMIM=[618520], no_hdr0=''),
    285590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285590, CurrentID=0, Status='live', Symbol='SH3PXD2B', Aliases=['FAD49', 'FTHS', 'HOFI', 'KIAA1295', 'TKS4', 'TSK4'], description='SH3 and PX domains 2B', other_designations='SH3 and PX domain-containing protein 2B|adapter protein HOFI|adaptor protein HOFI|factor for adipocyte differentiation 49|tyrosine kinase substrate with four SH3 domains', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=172325181, end_position_on_the_genomic_accession=172454525, orientation='minus', exon_count=15, OMIM=[613293], no_hdr0=''),
    285596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285596, CurrentID=0, Status='live', Symbol='FAM153A', Aliases=['NY-REN-7'], description='family with sequence similarity 153 member A', other_designations='protein FAM153A|NY REN 7 antigen|renal carcinoma antigen NY-REN-7', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177694247, end_position_on_the_genomic_accession=177783518, orientation='minus', exon_count=38, OMIM=[], no_hdr0=''),
    285598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285598, CurrentID=0, Status='live', Symbol='ARL10', Aliases=['ARL10A'], description='ADP ribosylation factor like GTPase 10', other_designations='ADP-ribosylation factor-like protein 10|ADP-ribosylation factor-like 10A|ADP-ribosylation factor-like membrane-associated protein', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176365474, end_position_on_the_genomic_accession=176415096, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    285600 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285600, CurrentID=0, Status='live', Symbol='KIAA0825', Aliases=['C5orf36', 'PAPA10'], description='KIAA0825', other_designations='uncharacterized protein KIAA0825', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=94150851, end_position_on_the_genomic_accession=94618604, orientation='minus', exon_count=39, OMIM=[617266], no_hdr0=''),
    285601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285601, CurrentID=0, Status='live', Symbol='GPR150', Aliases=['PGR11'], description='G protein-coupled receptor 150', other_designations='probable G-protein coupled receptor 150|seven transmembrane helix receptor', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95620087, end_position_on_the_genomic_accession=95622142, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    285605 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285605, CurrentID=0, Status='live', Symbol='DTWD2', Aliases=[], description='DTW domain containing 2', other_designations='tRNA-uridine aminocarboxypropyltransferase 2|DTW domain-containing protein 2', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=118836074, end_position_on_the_genomic_accession=118988547, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    285613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285613, CurrentID=0, Status='live', Symbol='RELL2', Aliases=['C5orf16'], description='RELT like 2', other_designations='RELT-like protein 2|receptor expressed in lymphoid tissues like 2', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=141636961, end_position_on_the_genomic_accession=141641077, orientation='plus', exon_count=6, OMIM=[611213], no_hdr0=''),
    285636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285636, CurrentID=0, Status='live', Symbol='C5orf51', Aliases=[], description='chromosome 5 open reading frame 51', other_designations='UPF0600 protein C5orf51', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=41904313, end_position_on_the_genomic_accession=41921636, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    285641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285641, CurrentID=0, Status='live', Symbol='SLC36A3', Aliases=['PAT3', 'TRAMD2', 'tramdorin2'], description='solute carrier family 36 member 3', other_designations='proton-coupled amino acid transporter 3|proton/amino acid transporter 3|solute carrier family 36 (proton/amino acid symporter), member 3|tramdorin 2', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=151276358, end_position_on_the_genomic_accession=151303766, orientation='minus', exon_count=11, OMIM=[608332], no_hdr0=''),
    285643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285643, CurrentID=0, Status='live', Symbol='KIF4B', Aliases=[], description='kinesin family member 4B', other_designations='chromosome-associated kinesin KIF4B|chromokinesin-B', map_location='5q33.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=155013755, end_position_on_the_genomic_accession=155018141, orientation='plus', exon_count=1, OMIM=[609184], no_hdr0=''),
    285659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285659, CurrentID=0, Status='live', Symbol='OR2V2', Aliases=['OR2V3', 'OST713'], description='olfactory receptor family 2 subfamily V member 2', other_designations='olfactory receptor 2V2|olfactory receptor 2V3|olfactory receptor OR5-3|olfactory receptor, family 2, subfamily V, member 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=181147586, end_position_on_the_genomic_accession=181159285, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    285671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285671, CurrentID=0, Status='live', Symbol='RNF180', Aliases=['RINES'], description='ring finger protein 180', other_designations='E3 ubiquitin-protein ligase RNF180|RING-type E3 ubiquitin transferase RNF180', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=64165311, end_position_on_the_genomic_accession=64372879, orientation='plus', exon_count=13, OMIM=[616015], no_hdr0=''),
    285672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285672, CurrentID=0, Status='live', Symbol='SREK1IP1', Aliases=['P18SRP', 'SFRS12IP1'], description='SREK1 interacting protein 1', other_designations='protein SREK1IP1|SFRS12-interacting protein 1|p18 splicing regulatory protein|protein SFRS12IP1|splicing regulatory protein of 18 kDa', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=64718148, end_position_on_the_genomic_accession=64768839, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    285676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285676, CurrentID=0, Status='live', Symbol='ZNF454', Aliases=[], description='zinc finger protein 454', other_designations='zinc finger protein 454', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178941198, end_position_on_the_genomic_accession=178966433, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    285704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285704, CurrentID=0, Status='live', Symbol='RGMB', Aliases=['DRAGON'], description='repulsive guidance molecule BMP co-receptor b', other_designations='repulsive guidance molecule B|RGM domain family member B|DRG11-responsive axonal guidance and outgrowth of neurite|RGM domain family, member B|repulsive guidance molecule family member b', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=98768632, end_position_on_the_genomic_accession=98796494, orientation='plus', exon_count=9, OMIM=[612687], no_hdr0=''),
    285753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285753, CurrentID=0, Status='live', Symbol='CEP57L1', Aliases=['C6orf182', 'bA487F23.2', 'cep57R'], description='centrosomal protein 57 like 1', other_designations='centrosomal protein CEP57L1|centrosomal protein 57kDa-like 1|centrosomal protein 57kDa-like protein 1|centrosomal protein of 57 kDa-related protein|cep57-related protein', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109095163, end_position_on_the_genomic_accession=109174418, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    285755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285755, CurrentID=0, Status='live', Symbol='PPIL6', Aliases=['PPIase', 'RSPH12', 'bA425D10.6', 'dJ919F19.1'], description='peptidylprolyl isomerase like 6', other_designations='probable inactive peptidyl-prolyl cis-trans isomerase-like 6|cyclophilin-like protein PPIL6|peptidyl-prolyl cis-trans isomerase-like 6|peptidyl-prolyl cis-trans isomerase-like variant a|peptidylprolyl isomerase (cyclophilin)-like 6|problable inactive peptidyl-prolyl cis-trans isomerase-like 6|radial spoke 12 homolog|rotamase PPIL6', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=109390215, end_position_on_the_genomic_accession=109441171, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    285761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285761, CurrentID=0, Status='live', Symbol='DCBLD1', Aliases=['dJ94G16.1'], description='discoidin, CUB and LCCL domain containing 1', other_designations='discoidin, CUB and LCCL domain-containing protein 1', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=117480351, end_position_on_the_genomic_accession=117569858, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    285782 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285782, CurrentID=0, Status='live', Symbol='CAGE1', Aliases=['CT3', 'CT95', 'CTAG3', 'bA69L16.7'], description='cancer antigen 1', other_designations='cancer-associated gene 1 protein|cancer/testis antigen 3|cancer/testis antigen 95|cancer/testis antigen gene 1', map_location='6p24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=7326659, end_position_on_the_genomic_accession=7389742, orientation='minus', exon_count=15, OMIM=[608304], no_hdr0=''),
    285800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285800, CurrentID=0, Status='live', Symbol='PRR18', Aliases=[], description='proline rich 18', other_designations='proline-rich protein 18|proline rich region 18', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=166305300, end_position_on_the_genomic_accession=166308392, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    285834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285834, CurrentID=0, Status='live', Symbol='HCG22', Aliases=['PBMUCL2'], description='HLA complex group 22 (gene/pseudogene)', other_designations='protein PBMUCL2|HLA complex group 22 (non-protein coding)|panbronchiolitis related mucin-like 2|panbronchiolitis-related mucin-like protein 2', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31053449, end_position_on_the_genomic_accession=31059849, orientation='plus', exon_count=4, OMIM=[613918], no_hdr0=''),
    285848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285848, CurrentID=0, Status='live', Symbol='PNPLA1', Aliases=['ARCI10', 'dJ50J22.1'], description='patatin like phospholipase domain containing 1', other_designations='omega-hydroxyceramide transacylase|patatin-like phospholipase domain-containing protein 1', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36242523, end_position_on_the_genomic_accession=36313955, orientation='plus', exon_count=11, OMIM=[612121], no_hdr0=''),
    285852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285852, CurrentID=0, Status='live', Symbol='TREML4', Aliases=['TLT-4', 'TLT4'], description='triggering receptor expressed on myeloid cells like 4', other_designations='trem-like transcript 4 protein|TREM like transcript 4|triggering receptor expressed on myeloid cells-like protein 4', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41228287, end_position_on_the_genomic_accession=41239386, orientation='plus', exon_count=7, OMIM=[614664], no_hdr0=''),
    285855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285855, CurrentID=0, Status='live', Symbol='RPL7L1', Aliases=['dJ475N16.4'], description='ribosomal protein L7 like 1', other_designations='60S ribosomal protein L7-like 1|large ribosomal subunit protein uL30-like 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42879616, end_position_on_the_genomic_accession=42889900, orientation='plus', exon_count=7, OMIM=[617417], no_hdr0=''),
    285877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285877, CurrentID=0, Status='live', Symbol='POM121L12', Aliases=[], description='POM121 transmembrane nucleoporin like 12', other_designations='POM121-like protein 12|POM121 membrane glycoprotein-like 12', map_location='7p12.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=53035633, end_position_on_the_genomic_accession=53036925, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    285888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285888, CurrentID=0, Status='live', Symbol='CNPY1', Aliases=[], description='canopy FGF signaling regulator 1', other_designations='protein canopy homolog 1|canopy 1 homolog', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=155501129, end_position_on_the_genomic_accession=155546559, orientation='minus', exon_count=9, OMIM=[612493], no_hdr0=''),
    285955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285955, CurrentID=0, Status='live', Symbol='SPDYE1', Aliases=['Ringo1', 'SPDYB2L2', 'SPDYE', 'WBSCR19'], description='speedy/RINGO cell cycle regulator family member E1', other_designations='putative WBSCR19-like protein 6|Speedy E|Williams Beuren syndrome chromosome region 19 protein|speedy homolog E1|speedy protein E1|williams-Beuren syndrome chromosomal region 19 protein', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43997897, end_position_on_the_genomic_accession=44011040, orientation='plus', exon_count=10, OMIM=[617623], no_hdr0=''),
    285966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285966, CurrentID=0, Status='live', Symbol='TCAF2', Aliases=['FAM115C', 'FAM139A', 'GATD9', 'GATD9B'], description='TRPM8 channel associated factor 2', other_designations='TRPM8 channel-associated factor 2|TRP channel-associated factor 2|family with sequence similarity 115, member C|family with sequence similarity 139, member A|protein FAM115C', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143620974, end_position_on_the_genomic_accession=143730410, orientation='plus', exon_count=13, OMIM=[616252], no_hdr0=''),
    285971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285971, CurrentID=0, Status='live', Symbol='ZNF775', Aliases=[], description='zinc finger protein 775', other_designations='zinc finger protein 775', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150379330, end_position_on_the_genomic_accession=150398630, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    285973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285973, CurrentID=0, Status='live', Symbol='ATG9B', Aliases=['APG9L2', 'NOS3AS', 'SONE'], description='autophagy related 9B', other_designations='autophagy-related protein 9B|APG9-like 2|ATG9 autophagy related 9 homolog B|autophagy 9-like 2 protein|endothelial nitric oxide synthase antisense|nitric oxide synthase 3-overlapping antisense gene protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151012209, end_position_on_the_genomic_accession=151028267, orientation='minus', exon_count=23, OMIM=[612205], no_hdr0=''),
    285989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=285989, CurrentID=0, Status='live', Symbol='ZNF789', Aliases=[], description='zinc finger protein 789', other_designations='zinc finger protein 789', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99472819, end_position_on_the_genomic_accession=99487605, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    286006 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286006, CurrentID=0, Status='live', Symbol='LSMEM1', Aliases=['C7orf53'], description='leucine rich single-pass membrane protein 1', other_designations='leucine-rich single-pass membrane protein 1', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=112479542, end_position_on_the_genomic_accession=112491062, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    286046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286046, CurrentID=0, Status='live', Symbol='XKR6', Aliases=['C8orf21', 'C8orf5', 'C8orf7', 'XRG6'], description='XK related 6', other_designations='XK-related protein 6|Transmembrane protein C8orf5|X Kell blood group precursor-related family, member 6|X-linked Kx blood group related 6|XK, Kell blood group complex subunit-related family, member 6', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=10893764, end_position_on_the_genomic_accession=11201833, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    286053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286053, CurrentID=0, Status='live', Symbol='NSMCE2', Aliases=['C8orf36', 'MMS21', 'NSE2', 'ZMIZ7'], description='NSE2 (MMS21) homolog, SMC5-SMC6 complex SUMO ligase', other_designations='E3 SUMO-protein ligase NSE2|E3 SUMO-protein transferase NSE2|NSMCE2/PVT1 fusion|PVT1/NSMCE2 fusion|methyl methanesulfonate sensitivity gene 21|non-SMC element 2, MMS21 homolog|non-structural maintenance of chromosomes element 2 homolog|zinc finger, MIZ-type containing 7', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=125091779, end_position_on_the_genomic_accession=125367125, orientation='plus', exon_count=15, OMIM=[617246], no_hdr0=''),
    286075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286075, CurrentID=0, Status='live', Symbol='ZNF707', Aliases=[], description='zinc finger protein 707', other_designations='zinc finger protein 707', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143684479, end_position_on_the_genomic_accession=143695385, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    286077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286077, CurrentID=0, Status='live', Symbol='FAM83H', Aliases=['AI3', 'AI3A'], description='family with sequence similarity 83 member H', other_designations='protein FAM83H|FAM83H variant 1|FAM83H variant 2|truncated FAM83H', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143723933, end_position_on_the_genomic_accession=143733779, orientation='minus', exon_count=5, OMIM=[611927], no_hdr0=''),
    286097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286097, CurrentID=0, Status='live', Symbol='MICU3', Aliases=['EFHA2'], description='mitochondrial calcium uptake family member 3', other_designations='calcium uptake protein 3, mitochondrial|EF hand domain family A2|EF-hand domain family, member A2|EF-hand domain-containing family member A2|mitochondrial uptake family, member 3', map_location='8p22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=17027238, end_position_on_the_genomic_accession=17133069, orientation='plus', exon_count=20, OMIM=[610633], no_hdr0=''),
    286128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286128, CurrentID=0, Status='live', Symbol='ZFP41', Aliases=['ZNF753', 'zfp-41'], description='ZFP41 zinc finger protein', other_designations='zinc finger protein 41 homolog', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143246939, end_position_on_the_genomic_accession=143262705, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    286133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286133, CurrentID=0, Status='live', Symbol='SCARA5', Aliases=['NET33', 'Tesr'], description='scavenger receptor class A member 5', other_designations='scavenger receptor class A member 5|scavenger receptor class A, member 5 (putative)|scavenger receptor hlg|testis expressed scavenger receptor', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=27869883, end_position_on_the_genomic_accession=27992673, orientation='minus', exon_count=9, OMIM=[611306], no_hdr0=''),
    286144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286144, CurrentID=0, Status='live', Symbol='TRIQK', Aliases=['C8orf83', 'PRO0845', 'UPF0599'], description='triple QxxK/R motif containing', other_designations='triple QxxK/R motif-containing protein|protein TRIQK|triple repetitive-sequence of QXXK/R protein homolog', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=92883530, end_position_on_the_genomic_accession=92966150, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    286148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286148, CurrentID=0, Status='live', Symbol='DPY19L4', Aliases=[], description='dpy-19 like 4', other_designations='probable C-mannosyltransferase DPY19L4|dpy-19-like protein 4|protein dpy-19 homolog 4', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94719708, end_position_on_the_genomic_accession=94793836, orientation='plus', exon_count=20, OMIM=[613895], no_hdr0=''),
    286151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286151, CurrentID=0, Status='live', Symbol='FBXO43', Aliases=['EMI2', 'ERP1', 'FBX43'], description='F-box protein 43', other_designations='F-box only protein 43|early mitotic inhibitor 2|endogenous meiotic inhibitor 2', map_location='8q22.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=100133351, end_position_on_the_genomic_accession=100150569, orientation='minus', exon_count=8, OMIM=[609110], no_hdr0=''),
    286183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286183, CurrentID=0, Status='live', Symbol='NKAIN3', Aliases=['FAM77D-IT1', 'UG0898H09', 'NKAIN3'], description='sodium/potassium transporting ATPase interacting 3', other_designations='sodium/potassium-transporting ATPase subunit beta-1-interacting protein 3|NKAIN3 intronic transcript|Na(+)/K(+)-transporting ATPase subunit beta-1-interacting protein 3|Na+/K+ transporting ATPase interacting 3|family with sequence similarity 77, member D', map_location='8q12.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=62248854, end_position_on_the_genomic_accession=62999652, orientation='plus', exon_count=12, OMIM=[612872], no_hdr0=''),
    286187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286187, CurrentID=0, Status='live', Symbol='PPP1R42', Aliases=['LRRC67', 'TLLR', 'TLRR', 'dtr'], description='protein phosphatase 1 regulatory subunit 42', other_designations='protein phosphatase 1 regulatory subunit 42|leucine rich repeat containing 67|leucine-rich repeat-containing protein 67|testis leucine-rich repeat', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66964103, end_position_on_the_genomic_accession=67028554, orientation='minus', exon_count=9, OMIM=[617720], no_hdr0=''),
    286204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286204, CurrentID=0, Status='live', Symbol='CRB2', Aliases=['FSGS9', 'VMCKD'], description='crumbs cell polarity complex component 2', other_designations='protein crumbs homolog 2|crumbs 2, cell polarity complex component|crumbs family member 2|crumbs-like protein 2', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=123354065, end_position_on_the_genomic_accession=123380326, orientation='plus', exon_count=17, OMIM=[609720], no_hdr0=''),
    286205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286205, CurrentID=0, Status='live', Symbol='SCAI', Aliases=['C9orf126', 'NET40'], description='suppressor of cancer cell invasion', other_designations='protein SCAI|suppressor of cancer cell invasion protein', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124942608, end_position_on_the_genomic_accession=125143528, orientation='minus', exon_count=21, OMIM=[619222], no_hdr0=''),
    286207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286207, CurrentID=0, Status='live', Symbol='CFAP157', Aliases=['C9orf117'], description='cilia and flagella associated protein 157', other_designations='cilia- and flagella-associated protein 157', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127706988, end_position_on_the_genomic_accession=127716002, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    286223 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286223, CurrentID=0, Status='live', Symbol='C9orf47', Aliases=['C9orf108', 'bA791O21.3'], description='chromosome 9 open reading frame 47', other_designations='uncharacterized protein C9orf47', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=88990863, end_position_on_the_genomic_accession=88996142, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    286234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286234, CurrentID=0, Status='live', Symbol='SPATA31E1', Aliases=['C9orf79', 'FAM75E1'], description='SPATA31 subfamily E member 1', other_designations='spermatogenesis-associated protein 31E1|FAM75-like protein C9orf79|XXyac-YM21GA2.5|family with sequence similarity 75, member E1|protein FAM75E1', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=87882877, end_position_on_the_genomic_accession=87888903, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    286256 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286256, CurrentID=0, Status='live', Symbol='LCN12', Aliases=[], description='lipocalin 12', other_designations='epididymal-specific lipocalin-12|epididymis secretory sperm binding protein|lipocalcin 12', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136949180, end_position_on_the_genomic_accession=136955505, orientation='plus', exon_count=10, OMIM=[612905], no_hdr0=''),
    286257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286257, CurrentID=0, Status='live', Symbol='PAXX', Aliases=['C9orf142', 'XLS'], description='PAXX non-homologous end joining factor', other_designations='protein PAXX|XRCC4-like small protein|paralog of XRCC4 and XLF', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136992422, end_position_on_the_genomic_accession=136993976, orientation='plus', exon_count=7, OMIM=[616315], no_hdr0=''),
    286262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286262, CurrentID=0, Status='live', Symbol='TPRN', Aliases=['C9orf75', 'DFNB79'], description='taperin', other_designations='taperin', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137191619, end_position_on_the_genomic_accession=137200741, orientation='minus', exon_count=4, OMIM=[613354], no_hdr0=''),
    286319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286319, CurrentID=0, Status='live', Symbol='TUSC1', Aliases=['CCDC89B', 'TSG-9', 'TSG9'], description='tumor suppressor candidate 1', other_designations='tumor suppressor candidate gene 1 protein', map_location='9p21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=25676969, end_position_on_the_genomic_accession=25678444, orientation='minus', exon_count=1, OMIM=[610529], no_hdr0=''),
    286336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286336, CurrentID=0, Status='live', Symbol='FAM78A', Aliases=['C9orf59'], description='family with sequence similarity 78 member A', other_designations='protein FAM78A', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131258078, end_position_on_the_genomic_accession=131281928, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    286343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286343, CurrentID=0, Status='live', Symbol='LURAP1L', Aliases=['C9orf150', 'HYST0841', 'LRAP35b', 'bA3L8.2'], description='leucine rich adaptor protein 1 like', other_designations='leucine rich adaptor protein 1-like|leucine repeat adaptor protein 35b', map_location='9p23', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=12774994, end_position_on_the_genomic_accession=12823060, orientation='plus', exon_count=3, OMIM=[616130], no_hdr0=''),
    286362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286362, CurrentID=0, Status='live', Symbol='OR13C9', Aliases=['OR37L', 'OR9-13'], description='olfactory receptor family 13 subfamily C member 9', other_designations='olfactory receptor 13C9|olfactory receptor OR9-13', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104617248, end_position_on_the_genomic_accession=104618204, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    286365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286365, CurrentID=0, Status='live', Symbol='OR13D1', Aliases=['OR9-15'], description='olfactory receptor family 13 subfamily D member 1', other_designations='olfactory receptor 13D1|olfactory receptor OR9-15', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104694518, end_position_on_the_genomic_accession=104695462, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    286380 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286380, CurrentID=0, Status='live', Symbol='FOXD4L3', Aliases=['FOXD4B', 'FOXD4L2', 'FOXD4L4', 'FOXD6'], description='forkhead box D4 like 3', other_designations='forkhead box protein D4-like 3|FOXD4-like 2|FOXD4-like 3|FOXD4-like 4|Forkhead box protein D4-like 3|Forkhead box protein D4-like 4|Forkhead box protein D4B|Myeloid factor-gamma|forkhead box protein D4-like 2', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68302867, end_position_on_the_genomic_accession=68305084, orientation='plus', exon_count=1, OMIM=[611086], no_hdr0=''),
    286410 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286410, CurrentID=0, Status='live', Symbol='ATP11C', Aliases=['ATPIG', 'ATPIQ', 'HACXL'], description='ATPase phospholipid transporting 11C', other_designations='phospholipid-transporting ATPase IG|ATPase, class VI, type 11C|P4-ATPase flippase complex alpha subunit ATP11C|probable phospholipid-transporting ATPase IG', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=139726346, end_position_on_the_genomic_accession=139933083, orientation='minus', exon_count=35, OMIM=[300516], no_hdr0=''),
    286430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286430, CurrentID=0, Status='live', Symbol='NLRP2B', Aliases=['CLRX.1', 'NALP2P', 'NLRP2P', 'NOD24', 'POP4'], description='NLR family pyrin domain containing 2B', other_designations='NLR family pyrin domain-containing protein 2B|NLR family and pyrin domain-containing 2 pseudogene|NLR family, pyrin domain containing 2 pseudogene|NOD24 pseudogene|Pyrin domain-containing protein 2-like protein POP4|Pyrin-only protein 4', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57677067, end_position_on_the_genomic_accession=57680260, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    286436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286436, CurrentID=0, Status='live', Symbol='H2BW2', Aliases=['H2BFM', 'H2BM'], description='H2B.W histone 2', other_designations='histone H2B type F-M|H2B histone family member M|H2B.M histone|H2B/s|histone H2B.s', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104039753, end_position_on_the_genomic_accession=104042454, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    286451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286451, CurrentID=0, Status='live', Symbol='YIPF6', Aliases=['FinGER6'], description='Yip1 domain family member 6', other_designations='protein YIPF6|YIP1 family member 6', map_location='Xq12-q13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=68498362, end_position_on_the_genomic_accession=68572459, orientation='plus', exon_count=8, OMIM=[300996], no_hdr0=''),
    286464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286464, CurrentID=0, Status='live', Symbol='CFAP47', Aliases=['CHDC2', 'CXorf22', 'CXorf30', 'CXorf59', 'SPGF52', 'SPGFX3'], description='cilia and flagella associated protein 47', other_designations='cilia- and flagella-associated protein 47|calponin homology domain-containing protein 2', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=35919734, end_position_on_the_genomic_accession=36385317, orientation='plus', exon_count=65, OMIM=[301057], no_hdr0=''),
    286499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286499, CurrentID=0, Status='live', Symbol='FAM133A', Aliases=['CT115'], description='family with sequence similarity 133 member A', other_designations='protein FAM133A|cancer/testis antigen 115', map_location='Xq21.32', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=93673716, end_position_on_the_genomic_accession=93712265, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    286514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286514, CurrentID=0, Status='live', Symbol='MAGEB18', Aliases=[], description='MAGE family member B18', other_designations='melanoma-associated antigen B18|MAGE-B18 antigen|melanoma antigen family B, 18|melanoma antigen family B18', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=26138343, end_position_on_the_genomic_accession=26140736, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    286527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286527, CurrentID=0, Status='live', Symbol='TMSB15B', Aliases=['TMSB15A', 'TMSL8', 'TMSNB', 'Tbeta15b'], description='thymosin beta 15B', other_designations='thymosin beta-15B|NB thymosin beta|Thymosin beta-15A|Thymosin-like protein 8', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103919155, end_position_on_the_genomic_accession=103974426, orientation='plus', exon_count=6, OMIM=[301011], no_hdr0=''),
    286530 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286530, CurrentID=0, Status='live', Symbol='P2RY8', Aliases=['P2Y8'], description='P2Y receptor family member 8', other_designations='P2Y purinoceptor 8|G-protein coupled purinergic receptor P2Y8|purinergic receptor P2Y, G-protein coupled, 8|purinergic receptor P2Y8', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1462576, end_position_on_the_genomic_accession=1537488, orientation='minus', exon_count=6, OMIM=[300525], no_hdr0=''),
    286676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286676, CurrentID=0, Status='live', Symbol='ILDR1', Aliases=['DFNB42alpha', "ILDR1alpha'", 'ILDR1beta', 'ILDR1'], description='immunoglobulin like domain containing receptor 1', other_designations='immunoglobulin-like domain-containing receptor 1|angulin-2|immunoglobulin-like domain-containing receptor 1 alpha|immunoglobulin-like domain-containing receptor 1 beta', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121987323, end_position_on_the_genomic_accession=122060554, orientation='minus', exon_count=9, OMIM=[609739], no_hdr0=''),
    286749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286749, CurrentID=0, Status='live', Symbol='STON1-GTF2A1L', Aliases=['ALF', 'GTF2A1L', 'GTF2A1LF', 'SALF'], description='STON1-GTF2A1L readthrough', other_designations='STON1-GTF2A1L protein|General transcription factor II A, 1-like factor|TFIIA-alpha and beta-like factor|stoned B/TFIIA-alpha/beta-like factor', map_location='2p16.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=48529925, end_position_on_the_genomic_accession=48776519, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    286753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286753, CurrentID=0, Status='live', Symbol='TRARG1', Aliases=['BEC-1', 'DSPB1', 'IFITMD3', 'LOST1', 'TUSC5'], description='trafficking regulator of GLUT4 (SLC2A4) 1', other_designations='trafficking regulator of GLUT4 1|brain endothelial cell derived gene-1|dispanin subfamily B member 1|interferon induced transmembrane protein domain containing 3|interferon-induced transmembrane domain-containing protein D3|located at seventeen p thirteen point three 1|protein located at seventeen-p-thirteen point three 1|tumor suppressor candidate 5', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1279662, end_position_on_the_genomic_accession=1300978, orientation='plus', exon_count=3, OMIM=[612211], no_hdr0=''),
    286826 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286826, CurrentID=0, Status='live', Symbol='LIN9', Aliases=['BARA', 'BARPsv', 'Lin-9', 'TGS', 'TGS1', 'TGS2'], description='lin-9 DREAM MuvB core complex component', other_designations='protein lin-9 homolog|TUDOR gene similar protein|beta subunit-associated regulator of apoptosis|lin-9 homolog|pRB-associated protein|rb related pathway actor|type I interferon receptor beta chain-associated protein', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226231149, end_position_on_the_genomic_accession=226310082, orientation='minus', exon_count=18, OMIM=[609375], no_hdr0=''),
    286827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286827, CurrentID=0, Status='live', Symbol='TRIM59', Aliases=['IFT80L', 'MRF1', 'RNF104', 'TRIM57', 'TSBF1'], description='tripartite motif containing 59', other_designations='tripartite motif-containing protein 59|RING finger protein 104|tripartite motif-containing 57|tumor suppressor TSBF-1|tumor suppressor TSBF1', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160435503, end_position_on_the_genomic_accession=160449786, orientation='minus', exon_count=3, OMIM=[616148], no_hdr0=''),
    286887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=286887, CurrentID=0, Status='live', Symbol='KRT6C', Aliases=['K6E', 'KRT6E', 'PPKNEFD'], description='keratin 6C', other_designations='keratin, type II cytoskeletal 6C|CK-6C|CK-6E|K6C|cytokeratin-6C|cytokeratin-6E|keratin 6C, type II|keratin 6E|keratin K6h|type-II keratin Kb12', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52468516, end_position_on_the_genomic_accession=52473805, orientation='minus', exon_count=9, OMIM=[612315], no_hdr0=''),
    287015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=287015, CurrentID=0, Status='live', Symbol='TRIM42', Aliases=['PPP1R40', 'T4A1'], description='tripartite motif containing 42', other_designations='tripartite motif-containing protein 42|protein phosphatase 1, regulatory subunit 40', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=140678053, end_position_on_the_genomic_accession=140701150, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    317649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317649, CurrentID=0, Status='live', Symbol='EIF4E3', Aliases=['eIF-4E3', 'eIF4E-3'], description='eukaryotic translation initiation factor 4E family member 3', other_designations='eukaryotic translation initiation factor 4E type 3', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=71675414, end_position_on_the_genomic_accession=71754773, orientation='minus', exon_count=13, OMIM=[609896], no_hdr0=''),
    317662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317662, CurrentID=0, Status='live', Symbol='FAM149B1', Aliases=['JBTS36', 'KIAA0974'], description='family with sequence similarity 149 member B1', other_designations='primary cilium assembly protein FAM149B1|protein FAM149B1', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73168090, end_position_on_the_genomic_accession=73244504, orientation='plus', exon_count=17, OMIM=[618413], no_hdr0=''),
    317671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317671, CurrentID=0, Status='live', Symbol='RFESD', Aliases=[], description='Rieske Fe-S domain containing', other_designations='Rieske domain-containing protein', map_location='5q15', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=95646777, end_position_on_the_genomic_accession=95658082, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    317701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317701, CurrentID=0, Status='live', Symbol='VN1R2', Aliases=['V1RL2'], description='vomeronasal 1 receptor 2', other_designations='vomeronasal type-1 receptor 2|G-protein coupled receptor GPCR25|V1R-like 2|V1r-like receptor 2|hGPCR25|pheromone receptor', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53258292, end_position_on_the_genomic_accession=53259602, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    317702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317702, CurrentID=0, Status='live', Symbol='VN1R3', Aliases=['FKSG46', 'V1RL3', 'V1RL3p'], description='vomeronasal 1 receptor 3', other_designations='vomeronasal type-1 receptor 3|V1R-like 3|V1RL3 pseudogene|V1r-like receptor 3|vomeronasal 1 receptor 3 pseudogene|vomeronasal 1 receptor 4 pseudogene', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31807585, end_position_on_the_genomic_accession=31808853, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    317703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317703, CurrentID=0, Status='live', Symbol='VN1R4', Aliases=['V1RL4'], description='vomeronasal 1 receptor 4', other_designations='vomeronasal type-1 receptor 4|CTD-2245F17.9|G-protein coupled receptor GPCR27|V1R-like 4|V1r-like receptor 4|hGPCR27|pheromone receptor', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53264418, end_position_on_the_genomic_accession=53270939, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    317705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317705, CurrentID=0, Status='live', Symbol='VN1R5', Aliases=['V1RL5'], description='vomeronasal 1 receptor 5 (gene/pseudogene)', other_designations='vomeronasal type-1 receptor 5|G-protein coupled receptor GPCR26|V1R-like 5|V1r-like receptor 5|hGPCR26|pheromone receptor', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247256072, end_position_on_the_genomic_accession=247257145, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    317719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317719, CurrentID=0, Status='live', Symbol='KLHL10', Aliases=['SPGF11'], description='kelch like family member 10', other_designations='kelch-like protein 10|testicular tissue protein Li 104', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41835685, end_position_on_the_genomic_accession=41848384, orientation='plus', exon_count=7, OMIM=[608778], no_hdr0=''),
    317749 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317749, CurrentID=0, Status='live', Symbol='DHRS4L2', Aliases=['SDR25C3'], description='dehydrogenase/reductase 4 like 2', other_designations='dehydrogenase/reductase SDR family member 4-like 2|NADPH-dependent retinol dehydrogenase/reductase-like protein 2|dehydrogenase/reductase (SDR family) member 4 like 2|dehydrogenase/reductase (SDR family) member 4 like 2A3|short chain dehydrogenase/reductase family 25C member 3', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23969874, end_position_on_the_genomic_accession=24006408, orientation='plus', exon_count=10, OMIM=[615196], no_hdr0=''),
    317754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317754, CurrentID=0, Status='live', Symbol='POTED', Aliases=['A26B3', 'ANKRD21', 'CT104.1', 'POTE', 'POTE-21', 'POTE21'], description='POTE ankyrin domain family member D', other_designations='POTE ankyrin domain family member D|ANKRD26-like family B member 3|Expressed in prostate, ovary, testis, and placenta|ankyrin repeat domain 21|ankyrin repeat domain-containing protein 21|cancer/testis antigen family 104, member 1|prostate, ovary, testis-expressed protein', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=13609777, end_position_on_the_genomic_accession=13645823, orientation='plus', exon_count=12, OMIM=[607549], no_hdr0=''),
    317761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317761, CurrentID=0, Status='live', Symbol='C14orf39', Aliases=['POF18', 'SPGF52', 'Six6os1'], description='chromosome 14 open reading frame 39', other_designations='protein SIX6OS1|six6 opposite strand transcript 1', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=60435954, end_position_on_the_genomic_accession=60499774, orientation='minus', exon_count=20, OMIM=[617307], no_hdr0=''),
    317762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317762, CurrentID=0, Status='live', Symbol='CCDC85C', Aliases=[], description='coiled-coil domain containing 85C', other_designations='coiled-coil domain-containing protein 85C', map_location='14q32.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=99500190, end_position_on_the_genomic_accession=99604207, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    317772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317772, CurrentID=0, Status='live', Symbol='H2AC21', Aliases=['H2AB', 'HIST2H2AB'], description='H2A clustered histone 21', other_designations='histone H2A type 2-B|histone 2, H2ab|histone cluster 2 H2A family member b|histone cluster 2, H2ab', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149887469, end_position_on_the_genomic_accession=149887965, orientation='minus', exon_count=1, OMIM=[615014], no_hdr0=''),
    317781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=317781, CurrentID=0, Status='live', Symbol='DDX51', Aliases=[], description='DEAD-box helicase 51', other_designations='ATP-dependent RNA helicase DDX51|DEAD (Asp-Glu-Ala-Asp) box polypeptide 51|DEAD box protein 51', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132136594, end_position_on_the_genomic_accession=132144335, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    319089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=319089, CurrentID=0, Status='live', Symbol='TTC6', Aliases=['C14orf25', 'NCRNA00291'], description='tetratricopeptide repeat domain 6', other_designations='tetratricopeptide repeat protein 6|TPR repeat protein 6', map_location='14q21.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=37593159, end_position_on_the_genomic_accession=37842717, orientation='plus', exon_count=41, OMIM=[], no_hdr0=''),
    319100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=319100, CurrentID=0, Status='live', Symbol='TAAR6', Aliases=['TA4', 'TAR4', 'TAR6', 'TRAR4', 'taR-4', 'taR-6'], description='trace amine associated receptor 6', other_designations='trace amine-associated receptor 6|trace amine receptor 4|trace amine receptor 6', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=132570322, end_position_on_the_genomic_accession=132571359, orientation='plus', exon_count=1, OMIM=[608923], no_hdr0=''),
    319101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=319101, CurrentID=0, Status='live', Symbol='KRT73', Aliases=['CK-73', 'IRT6IRS3', 'K6IRS3', 'K73', 'KRT6IRS3'], description='keratin 73', other_designations='keratin, type II cytoskeletal 73|cytokeratin-73|keratin 6 irs3|keratin 73, type II|type II inner root sheath-specific keratin-K6irs3|type-II keratin Kb36', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52601813, end_position_on_the_genomic_accession=52620133, orientation='minus', exon_count=11, OMIM=[608247], no_hdr0=''),
    326340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=326340, CurrentID=0, Status='live', Symbol='ZAR1', Aliases=['Z3CXXC6'], description='zygote arrest 1', other_designations='zygote arrest protein 1|oocyte-specific maternal effect factor|zinc finger, 3CxxC-type 6', map_location='4p11', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=48490252, end_position_on_the_genomic_accession=48499351, orientation='plus', exon_count=5, OMIM=[607520], no_hdr0=''),
    326624 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=326624, CurrentID=0, Status='live', Symbol='RAB37', Aliases=[], description='RAB37, member RAS oncogene family', other_designations='ras-related protein Rab-37|RAB37, member of RAS oncogene family', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74671131, end_position_on_the_genomic_accession=74747335, orientation='plus', exon_count=13, OMIM=[609956], no_hdr0=''),
    326625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=326625, CurrentID=0, Status='live', Symbol='MMAB', Aliases=['ATR', 'CFAP23', 'cblB', 'cob'], description='metabolism of cobalamin associated B', other_designations='corrinoid adenosyltransferase|ATP:cob(I)alamin adenosyltransferase|ATP:corrinoid adenosyltransferase|aquocob(I)alamin vitamin B12s adenosyltransferase|cilia and flagella associated protein 23|cob(I)yrinic acid a,c-diamide adenosyltransferase, mitochondrial|cob(II)alamin adenosyltransferase|cob(II)yrinic acid a,c-diamide adenosyltransferase|cobinamide/cobalamin adenosyltransferase|methylmalonic aciduria (cobalamin deficiency) cblB type|methylmalonic aciduria type B protein', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=109553715, end_position_on_the_genomic_accession=109573580, orientation='minus', exon_count=13, OMIM=[607568], no_hdr0=''),
    327657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=327657, CurrentID=0, Status='live', Symbol='SERPINA9', Aliases=['GCET1', 'SERPINA11', 'SERPINA11b'], description='serpin family A member 9', other_designations='serpin A9|centerin|germinal center B-cell-expressed transcript 1 protein|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 9|serine proteinase inhibitor A11|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 9', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94462721, end_position_on_the_genomic_accession=94476227, orientation='minus', exon_count=6, OMIM=[615677], no_hdr0=''),
    333926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=333926, CurrentID=0, Status='live', Symbol='PPM1J', Aliases=['PP2C-zeta', 'PP2CZ', 'PP2Czeta', 'PPP2CZ'], description='protein phosphatase, Mg2+/Mn2+ dependent 1J', other_designations='protein phosphatase 1J|protein phosphatase 1J (PP2C domain containing)|protein phosphatase 2C zeta', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=112709998, end_position_on_the_genomic_accession=112715332, orientation='minus', exon_count=10, OMIM=[609957], no_hdr0=''),
    333929 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=333929, CurrentID=0, Status='live', Symbol='SNAI3', Aliases=['SMUC', 'SNAIL3', 'ZNF293', 'Zfp293'], description='snail family transcriptional repressor 3', other_designations='zinc finger protein SNAI3|protein snail homolog 3|snail family zinc finger 3|snail homolog 3|zinc finger protein 293', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88677688, end_position_on_the_genomic_accession=88686507, orientation='minus', exon_count=3, OMIM=[612741], no_hdr0=''),
    333932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=333932, CurrentID=0, Status='live', Symbol='H3C15', Aliases=['H3/n', 'H3/o', 'H3C13', 'H3C14', 'HIST2H3A'], description='H3 clustered histone 15', other_designations='histone H3.2|H3-clustered histone 13|H3-clustered histone 14|histone 2, H3a|histone H3/o|histone cluster 2 H3 family member a|histone cluster 2, H3a', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149852608, end_position_on_the_genomic_accession=149853125, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    337867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337867, CurrentID=0, Status='live', Symbol='UBAC2', Aliases=['PHGDHL1'], description='UBA domain containing 2', other_designations='ubiquitin-associated domain-containing protein 2|RP11-178C10.1|UBA domain-containing protein 2|phosphoglycerate dehydrogenase like 1|phosphoglycerate dehydrogenase-like protein 1', map_location='13q32.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=99200425, end_position_on_the_genomic_accession=99386504, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    337876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337876, CurrentID=0, Status='live', Symbol='CHSY3', Aliases=['CHSY2', 'CSS3'], description='chondroitin sulfate synthase 3', other_designations='chondroitin sulfate synthase 3|N-acetylgalactosaminyl-proteoglycan 3-beta-glucuronosyltransferase 3|N-acetylgalactosaminyltransferase 3|carbohydrate synthase 2|chSy-2|chondroitin glucuronyltransferase 3|chondroitin synthase-2|glucuronosyl-N-acetylgalactosaminyl-proteoglycan 4-beta-N-acetylgalactosaminyltransferase II', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=129903384, end_position_on_the_genomic_accession=130186637, orientation='plus', exon_count=8, OMIM=[609963], no_hdr0=''),
    337878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337878, CurrentID=0, Status='live', Symbol='KRTAP7-1', Aliases=['KAP7.1'], description='keratin associated protein 7-1', other_designations='keratin-associated protein 7-1|high tyrosine-glycine keratin-associated protein 7.1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30829039, end_position_on_the_genomic_accession=30829759, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337879, CurrentID=0, Status='live', Symbol='KRTAP8-1', Aliases=['KAP8.1'], description='keratin associated protein 8-1', other_designations='keratin-associated protein 8-1|high glycine-tyrosine keratin-associated protein 8.1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30812697, end_position_on_the_genomic_accession=30813274, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337880, CurrentID=0, Status='live', Symbol='KRTAP11-1', Aliases=['HACL-1', 'HACL1', 'KAP11.1'], description='keratin associated protein 11-1', other_designations='keratin-associated protein 11-1|high sulfur keratin-associated protein 11.1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30880644, end_position_on_the_genomic_accession=30881580, orientation='minus', exon_count=1, OMIM=[600064], no_hdr0=''),
    337882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337882, CurrentID=0, Status='live', Symbol='KRTAP19-1', Aliases=['KAP19.1'], description='keratin associated protein 19-1', other_designations='keratin-associated protein 19-1|high tyrosine-glycine keratin-associated protein 19.1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30479706, end_position_on_the_genomic_accession=30480367, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337959 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337959, CurrentID=0, Status='live', Symbol='KRTAP13-2', Aliases=['KAP13-2'], description='keratin associated protein 13-2', other_designations='keratin-associated protein 13-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30371390, end_position_on_the_genomic_accession=30372271, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337960, CurrentID=0, Status='live', Symbol='KRTAP13-3', Aliases=['KAP13.3'], description='keratin associated protein 13-3', other_designations='keratin-associated protein 13-3', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30425380, end_position_on_the_genomic_accession=30425926, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337963, CurrentID=0, Status='live', Symbol='KRTAP23-1', Aliases=['KAP23.1'], description='keratin associated protein 23-1', other_designations='keratin-associated protein 23-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30348399, end_position_on_the_genomic_accession=30348606, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337966, CurrentID=0, Status='live', Symbol='KRTAP6-1', Aliases=['C21orf103', 'KAP6.1'], description='keratin associated protein 6-1', other_designations='keratin-associated protein 6-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30613686, end_position_on_the_genomic_accession=30613904, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337967, CurrentID=0, Status='live', Symbol='KRTAP6-2', Aliases=['KAP6.2'], description='keratin associated protein 6-2', other_designations='keratin-associated protein 6-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30598686, end_position_on_the_genomic_accession=30598874, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337968, CurrentID=0, Status='live', Symbol='KRTAP6-3', Aliases=['KAP6.3'], description='keratin associated protein 6-3', other_designations='keratin-associated protein 6-3', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30592440, end_position_on_the_genomic_accession=30593075, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    337969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337969, CurrentID=0, Status='live', Symbol='KRTAP19-2', Aliases=['KAP19.2'], description='keratin associated protein 19-2', other_designations='keratin-associated protein 19-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30487043, end_position_on_the_genomic_accession=30487436, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337970 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337970, CurrentID=0, Status='live', Symbol='KRTAP19-3', Aliases=['GTRHP', 'KAP19.3'], description='keratin associated protein 19-3', other_designations='keratin-associated protein 19-3|GTHRP|glycine/tyrosine-rich protein', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30491462, end_position_on_the_genomic_accession=30492013, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337971, CurrentID=0, Status='live', Symbol='KRTAP19-4', Aliases=['KAP19.4'], description='keratin associated protein 19-4', other_designations='keratin-associated protein 19-4', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30496824, end_position_on_the_genomic_accession=30497165, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337972 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337972, CurrentID=0, Status='live', Symbol='KRTAP19-5', Aliases=['KAP19.5'], description='keratin associated protein 19-5', other_designations='keratin-associated protein 19-5', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30501657, end_position_on_the_genomic_accession=30502141, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337973, CurrentID=0, Status='live', Symbol='KRTAP19-6', Aliases=['KAP19.6'], description='keratin associated protein 19-6', other_designations='keratin-associated protein 19-6', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30541535, end_position_on_the_genomic_accession=30541864, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337974, CurrentID=0, Status='live', Symbol='KRTAP19-7', Aliases=['KAP19.7'], description='keratin associated protein 19-7', other_designations='keratin-associated protein 19-7', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30560875, end_position_on_the_genomic_accession=30561314, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337975 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337975, CurrentID=0, Status='live', Symbol='KRTAP20-1', Aliases=['KAP20.1'], description='keratin associated protein 20-1', other_designations='keratin-associated protein 20-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30616425, end_position_on_the_genomic_accession=30616699, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    337976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337976, CurrentID=0, Status='live', Symbol='KRTAP20-2', Aliases=['KAP20.2'], description='keratin associated protein 20-2', other_designations='keratin-associated protein 20-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30635206, end_position_on_the_genomic_accession=30635619, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    337977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337977, CurrentID=0, Status='live', Symbol='KRTAP21-1', Aliases=['KAP21.1'], description='keratin associated protein 21-1', other_designations='keratin-associated protein 21-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30755015, end_position_on_the_genomic_accession=30755428, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337978, CurrentID=0, Status='live', Symbol='KRTAP21-2', Aliases=['KAP21.2'], description='keratin associated protein 21-2', other_designations='keratin-associated protein 21-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30746794, end_position_on_the_genomic_accession=30747259, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    337979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337979, CurrentID=0, Status='live', Symbol='KRTAP22-1', Aliases=['KAP22.1'], description='keratin associated protein 22-1', other_designations='keratin-associated protein 22-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30601087, end_position_on_the_genomic_accession=30601382, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    337985 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=337985, CurrentID=0, Status='live', Symbol='KRTAP20-3', Aliases=['KAP19D', 'KAP20.3', 'KRTAP19P4'], description='keratin associated protein 20-3', other_designations='keratin-associated protein 20-3|keratin associated protein 19 pseudogene 4', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30642864, end_position_on_the_genomic_accession=30643136, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    338094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338094, CurrentID=0, Status='live', Symbol='FAM151A', Aliases=['C1orf179'], description='family with sequence similarity 151 member A', other_designations='protein FAM151A|hyporthetical protein MGC27169', map_location='', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54609180, end_position_on_the_genomic_accession=54623527, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    338321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338321, CurrentID=0, Status='live', Symbol='NLRP9', Aliases=['CLR19.1', 'NALP9', 'NOD6', 'PAN12'], description='NLR family pyrin domain containing 9', other_designations='NACHT, LRR and PYD domains-containing protein 9|NACHT, LRR and PYD containing protein 9|NACHT, leucine rich repeat and PYD containing 9|PYRIN and NACHT-containing protein 12|nucleotide-binding oligomerization domain protein 6|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 9', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55708438, end_position_on_the_genomic_accession=55738402, orientation='minus', exon_count=11, OMIM=[609663], no_hdr0=''),
    338322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338322, CurrentID=0, Status='live', Symbol='NLRP10', Aliases=['CLR11.1', 'NALP10', 'NOD8', 'PAN5', 'PYNOD'], description='NLR family pyrin domain containing 10', other_designations='NACHT, LRR and PYD domains-containing protein 10|NACHT, leucine rich repeat and PYD containing 10|nucleotide-binding oligomerization domain protein 8|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 10', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7957537, end_position_on_the_genomic_accession=7965447, orientation='minus', exon_count=3, OMIM=[609662], no_hdr0=''),
    338323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338323, CurrentID=0, Status='live', Symbol='NLRP14', Aliases=['CLR11.2', 'GC-LRR', 'NALP14', 'NOD5', 'PAN8'], description='NLR family pyrin domain containing 14', other_designations='NACHT, LRR and PYD domains-containing protein 14|NACHT, LRR and PYD containing protein 14|NACHT, leucine rich repeat and PYD containing 14|nucleotide-binding oligomerization domain protein 5|nucleotide-binding oligomerization domain, leucine rich repeat and pyrin domain containing 14', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7020446, end_position_on_the_genomic_accession=7089025, orientation='plus', exon_count=13, OMIM=[609665], no_hdr0=''),
    338324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338324, CurrentID=0, Status='live', Symbol='S100A7A', Aliases=['NICE-2', 'NICE2', 'S100A15', 'S100A7L1', 'S100A7f'], description='S100 calcium binding protein A7A', other_designations='protein S100-A7A|S100 calcium-binding protein A15|S100 calcium-binding protein A7-like 1|koebnerisin', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153416520, end_position_on_the_genomic_accession=153423222, orientation='plus', exon_count=3, OMIM=[617427], no_hdr0=''),
    338328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338328, CurrentID=0, Status='live', Symbol='GPIHBP1', Aliases=['GPI-HBP1', 'HYPL1D'], description='glycosylphosphatidylinositol anchored high density lipoprotein binding protein 1', other_designations='glycosylphosphatidylinositol-anchored high density lipoprotein-binding protein 1|GPI anchored high density lipoprotein binding protein 1|GPI-anchored HDL-binding protein 1|endothelial cell LPL transporter', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143213218, end_position_on_the_genomic_accession=143217170, orientation='plus', exon_count=4, OMIM=[612757], no_hdr0=''),
    338339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338339, CurrentID=0, Status='live', Symbol='CLEC4D', Aliases=['CD368', 'CLEC-6', 'CLEC6', 'CLECSF8', 'Dectin-3', 'MCL', 'MPCL'], description='C-type lectin domain family 4 member D', other_designations='C-type lectin domain family 4 member D|C-type (calcium dependent, carbohydrate-recognition domain) lectin, superfamily member 8|C-type lectin receptor|C-type lectin superfamily member 8|C-type lectin-like receptor 6|DC-associated C-type lectin 3|Dectin 3|dendritic cell-associated C-type lectin 3|macrophage C-type lectin', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8513492, end_position_on_the_genomic_accession=8522366, orientation='plus', exon_count=7, OMIM=[609964], no_hdr0=''),
    338376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338376, CurrentID=0, Status='live', Symbol='IFNE', Aliases=['IFN-E1', 'IFNT1', 'INFE1', 'PRO655', 'IFNE'], description='interferon epsilon', other_designations='interferon epsilon|IFN-epsilon|interferon epsilon 1|interferon tau-1', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=21480839, end_position_on_the_genomic_accession=21482313, orientation='minus', exon_count=1, OMIM=[615223], no_hdr0=''),
    338382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338382, CurrentID=0, Status='live', Symbol='RAB7B', Aliases=['RAB7'], description='RAB7B, member RAS oncogene family', other_designations='ras-related protein Rab-7b|Ras-related protein Rab-7', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205976740, end_position_on_the_genomic_accession=206003470, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    338398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338398, CurrentID=0, Status='live', Symbol='TAS2R60', Aliases=['T2R56', 'T2R60'], description='taste 2 receptor member 60', other_designations='taste receptor type 2 member 60|taste receptor type 2 member 56|taste receptor, type 2, member 60', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143443453, end_position_on_the_genomic_accession=143444409, orientation='plus', exon_count=1, OMIM=[613968], no_hdr0=''),
    338440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338440, CurrentID=0, Status='live', Symbol='ANO9', Aliases=['PIG5', 'TMEM16J', 'TP53I5'], description='anoctamin 9', other_designations='anoctamin-9|p53-induced gene 5 protein|transmembrane protein 16J|tumor protein p53-inducible protein 5', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=417934, end_position_on_the_genomic_accession=442011, orientation='minus', exon_count=26, OMIM=[], no_hdr0=''),
    338442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338442, CurrentID=0, Status='live', Symbol='HCAR2', Aliases=['GPR109A', 'HCA2', 'HM74a', 'HM74b', 'NIACR1', 'PUMAG', 'Puma-g'], description='hydroxycarboxylic acid receptor 2', other_designations='hydroxycarboxylic acid receptor 2|G protein-coupled receptor HM74a|G-protein coupled receptor 109A|G-protein coupled receptor HM74A|hydroxy-carboxylic acid receptor 2|niacin receptor 1|nicotinic acid receptor', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122701293, end_position_on_the_genomic_accession=122703357, orientation='minus', exon_count=1, OMIM=[609163], no_hdr0=''),
    338557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338557, CurrentID=0, Status='live', Symbol='FFAR4', Aliases=['BMIQ10', 'GPR120', 'GPR129', 'GT01', 'O3FAR1', 'PGR4'], description='free fatty acid receptor 4', other_designations='free fatty acid receptor 4|G-protein coupled receptor 120|G-protein coupled receptor 129|G-protein coupled receptor GT01|G-protein coupled receptor PGR4|omega-3 fatty acid receptor 1', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93566178, end_position_on_the_genomic_accession=93590072, orientation='plus', exon_count=4, OMIM=[609044], no_hdr0=''),
    338567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338567, CurrentID=0, Status='live', Symbol='KCNK18', Aliases=['K2p18.1', 'MGR13', 'TRESK', 'TRESK-2', 'TRESK2', 'TRIK'], description='potassium two pore domain channel subfamily K member 18', other_designations='potassium channel subfamily K member 18|TWIK-related individual K+ channel|TWIK-related individual potassium channel|TWIK-related spinal cord K+ channel|TWIK-related spinal cord potassium channel|potassium channel, subfamily K, member 18|potassium channel, two pore domain subfamily K, member 18', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=117197489, end_position_on_the_genomic_accession=117210299, orientation='plus', exon_count=3, OMIM=[613655], no_hdr0=''),
    338596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338596, CurrentID=0, Status='live', Symbol='ST8SIA6', Aliases=['SIA8F', 'SIAT8-F', 'SIAT8F', 'ST8SIA-VI', 'ST8SiaVI'], description='ST8 alpha-N-acetyl-neuraminide alpha-2,8-sialyltransferase 6', other_designations='alpha-2,8-sialyltransferase 8F|ST8 alpha-N-acetylneuraminate alpha-2,8-sialyltransferase 6|sialyltransferase 8F (alpha-2, 8-sialyltransferase)|sialyltransferase St8Sia VI', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17315414, end_position_on_the_genomic_accession=17455966, orientation='minus', exon_count=12, OMIM=[610139], no_hdr0=''),
    338599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338599, CurrentID=0, Status='live', Symbol='DUSP29', Aliases=['DUPD1', 'DUSP27', 'FMDSP'], description='dual specificity phosphatase 29', other_designations='dual specificity phosphatase 29|atypical dual-specific protein phosphatase|dual specificity phosphatase 27|dual specificity phosphatase DUPD1|dual specificity phosphatase and pro isomerase domain containing 1', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=75026427, end_position_on_the_genomic_accession=75073827, orientation='minus', exon_count=7, OMIM=[618574], no_hdr0=''),
    338645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338645, CurrentID=0, Status='live', Symbol='LUZP2', Aliases=['KFSP2566', 'PRO6246'], description='leucine zipper protein 2', other_designations='leucine zipper protein 2', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=24496488, end_position_on_the_genomic_accession=25082638, orientation='plus', exon_count=15, OMIM=[608178], no_hdr0=''),
    338657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338657, CurrentID=0, Status='live', Symbol='CENATAC', Aliases=['CCDC84', 'DLNB14'], description='centrosomal AT-AC splicing factor', other_designations='centrosomal AT-AC splicing factor|coiled-coil domain containing 84|coiled-coil domain-containing protein 84', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118998138, end_position_on_the_genomic_accession=119015793, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    338661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338661, CurrentID=0, Status='live', Symbol='TMEM225', Aliases=['PMP22CD', 'PPP1R154', 'SPATA47'], description='transmembrane protein 225', other_designations='transmembrane protein 225|PMP22 claudin domain-containing protein|protein phosphatase 1, regulatory subunit 154|spermatogenesis associated 47', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123882920, end_position_on_the_genomic_accession=123885923, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    338662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338662, CurrentID=0, Status='live', Symbol='OR8D4', Aliases=['OR11-275'], description='olfactory receptor family 8 subfamily D member 4', other_designations='olfactory receptor 8D4|olfactory receptor OR11-275', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123902167, end_position_on_the_genomic_accession=123909229, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    338667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338667, CurrentID=0, Status='live', Symbol='VSIG10L2', Aliases=[], description='V-set and immunoglobulin domain containing 10 like 2', other_designations='V-set and immunoglobulin domain-containing protein 10-like 2', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125946044, end_position_on_the_genomic_accession=125956319, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    338674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338674, CurrentID=0, Status='live', Symbol='OR5F1', Aliases=['OR11-10'], description='olfactory receptor family 5 subfamily F member 1', other_designations='olfactory receptor 5F1|olfactory receptor 11-10|olfactory receptor OR11-167', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55993681, end_position_on_the_genomic_accession=55994625, orientation='minus', exon_count=1, OMIM=[608492], no_hdr0=''),
    338675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338675, CurrentID=0, Status='live', Symbol='OR5AP2', Aliases=['OR9J1'], description='olfactory receptor family 5 subfamily AP member 2', other_designations='olfactory receptor 5AP2|olfactory receptor, family 9, subfamily J, member 1', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56641489, end_position_on_the_genomic_accession=56642439, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    338692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338692, CurrentID=0, Status='live', Symbol='ANKRD13D', Aliases=[], description='ankyrin repeat domain 13D', other_designations='ankyrin repeat domain-containing protein 13D|ankyrin repeat domain 13 family, member D', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67289303, end_position_on_the_genomic_accession=67302484, orientation='plus', exon_count=16, OMIM=[615126], no_hdr0=''),
    338699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338699, CurrentID=0, Status='live', Symbol='ANKRD42', Aliases=['PPP1R79', 'SARP'], description='ankyrin repeat domain 42', other_designations='ankyrin repeat domain-containing protein 42|protein phosphatase 1, regulatory subunit 79|several ankyrin repeat protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=83193712, end_position_on_the_genomic_accession=83256099, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    338707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338707, CurrentID=0, Status='live', Symbol='B4GALNT4', Aliases=[], description='beta-1,4-N-acetyl-galactosaminyltransferase 4', other_designations='N-acetyl-beta-glucosaminyl-glycoprotein 4-beta-N-acetylgalactosaminyltransferase 1|N-acetyl-beta-glucosaminyl-glycoprotein 4-beta-N- acetylgalactosaminyltransferase|NGalNAc-T1|beta-1,4-N-acetyl-galactosaminyl transferase 4|beta-1,4-N-acetylgalactosaminyltransferase IV|beta1,4-N-acetylgalactosaminyltransferases IV|beta4GalNAc-T4|beta4GalNAcT4|betaGT4', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=369499, end_position_on_the_genomic_accession=382117, orientation='plus', exon_count=21, OMIM=[618560], no_hdr0=''),
    338751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338751, CurrentID=0, Status='live', Symbol='OR52L1', Aliases=['OR11-50'], description='olfactory receptor family 52 subfamily L member 1', other_designations='olfactory receptor 52L1|olfactory receptor OR11-50', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5985892, end_position_on_the_genomic_accession=5986985, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    338755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338755, CurrentID=0, Status='live', Symbol='OR2AG2', Aliases=['OR11-76P', 'OR2AG2'], description='olfactory receptor family 2 subfamily AG member 2', other_designations='olfactory receptor 2AG2|olfactory receptor OR11-76 pseudogene|olfactory receptor, family 2, subfamily AG, member 2 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6765626, end_position_on_the_genomic_accession=6771976, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    338761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338761, CurrentID=0, Status='live', Symbol='C1QL4', Aliases=['C1QTNF11', 'CTRP11'], description='complement C1q like 4', other_designations='complement C1q-like protein 4|C1q and tumor necrosis factor-related protein 11|C1q/TNF-related protein 11|complement component 1, q subcomponent like 4', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=49332409, end_position_on_the_genomic_accession=49337195, orientation='minus', exon_count=3, OMIM=[615229], no_hdr0=''),
    338773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338773, CurrentID=0, Status='live', Symbol='TMEM119', Aliases=['OBIF'], description='transmembrane protein 119', other_designations='transmembrane protein 119|osteoblast induction factor', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=108589846, end_position_on_the_genomic_accession=108598099, orientation='minus', exon_count=3, OMIM=[618989], no_hdr0=''),
    338785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338785, CurrentID=0, Status='live', Symbol='KRT79', Aliases=['K6L', 'KRT6L'], description='keratin 79', other_designations='keratin, type II cytoskeletal 79|CK-79|K79|cytokeratin-79|keratin 6L|keratin 79, type II|type-II keratin Kb38', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52821408, end_position_on_the_genomic_accession=52834311, orientation='minus', exon_count=9, OMIM=[611160], no_hdr0=''),
    338811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338811, CurrentID=0, Status='live', Symbol='TAFA2', Aliases=['FAM19A2', 'TAFA-2'], description='TAFA chemokine like family member 2', other_designations='chemokine-like protein TAFA-2|family with sequence similarity 19 (chemokine (C-C motif)-like), member A2|family with sequence similarity 19 member A2, C-C motif chemokine like|protein FAM19A2', map_location='12q14.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=61708273, end_position_on_the_genomic_accession=62260104, orientation='minus', exon_count=12, OMIM=[617496], no_hdr0=''),
    338872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338872, CurrentID=0, Status='live', Symbol='C1QTNF9', Aliases=['AQL1A', 'CTRP9', 'C1QTNF9'], description='C1q and TNF related 9', other_designations='complement C1q and tumor necrosis factor-related protein 9A|C1q and tumor necrosis factor related protein 9|complement C1q and tumor necrosis factor-related protein 9|complement C1q tumor necrosis factor-related protein 9|complement C1q tumor necrosis factor-related protein 9A', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24307166, end_position_on_the_genomic_accession=24322531, orientation='plus', exon_count=6, OMIM=[614285], no_hdr0=''),
    338879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338879, CurrentID=0, Status='live', Symbol='RNASE10', Aliases=['RAH1', 'RNASE9'], description='ribonuclease A family member 10 (inactive)', other_designations='inactive ribonuclease-like protein 10|ribonuclease A H1|ribonuclease, RNase A family, 10 (non-active)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20504233, end_position_on_the_genomic_accession=20513884, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    338917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338917, CurrentID=0, Status='live', Symbol='VSX2', Aliases=['CHX10', 'HOX10', 'MCOP2', 'MCOPCB3', 'RET1'], description='visual system homeobox 2', other_designations='visual system homeobox 2|ceh-10 homeo domain containing homolog|ceh-10 homeodomain-containing homolog|homeobox protein CHX10', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74239449, end_position_on_the_genomic_accession=74262738, orientation='plus', exon_count=5, OMIM=[142993], no_hdr0=''),
    338949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=338949, CurrentID=0, Status='live', Symbol='TMEM202', Aliases=[], description='transmembrane protein 202', other_designations='transmembrane protein 202', map_location='15q23-q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72398296, end_position_on_the_genomic_accession=72408367, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    339105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339105, CurrentID=0, Status='live', Symbol='PRSS53', Aliases=['POL3S', 'UNQ308'], description='serine protease 53', other_designations='serine protease 53|EDTP308|polyserase-3|polyserine protease 3|protease, serine 53', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31083424, end_position_on_the_genomic_accession=31089652, orientation='minus', exon_count=11, OMIM=[610561], no_hdr0=''),
    339122 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339122, CurrentID=0, Status='live', Symbol='RAB43', Aliases=['RAB11B', 'RAB41'], description='RAB43, member RAS oncogene family', other_designations='ras-related protein Rab-43|ras-related protein Rab-41', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129087569, end_position_on_the_genomic_accession=129122150, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    339123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339123, CurrentID=0, Status='live', Symbol='JMJD8', Aliases=['C16orf20', 'PP14397'], description='jumonji domain containing 8', other_designations='jmjC domain-containing protein 8|jumonji domain-containing protein 8', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=681670, end_position_on_the_genomic_accession=684334, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    339145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339145, CurrentID=0, Status='live', Symbol='CIBAR2', Aliases=['FAM92B'], description='CBY1 interacting BAR domain containing 2', other_designations='CBY1-interacting BAR domain-containing protein 2|family with sequence similarity 92 member B|protein FAM92B', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85098358, end_position_on_the_genomic_accession=85112508, orientation='minus', exon_count=10, OMIM=[617274], no_hdr0=''),
    339168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339168, CurrentID=0, Status='live', Symbol='TMEM95', Aliases=['UNQ9390'], description='transmembrane protein 95', other_designations='sperm-egg fusion protein TMEM95', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7354968, end_position_on_the_genomic_accession=7357219, orientation='plus', exon_count=8, OMIM=[617814], no_hdr0=''),
    339175 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339175, CurrentID=0, Status='live', Symbol='METTL2A', Aliases=['METTL2'], description='methyltransferase 2A, methylcytidine', other_designations='tRNA N(3)-methylcytidine methyltransferase METTL2A|methyltransferase like 2A|methyltransferase-like protein 2A', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=62423876, end_position_on_the_genomic_accession=62453385, orientation='plus', exon_count=9, OMIM=[618902], no_hdr0=''),
    339210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339210, CurrentID=0, Status='live', Symbol='C17orf67', Aliases=[], description='chromosome 17 open reading frame 67', other_designations='uncharacterized protein C17orf67', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=56791913, end_position_on_the_genomic_accession=56833920, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    339221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339221, CurrentID=0, Status='live', Symbol='ENPP7', Aliases=['ALK-SMase', 'E-NPP 7', 'NPP-7', 'NPP7'], description='ectonucleotide pyrophosphatase/phosphodiesterase 7', other_designations='ectonucleotide pyrophosphatase/phosphodiesterase family member 7|alkaline sphingomyelin phosphodiesterase|alkaline sphingomyelinase|intestinal alkaline sphingomyelinase', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=79730919, end_position_on_the_genomic_accession=79742926, orientation='plus', exon_count=6, OMIM=[616997], no_hdr0=''),
    339229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339229, CurrentID=0, Status='live', Symbol='OXLD1', Aliases=['C17orf90'], description='oxidoreductase like domain containing 1', other_designations='oxidoreductase-like domain-containing protein 1', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81665036, end_position_on_the_genomic_accession=81666605, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    339230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339230, CurrentID=0, Status='live', Symbol='CCDC137', Aliases=['RaRF'], description='coiled-coil domain containing 137', other_designations='coiled-coil domain-containing protein 137|hepatocellular carcinoma related protein 2|retinoic acid resistance factor', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81666697, end_position_on_the_genomic_accession=81673907, orientation='plus', exon_count=8, OMIM=[614271], no_hdr0=''),
    339231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339231, CurrentID=0, Status='live', Symbol='ARL16', Aliases=[], description='ADP ribosylation factor like GTPase 16', other_designations='ADP-ribosylation factor-like protein 16', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81681165, end_position_on_the_genomic_accession=81683797, orientation='minus', exon_count=5, OMIM=[619117], no_hdr0=''),
    339287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339287, CurrentID=0, Status='live', Symbol='MSL1', Aliases=['MSL-1'], description='MSL complex subunit 1', other_designations='male-specific lethal 1 homolog|MSL1-like 1|male specific lethal 1 homolog|male-specific lethal 1-like 1|male-specific lethal-1 homolog 1', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40121971, end_position_on_the_genomic_accession=40136917, orientation='plus', exon_count=9, OMIM=[614801], no_hdr0=''),
    339291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339291, CurrentID=0, Status='live', Symbol='LRRC30', Aliases=[], description='leucine rich repeat containing 30', other_designations='leucine-rich repeat-containing protein 30', map_location='18p11.23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=7231089, end_position_on_the_genomic_accession=7232044, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    339302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339302, CurrentID=0, Status='live', Symbol='CPLX4', Aliases=['CPX-IV', 'CPXIV'], description='complexin 4', other_designations='complexin-4|CPX IV|complexin IV', map_location='18q21.32', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=59295402, end_position_on_the_genomic_accession=59318649, orientation='minus', exon_count=3, OMIM=[609586], no_hdr0=''),
    339318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339318, CurrentID=0, Status='live', Symbol='ZNF181', Aliases=['HHZ181'], description='zinc finger protein 181', other_designations='zinc finger protein 181', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=34734194, end_position_on_the_genomic_accession=34746483, orientation='plus', exon_count=6, OMIM=[606741], no_hdr0=''),
    339324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339324, CurrentID=0, Status='live', Symbol='ZNF260', Aliases=['OZRF1', 'PEX1', 'ZFP260'], description='zinc finger protein 260', other_designations='zinc finger protein 260|zfp-260', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36510687, end_position_on_the_genomic_accession=36528271, orientation='minus', exon_count=6, OMIM=[613749], no_hdr0=''),
    339327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339327, CurrentID=0, Status='live', Symbol='ZNF546', Aliases=['ZNF49'], description='zinc finger protein 546', other_designations='zinc finger protein 546|CTC-471F3.6|zinc finger protein 49', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39997060, end_position_on_the_genomic_accession=40021038, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    339344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339344, CurrentID=0, Status='live', Symbol='MYPOP', Aliases=['P42pop'], description='Myb related transcription factor, partner of profilin', other_designations='myb-related transcription factor, partner of profilin|myb-related protein p42POP|p42 Myb-related transcription factor, partner of profilin', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45890020, end_position_on_the_genomic_accession=45902619, orientation='minus', exon_count=4, OMIM=[617861], no_hdr0=''),
    339345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339345, CurrentID=0, Status='live', Symbol='NANOS2', Aliases=['NOS2', 'ZC2HC12B'], description='nanos C2HC-type zinc finger 2', other_designations='nanos homolog 2|NOS-2', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45913214, end_position_on_the_genomic_accession=45914778, orientation='minus', exon_count=1, OMIM=[608228], no_hdr0=''),
    339366 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339366, CurrentID=0, Status='live', Symbol='ADAMTSL5', Aliases=['THSD6'], description='ADAMTS like 5', other_designations='ADAMTS-like protein 5|ADAMTSL-5|thrombospondin type-1 domain-containing protein 6|thrombospondin, type I, domain containing 6', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1505018, end_position_on_the_genomic_accession=1513038, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    339390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339390, CurrentID=0, Status='live', Symbol='CLEC4G', Aliases=['DTTR431', 'LP2698', 'LSECtin', 'UNQ431'], description='C-type lectin domain family 4 member G', other_designations='C-type lectin domain family 4 member G|C-type lectin superfamily 4, member G|liver and lymph node sinusoidal endothelial cell C-type lectin', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7728957, end_position_on_the_genomic_accession=7732110, orientation='minus', exon_count=9, OMIM=[616256], no_hdr0=''),
    339398 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339398, CurrentID=0, Status='live', Symbol='LINGO4', Aliases=['DAAT9248', 'LRRN6D', 'PRO34002'], description='leucine rich repeat and Ig domain containing 4', other_designations='leucine-rich repeat and immunoglobulin-like domain-containing nogo receptor-interacting protein 4|leucine-rich repeat neuronal protein 6D', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151800264, end_position_on_the_genomic_accession=151805419, orientation='minus', exon_count=2, OMIM=[609794], no_hdr0=''),
    339403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339403, CurrentID=0, Status='live', Symbol='RXFP4', Aliases=['GPCR142', 'GPR100', 'RLN3R2', 'RXFPR4'], description='relaxin family peptide/INSL5 receptor 4', other_designations='relaxin-3 receptor 2|G protein-coupled receptor 100|G-protein coupled receptor GPCR142|RLN3 receptor 2|insulin-like peptide INSL5 receptor|relaxin family peptide receptor 4|relaxin/insulin like family peptide receptor 4', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=155941638, end_position_on_the_genomic_accession=155943087, orientation='plus', exon_count=1, OMIM=[609043], no_hdr0=''),
    339416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339416, CurrentID=0, Status='live', Symbol='ANKRD45', Aliases=['CT117'], description='ankyrin repeat domain 45', other_designations='ankyrin repeat domain-containing protein 45|cancer/testis antigen 117', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173608336, end_position_on_the_genomic_accession=173705430, orientation='minus', exon_count=15, OMIM=[618712], no_hdr0=''),
    339448 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339448, CurrentID=0, Status='live', Symbol='C1orf174', Aliases=[], description='chromosome 1 open reading frame 174', other_designations='UPF0688 protein C1orf174|RP13-531C17.2', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3889133, end_position_on_the_genomic_accession=3900293, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    339451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339451, CurrentID=0, Status='live', Symbol='KLHL17', Aliases=['AF'], description='kelch like family member 17', other_designations='kelch-like protein 17|actinfilin|kelch-like 17', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=960103, end_position_on_the_genomic_accession=965719, orientation='plus', exon_count=12, OMIM=[619262], no_hdr0=''),
    339453 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339453, CurrentID=0, Status='live', Symbol='TMEM240', Aliases=['C1orf70', 'SCA21'], description='transmembrane protein 240', other_designations='transmembrane protein 240|transmembrane protein C1orf70', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1534778, end_position_on_the_genomic_accession=1540624, orientation='minus', exon_count=4, OMIM=[616101], no_hdr0=''),
    339456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339456, CurrentID=0, Status='live', Symbol='TMEM52', Aliases=[], description='transmembrane protein 52', other_designations='transmembrane protein 52', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1917591, end_position_on_the_genomic_accession=1919279, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    339479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339479, CurrentID=0, Status='live', Symbol='BRINP3', Aliases=['DBCCR1L', 'DBCCR1L1', 'FAM5C'], description='BMP/retinoic acid inducible neural specific 3', other_designations='BMP/retinoic acid-inducible neural-specific protein 3|DBCCR1-like protein 1|bone morphogenetic protein/retinoic acid inducible neural-specific 3|family with sequence similarity 5, member C|protein FAM5C', map_location='1q31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=190097658, end_position_on_the_genomic_accession=190477997, orientation='minus', exon_count=15, OMIM=[618390], no_hdr0=''),
    339487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339487, CurrentID=0, Status='live', Symbol='ZBTB8OS', Aliases=['ARCH', 'ARCH2'], description='zinc finger and BTB domain containing 8 opposite strand', other_designations='protein archease|archease (ARCH)|archease-like protein|zinc finger and BTB domain-containing opposite strand protein 8', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32620818, end_position_on_the_genomic_accession=32651008, orientation='minus', exon_count=11, OMIM=[615891], no_hdr0=''),
    339488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339488, CurrentID=0, Status='live', Symbol='TFAP2E', Aliases=['AP-2epsilon', 'AP2E'], description='transcription factor AP-2 epsilon', other_designations='transcription factor AP-2-epsilon|AP2-epsilon|activating enhancer-binding protein 2-epsilon|adaptor-related protein complex 2, epsilon subunit|transcription factor AP-2 epsilon (activating enhancer binding protein 2 epsilon)', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=35568739, end_position_on_the_genomic_accession=35595591, orientation='plus', exon_count=7, OMIM=[614428], no_hdr0=''),
    339500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339500, CurrentID=0, Status='live', Symbol='ZNF678', Aliases=[], description='zinc finger protein 678', other_designations='zinc finger protein 678|hypothetical protein MGC42493', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=227563556, end_position_on_the_genomic_accession=227679669, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    339501 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339501, CurrentID=0, Status='live', Symbol='PRSS38', Aliases=['MPN2'], description='serine protease 38', other_designations='serine protease 38|marapsin 2|protease, serine 38|serine protease MPN2', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=227815685, end_position_on_the_genomic_accession=227846470, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    339512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339512, CurrentID=0, Status='live', Symbol='CCDC190', Aliases=['C1orf110'], description='coiled-coil domain containing 190', other_designations='coiled-coil domain-containing protein 190', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162851020, end_position_on_the_genomic_accession=162868918, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    339541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339541, CurrentID=0, Status='live', Symbol='ARMH1', Aliases=['C1orf228', 'NCRNA00082', 'p40'], description='armadillo like helical domain containing 1', other_designations='armadillo-like helical domain containing protein 1|uncharacterized protein C1orf228', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44674696, end_position_on_the_genomic_accession=44725591, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    339559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339559, CurrentID=0, Status='live', Symbol='ZFP69', Aliases=['ZFP69A', 'ZKSCAN23A', 'ZNF642', 'ZSCAN54A'], description='ZFP69 zinc finger protein', other_designations='zinc finger protein 69 homolog|ZFP69 zinc finger protein A|zinc finger protein 642|zinc finger protein ZFP69', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=40477220, end_position_on_the_genomic_accession=40496343, orientation='plus', exon_count=6, OMIM=[617939], no_hdr0=''),
    339665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339665, CurrentID=0, Status='live', Symbol='SLC35E4', Aliases=[], description='solute carrier family 35 member E4', other_designations='solute carrier family 35 member E4', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30634148, end_position_on_the_genomic_accession=30669019, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    339669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339669, CurrentID=0, Status='live', Symbol='TEX33', Aliases=['C22orf33', 'EAN57', 'cE81G9.2'], description='testis expressed 33', other_designations='testis-expressed protein 33|protein EAN57|testis-expressed sequence 33 protein', map_location='22q12.3', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=36991124, end_position_on_the_genomic_accession=37007864, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    339745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339745, CurrentID=0, Status='live', Symbol='SPOPL', Aliases=['BTBD33'], description='speckle type BTB/POZ protein like', other_designations='speckle-type POZ protein-like|HIB homolog 2|roadkill homolog 2', map_location='2q22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=138501770, end_position_on_the_genomic_accession=138573547, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    339761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339761, CurrentID=0, Status='live', Symbol='CYP27C1', Aliases=[], description='cytochrome P450 family 27 subfamily C member 1', other_designations='cytochrome P450 27C1|all-trans retinol 3,4-desaturase|cytochrome P450, family 27, subfamily C, polypeptide 1|cytochrome P450, family 27, subfamily C, polypeptide 13', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=127183832, end_position_on_the_genomic_accession=127220299, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    339766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339766, CurrentID=0, Status='live', Symbol='MROH2A', Aliases=['HEATR7B1'], description='maestro heat like repeat family member 2A', other_designations='maestro heat-like repeat-containing protein family member 2A|HEAT repeat containing 7B1', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233774022, end_position_on_the_genomic_accession=233833423, orientation='plus', exon_count=45, OMIM=[], no_hdr0=''),
    339768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339768, CurrentID=0, Status='live', Symbol='ESPNL', Aliases=[], description='espin like', other_designations='espin-like protein', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238100340, end_position_on_the_genomic_accession=238133287, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    339778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339778, CurrentID=0, Status='live', Symbol='FAM166C', Aliases=['C2orf70'], description='family with sequence similarity 166 member C', other_designations='protein FAM166C|UPF0573 protein C2orf70', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=26562565, end_position_on_the_genomic_accession=26581166, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    339779 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339779, CurrentID=0, Status='live', Symbol='PRR30', Aliases=['C2orf53'], description='proline rich 30', other_designations='proline-rich protein 30', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27136848, end_position_on_the_genomic_accession=27139410, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    339804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339804, CurrentID=0, Status='live', Symbol='C2orf74', Aliases=[], description='chromosome 2 open reading frame 74', other_designations='uncharacterized protein C2orf74', map_location='2p15', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=61145116, end_position_on_the_genomic_accession=61164828, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    339829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339829, CurrentID=0, Status='live', Symbol='CCDC39', Aliases=['CFAP59', 'CILD14', 'FAP59'], description='coiled-coil domain containing 39', other_designations='coiled-coil domain-containing protein 39', map_location='3q26.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=180614008, end_position_on_the_genomic_accession=180679489, orientation='minus', exon_count=20, OMIM=[613798], no_hdr0=''),
    339834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339834, CurrentID=0, Status='live', Symbol='IHO1', Aliases=['CCDC36', 'CT74', 'LELA1'], description='interactor of HORMAD1 1', other_designations='interactor of HORMAD1 protein 1|cancer/testis antigen 74|coiled-coil domain containing 36|coiled-coil domain-containing protein 36', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49198428, end_position_on_the_genomic_accession=49258106, orientation='plus', exon_count=13, OMIM=[619190], no_hdr0=''),
    339855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339855, CurrentID=0, Status='live', Symbol='KY', Aliases=['MFM7'], description='kyphoscoliosis peptidase', other_designations='kyphoscoliosis peptidase', map_location='3q22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=134599923, end_position_on_the_genomic_accession=134656053, orientation='minus', exon_count=11, OMIM=[605739], no_hdr0=''),
    339896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339896, CurrentID=0, Status='live', Symbol='GADL1', Aliases=['ADC', 'CSADC', 'HuADC', 'HuCSADC'], description='glutamate decarboxylase like 1', other_designations='acidic amino acid decarboxylase GADL1|aspartate 1-decarboxylase|cysteine sulfinic acid decarboxylase|glutamate decarboxylase-like protein 1', map_location='3p24.1-p23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=30726009, end_position_on_the_genomic_accession=30894661, orientation='minus', exon_count=16, OMIM=[615601], no_hdr0=''),
    339965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339965, CurrentID=0, Status='live', Symbol='CCDC158', Aliases=[], description='coiled-coil domain containing 158', other_designations='coiled-coil domain-containing protein 158', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76313039, end_position_on_the_genomic_accession=76421920, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    339967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339967, CurrentID=0, Status='live', Symbol='TMPRSS11A', Aliases=['ECRG1', 'HATL1', 'HESP'], description='transmembrane serine protease 11A', other_designations='transmembrane protease serine 11A|airway trypsin-like protease 1|epidermal type-II transmembrane serine protease|esophageal cancer-susceptibility gene 1 protein|transmembrane protease, serine 11A', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=67909395, end_position_on_the_genomic_accession=67963493, orientation='minus', exon_count=10, OMIM=[611704], no_hdr0=''),
    339976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339976, CurrentID=0, Status='live', Symbol='TRIML1', Aliases=['RNF209'], description='tripartite motif family like 1', other_designations='probable E3 ubiquitin-protein ligase TRIML1|RING finger protein 209|RING-type E3 ubiquitin transferase TRIML1', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=188137229, end_position_on_the_genomic_accession=188150768, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    339977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339977, CurrentID=0, Status='live', Symbol='LRRC66', Aliases=[], description='leucine rich repeat containing 66', other_designations='leucine-rich repeat-containing protein 66', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=51993652, end_position_on_the_genomic_accession=52020363, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    339983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=339983, CurrentID=0, Status='live', Symbol='NAT8L', Aliases=['CML3', 'NACED', 'NAT8-LIKE'], description='N-acetyltransferase 8 like', other_designations='N-acetylaspartate synthetase|N-acetyltransferase 8-like (GCN5-related, putative)|NAA synthetase|Shati|camello-like protein 3', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2059327, end_position_on_the_genomic_accession=2069089, orientation='plus', exon_count=3, OMIM=[610647], no_hdr0=''),
    340024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340024, CurrentID=0, Status='live', Symbol='SLC6A19', Aliases=['B0AT1', 'HND'], description='solute carrier family 6 member 19', other_designations='sodium-dependent neutral amino acid transporter B(0)AT1|sodium-dependent amino acid transporter system B0|solute carrier family 6 (neurotransmitter transporter), member 19|solute carrier family 6 (neutral amino acid transporter), member 19|system B(0) neutral amino acid transporter AT1|system B0 neutral amino acid transporter', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1201595, end_position_on_the_genomic_accession=1225111, orientation='plus', exon_count=12, OMIM=[608893], no_hdr0=''),
    340061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340061, CurrentID=0, Status='live', Symbol='STING1', Aliases=['ERIS', 'MITA', 'MPYS', 'NET23', 'SAVI', 'STING', 'STING-beta', 'TMEM173', 'hMITA', 'hSTING'], description='stimulator of interferon response cGAMP interactor 1', other_designations='stimulator of interferon genes protein|N-terminal methionine-proline-tyrosine-serine plasma membrane tetraspanner|endoplasmic reticulum IFN stimulator|endoplasmic reticulum interferon stimulator|mitochondrial mediator of IRF3 activation|stimulator of interferon protein|transmembrane protein 173', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139475533, end_position_on_the_genomic_accession=139482758, orientation='minus', exon_count=9, OMIM=[612374], no_hdr0=''),
    340069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340069, CurrentID=0, Status='live', Symbol='FAM170A', Aliases=['ZNFD'], description='family with sequence similarity 170 member A', other_designations='protein FAM170A|Znf domain containing protein|zinc finger domain-containing protein|zinc finger protein ZNFD', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=119629558, end_position_on_the_genomic_accession=119635822, orientation='plus', exon_count=5, OMIM=[618401], no_hdr0=''),
    340075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340075, CurrentID=0, Status='live', Symbol='ARSI', Aliases=['ASI', 'SPG66'], description='arylsulfatase family member I', other_designations='arylsulfatase I', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150296343, end_position_on_the_genomic_accession=150302905, orientation='minus', exon_count=2, OMIM=[610009], no_hdr0=''),
    340096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340096, CurrentID=0, Status='live', Symbol='H3Y2', Aliases=['H3.X', 'H3.Y.2'], description='H3.Y histone 2', other_designations='histone H3.X|H3 histone, family 3B (H3.3B) pseudogene|Putative histone H3.X|histone H3.Y2|histone cluster 2, H3d pseudogene', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=17490967, end_position_on_the_genomic_accession=17492076, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    340120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340120, CurrentID=0, Status='live', Symbol='ANKRD34B', Aliases=['DP58'], description='ankyrin repeat domain 34B', other_designations='ankyrin repeat domain-containing protein 34B|cytosolic phosphoprotein DP58|dendritic phosphoprotein 58 kDa', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80556755, end_position_on_the_genomic_accession=80570292, orientation='minus', exon_count=6, OMIM=[618581], no_hdr0=''),
    340146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340146, CurrentID=0, Status='live', Symbol='SLC35D3', Aliases=['FRCL1'], description='solute carrier family 35 member D3', other_designations='solute carrier family 35 member D3|frc, fringe-like 1|fringe connection-like protein 1', map_location='6q23.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=136922301, end_position_on_the_genomic_accession=136925660, orientation='plus', exon_count=2, OMIM=[612519], no_hdr0=''),
    340152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340152, CurrentID=0, Status='live', Symbol='ZC3H12D', Aliases=['C6orf95', 'MCPIP4', 'TFL', 'dJ281H8.1', 'p34'], description='zinc finger CCCH-type containing 12D', other_designations='probable ribonuclease ZC3H12D|Zinc finger CCCH domain-containing protein 12D|transformed follicular lymphoma|tumor suppressor TFL', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149446795, end_position_on_the_genomic_accession=149485014, orientation='minus', exon_count=6, OMIM=[611106], no_hdr0=''),
    340156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340156, CurrentID=0, Status='live', Symbol='MYLK4', Aliases=['SgK085'], description='myosin light chain kinase family member 4', other_designations='myosin light chain kinase family member 4|caMLCK like|sugen kinase 85', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=2663629, end_position_on_the_genomic_accession=2770376, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    340168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340168, CurrentID=0, Status='live', Symbol='DPPA5', Aliases=['ESG1'], description='developmental pluripotency associated 5', other_designations='developmental pluripotency-associated 5 protein|embryonal stem cell specific gene 1', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73353063, end_position_on_the_genomic_accession=73354276, orientation='minus', exon_count=3, OMIM=[611111], no_hdr0=''),
    340204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340204, CurrentID=0, Status='live', Symbol='CLPSL1', Aliases=['C6orf127', 'ESP32', 'dJ510O8.6'], description='colipase like 1', other_designations='colipase-like protein 1|colipase-like protein C6orf127', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35781019, end_position_on_the_genomic_accession=35794039, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    340205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340205, CurrentID=0, Status='live', Symbol='TREML1', Aliases=['GLTL1825', 'PRO3438', 'TLT-1', 'TLT1', 'dJ238O23.3'], description='triggering receptor expressed on myeloid cells like 1', other_designations='trem-like transcript 1 protein|triggering receptor expressed on myeloid cells-like protein 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41149097, end_position_on_the_genomic_accession=41158450, orientation='minus', exon_count=9, OMIM=[609714], no_hdr0=''),
    340252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340252, CurrentID=0, Status='live', Symbol='ZNF680', Aliases=[], description='zinc finger protein 680', other_designations='zinc finger protein 680', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64500253, end_position_on_the_genomic_accession=64563135, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    340260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340260, CurrentID=0, Status='live', Symbol='UNCX', Aliases=['UNCX4.1'], description='UNC homeobox', other_designations='homeobox protein unc-4 homolog|UNC homeobox protein|Unc4.1 homeobox|homeobox protein Uncx4.1|truncated UNCX homeobox protein', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1232872, end_position_on_the_genomic_accession=1237326, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    340267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340267, CurrentID=0, Status='live', Symbol='COL28A1', Aliases=['COL28'], description='collagen type XXVIII alpha 1 chain', other_designations='collagen alpha-1(XXVIII) chain|collagen, type XXVIII, alpha 1', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7338542, end_position_on_the_genomic_accession=7542094, orientation='minus', exon_count=46, OMIM=[609996], no_hdr0=''),
    340273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340273, CurrentID=0, Status='live', Symbol='ABCB5', Aliases=['ABCB5alphabeta', 'EST422562', 'ABCB5'], description='ATP binding cassette subfamily B member 5', other_designations='ATP-binding cassette sub-family B member 5|ABCB5 P-gp|ATP-binding cassette protein|ATP-binding cassette, sub-family B (MDR/TAP), member 5|P-glycoprotein ABCB5', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=20615667, end_position_on_the_genomic_accession=20757008, orientation='plus', exon_count=31, OMIM=[611785], no_hdr0=''),
    340277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340277, CurrentID=0, Status='live', Symbol='FAM221A', Aliases=['C7orf46'], description='family with sequence similarity 221 member A', other_designations='protein FAM221A|uncharacterized protein C7orf46', map_location='7p15.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=23680118, end_position_on_the_genomic_accession=23703249, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    340307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340307, CurrentID=0, Status='live', Symbol='CTAGE6', Aliases=['CTAGE6P'], description='CTAGE family member 6', other_designations='cTAGE family member 6|CTAGE family, member 6, pseudogene|cutaneous T-cell lymphoma-associated antigen 6|protein cTAGE-6|putative protein cTAGE-6', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143755089, end_position_on_the_genomic_accession=143757696, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    340348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340348, CurrentID=0, Status='live', Symbol='TSPAN33', Aliases=['PEN', 'PEN.', 'TSPAN-33'], description='tetraspanin 33', other_designations='tetraspanin-33|penumbra|proerythroblast new membrane', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129144707, end_position_on_the_genomic_accession=129169699, orientation='plus', exon_count=8, OMIM=[610120], no_hdr0=''),
    340351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340351, CurrentID=0, Status='live', Symbol='AGBL3', Aliases=['CCP3'], description='AGBL carboxypeptidase 3', other_designations='cytosolic carboxypeptidase 3|ATP/GTP binding protein like 3', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134986139, end_position_on_the_genomic_accession=135135782, orientation='plus', exon_count=22, OMIM=[617346], no_hdr0=''),
    340359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340359, CurrentID=0, Status='live', Symbol='KLHL38', Aliases=['C8ORFK36'], description='kelch like family member 38', other_designations='kelch-like protein 38|kelch-like 38', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123644442, end_position_on_the_genomic_accession=123653801, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    340371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340371, CurrentID=0, Status='live', Symbol='NRBP2', Aliases=['TRG16', 'pp9320'], description='nuclear receptor binding protein 2', other_designations='nuclear receptor-binding protein 2|transformation-related protein 16', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143829776, end_position_on_the_genomic_accession=143840974, orientation='minus', exon_count=21, OMIM=[615563], no_hdr0=''),
    340385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340385, CurrentID=0, Status='live', Symbol='ZNF517', Aliases=[], description='zinc finger protein 517', other_designations='zinc finger protein 517', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144798913, end_position_on_the_genomic_accession=144813137, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    340390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340390, CurrentID=0, Status='live', Symbol='WDR97', Aliases=['KIAA1875'], description='WD repeat domain 97', other_designations='WD repeat-containing protein 97', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144107739, end_position_on_the_genomic_accession=144118328, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    340393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340393, CurrentID=0, Status='live', Symbol='TMEM249', Aliases=['C8ORFK29'], description='transmembrane protein 249', other_designations='transmembrane protein 249|putative transmembrane protein C8orfK29', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144353228, end_position_on_the_genomic_accession=144354931, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    340419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340419, CurrentID=0, Status='live', Symbol='RSPO2', Aliases=['CRISTIN2', 'HHRRD', 'TETAMS2'], description='R-spondin 2', other_designations='R-spondin-2|R-spondin 2 homolog|roof plate-specific spondin-2', map_location='8q23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=107899316, end_position_on_the_genomic_accession=108083680, orientation='minus', exon_count=7, OMIM=[610575], no_hdr0=''),
    340441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340441, CurrentID=0, Status='live', Symbol='POTEA', Aliases=['A26A1', 'CT104.3', 'POTE-8', 'POTE8'], description='POTE ankyrin domain family member A', other_designations='POTE ankyrin domain family member A|ANKRD26-like family A, member 1|cancer/testis antigen family 104, member 3|prostate, ovary, testis-expressed protein on chromosome 8|protein expressed in prostate, ovary, testis, and placenta 8', map_location='8p11.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=43292370, end_position_on_the_genomic_accession=43365175, orientation='plus', exon_count=14, OMIM=[608915], no_hdr0=''),
    340481 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340481, CurrentID=0, Status='live', Symbol='ZDHHC21', Aliases=['DHHC-21', 'DHHC21', 'DNZ1', 'HSPC097'], description='zinc finger DHHC-type palmitoyltransferase 21', other_designations='palmitoyltransferase ZDHHC21|DHHC domain-containing cysteine-rich protein 21|zinc finger DHHC-type containing 21|zinc finger, DHHC domain containing 21', map_location='9p22.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=14588797, end_position_on_the_genomic_accession=14693432, orientation='minus', exon_count=19, OMIM=[614605], no_hdr0=''),
    340485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340485, CurrentID=0, Status='live', Symbol='ACER2', Aliases=['ALKCDase2', 'ASAH3L'], description='alkaline ceramidase 2', other_designations='alkaline ceramidase 2|alkCDase 2|alkaline CDase 2|ceramide hydrolase|haCER2', map_location='9p22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=19408927, end_position_on_the_genomic_accession=19455173, orientation='plus', exon_count=12, OMIM=[613492], no_hdr0=''),
    340526 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340526, CurrentID=0, Status='live', Symbol='RTL5', Aliases=['6430402L03Rik', 'MAR5', 'MART5', 'RGAG4', 'SIRH8'], description='retrotransposon Gag like 5', other_designations='retrotransposon Gag-like protein 5|Sushi-Ichi retrotransposon homolog 8|mammalian retrotransposon-derived 5|retrotransposon gag domain containing 4|retrotransposon gag domain-containing protein 4', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72127110, end_position_on_the_genomic_accession=72131915, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    340527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340527, CurrentID=0, Status='live', Symbol='NHSL2', Aliases=[], description='NHS like 2', other_designations='NHS-like protein 2', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71910845, end_position_on_the_genomic_accession=72153286, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    340529 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340529, CurrentID=0, Status='live', Symbol='PABPC1L2A', Aliases=['RBM32A'], description='poly(A) binding protein cytoplasmic 1 like 2A', other_designations='polyadenylate-binding protein 1-like 2|RNA binding motif protein 32A|RNA-binding motif protein 32|RNA-binding protein 32', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=73077276, end_position_on_the_genomic_accession=73079512, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    340533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340533, CurrentID=0, Status='live', Symbol='NEXMIF', Aliases=['KIAA2022', 'KIDLIA', 'MRX98', 'XPN'], description='neurite extension and migration factor', other_designations='neurite extension and migration factor|XLMR protein related to neurite extension|XLMR-related protein, neurite extension', map_location='Xq13.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=74732856, end_position_on_the_genomic_accession=74925452, orientation='minus', exon_count=4, OMIM=[300524], no_hdr0=''),
    340542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340542, CurrentID=0, Status='live', Symbol='BEX5', Aliases=['NGFRAP1L1'], description='brain expressed X-linked 5', other_designations='protein BEX5|BEX family member 5|NGFRAP1-like 1|NGFRAP1-like protein 1|brain-expressed X-linked protein 5|nerve growth factor receptor-associated protein 2', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102153712, end_position_on_the_genomic_accession=102155977, orientation='minus', exon_count=4, OMIM=[300693], no_hdr0=''),
    340543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340543, CurrentID=0, Status='live', Symbol='TCEAL5', Aliases=['WEX4'], description='transcription elongation factor A like 5', other_designations='transcription elongation factor A protein-like 5|TCEA-like protein 5|transcription elongation factor A (SII)-like 5|transcription elongation factor S-II protein-like 5', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=103273691, end_position_on_the_genomic_accession=103276750, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    340547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340547, CurrentID=0, Status='live', Symbol='VSIG1', Aliases=['1700062D20Rik', 'GPA34', 'dJ889N15.1'], description='V-set and immunoglobulin domain containing 1', other_designations='V-set and immunoglobulin domain-containing protein 1|cell surface A33 antigen|glycoprotein A34', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=108018886, end_position_on_the_genomic_accession=108079184, orientation='plus', exon_count=10, OMIM=[300620], no_hdr0=''),
    340554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340554, CurrentID=0, Status='live', Symbol='ZC3H12B', Aliases=['CXorf32', 'MCPIP2'], description='zinc finger CCCH-type containing 12B', other_designations='probable ribonuclease ZC3H12B|MCP-induced protein 2|zinc finger CCCH domain-containing protein 12B', map_location='Xq11.2-q12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=65034815, end_position_on_the_genomic_accession=65507887, orientation='plus', exon_count=19, OMIM=[300889], no_hdr0=''),
    340562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340562, CurrentID=0, Status='live', Symbol='SATL1', Aliases=[], description='spermidine/spermine N1-acetyl transferase like 1', other_designations='spermidine/spermine N(1)-acetyltransferase-like protein 1', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=85092284, end_position_on_the_genomic_accession=85243779, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    340578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340578, CurrentID=0, Status='live', Symbol='DCAF12L2', Aliases=['WDR40C'], description='DDB1 and CUL4 associated factor 12 like 2', other_designations='DDB1- and CUL4-associated factor 12-like protein 2|WD repeat-containing protein 40C', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=126163499, end_position_on_the_genomic_accession=126166289, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    340595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340595, CurrentID=0, Status='live', Symbol='RTL4', Aliases=['Mar4', 'Mart4', 'SIRH11', 'ZCCHC16'], description='retrotransposon Gag like 4', other_designations='retrotransposon Gag-like protein 4|Sushi-Ichi retrotransposon homolog 11|mammalian retrotransposon-derived 4|mammalian retrotransposon-derived protein 4|zinc finger CCHC domain-containing protein 16|zinc finger CCHC-type containing 16|zinc finger, CCHC domain containing 16', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=112083025, end_position_on_the_genomic_accession=112457245, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    340596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340596, CurrentID=0, Status='live', Symbol='LHFPL1', Aliases=[], description='LHFPL tetraspan subfamily member 1', other_designations='LHFPL tetraspan subfamily member 1 protein|LHFP-like protein 1|lipoma HMGIC fusion partner like 1|lipoma HMGIC fusion partner-like 1 protein', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=112630648, end_position_on_the_genomic_accession=112680178, orientation='minus', exon_count=6, OMIM=[300566], no_hdr0=''),
    340602 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340602, CurrentID=0, Status='live', Symbol='EZHIP', Aliases=['CATACOMB', 'CXorf67', 'KIP75'], description='EZH inhibitory protein', other_designations='EZH inhibitory protein|K27M-like inhibitor of PRC2|catalytic antagonist of Polycomb|uncharacterized protein CXorf67', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51406948, end_position_on_the_genomic_accession=51408843, orientation='plus', exon_count=1, OMIM=[301036], no_hdr0=''),
    340654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340654, CurrentID=0, Status='live', Symbol='LIPM', Aliases=['LIPL3', 'bA304I5.1'], description='lipase family member M', other_designations='lipase member M|lipase M|lipase-like abhydrolase domain-containing protein 3|lipase-like, ab-hydrolase domain containing 3', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88802730, end_position_on_the_genomic_accession=88822022, orientation='plus', exon_count=10, OMIM=[613923], no_hdr0=''),
    340665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340665, CurrentID=0, Status='live', Symbol='CYP26C1', Aliases=['FFDD4'], description='cytochrome P450 family 26 subfamily C member 1', other_designations='cytochrome P450 26C1|cytochrome P450, family 26, subfamily C, polypeptide 1', map_location='10q23.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=93060798, end_position_on_the_genomic_accession=93069540, orientation='plus', exon_count=6, OMIM=[608428], no_hdr0=''),
    340706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340706, CurrentID=0, Status='live', Symbol='VWA2', Aliases=['AMACO', 'CCSP-2', 'CCSP2', 'NET42'], description='von Willebrand factor A domain containing 2', other_designations='von Willebrand factor A domain-containing protein 2|a domain-containing protein similar to matrilin and collagen|colon cancer diagnostic marker|colon cancer secreted protein 2', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=114239254, end_position_on_the_genomic_accession=114294500, orientation='plus', exon_count=18, OMIM=[618281], no_hdr0=''),
    340719 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340719, CurrentID=0, Status='live', Symbol='NANOS1', Aliases=['EC_Rep1a', 'NOS-1', 'NOS1', 'SPGF12', 'ZC2HC12A'], description='nanos C2HC-type zinc finger 1', other_designations='nanos homolog 1', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119029714, end_position_on_the_genomic_accession=119033730, orientation='plus', exon_count=1, OMIM=[608226], no_hdr0=''),
    340745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340745, CurrentID=0, Status='live', Symbol='LRIT2', Aliases=['LRRC22'], description='leucine rich repeat, Ig-like and transmembrane domains 2', other_designations='leucine-rich repeat, immunoglobulin-like domain and transmembrane domain-containing protein 2|leucine rich repeat containing 22|leucine-rich repeat, immunoglobulin-like and transmembrane domains 2|leucine-rich repeat-containing protein 22', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84220485, end_position_on_the_genomic_accession=84225589, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    340784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340784, CurrentID=0, Status='live', Symbol='HMX3', Aliases=['NKX-5.1', 'NKX5.1', 'Nkx5-1'], description='H6 family homeobox 3', other_designations='homeobox protein HMX3|homeo box (H6 family) 3|homeobox (H6 family) 3|homeobox protein H6 family member 3|homeobox protein Nkx-5.1', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=123135970, end_position_on_the_genomic_accession=123139423, orientation='plus', exon_count=2, OMIM=[613380], no_hdr0=''),
    340895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340895, CurrentID=0, Status='live', Symbol='MALRD1', Aliases=['C10orf112', 'DIET1', 'bA265G8.2'], description='MAM and LDL receptor class A domain containing 1', other_designations='MAM and LDL-receptor class A domain-containing protein 1|MAM and LDL-receptor class A domain-containing protein C10orf112|novel MAM domain containing protein', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=19046931, end_position_on_the_genomic_accession=19734478, orientation='plus', exon_count=46, OMIM=[617715], no_hdr0=''),
    340900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340900, CurrentID=0, Status='live', Symbol='EBLN1', Aliases=['EBLN-1'], description='endogenous Bornavirus like nucleoprotein 1', other_designations='endogenous Bornavirus-like nucleoprotein 1|endogenous Borna-like N element-1|endogenous Borna-like N element-containing protein 1', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22208475, end_position_on_the_genomic_accession=22218015, orientation='minus', exon_count=3, OMIM=[613249], no_hdr0=''),
    340980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340980, CurrentID=0, Status='live', Symbol='OR52B6', Aliases=['OR11-47'], description='olfactory receptor family 52 subfamily B member 6', other_designations='olfactory receptor 52B6|olfactory receptor OR11-47', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5580877, end_position_on_the_genomic_accession=5581884, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    340990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=340990, CurrentID=0, Status='live', Symbol='OTOG', Aliases=['DFNB18B', 'MLEMP', 'OTGN'], description='otogelin', other_designations='otogelin', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17547259, end_position_on_the_genomic_accession=17646044, orientation='plus', exon_count=56, OMIM=[604487], no_hdr0=''),
    341019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341019, CurrentID=0, Status='live', Symbol='DCDC1', Aliases=['DCDC5'], description='doublecortin domain containing 1', other_designations='doublecortin domain-containing protein 1|doublecortin domain-containing 5 protein|doublecortin domain-containing protein 5', map_location='11p14.1-p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=30863603, end_position_on_the_genomic_accession=31369810, orientation='minus', exon_count=52, OMIM=[608062], no_hdr0=''),
    341032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341032, CurrentID=0, Status='live', Symbol='C11orf53', Aliases=[], description='chromosome 11 open reading frame 53', other_designations='uncharacterized protein C11orf53', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111245725, end_position_on_the_genomic_accession=111286401, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    341116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341116, CurrentID=0, Status='live', Symbol='MS4A10', Aliases=['CD20L7', 'MS4A9'], description='membrane spanning 4-domains A10', other_designations='membrane-spanning 4-domains subfamily A member 10|CD20 antigen-like 7|membrane-spanning 4-domains, subfamily A, member 10', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60785332, end_position_on_the_genomic_accession=60801305, orientation='plus', exon_count=9, OMIM=[608403], no_hdr0=''),
    341152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341152, CurrentID=0, Status='live', Symbol='OR2AT4', Aliases=['OR11-265'], description='olfactory receptor family 2 subfamily AT member 4', other_designations='olfactory receptor 2AT4|olfactory receptor OR11-265 pseudogene', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75088692, end_position_on_the_genomic_accession=75096890, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    341208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341208, CurrentID=0, Status='live', Symbol='HEPHL1', Aliases=['HJDD', 'ZP'], description='hephaestin like 1', other_designations='ferroxidase HEPHL1|hephaestin-like protein 1', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94021354, end_position_on_the_genomic_accession=94114208, orientation='plus', exon_count=20, OMIM=[618455], no_hdr0=''),
    341276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341276, CurrentID=0, Status='live', Symbol='OR10A2', Aliases=['OR10A2P', 'OR11-82', 'OR11-86', 'OST363'], description='olfactory receptor family 10 subfamily A member 2', other_designations='olfactory receptor 10A2|hP4 olfactory receptor|olfactory receptor OR11-82 pseudogene|olfactory receptor OR11-86|olfactory receptor, family 10, subfamily A, member 2 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=6863057, end_position_on_the_genomic_accession=6874717, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    341277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341277, CurrentID=0, Status='live', Symbol='OVCH2', Aliases=['OVTN'], description='ovochymase 2', other_designations='ovochymase-2|oviductin protease', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7678623, end_position_on_the_genomic_accession=7706894, orientation='minus', exon_count=19, OMIM=[618962], no_hdr0=''),
    341346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341346, CurrentID=0, Status='live', Symbol='SMCO2', Aliases=['C12orf70'], description='single-pass membrane protein with coiled-coil domains 2', other_designations='single-pass membrane and coiled-coil domain-containing protein 2', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27446482, end_position_on_the_genomic_accession=27506911, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    341350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341350, CurrentID=0, Status='live', Symbol='OVCH1', Aliases=['OVCH'], description='ovochymase 1', other_designations='ovochymase-1', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=29420822, end_position_on_the_genomic_accession=29499693, orientation='minus', exon_count=30, OMIM=[], no_hdr0=''),
    341359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341359, CurrentID=0, Status='live', Symbol='SYT10', Aliases=[], description='synaptotagmin 10', other_designations='synaptotagmin-10|synaptotagmin X|sytX', map_location='12p11.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=33374238, end_position_on_the_genomic_accession=33439819, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    341392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341392, CurrentID=0, Status='live', Symbol='ACSM4', Aliases=[], description='acyl-CoA synthetase medium chain family member 4', other_designations='acyl-coenzyme A synthetase ACSM4, mitochondrial', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7304072, end_position_on_the_genomic_accession=7328719, orientation='plus', exon_count=13, OMIM=[614360], no_hdr0=''),
    341405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341405, CurrentID=0, Status='live', Symbol='ANKRD33', Aliases=['C12orf7', 'PANKY'], description='ankyrin repeat domain 33', other_designations='photoreceptor ankyrin repeat protein|ankyrin repeat domain-containing protein 33', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51888103, end_position_on_the_genomic_accession=51891727, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    341416 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341416, CurrentID=0, Status='live', Symbol='OR6C2', Aliases=['OR6C67'], description='olfactory receptor family 6 subfamily C member 2', other_designations='olfactory receptor 6C2|HSA3', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55444076, end_position_on_the_genomic_accession=55453347, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    341418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341418, CurrentID=0, Status='live', Symbol='OR6C4', Aliases=['OR12-10'], description='olfactory receptor family 6 subfamily C member 4', other_designations='olfactory receptor 6C4|olfactory receptor OR12-10', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55549602, end_position_on_the_genomic_accession=55555832, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    341567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341567, CurrentID=0, Status='live', Symbol='H1-7', Aliases=['H1.7', 'H1FNT', 'H1T2'], description='H1.7 linker histone', other_designations='testis-specific H1 histone|H1 histone family member N, testis specific|HANP1|haploid germ cell-specific nuclear protein 1|histone H1.7|histone H1t2|testis secretory sperm-binding protein Li 223n', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48328980, end_position_on_the_genomic_accession=48330279, orientation='plus', exon_count=1, OMIM=[618565], no_hdr0=''),
    341568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341568, CurrentID=0, Status='live', Symbol='OR8S1', Aliases=[], description='olfactory receptor family 8 subfamily S member 1', other_designations='olfactory receptor 8S1', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48525632, end_position_on_the_genomic_accession=48526570, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    341640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341640, CurrentID=0, Status='live', Symbol='FREM2', Aliases=['CRYPTOP', 'FRASRS2'], description='FRAS1 related extracellular matrix 2', other_designations='FRAS1-related extracellular matrix protein 2|ECM3 homolog|FRAS1 related extracellular matrix protein 2', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=38687041, end_position_on_the_genomic_accession=38887131, orientation='plus', exon_count=26, OMIM=[608945], no_hdr0=''),
    341676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341676, CurrentID=0, Status='live', Symbol='NEK5', Aliases=[], description='NIMA related kinase 5', other_designations='serine/threonine-protein kinase Nek5|NIMA (never in mitosis gene a)-related kinase 5|nimA-related protein kinase 5', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52033611, end_position_on_the_genomic_accession=52129073, orientation='minus', exon_count=31, OMIM=[616731], no_hdr0=''),
    341799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341799, CurrentID=0, Status='live', Symbol='OR6S1', Aliases=['OR14-37Q', 'OR6S1'], description='olfactory receptor family 6 subfamily S member 1', other_designations='olfactory receptor 6S1|olfactory receptor OR14-37', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20640696, end_position_on_the_genomic_accession=20641691, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    341880 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341880, CurrentID=0, Status='live', Symbol='SLC35F4', Aliases=['C14orf36', 'c14_5373'], description='solute carrier family 35 member F4', other_designations='solute carrier family 35 member F4', map_location='14q22.3-q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=57563920, end_position_on_the_genomic_accession=57982327, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    341883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341883, CurrentID=0, Status='live', Symbol='LRRC9', Aliases=[], description='leucine rich repeat containing 9', other_designations='leucine-rich repeat-containing protein 9', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59919713, end_position_on_the_genomic_accession=60064596, orientation='plus', exon_count=40, OMIM=[], no_hdr0=''),
    341947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=341947, CurrentID=0, Status='live', Symbol='COX8C', Aliases=['COX8-3'], description='cytochrome c oxidase subunit 8C', other_designations='cytochrome c oxidase subunit 8C, mitochondrial|COX VIII-3|cytochrome c oxidase polypeptide 8|cytochrome c oxidase polypeptide VIII|cytochrome c oxidase subunit 8-3|cytochrome c oxidase subunit VIII|cytochrome c oxidase subunit VIIIC', map_location='14q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=93347182, end_position_on_the_genomic_accession=93348356, orientation='plus', exon_count=2, OMIM=[616855], no_hdr0=''),
    342035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342035, CurrentID=0, Status='live', Symbol='GLDN', Aliases=['CLOM', 'COLM', 'CRG-L2', 'CRGL2', 'LCCS11', 'UNC-112', 'UNC-122'], description='gliomedin', other_designations='gliomedin|collomin|colmedin', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51341655, end_position_on_the_genomic_accession=51413365, orientation='plus', exon_count=14, OMIM=[608603], no_hdr0=''),
    342096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342096, CurrentID=0, Status='live', Symbol='GOLGA6A', Aliases=['GLP', 'GOLGA6'], description='golgin A6 family member A', other_designations='golgin subfamily A member 6A|Golgin linked to PML|golgi autoantigen, golgin subfamily a, 6|golgi autoantigen, golgin subfamily a, 6A|golgi autoantigen, golgin subfamily a, member 6|golgin-like protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74069857, end_position_on_the_genomic_accession=74082550, orientation='minus', exon_count=18, OMIM=[610288], no_hdr0=''),
    342125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342125, CurrentID=0, Status='live', Symbol='TMC3', Aliases=[], description='transmembrane channel like 3', other_designations='transmembrane channel-like protein 3', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=81331088, end_position_on_the_genomic_accession=81374213, orientation='minus', exon_count=22, OMIM=[617196], no_hdr0=''),
    342132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342132, CurrentID=0, Status='live', Symbol='ZNF774', Aliases=[], description='zinc finger protein 774', other_designations='zinc finger protein 774', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90351439, end_position_on_the_genomic_accession=90362847, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    342184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342184, CurrentID=0, Status='live', Symbol='FMN1', Aliases=['FMN', 'LD'], description='formin 1', other_designations='formin-1|formin (limb deformity)|limb deformity protein homolog', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32765544, end_position_on_the_genomic_accession=33194765, orientation='minus', exon_count=29, OMIM=[136535], no_hdr0=''),
    342346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342346, CurrentID=0, Status='live', Symbol='C16orf96', Aliases=[], description='chromosome 16 open reading frame 96', other_designations='uncharacterized protein C16orf96', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4538601, end_position_on_the_genomic_accession=4600758, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    342357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342357, CurrentID=0, Status='live', Symbol='ZKSCAN2', Aliases=['ZNF694', 'ZSCAN31', 'ZSCAN34'], description='zinc finger with KRAB and SCAN domains 2', other_designations='zinc finger protein with KRAB and SCAN domains 2|zinc finger and SCAN domain containing 31|zinc finger protein 694', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=25236001, end_position_on_the_genomic_accession=25257937, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    342371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342371, CurrentID=0, Status='live', Symbol='ATXN1L', Aliases=['BOAT', 'BOAT1'], description='ataxin 1 like', other_designations='ataxin-1-like|brother of ATXN1|brother of ataxin-1', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71845976, end_position_on_the_genomic_accession=71857328, orientation='plus', exon_count=3, OMIM=[614301], no_hdr0=''),
    342372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342372, CurrentID=0, Status='live', Symbol='PKD1L3', Aliases=[], description='polycystin 1 like 3, transient receptor potential channel interacting', other_designations='polycystic kidney disease protein 1-like 3|PC1-like 3 protein|polycystic kidney disease 1-like 3|polycystin-1L3', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71929538, end_position_on_the_genomic_accession=72000402, orientation='minus', exon_count=31, OMIM=[607895], no_hdr0=''),
    342510 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342510, CurrentID=0, Status='live', Symbol='CD300E', Aliases=['CD300LE', 'CLM-2', 'CLM2', 'CMRF35-A5', 'IREM-2', 'IREM2', 'PIgR-2', 'PIgR2'], description='CD300e molecule', other_designations='CMRF35-like molecule 2|CD300 antigen-like family member E|CD300e antigen|immune receptor expressed on myeloid cells 2|poly-Ig receptor 2|polymeric immunoglobulin receptor 2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74609885, end_position_on_the_genomic_accession=74623958, orientation='minus', exon_count=5, OMIM=[609801], no_hdr0=''),
    342527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342527, CurrentID=0, Status='live', Symbol='SMTNL2', Aliases=[], description='smoothelin like 2', other_designations='smoothelin-like protein 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4584007, end_position_on_the_genomic_accession=4608319, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    342538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342538, CurrentID=0, Status='live', Symbol='NACA2', Aliases=['ANAC', 'NACAL'], description='nascent polypeptide associated complex subunit alpha 2', other_designations='nascent polypeptide-associated complex subunit alpha-2|IgE autoantigen alpha-nascent polypeptide-associated complex|alpha-NAC protein|hom s 2.01 protein|nascent polypeptide associated complex alpha subunit 2|nascent polypeptide-associated complex, alpha polypeptide, 2', map_location='17q23.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=61590421, end_position_on_the_genomic_accession=61591219, orientation='minus', exon_count=1, OMIM=[609274], no_hdr0=''),
    342574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342574, CurrentID=0, Status='live', Symbol='KRT27', Aliases=['K25IRS3', 'KRT25C'], description='keratin 27', other_designations='keratin, type I cytoskeletal 27|CK-27|K25C|K27|cytokeratin-27|keratin 27, type I|keratin-25C|type I inner root sheath specific keratin 25 irs3|type I inner root sheath-specific keratin-K25irs3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40776808, end_position_on_the_genomic_accession=40782550, orientation='minus', exon_count=8, OMIM=[616676], no_hdr0=''),
    342618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342618, CurrentID=0, Status='live', Symbol='SLFN14', Aliases=['BDPLT20'], description='schlafen family member 14', other_designations='protein SLFN14', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35543985, end_position_on_the_genomic_accession=35560819, orientation='minus', exon_count=7, OMIM=[614958], no_hdr0=''),
    342667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342667, CurrentID=0, Status='live', Symbol='STAC2', Aliases=['24b2', '24b2/STAC2'], description='SH3 and cysteine rich domain 2', other_designations='SH3 and cysteine-rich domain-containing protein 2|SRC homology 3 and cysteine-rich domain-containing protein 2', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39210536, end_position_on_the_genomic_accession=39225945, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    342850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342850, CurrentID=0, Status='live', Symbol='ANKRD62', Aliases=['DKFZp779B1634'], description='ankyrin repeat domain 62', other_designations='ankyrin repeat domain-containing protein 62', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=12093796, end_position_on_the_genomic_accession=12181684, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    342865 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342865, CurrentID=0, Status='live', Symbol='VSTM2B', Aliases=[], description='V-set and transmembrane domain containing 2B', other_designations='V-set and transmembrane domain-containing protein 2B', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=29525418, end_position_on_the_genomic_accession=29564555, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    342892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342892, CurrentID=0, Status='live', Symbol='ZNF850', Aliases=['ZNF850P'], description='zinc finger protein 850', other_designations='zinc finger protein 850|putative zinc finger protein ENSP00000330994', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36743480, end_position_on_the_genomic_accession=36772807, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    342897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342897, CurrentID=0, Status='live', Symbol='NCCRP1', Aliases=['FBXO50', 'NCCRP-1'], description='NCCRP1, F-box associated domain containing', other_designations='F-box only protein 50|NCC receptor protein 1 homolog|non-specific cytotoxic cell receptor protein 1 homolog|nonspecific cytotoxic cell receptor protein 1 homolog', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39196964, end_position_on_the_genomic_accession=39201884, orientation='plus', exon_count=7, OMIM=[615901], no_hdr0=''),
    342898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342898, CurrentID=0, Status='live', Symbol='SYCN', Aliases=['INSSA1', 'SYL'], description='syncollin', other_designations='syncollin|insulin synthesis associated 1|insulin synthesis-associated protein 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39202825, end_position_on_the_genomic_accession=39204263, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    342900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342900, CurrentID=0, Status='live', Symbol='LEUTX', Aliases=[], description='leucine twenty homeobox', other_designations='paired-like homeodomain transcription factor LEUTX|PRD-LIKE homeobox transcription factor LEUTX|arginine-fifty homeobox-like pseudogene|paired-like homeobox transcription factor LEUTX|putative leucine-twenty homeobox', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39776453, end_position_on_the_genomic_accession=39786291, orientation='plus', exon_count=4, OMIM=[618701], no_hdr0=''),
    342908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342908, CurrentID=0, Status='live', Symbol='ZNF404', Aliases=[], description='zinc finger protein 404', other_designations='zinc finger protein 404', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43872365, end_position_on_the_genomic_accession=43883964, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    342909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342909, CurrentID=0, Status='live', Symbol='ZNF284', Aliases=['ZNF284L'], description='zinc finger protein 284', other_designations='zinc finger protein 284', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44072137, end_position_on_the_genomic_accession=44089613, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    342918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342918, CurrentID=0, Status='live', Symbol='C19orf81', Aliases=[], description='chromosome 19 open reading frame 81', other_designations='putative uncharacterized protein C19orf81', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50649445, end_position_on_the_genomic_accession=50659306, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    342926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342926, CurrentID=0, Status='live', Symbol='ZNF677', Aliases=[], description='zinc finger protein 677', other_designations='zinc finger protein 677|hypothetical protein MGC48625', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53235381, end_position_on_the_genomic_accession=53254873, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    342931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342931, CurrentID=0, Status='live', Symbol='RFPL4A', Aliases=['RFPL4', 'RNF210'], description='ret finger protein like 4A', other_designations='ret finger protein-like 4A|RING finger protein 210|ret finger protein-like 4', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55757298, end_position_on_the_genomic_accession=55763421, orientation='plus', exon_count=4, OMIM=[612601], no_hdr0=''),
    342933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342933, CurrentID=0, Status='live', Symbol='ZSCAN5B', Aliases=['ZNF371', 'ZNF495B'], description='zinc finger and SCAN domain containing 5B', other_designations='zinc finger and SCAN domain-containing protein 5B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56189686, end_position_on_the_genomic_accession=56197890, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    342945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342945, CurrentID=0, Status='live', Symbol='ZSCAN22', Aliases=['HKR2', 'ZNF50'], description='zinc finger and SCAN domain containing 22', other_designations='zinc finger and SCAN domain-containing protein 22|GLI-Kruppel family member HKR2|krueppel-related zinc finger protein 2|zinc finger protein 50', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58326994, end_position_on_the_genomic_accession=58342336, orientation='plus', exon_count=4, OMIM=[165260], no_hdr0=''),
    342977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342977, CurrentID=0, Status='live', Symbol='NANOS3', Aliases=['NANOS1L', 'NOS3', 'ZC2HC12C'], description='nanos C2HC-type zinc finger 3', other_designations='nanos homolog 3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13862036, end_position_on_the_genomic_accession=13880757, orientation='plus', exon_count=4, OMIM=[608229], no_hdr0=''),
    342979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=342979, CurrentID=0, Status='live', Symbol='PALM3', Aliases=[], description='paralemmin 3', other_designations='paralemmin-3', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14053367, end_position_on_the_genomic_accession=14062137, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    343035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343035, CurrentID=0, Status='live', Symbol='RD3', Aliases=['C1orf36', 'LCA12'], description='RD3 regulator of GUCY2D', other_designations='protein RD3|retinal degeneration 3, GUCY2D regulator|retinal degeneration protein 3', map_location='1q32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=211476522, end_position_on_the_genomic_accession=211492162, orientation='minus', exon_count=3, OMIM=[180040], no_hdr0=''),
    343066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343066, CurrentID=0, Status='live', Symbol='AADACL4', Aliases=[], description='arylacetamide deacetylase like 4', other_designations='arylacetamide deacetylase-like 4', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12644085, end_position_on_the_genomic_accession=12667076, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    343068 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343068, CurrentID=0, Status='live', Symbol='PRAMEF5', Aliases=['PRAMEF23L', 'PRAMEF5'], description='PRAME family member 5', other_designations='PRAME family member 5|PRAME family member 23', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13254197, end_position_on_the_genomic_accession=13263435, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    343069 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343069, CurrentID=0, Status='live', Symbol='HNRNPCL1', Aliases=['HNRPCL1'], description='heterogeneous nuclear ribonucleoprotein C like 1', other_designations='heterogeneous nuclear ribonucleoprotein C-like 1|hnRNP C-like-1|hnRNP core protein C-like 1', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12847377, end_position_on_the_genomic_accession=12848720, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    343070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343070, CurrentID=0, Status='live', Symbol='PRAMEF9', Aliases=[], description='PRAME family member 9', other_designations='PRAME family member 9/15', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13171848, end_position_on_the_genomic_accession=13179459, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    343071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343071, CurrentID=0, Status='live', Symbol='PRAMEF10', Aliases=[], description='PRAME family member 10', other_designations='PRAME family member 10', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12892896, end_position_on_the_genomic_accession=12898270, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    343099 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343099, CurrentID=0, Status='live', Symbol='CCDC18', Aliases=['NY-SAR-41'], description='coiled-coil domain containing 18', other_designations='coiled-coil domain-containing protein 18|sarcoma antigen NY-SAR-24|sarcoma antigen NY-SAR-41', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=93179802, end_position_on_the_genomic_accession=93279037, orientation='plus', exon_count=36, OMIM=[], no_hdr0=''),
    343169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343169, CurrentID=0, Status='live', Symbol='OR6F1', Aliases=['OR1-34', 'OR1-38', 'OST731'], description='olfactory receptor family 6 subfamily F member 1', other_designations='olfactory receptor 6F1|olfactory receptor OR1-34 pseudogene|olfactory receptor OR1-38', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247711436, end_position_on_the_genomic_accession=247716646, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    343170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343170, CurrentID=0, Status='live', Symbol='OR14K1', Aliases=['OR1-39', 'OR1.5.9', 'OR5AY1'], description='olfactory receptor family 14 subfamily K member 1', other_designations='olfactory receptor 14K1|olfactory receptor 5AY1|olfactory receptor OR1-39|olfactory receptor, family 5, subfamily AY, member 1', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247738615, end_position_on_the_genomic_accession=247739559, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    343171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343171, CurrentID=0, Status='live', Symbol='OR2W3', Aliases=['OR2W3P', 'OR2W8P', 'OST718'], description='olfactory receptor family 2 subfamily W member 3', other_designations='olfactory receptor 2W3|olfactory receptor 2W8|olfactory receptor OR1-49|olfactory receptor, family 2, subfamily W, member 3 pseudogene|olfactory receptor, family 2, subfamily W, member 8 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247895587, end_position_on_the_genomic_accession=247896531, orientation='plus', exon_count=1, OMIM=[616729], no_hdr0=''),
    343172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343172, CurrentID=0, Status='live', Symbol='OR2T8', Aliases=['OR2T8P'], description='olfactory receptor family 2 subfamily T member 8', other_designations='olfactory receptor 2T8|olfactory receptor, family 2, subfamily T, member 8 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247920252, end_position_on_the_genomic_accession=247923152, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    343173 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343173, CurrentID=0, Status='live', Symbol='OR2T3', Aliases=[], description='olfactory receptor family 2 subfamily T member 3', other_designations='olfactory receptor 2T3|seven transmembrane helix receptor', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248473351, end_position_on_the_genomic_accession=248474307, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    343263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343263, CurrentID=0, Status='live', Symbol='MYBPHL', Aliases=[], description='myosin binding protein H like', other_designations='myosin-binding protein H-like', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=109292365, end_position_on_the_genomic_accession=109309394, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    343406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343406, CurrentID=0, Status='live', Symbol='OR10R2', Aliases=['OR1-8Q', 'OR10R2'], description='olfactory receptor family 10 subfamily R member 2', other_designations='olfactory receptor 10R2|olfactory receptor OR1-8', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158479878, end_position_on_the_genomic_accession=158480885, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    343413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343413, CurrentID=0, Status='live', Symbol='FCRL6', Aliases=['FcRH6'], description='Fc receptor like 6', other_designations='Fc receptor-like protein 6|Fc receptor-like protein 7|IFGP6|IgSF type I transmembrane receptor|fc receptor homolog 6|fcR-like protein 6|leukocyte receptor', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159800506, end_position_on_the_genomic_accession=159816257, orientation='plus', exon_count=11, OMIM=[613562], no_hdr0=''),
    343450 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343450, CurrentID=0, Status='live', Symbol='KCNT2', Aliases=['DEE57', 'EIEE57', 'KCa4.2', 'SLICK', 'SLO2.1'], description='potassium sodium-activated channel subfamily T member 2', other_designations='potassium channel subfamily T member 2|potassium channel, subfamily T, member 2|sequence like an intermediate conductance potassium channel subunit|sodium and chloride-activated ATP-sensitive potassium channel Slo2.1|sodium-and chloride-activated ATP-sensitive potassium channel (SLICK)', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=196225779, end_position_on_the_genomic_accession=196608560, orientation='minus', exon_count=35, OMIM=[610044], no_hdr0=''),
    343472 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343472, CurrentID=0, Status='live', Symbol='BARHL2', Aliases=[], description='BarH like homeobox 2', other_designations='barH-like 2 homeobox protein', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=90711539, end_position_on_the_genomic_accession=90717302, orientation='minus', exon_count=3, OMIM=[605212], no_hdr0=''),
    343521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343521, CurrentID=0, Status='live', Symbol='DYNLT4', Aliases=['TCTEX1D4'], description='dynein light chain Tctex-type 4', other_designations='dynein light chain Tctex-type 4|Tctex1 domain containing 4|Tctex2 beta|novel Tctex-1 family domain-containing protein|protein N22.1|tctex-2-beta|tctex1 domain-containing protein 4', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44805893, end_position_on_the_genomic_accession=44807351, orientation='minus', exon_count=3, OMIM=[611713], no_hdr0=''),
    343563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343563, CurrentID=0, Status='live', Symbol='OR2T29', Aliases=[], description='olfactory receptor family 2 subfamily T member 29', other_designations='olfactory receptor 2T29', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248556912, end_position_on_the_genomic_accession=248562772, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    343578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343578, CurrentID=0, Status='live', Symbol='ARHGAP40', Aliases=['C20orf95', 'dJ1100H13.4'], description='Rho GTPase activating protein 40', other_designations='rho GTPase-activating protein 40|rho-type GTPase-activating protein 40', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=38601809, end_position_on_the_genomic_accession=38650653, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    343637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343637, CurrentID=0, Status='live', Symbol='RSPO4', Aliases=['C20orf182', 'CRISTIN4'], description='R-spondin 4', other_designations='R-spondin-4|R-spondin family, member 4|hRspo4|roof plate-specific spondin-4', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=958452, end_position_on_the_genomic_accession=1002311, orientation='minus', exon_count=5, OMIM=[610573], no_hdr0=''),
    343641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343641, CurrentID=0, Status='live', Symbol='TGM6', Aliases=['SCA35', 'TG6', 'TGM3L', 'TGY', 'dJ734P14.3'], description='transglutaminase 6', other_designations='protein-glutamine gamma-glutamyltransferase 6|TGase Y|TGase-6|transglutaminase y', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2380901, end_position_on_the_genomic_accession=2432753, orientation='plus', exon_count=13, OMIM=[613900], no_hdr0=''),
    343702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343702, CurrentID=0, Status='live', Symbol='XKR7', Aliases=['C20orf159', 'dJ310O13.4'], description='XK related 7', other_designations='XK-related protein 7|X Kell blood group precursor-related family, member 7|X-linked Kx blood group related 7|XK, Kell blood group complex subunit-related family, member 7', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=31968151, end_position_on_the_genomic_accession=32003387, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    343930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343930, CurrentID=0, Status='live', Symbol='MSGN1', Aliases=['MSOG', 'pMsgn1'], description='mesogenin 1', other_designations='mesogenin-1|pMesogenin1|paraxial mesoderm-specific mesogenin1', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17816460, end_position_on_the_genomic_accession=17817798, orientation='plus', exon_count=1, OMIM=[612209], no_hdr0=''),
    343990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=343990, CurrentID=0, Status='live', Symbol='CRACDL', Aliases=['C2orf55', 'KIAA1211L'], description='CRACD like', other_designations='CRACD-like protein|KIAA1211 like|uncharacterized protein C2orf55', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98793846, end_position_on_the_genomic_accession=98936225, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    344018 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344018, CurrentID=0, Status='live', Symbol='FIGLA', Aliases=['BHLHC8', 'FIGALPHA', 'POF6'], description='folliculogenesis specific bHLH transcription factor', other_designations='factor in the germline alpha|class C basic helix-loop-helix protein 8|folliculogenesis-specific basic helix-loop-helix protein|transcription factor FIGa', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=70777310, end_position_on_the_genomic_accession=70790643, orientation='minus', exon_count=5, OMIM=[608697], no_hdr0=''),
    344022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344022, CurrentID=0, Status='live', Symbol='NOTO', Aliases=[], description='notochord homeobox', other_designations='homeobox protein notochord|notochord homolog', map_location='2p13.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73202574, end_position_on_the_genomic_accession=73212513, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    344148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344148, CurrentID=0, Status='live', Symbol='NCKAP5', Aliases=['ERIH1', 'ERIH2', 'NAP5'], description='NCK associated protein 5', other_designations='nck-associated protein 5|NAP-5|peripheral clock protein 2', map_location='2q21.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=132671788, end_position_on_the_genomic_accession=133675182, orientation='minus', exon_count=30, OMIM=[608789], no_hdr0=''),
    344167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344167, CurrentID=0, Status='live', Symbol='FOXI3', Aliases=[], description='forkhead box I3', other_designations='forkhead box protein I3', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=88446787, end_position_on_the_genomic_accession=88452693, orientation='minus', exon_count=2, OMIM=[612351], no_hdr0=''),
    344191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344191, CurrentID=0, Status='live', Symbol='EVX2', Aliases=['EVX-2'], description='even-skipped homeobox 2', other_designations='homeobox even-skipped homolog protein 2|eve, even-skipped homeo box homolog 2|even-skipped homeo box 2 (homolog of Drosophila eve)', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176077472, end_position_on_the_genomic_accession=176083962, orientation='minus', exon_count=3, OMIM=[142991], no_hdr0=''),
    344387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344387, CurrentID=0, Status='live', Symbol='CDKL4', Aliases=[], description='cyclin dependent kinase like 4', other_designations='cyclin-dependent kinase-like 4', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=39168045, end_position_on_the_genomic_accession=39248835, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    344558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344558, CurrentID=0, Status='live', Symbol='SH3RF3', Aliases=['POSH2', 'SH3MD4'], description='SH3 domain containing ring finger 3', other_designations='E3 ubiquitin-protein ligase SH3RF3|SH3 domain-containing RING finger protein 3|SH3 multiple domains 4|plenty of SH3s-2', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109129205, end_position_on_the_genomic_accession=109504635, orientation='plus', exon_count=12, OMIM=[618933], no_hdr0=''),
    344561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344561, CurrentID=0, Status='live', Symbol='GPR148', Aliases=['BTR', 'PGR6'], description='G protein-coupled receptor 148', other_designations='probable G-protein coupled receptor 148|G protein-coupled receptor PGR6|brain and testis restricted GPCR', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130729070, end_position_on_the_genomic_accession=130730336, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    344657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344657, CurrentID=0, Status='live', Symbol='LRRIQ4', Aliases=['LRRC64'], description='leucine rich repeats and IQ motif containing 4', other_designations='leucine-rich repeat and IQ domain-containing protein 4|leucine rich repeat containing 64', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169812870, end_position_on_the_genomic_accession=169838007, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    344658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344658, CurrentID=0, Status='live', Symbol='SAMD7', Aliases=[], description='sterile alpha motif domain containing 7', other_designations='sterile alpha motif domain-containing protein 7|SAM domain-containing protein 7', map_location='3q26.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=169911572, end_position_on_the_genomic_accession=169939175, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    344752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344752, CurrentID=0, Status='live', Symbol='AADACL2', Aliases=[], description='arylacetamide deacetylase like 2', other_designations='arylacetamide deacetylase-like 2', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=151733927, end_position_on_the_genomic_accession=151761339, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    344758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344758, CurrentID=0, Status='live', Symbol='GPR149', Aliases=['IEDA', 'PGR10', 'R35'], description='G protein-coupled receptor 149', other_designations='probable G-protein coupled receptor 149|G protein-coupled receptor PGR10', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=154334943, end_position_on_the_genomic_accession=154430190, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    344787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344787, CurrentID=0, Status='live', Symbol='ZNF860', Aliases=[], description='zinc finger protein 860', other_designations='zinc finger protein 860', map_location='3p23-p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=31981750, end_position_on_the_genomic_accession=32005112, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    344805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344805, CurrentID=0, Status='live', Symbol='TMPRSS7', Aliases=[], description='transmembrane serine protease 7', other_designations='transmembrane protease serine 7|matriptase-3|transmembrane protease, serine 7|type II transmembrane serine protease 7', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112039067, end_position_on_the_genomic_accession=112081269, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    344807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344807, CurrentID=0, Status='live', Symbol='CD200R1L', Aliases=['CD200R2', 'CD200RLa'], description='CD200 receptor 1 like', other_designations='cell surface glycoprotein CD200 receptor 2|CD200 cell surface glycoprotein receptor 2|CD200 cell surface glycoprotein receptor-like 2|CD200 cell surface glycoprotein receptor-like a|CD200 receptor 2|CD200 receptor-like 2|cell surface glycoprotein CD200 receptor 1-like|cell surface glycoprotein OX2 receptor 2', map_location='3q13.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=112815711, end_position_on_the_genomic_accession=112846864, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    344838 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344838, CurrentID=0, Status='live', Symbol='PAQR9', Aliases=['BLNC1'], description='progestin and adipoQ receptor family member 9', other_designations='membrane progestin receptor epsilon|brown fat long noncoding RNA|mPR epsilon|membrane progesterone P4 receptor epsilon|membrane progesterone receptor epsilon|progesterone and adipoQ receptor family member 9|progestin and adipoQ receptor family member IX', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=142949164, end_position_on_the_genomic_accession=142964008, orientation='minus', exon_count=5, OMIM=[614580], no_hdr0=''),
    344892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344892, CurrentID=0, Status='live', Symbol='RTP2', Aliases=['Z3CXXC2'], description='receptor transporter protein 2', other_designations='receptor-transporting protein 2|3CxxC-type zinc finger protein 2|receptor (chemosensory) transporter protein 2|zinc finger, 3CxxC-type 2', map_location='3q27.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=187698259, end_position_on_the_genomic_accession=187715625, orientation='minus', exon_count=5, OMIM=[609138], no_hdr0=''),
    344901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344901, CurrentID=0, Status='live', Symbol='OSTN', Aliases=['MUSCLIN'], description='osteocrin', other_designations='osteocrin', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=191199241, end_position_on_the_genomic_accession=191265615, orientation='plus', exon_count=6, OMIM=[610280], no_hdr0=''),
    344905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=344905, CurrentID=0, Status='live', Symbol='ATP13A5', Aliases=[], description='ATPase 13A5', other_designations='probable cation-transporting ATPase 13A5|ATPase type 13A5|P5-ATPase', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=193274789, end_position_on_the_genomic_accession=193378820, orientation='minus', exon_count=31, OMIM=[619119], no_hdr0=''),
    345051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345051, CurrentID=0, Status='live', Symbol='REELD1', Aliases=[], description='reeler domain containing 1', other_designations='reelin domain-containing protein 1', map_location='4q31.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=146214538, end_position_on_the_genomic_accession=146232267, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    345062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345062, CurrentID=0, Status='live', Symbol='PRSS48', Aliases=['ESSPL'], description='serine protease 48', other_designations='serine protease 48|epidermis-specific serine protease-like protein|protease, serine 48|testicular tissue protein Li 65', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=151276482, end_position_on_the_genomic_accession=151291862, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    345079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345079, CurrentID=0, Status='live', Symbol='SOWAHB', Aliases=['ANKRD56'], description='sosondowah ankyrin repeat domain family member B', other_designations='ankyrin repeat domain-containing protein SOWAHB|ankyrin repeat domain 56|ankyrin repeat domain-containing protein 56|protein sosondowah homolog B', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76894152, end_position_on_the_genomic_accession=76898144, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    345193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345193, CurrentID=0, Status='live', Symbol='LRIT3', Aliases=['CSNB1F', 'FIGLER4'], description='leucine rich repeat, Ig-like and transmembrane domains 3', other_designations='leucine-rich repeat, immunoglobulin-like domain and transmembrane domain-containing protein 3|fibronectin type III, immunoglobulin and leucine rich repeat domains 4|leucine-rich repeat, immunoglobulin-like and transmembrane domains 3', map_location='4q25', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=109848107, end_position_on_the_genomic_accession=109872315, orientation='plus', exon_count=5, OMIM=[615004], no_hdr0=''),
    345222 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345222, CurrentID=0, Status='live', Symbol='MSANTD1', Aliases=['C4orf44'], description='Myb/SANT DNA binding domain containing 1', other_designations='myb/SANT-like DNA-binding domain-containing protein 1|Myb/SANT-like DNA-binding domain containing 1', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=3241598, end_position_on_the_genomic_accession=3256613, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    345274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345274, CurrentID=0, Status='live', Symbol='SLC10A6', Aliases=['SOAT'], description='solute carrier family 10 member 6', other_designations='solute carrier family 10 member 6|sodium-dependent organic anion transporter|solute carrier family 10 (sodium/bile acid cotransporter family), member 6|solute carrier family 10 (sodium/bile acid cotransporter), member 6', map_location='4q21.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=86823468, end_position_on_the_genomic_accession=86849384, orientation='minus', exon_count=6, OMIM=[613366], no_hdr0=''),
    345275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345275, CurrentID=0, Status='live', Symbol='HSD17B13', Aliases=['HMFN0376', 'NIIL497', 'SCDR9', 'SDR16C3'], description='hydroxysteroid 17-beta dehydrogenase 13', other_designations='17-beta-hydroxysteroid dehydrogenase 13|17-beta hydroxysteroid dehydrogenase|17-beta-HSD 13|short chain dehydrogenase/reductase family 16C member 3|short-chain dehydrogenase/reductase 9', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=87303794, end_position_on_the_genomic_accession=87322882, orientation='minus', exon_count=7, OMIM=[612127], no_hdr0=''),
    345456 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345456, CurrentID=0, Status='live', Symbol='PFN3', Aliases=[], description='profilin 3', other_designations='profilin-3|profilin III', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=177400109, end_position_on_the_genomic_accession=177400661, orientation='minus', exon_count=1, OMIM=[612812], no_hdr0=''),
    345462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345462, CurrentID=0, Status='live', Symbol='ZNF879', Aliases=['DKFZp686E2433'], description='zinc finger protein 879', other_designations='zinc finger protein 879', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179023759, end_position_on_the_genomic_accession=179035064, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    345557 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345557, CurrentID=0, Status='live', Symbol='PLCXD3', Aliases=[], description='phosphatidylinositol specific phospholipase C X domain containing 3', other_designations='PI-PLC X domain-containing protein 3', map_location='5p13.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=41306952, end_position_on_the_genomic_accession=41510601, orientation='minus', exon_count=6, OMIM=[617016], no_hdr0=''),
    345611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345611, CurrentID=0, Status='live', Symbol='IRGM', Aliases=['IFI11', 'LRG-47', 'LRG47', 'IRGM'], description='immunity related GTPase M', other_designations='immunity-related GTPase family M protein|LPS-stimulated RAW 264.7 macrophage protein 47 homolog|LRG-47-like protein|immunity-related GTPase family, M1|interferon-inducible protein 1', map_location='5q33.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=150846521, end_position_on_the_genomic_accession=150902402, orientation='plus', exon_count=5, OMIM=[608212], no_hdr0=''),
    345630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345630, CurrentID=0, Status='live', Symbol='FBLL1', Aliases=[], description='fibrillarin like 1', other_designations="rRNA/tRNA 2'-O-methyltransferase fibrillarin-like protein 1|protein-glutamine methyltransferase", map_location='5q34', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=168529305, end_position_on_the_genomic_accession=168530634, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    345643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345643, CurrentID=0, Status='live', Symbol='MCIDAS', Aliases=['CILD42', 'IDAS', 'MCI', 'MCIN'], description='multiciliate differentiation and DNA synthesis associated cell cycle protein', other_designations='multicilin|multiciliate cell differentiation 1|protein Idas', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55218791, end_position_on_the_genomic_accession=55227315, orientation='minus', exon_count=6, OMIM=[614086], no_hdr0=''),
    345651 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345651, CurrentID=0, Status='live', Symbol='ACTBL2', Aliases=['ACT'], description='actin beta like 2', other_designations='beta-actin-like protein 2|actin-like protein|kappa-actin', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=57480018, end_position_on_the_genomic_accession=57482811, orientation='minus', exon_count=1, OMIM=[614835], no_hdr0=''),
    345757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345757, CurrentID=0, Status='live', Symbol='FAM174A', Aliases=['HGS_RE408', 'NS5ATP6', 'TMEM157', 'UNQ1912'], description='family with sequence similarity 174 member A', other_designations='membrane protein FAM174A|HCV NS5A-transactivated protein 6|hepatitis C virus NS5A-transactivated protein 6|hepatitis C virus nonstructural protein 5A trans-activated protein 6|transmembrane protein 157', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=100535347, end_position_on_the_genomic_accession=100586741, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    345778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345778, CurrentID=0, Status='live', Symbol='MTX3', Aliases=[], description='metaxin 3', other_designations='metaxin-3', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=79976716, end_position_on_the_genomic_accession=79991262, orientation='minus', exon_count=9, OMIM=[619336], no_hdr0=''),
    345895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345895, CurrentID=0, Status='live', Symbol='RSPH4A', Aliases=['CILD11', 'RSHL3', 'RSPH6B', 'dJ412I7.1'], description='radial spoke head component 4A', other_designations='radial spoke head protein 4 homolog A|radial spoke head 4 homolog A|radial spoke head-like protein 3|radial spokehead-like 3', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116598184, end_position_on_the_genomic_accession=116633051, orientation='plus', exon_count=7, OMIM=[612647], no_hdr0=''),
    345930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=345930, CurrentID=0, Status='live', Symbol='ECT2L', Aliases=['ARHGEF32', 'C6orf91', 'FBXO49', 'LFDH', 'dJ509I19.2', 'dJ509I19.3', 'dJ509I19.5'], description='epithelial cell transforming 2 like', other_designations='epithelial cell-transforming sequence 2 oncogene-like|ECT2-like|F-box protein 49|lung specific F-box and DH domain containing protein|putative guanine nucleotide exchange factor LFDH', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138796087, end_position_on_the_genomic_accession=138904070, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    346007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346007, CurrentID=0, Status='live', Symbol='EYS', Aliases=['C6orf178', 'C6orf179', 'C6orf180', 'EGFL10', 'EGFL11', 'RP25', 'SPAM', 'bA166P24.2', 'bA307F22.3', 'bA74E24.1', 'dJ1018A4.2', 'dJ22I17.2', 'dJ303F19.1'], description='eyes shut homolog', other_designations='protein eyes shut homolog|EGF-like-domain, multiple 10|EGF-like-domain, multiple 11|epidermal growth factor-like protein 10|epidermal growth factor-like protein 11|protein spacemaker homolog', map_location='6q12', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=63719980, end_position_on_the_genomic_accession=65707226, orientation='minus', exon_count=46, OMIM=[612424], no_hdr0=''),
    346157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346157, CurrentID=0, Status='live', Symbol='ZNF391', Aliases=['dJ153G14.3'], description='zinc finger protein 391', other_designations='zinc finger protein 391', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27374615, end_position_on_the_genomic_accession=27403908, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    346171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346171, CurrentID=0, Status='live', Symbol='ZFP57', Aliases=['C6orf40', 'TNDM1', 'ZNF698', 'bA145L22', 'bA145L22.2'], description='ZFP57 zinc finger protein', other_designations='zinc finger protein 57 homolog|zfp-57|zinc finger protein 698', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29672392, end_position_on_the_genomic_accession=29681152, orientation='minus', exon_count=5, OMIM=[612192], no_hdr0=''),
    346288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346288, CurrentID=0, Status='live', Symbol='SEPTIN14', Aliases=['SEPT14'], description='septin 14', other_designations='septin-14', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55793540, end_position_on_the_genomic_accession=55862752, orientation='minus', exon_count=11, OMIM=[612140], no_hdr0=''),
    346389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346389, CurrentID=0, Status='live', Symbol='MACC1', Aliases=['7A5', 'SH3BP4L'], description='MET transcriptional regulator MACC1', other_designations='metastasis-associated in colon cancer protein 1|MACC1, MET transcriptional regulator|SH3 domain-containing protein 7a5|metastasis associated in colon cancer 1|putative binding protein 7a5', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=20134655, end_position_on_the_genomic_accession=20217384, orientation='minus', exon_count=7, OMIM=[612646], no_hdr0=''),
    346517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346517, CurrentID=0, Status='live', Symbol='OR6V1', Aliases=['GPR138'], description='olfactory receptor family 6 subfamily V member 1', other_designations='olfactory receptor 6V1|olfactory receptor OR7-3', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143052341, end_position_on_the_genomic_accession=143053282, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    346525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346525, CurrentID=0, Status='live', Symbol='OR2A12', Aliases=['OR2A12P', 'OR2A16P'], description='olfactory receptor family 2 subfamily A member 12', other_designations='olfactory receptor 2A12|olfactory receptor OR7-10|olfactory receptor, family 2, subfamily A, member 12 pseudogene|olfactory receptor, family 2, subfamily A, member 16 pseudogene', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144086278, end_position_on_the_genomic_accession=144098953, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    346528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346528, CurrentID=0, Status='live', Symbol='OR2A1', Aliases=[], description='olfactory receptor family 2 subfamily A member 1', other_designations='olfactory receptor 2A1/2A42|olfactory receptor OR7-16|olfactory receptor OR7-19', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144312419, end_position_on_the_genomic_accession=144322737, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    346562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346562, CurrentID=0, Status='live', Symbol='GNAT3', Aliases=['GDCA'], description='G protein subunit alpha transducin 3', other_designations='guanine nucleotide-binding protein G(t) subunit alpha-3|guanine nucleotide binding protein, alpha transducing 3|gustatory G protein|gustducin alpha-3 chain|gustducin, alpha polypeptide', map_location='7q21.11', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=80458635, end_position_on_the_genomic_accession=80512064, orientation='minus', exon_count=8, OMIM=[139395], no_hdr0=''),
    346606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346606, CurrentID=0, Status='live', Symbol='MOGAT3', Aliases=['DC7', 'DGAT2L2', 'MGAT3'], description='monoacylglycerol O-acyltransferase 3', other_designations='2-acylglycerol O-acyltransferase 3|acyl coenzyme A:monoacylglycerol acyltransferase 3|acyl-CoA:monoacylglycerol acyltransferase 3|diacylglycerol O-acyltransferase candidate 7|diacylglycerol acyltransferase 2-like protein 7', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101192886, end_position_on_the_genomic_accession=101201131, orientation='minus', exon_count=8, OMIM=[610184], no_hdr0=''),
    346653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346653, CurrentID=0, Status='live', Symbol='FAM71F2', Aliases=['FAM137B'], description='family with sequence similarity 71 member F2', other_designations='protein FAM71F2|family with sequence similarity 137, member B', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128671628, end_position_on_the_genomic_accession=128702262, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    346673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346673, CurrentID=0, Status='live', Symbol='STRA8', Aliases=[], description='stimulated by retinoic acid 8', other_designations='stimulated by retinoic acid gene 8 protein homolog', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135231915, end_position_on_the_genomic_accession=135258663, orientation='plus', exon_count=11, OMIM=[609987], no_hdr0=''),
    346689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346689, CurrentID=0, Status='live', Symbol='KLRG2', Aliases=['CLEC15B'], description='killer cell lectin like receptor G2', other_designations='killer cell lectin-like receptor subfamily G member 2|C-type lectin domain family 15 member B|killer cell lectin-like receptor subfamily G, member 2', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139426931, end_position_on_the_genomic_accession=139483716, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    346702 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=346702, CurrentID=0, Status='live', Symbol='PRSS51', Aliases=[], description='serine protease 51', other_designations='serine protease-like protein 51|protease, serine 51', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    347051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347051, CurrentID=0, Status='live', Symbol='SLC10A5', Aliases=['P5'], description='solute carrier family 10 member 5', other_designations='sodium/bile acid cotransporter 5|Na(+)/bile acid cotransporter 5|solute carrier family 10 (sodium/bile acid cotransporter family), member 5', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81693631, end_position_on_the_genomic_accession=81695058, orientation='minus', exon_count=1, OMIM=[618582], no_hdr0=''),
    347088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347088, CurrentID=0, Status='live', Symbol='ADGRD2', Aliases=['GPR144', 'PGR24'], description='adhesion G protein-coupled receptor D2', other_designations='adhesion G-protein coupled receptor D2|G protein-coupled receptor PGR24|G-protein coupled receptor 144|G-protein coupled receptor GPR144', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124451087, end_position_on_the_genomic_accession=124477795, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    347148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347148, CurrentID=0, Status='live', Symbol='QRFP', Aliases=['26RFa', 'P518'], description='pyroglutamylated RFamide peptide', other_designations='orexigenic neuropeptide QRFP|P518 precursor protein|RF(Arg-Phe)amide family 26 amino acid peptide (P518)|prepro-26RFa|prepro-QRFP', map_location='9q34.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=130892707, end_position_on_the_genomic_accession=130896812, orientation='minus', exon_count=3, OMIM=[609795], no_hdr0=''),
    347168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347168, CurrentID=0, Status='live', Symbol='OR1J1', Aliases=['OR9-18', 'hg32'], description='olfactory receptor family 1 subfamily J member 1', other_designations='olfactory receptor 1J1|olfactory receptor OR9-18', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122476958, end_position_on_the_genomic_accession=122477926, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    347169 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347169, CurrentID=0, Status='live', Symbol='OR1B1', Aliases=['OR9-26', 'OR9-B'], description='olfactory receptor family 1 subfamily B member 1', other_designations='olfactory receptor 1B1|olfactory receptor 9-B|olfactory receptor OR9-26', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122628069, end_position_on_the_genomic_accession=122657626, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    347240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347240, CurrentID=0, Status='live', Symbol='KIF24', Aliases=['C9orf48', 'bA571F15.4'], description='kinesin family member 24', other_designations='kinesin-like protein KIF24', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34252033, end_position_on_the_genomic_accession=34333520, orientation='minus', exon_count=17, OMIM=[613747], no_hdr0=''),
    347252 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347252, CurrentID=0, Status='live', Symbol='IGFBPL1', Aliases=['IGFBP-RP4', 'IGFBPRP4', 'bA113O24.1'], description='insulin like growth factor binding protein like 1', other_designations='insulin-like growth factor-binding protein-like 1|IGFBP-related protein 10|insulin-like growth factor binding protein related protein 4|insulin-like growth factor-binding-related protein 4', map_location='9p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=38406528, end_position_on_the_genomic_accession=38424454, orientation='minus', exon_count=6, OMIM=[610413], no_hdr0=''),
    347273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347273, CurrentID=0, Status='live', Symbol='CAVIN4', Aliases=['MURC', 'cavin-4'], description='caveolae associated protein 4', other_designations='caveolae-associated protein 4|muscle related coiled-coil protein|muscle-restricted coiled-coil protein', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100578079, end_position_on_the_genomic_accession=100588389, orientation='plus', exon_count=2, OMIM=[617714], no_hdr0=''),
    347344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347344, CurrentID=0, Status='live', Symbol='ZNF81', Aliases=['HFZ20', 'MRX45', 'dJ54B20.6'], description='zinc finger protein 81', other_designations='zinc finger protein 81', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=47836902, end_position_on_the_genomic_accession=47925627, orientation='plus', exon_count=7, OMIM=[314998], no_hdr0=''),
    347365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347365, CurrentID=0, Status='live', Symbol='ITIH6', Aliases=['ITIH5L', 'UNQ6369', 'dJ14O9.1'], description='inter-alpha-trypsin inhibitor heavy chain family member 6', other_designations='inter-alpha-trypsin inhibitor heavy chain H6|ITI-like protein|inter-alpha inhibitor H5-like protein|inter-alpha-trypsin inhibitor heavy chain H5-like protein', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=54748918, end_position_on_the_genomic_accession=54798255, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    347404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347404, CurrentID=0, Status='live', Symbol='LANCL3', Aliases=[], description='LanC like 3', other_designations='lanC-like protein 3|LanC lantibiotic synthetase component C-like 3', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37571661, end_position_on_the_genomic_accession=37684463, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    347411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347411, CurrentID=0, Status='live', Symbol='MPC1L', Aliases=['SLC54A3'], description='mitochondrial pyruvate carrier 1 like', other_designations='mitochondrial pyruvate carrier 1-like protein|brain protein 44-like protein 2', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=40623428, end_position_on_the_genomic_accession=40624136, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    347442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347442, CurrentID=0, Status='live', Symbol='DCAF8L2', Aliases=['WDR42C'], description='DDB1 and CUL4 associated factor 8 like 2', other_designations='DDB1- and CUL4-associated factor 8-like protein 2|WD repeat domain 42C|WD repeat-containing protein 42C', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=27468941, end_position_on_the_genomic_accession=27749942, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    347454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347454, CurrentID=0, Status='live', Symbol='SOWAHD', Aliases=['ANKRD58'], description='sosondowah ankyrin repeat domain family member D', other_designations='ankyrin repeat domain-containing protein SOWAHD|ankyrin repeat domain 58|ankyrin repeat domain-containing protein 58|protein sosondowah homolog D', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=119758588, end_position_on_the_genomic_accession=119760202, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    347468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347468, CurrentID=0, Status='live', Symbol='OR13H1', Aliases=['ORX1'], description='olfactory receptor family 13 subfamily H member 1', other_designations='olfactory receptor 13H1|olfactory receptor ORX-1|olfactory receptor ORX1', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=131544074, end_position_on_the_genomic_accession=131545000, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    347475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347475, CurrentID=0, Status='live', Symbol='CCDC160', Aliases=[], description='coiled-coil domain containing 160', other_designations='coiled-coil domain-containing protein 160|UPF0625 coiled-coil domain-containing protein ENSP00000359845', map_location='Xq26.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134237182, end_position_on_the_genomic_accession=134246207, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    347487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347487, CurrentID=0, Status='live', Symbol='CXorf66', Aliases=['SGPX'], description='chromosome X open reading frame 66', other_designations='uncharacterized protein CXorf66|RP11-35F15.2|secreted glycoprotein, X-linked', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=139955728, end_position_on_the_genomic_accession=139965521, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    347516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347516, CurrentID=0, Status='live', Symbol='DGAT2L6', Aliases=['DC3'], description='diacylglycerol O-acyltransferase 2 like 6', other_designations='diacylglycerol O-acyltransferase 2-like protein 6|diacylglycerol O-acyltransferase candidate 3', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70177483, end_position_on_the_genomic_accession=70205704, orientation='plus', exon_count=7, OMIM=[300926], no_hdr0=''),
    347517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347517, CurrentID=0, Status='live', Symbol='RAB41', Aliases=[], description='RAB41, member RAS oncogene family', other_designations='ras-related protein Rab-41|RAB41, member RAS homolog family', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=70280592, end_position_on_the_genomic_accession=70285002, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    347527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347527, CurrentID=0, Status='live', Symbol='ARSH', Aliases=['sulfatase'], description='arylsulfatase family member H', other_designations='arylsulfatase H|ASH', map_location='Xp22.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=3006546, end_position_on_the_genomic_accession=3034111, orientation='plus', exon_count=9, OMIM=[300586], no_hdr0=''),
    347541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347541, CurrentID=0, Status='live', Symbol='MAGEB5', Aliases=['CT3.3', 'MAGE-B5'], description='MAGE family member B5', other_designations='melanoma-associated antigen B5|MAGE family testis and tumor-specific protein|MAGE-B5 antigen|cancer/testis antigen 3.3|cancer/testis antigen family 3, member 3|melanoma antigen family B, 5|melanoma antigen family B5', map_location='Xp21.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=26216169, end_position_on_the_genomic_accession=26218270, orientation='plus', exon_count=2, OMIM=[300466], no_hdr0=''),
    347549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347549, CurrentID=0, Status='live', Symbol='CENPVL3', Aliases=['CENPVP3'], description='centromere protein V like 3', other_designations='centromere protein V-like protein 3', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51617020, end_position_on_the_genomic_accession=51618912, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    347688 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347688, CurrentID=0, Status='live', Symbol='TUBB8', Aliases=['OOMD', 'OOMD2', 'bA631M21.2'], description='tubulin beta 8 class VIII', other_designations='tubulin beta-8 chain|HSA10p15 beta-tubulin 4Q', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46437, end_position_on_the_genomic_accession=76621, orientation='minus', exon_count=9, OMIM=[616768], no_hdr0=''),
    347730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347730, CurrentID=0, Status='live', Symbol='LRRTM1', Aliases=[], description='leucine rich repeat transmembrane neuronal 1', other_designations='leucine-rich repeat transmembrane neuronal protein 1|leucine-rich repeat transmembrane neuronal 1 protein', map_location='2p12', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=80301878, end_position_on_the_genomic_accession=80304752, orientation='minus', exon_count=2, OMIM=[610867], no_hdr0=''),
    347731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347731, CurrentID=0, Status='live', Symbol='LRRTM3', Aliases=[], description='leucine rich repeat transmembrane neuronal 3', other_designations='leucine-rich repeat transmembrane neuronal protein 3', map_location='10q21.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=66926036, end_position_on_the_genomic_accession=67101551, orientation='plus', exon_count=5, OMIM=[610869], no_hdr0=''),
    347732 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347732, CurrentID=0, Status='live', Symbol='CATSPER3', Aliases=['CACRC'], description='cation channel sperm associated 3', other_designations='cation channel sperm-associated protein 3|ca(v)-like protein|calcium channel repeat containing 1|one-repeat calcium channel-like protein|putative ion channel CatSper3', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=134967907, end_position_on_the_genomic_accession=135011696, orientation='plus', exon_count=8, OMIM=[609120], no_hdr0=''),
    347733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347733, CurrentID=0, Status='live', Symbol='TUBB2B', Aliases=['CDCBM7', 'PMGYSA', 'bA506K6.1'], description='tubulin beta 2B class IIb', other_designations='tubulin beta-2B chain|class II beta-tubulin isotype|class IIb beta-tubulin|epididymis secretory sperm binding protein|tubulin, beta 2B|tubulin, beta polypeptide paralog', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3224277, end_position_on_the_genomic_accession=3227653, orientation='minus', exon_count=4, OMIM=[612850], no_hdr0=''),
    347734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347734, CurrentID=0, Status='live', Symbol='SLC35B2', Aliases=['PAPST1', 'SLL', 'UGTrel4'], description='solute carrier family 35 member B2', other_designations="adenosine 3'-phospho 5'-phosphosulfate transporter 1|3'-phosphoadenosine 5'-phosphosulfate transporter|PAPS transporter 1|putative MAPK-activating protein PM15|putative NF-kappa-B-activating protein 48|solute carrier family 35 (adenosine 3'-phospho 5'-phosphosulfate transporter), member B2|solute carrier family 35 member B2 variant 2", map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44254101, end_position_on_the_genomic_accession=44257890, orientation='minus', exon_count=6, OMIM=[610788], no_hdr0=''),
    347735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347735, CurrentID=0, Status='live', Symbol='SERINC2', Aliases=['FKSG84', 'PRO0899', 'TDE2', 'TDE2L'], description='serine incorporator 2', other_designations='serine incorporator 2|tumor differentially expressed protein 2', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31409777, end_position_on_the_genomic_accession=31434678, orientation='plus', exon_count=14, OMIM=[614549], no_hdr0=''),
    347736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347736, CurrentID=0, Status='live', Symbol='NME9', Aliases=['NM23-H9', 'NXL2', 'TXL-2', 'TXL2', 'TXNDC6'], description='NME/NM23 family member 9', other_designations='thioredoxin domain-containing protein 6|NME gene family member 9|thioredoxin-like protein 2', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138261436, end_position_on_the_genomic_accession=138331785, orientation='minus', exon_count=17, OMIM=[618584], no_hdr0=''),
    347741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347741, CurrentID=0, Status='live', Symbol='OTOP3', Aliases=[], description='otopetrin 3', other_designations='proton channel OTOP3', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74935802, end_position_on_the_genomic_accession=74949993, orientation='plus', exon_count=7, OMIM=[607828], no_hdr0=''),
    347744 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347744, CurrentID=0, Status='live', Symbol='C6orf52', Aliases=[], description='chromosome 6 open reading frame 52', other_designations='putative uncharacterized protein C6orf52', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=10671418, end_position_on_the_genomic_accession=10694797, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    347853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347853, CurrentID=0, Status='live', Symbol='TBX10', Aliases=['TBX13', 'TBX7'], description='T-box transcription factor 10', other_designations='T-box transcription factor TBX10|T-box 10|T-box 7|T-box protein 10|T-box-containing transcriptional activator', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67631303, end_position_on_the_genomic_accession=67639763, orientation='minus', exon_count=8, OMIM=[604648], no_hdr0=''),
    347862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347862, CurrentID=0, Status='live', Symbol='GATD1', Aliases=['PDDC1'], description='glutamine amidotransferase class 1 domain containing 1', other_designations='glutamine amidotransferase-like class 1 domain-containing protein 1|Parkinson disease 7 domain containing 1|glutamine amidotransferase like class 1 domain containing 1|parkinson disease 7 domain-containing protein 1', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=767095, end_position_on_the_genomic_accession=777501, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    347902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=347902, CurrentID=0, Status='live', Symbol='AMIGO2', Aliases=['ALI1', 'AMIGO-2', 'DEGA'], description='adhesion molecule with Ig like domain 2', other_designations='amphoterin-induced protein 2|alivin 1|amphoterin induced gene 2|differentially expressed in gastric adenocarcinoma|differentially expressed in gastric adenocarcinomas|transmembrane protein AMIGO2', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=47075707, end_position_on_the_genomic_accession=47079959, orientation='minus', exon_count=3, OMIM=[615690], no_hdr0=''),
    348013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348013, CurrentID=0, Status='live', Symbol='TMEM255B', Aliases=['FAM70B'], description='transmembrane protein 255B', other_designations='transmembrane protein 255B|family with sequence similarity 70, member B|protein FAM70B', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113759217, end_position_on_the_genomic_accession=113816995, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    348093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348093, CurrentID=0, Status='live', Symbol='RBPMS2', Aliases=[], description='RNA binding protein, mRNA processing factor 2', other_designations='RNA-binding protein with multiple splicing 2|RNA binding protein with multiple splicing 2', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64739891, end_position_on_the_genomic_accession=64775589, orientation='minus', exon_count=10, OMIM=[619034], no_hdr0=''),
    348094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348094, CurrentID=0, Status='live', Symbol='ANKDD1A', Aliases=[], description='ankyrin repeat and death domain containing 1A', other_designations='ankyrin repeat and death domain-containing protein 1A', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=64911902, end_position_on_the_genomic_accession=64958691, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    348110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348110, CurrentID=0, Status='live', Symbol='ARPIN', Aliases=['C15orf38'], description='actin related protein 2/3 complex inhibitor', other_designations='arpin|UPF0552 protein C15orf38|arp2/3 inhibition protein', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89895006, end_position_on_the_genomic_accession=89912952, orientation='minus', exon_count=7, OMIM=[615543], no_hdr0=''),
    348158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348158, CurrentID=0, Status='live', Symbol='ACSM2B', Aliases=['ACSM2', 'HXMA', 'HYST1046'], description='acyl-CoA synthetase medium chain family member 2B', other_designations='acyl-coenzyme A synthetase ACSM2B, mitochondrial|acyl-CoA synthetase medium-chain family member 2|benzoate--CoA ligase|butyrate--CoA ligase 2B|butyryl-coenzyme A synthetase 2B|middle-chain acyl-CoA synthetase 2B|xenobiotic/medium-chain fatty acid-CoA ligase HXM-A|xenobiotic/medium-chain fatty acid:CoA ligase', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=20536226, end_position_on_the_genomic_accession=20576376, orientation='minus', exon_count=17, OMIM=[614359], no_hdr0=''),
    348174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348174, CurrentID=0, Status='live', Symbol='CLEC18A', Aliases=['MRCL', 'MRCL1', 'MRLP2'], description='C-type lectin domain family 18 member A', other_designations='C-type lectin domain family 18 member A|mannose receptor-like 1|mannose receptor-like protein 2|mannose receptor-like protein 3', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69950232, end_position_on_the_genomic_accession=69968478, orientation='plus', exon_count=16, OMIM=[616571], no_hdr0=''),
    348180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348180, CurrentID=0, Status='live', Symbol='CTU2', Aliases=['C16orf84', 'MFRG', 'NCS2', 'UPF0432'], description='cytosolic thiouridylase subunit 2', other_designations='cytoplasmic tRNA 2-thiolation protein 2|cytosolic thiouridylase subunit 2 homolog', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88706481, end_position_on_the_genomic_accession=88715396, orientation='plus', exon_count=15, OMIM=[617057], no_hdr0=''),
    348235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348235, CurrentID=0, Status='live', Symbol='SKA2', Aliases=['FAM33A'], description='spindle and kinetochore associated complex subunit 2', other_designations='spindle and kinetochore-associated protein 2|family with sequence similarity 33, member A|spindle and KT (kinetochore) associated 2', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59109857, end_position_on_the_genomic_accession=59155186, orientation='minus', exon_count=4, OMIM=[616674], no_hdr0=''),
    348262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348262, CurrentID=0, Status='live', Symbol='MCRIP1', Aliases=['FAM195B', 'GRAN2', 'MCRIP'], description='MAPK regulated corepressor interacting protein 1', other_designations='mapk-regulated corepressor-interacting protein 1|MAPK-regulated co-repressor interacting protein 1|family with sequence similarity 195, member B|granulin-2|protein FAM195B', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81822361, end_position_on_the_genomic_accession=81833291, orientation='minus', exon_count=7, OMIM=[616514], no_hdr0=''),
    348303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348303, CurrentID=0, Status='live', Symbol='SELENOV', Aliases=['SELV'], description='selenoprotein V', other_designations='selenoprotein V', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39515113, end_position_on_the_genomic_accession=39520686, orientation='plus', exon_count=6, OMIM=[607919], no_hdr0=''),
    348327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348327, CurrentID=0, Status='live', Symbol='ZNF530', Aliases=[], description='zinc finger protein 530', other_designations='zinc finger protein 530', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57599885, end_position_on_the_genomic_accession=57612722, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    348378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348378, CurrentID=0, Status='live', Symbol='SHISAL2A', Aliases=['FAM159A', 'PRO7171', 'WWLS2783'], description='shisa like 2A', other_designations='protein shisa-like-2A|family with sequence similarity 159 member A|membrane protein FAM159A', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52631438, end_position_on_the_genomic_accession=52669683, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    348487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348487, CurrentID=0, Status='live', Symbol='FAM131C', Aliases=['C1orf117'], description='family with sequence similarity 131 member C', other_designations='protein FAM131C', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16057769, end_position_on_the_genomic_accession=16073651, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    348654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348654, CurrentID=0, Status='live', Symbol='GEN1', Aliases=['Gen'], description="GEN1 Holliday junction 5' flap endonuclease", other_designations='flap endonuclease GEN homolog 1|Gen endonuclease homolog 1|Holliday junction resolvase', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17753687, end_position_on_the_genomic_accession=17788946, orientation='plus', exon_count=16, OMIM=[612449], no_hdr0=''),
    348751 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348751, CurrentID=0, Status='live', Symbol='FTCDNL1', Aliases=['FONG'], description='formiminotransferase cyclodeaminase N-terminal like', other_designations='formiminotransferase N-terminal subdomain-containing protein|formiminotransferase N-terminal sub-domain containing|formiminotransferase-cyclodeaminase N-terminal-like protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=199663332, end_position_on_the_genomic_accession=199851192, orientation='minus', exon_count=18, OMIM=[614308], no_hdr0=''),
    348793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348793, CurrentID=0, Status='live', Symbol='WDR53', Aliases=[], description='WD repeat domain 53', other_designations='WD repeat-containing protein 53|WD domain, G-beta repeat-containing protein', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196554177, end_position_on_the_genomic_accession=196568608, orientation='minus', exon_count=4, OMIM=[615110], no_hdr0=''),
    348801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348801, CurrentID=0, Status='live', Symbol='LNP1', Aliases=['NP3'], description='leukemia NUP98 fusion partner 1', other_designations='leukemia NUP98 fusion partner 1', map_location='3q12.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=100401539, end_position_on_the_genomic_accession=100456319, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    348807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348807, CurrentID=0, Status='live', Symbol='CFAP100', Aliases=['CCDC37', 'MIA1'], description='cilia and flagella associated protein 100', other_designations='cilia- and flagella-associated protein 100|coiled-coil domain containing 37|coiled-coil domain-containing protein 37', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=126394893, end_position_on_the_genomic_accession=126436556, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    348932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348932, CurrentID=0, Status='live', Symbol='SLC6A18', Aliases=['Xtrp2'], description='solute carrier family 6 member 18', other_designations='inactive sodium-dependent neutral amino acid transporter B(0)AT3|sodium channel-like protein|sodium- and chloride-dependent transporter XTRP2|sodium-dependent neutral amino acid transporter B(0)AT3|solute carrier family 6 (neurotransmitter transporter), member 18|solute carrier family 6 (neutral amino acid transporter), member 18|system B(0) neutral amino acid transporter AT3', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=1225381, end_position_on_the_genomic_accession=1246189, orientation='plus', exon_count=12, OMIM=[610300], no_hdr0=''),
    348938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348938, CurrentID=0, Status='live', Symbol='NIPAL4', Aliases=['ARCI6', 'ICHTHYIN', 'ICHYN', 'SLC57A6'], description='NIPA like domain containing 4', other_designations='magnesium transporter NIPA4|NIPA-like protein 4|non-imprinted in Prader-Willi/Angelman syndrome region protein 4', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157460019, end_position_on_the_genomic_accession=157474722, orientation='plus', exon_count=7, OMIM=[609383], no_hdr0=''),
    348980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348980, CurrentID=0, Status='live', Symbol='HCN1', Aliases=['BCNG-1', 'BCNG1', 'DEE24', 'EIEE24', 'GEFSP10', 'HAC-2'], description='hyperpolarization activated cyclic nucleotide gated potassium channel 1', other_designations='potassium/sodium hyperpolarization-activated cyclic nucleotide-gated channel 1|brain cyclic nucleotide-gated channel 1', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=45254948, end_position_on_the_genomic_accession=45696380, orientation='minus', exon_count=8, OMIM=[602780], no_hdr0=''),
    348995 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=348995, CurrentID=0, Status='live', Symbol='NUP43', Aliases=['bA350J20.1', 'p42'], description='nucleoporin 43', other_designations='nucleoporin Nup43|nucleoporin 43kDa|nup107-160 subcomplex subunit Nup43', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149724315, end_position_on_the_genomic_accession=149746529, orientation='minus', exon_count=11, OMIM=[608141], no_hdr0=''),
    349075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349075, CurrentID=0, Status='live', Symbol='ZNF713', Aliases=[], description='zinc finger protein 713', other_designations='zinc finger protein 713', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55887456, end_position_on_the_genomic_accession=55942225, orientation='plus', exon_count=7, OMIM=[616181], no_hdr0=''),
    349136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349136, CurrentID=0, Status='live', Symbol='WDR86', Aliases=[], description='WD repeat domain 86', other_designations='WD repeat-containing protein 86', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151377974, end_position_on_the_genomic_accession=151410712, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    349149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349149, CurrentID=0, Status='live', Symbol='GJC3', Aliases=['CX29', 'CX30.2', 'CX31.3', 'GJE1'], description='gap junction protein gamma 3', other_designations='gap junction gamma-3 protein|connexin 29|connexin-30.2|connexin-31.3|gap junction epsilon-1 protein|gap junction protein, gamma 3, 30.2kDa', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99923266, end_position_on_the_genomic_accession=99929620, orientation='minus', exon_count=2, OMIM=[611925], no_hdr0=''),
    349334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349334, CurrentID=0, Status='live', Symbol='FOXD4L4', Aliases=['FOXD4L2', 'FOXD4b', 'bA460E7.2'], description='forkhead box D4 like 4', other_designations='forkhead box protein D4-like 4|FOXD4-like 4|forkhead box D4-like 2|forkhead box protein D4-like 2|forkhead box protein D4b|myeloid factor-gamma|winged helix factor-1|winged helix transcription factor beta', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=65737146, end_position_on_the_genomic_accession=65738396, orientation='plus', exon_count=1, OMIM=[611085], no_hdr0=''),
    349565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349565, CurrentID=0, Status='live', Symbol='NMNAT3', Aliases=['FKSG76', 'PNAT-3', 'PNAT3'], description='nicotinamide nucleotide adenylyltransferase 3', other_designations='nicotinamide/nicotinic acid mononucleotide adenylyltransferase 3|NMN adenylyltransferase 3|NMN/NaMN adenylyltransferase 3|NaMN adenylyltransferase 3|nicotinamide mononucleotide adenylyltransferase 3|nicotinate-nucleotide adenylyltransferase 3|pyridine nucleotide adenylyltransferase 3', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139560180, end_position_on_the_genomic_accession=139678050, orientation='minus', exon_count=14, OMIM=[608702], no_hdr0=''),
    349633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349633, CurrentID=0, Status='live', Symbol='PLET1', Aliases=['C11orf34'], description='placenta expressed transcript 1', other_designations='placenta-expressed transcript 1 protein', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=112248153, end_position_on_the_genomic_accession=112260860, orientation='minus', exon_count=4, OMIM=[611904], no_hdr0=''),
    349667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=349667, CurrentID=0, Status='live', Symbol='RTN4RL2', Aliases=['NGRH1', 'NgR2'], description='reticulon 4 receptor like 2', other_designations='reticulon-4 receptor-like 2|Nogo-66 receptor homolog 1|nogo receptor-like 3|nogo-66 receptor-related protein 2', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57460528, end_position_on_the_genomic_accession=57477534, orientation='plus', exon_count=3, OMIM=[610462], no_hdr0=''),
    350383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=350383, CurrentID=0, Status='live', Symbol='GPR142', Aliases=['GPRg1b', 'PGR2'], description='G protein-coupled receptor 142', other_designations='probable G-protein coupled receptor 142|G-protein coupled receptor 142 long form|G-protein coupled receptor PGR2', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74367506, end_position_on_the_genomic_accession=74372600, orientation='plus', exon_count=4, OMIM=[609046], no_hdr0=''),
    352909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=352909, CurrentID=0, Status='live', Symbol='DNAAF3', Aliases=['C19orf51', 'CILD2', 'DAB1', 'PCD', 'PF22'], description='dynein axonemal assembly factor 3', other_designations='dynein axonemal assembly factor 3|UPF0470 protein C19orf51', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55158661, end_position_on_the_genomic_accession=55166722, orientation='minus', exon_count=12, OMIM=[614566], no_hdr0=''),
    352999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=352999, CurrentID=0, Status='live', Symbol='C6orf58', Aliases=['LEG1'], description='chromosome 6 open reading frame 58', other_designations='protein LEG1 homolog|UPF0762 protein C6orf58|liver enriched gene 1 homolog', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127577174, end_position_on_the_genomic_accession=127591820, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    353088 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353088, CurrentID=0, Status='live', Symbol='ZNF429', Aliases=[], description='zinc finger protein 429', other_designations='zinc finger protein 429', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=21505427, end_position_on_the_genomic_accession=21541157, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    353091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353091, CurrentID=0, Status='live', Symbol='RAET1G', Aliases=['ULBP5'], description='retinoic acid early transcript 1G', other_designations='UL-16 binding protein 5|retinoic acid early transcript 1G protein', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149916878, end_position_on_the_genomic_accession=149923133, orientation='minus', exon_count=5, OMIM=[609244], no_hdr0=''),
    353116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353116, CurrentID=0, Status='live', Symbol='RILPL1', Aliases=['GOSPEL', 'RLP1'], description='Rab interacting lysosomal protein like 1', other_designations='RILP-like protein 1|GAPDH competitor of SIAH protein enhances life', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123470054, end_position_on_the_genomic_accession=123533719, orientation='minus', exon_count=14, OMIM=[614092], no_hdr0=''),
    353131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353131, CurrentID=0, Status='live', Symbol='LCE1A', Aliases=['LEP1'], description='late cornified envelope 1A', other_designations='late cornified envelope protein 1A|late envelope protein 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152827473, end_position_on_the_genomic_accession=152828097, orientation='plus', exon_count=1, OMIM=[612603], no_hdr0=''),
    353132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353132, CurrentID=0, Status='live', Symbol='LCE1B', Aliases=['LEP2', 'SPRL2A'], description='late cornified envelope 1B', other_designations='late cornified envelope protein 1B|late envelope protein 2|small proline rich-like (epidermal differentiation complex) 2A|small proline-rich-like epidermal differentiation complex protein 2A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152811971, end_position_on_the_genomic_accession=152813108, orientation='plus', exon_count=1, OMIM=[612604], no_hdr0=''),
    353133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353133, CurrentID=0, Status='live', Symbol='LCE1C', Aliases=['LEP3'], description='late cornified envelope 1C', other_designations='late cornified envelope protein 1C|late envelope protein 3', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152804832, end_position_on_the_genomic_accession=152806651, orientation='minus', exon_count=3, OMIM=[612605], no_hdr0=''),
    353134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353134, CurrentID=0, Status='live', Symbol='LCE1D', Aliases=['LEP4'], description='late cornified envelope 1D', other_designations='late cornified envelope protein 1D|late envelope protein 4', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152796721, end_position_on_the_genomic_accession=152798181, orientation='plus', exon_count=2, OMIM=[612606], no_hdr0=''),
    353135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353135, CurrentID=0, Status='live', Symbol='LCE1E', Aliases=['LEP5'], description='late cornified envelope 1E', other_designations='late cornified envelope protein 1E|late envelope protein 5', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152786257, end_position_on_the_genomic_accession=152788426, orientation='plus', exon_count=2, OMIM=[612607], no_hdr0=''),
    353137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353137, CurrentID=0, Status='live', Symbol='LCE1F', Aliases=['LEP6'], description='late cornified envelope 1F', other_designations='late cornified envelope protein 1F|late envelope protein 6', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152775140, end_position_on_the_genomic_accession=152777024, orientation='plus', exon_count=2, OMIM=[612608], no_hdr0=''),
    353139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353139, CurrentID=0, Status='live', Symbol='LCE2A', Aliases=['LEP9'], description='late cornified envelope 2A', other_designations='late cornified envelope protein 2A|late envelope protein 9', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152698345, end_position_on_the_genomic_accession=152699442, orientation='plus', exon_count=2, OMIM=[612609], no_hdr0=''),
    353140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353140, CurrentID=0, Status='live', Symbol='LCE2C', Aliases=['LEP11'], description='late cornified envelope 2C', other_designations='late cornified envelope protein 2C|late envelope protein 11', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152675279, end_position_on_the_genomic_accession=152676569, orientation='plus', exon_count=2, OMIM=[612611], no_hdr0=''),
    353141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353141, CurrentID=0, Status='live', Symbol='LCE2D', Aliases=['LEP12', 'SPRL1A'], description='late cornified envelope 2D', other_designations='late cornified envelope protein 2D|late envelope protein 12|small proline rich-like (epidermal differentiation complex) 1A|small proline-rich-like epidermal differentiation complex protein 1A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152663380, end_position_on_the_genomic_accession=152664659, orientation='plus', exon_count=2, OMIM=[612612], no_hdr0=''),
    353142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353142, CurrentID=0, Status='live', Symbol='LCE3A', Aliases=['LEP13'], description='late cornified envelope 3A', other_designations='late cornified envelope protein 3A|late envelope protein 13', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152622834, end_position_on_the_genomic_accession=152623103, orientation='minus', exon_count=1, OMIM=[612613], no_hdr0=''),
    353143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353143, CurrentID=0, Status='live', Symbol='LCE3B', Aliases=['LEP14'], description='late cornified envelope 3B', other_designations='late cornified envelope protein 3B|late envelope protein 14', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152613811, end_position_on_the_genomic_accession=152614098, orientation='plus', exon_count=1, OMIM=[612614], no_hdr0=''),
    353144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353144, CurrentID=0, Status='live', Symbol='LCE3C', Aliases=['LEP15', 'SPRL3A'], description='late cornified envelope 3C', other_designations='late cornified envelope protein 3C|late envelope protein 15|small proline rich-like (epidermal differentiation complex) 3A|small proline-rich-like epidermal differentiation complex protein 3A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152600234, end_position_on_the_genomic_accession=152601086, orientation='plus', exon_count=2, OMIM=[612615], no_hdr0=''),
    353145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353145, CurrentID=0, Status='live', Symbol='LCE3E', Aliases=['LEP17'], description='late cornified envelope 3E', other_designations='late cornified envelope protein 3E|late envelope protein 17', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152565654, end_position_on_the_genomic_accession=152566780, orientation='minus', exon_count=2, OMIM=[612617], no_hdr0=''),
    353149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353149, CurrentID=0, Status='live', Symbol='TBC1D26', Aliases=[], description='TBC1 domain family member 26', other_designations='TBC1 domain family member 26', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15732277, end_position_on_the_genomic_accession=15744784, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    353164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353164, CurrentID=0, Status='live', Symbol='TAS2R42', Aliases=['T2R24', 'T2R42', 'T2R55', 'TAS2R55'], description='taste 2 receptor member 42', other_designations='taste receptor type 2 member 42|candidate taste receptor hT2R55|taste receptor type 2 member 55|taste receptor, type 2, member 42', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11185993, end_position_on_the_genomic_accession=11186937, orientation='minus', exon_count=1, OMIM=[613966], no_hdr0=''),
    353174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353174, CurrentID=0, Status='live', Symbol='ZACN', Aliases=['L2', 'LGICZ', 'LGICZ1', 'ZAC', 'ZAC1'], description='zinc activated ion channel', other_designations='zinc-activated ligand-gated ion channel|ligand-gated ion channel subunit|ligand-gated ion channel zinc-activated 1|ligand-gated ion-channel receptor L2|zinc activated ligand-gated ion channel 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76079182, end_position_on_the_genomic_accession=76082806, orientation='plus', exon_count=9, OMIM=[610935], no_hdr0=''),
    353189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353189, CurrentID=0, Status='live', Symbol='SLCO4C1', Aliases=['OATP-H', 'OATP-M1', 'OATP4C1', 'OATPX', 'PRO2176', 'SLC21A20'], description='solute carrier organic anion transporter family member 4C1', other_designations='solute carrier organic anion transporter family member 4C1|organic anion transporter M1|solute carrier family 21 member 20', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=102233986, end_position_on_the_genomic_accession=102296516, orientation='minus', exon_count=15, OMIM=[609013], no_hdr0=''),
    353219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353219, CurrentID=0, Status='live', Symbol='KAAG1', Aliases=['RU2AS'], description='kidney associated antigen 1', other_designations='kidney-associated antigen 1|RU2 antisense gene protein', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24356903, end_position_on_the_genomic_accession=24358285, orientation='plus', exon_count=1, OMIM=[608211], no_hdr0=''),
    353238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353238, CurrentID=0, Status='live', Symbol='PADI6', Aliases=['PREMBL2', 'hPADVI'], description='peptidyl arginine deiminase 6', other_designations='protein-arginine deiminase type-6|peptidyl arginine deiminase, type VI|peptidyl arginine deiminase-like protein|peptidylarginine deiminase type 6', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=17372196, end_position_on_the_genomic_accession=17401699, orientation='plus', exon_count=16, OMIM=[610363], no_hdr0=''),
    353274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353274, CurrentID=0, Status='live', Symbol='ZNF445', Aliases=['ZFP445', 'ZKSCAN15', 'ZNF168', 'ZSCAN47'], description='zinc finger protein 445', other_designations='zinc finger protein 445|zinc finger protein 168|zinc finger protein with KRAB and SCAN domains 15', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44431705, end_position_on_the_genomic_accession=44477670, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    353288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353288, CurrentID=0, Status='live', Symbol='KRT26', Aliases=['CK26', 'K25B', 'K25IRS2', 'K26', 'KRT25B'], description='keratin 26', other_designations='keratin, type I cytoskeletal 26|cytokeratin-26|keratin 26, type I|keratin-25B|type I inner root sheath specific keratin 25 irs2|type I inner root sheath-specific keratin-K25irs2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40766238, end_position_on_the_genomic_accession=40772159, orientation='minus', exon_count=8, OMIM=[616675], no_hdr0=''),
    353299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353299, CurrentID=0, Status='live', Symbol='RGSL1', Aliases=['RGSL', 'RGSL2'], description='regulator of G protein signaling like 1', other_designations='regulator of G-protein signaling protein-like|regulator of G-protein signaling like 2', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=182447876, end_position_on_the_genomic_accession=182560597, orientation='plus', exon_count=32, OMIM=[611012], no_hdr0=''),
    353322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353322, CurrentID=0, Status='live', Symbol='ANKRD37', Aliases=['Lrp2bp'], description='ankyrin repeat domain 37', other_designations='ankyrin repeat domain-containing protein 37|low density lipoprotein receptor-related protein binding protein|low-density lipoprotein receptor-related protein 2-binding protein', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185396841, end_position_on_the_genomic_accession=185400243, orientation='plus', exon_count=4, OMIM=[619021], no_hdr0=''),
    353323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353323, CurrentID=0, Status='live', Symbol='KRTAP12-2', Aliases=['KAP12.2', 'KRTAP12.2'], description='keratin associated protein 12-2', other_designations='keratin-associated protein 12-2|high sulfur keratin-associated protein 12.2|keratin-associated protein 12.2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44666189, end_position_on_the_genomic_accession=44666927, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    353324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353324, CurrentID=0, Status='live', Symbol='SPATA12', Aliases=['SRG5'], description='spermatogenesis associated 12', other_designations='spermatogenesis-associated protein 12|spermatogenesis-related protein 5|testicular tissue protein Li 184', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=57060664, end_position_on_the_genomic_accession=57075432, orientation='plus', exon_count=4, OMIM=[609869], no_hdr0=''),
    353332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353332, CurrentID=0, Status='live', Symbol='KRTAP12-1', Aliases=['KAP12.1', 'KRTAP12.1'], description='keratin associated protein 12-1', other_designations='keratin-associated protein 12-1|high sulfur keratin-associated protein 12.1|keratin-associated protein 12.1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44681576, end_position_on_the_genomic_accession=44682163, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    353333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353333, CurrentID=0, Status='live', Symbol='KRTAP10-10', Aliases=['KAP10.10', 'KAP18.10', 'KRTAP18-10', 'KRTAP18.10'], description='keratin associated protein 10-10', other_designations='keratin-associated protein 10-10|high sulfur keratin-associated protein 10.10|keratin-associated protein 18-10', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44637356, end_position_on_the_genomic_accession=44638455, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    353345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353345, CurrentID=0, Status='live', Symbol='GPR141', Aliases=['PGR13'], description='G protein-coupled receptor 141', other_designations='probable G-protein coupled receptor 141|G-protein coupled receptor PGR13', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=37683560, end_position_on_the_genomic_accession=37743835, orientation='plus', exon_count=10, OMIM=[609045], no_hdr0=''),
    353355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353355, CurrentID=0, Status='live', Symbol='ZNF233', Aliases=[], description='zinc finger protein 233', other_designations='zinc finger protein 233', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44259742, end_position_on_the_genomic_accession=44278534, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    353376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353376, CurrentID=0, Status='live', Symbol='TICAM2', Aliases=['MyD88-4', 'TICAM-2', 'TIRAP3', 'TIRP', 'TRAM'], description='toll like receptor adaptor molecule 2', other_designations='TIR domain-containing adapter molecule 2|NF-kappa-B-activating protein 502|TRIF-related adaptor molecule|cytoplasmic adaptor|putative NF-kappa-B-activating protein 502|toll-like receptor adaptor protein 3|toll/interleukin-1 receptor (TIR) domain-containing adapter protein', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115578496, end_position_on_the_genomic_accession=115602479, orientation='minus', exon_count=2, OMIM=[608321], no_hdr0=''),
    353497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353497, CurrentID=0, Status='live', Symbol='POLN', Aliases=['POL4P'], description='DNA polymerase nu', other_designations='DNA polymerase nu|DNA polymerase N|DNA polymerase POL4P|polymerase (DNA directed) nu|polymerase (DNA) nu', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2071918, end_position_on_the_genomic_accession=2242121, orientation='minus', exon_count=26, OMIM=[610887], no_hdr0=''),
    353500 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353500, CurrentID=0, Status='live', Symbol='BMP8A', Aliases=['OP-2'], description='bone morphogenetic protein 8a', other_designations='bone morphogenetic protein 8A|BMP-8A', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39491626, end_position_on_the_genomic_accession=39529869, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    353513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353513, CurrentID=0, Status='live', Symbol='VCY1B', Aliases=['BPY1B'], description='variable charge Y-linked 1B', other_designations='testis-specific basic protein Y 1|basic charge, Y-linked 1|basic protein on Y chromosome, 1|testis-specific basic protein on Y, 1|variably charged protein Y', map_location='Yq11.221', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=14056227, end_position_on_the_genomic_accession=14056958, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    353514 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=353514, CurrentID=0, Status='live', Symbol='LILRA5', Aliases=['CD85', 'CD85F', 'ILT-11', 'ILT11', 'LILRB7', 'LIR-9', 'LIR9'], description='leukocyte immunoglobulin like receptor A5', other_designations='leukocyte immunoglobulin-like receptor subfamily A member 5|CD85 antigen-like family member F|immunoglobulin-like transcript 11 protein|leucocyte Ig-like receptor A5|leukocyte Ig-like receptor 9|leukocyte immunoglobulin-like receptor 9|leukocyte immunoglobulin-like receptor subfamily A member 5 soluble|leukocyte immunoglobulin-like receptor, subfamily A (with TM domain), member 5|leukocyte immunoglobulin-like receptor, subfamily B (with TM and ITIM domains), member 7', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54307070, end_position_on_the_genomic_accession=54313166, orientation='minus', exon_count=7, OMIM=[606047], no_hdr0=''),
    359710 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=359710, CurrentID=0, Status='live', Symbol='BPIFB3', Aliases=['C20orf185', 'LPLUNC3', 'RYA3'], description='BPI fold containing family B member 3', other_designations='BPI fold-containing family B member 3|ligand-binding protein RYA3|long palate, lung and nasal epithelium carcinoma-associated protein 3', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=33053903, end_position_on_the_genomic_accession=33073847, orientation='plus', exon_count=16, OMIM=[615717], no_hdr0=''),
    359787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=359787, CurrentID=0, Status='live', Symbol='DPPA3', Aliases=['Pgc7', 'STELLA'], description='developmental pluripotency associated 3', other_designations='developmental pluripotency-associated protein 3|stella-related protein', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7711433, end_position_on_the_genomic_accession=7717559, orientation='plus', exon_count=4, OMIM=[608408], no_hdr0=''),
    359845 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=359845, CurrentID=0, Status='live', Symbol='RFLNB', Aliases=['CFM1', 'FAM101B'], description='refilin B', other_designations='refilin-B|family with sequence similarity 101, member B|filamin-interacting protein FAM101B|protein FAM101B|refilinB|regulator of filamin protein B', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=439978, end_position_on_the_genomic_accession=445940, orientation='minus', exon_count=2, OMIM=[615928], no_hdr0=''),
    359948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=359948, CurrentID=0, Status='live', Symbol='IRF2BP2', Aliases=['CVID14'], description='interferon regulatory factor 2 binding protein 2', other_designations='interferon regulatory factor 2-binding protein 2|IRF-2-binding protein 2', map_location='1q42.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=234604269, end_position_on_the_genomic_accession=234610178, orientation='minus', exon_count=2, OMIM=[615332], no_hdr0=''),
    360023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360023, CurrentID=0, Status='live', Symbol='ZBTB41', Aliases=['FRBZ1', 'ZNF924'], description='zinc finger and BTB domain containing 41', other_designations='zinc finger and BTB domain-containing protein 41|FRBZ1 protein (FRBZ1)', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197153682, end_position_on_the_genomic_accession=197201390, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    360030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360030, CurrentID=0, Status='live', Symbol='NANOGNB', Aliases=[], description='NANOG neighbor homeobox', other_designations='NANOG neighbor homeobox|homeobox C14|homeobox protein C14', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=7765216, end_position_on_the_genomic_accession=7774121, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    360200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360200, CurrentID=0, Status='live', Symbol='TMPRSS9', Aliases=[], description='transmembrane serine protease 9', other_designations='transmembrane protease serine 9|polyserase-1|polyserase-I|polyserine protease 1|transmembrane protease, serine 9', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2385254, end_position_on_the_genomic_accession=2426261, orientation='plus', exon_count=22, OMIM=[610477], no_hdr0=''),
    360203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360203, CurrentID=0, Status='live', Symbol='GLT6D1', Aliases=['GLTDC1', 'GT6M7'], description='glycosyltransferase 6 domain containing 1', other_designations='putative glycosyltransferase 6 domain-containing protein 1|galactosyltransferase family 6 domain containing 1|glycosyltransferase 6 domain-containing protein 1', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135623648, end_position_on_the_genomic_accession=135641224, orientation='minus', exon_count=10, OMIM=[613699], no_hdr0=''),
    360205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360205, CurrentID=0, Status='live', Symbol='PRAC2', Aliases=['C17orf93', 'HOXB-AS5', 'HOXB13-AS1', 'HOXBAS5', 'NCRNA00253'], description='PRAC2 small nuclear protein', other_designations='putative protein PRAC2|HOXB cluster antisense RNA 5|prostate cancer susceptibility candidate 2|prostate, rectum and colon 2|prostate, rectum and colon expressed gene 2 protein|prostate, rectum and colon expressed gene protein 2|putative protein PRCA2|small nuclear protein PRAC2', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=48720802, end_position_on_the_genomic_accession=48724758, orientation='plus', exon_count=5, OMIM=[610787], no_hdr0=''),
    360226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=360226, CurrentID=0, Status='live', Symbol='PRSS41', Aliases=['TESSP1'], description='serine protease 41', other_designations='serine protease 41|protease, serine 41|putative serine protease 41|testis-specific serine protease 1', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2798470, end_position_on_the_genomic_accession=2805304, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    373156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=373156, CurrentID=0, Status='live', Symbol='GSTK1', Aliases=['GST', 'GST 13-13', 'GST13', 'GST13-13-1', 'hGSTK1', 'GSTK1'], description='glutathione S-transferase kappa 1', other_designations='glutathione S-transferase kappa 1|GST class-kappa|glutathione S-transferase k1|glutathione S-transferase subunit 13 homolog', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143263441, end_position_on_the_genomic_accession=143269115, orientation='plus', exon_count=8, OMIM=[602321], no_hdr0=''),
    373509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=373509, CurrentID=0, Status='live', Symbol='USP50', Aliases=[], description='ubiquitin specific peptidase 50', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 50|inactive ubiquitin-specific peptidase 50|ubiquitin specific protease 50', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=50500562, end_position_on_the_genomic_accession=50546666, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    373856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=373856, CurrentID=0, Status='live', Symbol='USP41', Aliases=[], description='ubiquitin specific peptidase 41', other_designations='putative ubiquitin carboxyl-terminal hydrolase 41|deubiquitinating enzyme 41|ubiquitin specific proteinase 41|ubiquitin thioesterase 41|ubiquitin thiolesterase 41|ubiquitin-specific-processing protease 41', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20363621, end_position_on_the_genomic_accession=20390758, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    373863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=373863, CurrentID=0, Status='live', Symbol='DND1', Aliases=['RBMS4'], description='DND microRNA-mediated repression inhibitor 1', other_designations='dead end protein homolog 1|RNA-binding motif, single-stranded-interacting protein 4|dead end homolog 1', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140670794, end_position_on_the_genomic_accession=140673576, orientation='minus', exon_count=4, OMIM=[609385], no_hdr0=''),
    374286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374286, CurrentID=0, Status='live', Symbol='CDRT1', Aliases=['C170RF1', 'C17ORF1', 'C17ORF1A', 'FBXW10B', 'FBXW10P1', 'HREP', 'SM25H2'], description='CMT1A duplicated region transcript 1', other_designations='CMT1A duplicated region transcript 1 protein|Charcot-Marie-Tooth duplicated region transcript 1|F-box and WD repeat domain containing 10 pseudogene 1|F-box and WD-40 domain protein 10 pseudogene 1', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15565482, end_position_on_the_genomic_accession=15619704, orientation='minus', exon_count=14, OMIM=[604596], no_hdr0=''),
    374291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374291, CurrentID=0, Status='live', Symbol='NDUFS7', Aliases=['CI-20', 'CI-20KD', 'MC1DN3', 'MY017', 'PSST'], description='NADH:ubiquinone oxidoreductase core subunit S7', other_designations='NADH dehydrogenase [ubiquinone] iron-sulfur protein 7, mitochondrial|NADH dehydrogenase (ubiquinone) Fe-S protein 7, 20kDa (NADH-coenzyme Q reductase)|NADH-coenzyme Q reductase|NADH-ubiquinone oxidoreductase 20 kDa subunit|NADH:ubiquinone oxidoreductase PSST subunit|PSST subunit|complex I 20kDa subunit|complex I, mitochondrial respiratory chain, 20-KD subunit|complex I-20kD', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1383904, end_position_on_the_genomic_accession=1395584, orientation='plus', exon_count=8, OMIM=[601825], no_hdr0=''),
    374308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374308, CurrentID=0, Status='live', Symbol='PTCHD3', Aliases=['PTR'], description='patched domain containing 3', other_designations='patched domain-containing protein 3|patched-related protein', map_location='10p12.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=27398188, end_position_on_the_genomic_accession=27414347, orientation='minus', exon_count=4, OMIM=[611791], no_hdr0=''),
    374354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374354, CurrentID=0, Status='live', Symbol='NHLRC2', Aliases=['FINCA'], description='NHL repeat containing 2', other_designations='NHL repeat-containing protein 2|1200003G01Rik|novel NHL repeat domain containing protein', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=113854634, end_position_on_the_genomic_accession=113917194, orientation='plus', exon_count=12, OMIM=[618277], no_hdr0=''),
    374355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374355, CurrentID=0, Status='live', Symbol='CCDC172', Aliases=['C10orf96'], description='coiled-coil domain containing 172', other_designations='coiled-coil domain-containing protein 172|UPF0628 protein C10orf96', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116324097, end_position_on_the_genomic_accession=116380029, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    374378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374378, CurrentID=0, Status='live', Symbol='GALNT18', Aliases=['GALNACT18', 'GALNT15', 'GALNTL4', 'GalNAc-T15', 'GalNAc-T18'], description='polypeptide N-acetylgalactosaminyltransferase 18', other_designations='polypeptide N-acetylgalactosaminyltransferase 18|GalNAc-transferase 18|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase-like protein 4|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 15|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 18|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase-like 4|galNAc-T-like protein 4|polypeptide GalNAc transferase 18|polypeptide GalNAc transferase-like protein 4|polypeptide N-acetylgalactosaminyltransferase-like protein 4|pp-GaNTase-like protein 4|protein-UDP acetylgalactosaminyltransferase-like protein 4|putative polypeptide N-acetylgalactosaminyltransferase-like protein 4', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=11270877, end_position_on_the_genomic_accession=11622005, orientation='minus', exon_count=16, OMIM=[615136], no_hdr0=''),
    374383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374383, CurrentID=0, Status='live', Symbol='NCR3LG1', Aliases=['B7-H6', 'B7H6', 'DKFZp686O24166'], description='natural killer cell cytotoxicity receptor 3 ligand 1', other_designations='natural cytotoxicity triggering receptor 3 ligand 1|B7 homolog 6|putative Ig-like domain-containing protein DKFZp686O24166/DKFZp686I21167', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=17351800, end_position_on_the_genomic_accession=17377341, orientation='plus', exon_count=6, OMIM=[613714], no_hdr0=''),
    374393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374393, CurrentID=0, Status='live', Symbol='FAM111B', Aliases=['CANP', 'POIKTMP'], description='FAM111 trypsin like peptidase B', other_designations='serine protease FAM111B|cancer-associated nucleoprotein|family with sequence similarity 111 member B', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59107237, end_position_on_the_genomic_accession=59127412, orientation='plus', exon_count=4, OMIM=[615584], no_hdr0=''),
    374395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374395, CurrentID=0, Status='live', Symbol='TMEM179B', Aliases=[], description='transmembrane protein 179B', other_designations='transmembrane protein 179B', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62787402, end_position_on_the_genomic_accession=62790400, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    374403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374403, CurrentID=0, Status='live', Symbol='TBC1D10C', Aliases=['CARABIN', 'EPI64C'], description='TBC1 domain family member 10C', other_designations='carabin', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67403718, end_position_on_the_genomic_accession=67410090, orientation='plus', exon_count=11, OMIM=[610831], no_hdr0=''),
    374407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374407, CurrentID=0, Status='live', Symbol='DNAJB13', Aliases=['CILD34', 'RSPH16A', 'TSARG5', 'TSARG6'], description='DnaJ heat shock protein family (Hsp40) member B13', other_designations='dnaJ homolog subfamily B member 13|DnaJ (Hsp40) homolog, subfamily B, member 13|DnaJ (Hsp40) related, subfamily B, member 13|DnaJ-like protein|radial spoke 16 homolog A|testis and spermatogenesis cell-related protein 6|testis spermatocyte apoptosis-related gene 6 protein|testis spermatogenesis apoptosis-related gene 3 protein|testis spermatogenesis apoptosis-related gene 6 protein', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=73950621, end_position_on_the_genomic_accession=73970287, orientation='plus', exon_count=15, OMIM=[610263], no_hdr0=''),
    374454 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374454, CurrentID=0, Status='live', Symbol='KRT77', Aliases=['K1B', 'KRT1B'], description='keratin 77', other_designations='keratin, type II cytoskeletal 1b|CK-1B|K77|cytokeratin-1B|keratin 1B|keratin 77, type II|type-II keratin Kb39', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52689612, end_position_on_the_genomic_accession=52703524, orientation='minus', exon_count=10, OMIM=[611158], no_hdr0=''),
    374462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374462, CurrentID=0, Status='live', Symbol='PTPRQ', Aliases=['DFNA73', 'DFNB84', 'DFNB84A', 'PTPGMC1', 'R-PTP-Q'], description='protein tyrosine phosphatase receptor type Q', other_designations='phosphatidylinositol phosphatase PTPRQ|phosphotidylinositol phosphatase PTPRQ|protein-tyrosine phosphatase, receptor-type, expressed by glomerular mesangial cells', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80424261, end_position_on_the_genomic_accession=80680273, orientation='plus', exon_count=51, OMIM=[603317], no_hdr0=''),
    374470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374470, CurrentID=0, Status='live', Symbol='C12orf42', Aliases=[], description='chromosome 12 open reading frame 42', other_designations='uncharacterized protein C12orf42', map_location='12q23.2-q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103047669, end_position_on_the_genomic_accession=103525258, orientation='minus', exon_count=38, OMIM=[], no_hdr0=''),
    374569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374569, CurrentID=0, Status='live', Symbol='ASPG', Aliases=['C14orf76', 'GPA/WT', 'LYSOLP'], description='asparaginase', other_designations='60 kDa lysophospholipase|asparaginase homolog|lysophospholipase-transacylase|wild-type L-asparaginase', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104085658, end_position_on_the_genomic_accession=104115582, orientation='plus', exon_count=20, OMIM=[618472], no_hdr0=''),
    374618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374618, CurrentID=0, Status='live', Symbol='TEX9', Aliases=[], description='testis expressed 9', other_designations='testis-expressed protein 9|testis-expressed sequence 9 protein', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=56243973, end_position_on_the_genomic_accession=56445883, orientation='plus', exon_count=20, OMIM=[], no_hdr0=''),
    374654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374654, CurrentID=0, Status='live', Symbol='KIF7', Aliases=['ACLS', 'AGBK', 'HLS2', 'JBTS12', 'UNQ340'], description='kinesin family member 7', other_designations='kinesin-like protein KIF7|EQYK340', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89627977, end_position_on_the_genomic_accession=89663086, orientation='minus', exon_count=20, OMIM=[611254], no_hdr0=''),
    374655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374655, CurrentID=0, Status='live', Symbol='ZNF710', Aliases=[], description='zinc finger protein 710', other_designations='zinc finger protein 710', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90001324, end_position_on_the_genomic_accession=90082191, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    374659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374659, CurrentID=0, Status='live', Symbol='HDDC3', Aliases=['(ppGpp)ase', 'MESH1'], description='HD domain containing 3', other_designations="guanosine-3',5'-bis(diphosphate) 3'-pyrophosphohydrolase MESH1|HD domain-containing protein 3|metazoan SpoT homolog 1|penta-phosphate guanosine-3'-pyrophosphohydrolase", map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90929968, end_position_on_the_genomic_accession=90932569, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    374739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374739, CurrentID=0, Status='live', Symbol='TEPP', Aliases=[], description='testis, prostate and placenta expressed', other_designations='testis, prostate and placenta-expressed protein|testicular tissue protein Li 196|testis/prostate/placenta-expressed protein', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=57976544, end_position_on_the_genomic_accession=57988116, orientation='plus', exon_count=8, OMIM=[610264], no_hdr0=''),
    374768 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374768, CurrentID=0, Status='live', Symbol='SPEM1', Aliases=['C17orf83'], description='spermatid maturation 1', other_designations='spermatid maturation protein 1', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7420324, end_position_on_the_genomic_accession=7421632, orientation='plus', exon_count=3, OMIM=[615116], no_hdr0=''),
    374786 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374786, CurrentID=0, Status='live', Symbol='EFCAB5', Aliases=[], description='EF-hand calcium binding domain 5', other_designations='EF-hand calcium-binding domain-containing protein 5', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29929903, end_position_on_the_genomic_accession=30108452, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    374819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374819, CurrentID=0, Status='live', Symbol='LRRC37A3', Aliases=['LRRC37', 'LRRC37A'], description='leucine rich repeat containing 37 member A3', other_designations='leucine-rich repeat-containing protein 37A3', map_location='17q24.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=64854130, end_position_on_the_genomic_accession=64919478, orientation='minus', exon_count=15, OMIM=[616557], no_hdr0=''),
    374860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374860, CurrentID=0, Status='live', Symbol='ANKRD30B', Aliases=['NY-BR-1.1'], description='ankyrin repeat domain 30B', other_designations='ankyrin repeat domain-containing protein 30B|serologically defined breast cancer antigen NY-BR-1.1', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=14748172, end_position_on_the_genomic_accession=14855465, orientation='plus', exon_count=47, OMIM=[616565], no_hdr0=''),
    374864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374864, CurrentID=0, Status='live', Symbol='CCDC178', Aliases=['C18orf34'], description='coiled-coil domain containing 178', other_designations='coiled-coil domain-containing protein 178', map_location='18q12.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=32937406, end_position_on_the_genomic_accession=33441040, orientation='minus', exon_count=29, OMIM=[], no_hdr0=''),
    374868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374868, CurrentID=0, Status='live', Symbol='ATP9B', Aliases=['ATPASEP', 'ATPIIB', 'HUSSY-20', 'NEO1L', 'hMMR1'], description='ATPase phospholipid transporting 9B (putative)', other_designations='probable phospholipid-transporting ATPase IIB|ATPase type IV, phospholipid transporting (P-type)|ATPase, class II, type 9B|macrophage MHC receptor 1', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79069285, end_position_on_the_genomic_accession=79378391, orientation='plus', exon_count=39, OMIM=[614446], no_hdr0=''),
    374872 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374872, CurrentID=0, Status='live', Symbol='PEAK3', Aliases=['C19orf35'], description='PEAK family member 3', other_designations='protein PEAK3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2274631, end_position_on_the_genomic_accession=2282175, orientation='minus', exon_count=4, OMIM=[618526], no_hdr0=''),
    374875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374875, CurrentID=0, Status='live', Symbol='HSD11B1L', Aliases=['11-DH3', '11-beta-HSD3', 'HSD1L', 'HSD3', 'SCDR10', 'SCDR10B', 'SDR26C2'], description='hydroxysteroid 11-beta dehydrogenase 1 like', other_designations='hydroxysteroid 11-beta-dehydrogenase 1-like protein|11-beta-hydroxysteroid dehydrogenase type 3|short chain dehydrogenase/reductase 10|short chain dehydrogenase/reductase family 26C member 2', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5681027, end_position_on_the_genomic_accession=5688522, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    374877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374877, CurrentID=0, Status='live', Symbol='TEX45', Aliases=['C19orf45'], description='testis expressed 45', other_designations='testis-expressed protein 45|uncharacterized protein C19orf45', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7497548, end_position_on_the_genomic_accession=7508450, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    374879 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374879, CurrentID=0, Status='live', Symbol='ZNF699', Aliases=['hang'], description='zinc finger protein 699', other_designations='zinc finger protein 699|hangover homolog|hangover, Drosophila, homolog of', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9291140, end_position_on_the_genomic_accession=9309838, orientation='minus', exon_count=6, OMIM=[609571], no_hdr0=''),
    374882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374882, CurrentID=0, Status='live', Symbol='TMEM205', Aliases=['UNQ501'], description='transmembrane protein 205', other_designations='transmembrane protein 205|MBC3205', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=11342512, end_position_on_the_genomic_accession=11346459, orientation='minus', exon_count=5, OMIM=[613771], no_hdr0=''),
    374887 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374887, CurrentID=0, Status='live', Symbol='YJEFN3', Aliases=[], description='YjeF N-terminal domain containing 3', other_designations='yjeF N-terminal domain-containing protein 3|apoA-I-binding protein 2|apolipoprotein A1 binding protein|hYjeF_N3|hYjeF_N3-19p13.11|yjeF_N3', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19528901, end_position_on_the_genomic_accession=19537584, orientation='plus', exon_count=8, OMIM=[618607], no_hdr0=''),
    374897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374897, CurrentID=0, Status='live', Symbol='SBSN', Aliases=['UNQ698'], description='suprabasin', other_designations='suprabasin|HLAR698', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35523367, end_position_on_the_genomic_accession=35528371, orientation='minus', exon_count=5, OMIM=[609969], no_hdr0=''),
    374899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374899, CurrentID=0, Status='live', Symbol='ZNF829', Aliases=[], description='zinc finger protein 829', other_designations='zinc finger protein 829', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36888124, end_position_on_the_genomic_accession=36916387, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    374900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374900, CurrentID=0, Status='live', Symbol='ZNF568', Aliases=['ZFP568'], description='zinc finger protein 568', other_designations='zinc finger protein 568', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36916332, end_position_on_the_genomic_accession=36997932, orientation='plus', exon_count=15, OMIM=[617566], no_hdr0=''),
    374907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374907, CurrentID=0, Status='live', Symbol='B3GNT8', Aliases=['B3GALT7', 'BGALT15', 'beta3Gn-T8'], description='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 8', other_designations='UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 8|BGnT-8|UDP-Gal:betaGal beta 1,3-galactosyltransferase polypeptide 7|beta galactosyltransferase BGALT15|beta-1,3-Gn-T8|beta-1,3-N-acetylglucosaminyltransferase 8|beta1,3-N-acetylglucosaminyltransferase 8', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41425359, end_position_on_the_genomic_accession=41428730, orientation='minus', exon_count=3, OMIM=[615357], no_hdr0=''),
    374918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374918, CurrentID=0, Status='live', Symbol='IGFL1', Aliases=['APRG644', 'UNQ644'], description='IGF like family member 1', other_designations='insulin growth factor-like family member 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46229742, end_position_on_the_genomic_accession=46231243, orientation='plus', exon_count=4, OMIM=[610544], no_hdr0=''),
    374920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374920, CurrentID=0, Status='live', Symbol='ZSWIM9', Aliases=['C19orf68'], description='zinc finger SWIM-type containing 9', other_designations='uncharacterized protein ZSWIM9|uncharacterized protein C19orf68', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=48170662, end_position_on_the_genomic_accession=48197621, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    374928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374928, CurrentID=0, Status='live', Symbol='ZNF773', Aliases=['ZNF419B'], description='zinc finger protein 773', other_designations='zinc finger protein 773|zinc finger protein 419B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57499938, end_position_on_the_genomic_accession=57518437, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    374946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374946, CurrentID=0, Status='live', Symbol='DRAXIN', Aliases=['AGPA3119', 'C1orf187', 'UNQ3119', 'neucrin'], description='dorsal inhibitory axon guidance protein', other_designations='draxin|dorsal repulsive axon guidance protein|neural tissue-specific cysteine-rich protein', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=11686635, end_position_on_the_genomic_accession=11725857, orientation='plus', exon_count=10, OMIM=[612682], no_hdr0=''),
    374955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374955, CurrentID=0, Status='live', Symbol='SPATA21', Aliases=['spergen-2', 'spergen2'], description='spermatogenesis associated 21', other_designations='spermatogenesis-associated protein 21', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=16395606, end_position_on_the_genomic_accession=16437842, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    374969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374969, CurrentID=0, Status='live', Symbol='SVBP', Aliases=['CCDC23', 'NEDAHM'], description='small vasohibin binding protein', other_designations='small vasohibin-binding protein|coiled-coil domain containing 23|coiled-coil domain-containing protein 23', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42807052, end_position_on_the_genomic_accession=42817397, orientation='minus', exon_count=3, OMIM=[617853], no_hdr0=''),
    374973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374973, CurrentID=0, Status='live', Symbol='TEX38', Aliases=['ATPAF1-AS1', 'C1orf223', 'THEG4'], description='testis expressed 38', other_designations='testis-expressed protein 38|ATPAF1 antisense RNA 1|ATPAF1 antisense gene protein 1|testis highly expressed protein 4|testis-expressed sequence 38 protein', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46668886, end_position_on_the_genomic_accession=46673601, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    374977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374977, CurrentID=0, Status='live', Symbol='MROH7', Aliases=['C1orf175', 'HEATR8'], description='maestro heat like repeat family member 7', other_designations='maestro heat-like repeat-containing protein family member 7|HEAT repeat-containing protein 8', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54641786, end_position_on_the_genomic_accession=54710266, orientation='plus', exon_count=24, OMIM=[], no_hdr0=''),
    374986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=374986, CurrentID=0, Status='live', Symbol='MIGA1', Aliases=['FAM73A'], description='mitoguardin 1', other_designations='mitoguardin 1|family with sequence similarity 73, member A|protein FAM73A', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=77779649, end_position_on_the_genomic_accession=77879540, orientation='plus', exon_count=18, OMIM=[616773], no_hdr0=''),
    375033 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375033, CurrentID=0, Status='live', Symbol='PEAR1', Aliases=['JEDI', 'MEGF12'], description='platelet endothelial aggregation receptor 1', other_designations='platelet endothelial aggregation receptor 1|multiple EGF-like domains protein 12|multiple EGF-like-domains 12|multiple epidermal growth factor-like domains protein 12', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156893697, end_position_on_the_genomic_accession=156916429, orientation='plus', exon_count=25, OMIM=[610278], no_hdr0=''),
    375035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375035, CurrentID=0, Status='live', Symbol='SFT2D2', Aliases=['UNQ512', 'dJ747L4.C1.2'], description='SFT2 domain containing 2', other_designations='vesicle transport protein SFT2B|SFT2 domain-containing protein 2', map_location='1q24.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=168226004, end_position_on_the_genomic_accession=168253021, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    375056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375056, CurrentID=0, Status='live', Symbol='MIA3', Aliases=['ARNT', 'D320', 'ODCD2', 'TANGO', 'TANGO1', 'UNQ6077'], description='MIA SH3 domain ER export factor 3', other_designations='transport and Golgi organization protein 1 homolog|C219-reactive peptide|MIA family member 3, ER export factor|melanoma inhibitory activity family, member 3|melanoma inhibitory activity protein 3', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222618097, end_position_on_the_genomic_accession=222668007, orientation='plus', exon_count=32, OMIM=[613455], no_hdr0=''),
    375057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375057, CurrentID=0, Status='live', Symbol='STUM', Aliases=['C1orf95'], description='stum, mechanosensory transduction mediator homolog', other_designations='protein stum homolog|stumble homolog', map_location='1q42.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=226548746, end_position_on_the_genomic_accession=226609230, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    375061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375061, CurrentID=0, Status='live', Symbol='FAM89A', Aliases=['C1orf153'], description='family with sequence similarity 89 member A', other_designations='protein FAM89A', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231018958, end_position_on_the_genomic_accession=231040254, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    375189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375189, CurrentID=0, Status='live', Symbol='PFN4', Aliases=[], description='profilin family member 4', other_designations='profilin-4|profilin IV', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24114809, end_position_on_the_genomic_accession=24124268, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    375190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375190, CurrentID=0, Status='live', Symbol='FAM228B', Aliases=[], description='family with sequence similarity 228 member B', other_designations='protein FAM228B|UPF0638 protein B', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24076833, end_position_on_the_genomic_accession=24169638, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    375248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375248, CurrentID=0, Status='live', Symbol='ANKRD36', Aliases=['UNQ2430'], description='ankyrin repeat domain 36', other_designations='ankyrin repeat domain-containing protein 36A|ankyrin repeat domain-containing protein 36|ankyrin-related', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97113153, end_position_on_the_genomic_accession=97264521, orientation='plus', exon_count=79, OMIM=[], no_hdr0=''),
    375287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375287, CurrentID=0, Status='live', Symbol='RBM43', Aliases=['C2orf38'], description='RNA binding motif protein 43', other_designations='RNA-binding protein 43', map_location='2q23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=151247940, end_position_on_the_genomic_accession=151261863, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    375298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375298, CurrentID=0, Status='live', Symbol='CERKL', Aliases=['RP26'], description='ceramide kinase like', other_designations='ceramide kinase-like protein', map_location='2q31.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=181536672, end_position_on_the_genomic_accession=181657105, orientation='minus', exon_count=14, OMIM=[608381], no_hdr0=''),
    375307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375307, CurrentID=0, Status='live', Symbol='CATIP', Aliases=['C2orf62'], description='ciliogenesis associated TTC17 interacting protein', other_designations='ciliogenesis-associated TTC17-interacting protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=218356757, end_position_on_the_genomic_accession=218368393, orientation='plus', exon_count=10, OMIM=[619387], no_hdr0=''),
    375316 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375316, CurrentID=0, Status='live', Symbol='RBM44', Aliases=[], description='RNA binding motif protein 44', other_designations='RNA-binding protein 44', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=237798048, end_position_on_the_genomic_accession=237842808, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    375318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375318, CurrentID=0, Status='live', Symbol='AQP12A', Aliases=['AQP-12', 'AQP12', 'AQPX2'], description='aquaporin 12A', other_designations='aquaporin-12A|aquaporin 12|aquaporin X2', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240691866, end_position_on_the_genomic_accession=240698483, orientation='plus', exon_count=4, OMIM=[609789], no_hdr0=''),
    375323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375323, CurrentID=0, Status='live', Symbol='LHFPL4', Aliases=['GARLH4'], description='LHFPL tetraspan subfamily member 4', other_designations='LHFPL tetraspan subfamily member 4 protein|GABAA receptor regulatory Lhfpl4|LHFP-like protein 4|lipoma HMGIC fusion partner-like 4 protein', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9498361, end_position_on_the_genomic_accession=9553822, orientation='minus', exon_count=5, OMIM=[610240], no_hdr0=''),
    375337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375337, CurrentID=0, Status='live', Symbol='TOPAZ1', Aliases=['C3orf77'], description='testis and ovary specific TOPAZ 1', other_designations='protein TOPAZ1|testis and ovary specific PAZ domain containing 1|testis and ovary-specific PAZ domain gene 1|testis- and ovary-specific PAZ domain-containing protein 1|topaz 1', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44241886, end_position_on_the_genomic_accession=44337071, orientation='plus', exon_count=21, OMIM=[614412], no_hdr0=''),
    375341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375341, CurrentID=0, Status='live', Symbol='C3orf62', Aliases=['MAPS'], description='chromosome 3 open reading frame 62', other_designations='uncharacterized protein C3orf62|male pachynema-specific protein', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49268596, end_position_on_the_genomic_accession=49277232, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    375346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375346, CurrentID=0, Status='live', Symbol='STIMATE', Aliases=['TMEM110'], description='STIM activating enhancer', other_designations='store-operated calcium entry regulator STIMATE|STIM-activating enhancer encoded by TMEM110|transmembrane protein 110', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52836733, end_position_on_the_genomic_accession=52897548, orientation='minus', exon_count=8, OMIM=[617189], no_hdr0=''),
    375387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375387, CurrentID=0, Status='live', Symbol='NRROS', Aliases=['ELLP3030', 'GARPL1', 'LRRC33', 'SENEBAC', 'UNQ3030'], description='negative regulator of reactive oxygen species', other_designations='transforming growth factor beta activator LRRC33|leucine-rich repeat-containing protein 33', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=196639694, end_position_on_the_genomic_accession=196662004, orientation='plus', exon_count=3, OMIM=[615322], no_hdr0=''),
    375444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375444, CurrentID=0, Status='live', Symbol='C5orf34', Aliases=[], description='chromosome 5 open reading frame 34', other_designations='uncharacterized protein C5orf34', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43486699, end_position_on_the_genomic_accession=43515433, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    375449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375449, CurrentID=0, Status='live', Symbol='MAST4', Aliases=[], description='microtubule associated serine/threonine kinase family member 4', other_designations='microtubule-associated serine/threonine-protein kinase 4', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=66596354, end_position_on_the_genomic_accession=67169595, orientation='plus', exon_count=43, OMIM=[618002], no_hdr0=''),
    375484 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375484, CurrentID=0, Status='live', Symbol='SIMC1', Aliases=['C5orf25', 'OOMA1', 'PLEIAD'], description='SUMO interacting motifs containing 1', other_designations='SUMO-interacting motif-containing protein 1|oocyte maturation associated 1|platform element for inhibition of autolytic degradation', map_location='5q35.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=176238371, end_position_on_the_genomic_accession=176345991, orientation='plus', exon_count=16, OMIM=[618102], no_hdr0=''),
    375519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375519, CurrentID=0, Status='live', Symbol='GJB7', Aliases=['CX25', 'bA136M9.1', 'connexin25'], description='gap junction protein beta 7', other_designations='gap junction beta-7 protein|connexin-25|gap junction protein, beta 7, 25kDa', map_location='6q14.3-q15', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=87282978, end_position_on_the_genomic_accession=87329278, orientation='minus', exon_count=4, OMIM=[611921], no_hdr0=''),
    375567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375567, CurrentID=0, Status='live', Symbol='VWC2', Aliases=['PSST739', 'UNQ739'], description='von Willebrand factor C domain containing 2', other_designations='brorin|brain-specific chordin-like protein|von Willebrand factor C domain-containing protein 2', map_location='7p12.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=49773638, end_position_on_the_genomic_accession=49923777, orientation='plus', exon_count=8, OMIM=[611108], no_hdr0=''),
    375593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375593, CurrentID=0, Status='live', Symbol='TRIM73', Aliases=['TRIM50B'], description='tripartite motif containing 73', other_designations='tripartite motif-containing protein 73|tripartite motif-containing protein 50B', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75395629, end_position_on_the_genomic_accession=75405605, orientation='plus', exon_count=5, OMIM=[612549], no_hdr0=''),
    375607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375607, CurrentID=0, Status='live', Symbol='NAT16', Aliases=['C7orf52'], description='N-acetyltransferase 16 (putative)', other_designations='probable N-acetyltransferase 16|N-acetyltransferase 16 (GCN5-related, putative)|putative N-acetyltransferase 16|putative N-acetyltransferase C7orf52', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=101170496, end_position_on_the_genomic_accession=101180293, orientation='minus', exon_count=5, OMIM=[615783], no_hdr0=''),
    375611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375611, CurrentID=0, Status='live', Symbol='SLC26A5', Aliases=['DFNB61', 'PRES'], description='solute carrier family 26 member 5', other_designations='prestin|prestin (motor protein)|solute carrier family 26 (anion exchanger), member 5', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=103352598, end_position_on_the_genomic_accession=103446207, orientation='minus', exon_count=22, OMIM=[604943], no_hdr0=''),
    375612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375612, CurrentID=0, Status='live', Symbol='LHFPL3', Aliases=['LHFPL4'], description='LHFPL tetraspan subfamily member 3', other_designations='LHFPL tetraspan subfamily member 3 protein|LHFP-like protein 3|lipoma HMGIC fusion partner-like 3 protein|lipoma HMGIC fusion partner-like 4', map_location='7q22.2-q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=104328603, end_position_on_the_genomic_accession=104908561, orientation='plus', exon_count=4, OMIM=[609719], no_hdr0=''),
    375616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375616, CurrentID=0, Status='live', Symbol='KCP', Aliases=['CRIM21', 'NET67', 'KCP'], description='kielin cysteine rich BMP regulator', other_designations='kielin/chordin-like protein|cysteine rich BMP regulator 2 (chordin-like)|cysteine-rich motor neuron 2 protein|kielin/chordin-like protein 1', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128870645, end_position_on_the_genomic_accession=128910719, orientation='minus', exon_count=46, OMIM=[609344], no_hdr0=''),
    375686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375686, CurrentID=0, Status='live', Symbol='SPATC1', Aliases=['SPATA15'], description='spermatogenesis and centriole associated 1', other_designations='speriolin|spermatogenesis and centriole-associated protein 1|spermatogenesis-associated protein 15|spermatogenic cell-specific Cdc20-binding protein|testicular tissue protein Li 181', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144010992, end_position_on_the_genomic_accession=144047114, orientation='plus', exon_count=11, OMIM=[610874], no_hdr0=''),
    375704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375704, CurrentID=0, Status='live', Symbol='ENHO', Aliases=['C9orf165', 'UNQ470'], description='energy homeostasis associated', other_designations='adropin|GAAI470|energy homeostasis-associated protein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34521043, end_position_on_the_genomic_accession=34522990, orientation='minus', exon_count=2, OMIM=[618556], no_hdr0=''),
    375743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375743, CurrentID=0, Status='live', Symbol='PTAR1', Aliases=[], description='protein prenyltransferase alpha subunit repeat containing 1', other_designations='protein prenyltransferase alpha subunit repeat-containing protein 1', map_location='9q21.12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=69709525, end_position_on_the_genomic_accession=69760044, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    375748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375748, CurrentID=0, Status='live', Symbol='ERCC6L2', Aliases=['BMFS2', 'C9orf102', 'HEBO', 'RAD26L', 'SR278'], description='ERCC excision repair 6 like 2', other_designations='DNA excision repair protein ERCC-6-like 2|DNA repair and recombination protein RAD26-like|excision repair cross-complementation group 6 like 2|excision repair cross-complementing rodent repair deficiency, complementation group 6-like 2|putative repair and recombination helicase RAD26L|stretch responsive protein 278', map_location='9q22.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=95875632, end_position_on_the_genomic_accession=96041092, orientation='plus', exon_count=27, OMIM=[615667], no_hdr0=''),
    375757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375757, CurrentID=0, Status='live', Symbol='SWI5', Aliases=['C9orf119', 'SAE3'], description='SWI5 homologous recombination repair protein', other_designations='DNA repair protein SWI5 homolog|HBV DNAPTP1-transactivated protein A|SWI5 recombination repair homolog|protein SAE3 homolog', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=128275356, end_position_on_the_genomic_accession=128288989, orientation='plus', exon_count=6, OMIM=[616528], no_hdr0=''),
    375759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375759, CurrentID=0, Status='live', Symbol='C9orf50', Aliases=[], description='chromosome 9 open reading frame 50', other_designations='uncharacterized protein C9orf50', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129612225, end_position_on_the_genomic_accession=129622275, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    375775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375775, CurrentID=0, Status='live', Symbol='PNPLA7', Aliases=['C9orf111', 'NTE-R1', 'NTEL1'], description='patatin like phospholipase domain containing 7', other_designations='patatin-like phospholipase domain-containing protein 7', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137459399, end_position_on_the_genomic_accession=137550666, orientation='minus', exon_count=38, OMIM=[612122], no_hdr0=''),
    375790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375790, CurrentID=0, Status='live', Symbol='AGRN', Aliases=['AGRIN', 'CMS8', 'CMSPPD'], description='agrin', other_designations='agrin|agrin proteoglycan', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1020102, end_position_on_the_genomic_accession=1056119, orientation='plus', exon_count=41, OMIM=[103320], no_hdr0=''),
    375791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=375791, CurrentID=0, Status='live', Symbol='CYSRT1', Aliases=['C9orf169'], description='cysteine rich tail 1', other_designations='cysteine-rich tail protein 1|UPF0574 protein C9orf169', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137225174, end_position_on_the_genomic_accession=137226315, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    376132 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=376132, CurrentID=0, Status='live', Symbol='LRRC10', Aliases=['HRLRRPA', 'LRRC10'], description='leucine rich repeat containing 10', other_designations='leucine-rich repeat-containing protein 10|heart-restricted leucine-rich repeat protein', map_location='12q15', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=69608564, end_position_on_the_genomic_accession=69610907, orientation='minus', exon_count=1, OMIM=[610846], no_hdr0=''),
    376267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=376267, CurrentID=0, Status='live', Symbol='RAB15', Aliases=[], description='RAB15, member RAS oncogene family', other_designations='ras-related protein Rab-15|RAB15, member RAS onocogene family', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64945816, end_position_on_the_genomic_accession=64972336, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    376497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=376497, CurrentID=0, Status='live', Symbol='SLC27A1', Aliases=['ACSVL5', 'FATP', 'FATP-1', 'FATP1'], description='solute carrier family 27 member 1', other_designations='long-chain fatty acid transport protein 1|fatty acid transport protein 1|solute carrier family 27 (fatty acid transporter), member 1', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17468745, end_position_on_the_genomic_accession=17506169, orientation='plus', exon_count=16, OMIM=[600691], no_hdr0=''),
    376940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=376940, CurrentID=0, Status='live', Symbol='ZC3H6', Aliases=['ZC3HDC6'], description='zinc finger CCCH-type containing 6', other_designations='zinc finger CCCH domain-containing protein 6|zinc finger CCCH-type domain containing 6', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112275594, end_position_on_the_genomic_accession=112340059, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    377007 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=377007, CurrentID=0, Status='live', Symbol='KLHL30', Aliases=[], description='kelch like family member 30', other_designations='kelch-like protein 30|kelch-like 30', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=238138668, end_position_on_the_genomic_accession=238152947, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    377630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=377630, CurrentID=0, Status='live', Symbol='USP17L2', Aliases=['DUB-3', 'DUB3', 'USP17'], description='ubiquitin specific peptidase 17 like family member 2', other_designations='ubiquitin carboxyl-terminal hydrolase 17|deubiquitinating enzyme 17-like protein 2|deubiquitinating enzyme 3|deubiquitinating protein 3|ubiquitin carboxyl-terminal hydrolase 17-like protein 2|ubiquitin specific peptidase 17-like 2|ubiquitin thioesterase 17-like protein 2|ubiquitin thiolesterase 17-like protein 2|ubiquitin-specific-processing protease 17-like protein 2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12136435, end_position_on_the_genomic_accession=12138849, orientation='minus', exon_count=1, OMIM=[610186], no_hdr0=''),
    377677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=377677, CurrentID=0, Status='live', Symbol='CA13', Aliases=['CAXIII'], description='carbonic anhydrase 13', other_designations='carbonic anhydrase 13|CA-XIII|carbonate dehydratase XIII|carbonic anhydrase XIII', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85245458, end_position_on_the_genomic_accession=85284073, orientation='plus', exon_count=7, OMIM=[611436], no_hdr0=''),
    377841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=377841, CurrentID=0, Status='live', Symbol='ENTPD8', Aliases=['E-NTPDase', 'GLSR2492', 'NTPDase-8', 'UNQ2492'], description='ectonucleoside triphosphate diphosphohydrolase 8', other_designations='ectonucleoside triphosphate diphosphohydrolase 8|E-NTPDase 8|liver ecto-ATP-diphosphohydrolase', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137434364, end_position_on_the_genomic_accession=137441710, orientation='minus', exon_count=11, OMIM=[616748], no_hdr0=''),
    378108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378108, CurrentID=0, Status='live', Symbol='TRIM74', Aliases=['TRIM50C'], description='tripartite motif containing 74', other_designations='tripartite motif-containing protein 74|tripartite motif-containing 50C|tripartite motif-containing protein 50C', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=72954845, end_position_on_the_genomic_accession=73005932, orientation='minus', exon_count=26, OMIM=[612550], no_hdr0=''),
    378708 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378708, CurrentID=0, Status='live', Symbol='CENPS', Aliases=['APITD1', 'CENP-S', 'FAAP16', 'MHF1'], description='centromere protein S', other_designations='centromere protein S|FANCM associated histone fold protein 1|FANCM-interacting histone fold protein 1|Fanconi anemia-associated polypeptide of 16 kDa|apoptosis-inducing TAF9-like domain-containing protein 1|apoptosis-inducing, TAF9-like domain 1', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10430433, end_position_on_the_genomic_accession=10442808, orientation='plus', exon_count=6, OMIM=[609130], no_hdr0=''),
    378807 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378807, CurrentID=0, Status='live', Symbol='CATSPER4', Aliases=[], description='cation channel sperm associated 4', other_designations='cation channel sperm-associated protein 4|ion channel CatSper4', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26189962, end_position_on_the_genomic_accession=26202964, orientation='plus', exon_count=11, OMIM=[609121], no_hdr0=''),
    378884 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378884, CurrentID=0, Status='live', Symbol='NHLRC1', Aliases=['EPM2A', 'EPM2B', 'MALIN', 'bA204B7.2'], description='NHL repeat containing E3 ubiquitin protein ligase 1', other_designations='E3 ubiquitin-protein ligase NHLRC1|NHL repeat containing 1|NHL repeat-containing protein 1|RING-type E3 ubiquitin transferase NHLRC1', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=18120440, end_position_on_the_genomic_accession=18122677, orientation='minus', exon_count=1, OMIM=[608072], no_hdr0=''),
    378925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378925, CurrentID=0, Status='live', Symbol='RNF148', Aliases=[], description='ring finger protein 148', other_designations='RING finger protein 148', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122701668, end_position_on_the_genomic_accession=122702922, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    378948 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378948, CurrentID=0, Status='live', Symbol='RBMY1B', Aliases=['RBMY1D'], description='RNA binding motif protein Y-linked family 1 member B', other_designations='RNA-binding motif protein, Y chromosome, family 1 member B|RNA-binding motif protein, Y chromosome, family 1 member D', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=21511338, end_position_on_the_genomic_accession=21527212, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    378949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378949, CurrentID=0, Status='live', Symbol='RBMY1D', Aliases=['RBM1', 'RBM2', 'RBMY1A1', 'YRRM1', 'YRRM2', 'hRBMY'], description='RNA binding motif protein Y-linked family 1 member D', other_designations='RNA-binding motif protein, Y chromosome, family 1 member D|RNA-binding motif protein 1|RNA-binding motif protein 2|RNA-binding motif protein, Y chromosome, family 1 member A1|Y chromosome RNA recognition motif 1', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=21869718, end_position_on_the_genomic_accession=21900746, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    378950 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378950, CurrentID=0, Status='live', Symbol='RBMY1E', Aliases=[], description='RNA binding motif protein Y-linked family 1 member E', other_designations='RNA-binding motif protein, Y chromosome, family 1 member E', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=21902177, end_position_on_the_genomic_accession=21918044, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    378951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=378951, CurrentID=0, Status='live', Symbol='RBMY1J', Aliases=[], description='RNA binding motif protein Y-linked family 1 member J', other_designations='RNA-binding motif protein, Y chromosome, family 1 member F/J|Y chromosome RNA recognition motif 2', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=22403410, end_position_on_the_genomic_accession=22419317, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    386617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386617, CurrentID=0, Status='live', Symbol='KCTD8', Aliases=[], description='potassium channel tetramerization domain containing 8', other_designations='BTB/POZ domain-containing protein KCTD8|potassium channel tetramerisation domain containing 8', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=44173903, end_position_on_the_genomic_accession=44449792, orientation='minus', exon_count=3, OMIM=[618442], no_hdr0=''),
    386618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386618, CurrentID=0, Status='live', Symbol='KCTD4', Aliases=['bA321C24.3'], description='potassium channel tetramerization domain containing 4', other_designations='BTB/POZ domain-containing protein KCTD4|potassium channel tetramerisation domain containing 4', map_location='13q14.12-q14.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=45192853, end_position_on_the_genomic_accession=45201045, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    386653 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386653, CurrentID=0, Status='live', Symbol='IL31', Aliases=['IL-31'], description='interleukin 31', other_designations='interleukin-31', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=122172029, end_position_on_the_genomic_accession=122174221, orientation='minus', exon_count=3, OMIM=[609509], no_hdr0=''),
    386672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386672, CurrentID=0, Status='live', Symbol='KRTAP10-4', Aliases=['KAP10.4', 'KAP18-4', 'KRTAP10.4', 'KRTAP18-4', 'KRTAP18.4'], description='keratin associated protein 10-4', other_designations='keratin-associated protein 10-4|high sulfur keratin-associated protein 10.4|keratin-associated protein 18.4', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44573729, end_position_on_the_genomic_accession=44575371, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386674 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386674, CurrentID=0, Status='live', Symbol='KRTAP10-6', Aliases=['KAP10.6', 'KAP18.6', 'KRTAP18-6', 'KRTAP18.6'], description='keratin associated protein 10-6', other_designations='keratin-associated protein 10-6|high sulfur keratin-associated protein 10.6|keratin associated protein 18-6', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44591268, end_position_on_the_genomic_accession=44592505, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    386675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386675, CurrentID=0, Status='live', Symbol='KRTAP10-7', Aliases=['KAP10.7', 'KAP18.7', 'KRTAP18-7'], description='keratin associated protein 10-7', other_designations='keratin-associated protein 10-7|high sulfur keratin-associated protein 10.7|keratin associated protein 18-7', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44600597, end_position_on_the_genomic_accession=44602174, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386676 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386676, CurrentID=0, Status='live', Symbol='KRTAP10-9', Aliases=['KAP10.9', 'KAP18.9', 'KRTAP18-9'], description='keratin associated protein 10-9', other_designations='keratin-associated protein 10-9|high sulfur keratin-associated protein 10.9|keratin associated protein 18-9|keratin-associated protein 10.9|keratin-associated protein 18.9', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44627093, end_position_on_the_genomic_accession=44628378, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386677, CurrentID=0, Status='live', Symbol='KRTAP10-1', Aliases=['KAP10.1', 'KAP18-1', 'KAP18.1', 'KRTAP10.1', 'KRTAP18-1', 'KRTAP18.1'], description='keratin associated protein 10-1', other_designations='keratin-associated protein 10-1|high sulfur keratin-associated protein 10.1|keratin-associated protein 10.1|keratin-associated protein 18-1|keratin-associated protein 18.1', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44538981, end_position_on_the_genomic_accession=44540195, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    386678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386678, CurrentID=0, Status='live', Symbol='KRTAP10-11', Aliases=['KAP10.11', 'KAP10.9', 'KAP18-9', 'KAP18.11', 'KRTAP10-9', 'KRTAP10.9', 'KRTAP18-11', 'KRTAP18-9', 'KRTAP18.11', 'KRTAP18.9'], description='keratin associated protein 10-11', other_designations='keratin-associated protein 10-11|High sulfur keratin-associated protein 10.9|Keratin-associated protein 10-9|Keratin-associated protein 10.9|Keratin-associated protein 18-9|Keratin-associated protein 18.9|high sulfur keratin-associated protein 10.11|keratin associated protein 18-11|keratin-associated protein 10.11|keratin-associated protein 18.11', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44646414, end_position_on_the_genomic_accession=44647650, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386679, CurrentID=0, Status='live', Symbol='KRTAP10-2', Aliases=['KAP10.2', 'KAP18-2', 'KAP18.2', 'KRTAP10.2', 'KRTAP18-2', 'KRTAP18.2'], description='keratin associated protein 10-2', other_designations='keratin-associated protein 10-2|high sulfur keratin-associated protein 10.2|keratin-associated protein 18-2|keratin-associated protein 18.2', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44550357, end_position_on_the_genomic_accession=44551505, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    386680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386680, CurrentID=0, Status='live', Symbol='KRTAP10-5', Aliases=['KAP10.5', 'KAP18-5', 'KAP18.5', 'KRTAP10.5', 'KRTAP18-5', 'KRTAP18.1', 'KRTAP18.5'], description='keratin associated protein 10-5', other_designations='keratin-associated protein 10-5|high sulfur keratin-associated protein 10.5|keratin-associated protein 18.5', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44579455, end_position_on_the_genomic_accession=44580604, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    386681 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386681, CurrentID=0, Status='live', Symbol='KRTAP10-8', Aliases=['KAP10.8', 'KRTAP18-8', 'KRTAP18.8'], description='keratin associated protein 10-8', other_designations='keratin-associated protein 10-8|high sulfur keratin-associated protein 10.8|keratin associated protein 18-8|keratin-associated protein 10.8|keratin-associated protein 18.8', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44612079, end_position_on_the_genomic_accession=44612954, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386682, CurrentID=0, Status='live', Symbol='KRTAP10-3', Aliases=['KAP10.3', 'KAP18-3', 'KAP18.3', 'KRTAP10.3', 'KRTAP18-3', 'KRTAP18.3'], description='keratin associated protein 10-3', other_designations='keratin-associated protein 10-3|high sulfur keratin-associated protein 10.3|keratin-associated protein 18-3|keratin-associated protein 18.3', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44557790, end_position_on_the_genomic_accession=44558795, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    386683 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386683, CurrentID=0, Status='live', Symbol='KRTAP12-3', Aliases=['KRTAP12.3'], description='keratin associated protein 12-3', other_designations='keratin-associated protein 12-3|high sulfur keratin-associated protein 12.3|keratin-associated protein 12.3', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44657932, end_position_on_the_genomic_accession=44658341, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386684, CurrentID=0, Status='live', Symbol='KRTAP12-4', Aliases=['KRTAP12.4'], description='keratin associated protein 12-4', other_designations='keratin-associated protein 12-4|high sulfur keratin-associated protein 12.4', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44654213, end_position_on_the_genomic_accession=44654659, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    386685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386685, CurrentID=0, Status='live', Symbol='KRTAP10-12', Aliases=['KAP10.12', 'KRTAP18-12', 'KRTAP18.12'], description='keratin associated protein 10-12', other_designations='keratin-associated protein 10-12|high sulfur keratin-associated protein 10.12|keratin-associated protein 18-12', map_location='21q22.3', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=44697172, end_position_on_the_genomic_accession=44698044, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    386724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386724, CurrentID=0, Status='live', Symbol='AMIGO3', Aliases=['ALI3', 'AMIGO-3'], description='adhesion molecule with Ig like domain 3', other_designations='amphoterin-induced protein 3|alivin-3|amphoterin-induced gene and ORF 3', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49716829, end_position_on_the_genomic_accession=49719684, orientation='minus', exon_count=1, OMIM=[615691], no_hdr0=''),
    386746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=386746, CurrentID=0, Status='live', Symbol='MRGPRG', Aliases=['GPR169', 'MRGG'], description='MAS related GPR family member G', other_designations='mas-related G-protein coupled receptor member G|G protein-coupled receptor 169|G protein-coupled receptor MRGG', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3217944, end_position_on_the_genomic_accession=3218813, orientation='minus', exon_count=1, OMIM=[607234], no_hdr0=''),
    387032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387032, CurrentID=0, Status='live', Symbol='ZKSCAN4', Aliases=['P1P373C6', 'ZNF307', 'ZNF427', 'ZSCAN36'], description='zinc finger with KRAB and SCAN domains 4', other_designations='zinc finger protein with KRAB and SCAN domains 4|p373c6.1 (novel C2H2 type zinc finger protein)|zinc finger protein 307|zinc finger protein 427', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28241697, end_position_on_the_genomic_accession=28259258, orientation='minus', exon_count=7, OMIM=[611643], no_hdr0=''),
    387082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387082, CurrentID=0, Status='live', Symbol='SUMO4', Aliases=['IDDM5', 'SMT3H4', 'SUMO-4', 'dJ281H8.4'], description='small ubiquitin like modifier 4', other_designations='small ubiquitin-related modifier 4|SMT3 suppressor of mif two 3 homolog 2|SMT3 suppressor of mif two 3 homolog 4|insulin-dependent diabetes mellitus 5|small ubiquitin-like modifier 4 protein', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=149400262, end_position_on_the_genomic_accession=149401278, orientation='plus', exon_count=1, OMIM=[608829], no_hdr0=''),
    387103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387103, CurrentID=0, Status='live', Symbol='CENPW', Aliases=['C6orf173', 'CENP-W', 'CUG2'], description='centromere protein W', other_designations='centromere protein W|cancer-up-regulated gene 2 protein|cancer-upregulated gene 2', map_location='6q22.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=126339696, end_position_on_the_genomic_accession=126483320, orientation='plus', exon_count=5, OMIM=[611264], no_hdr0=''),
    387104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387104, CurrentID=0, Status='live', Symbol='SOGA3', Aliases=['C6orf174', 'dJ403A15.3'], description='SOGA family member 3', other_designations='protein SOGA3', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127438406, end_position_on_the_genomic_accession=127519024, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    387119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387119, CurrentID=0, Status='live', Symbol='CEP85L', Aliases=['C6orf204', 'LIS10', 'NY-BR-15', 'bA57K17.2'], description='centrosomal protein 85 like', other_designations='centrosomal protein of 85 kDa-like|centrosomal protein 85kDa-like|serologically defined breast cancer antigen NY-BR-15', map_location='6q22.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=118460772, end_position_on_the_genomic_accession=118710101, orientation='minus', exon_count=19, OMIM=[618865], no_hdr0=''),
    387129 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387129, CurrentID=0, Status='live', Symbol='NPSR1', Aliases=['ASRT2', 'GPR154', 'GPRA', 'NPSR', 'PGR14', 'VRR1'], description='neuropeptide S receptor 1', other_designations='neuropeptide S receptor|G-protein coupled receptor 154|G-protein coupled receptor PGR14|G-protein coupled receptor for asthma susceptibility|vasopressin receptor-related receptor 1', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=34658218, end_position_on_the_genomic_accession=34878332, orientation='plus', exon_count=11, OMIM=[608595], no_hdr0=''),
    387263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387263, CurrentID=0, Status='live', Symbol='C6orf120', Aliases=[], description='chromosome 6 open reading frame 120', other_designations='UPF0669 protein C6orf120', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169702112, end_position_on_the_genomic_accession=169706360, orientation='plus', exon_count=1, OMIM=[616987], no_hdr0=''),
    387264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387264, CurrentID=0, Status='live', Symbol='KRTAP5-1', Aliases=['KRN1L', 'KRTAP5.1'], description='keratin associated protein 5-1', other_designations='keratin-associated protein 5-1|keratin-associated protein 5.1|ultrahigh sulfur keratin-associated protein 5.1', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1584342, end_position_on_the_genomic_accession=1585283, orientation='minus', exon_count=1, OMIM=[148022], no_hdr0=''),
    387266 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387266, CurrentID=0, Status='live', Symbol='KRTAP5-3', Aliases=['KRTAP5-9', 'KRTAP5.3'], description='keratin associated protein 5-3', other_designations='keratin-associated protein 5-3|keratin-associated protein 5-9|keratin-associated protein 5.3|keratin-associated protein 5.9|ultrahigh sulfur keratin-associated protein 5.3', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1607565, end_position_on_the_genomic_accession=1608463, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    387267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387267, CurrentID=0, Status='live', Symbol='KRTAP5-4', Aliases=['KRTAP5.4'], description='keratin associated protein 5-4', other_designations='keratin-associated protein 5-4|keratin-associated protein 5.4|ultrahigh sulfur keratin-associated protein 5.4', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1620958, end_position_on_the_genomic_accession=1622138, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    387273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387273, CurrentID=0, Status='live', Symbol='KRTAP5-10', Aliases=['KRTAP5.10'], description='keratin associated protein 5-10', other_designations='keratin-associated protein 5-10|keratin-associated protein 5.10|ultrahigh sulfur keratin-associated protein 5.10', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71565563, end_position_on_the_genomic_accession=71566735, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    387332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387332, CurrentID=0, Status='live', Symbol='TBPL2', Aliases=['TBP2', 'TRF3'], description='TATA-box binding protein like 2', other_designations='TATA box-binding protein-like 2|TATA box-binding protein-like protein 2|TATA box-binding protein-related factor 3|TBP-like 2|TBP-like protein 2|TBP-related factor 3', map_location='14q22.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=55414210, end_position_on_the_genomic_accession=55440545, orientation='minus', exon_count=7, OMIM=[608964], no_hdr0=''),
    387338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387338, CurrentID=0, Status='live', Symbol='NSUN4', Aliases=['SHTAP'], description='NOP2/Sun RNA methyltransferase 4', other_designations='5-methylcytosine rRNA methyltransferase NSUN4|5-methylcytosine tRNA methyltransferase NSUN4|NOL1/NOP2/Sun domain family member 4|NOP2/Sun RNA methyltransferase family member 4|NOP2/Sun domain family, member 4|putative methyltransferase NSUN4|sperm head and tail associated protein', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46340807, end_position_on_the_genomic_accession=46385199, orientation='plus', exon_count=10, OMIM=[615394], no_hdr0=''),
    387357 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387357, CurrentID=0, Status='live', Symbol='THEMIS', Aliases=['C6orf190', 'C6orf207', 'GASP', 'SPOT', 'TSEPA'], description='thymocyte selection associated', other_designations='protein THEMIS|GRB2-associated protein|signaling phosphoprotein specific for T cells|thymocyte selection pathway associated|thymocyte-expressed molecule involved in selection', map_location='6q22.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=127708194, end_position_on_the_genomic_accession=127918595, orientation='minus', exon_count=12, OMIM=[613607], no_hdr0=''),
    387496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387496, CurrentID=0, Status='live', Symbol='RASL11A', Aliases=[], description='RAS like family 11 member A', other_designations='ras-like protein family member 11A', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27270830, end_position_on_the_genomic_accession=27275192, orientation='plus', exon_count=5, OMIM=[612403], no_hdr0=''),
    387509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387509, CurrentID=0, Status='live', Symbol='GPR153', Aliases=['PGR1'], description='G protein-coupled receptor 153', other_designations='probable G-protein coupled receptor 153|G-protein coupled receptor PGR1', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6247353, end_position_on_the_genomic_accession=6261098, orientation='minus', exon_count=6, OMIM=[614269], no_hdr0=''),
    387521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387521, CurrentID=0, Status='live', Symbol='PEDS1', Aliases=['CarF', 'KUA', 'TMEM189'], description='plasmanylethanolamine desaturase 1', other_designations='plasmanylethanolamine desaturase|transmembrane protein 189', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50118254, end_position_on_the_genomic_accession=50153723, orientation='minus', exon_count=7, OMIM=[610994], no_hdr0=''),
    387522 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387522, CurrentID=0, Status='live', Symbol='PEDS1-UBE2V1', Aliases=['CROC-1B', 'CROC1B', 'KUA-UEV', 'TMEM189-UBE2V1'], description='PEDS1-UBE2V1 readthrough', other_designations='TMEM189-UBE2V1 fusion protein|TMEM189-UBE2V1 readthrough transcript|transmembrane protein 189-ubiquitin-conjugating enzyme E2 variant 1 read-through', map_location='20q13.13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=50081124, end_position_on_the_genomic_accession=50153723, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    387597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387597, CurrentID=0, Status='live', Symbol='ILDR2', Aliases=['C1orf32', 'dJ782G3.1'], description='immunoglobulin like domain containing receptor 2', other_designations='immunoglobulin-like domain-containing receptor 2|angulin-3', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=166908187, end_position_on_the_genomic_accession=166975540, orientation='minus', exon_count=15, OMIM=[618081], no_hdr0=''),
    387601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387601, CurrentID=0, Status='live', Symbol='SLC22A25', Aliases=['HIMTP', 'UST6'], description='solute carrier family 22 member 25', other_designations='solute carrier family 22 member 25|MGI:2442751, MGI:2385316, MGI:3042283, MGI:3645714, MGI:3605624, MGI:2442750|organic anion transporter UST6|putative UST1-like organic anion transporter', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63158437, end_position_on_the_genomic_accession=63243599, orientation='minus', exon_count=16, OMIM=[610792], no_hdr0=''),
    387640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387640, CurrentID=0, Status='live', Symbol='SKIDA1', Aliases=['C10orf140', 'DLN-1'], description='SKI/DACH domain containing 1', other_designations='SKI/DACH domain-containing protein 1|protein DLN-1', map_location='10p12.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=21510754, end_position_on_the_genomic_accession=21525682, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    387680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387680, CurrentID=0, Status='live', Symbol='WASHC2A', Aliases=['FAM21A', 'FAM21B', 'bA56A21.1', 'bA98I6.1'], description='WASH complex subunit 2A', other_designations='WASH complex subunit 2A|WASH complex subunit FAM21A|WASH complex subunit FAM21B|alternative protein FAM21B|family with sequence similarity 21 member A|family with sequence similarity 21, member B', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50067901, end_position_on_the_genomic_accession=50133509, orientation='plus', exon_count=33, OMIM=[], no_hdr0=''),
    387694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387694, CurrentID=0, Status='live', Symbol='SH2D4B', Aliases=[], description='SH2 domain containing 4B', other_designations='SH2 domain-containing protein 4B|novel SH2 domain-containing protein', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=80537902, end_position_on_the_genomic_accession=80646560, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    387695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387695, CurrentID=0, Status='live', Symbol='C10orf99', Aliases=['AP-57', 'AP57', 'CSBF', 'GPR15L', 'UNQ1833'], description='chromosome 10 open reading frame 99', other_designations='protein GPR15L|G protein-coupled receptor 15 ligand|RLLV1833|anti-microbial peptide with 57 amino acid residues|antimicrobial peptide with 57 amino acid residues|antimicrobial peptide-57|colon-derived SUSD2 binding factor|secreted protein C10orf99', map_location='10q23.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=84173764, end_position_on_the_genomic_accession=84185294, orientation='plus', exon_count=3, OMIM=[617775], no_hdr0=''),
    387700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387700, CurrentID=0, Status='live', Symbol='SLC16A12', Aliases=['CJMG', 'CRT2', 'CTRCT47', 'MCT12'], description='solute carrier family 16 member 12', other_designations='monocarboxylate transporter 12|creatine transporter 2|monocarboxylic acid transporter 12', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89430299, end_position_on_the_genomic_accession=89536029, orientation='minus', exon_count=9, OMIM=[611910], no_hdr0=''),
    387707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387707, CurrentID=0, Status='live', Symbol='CC2D2B', Aliases=['C10orf130', 'C10orf131'], description='coiled-coil and C2 domain containing 2B', other_designations='protein CC2D2B|uncharacterized protein C10orf131', map_location='10q24.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=95907440, end_position_on_the_genomic_accession=96035768, orientation='plus', exon_count=41, OMIM=[], no_hdr0=''),
    387712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387712, CurrentID=0, Status='live', Symbol='ENO4', Aliases=['C10orf134'], description='enolase 4', other_designations='enolase 4|2-phospho-D-glycerate hydro-lyase|enolase family member 4|enolase-like protein ENO4', map_location='10q25.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=116848230, end_position_on_the_genomic_accession=116911803, orientation='plus', exon_count=15, OMIM=[131375], no_hdr0=''),
    387715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387715, CurrentID=0, Status='live', Symbol='ARMS2', Aliases=['ARMD8'], description='age-related maculopathy susceptibility 2', other_designations='age-related maculopathy susceptibility protein 2', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122454653, end_position_on_the_genomic_accession=122457352, orientation='plus', exon_count=2, OMIM=[611313], no_hdr0=''),
    387718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387718, CurrentID=0, Status='live', Symbol='TEX36', Aliases=['C10orf122', 'bA383C5.1'], description='testis expressed 36', other_designations='testis-expressed protein 36|testis-expressed sequence 36 protein', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=125576522, end_position_on_the_genomic_accession=125683163, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    387723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387723, CurrentID=0, Status='live', Symbol='C10orf143', Aliases=['LINC00959'], description='chromosome 10 open reading frame 143', other_designations='uncharacterized protein C10orf143|long intergenic non-protein coding RNA 959', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=130034490, end_position_on_the_genomic_accession=130110848, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    387733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387733, CurrentID=0, Status='live', Symbol='IFITM5', Aliases=['BRIL', 'DSPA1', 'Hrmp1', 'OI5', 'fragilis4'], description='interferon induced transmembrane protein 5', other_designations='interferon-induced transmembrane protein 5|bone-restricted ifitm-like protein|bone-restricted interferon-induced transmembrane protein-like protein|dispanin subfamily A member 1', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=298200, end_position_on_the_genomic_accession=299526, orientation='minus', exon_count=2, OMIM=[614757], no_hdr0=''),
    387748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387748, CurrentID=0, Status='live', Symbol='OR56B1', Aliases=['OR11-65P', 'OR56B1'], description='olfactory receptor family 56 subfamily B member 1', other_designations='olfactory receptor 56B1|olfactory receptor OR11-65|olfactory receptor, family 56, subfamily B, member 1 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5736448, end_position_on_the_genomic_accession=5738523, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    387755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387755, CurrentID=0, Status='live', Symbol='INSC', Aliases=[], description='INSC spindle orientation adaptor protein', other_designations='protein inscuteable homolog|inscuteable homolog|inscuteable spindle orientation adaptor protein', map_location='11p15.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=15111416, end_position_on_the_genomic_accession=15269675, orientation='plus', exon_count=20, OMIM=[610668], no_hdr0=''),
    387758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387758, CurrentID=0, Status='live', Symbol='FIBIN', Aliases=[], description='fin bud initiation factor homolog', other_designations='fin bud initiation factor homolog', map_location='11p14.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=26994112, end_position_on_the_genomic_accession=26997087, orientation='plus', exon_count=1, OMIM=[617085], no_hdr0=''),
    387763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387763, CurrentID=0, Status='live', Symbol='C11orf96', Aliases=['AG2'], description='chromosome 11 open reading frame 96', other_designations='uncharacterized protein C11orf96|protein Ag2 homolog', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=43942637, end_position_on_the_genomic_accession=43943878, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    387775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387775, CurrentID=0, Status='live', Symbol='SLC22A10', Aliases=['OAT5', 'hOAT5'], description='solute carrier family 22 member 10', other_designations='solute carrier family 22 member 10|organic anion transporter 5|solute carrier family 22 (organic anion/cation transporter), member 10', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=63268257, end_position_on_the_genomic_accession=63311983, orientation='plus', exon_count=12, OMIM=[607580], no_hdr0=''),
    387778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387778, CurrentID=0, Status='live', Symbol='SPDYC', Aliases=['RINGOC', 'Ringo2'], description='speedy/RINGO cell cycle regulator family member C', other_designations='speedy protein C|RINGO C|hSpy/Ringo C|rapid inducer of G2/M progression in oocytes C|speedy homolog C', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65170154, end_position_on_the_genomic_accession=65173666, orientation='plus', exon_count=7, OMIM=[614030], no_hdr0=''),
    387787 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387787, CurrentID=0, Status='live', Symbol='LIPT2', Aliases=[], description='lipoyl(octanoyl) transferase 2', other_designations='putative lipoyltransferase 2, mitochondrial|lipoate-protein ligase B|lipoyl(octanoyl) transferase 2 (putative)|octanoyl-[acyl-carrier-protein]-protein N-octanoyltransferase|putative octanoyltransferase, mitochondrial', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=74490519, end_position_on_the_genomic_accession=74493724, orientation='minus', exon_count=2, OMIM=[617659], no_hdr0=''),
    387804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387804, CurrentID=0, Status='live', Symbol='VSTM5', Aliases=['C11orf90'], description='V-set and transmembrane domain containing 5', other_designations='V-set and transmembrane domain-containing protein 5', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93817315, end_position_on_the_genomic_accession=93850653, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    387836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387836, CurrentID=0, Status='live', Symbol='CLEC2A', Aliases=['INPE5792', 'KACL', 'PILAR', 'UNQ5792'], description='C-type lectin domain family 2 member A', other_designations='C-type lectin domain family 2 member A|keratinocyte-associated C-type lectin|proliferation-induced lymphocyte-associated receptor', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9882733, end_position_on_the_genomic_accession=9932430, orientation='minus', exon_count=7, OMIM=[612087], no_hdr0=''),
    387837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387837, CurrentID=0, Status='live', Symbol='CLEC12B', Aliases=['UNQ5782'], description='C-type lectin domain family 12 member B', other_designations='C-type lectin domain family 12 member B|macrophage antigen h|testis secretory sperm-binding protein Li 205a', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10006138, end_position_on_the_genomic_accession=10018800, orientation='plus', exon_count=8, OMIM=[617573], no_hdr0=''),
    387849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387849, CurrentID=0, Status='live', Symbol='REP15', Aliases=['RAB15EP'], description='RAB15 effector protein', other_designations='rab15 effector protein', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27696447, end_position_on_the_genomic_accession=27697596, orientation='plus', exon_count=1, OMIM=[610848], no_hdr0=''),
    387856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387856, CurrentID=0, Status='live', Symbol='CCDC184', Aliases=['C12orf68'], description='coiled-coil domain containing 184', other_designations='coiled-coil domain-containing protein 184', map_location='12q13.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=48183644, end_position_on_the_genomic_accession=48185926, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    387882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387882, CurrentID=0, Status='live', Symbol='C12orf75', Aliases=['AGD3', 'OCC-1', 'OCC1'], description='chromosome 12 open reading frame 75', other_designations='overexpressed in colon carcinoma 1 protein|adipogenesis down-regulated 3|overexpressed in colon carcinoma-1|putative overexpressed in colon carcinoma-1 protein variant C', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=105330691, end_position_on_the_genomic_accession=105371518, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    387885 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387885, CurrentID=0, Status='live', Symbol='CFAP73', Aliases=['CCDC42B', 'MIA2'], description='cilia and flagella associated protein 73', other_designations='cilia- and flagella-associated protein 73|coiled-coil domain containing 42B|coiled-coil domain-containing protein 42B', map_location='12q24.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=113149162, end_position_on_the_genomic_accession=113159276, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    387890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387890, CurrentID=0, Status='live', Symbol='TMEM233', Aliases=['DSPB2', 'IFITMD2'], description='transmembrane protein 233', other_designations='transmembrane protein 233|dispanin subfamily B member 2|interferon induced transmembrane protein domain containing 2|interferon-induced transmembrane domain-containing protein D2', map_location='12q24.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=119592123, end_position_on_the_genomic_accession=119654455, orientation='plus', exon_count=7, OMIM=[618296], no_hdr0=''),
    387893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387893, CurrentID=0, Status='live', Symbol='KMT5A', Aliases=['PR-Set7', 'PR/SET07', 'SET07', 'SET8', 'SETD8'], description='lysine methyltransferase 5A', other_designations='N-lysine methyltransferase KMT5A|H4-K20-HMTase KMT5A|H4-K20-HMTase SETD8|H4-K20-specific histone methyltransferase|H4K20-specific histone methyltransferase splice variant Set8b|N-lysine methyltransferase SETD8|PR/SET domain containing protein 8|PR/SET domain-containing protein 07|SET domain containing (lysine methyltransferase) 8|SET domain-containing protein 8|histone-lysine N-methyltransferase KMT5A|histone-lysine N-methyltransferase SETD8|lysine (K)-specific methyltransferase 5A|lysine N-methyltransferase 5A|lysine-specific methylase 5A', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123384132, end_position_on_the_genomic_accession=123409353, orientation='plus', exon_count=11, OMIM=[607240], no_hdr0=''),
    387911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387911, CurrentID=0, Status='live', Symbol='C1QTNF9B', Aliases=['CTRP9B'], description='C1q and TNF related 9B', other_designations='complement C1q and tumor necrosis factor-related protein 9B|C1q and tumor necrosis factor related protein 9B|C1q/TNF-related protein 9B|collagen triple helix repeat-containing', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=23891099, end_position_on_the_genomic_accession=23897502, orientation='minus', exon_count=6, OMIM=[614148], no_hdr0=''),
    387914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387914, CurrentID=0, Status='live', Symbol='SHISA2', Aliases=['C13orf13', 'PRO28631', 'TMEM46', 'WGAR9166', 'bA398O19.2', 'hShisa'], description='shisa family member 2', other_designations='protein shisa-2 homolog|shisa homolog 2|transmembrane protein 46', map_location='13q12.13', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=26044597, end_position_on_the_genomic_accession=26052016, orientation='minus', exon_count=2, OMIM=[617324], no_hdr0=''),
    387921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387921, CurrentID=0, Status='live', Symbol='NHLRC3', Aliases=[], description='NHL repeat containing 3', other_designations='NHL repeat-containing protein 3', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=39038311, end_position_on_the_genomic_accession=39050109, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    387923 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387923, CurrentID=0, Status='live', Symbol='SERP2', Aliases=['C13orf21', 'bA269C23.1'], description='stress associated endoplasmic reticulum protein family member 2', other_designations='stress-associated endoplasmic reticulum protein 2|ribosome-associated membrane protein RAMP4-2', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=44373523, end_position_on_the_genomic_accession=44397714, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    387990 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=387990, CurrentID=0, Status='live', Symbol='TOMM20L', Aliases=['UNQ9438'], description='translocase of outer mitochondrial membrane 20 like', other_designations='TOMM20-like protein 1|translocase of outer mitochondrial membrane 20 homolog type I|translocase of outer mitochondrial membrane 20 homolog-like', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=58395904, end_position_on_the_genomic_accession=58417080, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    388015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388015, CurrentID=0, Status='live', Symbol='RTL1', Aliases=['HUR1', 'MART1', 'Mar1', 'PEG11', 'SIRH2'], description='retrotransposon Gag like 1', other_designations='retrotransposon-like protein 1|Sushi-Ichi retrotransposon homolog 2|mammalian retrotransposon derived protein 1|mammalian retrotransposon-derived 1|paternally expressed 11|paternally expressed gene 11 protein|retrotransposon-derived protein PEG11|retrotransposon-like 1', map_location='14q32.2-q32.31', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=100879753, end_position_on_the_genomic_accession=100903722, orientation='minus', exon_count=4, OMIM=[611896], no_hdr0=''),
    388021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388021, CurrentID=0, Status='live', Symbol='TMEM179', Aliases=['C14orf90A', 'TMEM179'], description='transmembrane protein 179', other_designations='transmembrane protein 179|transmembrane protein 179A', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104590864, end_position_on_the_genomic_accession=104604787, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    388112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388112, CurrentID=0, Status='live', Symbol='NANOGP8', Aliases=['NANOGP1', 'PN8'], description='Nanog homeobox retrogene P8', other_designations='homeobox protein NANOGP8|putative homeobox protein NANOGP8', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=35083410, end_position_on_the_genomic_accession=35085295, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    388115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388115, CurrentID=0, Status='live', Symbol='CCDC9B', Aliases=['C15orf52'], description='coiled-coil domain containing 9B', other_designations='coiled-coil domain-containing protein 9B|uncharacterized protein C15orf52', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40331452, end_position_on_the_genomic_accession=40340939, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    388121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388121, CurrentID=0, Status='live', Symbol='TNFAIP8L3', Aliases=['TIPE3'], description='TNF alpha induced protein 8 like 3', other_designations='tumor necrosis factor alpha-induced protein 8-like protein 3|TNF alpha-induced protein 8-like protein 3|TNFAIP8-like protein 3|tumor necrosis factor, alpha induced protein 8 like 3', map_location='15q21.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=51056601, end_position_on_the_genomic_accession=51105276, orientation='minus', exon_count=3, OMIM=[616438], no_hdr0=''),
    388125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388125, CurrentID=0, Status='live', Symbol='C2CD4B', Aliases=['FAM148B', 'NLF2'], description='C2 calcium dependent domain containing 4B', other_designations='C2 calcium-dependent domain-containing protein 4B|family with sequence similarity 148, member B|nuclear localized factor 2', map_location='15q22.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=62163535, end_position_on_the_genomic_accession=62165732, orientation='minus', exon_count=3, OMIM=[610344], no_hdr0=''),
    388135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388135, CurrentID=0, Status='live', Symbol='INSYN1', Aliases=['C15orf59'], description='inhibitory synaptic factor 1', other_designations='inhibitory synaptic factor 1|UPF0583 protein C15orf59|inhibitory synaptic protein 1', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=73735458, end_position_on_the_genomic_accession=73753351, orientation='minus', exon_count=3, OMIM=[617128], no_hdr0=''),
    388199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388199, CurrentID=0, Status='live', Symbol='PRR25', Aliases=['gs64'], description='proline rich 25', other_designations='proline-rich protein 25', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=805443, end_position_on_the_genomic_accession=813861, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    388228 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388228, CurrentID=0, Status='live', Symbol='SBK1', Aliases=['SBK'], description='SH3 domain binding kinase 1', other_designations='serine/threonine-protein kinase SBK1|SH3-binding domain kinase 1', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28258628, end_position_on_the_genomic_accession=28323849, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    388272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388272, CurrentID=0, Status='live', Symbol='C16orf87', Aliases=[], description='chromosome 16 open reading frame 87', other_designations='UPF0547 protein C16orf87', map_location='16q11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=46796603, end_position_on_the_genomic_accession=46831471, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388284, CurrentID=0, Status='live', Symbol='C16orf86', Aliases=[], description='chromosome 16 open reading frame 86', other_designations='uncharacterized protein C16orf86', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67666814, end_position_on_the_genomic_accession=67670523, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    388323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388323, CurrentID=0, Status='live', Symbol='GLTPD2', Aliases=[], description='glycolipid transfer protein domain containing 2', other_designations='glycolipid transfer protein domain-containing protein 2', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4788964, end_position_on_the_genomic_accession=4790589, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    388324 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388324, CurrentID=0, Status='live', Symbol='INCA1', Aliases=['HSD45'], description='inhibitor of CDK, cyclin A1 interacting protein 1', other_designations='protein INCA1', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4988130, end_position_on_the_genomic_accession=5006093, orientation='minus', exon_count=10, OMIM=[617374], no_hdr0=''),
    388325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388325, CurrentID=0, Status='live', Symbol='SCIMP', Aliases=['C17orf87', 'UNQ5783'], description='SLP adaptor and CSK interacting membrane protein', other_designations='SLP adapter and CSK-interacting membrane protein|DTFT5783|SLP65/SLP76, Csk-interacting membrane protein|transmembrane protein C17orf87', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5208920, end_position_on_the_genomic_accession=5234860, orientation='minus', exon_count=6, OMIM=[614406], no_hdr0=''),
    388327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388327, CurrentID=0, Status='live', Symbol='C17orf100', Aliases=[], description='chromosome 17 open reading frame 100', other_designations='uncharacterized protein C17orf100|hCG1985469', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=6651762, end_position_on_the_genomic_accession=6653476, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    388333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388333, CurrentID=0, Status='live', Symbol='SPDYE4', Aliases=[], description='speedy/RINGO cell cycle regulator family member E4', other_designations='speedy protein E4|putative Speedy protein E4|speedy homolog E4', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8747532, end_position_on_the_genomic_accession=8758546, orientation='minus', exon_count=8, OMIM=[617628], no_hdr0=''),
    388335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388335, CurrentID=0, Status='live', Symbol='TMEM220', Aliases=[], description='transmembrane protein 220', other_designations='transmembrane protein 220', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10711084, end_position_on_the_genomic_accession=10730023, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    388336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388336, CurrentID=0, Status='live', Symbol='SHISA6', Aliases=[], description='shisa family member 6', other_designations='protein shisa-6|protein shisa-6 homolog|shisa homolog 6', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=11241213, end_position_on_the_genomic_accession=11564063, orientation='plus', exon_count=6, OMIM=[617327], no_hdr0=''),
    388341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388341, CurrentID=0, Status='live', Symbol='LRRC75A', Aliases=['C17orf76', 'FAM211A'], description='leucine rich repeat containing 75A', other_designations='leucine-rich repeat-containing protein 75A|family with sequence similarity 211, member A|leucine-rich repeat-containing protein C17orf76|leucine-rich repeat-containing protein FAM211A', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=16441577, end_position_on_the_genomic_accession=16492193, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388364, CurrentID=0, Status='live', Symbol='TMIGD1', Aliases=['TMIGD', 'UNQ9372'], description='transmembrane and immunoglobulin domain containing 1', other_designations='transmembrane and immunoglobulin domain-containing protein 1|AWKS9372', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=30316329, end_position_on_the_genomic_accession=30334076, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388372, CurrentID=0, Status='live', Symbol='CCL4L1', Aliases=['AT744.2', 'CCL4L', 'LAG-1', 'LAG1', 'MIP-1-beta', 'SCYA4L', 'SCYA4L1', 'SCYA4L2'], description='C-C motif chemokine ligand 4 like 1', other_designations='C-C motif chemokine 4-like|CC chemokine ligand 4L1|Lymphocyte activation gene 1 protein|Macrophage inflammatory protein 1-beta|Monocyte adherence-induced protein 5-alpha|Small-inducible cytokine A4-like|chemokine (C-C motif) ligand 4-like 1, telomeric|macrophage inflammatory protein-1b2|small inducible cytokine A4-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[603782], no_hdr0=''),
    388381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388381, CurrentID=0, Status='live', Symbol='C17orf98', Aliases=[], description='chromosome 17 open reading frame 98', other_designations='uncharacterized protein C17orf98', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38835086, end_position_on_the_genomic_accession=38841438, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    388389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388389, CurrentID=0, Status='live', Symbol='CCDC103', Aliases=['CILD17', 'PR46b', 'SMH'], description='coiled-coil domain containing 103', other_designations='coiled-coil domain-containing protein 103', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44899729, end_position_on_the_genomic_accession=44905390, orientation='plus', exon_count=4, OMIM=[614677], no_hdr0=''),
    388394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388394, CurrentID=0, Status='live', Symbol='RPRML', Aliases=[], description='reprimo like', other_designations='reprimo-like protein', map_location='17q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46978156, end_position_on_the_genomic_accession=46979253, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    388403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388403, CurrentID=0, Status='live', Symbol='YPEL2', Aliases=['FKSG4'], description='yippee like 2', other_designations='protein yippee-like 2|DiGeorge syndrome-related protein', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=59331655, end_position_on_the_genomic_accession=59401732, orientation='plus', exon_count=6, OMIM=[609723], no_hdr0=''),
    388419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388419, CurrentID=0, Status='live', Symbol='BTBD17', Aliases=['BTBD17A', 'LGALS3BPL', 'TANGO10A'], description='BTB domain containing 17', other_designations='BTB/POZ domain-containing protein 17|BTB (POZ) domain containing 17|BTB/POZ and BACK domain-containing protein LOC388419|transport and golgi organization 10 homolog A', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74356416, end_position_on_the_genomic_accession=74363655, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    388428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388428, CurrentID=0, Status='live', Symbol='PVALEF', Aliases=['AATK-AS1'], description='parvalbumin like EF-hand containing', other_designations='parvalbumin-like EF-hand-containing protein|AATK antisense RNA 1 (non-protein coding)', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81165507, end_position_on_the_genomic_accession=81183166, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    388468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388468, CurrentID=0, Status='live', Symbol='POTEC', Aliases=['A26B2', 'CT104.6', 'POTE-18', 'POTE18'], description='POTE ankyrin domain family member C', other_designations='POTE ankyrin domain family member C|ANKRD26-like family B member 2|cancer/testis antigen family 104, member 6|prostate, ovary, testis-expressed protein on chromosome 18', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=14507339, end_position_on_the_genomic_accession=14543600, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    388512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388512, CurrentID=0, Status='live', Symbol='CLEC17A', Aliases=[], description='C-type lectin domain containing 17A', other_designations='C-type lectin domain family 17, member A|C-type lectin domain family 17 member A|prolectin', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14580777, end_position_on_the_genomic_accession=14612035, orientation='plus', exon_count=17, OMIM=[616838], no_hdr0=''),
    388523 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388523, CurrentID=0, Status='live', Symbol='ZNF728', Aliases=[], description='zinc finger protein 728', other_designations='zinc finger protein 728', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22974883, end_position_on_the_genomic_accession=23003176, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    388524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388524, CurrentID=0, Status='live', Symbol='RPSAP58', Aliases=['RPSA_30_1642'], description='ribosomal protein SA pseudogene 58', other_designations='ribosomal protein SA pseudogene 58', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23758496, end_position_on_the_genomic_accession=23871188, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    388531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388531, CurrentID=0, Status='live', Symbol='RGS9BP', Aliases=['PERRS', 'R9AP', 'RGS9'], description='regulator of G protein signaling 9 binding protein', other_designations='regulator of G-protein signaling 9-binding protein|RGS9 anchor protein|RGS9-anchoring protein', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32675848, end_position_on_the_genomic_accession=32678300, orientation='plus', exon_count=1, OMIM=[607814], no_hdr0=''),
    388533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388533, CurrentID=0, Status='live', Symbol='KRTDAP', Aliases=['KDAP', 'UNQ467'], description='keratinocyte differentiation associated protein', other_designations='keratinocyte differentiation-associated protein|KIPV467', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35487324, end_position_on_the_genomic_accession=35490464, orientation='minus', exon_count=6, OMIM=[617212], no_hdr0=''),
    388536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388536, CurrentID=0, Status='live', Symbol='ZNF790', Aliases=[], description='zinc finger protein 790', other_designations='zinc finger protein 790', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36817391, end_position_on_the_genomic_accession=36850792, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    388551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388551, CurrentID=0, Status='live', Symbol='CEACAM16', Aliases=['CEAL2', 'DFNA4B', 'DFNB113'], description='CEA cell adhesion molecule 16, tectorial membrane component', other_designations='carcinoembryonic antigen-related cell adhesion molecule 16|carcinoembryonic antigen like-2 protein|carcinoembryonic antigen related cell adhesion molecule 16', map_location='19q13.31-q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=44699151, end_position_on_the_genomic_accession=44710718, orientation='plus', exon_count=7, OMIM=[614591], no_hdr0=''),
    388552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388552, CurrentID=0, Status='live', Symbol='BLOC1S3', Aliases=['BLOS3', 'HPS8', 'RP'], description='biogenesis of lysosomal organelles complex 1 subunit 3', other_designations='biogenesis of lysosome-related organelles complex 1 subunit 3|BLOC-1 subunit 3|biogenesis of lysosome-related organelles complex-1, subunit 3|reduced pigmentation, mouse, homolog of', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45178784, end_position_on_the_genomic_accession=45202715, orientation='plus', exon_count=4, OMIM=[609762], no_hdr0=''),
    388553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388553, CurrentID=0, Status='live', Symbol='MEIOSIN', Aliases=['BHMG1', 'HMGDC'], description='meiosis initiator', other_designations='meiosis initiator protein|HMG domain containing|basic helix-loop-helix and HMG box domain containing 1|basic helix-loop-helix and HMG box domain-containing protein 1|basic helix-loop-helix and HMG-box containing 1', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45733439, end_position_on_the_genomic_accession=45764692, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    388555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388555, CurrentID=0, Status='live', Symbol='IGFL3', Aliases=['UNQ483'], description='IGF like family member 3', other_designations='insulin growth factor-like family member 3|RPRC483', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46119778, end_position_on_the_genomic_accession=46127101, orientation='minus', exon_count=3, OMIM=[610546], no_hdr0=''),
    388558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388558, CurrentID=0, Status='live', Symbol='ZNF808', Aliases=[], description='zinc finger protein 808', other_designations='zinc finger protein 808', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52512747, end_position_on_the_genomic_accession=52564464, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    388559 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388559, CurrentID=0, Status='live', Symbol='ZNF888', Aliases=[], description='zinc finger protein 888', other_designations='zinc finger protein 888|CTD-2331H12.6', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52904415, end_position_on_the_genomic_accession=52929161, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    388561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388561, CurrentID=0, Status='live', Symbol='ZNF761', Aliases=['ZNF468'], description='zinc finger protein 761', other_designations='zinc finger protein 761|zinc finger protein 468', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53431984, end_position_on_the_genomic_accession=53458261, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    388564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388564, CurrentID=0, Status='live', Symbol='TMEM238', Aliases=[], description='transmembrane protein 238', other_designations='transmembrane protein 238', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55379244, end_position_on_the_genomic_accession=55384292, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    388566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388566, CurrentID=0, Status='live', Symbol='ZNF470', Aliases=['CZF-1'], description='zinc finger protein 470', other_designations='zinc finger protein 470|chondrogenesis zinc finger protein 1', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56567468, end_position_on_the_genomic_accession=56582894, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    388567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388567, CurrentID=0, Status='live', Symbol='ZNF749', Aliases=[], description='zinc finger protein 749', other_designations='zinc finger protein 749', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57428565, end_position_on_the_genomic_accession=57447101, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    388569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388569, CurrentID=0, Status='live', Symbol='ZNF324B', Aliases=[], description='zinc finger protein 324B', other_designations='zinc finger protein 324B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58451611, end_position_on_the_genomic_accession=58457833, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    388581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388581, CurrentID=0, Status='live', Symbol='C1QTNF12', Aliases=['C1QDC2', 'CTRP12', 'FAM132A'], description='C1q and TNF related 12', other_designations='adipolin|C1q and TNF related protein 12|C1q and tumor necrosis factor related protein 12|C1q domain containing 2|C1q/TNF-related protein 12|adipose-derived insulin-sensitizing factor|complement C1q tumor necrosis factor-related protein 12|family with sequence similarity 132 member A|protein FAM132A', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1242448, end_position_on_the_genomic_accession=1247218, orientation='minus', exon_count=9, OMIM=[616593], no_hdr0=''),
    388585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388585, CurrentID=0, Status='live', Symbol='HES5', Aliases=['bHLHb38'], description='hes family bHLH transcription factor 5', other_designations='transcription factor HES-5|class B basic helix-loop-helix protein 38|hairy and enhancer of split 5', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2528745, end_position_on_the_genomic_accession=2530554, orientation='minus', exon_count=2, OMIM=[607348], no_hdr0=''),
    388588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388588, CurrentID=0, Status='live', Symbol='SMIM1', Aliases=['Vel'], description='small integral membrane protein 1 (Vel blood group)', other_designations='small integral membrane protein 1|vel blood group antigen', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=3772749, end_position_on_the_genomic_accession=3775956, orientation='plus', exon_count=4, OMIM=[615242], no_hdr0=''),
    388591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388591, CurrentID=0, Status='live', Symbol='RNF207', Aliases=['C1orf188'], description='ring finger protein 207', other_designations='RING finger protein 207', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6206004, end_position_on_the_genomic_accession=6221299, orientation='plus', exon_count=18, OMIM=[616923], no_hdr0=''),
    388595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388595, CurrentID=0, Status='live', Symbol='TMEM82', Aliases=[], description='transmembrane protein 82', other_designations='transmembrane protein 82', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15742499, end_position_on_the_genomic_accession=15747982, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    388610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388610, CurrentID=0, Status='live', Symbol='TRNP1', Aliases=['C1orf225', 'TNRP', 'TRNP'], description='TMF1 regulated nuclear protein 1', other_designations='TMF-regulated nuclear protein 1', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26993663, end_position_on_the_genomic_accession=27000891, orientation='plus', exon_count=2, OMIM=[616824], no_hdr0=''),
    388611 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388611, CurrentID=0, Status='live', Symbol='CD164L2', Aliases=['EAPG6122', 'UNQ6122'], description='CD164 molecule like 2', other_designations='CD164 sialomucin-like 2 protein', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=27379171, end_position_on_the_genomic_accession=27383333, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388630 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388630, CurrentID=0, Status='live', Symbol='TRABD2B', Aliases=['TIKI2'], description='TraB domain containing 2B', other_designations='metalloprotease TIKI2|TRAB domain-containing protein 2B|UPF0632 protein A|heart, kidney and adipose-enriched transmembrane protein homolog', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=47760528, end_position_on_the_genomic_accession=47997385, orientation='minus', exon_count=11, OMIM=[614913], no_hdr0=''),
    388633 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388633, CurrentID=0, Status='live', Symbol='LDLRAD1', Aliases=[], description='low density lipoprotein receptor class A domain containing 1', other_designations='low-density lipoprotein receptor class A domain-containing protein 1', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54007298, end_position_on_the_genomic_accession=54018186, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    388646 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388646, CurrentID=0, Status='live', Symbol='GBP7', Aliases=['GBP4L'], description='guanylate binding protein 7', other_designations='guanylate-binding protein 7|GBP-7|GTP-binding protein 7|guanine nucleotide-binding protein 7', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=89131742, end_position_on_the_genomic_accession=89176003, orientation='minus', exon_count=11, OMIM=[612468], no_hdr0=''),
    388649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388649, CurrentID=0, Status='live', Symbol='C1orf146', Aliases=['SCRE', 'SPO16'], description='chromosome 1 open reading frame 146', other_designations='protein SPO16 homolog|synaptonemal complex reinforcing element|uncharacterized protein C1orf146', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92217915, end_position_on_the_genomic_accession=92245813, orientation='plus', exon_count=7, OMIM=[618968], no_hdr0=''),
    388650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388650, CurrentID=0, Status='live', Symbol='DIPK1A', Aliases=['FAM69A'], description='divergent protein kinase domain 1A', other_designations='divergent protein kinase domain 1A|family with sequence similarity 69 member A|protein FAM69A', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92832729, end_position_on_the_genomic_accession=92961462, orientation='minus', exon_count=7, OMIM=[614542], no_hdr0=''),
    388662 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388662, CurrentID=0, Status='live', Symbol='SLC6A17', Aliases=['MRT48', 'NTT4'], description='solute carrier family 6 member 17', other_designations='sodium-dependent neutral amino acid transporter SLC6A17|orphan sodium- and chloride-dependent neurotransmitter transporter NTT4', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=110150494, end_position_on_the_genomic_accession=110202202, orientation='plus', exon_count=13, OMIM=[610299], no_hdr0=''),
    388677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388677, CurrentID=0, Status='live', Symbol='NOTCH2NLA', Aliases=['N2N', 'NOTCH2NL'], description='notch 2 N-terminal like A', other_designations='notch homolog 2 N-terminal-like protein A|Notch homolog 2 N-terminal like protein', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=146151908, end_position_on_the_genomic_accession=146229032, orientation='minus', exon_count=5, OMIM=[618023], no_hdr0=''),
    388695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388695, CurrentID=0, Status='live', Symbol='LYSMD1', Aliases=['SB145'], description='LysM domain containing 1', other_designations='lysM and putative peptidoglycan-binding domain-containing protein 1|LysM, putative peptidoglycan-binding, domain containing 1|RP11-68I18.5', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151148496, end_position_on_the_genomic_accession=151165902, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388697, CurrentID=0, Status='live', Symbol='HRNR', Aliases=['FLG3', 'S100A16', 'S100a18'], description='hornerin', other_designations='hornerin|filaggrin family member 3|intermediate filament-associated protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152212076, end_position_on_the_genomic_accession=152224193, orientation='minus', exon_count=3, OMIM=[616293], no_hdr0=''),
    388698 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388698, CurrentID=0, Status='live', Symbol='FLG2', Aliases=['IFPS', 'PSS6'], description='filaggrin family member 2', other_designations='filaggrin-2|ifapsoriasin|intermediate filament-associated and psoriasis susceptibility protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152348735, end_position_on_the_genomic_accession=152360028, orientation='minus', exon_count=4, OMIM=[616284], no_hdr0=''),
    388701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388701, CurrentID=0, Status='live', Symbol='C1orf189', Aliases=[], description='chromosome 1 open reading frame 189', other_designations='uncharacterized protein C1orf189', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=154199085, end_position_on_the_genomic_accession=154206333, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    388722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388722, CurrentID=0, Status='live', Symbol='C1orf53', Aliases=[], description='chromosome 1 open reading frame 53', other_designations='uncharacterized protein C1orf53', map_location='1q31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=197902630, end_position_on_the_genomic_accession=197907362, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    388730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388730, CurrentID=0, Status='live', Symbol='TMEM81', Aliases=['HC3107', 'KVLA2788', 'UNQ2788'], description='transmembrane protein 81', other_designations='transmembrane protein 81', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=205083129, end_position_on_the_genomic_accession=205084460, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    388743 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388743, CurrentID=0, Status='live', Symbol='CAPN8', Aliases=['nCL-2'], description='calpain 8', other_designations='calpain-8|new calpain 2|stomach-specific M-type calpain', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=223541609, end_position_on_the_genomic_accession=223665734, orientation='minus', exon_count=24, OMIM=[618777], no_hdr0=''),
    388753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388753, CurrentID=0, Status='live', Symbol='COA6', Aliases=['C1orf31', 'CEMCOX4', 'MC4DN13'], description='cytochrome c oxidase assembly factor 6', other_designations='cytochrome c oxidase assembly factor 6 homolog', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=234373456, end_position_on_the_genomic_accession=234385080, orientation='plus', exon_count=4, OMIM=[614772], no_hdr0=''),
    388761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388761, CurrentID=0, Status='live', Symbol='OR14A2', Aliases=['OR5AX1', 'OR5AX1P'], description='olfactory receptor family 14 subfamily A member 2', other_designations='olfactory receptor 14A2|olfactory receptor 5AX1|olfactory receptor OR1-31|olfactory receptor, family 5, subfamily AX, member 1 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247721640, end_position_on_the_genomic_accession=247750941, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388789, CurrentID=0, Status='live', Symbol='SMIM26', Aliases=['LINC00493'], description='small integral membrane protein 26', other_designations='small integral membrane protein 26|long intergenic non-protein coding RNA 493', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18567432, end_position_on_the_genomic_accession=18569611, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    388795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388795, CurrentID=0, Status='live', Symbol='EFCAB8', Aliases=[], description='EF-hand calcium binding domain 8', other_designations='EF-hand calcium-binding domain-containing protein 8|EF-hand domain-containing protein ENSP00000383366', map_location='20q11.21', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=32853904, end_position_on_the_genomic_accession=32961845, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    388799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388799, CurrentID=0, Status='live', Symbol='FAM209B', Aliases=['C20orf107', 'dJ1153D9.4'], description='family with sequence similarity 209 member B', other_designations='protein FAM209B|uncharacterized protein C20orf107', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=56527124, end_position_on_the_genomic_accession=56555626, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    388813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388813, CurrentID=0, Status='live', Symbol='LOC388813', Aliases=[], description='uncharacterized protein ENSP00000383407-like', other_designations='putative uncharacterized protein ENSP00000383407', map_location='21q11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=14591392, end_position_on_the_genomic_accession=14643107, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    388818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388818, CurrentID=0, Status='live', Symbol='KRTAP26-1', Aliases=[], description='keratin associated protein 26-1', other_designations='keratin-associated protein 26-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30319124, end_position_on_the_genomic_accession=30320315, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    388820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388820, CurrentID=0, Status='live', Symbol='SMIM34', Aliases=['SMIM34A'], description='small integral membrane protein 34', other_designations='small integral membrane protein 34A', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34418715, end_position_on_the_genomic_accession=34423951, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    388849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388849, CurrentID=0, Status='live', Symbol='CCDC188', Aliases=[], description='coiled-coil domain containing 188', other_designations='coiled-coil domain-containing protein 188', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=20148113, end_position_on_the_genomic_accession=20151828, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    388886 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388886, CurrentID=0, Status='live', Symbol='LRRC75B', Aliases=['C22orf36', 'FAM211B'], description='leucine rich repeat containing 75B', other_designations='leucine-rich repeat-containing protein 75B|family with sequence similarity 211, member B|leucine-rich repeat-containing protein C22orf36|leucine-rich repeat-containing protein FAM211B', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24585620, end_position_on_the_genomic_accession=24593103, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    388931 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388931, CurrentID=0, Status='live', Symbol='MFSD2B', Aliases=['SLC59A2'], description='major facilitator superfamily domain containing 2B', other_designations='major facilitator superfamily domain-containing protein 2B|S1P transporter|hMfsd2b|sphingosine 1-phosphate transporter', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24009022, end_position_on_the_genomic_accession=24026775, orientation='plus', exon_count=14, OMIM=[617845], no_hdr0=''),
    388939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388939, CurrentID=0, Status='live', Symbol='PCARE', Aliases=['C2orf71', 'RP54'], description='photoreceptor cilium actin regulator', other_designations='photoreceptor cilium actin regulator|uncharacterized protein C2orf71', map_location='2p23.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=29061695, end_position_on_the_genomic_accession=29074523, orientation='minus', exon_count=2, OMIM=[613425], no_hdr0=''),
    388946 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388946, CurrentID=0, Status='live', Symbol='TMEM247', Aliases=[], description='transmembrane protein 247', other_designations='transmembrane protein 247|transmembrane protein ENSP00000343375', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=46479565, end_position_on_the_genomic_accession=46484425, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    388951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388951, CurrentID=0, Status='live', Symbol='TSPYL6', Aliases=[], description='TSPY like 6', other_designations='testis-specific Y-encoded-like protein 6|TSPY-like protein 6|testicular tissue protein Li 211', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=54253178, end_position_on_the_genomic_accession=54256229, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    388960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388960, CurrentID=0, Status='live', Symbol='C2orf78', Aliases=['COG5373', 'hCG1989538'], description='chromosome 2 open reading frame 78', other_designations='uncharacterized protein C2orf78', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=73784189, end_position_on_the_genomic_accession=73817148, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    388962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388962, CurrentID=0, Status='live', Symbol='BOLA3', Aliases=['MMDS2'], description='bolA family member 3', other_designations='bolA-like protein 3|bolA homolog 3', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74135400, end_position_on_the_genomic_accession=74147912, orientation='minus', exon_count=4, OMIM=[613183], no_hdr0=''),
    388963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388963, CurrentID=0, Status='live', Symbol='C2orf81', Aliases=['hCG40743'], description='chromosome 2 open reading frame 81', other_designations='uncharacterized protein C2orf81', map_location='2p13.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=74414177, end_position_on_the_genomic_accession=74421619, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    388969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=388969, CurrentID=0, Status='live', Symbol='C2orf68', Aliases=['HCRCN81'], description='chromosome 2 open reading frame 68', other_designations='UPF0561 protein C2orf68', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=85605254, end_position_on_the_genomic_accession=85612066, orientation='minus', exon_count=5, OMIM=[618519], no_hdr0=''),
    389015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389015, CurrentID=0, Status='live', Symbol='SLC9A4', Aliases=['NHE4'], description='solute carrier family 9 member A4', other_designations='sodium/hydrogen exchanger 4|NHE-4|Na(+)/H(+) exchanger 4|solute carrier family 9 (sodium/hydrogen exchanger), member 4|solute carrier family 9 member 4|solute carrier family 9, subfamily A (NHE4, cation proton antiporter 4), member 4', map_location='2q12.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=102473226, end_position_on_the_genomic_accession=102533974, orientation='plus', exon_count=12, OMIM=[600531], no_hdr0=''),
    389058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389058, CurrentID=0, Status='live', Symbol='SP5', Aliases=[], description='Sp5 transcription factor', other_designations='transcription factor Sp5', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=170714725, end_position_on_the_genomic_accession=170718078, orientation='plus', exon_count=2, OMIM=[609391], no_hdr0=''),
    389072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389072, CurrentID=0, Status='live', Symbol='PLEKHM3', Aliases=['DAPR', 'PLEKHM1L'], description='pleckstrin homology domain containing M3', other_designations='pleckstrin homology domain-containing family M member 3|PH domain-containing family M member 3|differentiation associated protein', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=207821288, end_position_on_the_genomic_accession=208025675, orientation='minus', exon_count=13, OMIM=[619186], no_hdr0=''),
    389073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389073, CurrentID=0, Status='live', Symbol='C2orf80', Aliases=['GONDA1'], description='chromosome 2 open reading frame 80', other_designations='uncharacterized protein C2orf80|gonad development associated 1', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=208165347, end_position_on_the_genomic_accession=208190258, orientation='minus', exon_count=11, OMIM=[615536], no_hdr0=''),
    389075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389075, CurrentID=0, Status='live', Symbol='RESP18', Aliases=[], description='regulated endocrine specific protein 18', other_designations='regulated endocrine-specific protein 18|regulated endocrine-specific protein 18 homolog', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219327407, end_position_on_the_genomic_accession=219334535, orientation='minus', exon_count=8, OMIM=[612721], no_hdr0=''),
    389084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389084, CurrentID=0, Status='live', Symbol='SNORC', Aliases=['ASCL830', 'C2orf82', 'UNQ830'], description='secondary ossification center associated regulator of chondrocyte maturation', other_designations='protein SNORC|Small Novel Rich in Cartilage|secondary ossification center-associated regulator of chondrocyte maturation protein|uncharacterized protein C2orf82', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232866451, end_position_on_the_genomic_accession=232878704, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    389090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389090, CurrentID=0, Status='live', Symbol='OR6B2', Aliases=['OR2-1P', 'OR6B2'], description='olfactory receptor family 6 subfamily B member 2', other_designations='olfactory receptor 6B2|olfactory receptor OR2-1|olfactory receptor, family 6, subfamily B, member 2 pseudogene', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240029491, end_position_on_the_genomic_accession=240030429, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389114, CurrentID=0, Status='live', Symbol='ZNF662', Aliases=[], description='zinc finger protein 662', other_designations='zinc finger protein 662', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42906142, end_position_on_the_genomic_accession=42919334, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    389118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389118, CurrentID=0, Status='live', Symbol='CDHR4', Aliases=['CDH29', 'PRO34300'], description='cadherin related family member 4', other_designations='cadherin-related family member 4|Cadherin-like protein UNQ9392/PRO34300|VLLR9392|cadherin-like 29|cadherin-like protein 29', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49790732, end_position_on_the_genomic_accession=49802741, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    389119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389119, CurrentID=0, Status='live', Symbol='INKA1', Aliases=['C3orf54', 'FAM212A'], description='inka box actin regulator 1', other_designations='PAK4-inhibitor INKA1|HInca|Induced in Neural Crest by AP-2alpha|family with sequence similarity 212 member A|induced in neural crest by AP2-alpha protein homolog|protein FAM212A', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49803261, end_position_on_the_genomic_accession=49805030, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    389123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389123, CurrentID=0, Status='live', Symbol='IQCF2', Aliases=[], description='IQ motif containing F2', other_designations='IQ domain-containing protein F2', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51861615, end_position_on_the_genomic_accession=51863424, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    389124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389124, CurrentID=0, Status='live', Symbol='IQCF5', Aliases=[], description='IQ motif containing F5', other_designations='IQ domain-containing protein F5', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51873721, end_position_on_the_genomic_accession=51875601, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    389125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389125, CurrentID=0, Status='live', Symbol='MUSTN1', Aliases=['MUSTANG'], description='musculoskeletal, embryonic nuclear protein 1', other_designations='musculoskeletal embryonic nuclear protein 1|musculoskeletal temporally activated novel', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52833121, end_position_on_the_genomic_accession=52835019, orientation='minus', exon_count=3, OMIM=[617195], no_hdr0=''),
    389136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389136, CurrentID=0, Status='live', Symbol='VGLL3', Aliases=['VGL-3', 'VGL3'], description='vestigial like family member 3', other_designations='transcription cofactor vestigial-like protein 3|colon carcinoma related protein', map_location='3p12.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=86937973, end_position_on_the_genomic_accession=86991149, orientation='minus', exon_count=5, OMIM=[609980], no_hdr0=''),
    389151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389151, CurrentID=0, Status='live', Symbol='PRR23B', Aliases=[], description='proline rich 23B', other_designations='proline-rich protein 23B', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139019031, end_position_on_the_genomic_accession=139020926, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389152, CurrentID=0, Status='live', Symbol='PRR23C', Aliases=[], description='proline rich 23C', other_designations='proline-rich protein 23C|proline-rich protein 23A', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139042102, end_position_on_the_genomic_accession=139044892, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389158, CurrentID=0, Status='live', Symbol='PLSCR5', Aliases=[], description='phospholipid scramblase family member 5', other_designations='phospholipid scramblase family member 5', map_location='3q24', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=146576555, end_position_on_the_genomic_accession=146605427, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    389161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389161, CurrentID=0, Status='live', Symbol='ANKUB1', Aliases=['C3orf16'], description='ankyrin repeat and ubiquitin domain containing 1', other_designations='protein ANKUB1', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=149760648, end_position_on_the_genomic_accession=149792554, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    389170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389170, CurrentID=0, Status='live', Symbol='LEKR1', Aliases=[], description='leucine, glutamate and lysine rich 1', other_designations='leucine-, glutamate- and lysine-rich protein 1', map_location='3q25.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=156826287, end_position_on_the_genomic_accession=157047659, orientation='plus', exon_count=19, OMIM=[613536], no_hdr0=''),
    389177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389177, CurrentID=0, Status='live', Symbol='TMEM212', Aliases=[], description='transmembrane protein 212', other_designations='transmembrane protein 212', map_location='3q26.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=171843339, end_position_on_the_genomic_accession=171859318, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    389197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389197, CurrentID=0, Status='live', Symbol='C4orf50', Aliases=[], description='chromosome 4 open reading frame 50', other_designations='uncharacterized protein C4orf50', map_location='4p16.2-p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=5897591, end_position_on_the_genomic_accession=6018762, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    389199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389199, CurrentID=0, Status='live', Symbol='LOC389199', Aliases=[], description='uncharacterized LOC389199', other_designations='uncharacterized protein LOC389199', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7939001, end_position_on_the_genomic_accession=7940296, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    389203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389203, CurrentID=0, Status='live', Symbol='SMIM20', Aliases=['C4orf52', 'MITRAC7', 'PNX'], description='small integral membrane protein 20', other_designations='small integral membrane protein 20|mitochondrial translation regulation assembly intermediate of cytochrome c oxidase protein of 7 kDa|phoenixin', map_location='4p15.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=25914220, end_position_on_the_genomic_accession=25929812, orientation='plus', exon_count=3, OMIM=[617465], no_hdr0=''),
    389206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389206, CurrentID=0, Status='live', Symbol='BEND4', Aliases=['CCDC4'], description='BEN domain containing 4', other_designations='BEN domain-containing protein 4|coiled-coil domain containing 4|coiled-coil domain-containing protein 4', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=42110853, end_position_on_the_genomic_accession=42152655, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    389207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389207, CurrentID=0, Status='live', Symbol='GRXCR1', Aliases=['DFNB25', 'PPP1R88'], description='glutaredoxin and cysteine rich domain containing 1', other_designations='glutaredoxin domain-containing cysteine-rich protein 1|glutaredoxin, cysteine rich 1|protein phosphatase 1, regulatory subunit 88', map_location='4p13', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=42892713, end_position_on_the_genomic_accession=43030658, orientation='plus', exon_count=4, OMIM=[613283], no_hdr0=''),
    389208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389208, CurrentID=0, Status='live', Symbol='TMPRSS11F', Aliases=['HATL4'], description='transmembrane serine protease 11F', other_designations='transmembrane protease serine 11F|airway trypsin-like protease 4|transmembrane protease, serine 11F', map_location='4q13.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=68053198, end_position_on_the_genomic_accession=68129869, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    389257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389257, CurrentID=0, Status='live', Symbol='LRRC14B', Aliases=[], description='leucine rich repeat containing 14B', other_designations='leucine-rich repeat-containing protein 14B', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=191495, end_position_on_the_genomic_accession=196334, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    389289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389289, CurrentID=0, Status='live', Symbol='ANXA2R', Aliases=['AX2R', 'AXIIR', 'C5orf39'], description='annexin A2 receptor', other_designations='annexin-2 receptor|annexin II receptor', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=43039371, end_position_on_the_genomic_accession=43043247, orientation='minus', exon_count=2, OMIM=[611296], no_hdr0=''),
    389320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389320, CurrentID=0, Status='live', Symbol='TEX43', Aliases=['C5orf48', 'Tseg7'], description='testis expressed 43', other_designations='testis-expressed protein 43|testis specific expressed gene 7|testis-expressed sequence 43 protein', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=126631705, end_position_on_the_genomic_accession=126636284, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    389332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389332, CurrentID=0, Status='live', Symbol='SMIM32', Aliases=[], description='small integral membrane protein 32', other_designations='small integral membrane protein 32', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=136191468, end_position_on_the_genomic_accession=136193162, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389333, CurrentID=0, Status='live', Symbol='PROB1', Aliases=['C5orf65'], description='proline rich basic protein 1', other_designations='proline-rich basic protein 1|weakly similar to basic proline-rich protein', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139390592, end_position_on_the_genomic_accession=139395104, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389336, CurrentID=0, Status='live', Symbol='C5orf46', Aliases=['AP-64', 'SSSP1'], description='chromosome 5 open reading frame 46', other_designations='uncharacterized protein C5orf46|CTC-327F10.5|skin and saliva secreted protein 1', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=147850463, end_position_on_the_genomic_accession=147906594, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    389337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389337, CurrentID=0, Status='live', Symbol='ARHGEF37', Aliases=[], description='Rho guanine nucleotide exchange factor 37', other_designations='rho guanine nucleotide exchange factor 37|Rho guanine nucleotide exchange factor (GEF) 37', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=149552057, end_position_on_the_genomic_accession=149634968, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    389362 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389362, CurrentID=0, Status='live', Symbol='PSMG4', Aliases=['C6orf86', 'PAC4', 'bA506K6.2'], description='proteasome assembly chaperone 4', other_designations='proteasome assembly chaperone 4|PAC-4|hPAC4|proteasome (prosome, macropain) assembly chaperone 4', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=3254325, end_position_on_the_genomic_accession=3308224, orientation='plus', exon_count=6, OMIM=[617550], no_hdr0=''),
    389376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389376, CurrentID=0, Status='live', Symbol='SFTA2', Aliases=['GSGL541', 'SFTPG', 'SP-G', 'UNQ541'], description='surfactant associated 2', other_designations='surfactant-associated protein 2|surfactant associated protein G', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30931353, end_position_on_the_genomic_accession=30932170, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    389383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389383, CurrentID=0, Status='live', Symbol='CLPSL2', Aliases=['AAAL3045', 'C6orf126', 'UNQ3045', 'dJ510O8.5'], description='colipase like 2', other_designations='colipase-like protein 2|colipase-like protein C6orf126', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=35776598, end_position_on_the_genomic_accession=35779552, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    389384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389384, CurrentID=0, Status='live', Symbol='BNIP5', Aliases=['C6orf222'], description='BCL2 interacting protein 5', other_designations='protein BNIP5|uncharacterized protein C6orf222', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36315757, end_position_on_the_genomic_accession=36337015, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    389396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389396, CurrentID=0, Status='live', Symbol='GLYATL3', Aliases=['C6orf140', 'bA28H17.2'], description='glycine-N-acyltransferase like 3', other_designations='glycine N-acyltransferase-like protein 3|acyl-CoA:glycine-N-acyltransferase-like protein 3', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=49499923, end_position_on_the_genomic_accession=49528078, orientation='plus', exon_count=6, OMIM=[614763], no_hdr0=''),
    389400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389400, CurrentID=0, Status='live', Symbol='GFRAL', Aliases=['C6orf144', 'GRAL', 'UNQ9356', 'bA360D14.1'], description='GDNF family receptor alpha like', other_designations='GDNF family receptor alpha-like|IVFI9356', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=55327469, end_position_on_the_genomic_accession=55402493, orientation='plus', exon_count=9, OMIM=[617837], no_hdr0=''),
    389421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389421, CurrentID=0, Status='live', Symbol='LIN28B', Aliases=['CSDD2'], description='lin-28 homolog B', other_designations='protein lin-28 homolog B|Lin-28.2|lin-28B', map_location='6q16.3-q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=104936999, end_position_on_the_genomic_accession=105083332, orientation='plus', exon_count=7, OMIM=[611044], no_hdr0=''),
    389432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389432, CurrentID=0, Status='live', Symbol='SAMD5', Aliases=['dJ875H10.1'], description='sterile alpha motif domain containing 5', other_designations='sterile alpha motif domain-containing protein 5|SAM domain containing 1|SAM domain-containing protein 5', map_location='6q24.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=147508690, end_position_on_the_genomic_accession=147948291, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    389434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389434, CurrentID=0, Status='live', Symbol='IYD', Aliases=['C6orf71', 'DEHAL1-1', 'TDH4', 'IYD'], description='iodotyrosine deiodinase', other_designations='iodotyrosine deiodinase 1|iodotyrosine dehalogenase 1', map_location='6q25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=150368854, end_position_on_the_genomic_accession=150405969, orientation='plus', exon_count=7, OMIM=[612025], no_hdr0=''),
    389493 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389493, CurrentID=0, Status='live', Symbol='NUPR2', Aliases=['NUPR1L', 'P8'], description='nuclear protein 2, transcriptional regulator', other_designations='nuclear protein 2|nuclear protein, transcriptional regulator, 1-like|nuclear transcriptional regulator 1-like protein|nuclear transcriptional regulator protein 2', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56114681, end_position_on_the_genomic_accession=56116417, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    389524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389524, CurrentID=0, Status='live', Symbol='GTF2IRD2B', Aliases=['GTF2IRD2', 'GTF2IRD2A'], description='GTF2I repeat domain containing 2B', other_designations='general transcription factor II-I repeat domain-containing protein 2B|GTF2I repeat domain-containing protein 2A|GTF2I repeat domain-containing protein 2B|GTF2IRD2 beta|General transcription factor II-I repeat domain-containing protein 2A|Transcription factor GTF2IRD2-alpha|general transcription factor 2 I repeat domain-containing 2 beta|transcription factor GTF2IRD2-beta', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75092556, end_position_on_the_genomic_accession=75149817, orientation='plus', exon_count=17, OMIM=[608900], no_hdr0=''),
    389541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389541, CurrentID=0, Status='live', Symbol='LAMTOR4', Aliases=['C7orf59'], description='late endosomal/lysosomal adaptor, MAPK and MTOR activator 4', other_designations='ragulator complex protein LAMTOR4|UPF0539 protein C7orf59|late endosomal/lysosomal adaptor and MAPK and MTOR activator 4', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100140177, end_position_on_the_genomic_accession=100154212, orientation='plus', exon_count=6, OMIM=[618834], no_hdr0=''),
    389549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389549, CurrentID=0, Status='live', Symbol='FEZF1', Aliases=['FEZ', 'HH22', 'ZNF312B'], description='FEZ family zinc finger 1', other_designations='fez family zinc finger protein 1|zinc finger protein 312B', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=122300939, end_position_on_the_genomic_accession=122311855, orientation='minus', exon_count=6, OMIM=[613301], no_hdr0=''),
    389558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389558, CurrentID=0, Status='live', Symbol='FAM180A', Aliases=['UNQ1940'], description='family with sequence similarity 180 member A', other_designations='protein FAM180A|HWKM1940', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135729592, end_position_on_the_genomic_accession=135748813, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    389610 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389610, CurrentID=0, Status='live', Symbol='XKR5', Aliases=['HARL2754', 'UNQ2754', 'XRG5A', 'XRG5BM'], description='XK related 5', other_designations='XK-related protein 5|X Kell blood group precursor-related family, member 5|X-linked Kx blood group related 5|XK, Kell blood group complex subunit-related family, member 5|XK-related protein 5a', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6808517, end_position_on_the_genomic_accession=6835524, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    389643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389643, CurrentID=0, Status='live', Symbol='NUGGC', Aliases=['C8orf80', 'HMFN0672', 'SLIP-GC', 'SLIPGC'], description='nuclear GTPase, germinal center associated', other_designations='nuclear GTPase SLIP-GC|GTPase SLIP-GC|speckled-like pattern in the germinal center', map_location='8p21.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=28021964, end_position_on_the_genomic_accession=28084068, orientation='minus', exon_count=20, OMIM=[619088], no_hdr0=''),
    389658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389658, CurrentID=0, Status='live', Symbol='ALKAL1', Aliases=['AUGA', 'AUGB', 'FAM150A', 'UNQ9433'], description='ALK and LTK ligand 1', other_designations='ALK and LTK ligand 1|AUG-beta|RPLK9433|augmentor beta|augmentor-alpha|family with sequence similarity 150 member A|protein FAM150A', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=52534037, end_position_on_the_genomic_accession=52565430, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    389668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389668, CurrentID=0, Status='live', Symbol='XKR9', Aliases=['XRG9'], description='XK related 9', other_designations='XK-related protein 9|X Kell blood group precursor-related family, member 9|X-linked Kx blood group related 9|XK, Kell blood group complex subunit-related family, member 9', map_location='8q13.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=70669339, end_position_on_the_genomic_accession=71066635, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    389677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389677, CurrentID=0, Status='live', Symbol='RBM12B', Aliases=['MGC:33837'], description='RNA binding motif protein 12B', other_designations='RNA-binding protein 12B', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=93728155, end_position_on_the_genomic_accession=93741012, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    389690 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389690, CurrentID=0, Status='live', Symbol='MROH5', Aliases=[], description='maestro heat like repeat family member 5 (gene/pseudogene)', other_designations='maestro heat-like repeat family member 5', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=141433825, end_position_on_the_genomic_accession=141507229, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    389692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389692, CurrentID=0, Status='live', Symbol='MAFA', Aliases=['INSDM', 'RIPE3b1', 'hMafA'], description='MAF bZIP transcription factor A', other_designations='transcription factor MafA|RIPE3b1 factor|pancreatic beta-cell-specific transcriptional activator|transcription factor RIPE3b1|v-maf avian musculoaponeurotic fibrosarcoma oncogene homolog A', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143428064, end_position_on_the_genomic_accession=143430732, orientation='minus', exon_count=1, OMIM=[610303], no_hdr0=''),
    389730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389730, CurrentID=0, Status='live', Symbol='SPATA31A6', Aliases=['FAM75A6'], description='SPATA31 subfamily A member 6', other_designations='spermatogenesis-associated protein 31A6|family with sequence similarity 75, member A6', map_location='9p11.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=42183659, end_position_on_the_genomic_accession=42189887, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    389761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389761, CurrentID=0, Status='live', Symbol='SPATA31D4', Aliases=['FAM75D3', 'FAM75D4', 'SPATA31D3'], description='SPATA31 subfamily D member 4', other_designations='spermatogenesis-associated protein 31D4|FAM75-like protein FLJ43859|Protein FAM75D3|Spermatogenesis-associated protein 31D3|family with sequence similarity 75, member D4|putative protein FAM75D4|putative spermatogenesis-associated protein 31D4', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=81928428, end_position_on_the_genomic_accession=81934998, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    389762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389762, CurrentID=0, Status='live', Symbol='SPATA31D3', Aliases=['FAM75D3'], description='SPATA31 subfamily D member 3', other_designations='spermatogenesis-associated protein 31D3|FAM75-like protein FLJ44082|Putative FAM75-like protein FLJ44082|family with sequence similarity 75, member D3|putative protein FAM75D3|putative spermatogenesis-associated protein 31D3', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=81943500, end_position_on_the_genomic_accession=81950093, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    389763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389763, CurrentID=0, Status='live', Symbol='SPATA31D1', Aliases=['FAM75D1'], description='SPATA31 subfamily D member 1', other_designations='spermatogenesis-associated protein 31D1|FAM75-like protein FLJ46321|family with sequence similarity 75, member D1|protein FAM75D1', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=81987405, end_position_on_the_genomic_accession=81995256, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    389766 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389766, CurrentID=0, Status='live', Symbol='C9orf153', Aliases=['bA507D14.1'], description='chromosome 9 open reading frame 153', other_designations='uncharacterized protein C9orf153', map_location='9q21.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=86220265, end_position_on_the_genomic_accession=86259657, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    389792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389792, CurrentID=0, Status='live', Symbol='IER5L', Aliases=['bA247A12.2'], description='immediate early response 5 like', other_designations='immediate early response gene 5-like protein', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=129175552, end_position_on_the_genomic_accession=129178261, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    389799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389799, CurrentID=0, Status='live', Symbol='CFAP77', Aliases=['C9orf171'], description='cilia and flagella associated protein 77', other_designations='cilia- and flagella-associated protein 77', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=132410043, end_position_on_the_genomic_accession=132573319, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    389812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389812, CurrentID=0, Status='live', Symbol='LCN15', Aliases=['PRO6093', 'UNQ2541'], description='lipocalin 15', other_designations='lipocalin-15|MSFL2541', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136759634, end_position_on_the_genomic_accession=136764518, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    389813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389813, CurrentID=0, Status='live', Symbol='AJM1', Aliases=['C9orf172', 'ajm-1'], description='apical junction component 1 homolog', other_designations='apical junction component 1 homolog|uncharacterized protein C9orf172', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136842478, end_position_on_the_genomic_accession=136848801, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    389816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389816, CurrentID=0, Status='live', Symbol='LRRC26', Aliases=['CAPC', 'bA350O14.10'], description='leucine rich repeat containing 26', other_designations='leucine-rich repeat-containing protein 26|BK channel auxiliary gamma subunit LRRC26|BK channel auxilliary gamma subunit LRRC26|cytokeratin associated protein|cytokeratin-associated protein in cancer', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137168758, end_position_on_the_genomic_accession=137170051, orientation='minus', exon_count=2, OMIM=[613505], no_hdr0=''),
    389827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389827, CurrentID=0, Status='live', Symbol='MYMK', Aliases=['MYOMAKER', 'TMEM226', 'TMEM8C'], description='myomaker, myoblast fusion factor', other_designations='protein myomaker|myoblast fusion maker|transmembrane protein 226|transmembrane protein 8C', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133514586, end_position_on_the_genomic_accession=133524959, orientation='minus', exon_count=5, OMIM=[615345], no_hdr0=''),
    389831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389831, CurrentID=0, Status='live', Symbol='LOC389831', Aliases=[], description='uncharacterized LOC389831', other_designations='uncharacterized protein LOC389831', map_location='', chromosome='14', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    389840 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389840, CurrentID=0, Status='live', Symbol='MAP3K15', Aliases=['ASK3', 'bA723P2.3'], description='mitogen-activated protein kinase kinase kinase 15', other_designations='mitogen-activated protein kinase kinase kinase 15|MAPK/ERK kinase kinase 15|MEK kinase 15|MEKK 15|apoptosis signal-regulating kinase 3', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=19360059, end_position_on_the_genomic_accession=19515508, orientation='minus', exon_count=32, OMIM=[300820], no_hdr0=''),
    389852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389852, CurrentID=0, Status='live', Symbol='SPACA5', Aliases=['LYC5', 'LYZL5', 'PNPK6288', 'SLLP-X', 'SLLP2', 'UNQ6288'], description='sperm acrosome associated 5', other_designations='sperm acrosome-associated protein 5|lysozyme-like protein 5|sperm lysozyme-like protein 2|sperm-specific lysozyme-like protein X|testicular tissue protein Li 113', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48004336, end_position_on_the_genomic_accession=48009733, orientation='plus', exon_count=5, OMIM=[300593], no_hdr0=''),
    389856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389856, CurrentID=0, Status='live', Symbol='USP27X', Aliases=['MRX105', 'USP22L', 'USP27'], description='ubiquitin specific peptidase 27 X-linked', other_designations='ubiquitin carboxyl-terminal hydrolase 27|X-linked ubiquitin carboxyl-terminal hydrolase 27|deubiquitinating enzyme 27|ubiquitin specific protease 27, X chromosome|ubiquitin thioesterase 27|ubiquitin-specific-processing protease 27', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49879484, end_position_on_the_genomic_accession=49882558, orientation='plus', exon_count=1, OMIM=[300975], no_hdr0=''),
    389857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389857, CurrentID=0, Status='live', Symbol='CENPVL1', Aliases=['CENPVP1', 'PRR6L1'], description='centromere protein V like 1', other_designations='centromere protein V-like protein 1|proline rich 6-like 1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51710512, end_position_on_the_genomic_accession=51712131, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    389860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389860, CurrentID=0, Status='live', Symbol='PAGE2B', Aliases=['CT16.5', 'GAGEE3', 'PAGE-2B'], description='PAGE family member 2B', other_designations='putative G antigen family E member 3|G antigen, family E, 3|P antigen family, member 2B|prostate-associated gene 2B protein', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55027927, end_position_on_the_genomic_accession=55078909, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    389874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389874, CurrentID=0, Status='live', Symbol='ZCCHC13', Aliases=['CNBP2', 'ZNF9L'], description='zinc finger CCHC-type containing 13', other_designations='zinc finger CCHC domain-containing protein 13|zinc finger, CCHC domain containing 13', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=74304180, end_position_on_the_genomic_accession=74305034, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    389895 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389895, CurrentID=0, Status='live', Symbol='LOC389895', Aliases=[], description='chromosome 16 open reading frame 72-like', other_designations='UPF0472 protein C16orf72-like', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=140091678, end_position_on_the_genomic_accession=140092911, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    389898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389898, CurrentID=0, Status='live', Symbol='UBE2NL', Aliases=['Li174'], description='ubiquitin conjugating enzyme E2 N like (gene/pseudogene)', other_designations='putative ubiquitin-conjugating enzyme E2 N-like|epididymis tissue protein Li 174|ubiquitin conjugating enzyme E2N-like', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=143884071, end_position_on_the_genomic_accession=143885255, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    389903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389903, CurrentID=0, Status='live', Symbol='CSAG3', Aliases=['CSAG3A', 'CT24.2'], description='CSAG family member 3', other_designations='chondrosarcoma-associated gene 2/3 protein|CSAG family, member 3A|cancer/testis antigen 24.2|taxol resistance associated gene 3|taxol-resistant-associated gene 3 protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152753921, end_position_on_the_genomic_accession=152760219, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    389941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=389941, CurrentID=0, Status='live', Symbol='C1QL3', Aliases=['C1QTNF13', 'C1ql', 'CTRP13', 'K100'], description='complement C1q like 3', other_designations='complement C1q-like protein 3|C1q and tumor necrosis factor-related protein 13|C1q/TNF-related protein 13|complement component 1, q subcomponent-like 3', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=16513734, end_position_on_the_genomic_accession=16521879, orientation='minus', exon_count=2, OMIM=[615227], no_hdr0=''),
    390010 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390010, CurrentID=0, Status='live', Symbol='NKX1-2', Aliases=['C10orf121', 'NKX-1.1', 'bB238F13.2'], description='NK1 homeobox 2', other_designations='NK1 transcription factor-related protein 2|NK1 transcription factor related, locus 2|homeobox protein SAX-1', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124445243, end_position_on_the_genomic_accession=124450035, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390036, CurrentID=0, Status='live', Symbol='OR52K1', Aliases=['OR11-8'], description='olfactory receptor family 52 subfamily K member 1', other_designations='olfactory receptor 52K1|olfactory receptor OR11-8', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4482646, end_position_on_the_genomic_accession=4493497, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390037, CurrentID=0, Status='live', Symbol='OR52I1', Aliases=['OR11-13'], description='olfactory receptor family 52 subfamily I member 1', other_designations='olfactory receptor 52I1|olfactory receptor OR11-13', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4594039, end_position_on_the_genomic_accession=4595013, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390038, CurrentID=0, Status='live', Symbol='OR51D1', Aliases=['OR11-14Q', 'OR51D1'], description='olfactory receptor family 51 subfamily D member 1', other_designations='olfactory receptor 51D1|olfactory receptor OR11-14', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4637477, end_position_on_the_genomic_accession=4643060, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390054, CurrentID=0, Status='live', Symbol='OR52A5', Aliases=['OR11-33'], description='olfactory receptor family 52 subfamily A member 5', other_designations="olfactory receptor 52A5|odorant receptor HOR3'beta5|olfactory receptor OR11-33", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5128776, end_position_on_the_genomic_accession=5138356, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390058 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390058, CurrentID=0, Status='live', Symbol='OR51B6', Aliases=["HOR5'Beta6"], description='olfactory receptor family 51 subfamily B member 6', other_designations="olfactory receptor 51B6|odorant receptor HOR5'beta6|olfactory receptor 51B5", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5351508, end_position_on_the_genomic_accession=5352446, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390059, CurrentID=0, Status='live', Symbol='OR51M1', Aliases=["HOR5'Beta7", 'OR11-40'], description='olfactory receptor family 51 subfamily M member 1', other_designations="olfactory receptor 51M1|odorant receptor HOR5'beta7|olfactory receptor OR11-40", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5383812, end_position_on_the_genomic_accession=5393263, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390061, CurrentID=0, Status='live', Symbol='OR51Q1', Aliases=[], description='olfactory receptor family 51 subfamily Q member 1', other_designations='olfactory receptor 51Q1', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5422111, end_position_on_the_genomic_accession=5423206, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390063, CurrentID=0, Status='live', Symbol='OR51I1', Aliases=[], description='olfactory receptor family 51 subfamily I member 1', other_designations="olfactory receptor 51I1|HOR5'Beta11|odorant receptor HOR5'beta11|olfactory receptor OR11-39", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5440570, end_position_on_the_genomic_accession=5441514, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390064, CurrentID=0, Status='live', Symbol='OR51I2', Aliases=['OR11-38'], description='olfactory receptor family 51 subfamily I member 2', other_designations="olfactory receptor 51I2|HOR5'Beta12|odorant receptor HOR5'beta12|olfactory receptor OR11-38", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5449323, end_position_on_the_genomic_accession=5456518, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390066, CurrentID=0, Status='live', Symbol='OR52D1', Aliases=['OR11-43'], description='olfactory receptor family 52 subfamily D member 1', other_designations="olfactory receptor 52D1|HOR 5'Beta14|odorant receptor HOR5'beta14|olfactory receptor OR11-43", map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5488685, end_position_on_the_genomic_accession=5489749, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390067, CurrentID=0, Status='live', Symbol='OR52H1', Aliases=['OR11-41', 'OR11-45'], description='olfactory receptor family 52 subfamily H member 1', other_designations='olfactory receptor 52H1|olfactory receptor OR11-41 pseudogene|olfactory receptor OR11-45', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5544561, end_position_on_the_genomic_accession=5548540, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390072, CurrentID=0, Status='live', Symbol='OR52N4', Aliases=['OR11-64'], description='olfactory receptor family 52 subfamily N member 4', other_designations='olfactory receptor 52N4|olfactory receptor OR11-64', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5726462, end_position_on_the_genomic_accession=5755958, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    390075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390075, CurrentID=0, Status='live', Symbol='OR52N5', Aliases=['OR11-62Q', 'OR52N5'], description='olfactory receptor family 52 subfamily N member 5', other_designations='olfactory receptor 52N5|olfactory receptor OR11-62', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5776165, end_position_on_the_genomic_accession=5783355, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    390077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390077, CurrentID=0, Status='live', Symbol='OR52N2', Aliases=['OR11-57'], description='olfactory receptor family 52 subfamily N member 2', other_designations='olfactory receptor 52N2|olfactory receptor OR11-57', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5808924, end_position_on_the_genomic_accession=5821483, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390078 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390078, CurrentID=0, Status='live', Symbol='OR52E6', Aliases=['OR11-58'], description='olfactory receptor family 52 subfamily E member 6', other_designations='olfactory receptor 52E6|olfactory receptor OR11-58', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5840928, end_position_on_the_genomic_accession=5841897, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390079 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390079, CurrentID=0, Status='live', Symbol='OR52E8', Aliases=['OR11-54'], description='olfactory receptor family 52 subfamily E member 8', other_designations='olfactory receptor 52E8|olfactory receptor OR11-54|olfactory receptor, family 52, subfamily E, member 8 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5856749, end_position_on_the_genomic_accession=5857690, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390081, CurrentID=0, Status='live', Symbol='OR52E4', Aliases=['OR11-55'], description='olfactory receptor family 52 subfamily E member 4', other_designations='olfactory receptor 52E4|olfactory receptor OR11-55', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5880629, end_position_on_the_genomic_accession=5887079, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390082, CurrentID=0, Status='live', Symbol='OR52E5', Aliases=['OR11-56'], description='olfactory receptor family 52 subfamily E member 5', other_designations='olfactory receptor 52E5|olfactory receptor OR11-56 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5893208, end_position_on_the_genomic_accession=5902730, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390083 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390083, CurrentID=0, Status='live', Symbol='OR56A3', Aliases=['OR56A2PP', 'OR56A6', 'OR56A3'], description='olfactory receptor family 56 subfamily A member 3', other_designations='olfactory receptor 56A3|olfactory receptor 56A6|olfactory receptor OR11-51|olfactory receptor, family 56, subfamily A, member 2 pseudogene|olfactory receptor, family 56, subfamily A, member 3 pseudogene|olfactory receptor, family 56, subfamily A, member 6', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5942251, end_position_on_the_genomic_accession=5951347, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390084, CurrentID=0, Status='live', Symbol='OR56A5', Aliases=['OR56A5P'], description='olfactory receptor family 56 subfamily A member 5', other_designations='olfactory receptor 56A5|olfactory receptor, family 56, subfamily A, member 5 pseudogene', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5967553, end_position_on_the_genomic_accession=5968494, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390093, CurrentID=0, Status='live', Symbol='OR10A6', Aliases=['OR11-96'], description='olfactory receptor family 10 subfamily A member 6 (gene/pseudogene)', other_designations='olfactory receptor 10A6|olfactory receptor OR11-96|olfactory receptor, family 10, subfamily A, member 6', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=7924592, end_position_on_the_genomic_accession=7931268, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    390110 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390110, CurrentID=0, Status='live', Symbol='ACCSL', Aliases=[], description='1-aminocyclopropane-1-carboxylate synthase homolog (inactive) like', other_designations='probable inactive 1-aminocyclopropane-1-carboxylate synthase-like protein 2|1-aminocyclopropane-1-carboxylate synthase (inactive)-like|1-aminocyclopropane-1-carboxylate synthase homolog(non-functional)-like|1-aminocyclopropane-1-carboxylate synthase-like protein 2|ACC synthase-like protein 2', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=44047981, end_position_on_the_genomic_accession=44059977, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    390113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390113, CurrentID=0, Status='live', Symbol='OR4X1', Aliases=['OR11-104'], description='olfactory receptor family 4 subfamily X member 1', other_designations='olfactory receptor 4X1|olfactory receptor OR11-104', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48263861, end_position_on_the_genomic_accession=48264778, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390142, CurrentID=0, Status='live', Symbol='OR5D13', Aliases=[], description='olfactory receptor family 5 subfamily D member 13', other_designations='olfactory receptor 5D13|olfactory receptor OR11-142|olfactory receptor OR11-148', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55773438, end_position_on_the_genomic_accession=55774382, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390144, CurrentID=0, Status='live', Symbol='OR5D16', Aliases=['OR11-154'], description='olfactory receptor family 5 subfamily D member 16', other_designations='olfactory receptor 5D16|olfactory receptor OR11-154', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55838752, end_position_on_the_genomic_accession=55843036, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390148, CurrentID=0, Status='live', Symbol='OR5W2', Aliases=['OR5W2P', 'OR5W3P'], description='olfactory receptor family 5 subfamily W member 2', other_designations='olfactory receptor 5W2|olfactory receptor 5W3|olfactory receptor OR11-155|olfactory receptor, family 5, subfamily W, member 3 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=55913650, end_position_on_the_genomic_accession=55914582, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390151, CurrentID=0, Status='live', Symbol='OR8H2', Aliases=['OR11-171'], description='olfactory receptor family 8 subfamily H member 2', other_designations='olfactory receptor 8H2|olfactory receptor OR11-171', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56103687, end_position_on_the_genomic_accession=56107658, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390152, CurrentID=0, Status='live', Symbol='OR8H3', Aliases=['OR11-172'], description='olfactory receptor family 8 subfamily H member 3', other_designations='olfactory receptor 8H3|olfactory receptor OR11-172', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56122373, end_position_on_the_genomic_accession=56123311, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390154 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390154, CurrentID=0, Status='live', Symbol='OR5T3', Aliases=['OR11-178Q', 'OR5T3'], description='olfactory receptor family 5 subfamily T member 3', other_designations='olfactory receptor 5T3|olfactory receptor OR11-178', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56252254, end_position_on_the_genomic_accession=56253222, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390155, CurrentID=0, Status='live', Symbol='OR5T1', Aliases=['OR11-179P', 'OR5T1'], description='olfactory receptor family 5 subfamily T member 1', other_designations='olfactory receptor 5T1|olfactory receptor OR11-179|olfactory receptor, family 5, subfamily T, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56274154, end_position_on_the_genomic_accession=56276819, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390157, CurrentID=0, Status='live', Symbol='OR8K1', Aliases=['OR11-182', 'OR8N1P'], description='olfactory receptor family 8 subfamily K member 1', other_designations='olfactory receptor 8K1|olfactory receptor OR11-182|olfactory receptor, family 8, subfamily N, member 1 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56346039, end_position_on_the_genomic_accession=56346998, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390162 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390162, CurrentID=0, Status='live', Symbol='OR5M9', Aliases=['OR11-190'], description='olfactory receptor family 5 subfamily M member 9', other_designations='olfactory receptor 5M9|olfactory receptor OR11-190', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56462469, end_position_on_the_genomic_accession=56463401, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390167 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390167, CurrentID=0, Status='live', Symbol='OR5M10', Aliases=['OR11-207'], description='olfactory receptor family 5 subfamily M member 10', other_designations='olfactory receptor 5M10|olfactory receptor OR11-207', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56576774, end_position_on_the_genomic_accession=56577721, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390168, CurrentID=0, Status='live', Symbol='OR5M1', Aliases=['OR11-208', 'OST050'], description='olfactory receptor family 5 subfamily M member 1', other_designations='olfactory receptor 5M1|olfactory receptor OR11-208|seven transmembrane helix receptor', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56609236, end_position_on_the_genomic_accession=56614874, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390174, CurrentID=0, Status='live', Symbol='OR9G1', Aliases=['OR9G5'], description='olfactory receptor family 9 subfamily G member 1', other_designations='olfactory receptor 9G1|olfactory receptor 9G5|olfactory receptor OR11-114|olfactory receptor OR11-210|olfactory receptor, family 9, subfamily G, member 5', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56699095, end_position_on_the_genomic_accession=56703884, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390181, CurrentID=0, Status='live', Symbol='OR5AK2', Aliases=[], description='olfactory receptor family 5 subfamily AK member 2', other_designations='olfactory receptor 5AK2', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=56988914, end_position_on_the_genomic_accession=56989843, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390190, CurrentID=0, Status='live', Symbol='OR5B2', Aliases=['OR11-240', 'OST073'], description='olfactory receptor family 5 subfamily B member 2', other_designations='olfactory receptor 5B2|olfactory receptor OR11-240', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58421238, end_position_on_the_genomic_accession=58428121, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    390191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390191, CurrentID=0, Status='live', Symbol='OR5B12', Aliases=['OR11-241P', 'OR5B16', 'OST743', 'OR5B12'], description='olfactory receptor family 5 subfamily B member 12', other_designations='olfactory receptor 5B12|olfactory receptor 5B16|olfactory receptor OR11-241|olfactory receptor, family 5, subfamily B, member 12 pseudogene|olfactory receptor, family 5, subfamily B, member 16', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58438994, end_position_on_the_genomic_accession=58442236, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390195, CurrentID=0, Status='live', Symbol='OR5AN1', Aliases=['OR11-244'], description='olfactory receptor family 5 subfamily AN member 1', other_designations='olfactory receptor 5AN1|muscone receptor|olfactory receptor OR11-244', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59358895, end_position_on_the_genomic_accession=59371714, orientation='plus', exon_count=2, OMIM=[615702], no_hdr0=''),
    390197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390197, CurrentID=0, Status='live', Symbol='OR4D10', Aliases=['OR11-251P', 'OST711', 'OR4D10'], description='olfactory receptor family 4 subfamily D member 10', other_designations='olfactory receptor 4D10|olfactory receptor OR11-251|olfactory receptor, family 4, subfamily D, member 10 pseudogene|seven transmembrane helix receptor', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59473315, end_position_on_the_genomic_accession=59479361, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390199 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390199, CurrentID=0, Status='live', Symbol='OR4D9', Aliases=['OR11-253'], description='olfactory receptor family 4 subfamily D member 9', other_designations='olfactory receptor 4D9|olfactory receptor OR11-253|olfactory receptor, family 4, subfamily D, member 9 pseudogene', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59511539, end_position_on_the_genomic_accession=59520703, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390201, CurrentID=0, Status='live', Symbol='OR10V1', Aliases=['OR11-256'], description='olfactory receptor family 10 subfamily V member 1', other_designations='olfactory receptor 10V1|olfactory receptor OR11-256', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59712916, end_position_on_the_genomic_accession=59713845, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390205, CurrentID=0, Status='live', Symbol='LRRC10B', Aliases=[], description='leucine rich repeat containing 10B', other_designations='leucine-rich repeat-containing protein 10B|LRRC10-like protein ENSP00000367315', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61508749, end_position_on_the_genomic_accession=61511018, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390212, CurrentID=0, Status='live', Symbol='GPR152', Aliases=['PGR5'], description='G protein-coupled receptor 152', other_designations='probable G-protein coupled receptor 152|G protein-coupled receptor PGR5', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67451301, end_position_on_the_genomic_accession=67452729, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390231, CurrentID=0, Status='live', Symbol='TRIM77', Aliases=['TRIM77P'], description='tripartite motif containing 77', other_designations='tripartite motif-containing protein 77|TRIM77-isoform|putative tripartite motif-containing protein 64D|putative tripartite motif-containing protein 77|tripartite motif containing 77, pseudogene', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89710299, end_position_on_the_genomic_accession=89717872, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    390243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390243, CurrentID=0, Status='live', Symbol='IZUMO1R', Aliases=['FOLR4', 'FR-delta', 'Folbp3', 'JUNO'], description='IZUMO1 receptor, JUNO', other_designations='sperm-egg fusion protein Juno|IZUMO1 receptor protein JUNO|IZUMO1 receptor, JUNO, FR-delta|folate receptor 4 (delta) homolog|folate receptor 4, delta (putative)|folate receptor delta|probable folate receptor delta', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94304580, end_position_on_the_genomic_accession=94308146, orientation='plus', exon_count=5, OMIM=[615737], no_hdr0=''),
    390245 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390245, CurrentID=0, Status='live', Symbol='KDM4E', Aliases=['JMJD2E', 'KDM4DL', 'KDM5E'], description='lysine demethylase 4E', other_designations='lysine-specific demethylase 4E|KDM4D-like protein|[histone H3]-trimethyl-L-lysine(9) demethylase 4E|lysine (K)-specific demethylase 4E', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=95025258, end_position_on_the_genomic_accession=95027596, orientation='plus', exon_count=1, OMIM=[616581], no_hdr0=''),
    390259 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390259, CurrentID=0, Status='live', Symbol='BSX', Aliases=['BSX1'], description='brain specific homeobox', other_designations='brain-specific homeobox protein homolog', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=122977570, end_position_on_the_genomic_accession=122981834, orientation='minus', exon_count=3, OMIM=[611074], no_hdr0=''),
    390260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390260, CurrentID=0, Status='live', Symbol='OR6X1', Aliases=['OR11-270'], description='olfactory receptor family 6 subfamily X member 1', other_designations='olfactory receptor 6X1|olfactory receptor OR11-270', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123753580, end_position_on_the_genomic_accession=123754518, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390261, CurrentID=0, Status='live', Symbol='OR6M1', Aliases=['OR11-271'], description='olfactory receptor family 6 subfamily M member 1', other_designations='olfactory receptor 6M1|olfactory receptor OR11-271|olfactory receptor, family 6, subfamily M, member 2 pseudogene', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=123805408, end_position_on_the_genomic_accession=123806349, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390264, CurrentID=0, Status='live', Symbol='OR10G4', Aliases=['OR11-278'], description='olfactory receptor family 10 subfamily G member 4', other_designations='olfactory receptor 10G4|olfactory receptor OR11-278', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124012997, end_position_on_the_genomic_accession=124018732, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390265, CurrentID=0, Status='live', Symbol='OR10G7', Aliases=['OR11-283'], description='olfactory receptor family 10 subfamily G member 7', other_designations='olfactory receptor 10G7|olfactory receptor OR11-283', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124036013, end_position_on_the_genomic_accession=124041325, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390271, CurrentID=0, Status='live', Symbol='OR8B3', Aliases=['OR11-311'], description='olfactory receptor family 8 subfamily B member 3', other_designations='olfactory receptor 8B3|olfactory receptor OR11-311', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124395534, end_position_on_the_genomic_accession=124410495, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    390275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390275, CurrentID=0, Status='live', Symbol='OR8A1', Aliases=['OR11-318', 'OST025'], description='olfactory receptor family 8 subfamily A member 1', other_designations='olfactory receptor 8A1|olfactory receptor OR11-318', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=124569997, end_position_on_the_genomic_accession=124571374, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390321, CurrentID=0, Status='live', Symbol='OR6C1', Aliases=['OST267'], description='olfactory receptor family 6 subfamily C member 1', other_designations='olfactory receptor 6C1', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55314343, end_position_on_the_genomic_accession=55322364, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390323, CurrentID=0, Status='live', Symbol='OR6C75', Aliases=[], description='olfactory receptor family 6 subfamily C member 75', other_designations='olfactory receptor 6C75', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55362975, end_position_on_the_genomic_accession=55369279, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390326 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390326, CurrentID=0, Status='live', Symbol='OR6C76', Aliases=[], description='olfactory receptor family 6 subfamily C member 76', other_designations='olfactory receptor 6C76', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55426254, end_position_on_the_genomic_accession=55427192, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390327, CurrentID=0, Status='live', Symbol='OR6C70', Aliases=[], description='olfactory receptor family 6 subfamily C member 70', other_designations='olfactory receptor 6C70', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55469200, end_position_on_the_genomic_accession=55470138, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390429, CurrentID=0, Status='live', Symbol='OR4N2', Aliases=['OR14-13', 'OR14-8'], description='olfactory receptor family 4 subfamily N member 2', other_designations='olfactory receptor 4N2|olfactory receptor OR14-13|olfactory receptor OR14-8', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19803770, end_position_on_the_genomic_accession=19830253, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390431, CurrentID=0, Status='live', Symbol='OR4K2', Aliases=['OR14-15'], description='olfactory receptor family 4 subfamily K member 2', other_designations='olfactory receptor 4K2|olfactory receptor OR14-15', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19875142, end_position_on_the_genomic_accession=19883932, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390432, CurrentID=0, Status='live', Symbol='OR4Q2', Aliases=['OR4Q2P'], description='olfactory receptor family 4 subfamily Q member 2 (gene/pseudogene)', other_designations='olfactory receptor 4Q2|olfactory receptor OR14-21', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20002062, end_position_on_the_genomic_accession=20003192, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390433, CurrentID=0, Status='live', Symbol='OR4K13', Aliases=['OR14-27'], description='olfactory receptor family 4 subfamily K member 13', other_designations='olfactory receptor 4K13|olfactory receptor OR14-27', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20029399, end_position_on_the_genomic_accession=20036038, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390436, CurrentID=0, Status='live', Symbol='OR4K17', Aliases=['OR14-29'], description='olfactory receptor family 4 subfamily K member 17', other_designations='olfactory receptor 4K17|olfactory receptor OR14-29', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20110739, end_position_on_the_genomic_accession=20122199, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390437, CurrentID=0, Status='live', Symbol='OR4N5', Aliases=[], description='olfactory receptor family 4 subfamily N member 5', other_designations='olfactory receptor 4N5|olfactory receptor OR14-33', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20138820, end_position_on_the_genomic_accession=20145471, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    390439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390439, CurrentID=0, Status='live', Symbol='OR11G2', Aliases=['OR14-34'], description='olfactory receptor family 11 subfamily G member 2', other_designations='olfactory receptor 11G2|olfactory receptor OR14-34', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20190896, end_position_on_the_genomic_accession=20201075, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390441, CurrentID=0, Status='live', Symbol='OR11H7', Aliases=['OR11H7P'], description='olfactory receptor family 11 subfamily H member 7 (gene/pseudogene)', other_designations='olfactory receptor 11H7|olfactory receptor OR14-32|olfactory receptor, family 11, subfamily H, member 7 pseudogene|seven transmembrane helix receptor', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20228981, end_position_on_the_genomic_accession=20230749, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390442, CurrentID=0, Status='live', Symbol='OR11H4', Aliases=['OR14-36'], description='olfactory receptor family 11 subfamily H member 4', other_designations='olfactory receptor 11H4|olfactory receptor OR14-36', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20239286, end_position_on_the_genomic_accession=20244349, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390443 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390443, CurrentID=0, Status='live', Symbol='RNASE9', Aliases=['HEL128', 'RAK1', 'h461'], description='ribonuclease A family member 9 (inactive)', other_designations='inactive ribonuclease-like protein 9|ribonuclear enzyme|ribonuclease A K1|ribonuclease, RNase A family, 9 (non-active)', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20556093, end_position_on_the_genomic_accession=20560931, orientation='minus', exon_count=5, OMIM=[614014], no_hdr0=''),
    390445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390445, CurrentID=0, Status='live', Symbol='OR5AU1', Aliases=['OR14-38'], description='olfactory receptor family 5 subfamily AU member 1', other_designations='olfactory receptor 5AU1|olfactory receptor OR14-38', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21154865, end_position_on_the_genomic_accession=21156063, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390502, CurrentID=0, Status='live', Symbol='SERPINA2', Aliases=['ARGS', 'ATR', 'PILP', 'psiATR', 'SERPINA2'], description='serpin family A member 2 (gene/pseudogene)', other_designations='putative alpha-1-antitrypsin-related protein|alpha-1 antitrypsin-related protein|serine (or cysteine) proteinase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 2|serpin A2|serpin peptidase inhibitor, clade A (alpha-1 antiproteinase, antitrypsin), member 2, pseudogene', map_location='14q32.13', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=94364318, end_position_on_the_genomic_accession=94366702, orientation='minus', exon_count=2, OMIM=[107410], no_hdr0=''),
    390538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390538, CurrentID=0, Status='live', Symbol='OR4M2', Aliases=['OR15-3'], description='olfactory receptor family 4 subfamily M member 2', other_designations='olfactory receptor 4M2|olfactory receptor OR15-3', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22080527, end_position_on_the_genomic_accession=22081610, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    390594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390594, CurrentID=0, Status='live', Symbol='KBTBD13', Aliases=['HCG1645727', 'NEM6'], description='kelch repeat and BTB domain containing 13', other_designations='kelch repeat and BTB domain-containing protein 13|kelch repeat and BTB (POZ) domain containing 13|nemaline myopathy type 6', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65076746, end_position_on_the_genomic_accession=65079948, orientation='plus', exon_count=1, OMIM=[613727], no_hdr0=''),
    390595 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390595, CurrentID=0, Status='live', Symbol='UBAP1L', Aliases=['UBAP-1L'], description='ubiquitin associated protein 1 like', other_designations='ubiquitin-associated protein 1-like', map_location='15q22.31', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=65083036, end_position_on_the_genomic_accession=65115200, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    390598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390598, CurrentID=0, Status='live', Symbol='SKOR1', Aliases=['CORL1', 'FUSSEL15', 'LBXCOR1'], description='SKI family transcriptional corepressor 1', other_designations='SKI family transcriptional corepressor 1|LBX1 corepressor 1|Lbxcor1 homolog|corepressor for LBX1|functional Smad-suppressing element on chromosome 15|ladybird homeobox corepressor 1|transcriptional corepressor CORL1', map_location='15q23', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=67825509, end_position_on_the_genomic_accession=67834582, orientation='plus', exon_count=9, OMIM=[611273], no_hdr0=''),
    390616 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390616, CurrentID=0, Status='live', Symbol='ANKRD34C', Aliases=[], description='ankyrin repeat domain 34C', other_designations='ankyrin repeat domain-containing protein 34C', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79282722, end_position_on_the_genomic_accession=79298239, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390637, CurrentID=0, Status='live', Symbol='GDPGP1', Aliases=['C15orf58', 'VTC2'], description='GDP-D-glucose phosphorylase 1', other_designations='GDP-D-glucose phosphorylase 1|GDP-D-glucose phosphorylase C15orf58', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=90234209, end_position_on_the_genomic_accession=90245811, orientation='plus', exon_count=5, OMIM=[619240], no_hdr0=''),
    390648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390648, CurrentID=0, Status='live', Symbol='OR4F6', Aliases=['OR15-15', 'OR4F12'], description='olfactory receptor family 4 subfamily F member 6', other_designations='olfactory receptor 4F6|olfactory receptor 4F12|olfactory receptor OR15-15|olfactory receptor, family 4, subfamily F, member 12', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101803509, end_position_on_the_genomic_accession=101806887, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390649, CurrentID=0, Status='live', Symbol='OR4F15', Aliases=[], description='olfactory receptor family 4 subfamily F member 15', other_designations='olfactory receptor 4F15|olfactory receptor OR15-14', map_location='15q26.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=101812202, end_position_on_the_genomic_accession=101820197, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    390664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390664, CurrentID=0, Status='live', Symbol='C1QTNF8', Aliases=['CTRP8', 'UNQ5829'], description='C1q and TNF related 8', other_designations='complement C1q tumor necrosis factor-related protein 8|C1q and tumor necrosis factor related protein 8|C1q/TNF-related protein 8', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1088226, end_position_on_the_genomic_accession=1096306, orientation='minus', exon_count=5, OMIM=[614147], no_hdr0=''),
    390667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390667, CurrentID=0, Status='live', Symbol='PTX4', Aliases=['C16orf38'], description='pentraxin 4', other_designations='pentraxin-4|long pentraxin 4|neuronal pentraxin-like protein C16orf38|pentraxin 4, long', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1485886, end_position_on_the_genomic_accession=1488944, orientation='minus', exon_count=4, OMIM=[613442], no_hdr0=''),
    390748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390748, CurrentID=0, Status='live', Symbol='PABPN1L', Aliases=['PABPNL1', 'ePABP2'], description='PABPN1 like, cytoplasmic', other_designations='embryonic polyadenylate-binding protein 2|ePABP-2|embryonic poly(A)-binding protein 2|embryonic poly(A)-binding protein type II|poly(A) binding protein nuclear 1 like, cytoplasmic|poly(A)-binding protein nuclear-like 1', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88863333, end_position_on_the_genomic_accession=88870152, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    390790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390790, CurrentID=0, Status='live', Symbol='ARL5C', Aliases=['ARL12'], description='ADP ribosylation factor like GTPase 5C', other_designations='putative ADP-ribosylation factor-like protein 5C|ADP-ribosylation factor-like 5C|ADP-ribosylation factor-like protein 12', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39156894, end_position_on_the_genomic_accession=39166161, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    390792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390792, CurrentID=0, Status='live', Symbol='KRT39', Aliases=['CK-39', 'K39', 'KA35'], description='keratin 39', other_designations='keratin, type I cytoskeletal 39|cytokeratin-39|keratin 39, type I|type I hair keratin Ka35', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=40958417, end_position_on_the_genomic_accession=40966948, orientation='minus', exon_count=7, OMIM=[616678], no_hdr0=''),
    390874 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390874, CurrentID=0, Status='live', Symbol='ONECUT3', Aliases=['OC3'], description='one cut homeobox 3', other_designations='one cut domain family member 3|OC-3|transcription factor ONECUT-3', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1753506, end_position_on_the_genomic_accession=1780988, orientation='plus', exon_count=2, OMIM=[611294], no_hdr0=''),
    390877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390877, CurrentID=0, Status='live', Symbol='LOC390877', Aliases=[], description='adenylate kinase isoenzyme 1-like', other_designations='adenylate kinase isoenzyme 1-like|CTB-180A7.8', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=6393260, end_position_on_the_genomic_accession=6412404, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    390882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390882, CurrentID=0, Status='live', Symbol='OR7G2', Aliases=['OR19-6', 'OST260'], description='olfactory receptor family 7 subfamily G member 2', other_designations='olfactory receptor 7G2|OR19-13|olfactory receptor 19-13|olfactory receptor OR19-6', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9100407, end_position_on_the_genomic_accession=9107475, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390883 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390883, CurrentID=0, Status='live', Symbol='OR7G3', Aliases=['OST085'], description='olfactory receptor family 7 subfamily G member 3', other_designations='olfactory receptor 7G3|olfactory receptor OR19-9', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9126012, end_position_on_the_genomic_accession=9126950, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    390892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390892, CurrentID=0, Status='live', Symbol='OR7A10', Aliases=['BC85395_3', 'OR19-18'], description='olfactory receptor family 7 subfamily A member 10', other_designations='olfactory receptor 7A10|OST027|olfactory receptor OR19-18', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14840466, end_position_on_the_genomic_accession=14848922, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    390916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390916, CurrentID=0, Status='live', Symbol='NUDT19', Aliases=['RP2'], description='nudix hydrolase 19', other_designations='nucleoside diphosphate-linked moiety X motif 19|CTC-379B2.4|nucleoside diphosphate-linked moiety X motif 19, mitochondrial|nudix (nucleoside diphosphate linked moiety X)-type motif 19|nudix motif 19', map_location='19q13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=32691363, end_position_on_the_genomic_accession=32713792, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    390927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390927, CurrentID=0, Status='live', Symbol='ZNF793', Aliases=[], description='zinc finger protein 793', other_designations='zinc finger protein 793', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=37506939, end_position_on_the_genomic_accession=37543337, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    390928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390928, CurrentID=0, Status='live', Symbol='ACP7', Aliases=['PAPL', 'PAPL1'], description='acid phosphatase 7, tartrate resistant (putative)', other_designations='acid phosphatase type 7|iron/zinc purple acid phosphatase-like protein|purple acid phosphatase long form 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39083011, end_position_on_the_genomic_accession=39112074, orientation='plus', exon_count=14, OMIM=[610490], no_hdr0=''),
    390937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390937, CurrentID=0, Status='live', Symbol='ERFL', Aliases=['erfl1'], description='ETS repressor factor like', other_designations='ETS domain-containing transcription factor ERF-like|ETS domain-containing transcription factor ERF|Ets2 repressor factor-like', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41907549, end_position_on_the_genomic_accession=41928721, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    390940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390940, CurrentID=0, Status='live', Symbol='PINLYP', Aliases=[], description='phospholipase A2 inhibitor and LY6/PLAUR domain containing', other_designations='phospholipase A2 inhibitor and Ly6/PLAUR domain-containing protein', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43576800, end_position_on_the_genomic_accession=43582104, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    390980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390980, CurrentID=0, Status='live', Symbol='ZNF805', Aliases=[], description='zinc finger protein 805', other_designations='zinc finger protein 805|CTC-444N24.8', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57240632, end_position_on_the_genomic_accession=57262728, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    390992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390992, CurrentID=0, Status='live', Symbol='HES3', Aliases=['bHLHb43'], description='hes family bHLH transcription factor 3', other_designations='transcription factor HES-3|class B basic helix-loop-helix protein 43|hairy and enhancer of split 3', map_location='1p36.31', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=6244179, end_position_on_the_genomic_accession=6245578, orientation='plus', exon_count=4, OMIM=[609971], no_hdr0=''),
    390999 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=390999, CurrentID=0, Status='live', Symbol='PRAMEF12', Aliases=[], description='PRAME family member 12', other_designations='PRAME family member 12', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12773738, end_position_on_the_genomic_accession=12777906, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    391002 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391002, CurrentID=0, Status='live', Symbol='PRAMEF8', Aliases=['PRAMEF24'], description='PRAME family member 8', other_designations='PRAME family member 8|putative PRAME family member 24', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13281223, end_position_on_the_genomic_accession=13285137, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    391003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391003, CurrentID=0, Status='live', Symbol='PRAMEF18', Aliases=[], description='PRAME family member 18', other_designations='PRAME family member 18|PRAME family member-like', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13222695, end_position_on_the_genomic_accession=13226154, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    391004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391004, CurrentID=0, Status='live', Symbol='PRAMEF17', Aliases=[], description='PRAME family member 17', other_designations='PRAME family member 17', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13389632, end_position_on_the_genomic_accession=13392629, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    391013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391013, CurrentID=0, Status='live', Symbol='PLA2G2C', Aliases=['UBXN10-AS1'], description='phospholipase A2 group IIC', other_designations='putative inactive group IIC secretory phospholipase A2|UBXN10 antisense RNA 1|phosphatidylcholine 2-acylhydrolase-like protein GIIC|phospholipase A2, group IIC (possible pseudogene)', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20163055, end_position_on_the_genomic_accession=20186518, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    391059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391059, CurrentID=0, Status='live', Symbol='FRRS1', Aliases=['SDFR2', 'SDR2'], description='ferric chelate reductase 1', other_designations='ferric-chelate reductase 1|SDR-2|stromal cell derived factor receptor 2 homolog|stromal cell-derived receptor 2', map_location='1p21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=99703970, end_position_on_the_genomic_accession=99766635, orientation='minus', exon_count=20, OMIM=[611578], no_hdr0=''),
    391104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391104, CurrentID=0, Status='live', Symbol='VHLL', Aliases=['VHLP', 'VLP'], description='VHL like', other_designations='von Hippel-Lindau-like protein|VHL pseudogene|VHL-like protein|von Hippel-Lindau tumor suppressor like', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156298624, end_position_on_the_genomic_accession=156299307, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    391107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391107, CurrentID=0, Status='live', Symbol='OR10K2', Aliases=['OR1-4'], description='olfactory receptor family 10 subfamily K member 2', other_designations='olfactory receptor 10K2|olfactory receptor OR1-4', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158418210, end_position_on_the_genomic_accession=158426237, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    391109 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391109, CurrentID=0, Status='live', Symbol='OR10K1', Aliases=['OR1-6'], description='olfactory receptor family 10 subfamily K member 1', other_designations='olfactory receptor 10K1|olfactory receptor OR1-6', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158461834, end_position_on_the_genomic_accession=158467458, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    391112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391112, CurrentID=0, Status='live', Symbol='OR6Y1', Aliases=['OR1-11', 'OR6Y2'], description='olfactory receptor family 6 subfamily Y member 1', other_designations='olfactory receptor 6Y1|olfactory receptor 6Y2|olfactory receptor OR1-11', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158544550, end_position_on_the_genomic_accession=158554405, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    391114 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391114, CurrentID=0, Status='live', Symbol='OR6K3', Aliases=['OR1-18'], description='olfactory receptor family 6 subfamily K member 3', other_designations='olfactory receptor 6K3|olfactory receptor OR1-18|seven transmembrane helix receptor', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158716327, end_position_on_the_genomic_accession=158720720, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    391121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391121, CurrentID=0, Status='live', Symbol='OR10J4', Aliases=['OR10J4P', 'OST717'], description='olfactory receptor family 10 subfamily J member 4 (gene/pseudogene)', other_designations='olfactory receptor 10J4|olfactory receptor, family 10, subfamily J, member 4 pseudogene', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159432204, end_position_on_the_genomic_accession=159433138, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    391123 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391123, CurrentID=0, Status='live', Symbol='VSIG8', Aliases=[], description='V-set and immunoglobulin domain containing 8', other_designations='V-set and immunoglobulin domain-containing protein 8', map_location='1q23.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=159854316, end_position_on_the_genomic_accession=159862657, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    391189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391189, CurrentID=0, Status='live', Symbol='OR11L1', Aliases=[], description='olfactory receptor family 11 subfamily L member 1', other_designations='olfactory receptor 11L1|olfactory receptor OR1-50', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247840928, end_position_on_the_genomic_accession=247841896, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    391190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391190, CurrentID=0, Status='live', Symbol='OR2L8', Aliases=[], description='olfactory receptor family 2 subfamily L member 8', other_designations='olfactory receptor 2L8|olfactory receptor OR1-46', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247948858, end_position_on_the_genomic_accession=247949796, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    391191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391191, CurrentID=0, Status='live', Symbol='OR2AK2', Aliases=['OR1-47', 'OR2AK1P'], description='olfactory receptor family 2 subfamily AK member 2', other_designations='olfactory receptor 2AK2|olfactory receptor 2AK1|olfactory receptor OR1-47|olfactory receptor, family 2, subfamily AK, member 1 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247965332, end_position_on_the_genomic_accession=247966339, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    391192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391192, CurrentID=0, Status='live', Symbol='OR2L3', Aliases=[], description='olfactory receptor family 2 subfamily L member 3', other_designations='olfactory receptor 2L3', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248046836, end_position_on_the_genomic_accession=248063407, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    391194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391194, CurrentID=0, Status='live', Symbol='OR2M2', Aliases=['OR2M2Q', 'OST423'], description='olfactory receptor family 2 subfamily M member 2', other_designations='olfactory receptor 2M2', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248174821, end_position_on_the_genomic_accession=248181067, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    391195 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391195, CurrentID=0, Status='live', Symbol='OR2T33', Aliases=['OR1-56', 'OR2T32'], description='olfactory receptor family 2 subfamily T member 33', other_designations='olfactory receptor 2T33|novel 7 transmembrane receptor (rhodopsin family) protein|olfactory receptor OR1-56', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248269917, end_position_on_the_genomic_accession=248277976, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    391196 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391196, CurrentID=0, Status='live', Symbol='OR2M7', Aliases=['OR1-58'], description='olfactory receptor family 2 subfamily M member 7', other_designations='olfactory receptor 2M7|OR2M7 D|OR2M7 N|OR2M7 O|olfactory receptor OR1-58', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248323630, end_position_on_the_genomic_accession=248324568, orientation='minus', exon_count=1, OMIM=[618509], no_hdr0=''),
    391211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391211, CurrentID=0, Status='live', Symbol='OR2G6', Aliases=[], description='olfactory receptor family 2 subfamily G member 6', other_designations='olfactory receptor 2G6', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248508073, end_position_on_the_genomic_accession=248527337, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    391253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391253, CurrentID=0, Status='live', Symbol='SPINT4', Aliases=['C20orf137', 'SPINT3', 'dJ601O1.1'], description='serine peptidase inhibitor, Kunitz type 4', other_designations='kunitz-type protease inhibitor 4|epididymis secretory sperm binding protein|serine protease inhibitor, Kunitz type 1|serine protease inhibitor, Kunitz type 4', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45722347, end_position_on_the_genomic_accession=45725830, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    391322 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391322, CurrentID=0, Status='live', Symbol='LOC391322', Aliases=[], description='D-dopachrome tautomerase-like', other_designations='D-dopachrome decarboxylase related protein', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    391356 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391356, CurrentID=0, Status='live', Symbol='PTRHD1', Aliases=['C2orf79'], description='peptidyl-tRNA hydrolase domain containing 1', other_designations='putative peptidyl-tRNA hydrolase PTRHD1|peptidyl-tRNA hydrolase domain-containing protein 1', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24789728, end_position_on_the_genomic_accession=24793391, orientation='minus', exon_count=2, OMIM=[617342], no_hdr0=''),
    391365 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391365, CurrentID=0, Status='live', Symbol='SULT6B1', Aliases=['ST6B1'], description='sulfotransferase family 6B member 1', other_designations='sulfotransferase 6B1|sulfotransferase SULT6B1|sulfotransferase family, cytosolic, 6B, member 1|thyroxine sulfotransferase', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37167820, end_position_on_the_genomic_accession=37196087, orientation='minus', exon_count=9, OMIM=[617152], no_hdr0=''),
    391475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391475, CurrentID=0, Status='live', Symbol='DYTN', Aliases=[], description='dystrotelin', other_designations='dystrotelin', map_location='2q33.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=206651621, end_position_on_the_genomic_accession=206718396, orientation='minus', exon_count=12, OMIM=[618510], no_hdr0=''),
    391712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391712, CurrentID=0, Status='live', Symbol='TRIM61', Aliases=['RNF35'], description='tripartite motif containing 61', other_designations='putative tripartite motif-containing protein 61|ring finger protein 35', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=164954446, end_position_on_the_genomic_accession=164977657, orientation='minus', exon_count=5, OMIM=[619417], no_hdr0=''),
    391723 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391723, CurrentID=0, Status='live', Symbol='HELT', Aliases=['HCM1228', 'HESL', 'Mgn', 'bHLHb44'], description='helt bHLH transcription factor', other_designations='hairy and enhancer of split-related protein HELT|HES/HEY-like transcription factor|Hes-like transcription factor|Hey-like transcription factor|Hey-like transcriptional repressor|Megane bHLH factor', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185018490, end_position_on_the_genomic_accession=185021265, orientation='plus', exon_count=4, OMIM=[617546], no_hdr0=''),
    391769 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=391769, CurrentID=0, Status='live', Symbol='H3Y1', Aliases=['H3.Y', 'H3.Y.1'], description='H3.Y histone 1', other_designations='histone H3.Y|H3 histone, family 3B (H3.3B) pseudogene|Histone H3.Y|histone H3.Y1|histone cluster 2, H3c pseudogene', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=17654868, end_position_on_the_genomic_accession=17655849, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392133, CurrentID=0, Status='live', Symbol='OR10AC1', Aliases=['OR10AC1P'], description='olfactory receptor family 10 subfamily AC member 1 (gene/pseudogene)', other_designations='olfactory receptor 10AC1|Olfactory receptor OR7-5|Putative olfactory receptor 10AC1|olfactory receptor, family 10, subfamily AC, member 1 pseudogene|olfactory receptor, family 10, subfamily W, member 1 pseudogene|seven transmembrane helix receptor', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143510867, end_position_on_the_genomic_accession=143512011, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392138, CurrentID=0, Status='live', Symbol='OR2A25', Aliases=['OR2A24PP', 'OR2A27', 'OR2A25'], description='olfactory receptor family 2 subfamily A member 25', other_designations='olfactory receptor 2A25|olfactory receptor 2A27|olfactory receptor, family 2, subfamily A, member 24 pseudogene|olfactory receptor, family 2, subfamily A, member 25 pseudogene|olfactory receptor, family 2, subfamily A, member 27', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144069811, end_position_on_the_genomic_accession=144075870, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    392188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392188, CurrentID=0, Status='live', Symbol='USP17L8', Aliases=['USP17L10'], description='ubiquitin specific peptidase 17 like family member 8', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 17-like protein 8|ubiquitin specific peptidase 17-like 8', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7971661, end_position_on_the_genomic_accession=7973253, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392197, CurrentID=0, Status='live', Symbol='USP17L7', Aliases=[], description='ubiquitin specific peptidase 17 like family member 7', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 17-like protein 7|ubiquitin specific peptidase 17-like 7', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12132417, end_position_on_the_genomic_accession=12134099, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392255, CurrentID=0, Status='live', Symbol='GDF6', Aliases=['BMP-13', 'BMP13', 'CDMP2', 'KFM', 'KFS', 'KFS1', 'KFSL', 'SGM1', 'SYNS4'], description='growth differentiation factor 6', other_designations='growth/differentiation factor 6|bone morphogenetic protein 13|growth/differentiation factor 16', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=96142333, end_position_on_the_genomic_accession=96160806, orientation='minus', exon_count=2, OMIM=[601147], no_hdr0=''),
    392307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392307, CurrentID=0, Status='live', Symbol='FAM221B', Aliases=['C9orf128'], description='family with sequence similarity 221 member B', other_designations='protein FAM221B|uncharacterized protein C9orf128', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35816391, end_position_on_the_genomic_accession=35829148, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    392309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392309, CurrentID=0, Status='live', Symbol='OR13J1', Aliases=['OR9-2'], description='olfactory receptor family 13 subfamily J member 1', other_designations='olfactory receptor 13J1|olfactory receptor OR9-2', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35869463, end_position_on_the_genomic_accession=35870401, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392376, CurrentID=0, Status='live', Symbol='OR13C2', Aliases=['OR37K'], description='olfactory receptor family 13 subfamily C member 2', other_designations='olfactory receptor 13C2|olfactory receptor OR9-12', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=104604671, end_position_on_the_genomic_accession=104605627, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    392390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392390, CurrentID=0, Status='live', Symbol='OR1L6', Aliases=['HG16', 'OR1K1', 'OR1L7', 'OR9-30'], description='olfactory receptor family 1 subfamily L member 6', other_designations='olfactory receptor 1L6|olfactory receptor 1L7|olfactory receptor OR9-30|olfactory receptor, family 1, subfamily L, member 7', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122742303, end_position_on_the_genomic_accession=122750783, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    392391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392391, CurrentID=0, Status='live', Symbol='OR5C1', Aliases=['OR5C2P', 'OR9-31', 'OR9-F'], description='olfactory receptor family 5 subfamily C member 1', other_designations='olfactory receptor 5C1|hRPK-465_F_21|olfactory receptor 5C2|olfactory receptor 9-F|olfactory receptor, family 5, subfamily C, member 2 pseudogene', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122788933, end_position_on_the_genomic_accession=122789895, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    392392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392392, CurrentID=0, Status='live', Symbol='OR1K1', Aliases=['hg99'], description='olfactory receptor family 1 subfamily K member 1', other_designations='olfactory receptor 1K1', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=122800123, end_position_on_the_genomic_accession=122801073, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    392399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392399, CurrentID=0, Status='live', Symbol='LCN9', Aliases=['HEL129'], description='lipocalin 9', other_designations='epididymal-specific lipocalin-9|MUP-like lipocalin|epididymis luminal protein 129', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135663309, end_position_on_the_genomic_accession=135670731, orientation='plus', exon_count=8, OMIM=[612903], no_hdr0=''),
    392465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392465, CurrentID=0, Status='live', Symbol='GLOD5', Aliases=[], description='glyoxalase domain containing 5', other_designations='glyoxalase domain-containing protein 5', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48761747, end_position_on_the_genomic_accession=48773648, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    392509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392509, CurrentID=0, Status='live', Symbol='ARL13A', Aliases=['ARL13', 'dJ341D10.2'], description='ADP ribosylation factor like GTPase 13A', other_designations='ADP-ribosylation factor-like protein 13A|ADP-ribosylation factor-like 13|ADP-ribosylation factor-like 13A', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100969011, end_position_on_the_genomic_accession=100990831, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    392517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392517, CurrentID=0, Status='live', Symbol='NCBP2L', Aliases=['dJ820B18.1'], description='nuclear cap binding protein subunit 2 like', other_designations='nuclear cap-binding protein subunit 2-like', map_location='Xq22.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=107777733, end_position_on_the_genomic_accession=107795829, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    392617 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392617, CurrentID=0, Status='live', Symbol='ELFN1', Aliases=['PPP1R28'], description='extracellular leucine rich repeat and fibronectin type III domain containing 1', other_designations='protein ELFN1|extracellular leucine-rich repeat and fibronectin type III containing 1|extracellular leucine-rich repeat and fibronectin type-III domain-containing protein 1|protein phosphatase 1 regulatory subunit 28', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1666064, end_position_on_the_genomic_accession=1747954, orientation='plus', exon_count=8, OMIM=[614964], no_hdr0=''),
    392636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392636, CurrentID=0, Status='live', Symbol='AGMO', Aliases=['TMEM195'], description='alkylglycerol monooxygenase', other_designations='alkylglycerol monooxygenase|glyceryl-ether monooxygenase|transmembrane protein 195', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=15117223, end_position_on_the_genomic_accession=15562015, orientation='minus', exon_count=21, OMIM=[613738], no_hdr0=''),
    392843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392843, CurrentID=0, Status='live', Symbol='IQCA1L', Aliases=['IQCA1P1'], description='IQ motif containing with AAA domain 1 like', other_designations='IQ and AAA domain-containing protein 1-like|IQ and AAA domain-containing protein 1 pseudogene 1|IQ motif containing with AAA domain 1-like protein|putative IQ and AAA domain-containing protein 1 pseudogene 1|putative IQ and AAA domain-containing protein 1-like|putative IQ motif containing with AAA domain 1 pseudogene 1', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151190873, end_position_on_the_genomic_accession=151205784, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    392862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=392862, CurrentID=0, Status='live', Symbol='GRID2IP', Aliases=['DELPHILIN'], description='Grid2 interacting protein', other_designations='delphilin|glutamate receptor, ionotropic, delta 2 (Grid2) interacting protein 1|glutamate receptor, ionotropic, delta 2-interacting protein 1', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6496778, end_position_on_the_genomic_accession=6551461, orientation='minus', exon_count=24, OMIM=[610639], no_hdr0=''),
    393046 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=393046, CurrentID=0, Status='live', Symbol='OR2A5', Aliases=['OR2A11P', 'OR2A26', 'OR2A8', 'OR7-138', 'OR7-141'], description='olfactory receptor family 2 subfamily A member 5', other_designations='olfactory receptor 2A5|olfactory receptor 2A26|olfactory receptor 2A8|olfactory receptor 7-138/7-141|olfactory receptor, family 2, subfamily A, member 11 pseudogene|olfactory receptor, family 2, subfamily A, member 26|olfactory receptor, family 2, subfamily A, member 8', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144048948, end_position_on_the_genomic_accession=144058845, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    394263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=394263, CurrentID=0, Status='live', Symbol='MUC21', Aliases=['C6orf205', 'KMQK697', 'MUC-21'], description='mucin 21, cell surface associated', other_designations='mucin-21|epiglycanin', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=30983718, end_position_on_the_genomic_accession=30989903, orientation='plus', exon_count=3, OMIM=[616991], no_hdr0=''),
    399473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399473, CurrentID=0, Status='live', Symbol='SPRED3', Aliases=['Eve-3', 'spred-3'], description='sprouty related EVH1 domain containing 3', other_designations='sprouty-related, EVH1 domain-containing protein 3', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38388697, end_position_on_the_genomic_accession=38399587, orientation='plus', exon_count=7, OMIM=[609293], no_hdr0=''),
    399474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399474, CurrentID=0, Status='live', Symbol='TMEM200B', Aliases=['TTMB'], description='transmembrane protein 200B', other_designations='transmembrane protein 200B|transmembrane protein TTMA|two transmembrane B|two transmembrane domain-containing family member B', map_location='1p35.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=29119429, end_position_on_the_genomic_accession=29129138, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    399512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399512, CurrentID=0, Status='live', Symbol='SLC25A35', Aliases=[], description='solute carrier family 25 member 35', other_designations='solute carrier family 25 member 35', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8287763, end_position_on_the_genomic_accession=8295689, orientation='minus', exon_count=9, OMIM=[610818], no_hdr0=''),
    399664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399664, CurrentID=0, Status='live', Symbol='MEX3D', Aliases=['MEX-3D', 'MEX3', 'OK/SW-cl.4', 'RKHD1', 'RNF193', 'TINO'], description='mex-3 RNA binding family member D', other_designations='RNA-binding protein MEX3D|RING finger and KH domain-containing protein 1|RING finger protein 193|bcl-2 ARE RNA binding protein|ring finger (C3HC4 type) and KH domain containing 1|ring finger and KH domain containing 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=1554672, end_position_on_the_genomic_accession=1568325, orientation='minus', exon_count=3, OMIM=[611009], no_hdr0=''),
    399665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399665, CurrentID=0, Status='live', Symbol='FAM102A', Aliases=['C9orf132', 'EEIG1', 'SYM-3A', 'bA203J24.7'], description='family with sequence similarity 102 member A', other_designations='protein FAM102A|C230093N12Rik|early estrogen-induced gene 1 protein|sym-3 homolog A', map_location='9q34.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=127940582, end_position_on_the_genomic_accession=127980989, orientation='minus', exon_count=11, OMIM=[610891], no_hdr0=''),
    399668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399668, CurrentID=0, Status='live', Symbol='SMIM10L2A', Aliases=['LED', 'LINC00086', 'LINC00087', 'LINC0086', 'NCRNA00086', 'NCRNA00087', 'SMIM10L2B'], description='small integral membrane protein 10 like 2A', other_designations='small integral membrane protein 10-like protein 2A|Small integral membrane protein 10-like protein 2B|lncRNA activator of enhancer domains|long intergenic non-protein coding RNA 86', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135421944, end_position_on_the_genomic_accession=135428075, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    399671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399671, CurrentID=0, Status='live', Symbol='HEATR4', Aliases=[], description='HEAT repeat containing 4', other_designations='HEAT repeat-containing protein 4', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73478484, end_position_on_the_genomic_accession=73558947, orientation='minus', exon_count=20, OMIM=[], no_hdr0=''),
    399687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399687, CurrentID=0, Status='live', Symbol='MYO18A', Aliases=['MAJN', 'MYSPDZ', 'SP-R210', 'SPR210'], description='myosin XVIIIA', other_designations='unconventional myosin-XVIIIa|SP-A receptor subunit SP-R210 alphaS|molecule associated with JAK3 N-terminus|myosin 18A|myosin containing PDZ domain|myosin containing a PDZ domain|surfactant protein receptor SP-R210', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=29071122, end_position_on_the_genomic_accession=29180398, orientation='minus', exon_count=47, OMIM=[610067], no_hdr0=''),
    399693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399693, CurrentID=0, Status='live', Symbol='CCDC187', Aliases=[], description='coiled-coil domain containing 187', other_designations='coiled-coil domain-containing protein 187', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136249973, end_position_on_the_genomic_accession=136306901, orientation='minus', exon_count=27, OMIM=[], no_hdr0=''),
    399694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399694, CurrentID=0, Status='live', Symbol='SHC4', Aliases=['RaLP', 'SHCD'], description='SHC adaptor protein 4', other_designations='SHC-transforming protein 4|SH2 domain protein C4|SHC (Src homology 2 domain containing) family, member 4|SHC-transforming protein D|hShcD|rai-like protein|src homology 2 domain-containing-transforming protein C4', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48823741, end_position_on_the_genomic_accession=48963919, orientation='minus', exon_count=13, OMIM=[617372], no_hdr0=''),
    399697 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399697, CurrentID=0, Status='live', Symbol='CTXN2', Aliases=[], description='cortexin 2', other_designations='cortexin-2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=48178438, end_position_on_the_genomic_accession=48203758, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    399814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399814, CurrentID=0, Status='live', Symbol='C10orf120', Aliases=['bA318C4.1'], description='chromosome 10 open reading frame 120', other_designations='uncharacterized protein C10orf120', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122697709, end_position_on_the_genomic_accession=122699846, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    399818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399818, CurrentID=0, Status='live', Symbol='EEF1AKMT2', Aliases=['C10orf138', 'Efm4', 'METTL10'], description='EEF1A lysine methyltransferase 2', other_designations='EEF1A lysine methyltransferase 2|eukaryotic translation elongation factor 1 alpha lysine methyltransferase 2|methyltransferase like 10|methyltransferase-like protein 10|protein-lysine N-methyltransferase METTL10', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=124757834, end_position_on_the_genomic_accession=124791887, orientation='minus', exon_count=7, OMIM=[617794], no_hdr0=''),
    399823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399823, CurrentID=0, Status='live', Symbol='FOXI2', Aliases=[], description='forkhead box I2', other_designations='forkhead box protein I2|homolog of mouse Foxi2', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=127737185, end_position_on_the_genomic_accession=127741183, orientation='plus', exon_count=2, OMIM=[617202], no_hdr0=''),
    399888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399888, CurrentID=0, Status='live', Symbol='FAM180B', Aliases=[], description='family with sequence similarity 180 member B', other_designations='protein FAM180B|hypothetical gene supported by BC065704', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=47586651, end_position_on_the_genomic_accession=47589194, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    399909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399909, CurrentID=0, Status='live', Symbol='PCNX3', Aliases=['PCNXL3'], description='pecanex 3', other_designations='pecanex-like protein 3|pecanex homolog 3|pecanex homolog protein 3|pecanex-like 3', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65614311, end_position_on_the_genomic_accession=65637439, orientation='plus', exon_count=38, OMIM=[617657], no_hdr0=''),
    399939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399939, CurrentID=0, Status='live', Symbol='TRIM49D1', Aliases=['TRIM49DP', 'TRIM49D2', 'TRIM49D2P', 'TRIM49DP', 'TRIM49D1'], description='tripartite motif containing 49D1', other_designations='tripartite motif-containing protein 49D|tripartite motif containing 49D, pseudogene|tripartite motif containing 49D1, pseudogene|tripartite motif-containing protein 49-like protein|tripartite motif-containing protein 49D1|tripartite motif-containing protein 49D2 pseudogene', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89911409, end_position_on_the_genomic_accession=89922245, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    399947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399947, CurrentID=0, Status='live', Symbol='C11orf87', Aliases=['LOH11CR1A', 'NEURIM1'], description='chromosome 11 open reading frame 87', other_designations='uncharacterized protein C11orf87|neuronal integral membrane protein 1', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=109422190, end_position_on_the_genomic_accession=109433003, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    399949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399949, CurrentID=0, Status='live', Symbol='HOATZ', Aliases=['C11orf88'], description='HOATZ cilia and flagella associated protein', other_designations='cilia- and flagella-associated protein HOATZ|UPF0722 protein C11orf88|hypothetical gene supported by BC039505|protein Hoatz', map_location='11q23.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=111514778, end_position_on_the_genomic_accession=111537043, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    399967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399967, CurrentID=0, Status='live', Symbol='PATE2', Aliases=['C11orf38', 'PATE-M', 'UNQ3112'], description='prostate and testis expressed 2', other_designations='prostate and testis expressed protein 2|LVLF3112|PATE-like protein M|prostate and testis expression M', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125776113, end_position_on_the_genomic_accession=125778828, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    399968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399968, CurrentID=0, Status='live', Symbol='PATE4', Aliases=['PATE-B'], description='prostate and testis expressed 4', other_designations='prostate and testis expressed protein 4|PATE-like protein B|prostate and testis expression B', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125833316, end_position_on_the_genomic_accession=125840072, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    399979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=399979, CurrentID=0, Status='live', Symbol='SNX19', Aliases=['CHET8'], description='sorting nexin 19', other_designations='sorting nexin-19', map_location='11q24.3-q25', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=130866250, end_position_on_the_genomic_accession=130916488, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    400073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400073, CurrentID=0, Status='live', Symbol='C12orf76', Aliases=[], description='chromosome 12 open reading frame 76', other_designations='uncharacterized protein C12orf76', map_location='12q24.11', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=110041177, end_position_on_the_genomic_accession=110073639, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    400120 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400120, CurrentID=0, Status='live', Symbol='SERTM1', Aliases=['C13orf36'], description='serine rich and transmembrane domain containing 1', other_designations='serine-rich and transmembrane domain-containing protein 1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36674020, end_position_on_the_genomic_accession=36697839, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    400224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400224, CurrentID=0, Status='live', Symbol='PLEKHD1', Aliases=['UPF0639'], description='pleckstrin homology and coiled-coil domain containing D1', other_designations='pleckstrin homology domain-containing family D member 1|PH domain-containing family D member 1|pleckstrin homology domain containing, family D (with M protein repeats) member 1|pleckstrin homology domain containing, family D (with coiled-coil domains) member 1', map_location='14q24.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=69467744, end_position_on_the_genomic_accession=69531551, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    400258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400258, CurrentID=0, Status='live', Symbol='C14orf180', Aliases=['C14orf77', 'NRAC'], description='chromosome 14 open reading frame 180', other_designations='nutritionally-regulated adipose and cardiac enriched protein homolog|transmembrane protein C14orf180', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104579764, end_position_on_the_genomic_accession=104590515, orientation='plus', exon_count=6, OMIM=[619392], no_hdr0=''),
    400451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400451, CurrentID=0, Status='live', Symbol='FAM174B', Aliases=[], description='family with sequence similarity 174 member B', other_designations='membrane protein FAM174B', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=92617447, end_position_on_the_genomic_accession=92734219, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    400499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400499, CurrentID=0, Status='live', Symbol='LOC400499', Aliases=[], description='putative uncharacterized protein LOC400499', other_designations='putative uncharacterized protein LOC400499', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11372015, end_position_on_the_genomic_accession=11527247, orientation='minus', exon_count=72, OMIM=[], no_hdr0=''),
    400506 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400506, CurrentID=0, Status='live', Symbol='KNOP1', Aliases=['101F10.1', 'C16orf88', 'FAM191A', 'TSG118'], description='lysine rich nucleolar protein 1', other_designations='lysine-rich nucleolar protein 1|family with sequence similarity 191, member A|protein C16orf88|testis-specific gene 118 protein', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19701937, end_position_on_the_genomic_accession=19718227, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    400566 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400566, CurrentID=0, Status='live', Symbol='C17orf97', Aliases=['CK20', 'LIAT1'], description='chromosome 17 open reading frame 97', other_designations='protein LIAT1|ligand of ATE1 protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=410325, end_position_on_the_genomic_accession=414666, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    400569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400569, CurrentID=0, Status='live', Symbol='MED11', Aliases=['HSPC296'], description='mediator complex subunit 11', other_designations='mediator of RNA polymerase II transcription subunit 11|mediator of RNA polymerase II transcription, subunit 11 homolog', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4731428, end_position_on_the_genomic_accession=4733607, orientation='plus', exon_count=3, OMIM=[612383], no_hdr0=''),
    400581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400581, CurrentID=0, Status='live', Symbol='GRAPL', Aliases=[], description='GRB2 related adaptor protein like', other_designations='GRB2-related adapter protein-like|GRB2-related adapter protein LOC400581', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=19123189, end_position_on_the_genomic_accession=19159187, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    400629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400629, CurrentID=0, Status='live', Symbol='TEX19', Aliases=[], description='testis expressed 19', other_designations='testis-expressed protein 19|testis-expressed sequence 19 protein', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=82359247, end_position_on_the_genomic_accession=82363776, orientation='plus', exon_count=3, OMIM=[615647], no_hdr0=''),
    400668 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400668, CurrentID=0, Status='live', Symbol='PRSS57', Aliases=['NSP4', 'PRSSL1', 'UNQ782'], description='serine protease 57', other_designations='serine protease 57|neutrophil serine protease 4|protease, serine 57|serine protease 1-like protein 1', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=685546, end_position_on_the_genomic_accession=695452, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    400673 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400673, CurrentID=0, Status='live', Symbol='VMAC', Aliases=[], description='vimentin type intermediate filament associated coiled-coil protein', other_designations='vimentin-type intermediate filament-associated coiled-coil protein|vimentin-type IF-associated coiled-coil protein', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=5904872, end_position_on_the_genomic_accession=5910853, orientation='plus', exon_count=2, OMIM=[617204], no_hdr0=''),
    400709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400709, CurrentID=0, Status='live', Symbol='SIGLEC16', Aliases=['SIGLECP16', 'Siglec-P16'], description='sialic acid binding Ig like lectin 16', other_designations='sialic acid-binding Ig-like lectin 16|sialic acid binding Ig-like lectin, pseudogene 16|sialic acid-binding immunoglobulin-like lectin 16|siglec-16', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49969664, end_position_on_the_genomic_accession=49975814, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    400713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400713, CurrentID=0, Status='live', Symbol='ZNF880', Aliases=[], description='zinc finger protein 880', other_designations='zinc finger protein 880|zinc finger protein LOC400713', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52369923, end_position_on_the_genomic_accession=52395874, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    400720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400720, CurrentID=0, Status='live', Symbol='ZNF772', Aliases=[], description='zinc finger protein 772', other_designations='zinc finger protein 772', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57469586, end_position_on_the_genomic_accession=57479014, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    400735 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400735, CurrentID=0, Status='live', Symbol='PRAMEF4', Aliases=[], description='PRAME family member 4', other_designations='PRAME family member 4|RP5-845O24.6', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12879212, end_position_on_the_genomic_accession=12886201, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    400736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400736, CurrentID=0, Status='live', Symbol='PRAMEF13', Aliases=[], description='PRAME family member 13', other_designations='PRAME family member-like', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13196188, end_position_on_the_genomic_accession=13201409, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    400745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400745, CurrentID=0, Status='live', Symbol='SH2D5', Aliases=[], description='SH2 domain containing 5', other_designations='SH2 domain-containing protein 5', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=20719731, end_position_on_the_genomic_accession=20732703, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    400746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400746, CurrentID=0, Status='live', Symbol='NCMAP', Aliases=['C1orf130', 'MP11'], description='non-compact myelin associated protein', other_designations='noncompact myelin-associated protein|myelin protein of 11 kDa', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=24556087, end_position_on_the_genomic_accession=24609328, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    400757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400757, CurrentID=0, Status='live', Symbol='C1orf141', Aliases=[], description='chromosome 1 open reading frame 141', other_designations='uncharacterized protein C1orf141', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=67092165, end_position_on_the_genomic_accession=67141646, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    400793 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400793, CurrentID=0, Status='live', Symbol='C1orf226', Aliases=[], description='chromosome 1 open reading frame 226', other_designations='uncharacterized protein C1orf226', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=162378841, end_position_on_the_genomic_accession=162386812, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    400797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400797, CurrentID=0, Status='live', Symbol='CLEC20A', Aliases=['LINC00083', 'NCRNA00083'], description='C-type lectin domain containing 20A', other_designations='putative C-type lectin domain family 20 member A|C-type lectin domain family 20 member A|long intergenic non-protein coding RNA 83', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=178478153, end_position_on_the_genomic_accession=178499623, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    400818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400818, CurrentID=0, Status='live', Symbol='NBPF9', Aliases=['AE01'], description='NBPF member 9', other_designations='neuroblastoma breakpoint family member 9', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149052186, end_position_on_the_genomic_accession=149103551, orientation='minus', exon_count=34, OMIM=[613999], no_hdr0=''),
    400823 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400823, CurrentID=0, Status='live', Symbol='FAM177B', Aliases=[], description='family with sequence similarity 177 member B', other_designations='protein FAM177B', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=222737202, end_position_on_the_genomic_accession=222772193, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    400830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400830, CurrentID=0, Status='live', Symbol='DEFB132', Aliases=['BD-32', 'DEFB-32', 'DEFB32', 'HEL-75', 'KFLL827', 'UNQ827'], description='defensin beta 132', other_designations='beta-defensin 132|RP5-1103G7.6|beta-defensin 32|defensin HEL-75|defensin, beta 32', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=257724, end_position_on_the_genomic_accession=261096, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    400831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400831, CurrentID=0, Status='live', Symbol='C20orf202', Aliases=[], description='chromosome 20 open reading frame 202', other_designations='uncharacterized protein C20orf202', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1203454, end_position_on_the_genomic_accession=1209076, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    400891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400891, CurrentID=0, Status='live', Symbol='LRRC74B', Aliases=[], description='leucine rich repeat containing 74B', other_designations='leucine-rich repeat-containing protein 74B|leucine-rich repeat-containing protein LOC400891', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21045946, end_position_on_the_genomic_accession=21064168, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    400916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400916, CurrentID=0, Status='live', Symbol='CHCHD10', Aliases=['C22orf16', 'FTDALS2', 'IMMD', 'MIX17A', 'N27C7-4', 'SMAJ'], description='coiled-coil-helix-coiled-coil-helix domain containing 10', other_designations='coiled-coil-helix-coiled-coil-helix domain-containing protein 10, mitochondrial|MIX17 homolog A', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23765834, end_position_on_the_genomic_accession=23767972, orientation='minus', exon_count=4, OMIM=[615903], no_hdr0=''),
    400935 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400935, CurrentID=0, Status='live', Symbol='IL17REL', Aliases=[], description='interleukin 17 receptor E like', other_designations='putative interleukin-17 receptor E-like|IL-17 receptor E-like|IL-17RE-like', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49991811, end_position_on_the_genomic_accession=50013827, orientation='minus', exon_count=17, OMIM=[613414], no_hdr0=''),
    400954 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400954, CurrentID=0, Status='live', Symbol='EML6', Aliases=[], description='EMAP like 6', other_designations='echinoderm microtubule-associated protein-like 6|EMAP-6|echinoderm microtubule associated protein like 6', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=54723467, end_position_on_the_genomic_accession=54972908, orientation='plus', exon_count=46, OMIM=[], no_hdr0=''),
    400961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400961, CurrentID=0, Status='live', Symbol='PAIP2B', Aliases=[], description='poly(A) binding protein interacting protein 2B', other_designations='polyadenylate-binding protein-interacting protein 2B|PABP-interacting protein 2B|PAIP-2B', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=71182738, end_position_on_the_genomic_accession=71227110, orientation='minus', exon_count=6, OMIM=[611018], no_hdr0=''),
    400966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400966, CurrentID=0, Status='live', Symbol='RGPD1', Aliases=['RGP1', 'RGPD2', 'RanBP2L2', 'ranBP2L6'], description='RANBP2 like and GRIP domain containing 1', other_designations='RANBP2-like and GRIP domain-containing protein 1|RANBP2-like and GRIP domain-containing protein 1/2|ran-binding protein 2-like 2/6|ran-binding protein 2-like 6|ranBP2-like 2/6|ranBP2-like 6', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86913577, end_position_on_the_genomic_accession=87013976, orientation='plus', exon_count=30, OMIM=[612704], no_hdr0=''),
    400986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=400986, CurrentID=0, Status='live', Symbol='ANKRD36C', Aliases=[], description='ankyrin repeat domain 36C', other_designations='ankyrin repeat domain-containing protein 36C|protein immuno-reactive with anti-PTH polyclonal antibodies', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95848932, end_position_on_the_genomic_accession=95991824, orientation='minus', exon_count=89, OMIM=[], no_hdr0=''),
    401024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401024, CurrentID=0, Status='live', Symbol='FSIP2', Aliases=['SPGF34'], description='fibrous sheath interacting protein 2', other_designations='fibrous sheath-interacting protein 2', map_location='2q32.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=185738804, end_position_on_the_genomic_accession=185833290, orientation='plus', exon_count=23, OMIM=[615796], no_hdr0=''),
    401027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401027, CurrentID=0, Status='live', Symbol='C2orf66', Aliases=['IIDS6411', 'UNQ6411'], description='chromosome 2 open reading frame 66', other_designations='uncharacterized protein C2orf66', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=196804417, end_position_on_the_genomic_accession=196809355, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    401036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401036, CurrentID=0, Status='live', Symbol='ASB18', Aliases=['ASB-18'], description='ankyrin repeat and SOCS box containing 18', other_designations='ankyrin repeat and SOCS box protein 18', map_location='2q37.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=236193459, end_position_on_the_genomic_accession=236264406, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    401040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401040, CurrentID=0, Status='live', Symbol='LOC401040', Aliases=[], description='uncharacterized LOC401040', other_designations='uncharacterized protein LOC401040', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=239578396, end_position_on_the_genomic_accession=239586088, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    401067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401067, CurrentID=0, Status='live', Symbol='IQCF3', Aliases=[], description='IQ motif containing F3', other_designations='IQ domain-containing protein F3', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51826883, end_position_on_the_genomic_accession=51830856, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    401081 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401081, CurrentID=0, Status='live', Symbol='C3orf85', Aliases=[], description='chromosome 3 open reading frame 85', other_designations='uncharacterized protein C3orf85', map_location='3q13.13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=109136719, end_position_on_the_genomic_accession=109151401, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    401089 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401089, CurrentID=0, Status='live', Symbol='FOXL2NB', Aliases=['C3orf72'], description='FOXL2 neighbor', other_designations='FOXL2 neighbor protein|FLJ43329 protein', map_location='3q22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=138947217, end_position_on_the_genomic_accession=138953992, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    401097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401097, CurrentID=0, Status='live', Symbol='C3orf80', Aliases=[], description='chromosome 3 open reading frame 80', other_designations='uncharacterized membrane protein C3orf80', map_location='3q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=160225422, end_position_on_the_genomic_accession=160228213, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    401115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401115, CurrentID=0, Status='live', Symbol='C4orf48', Aliases=['CHR4_55'], description='chromosome 4 open reading frame 48', other_designations='neuropeptide-like protein C4orf48', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2035610, end_position_on_the_genomic_accession=2043970, orientation='plus', exon_count=9, OMIM=[614690], no_hdr0=''),
    401124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401124, CurrentID=0, Status='live', Symbol='DTHD1', Aliases=[], description='death domain containing 1', other_designations='death domain-containing protein 1', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=36281594, end_position_on_the_genomic_accession=36347511, orientation='plus', exon_count=13, OMIM=[616979], no_hdr0=''),
    401137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401137, CurrentID=0, Status='live', Symbol='PRR27', Aliases=['C4orf40'], description='proline rich 27', other_designations='proline-rich protein 27', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70154237, end_position_on_the_genomic_accession=70166609, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    401138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401138, CurrentID=0, Status='live', Symbol='AMTN', Aliases=['AI3B', 'UNQ689'], description='amelotin', other_designations='amelotin|RSTI689', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=70518569, end_position_on_the_genomic_accession=70532743, orientation='plus', exon_count=9, OMIM=[610912], no_hdr0=''),
    401145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401145, CurrentID=0, Status='live', Symbol='CCSER1', Aliases=['FAM190A'], description='coiled-coil serine rich protein 1', other_designations='serine-rich coiled-coil domain-containing protein 1|family with sequence similarity 190, member A|protein FAM190A', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=90127394, end_position_on_the_genomic_accession=91605295, orientation='plus', exon_count=32, OMIM=[618934], no_hdr0=''),
    401152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401152, CurrentID=0, Status='live', Symbol='C4orf3', Aliases=['ALN', 'HCVFTP1'], description='chromosome 4 open reading frame 3', other_designations='uncharacterized protein C4orf3|HCV F-transactivated protein 1|another-regulin|hepatitis C virus F protein-transactivated protein 1', map_location='4q26', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=119296419, end_position_on_the_genomic_accession=119304445, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    401190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401190, CurrentID=0, Status='live', Symbol='RGS7BP', Aliases=['R7BP'], description='regulator of G protein signaling 7 binding protein', other_designations='regulator of G-protein signaling 7-binding protein|R7 family-binding protein', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=64505947, end_position_on_the_genomic_accession=64612330, orientation='plus', exon_count=7, OMIM=[610890], no_hdr0=''),
    401207 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401207, CurrentID=0, Status='live', Symbol='C5orf63', Aliases=['YDR286C'], description='chromosome 5 open reading frame 63', other_designations='glutaredoxin-like protein C5orf63|glutaredoxin-like protein YDR286C homolog', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127042562, end_position_on_the_genomic_accession=127073502, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    401236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401236, CurrentID=0, Status='live', Symbol='STMND1', Aliases=[], description='stathmin domain containing 1', other_designations='stathmin domain-containing protein 1', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=17102050, end_position_on_the_genomic_accession=17131378, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    401250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401250, CurrentID=0, Status='live', Symbol='MCCD1', Aliases=[], description='mitochondrial coiled-coil domain 1', other_designations='mitochondrial coiled-coil domain protein 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31528962, end_position_on_the_genomic_accession=31530232, orientation='plus', exon_count=2, OMIM=[609624], no_hdr0=''),
    401251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401251, CurrentID=0, Status='live', Symbol='SAPCD1', Aliases=['C6orf26', 'NG23'], description='suppressor APC domain containing 1', other_designations='suppressor APC domain-containing protein 1|protein G7d', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31762996, end_position_on_the_genomic_accession=31764850, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    401258 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401258, CurrentID=0, Status='live', Symbol='RAB44', Aliases=['RASD3', 'RASL13', 'dJ431A14.3'], description='RAB44, member RAS oncogene family', other_designations='ras-related protein Rab-44|RAS-like, family 13|RASD family, member 3', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=36697808, end_position_on_the_genomic_accession=36733184, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    401262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401262, CurrentID=0, Status='live', Symbol='CRIP3', Aliases=['CRP-3', 'TLP', 'TLP-A', 'h6LIMo'], description='cysteine rich protein 3', other_designations='cysteine-rich protein 3|chromosome 6 LIM domain only protein|thymus LIM protein TLP-A', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=43305472, end_position_on_the_genomic_accession=43308826, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    401265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401265, CurrentID=0, Status='live', Symbol='KLHL31', Aliases=['BKLHD6', 'KBTBD1', 'KLHL', 'bA345L23.2'], description='kelch like family member 31', other_designations='kelch-like protein 31|BTB and kelch domain-containing protein 6|kelch repeat and BTB (POZ) domain containing 1|kelch repeat and BTB domain-containing protein 1|kelch-like protein KLHL', map_location='6p12.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=53647916, end_position_on_the_genomic_accession=53665854, orientation='minus', exon_count=4, OMIM=[610749], no_hdr0=''),
    401387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401387, CurrentID=0, Status='live', Symbol='LRRD1', Aliases=[], description='leucine rich repeats and death domain containing 1', other_designations='leucine-rich repeat and death domain-containing protein 1|leucine-rich repeat and death domain-containing protein LOC401387', map_location='7q21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=92141643, end_position_on_the_genomic_accession=92179142, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    401397 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401397, CurrentID=0, Status='live', Symbol='SMIM30', Aliases=['LINC00998'], description='small integral membrane protein 30', other_designations='small integral membrane protein 30|long intergenic non-protein coding RNA 998|putative transmembrane protein LINC00998', map_location='7q31.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=113116718, end_position_on_the_genomic_accession=113118554, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    401399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401399, CurrentID=0, Status='live', Symbol='PRRT4', Aliases=[], description='proline rich transmembrane protein 4', other_designations='proline-rich transmembrane protein 4', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128350325, end_position_on_the_genomic_accession=128362067, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    401409 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401409, CurrentID=0, Status='live', Symbol='RAB19', Aliases=['RAB19B'], description='RAB19, member RAS oncogene family', other_designations='ras-related protein Rab-19|GTP-binding protein RAB19B', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=140403740, end_position_on_the_genomic_accession=140427974, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    401427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401427, CurrentID=0, Status='live', Symbol='OR2A7', Aliases=['HSDJ0798C17', 'OR2A21'], description='olfactory receptor family 2 subfamily A member 7', other_designations='olfactory receptor 2A7|olfactory receptor OR7-18|olfactory receptor OR7-20|olfactory receptor, family 2, subfamily A, member 21', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144257663, end_position_on_the_genomic_accession=144264792, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    401447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401447, CurrentID=0, Status='live', Symbol='USP17L1', Aliases=['USP17L1P'], description='ubiquitin specific peptidase 17 like family member 1', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 1|deubiquitinating enzyme 17-like protein 1|putative ubiquitin carboxyl-terminal hydrolase 17-like protein 1|ubiquitin thioesterase 17-like protein 1|ubiquitin-specific-processing protease 17-like protein 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7332387, end_position_on_the_genomic_accession=7333979, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    401466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401466, CurrentID=0, Status='live', Symbol='RBIS', Aliases=['C8orf59'], description='ribosomal biogenesis factor', other_designations='ribosomal biogenesis factor|ribosome biogenesis factor identified in screen|uncharacterized protein C8orf59', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85214048, end_position_on_the_genomic_accession=85221079, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    401474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401474, CurrentID=0, Status='live', Symbol='SAMD12', Aliases=[], description='sterile alpha motif domain containing 12', other_designations='sterile alpha motif domain-containing protein 12|SAM domain-containing protein 12', map_location='8q24.11-q24.12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=118131825, end_position_on_the_genomic_accession=118621963, orientation='minus', exon_count=8, OMIM=[618073], no_hdr0=''),
    401494 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401494, CurrentID=0, Status='live', Symbol='HACD4', Aliases=['PTPLAD2'], description='3-hydroxyacyl-CoA dehydratase 4', other_designations='very-long-chain (3R)-3-hydroxyacyl-CoA dehydratase 4|protein tyrosine phosphatase-like A domain containing 2|protein tyrosine phosphatase-like protein PTPLAD2|protein-tyrosine phosphatase-like A domain-containing protein 2|very-long-chain (3R)-3-hydroxyacyl-[acyl-carrier protein] dehydratase 4', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=20999509, end_position_on_the_genomic_accession=21031712, orientation='minus', exon_count=10, OMIM=[615941], no_hdr0=''),
    401498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401498, CurrentID=0, Status='live', Symbol='TMEM215', Aliases=[], description='transmembrane protein 215', other_designations='transmembrane protein 215', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32783499, end_position_on_the_genomic_accession=32789201, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    401505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401505, CurrentID=0, Status='live', Symbol='TOMM5', Aliases=['C9orf105', 'Tom5', 'bA613M10.3'], description='translocase of outer mitochondrial membrane 5', other_designations='mitochondrial import receptor subunit TOM5 homolog|mitochondrial outer membrane protein TOM5|translocase of outer mitochondrial membrane 5 homolog', map_location='9p13.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=37588413, end_position_on_the_genomic_accession=37592597, orientation='minus', exon_count=2, OMIM=[616169], no_hdr0=''),
    401541 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401541, CurrentID=0, Status='live', Symbol='CENPP', Aliases=['CENP-P'], description='centromere protein P', other_designations='centromere protein P', map_location='9q22.31', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=92325457, end_position_on_the_genomic_accession=92620529, orientation='plus', exon_count=13, OMIM=[611505], no_hdr0=''),
    401546 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401546, CurrentID=0, Status='live', Symbol='C9orf152', Aliases=['bA470J20.2'], description='chromosome 9 open reading frame 152', other_designations='uncharacterized protein C9orf152', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=110199561, end_position_on_the_genomic_accession=110208159, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    401548 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401548, CurrentID=0, Status='live', Symbol='SNX30', Aliases=['ATG24A'], description='sorting nexin family member 30', other_designations='sorting nexin-30', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=112749723, end_position_on_the_genomic_accession=112875847, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    401551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401551, CurrentID=0, Status='live', Symbol='WDR38', Aliases=[], description='WD repeat domain 38', other_designations='WD repeat-containing protein 38', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=124853460, end_position_on_the_genomic_accession=124857884, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    401562 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401562, CurrentID=0, Status='live', Symbol='LCNL1', Aliases=[], description='lipocalin like 1', other_designations='lipocalin-like 1 protein', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136982993, end_position_on_the_genomic_accession=136985758, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    401565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401565, CurrentID=0, Status='live', Symbol='FAM166A', Aliases=['HSD46'], description='family with sequence similarity 166 member A', other_designations='protein FAM166A', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137243585, end_position_on_the_genomic_accession=137251313, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    401612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401612, CurrentID=0, Status='live', Symbol='SLC25A53', Aliases=['MCART6'], description='solute carrier family 25 member 53', other_designations='solute carrier family 25 member 53|mitochondrial carrier triple repeat protein 6', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104099214, end_position_on_the_genomic_accession=104157009, orientation='minus', exon_count=6, OMIM=[300941], no_hdr0=''),
    401613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401613, CurrentID=0, Status='live', Symbol='SERTM2', Aliases=['DKFZp686D0853', 'LINC00890'], description='serine rich and transmembrane domain containing 2', other_designations='serine-rich and transmembrane domain-containing 2|long intergenic non-protein coding RNA 890', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111511645, end_position_on_the_genomic_accession=111522399, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    401647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401647, CurrentID=0, Status='live', Symbol='GOLGA7B', Aliases=['C10orf132', 'C10orf133', 'bA451M19.3', 'bA459F3.4'], description='golgin A7 family member B', other_designations='golgin subfamily A member 7B|golgi autoantigen, golgin subfamily a, 7B', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97849843, end_position_on_the_genomic_accession=97871578, orientation='plus', exon_count=5, OMIM=[614189], no_hdr0=''),
    401665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401665, CurrentID=0, Status='live', Symbol='OR51T1', Aliases=['OR11-26'], description='olfactory receptor family 51 subfamily T member 1', other_designations='olfactory receptor 51T1|olfactory receptor OR11-26', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4881900, end_position_on_the_genomic_accession=4882883, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    401666 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401666, CurrentID=0, Status='live', Symbol='OR51A4', Aliases=[], description='olfactory receptor family 51 subfamily A member 4', other_designations='olfactory receptor 51A4', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4942831, end_position_on_the_genomic_accession=4947605, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    401667 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401667, CurrentID=0, Status='live', Symbol='OR51A2', Aliases=[], description='olfactory receptor family 51 subfamily A member 2', other_designations='olfactory receptor 51A2', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=4954772, end_position_on_the_genomic_accession=4955713, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    401720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401720, CurrentID=0, Status='live', Symbol='FIGNL2', Aliases=[], description='fidgetin like 2', other_designations='fidgetin-like protein 2|putative fidgetin-like protein 2', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51817892, end_position_on_the_genomic_accession=51848718, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    401934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401934, CurrentID=0, Status='live', Symbol='RNF223', Aliases=[], description='ring finger protein 223', other_designations='RING finger protein 223', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1070967, end_position_on_the_genomic_accession=1074306, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    401944 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401944, CurrentID=0, Status='live', Symbol='LDLRAD2', Aliases=[], description='low density lipoprotein receptor class A domain containing 2', other_designations='low-density lipoprotein receptor class A domain-containing protein 2|low density lipoprotein receptor A domain containing 2', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=21812265, end_position_on_the_genomic_accession=21825225, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    401992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401992, CurrentID=0, Status='live', Symbol='OR2T2', Aliases=['OR1-43P', 'OR2T2'], description='olfactory receptor family 2 subfamily T member 2', other_designations='olfactory receptor 2T2|olfactory receptor OR1-43|olfactory receptor, family 2, subfamily T, member 2 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248445637, end_position_on_the_genomic_accession=248455725, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    401993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401993, CurrentID=0, Status='live', Symbol='OR2T5', Aliases=['OR1-62'], description='olfactory receptor family 2 subfamily T member 5', other_designations='olfactory receptor 2T5|olfactory receptor OR1-62', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248488589, end_position_on_the_genomic_accession=248491113, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    401994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=401994, CurrentID=0, Status='live', Symbol='OR14I1', Aliases=['OR5BU1', 'OR5BU1P'], description='olfactory receptor family 14 subfamily I member 1', other_designations='olfactory receptor 14I1|olfactory receptor 5BU1|olfactory receptor, family 5, subfamily BU, member 1 pseudogene', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248678140, end_position_on_the_genomic_accession=248685488, orientation='minus', exon_count=2, OMIM=[618516], no_hdr0=''),
    402055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402055, CurrentID=0, Status='live', Symbol='SRRD', Aliases=['HC/HCC', 'SRR1L'], description='SRR1 domain containing', other_designations='SRR1-like protein|SRR1 domain-containing protein|hepatocellular carcinoma complicating hemochromatosis', map_location='22q12.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=26483867, end_position_on_the_genomic_accession=26494658, orientation='plus', exon_count=7, OMIM=[602254], no_hdr0=''),
    402117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402117, CurrentID=0, Status='live', Symbol='VWC2L', Aliases=[], description='von Willebrand factor C domain containing 2 like', other_designations='von Willebrand factor C domain-containing protein 2-like|brorin-like|von Willebrand factor C domain containing protein 2 like', map_location='2q34-q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=214411054, end_position_on_the_genomic_accession=214578976, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    402135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402135, CurrentID=0, Status='live', Symbol='OR5K2', Aliases=['OR3-9'], description='olfactory receptor family 5 subfamily K member 2', other_designations='olfactory receptor 5K2|olfactory receptor OR3-9', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98497681, end_position_on_the_genomic_accession=98498631, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    402160 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402160, CurrentID=0, Status='live', Symbol='CFAP99', Aliases=[], description='cilia and flagella associated protein 99', other_designations='cilia- and flagella-associated protein 99', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=2418892, end_position_on_the_genomic_accession=2463002, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    402317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402317, CurrentID=0, Status='live', Symbol='OR2A42', Aliases=[], description='olfactory receptor family 2 subfamily A member 42', other_designations='olfactory receptor 2A1/2A42|olfactory receptor OR7-16|olfactory receptor OR7-19|olfactory receptor, family 2, subfamily A, member 1', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144228244, end_position_on_the_genomic_accession=144239605, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    402381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402381, CurrentID=0, Status='live', Symbol='SOHLH1', Aliases=['C9orf157', 'NOHLH', 'ODG5', 'SPATA27', 'SPGF32', 'TEB2', 'bA100C15.3', 'bHLHe80'], description='spermatogenesis and oogenesis specific basic helix-loop-helix 1', other_designations='spermatogenesis- and oogenesis-specific basic helix-loop-helix-containing protein 1|newborn ovary helix loop helix|spermatogenesis associated 27', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135691862, end_position_on_the_genomic_accession=135702112, orientation='minus', exon_count=11, OMIM=[610224], no_hdr0=''),
    402415 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402415, CurrentID=0, Status='live', Symbol='XKRX', Aliases=['XKR2', 'XPLAC', 'XRG2'], description='XK related X-linked', other_designations='XK-related protein 2|X Kell blood group precursor-related, X-linked|X-linked Kx blood group related, X-linked|XK, Kell blood group complex subunit-related, X-linked|membrane protein XPLAC', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=100886919, end_position_on_the_genomic_accession=100957401, orientation='minus', exon_count=7, OMIM=[300684], no_hdr0=''),
    402569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402569, CurrentID=0, Status='live', Symbol='KPNA7', Aliases=['IPOA8'], description='karyopherin subunit alpha 7', other_designations='importin subunit alpha-8|karyopherin alpha 7', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99145467, end_position_on_the_genomic_accession=99219417, orientation='minus', exon_count=15, OMIM=[614107], no_hdr0=''),
    402573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402573, CurrentID=0, Status='live', Symbol='C7orf61', Aliases=[], description='chromosome 7 open reading frame 61', other_designations='uncharacterized protein C7orf61', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100456620, end_position_on_the_genomic_accession=100464260, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    402635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402635, CurrentID=0, Status='live', Symbol='GRIFIN', Aliases=[], description='galectin-related inter-fiber protein', other_designations='grifin|putative grifin', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=2474728, end_position_on_the_genomic_accession=2476398, orientation='minus', exon_count=5, OMIM=[619187], no_hdr0=''),
    402665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402665, CurrentID=0, Status='live', Symbol='IGLON5', Aliases=[], description='IgLON family member 5', other_designations='igLON family member 5|Ig-like domain-containing protein ENSP00000270642|hCG1651476', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51311644, end_position_on_the_genomic_accession=51330891, orientation='plus', exon_count=8, OMIM=[618861], no_hdr0=''),
    402682 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402682, CurrentID=0, Status='live', Symbol='UFSP1', Aliases=['UFSP'], description='UFM1 specific peptidase 1 (inactive)', other_designations='inactive Ufm1-specific protease 1|UFM1-specific peptidase 1 (non-functional)', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100888721, end_position_on_the_genomic_accession=100889715, orientation='minus', exon_count=1, OMIM=[611481], no_hdr0=''),
    402778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=402778, CurrentID=0, Status='live', Symbol='IFITM10', Aliases=['DSPA3'], description='interferon induced transmembrane protein 10', other_designations='interferon-induced transmembrane protein 10|dispanin subfamily A member 3', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1732406, end_position_on_the_genomic_accession=1750595, orientation='minus', exon_count=3, OMIM=[618293], no_hdr0=''),
    403239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403239, CurrentID=0, Status='live', Symbol='OR2T27', Aliases=[], description='olfactory receptor family 2 subfamily T member 27', other_designations='olfactory receptor 2T27|olfactory receptor OR1-67', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248649838, end_position_on_the_genomic_accession=248655528, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    403244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403244, CurrentID=0, Status='live', Symbol='OR2T35', Aliases=[], description='olfactory receptor family 2 subfamily T member 35', other_designations='olfactory receptor 2T35|olfactory receptor OR1-66', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248636356, end_position_on_the_genomic_accession=248645278, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    403253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403253, CurrentID=0, Status='live', Symbol='OR4A47', Aliases=['OR11-113'], description='olfactory receptor family 4 subfamily A member 47', other_designations='olfactory receptor 4A47|olfactory receptor OR11-113', map_location='11p11.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=48488793, end_position_on_the_genomic_accession=48489722, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403257, CurrentID=0, Status='live', Symbol='OR4C45', Aliases=[], description='olfactory receptor family 4 subfamily C member 45 (gene/pseudogene)', other_designations='olfactory receptor 4C45|olfactory receptor, family 4, subfamily C, member 45', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=50032874, end_position_on_the_genomic_accession=50033794, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403273, CurrentID=0, Status='live', Symbol='OR5H14', Aliases=[], description='olfactory receptor family 5 subfamily H member 14', other_designations='olfactory receptor 5H14|seven transmembrane helix receptor', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98147479, end_position_on_the_genomic_accession=98156614, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    403274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403274, CurrentID=0, Status='live', Symbol='OR5H15', Aliases=[], description='olfactory receptor family 5 subfamily H member 15', other_designations='olfactory receptor 5H15', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98166696, end_position_on_the_genomic_accession=98169774, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    403277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403277, CurrentID=0, Status='live', Symbol='OR5K3', Aliases=[], description='olfactory receptor family 5 subfamily K member 3', other_designations='olfactory receptor 5K3', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98390666, end_position_on_the_genomic_accession=98391631, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403278, CurrentID=0, Status='live', Symbol='OR5K4', Aliases=[], description='olfactory receptor family 5 subfamily K member 4', other_designations='olfactory receptor 5K4', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=98353854, end_position_on_the_genomic_accession=98354819, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403282, CurrentID=0, Status='live', Symbol='OR6C65', Aliases=[], description='olfactory receptor family 6 subfamily C member 65', other_designations='olfactory receptor 6C65', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55400529, end_position_on_the_genomic_accession=55401467, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403284, CurrentID=0, Status='live', Symbol='OR6C68', Aliases=[], description='olfactory receptor family 6 subfamily C member 68', other_designations='olfactory receptor 6C68', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55492378, end_position_on_the_genomic_accession=55493316, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    403313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403313, CurrentID=0, Status='live', Symbol='PLPP6', Aliases=['PDP1', 'PPAPDC2', 'PSDP', 'bA6J24.6'], description='phospholipid phosphatase 6', other_designations='phospholipid phosphatase 6|PPAP2 domain-containing protein 2|phosphatidic acid phosphatase type 2 domain containing 2|phosphatidic acid phosphatase type 2 domain-containing protein 2|polyisoprenoid diphosphate phosphatase type 1|presqualene diphosphate phosphatase', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=4662294, end_position_on_the_genomic_accession=4665258, orientation='plus', exon_count=1, OMIM=[611666], no_hdr0=''),
    403314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403314, CurrentID=0, Status='live', Symbol='APOBEC4', Aliases=['C1orf169'], description='apolipoprotein B mRNA editing enzyme catalytic polypeptide like 4', other_designations='putative C->U-editing enzyme APOBEC-4|apolipoprotein B mRNA editing enzyme, catalytic polypeptide-like 4 (putative)', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=183646275, end_position_on_the_genomic_accession=183653316, orientation='minus', exon_count=2, OMIM=[609908], no_hdr0=''),
    403341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=403341, CurrentID=0, Status='live', Symbol='ZBTB34', Aliases=['ZNF918'], description='zinc finger and BTB domain containing 34', other_designations='zinc finger and BTB domain-containing protein 34', map_location='9q33.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=126860639, end_position_on_the_genomic_accession=126885878, orientation='plus', exon_count=4, OMIM=[611692], no_hdr0=''),
    404037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404037, CurrentID=0, Status='live', Symbol='HAPLN4', Aliases=['BRAL2'], description='hyaluronan and proteoglycan link protein 4', other_designations='hyaluronan and proteoglycan link protein 4|brain link protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19254756, end_position_on_the_genomic_accession=19262804, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    404093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404093, CurrentID=0, Status='live', Symbol='CUEDC1', Aliases=[], description='CUE domain containing 1', other_designations='CUE domain-containing protein 1', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57861243, end_position_on_the_genomic_accession=57955412, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    404203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404203, CurrentID=0, Status='live', Symbol='SPINK6', Aliases=['BUSI2', 'UNQ844'], description='serine peptidase inhibitor Kazal type 6', other_designations='serine protease inhibitor Kazal-type 6|acrosin inhibitor|kallikrein inhibitor|protease inhibitor H', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148202778, end_position_on_the_genomic_accession=148215137, orientation='plus', exon_count=5, OMIM=[615868], no_hdr0=''),
    404217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404217, CurrentID=0, Status='live', Symbol='CTXN1', Aliases=['CTXN'], description='cortexin 1', other_designations='cortexin-1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7924491, end_position_on_the_genomic_accession=7926135, orientation='minus', exon_count=2, OMIM=[600135], no_hdr0=''),
    404220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404220, CurrentID=0, Status='live', Symbol='C6orf201', Aliases=['dJ1013A10.5'], description='chromosome 6 open reading frame 201', other_designations='uncharacterized protein C6orf201|protein MGC87625', map_location='6p25.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=4079209, end_position_on_the_genomic_accession=4130951, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    404281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404281, CurrentID=0, Status='live', Symbol='YY2', Aliases=['ZNF631'], description='YY2 transcription factor', other_designations='transcription factor YY2|transcription factor yin yang 2|yin and yang 2|zinc finger protein 631', map_location='Xp22.12', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=21855987, end_position_on_the_genomic_accession=21858740, orientation='plus', exon_count=1, OMIM=[300570], no_hdr0=''),
    404550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404550, CurrentID=0, Status='live', Symbol='C16orf74', Aliases=[], description='chromosome 16 open reading frame 74', other_designations='uncharacterized protein C16orf74|hypothetical protein 1|hypothetical protein 2|hypothetical protein 3', map_location='16q24.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=85707517, end_position_on_the_genomic_accession=85751096, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    404552 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404552, CurrentID=0, Status='live', Symbol='SCGB1D4', Aliases=['IIS'], description='secretoglobin family 1D member 4', other_designations='secretoglobin family 1D member 4|IFN-gamma inducible SCGB (IIS)|IFN-gamma-inducible secretoglobin', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62296281, end_position_on_the_genomic_accession=62299075, orientation='minus', exon_count=3, OMIM=[615062], no_hdr0=''),
    404636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404636, CurrentID=0, Status='live', Symbol='DENND10', Aliases=['FAM45A'], description='DENN domain containing 10', other_designations='DENN domain-containing protein 10|family with sequence similarity 45 member A|protein FAM45A', map_location='10q26.11', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=119104082, end_position_on_the_genomic_accession=119137984, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    404672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404672, CurrentID=0, Status='live', Symbol='GTF2H5', Aliases=['C6orf175', 'TFB5', 'TFIIH', 'TGF2H5', 'TTD', 'TTD-A', 'TTD3', 'TTDA', 'bA120J8.2'], description='general transcription factor IIH subunit 5', other_designations='general transcription factor IIH subunit 5|TFB5 ortholog|TFIIH basal transcription factor complex TTD-A subunit|TFIIH basal transcription factor complex TTDA subunit|TFIIH subunit p8|general transcription factor IIH, polypeptide 5', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=158168316, end_position_on_the_genomic_accession=158199344, orientation='plus', exon_count=3, OMIM=[608780], no_hdr0=''),
    404734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404734, CurrentID=0, Status='live', Symbol='ANKHD1-EIF4EBP3', Aliases=['MASK-BP3', 'MASK-BP3ARF'], description='ANKHD1-EIF4EBP3 readthrough', other_designations='ANKHD1-EIF4EBP3 protein|MASK-4E-BP3 alternate reading frame', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140401833, end_position_on_the_genomic_accession=140549576, orientation='plus', exon_count=36, OMIM=[], no_hdr0=''),
    404785 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=404785, CurrentID=0, Status='live', Symbol='POTEG', Aliases=['A26C2', 'ACTBL1', 'CT104.4', 'POTE-14', 'POTE14', 'POTE14alpha', 'POTE22'], description='POTE ankyrin domain family member G', other_designations='POTE ankyrin domain family member G|ANKRD26-like family C member 2|cancer/testis antigen family 104, member 4|prostate, ovary, testis-expressed protein on chromosome 14|protein expressed in prostate, ovary, testis, and placenta 14', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19402486, end_position_on_the_genomic_accession=19434341, orientation='minus', exon_count=12, OMIM=[608916], no_hdr0=''),
    405753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=405753, CurrentID=0, Status='live', Symbol='DUOXA2', Aliases=['SIMNIPHOM', 'TDH5'], description='dual oxidase maturation factor 2', other_designations='dual oxidase maturation factor 2', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45114321, end_position_on_the_genomic_accession=45118421, orientation='plus', exon_count=6, OMIM=[612772], no_hdr0=''),
    405754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=405754, CurrentID=0, Status='live', Symbol='ERVFRD-1', Aliases=['ERVFRDE1', 'GLLL6191', 'HERV-FRD', 'HERV-W/FRD', 'UNQ6191', 'envFRD'], description='endogenous retrovirus group FRD member 1, envelope', other_designations='syncytin-2|HERV-FRD provirus ancestral Env polyprotein|HERV-FRD_6p24.1 provirus ancestral Env polyprotein|endogenous retrovirus group FRD, member 1|envelope polyprotein|syncytin 2', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=11102489, end_position_on_the_genomic_accession=11111725, orientation='minus', exon_count=2, OMIM=[610524], no_hdr0=''),
    407738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=407738, CurrentID=0, Status='live', Symbol='TAFA1', Aliases=['FAM19A1', 'TAFA-1'], description='TAFA chemokine like family member 1', other_designations='chemokine-like protein TAFA-1|family with sequence similarity 19 (chemokine (C-C motif)-like), member A1|family with sequence similarity 19 member A1, C-C motif chemokine like|protein FAM19A1', map_location='3p14.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=67991544, end_position_on_the_genomic_accession=68546056, orientation='plus', exon_count=6, OMIM=[617495], no_hdr0=''),
    407977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=407977, CurrentID=0, Status='live', Symbol='TNFSF12-TNFSF13', Aliases=['TWE-PRIL'], description='TNFSF12-TNFSF13 readthrough', other_designations='TNFSF12-TNFSF13 protein|tumor necrosis factor (ligand) superfamily, member 12-member 13', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7549058, end_position_on_the_genomic_accession=7561601, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    408050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=408050, CurrentID=0, Status='live', Symbol='NOMO3', Aliases=['Nomo'], description='NODAL modulator 3', other_designations='nodal modulator 3|pM5 protein 3|pM5 protein, middle copy', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=16232528, end_position_on_the_genomic_accession=16294811, orientation='plus', exon_count=32, OMIM=[609159], no_hdr0=''),
    408187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=408187, CurrentID=0, Status='live', Symbol='SPINK14', Aliases=['SPINK5L2'], description='serine peptidase inhibitor Kazal type 14 (putative)', other_designations='serine protease inhibitor Kazal-type 14|Kazal type serine protease inhibitor 5-like 2', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148168546, end_position_on_the_genomic_accession=148176076, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    408263 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=408263, CurrentID=0, Status='live', Symbol='FNDC9', Aliases=['C5orf40'], description='fibronectin type III domain containing 9', other_designations='fibronectin type III domain-containing protein 9|fibronectin type-III domain-containing protein C5orf40', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157341598, end_position_on_the_genomic_accession=157345677, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    414059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414059, CurrentID=0, Status='live', Symbol='TBC1D3B', Aliases=['PRC17', 'TBC1D3I', 'TBC1D3L'], description='TBC1 domain family member 3B', other_designations='TBC1 domain family member 3B|Rab GTPase-activating protein PRC17 duplicate|TBC1 domain family member 3B/I|TBC1 domain family, member 3-like|TBC1 domain family, member 3I|prostate cancer gene 17 duplicate', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36165683, end_position_on_the_genomic_accession=36176636, orientation='minus', exon_count=14, OMIM=[610144], no_hdr0=''),
    414060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414060, CurrentID=0, Status='live', Symbol='TBC1D3C', Aliases=['PRC17', 'TBC1D3', 'TBC1D3A', 'TBC1D3D'], description='TBC1 domain family member 3C', other_designations='TBC1 domain family member 3C|Prostate cancer gene 17 protein|Protein TRE17-alpha|Rab GTPase-activating protein PRC17|TBC1 domain family member 3|TBC1 domain family member 3C-like protein ENSP00000341742|TBC1 domain family member 3C/3D', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38057693, end_position_on_the_genomic_accession=38068634, orientation='minus', exon_count=15, OMIM=[610806], no_hdr0=''),
    414061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414061, CurrentID=0, Status='live', Symbol='DNAJB3', Aliases=['HCG3'], description='DnaJ heat shock protein family (Hsp40) member B3', other_designations='dnaJ homolog subfamily B member 3|DnaJ (Hsp40) homolog, subfamily B, member 3', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=233742750, end_position_on_the_genomic_accession=233743998, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    414062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414062, CurrentID=0, Status='live', Symbol='CCL3L3', Aliases=['464.2', 'D17S1718', 'G0S19-2', 'LD78', 'LD78BETA', 'SCYA3L', 'SCYA3L1'], description='C-C motif chemokine ligand 3 like 3', other_designations='C-C motif chemokine 3-like 1|G0/G1 switch regulatory protein 19-2|LD78-beta(1-70)|chemokine (C-C motif) ligand 3-like 3|chemokine (C-C motif) ligand 3-like, centromeric|small inducible cytokine A3-like 1|tonsillar lymphocyte LD78 beta protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36194869, end_position_on_the_genomic_accession=36196758, orientation='minus', exon_count=3, OMIM=[609468], no_hdr0=''),
    414149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414149, CurrentID=0, Status='live', Symbol='ACBD7', Aliases=['bA455B2.2'], description='acyl-CoA binding domain containing 7', other_designations='acyl-CoA-binding domain-containing protein 7|acyl-Coenzyme A binding domain containing 7', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=15075475, end_position_on_the_genomic_accession=15088776, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    414152 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414152, CurrentID=0, Status='live', Symbol='C10orf105', Aliases=[], description='chromosome 10 open reading frame 105', other_designations='uncharacterized protein C10orf105', map_location='10q22.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=71711701, end_position_on_the_genomic_accession=71737850, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    414157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414157, CurrentID=0, Status='live', Symbol='C10orf62', Aliases=['bA548K23.1'], description='chromosome 10 open reading frame 62', other_designations='uncharacterized protein C10orf62', map_location='10q24.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=97589721, end_position_on_the_genomic_accession=97590934, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    414189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414189, CurrentID=0, Status='live', Symbol='AGAP6', Aliases=['AGAP-6', 'CTGLF3'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 6', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 6|centaurin-gamma-like family member 3', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49988368, end_position_on_the_genomic_accession=50010499, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    414301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414301, CurrentID=0, Status='live', Symbol='DDI1', Aliases=[], description='DNA damage inducible 1 homolog 1', other_designations='protein DDI1 homolog 1|DDI1, DNA-damage inducible 1, homolog 1|DNA-damage inducible protein 1', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=104036640, end_position_on_the_genomic_accession=104039196, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    414325 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414325, CurrentID=0, Status='live', Symbol='DEFB103A', Aliases=['BD-3', 'DEFB-3', 'DEFB103', 'DEFB3', 'HBD3', 'HBP-3', 'HBP3'], description='defensin beta 103A', other_designations='beta-defensin 103|beta-defensin 3|defensin, beta 103|defensin-like protein', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7881392, end_position_on_the_genomic_accession=7882663, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    414328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414328, CurrentID=0, Status='live', Symbol='IDNK', Aliases=['C9orf103', 'bA522I20.2', 'hGntK'], description='IDNK gluconokinase', other_designations='probable gluconokinase|glucokinase-like protein|gluconate kinase|gluconokinase-like protein|idnK, gluconokinase homolog', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83622324, end_position_on_the_genomic_accession=83644128, orientation='plus', exon_count=10, OMIM=[611343], no_hdr0=''),
    414332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414332, CurrentID=0, Status='live', Symbol='LCN10', Aliases=[], description='lipocalin 10', other_designations='epididymal-specific lipocalin-10', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136738170, end_position_on_the_genomic_accession=136742940, orientation='minus', exon_count=6, OMIM=[612904], no_hdr0=''),
    414899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414899, CurrentID=0, Status='live', Symbol='BLID', Aliases=['BRCC2'], description='BH3-like motif containing, cell death inducer', other_designations='BH3-like motif-containing cell death inducer|breast cancer cell 2|breast cancer cell protein 2', map_location='11q24.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=122115340, end_position_on_the_genomic_accession=122116215, orientation='minus', exon_count=1, OMIM=[608853], no_hdr0=''),
    414918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414918, CurrentID=0, Status='live', Symbol='DENND6B', Aliases=['AFI1B', 'FAM116B'], description='DENN domain containing 6B', other_designations='protein DENND6B|DENN domain-containing protein 6B|DENN/MADD domain containing 6B|family with sequence similarity 116, member B|protein FAM116B', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50309030, end_position_on_the_genomic_accession=50327016, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    414919 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=414919, CurrentID=0, Status='live', Symbol='C8orf82', Aliases=[], description='chromosome 8 open reading frame 82', other_designations='UPF0598 protein C8orf82', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144525733, end_position_on_the_genomic_accession=144529111, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    415116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=415116, CurrentID=0, Status='live', Symbol='PIM3', Aliases=['pim-3'], description='Pim-3 proto-oncogene, serine/threonine kinase', other_designations='serine/threonine-protein kinase pim-3|pim-3 oncogene|serine/threonine kinase Pim-3', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49960772, end_position_on_the_genomic_accession=49964072, orientation='plus', exon_count=6, OMIM=[610580], no_hdr0=''),
    415117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=415117, CurrentID=0, Status='live', Symbol='STX19', Aliases=[], description='syntaxin 19', other_designations='syntaxin-19', map_location='3q11.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=94014365, end_position_on_the_genomic_accession=94029281, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    425054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=425054, CurrentID=0, Status='live', Symbol='VCX3B', Aliases=['VCX-C', 'VCXC'], description='variable charge X-linked 3B', other_designations='variable charge X-linked protein 3B|variably charged protein X-C', map_location='Xp22.31', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=8464830, end_position_on_the_genomic_accession=8466510, orientation='plus', exon_count=3, OMIM=[300981], no_hdr0=''),
    431704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=431704, CurrentID=0, Status='live', Symbol='RGS21', Aliases=[], description='regulator of G protein signaling 21', other_designations='regulator of G-protein signaling 21|regulator of G-protein signalling 21', map_location='1q31.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=192316992, end_position_on_the_genomic_accession=192367285, orientation='plus', exon_count=5, OMIM=[612407], no_hdr0=''),
    431705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=431705, CurrentID=0, Status='live', Symbol='ASTL', Aliases=['SAS1B'], description='astacin like metalloendopeptidase', other_designations='astacin-like metalloendopeptidase|ZP2-proteinase|astacin-like metallo-endopeptidase (M12 family)|astacin-like metalloendopeptidase (M12 family)|oocyte astacin|ovastacin|sperm acrosomal SLLP1 binding', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=96122817, end_position_on_the_genomic_accession=96143059, orientation='minus', exon_count=10, OMIM=[608860], no_hdr0=''),
    431707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=431707, CurrentID=0, Status='live', Symbol='LHX8', Aliases=['LHX7'], description='LIM homeobox 8', other_designations='LIM/homeobox protein Lhx8|LIM-homeodomain protein Lhx8', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=75128434, end_position_on_the_genomic_accession=75199454, orientation='plus', exon_count=12, OMIM=[604425], no_hdr0=''),
    432355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=432355, CurrentID=0, Status='live', Symbol='SLURP2', Aliases=['SLURP-2'], description='secreted LY6/PLAUR domain containing 2', other_designations='secreted Ly-6/uPAR domain-containing protein 2|secreted LY6/PLAUR domain-containing protein 2|secreted Ly-6/uPAR-related protein 2|secreted Ly6/uPAR related protein 2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142764338, end_position_on_the_genomic_accession=142769828, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    439915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=439915, CurrentID=0, Status='live', Symbol='KRTAP5-5', Aliases=['KRTAP5-11', 'KRTAP5.5'], description='keratin associated protein 5-5', other_designations='keratin-associated protein 5-5|keratin associated protein 5-11|keratin-associated protein 5.11|keratin-associated protein 5.5|ultrahigh sulfur keratin-associated protein 5.5', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1629803, end_position_on_the_genomic_accession=1630930, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    439921 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=439921, CurrentID=0, Status='live', Symbol='MXRA7', Aliases=[], description='matrix remodeling associated 7', other_designations='matrix-remodeling-associated protein 7|matrix-remodelling associated 7', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76672551, end_position_on_the_genomic_accession=76710965, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    439996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=439996, CurrentID=0, Status='live', Symbol='IFIT1B', Aliases=['IFIT1L', 'bA149I23.6'], description='interferon induced protein with tetratricopeptide repeats 1B', other_designations='interferon-induced protein with tetratricopeptide repeats 1B|interferon-induced protein with tetratricopeptide repeats 1-like protein', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=89378056, end_position_on_the_genomic_accession=89385205, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    440021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440021, CurrentID=0, Status='live', Symbol='KRTAP5-2', Aliases=['KRTAP5-8', 'KRTAP5.2'], description='keratin associated protein 5-2', other_designations='keratin-associated protein 5-2|keratin-associated protein 5-8|keratin-associated protein 5.2|keratin-associated protein 5.8|ultrahigh sulfur keratin-associated protein 5.2', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1597177, end_position_on_the_genomic_accession=1598294, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    440023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440023, CurrentID=0, Status='live', Symbol='KRTAP5-6', Aliases=['KRTAP5.6'], description='keratin associated protein 5-6', other_designations='keratin-associated protein 5-6|keratin-associated protein 5.6|ultrahigh sulfur keratin-associated protein 5.6', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1697195, end_position_on_the_genomic_accession=1697755, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    440026 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440026, CurrentID=0, Status='live', Symbol='TMEM41B', Aliases=[], description='transmembrane protein 41B', other_designations='transmembrane protein 41B|protein stasimon|stasimon', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=9280654, end_position_on_the_genomic_accession=9314633, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    440050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440050, CurrentID=0, Status='live', Symbol='KRTAP5-7', Aliases=['KRTAP5-3', 'KRTAP5.7'], description='keratin associated protein 5-7', other_designations='keratin-associated protein 5-7|keratin-associated protein 5-3|keratin-associated protein 5.3|keratin-associated protein 5.7|ultrahigh sulfur keratin-associated protein 5.7', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71527267, end_position_on_the_genomic_accession=71528669, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    440051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440051, CurrentID=0, Status='live', Symbol='KRTAP5-11', Aliases=['KRTAP5-5', 'KRTAP5-6', 'KRTAP5.11'], description='keratin associated protein 5-11', other_designations='keratin-associated protein 5-11|keratin associated protein 5-5|keratin-associated protein 5.11|ultrahigh sulfur keratin-associated protein 5.11', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71581855, end_position_on_the_genomic_accession=71582875, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    440073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440073, CurrentID=0, Status='live', Symbol='IQSEC3', Aliases=[], description='IQ motif and Sec7 domain ArfGEF 3', other_designations='IQ motif and SEC7 domain-containing protein 3|IQ motif and Sec7 domain 3', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=66767, end_position_on_the_genomic_accession=178455, orientation='plus', exon_count=17, OMIM=[612118], no_hdr0=''),
    440077 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440077, CurrentID=0, Status='live', Symbol='ZNF705A', Aliases=[], description='zinc finger protein 705A', other_designations='zinc finger protein 705A', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=8156999, end_position_on_the_genomic_accession=8180046, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    440087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440087, CurrentID=0, Status='live', Symbol='SMCO3', Aliases=['C12orf69'], description='single-pass membrane protein with coiled-coil domains 3', other_designations='single-pass membrane and coiled-coil domain-containing protein 3', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14804650, end_position_on_the_genomic_accession=14816761, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    440093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440093, CurrentID=0, Status='live', Symbol='H3-5', Aliases=['H3.5', 'H3F3C'], description='H3.5 histone', other_designations='histone H3.3C|H3 histone family member 3C|H3 histone, family 3C|histone H3.5|histone variant H3.5', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=31791185, end_position_on_the_genomic_accession=31792298, orientation='minus', exon_count=1, OMIM=[616134], no_hdr0=''),
    440097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440097, CurrentID=0, Status='live', Symbol='DBX2', Aliases=[], description='developing brain homeobox 2', other_designations='homeobox protein DBX2|developing brain homeobox protein 2', map_location='12q12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=45014672, end_position_on_the_genomic_accession=45051099, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    440107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440107, CurrentID=0, Status='live', Symbol='PLEKHG7', Aliases=['C12orf74'], description='pleckstrin homology and RhoGEF domain containing G7', other_designations='pleckstrin homology domain-containing family G member 7|PH domain-containing family G member 7|pleckstrin homology domain containing, family G (with RhoGef domain) member 7|uncharacterized protein C12orf74', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=92702989, end_position_on_the_genomic_accession=92772455, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    440138 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440138, CurrentID=0, Status='live', Symbol='ALG11', Aliases=['CDG1P', 'GT8'], description='ALG11 alpha-1,2-mannosyltransferase', other_designations='GDP-Man:Man(3)GlcNAc(2)-PP-Dol alpha-1,2-mannosyltransferase|GDP-Man:Man(3)GlcNAc(2)-PP-dolichol alpha-1,2-mannosyltransferase|asparagine-linked glycosylation 11, alpha-1,2-mannosyltransferase homolog|asparagine-linked glycosylation protein 11 homolog|glycolipid 2-alpha-mannosyltransferase', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=52012398, end_position_on_the_genomic_accession=52033600, orientation='plus', exon_count=4, OMIM=[613666], no_hdr0=''),
    440145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440145, CurrentID=0, Status='live', Symbol='MZT1', Aliases=['C13orf37', 'MOZART1'], description='mitotic spindle organizing protein 1', other_designations='mitotic-spindle organizing protein 1|mitotic-spindle organizing protein associated with a ring of gamma-tubulin 1', map_location='13q21.33', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=72708367, end_position_on_the_genomic_accession=72727629, orientation='minus', exon_count=3, OMIM=[613448], no_hdr0=''),
    440153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440153, CurrentID=0, Status='live', Symbol='OR11H12', Aliases=[], description='olfactory receptor family 11 subfamily H member 12', other_designations='olfactory receptor 11H12', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=18601117, end_position_on_the_genomic_accession=18602097, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    440163 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440163, CurrentID=0, Status='live', Symbol='RNASE13', Aliases=['HEL-S-86p', 'RAL1'], description='ribonuclease A family member 13 (inactive)', other_designations='probable inactive ribonuclease-like protein 13|epididymis secretory sperm binding protein Li 86p|ribonuclease 13|ribonuclease A L1|ribonuclease, RNase A family, 13 (non-active)|ribonuclease-like protein 13', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21032818, end_position_on_the_genomic_accession=21034807, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440184, CurrentID=0, Status='live', Symbol='CCDC196', Aliases=['C14orf53', 'LINC00238', 'NCRNA00238'], description='coiled-coil domain containing 196', other_designations='putative coiled-coil domain-containing protein 196|long intergenic non-protein coding RNA 238', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=66484855, end_position_on_the_genomic_accession=66498553, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    440193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440193, CurrentID=0, Status='live', Symbol='CCDC88C', Aliases=['DAPLE', 'HKRP2', 'HYC1', 'KIAA1509', 'SCA40'], description='coiled-coil domain containing 88C', other_designations='protein Daple|Dvl-associating protein with a high frequency of leucine residues|hook-related protein 2|spinocerebellar ataxia 40', map_location='14q32.11-q32.12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=91271323, end_position_on_the_genomic_accession=91417820, orientation='minus', exon_count=34, OMIM=[611204], no_hdr0=''),
    440243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440243, CurrentID=0, Status='live', Symbol='GOLGA6L22', Aliases=[], description='golgin A6 family like 22', other_designations='golgin subfamily A member 6-like protein 22', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22458903, end_position_on_the_genomic_accession=22467626, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    440270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440270, CurrentID=0, Status='live', Symbol='GOLGA8B', Aliases=['GOLGA5'], description='golgin A8 family member B', other_designations='golgin subfamily A member 8B|golgi autoantigen, golgin subfamily a, 8B|golgin-67', map_location='15q14', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=34525095, end_position_on_the_genomic_accession=34583651, orientation='minus', exon_count=24, OMIM=[609619], no_hdr0=''),
    440275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440275, CurrentID=0, Status='live', Symbol='EIF2AK4', Aliases=['GCN2', 'PVOD2'], description='eukaryotic translation initiation factor 2 alpha kinase 4', other_designations='eIF-2-alpha kinase GCN2|GCN2 eIF2alpha kinase|GCN2-like protein|general control nonderepressible 2', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=39934115, end_position_on_the_genomic_accession=40035591, orientation='plus', exon_count=39, OMIM=[609280], no_hdr0=''),
    440279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440279, CurrentID=0, Status='live', Symbol='UNC13C', Aliases=[], description='unc-13 homolog C', other_designations='protein unc-13 homolog C|Munc13-3|unc-13-like 3', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=53837573, end_position_on_the_genomic_accession=54633440, orientation='plus', exon_count=38, OMIM=[614568], no_hdr0=''),
    440295 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440295, CurrentID=0, Status='live', Symbol='GOLGA6L9', Aliases=['GOLGA6L20'], description='golgin A6 family like 9', other_designations='golgin subfamily A member 6-like protein 9|golgi autoantigen, golgin subfamily a, 6-like 9|golgin A6 family-like 20|putative golgin subfamily A member 6-like protein 20', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82429363, end_position_on_the_genomic_accession=82439153, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    440335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440335, CurrentID=0, Status='live', Symbol='SMIM22', Aliases=['CASIMO1'], description='small integral membrane protein 22', other_designations='small integral membrane protein 22', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4788395, end_position_on_the_genomic_accession=4796491, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    440345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440345, CurrentID=0, Status='live', Symbol='NPIPB4', Aliases=['61E3.4'], description='nuclear pore complex interacting protein family member B4', other_designations='nuclear pore complex-interacting protein family member B4|nuclear pore complex interacting protein-like', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=21834568, end_position_on_the_genomic_accession=21857756, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    440348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440348, CurrentID=0, Status='live', Symbol='NPIPB15', Aliases=['A-761H5.4', 'NPIPL2'], description='nuclear pore complex interacting protein family member B15', other_designations='nuclear pore complex-interacting protein family member B15|nuclear pore complex interacting protein-like 2', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74374986, end_position_on_the_genomic_accession=74392115, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    440353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440353, CurrentID=0, Status='live', Symbol='NPIPB12', Aliases=[], description='nuclear pore complex interacting protein family member B12', other_designations='nuclear pore complex-interacting protein family member B12', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29483534, end_position_on_the_genomic_accession=29505874, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    440387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440387, CurrentID=0, Status='live', Symbol='CTRB2', Aliases=[], description='chymotrypsinogen B2', other_designations='chymotrypsinogen B2|chymotrypsin B2', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75204103, end_position_on_the_genomic_accession=75207161, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    440400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440400, CurrentID=0, Status='live', Symbol='RNASEK', Aliases=[], description='ribonuclease K', other_designations='ribonuclease kappa|RNase kappa|ribonuclease, RNase K', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7012624, end_position_on_the_genomic_accession=7014532, orientation='plus', exon_count=4, OMIM=[617098], no_hdr0=''),
    440435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440435, CurrentID=0, Status='live', Symbol='GPR179', Aliases=['CSNB1E', 'GPR158L', 'GPR158L1'], description='G protein-coupled receptor 179', other_designations='probable G-protein coupled receptor 179|GPR158-like 1|probable G-protein coupled receptor 158-like 1', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38324571, end_position_on_the_genomic_accession=38343956, orientation='minus', exon_count=11, OMIM=[614515], no_hdr0=''),
    440498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440498, CurrentID=0, Status='live', Symbol='HSBP1L1', Aliases=[], description='heat shock factor binding protein 1 like 1', other_designations='heat shock factor-binding protein 1-like protein 1', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79964643, end_position_on_the_genomic_accession=79970822, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    440503 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440503, CurrentID=0, Status='live', Symbol='PLIN5', Aliases=['LSDA5', 'LSDP5', 'MLDP', 'OXPAT'], description='perilipin 5', other_designations='perilipin-5|lipid storage droplet protein 5', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4522531, end_position_on_the_genomic_accession=4535224, orientation='minus', exon_count=8, OMIM=[613248], no_hdr0=''),
    440515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440515, CurrentID=0, Status='live', Symbol='ZNF506', Aliases=[], description='zinc finger protein 506', other_designations='zinc finger protein 506', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19792711, end_position_on_the_genomic_accession=19821750, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    440519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440519, CurrentID=0, Status='live', Symbol='ZNF724', Aliases=['ZNF724P'], description='zinc finger protein 724', other_designations='zinc finger protein 724', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23221584, end_position_on_the_genomic_accession=23250456, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    440533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440533, CurrentID=0, Status='live', Symbol='PSG8', Aliases=['PSG1'], description='pregnancy specific beta-1-glycoprotein 8', other_designations='pregnancy-specific beta-1-glycoprotein 8|C1 alternate|C2 alternate|C3 alternate|PS-beta-G-8|PSBG-8|pregnancy-specific beta-1 glycoprotein|pregnancy-specific glycoprotein 8', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=42752686, end_position_on_the_genomic_accession=42765692, orientation='minus', exon_count=7, OMIM=[176397], no_hdr0=''),
    440560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440560, CurrentID=0, Status='live', Symbol='PRAMEF11', Aliases=[], description='PRAME family member 11', other_designations='PRAME family member 11', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12824380, end_position_on_the_genomic_accession=12831410, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    440561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440561, CurrentID=0, Status='live', Symbol='PRAMEF6', Aliases=[], description='PRAME family member 6', other_designations='PRAME family member 6', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12938472, end_position_on_the_genomic_accession=12947580, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    440563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440563, CurrentID=0, Status='live', Symbol='HNRNPCL2', Aliases=['HNRNPCP5'], description='heterogeneous nuclear ribonucleoprotein C like 2', other_designations='heterogeneous nuclear ribonucleoprotein C-like 2|heterogeneous nuclear ribonucleoprotein C pseudogene 5|hnRNP C-like-2', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13115488, end_position_on_the_genomic_accession=13116854, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440567, CurrentID=0, Status='live', Symbol='UQCRHL', Aliases=['hCG25371'], description='ubiquinol-cytochrome c reductase hinge protein like', other_designations='cytochrome b-c1 complex subunit 6-like, mitochondrial', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=15807162, end_position_on_the_genomic_accession=15807699, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    440574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440574, CurrentID=0, Status='live', Symbol='MICOS10', Aliases=['C1orf151', 'MINOS1', 'MIO10', 'Mic10'], description='mitochondrial contact site and cristae organizing system subunit 10', other_designations='MICOS complex subunit MIC10|RP5-1056L3.2|UPF0327 protein C1orf151|mitochondrial inner membrane organizing system 1|mitochondrial inner membrane organizing system protein 1', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19596979, end_position_on_the_genomic_accession=19629820, orientation='plus', exon_count=7, OMIM=[616574], no_hdr0=''),
    440585 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440585, CurrentID=0, Status='live', Symbol='FAM183A', Aliases=[], description='family with sequence similarity 183 member A', other_designations='protein FAM183A|hCG23177', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=43142959, end_position_on_the_genomic_accession=43156396, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    440590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440590, CurrentID=0, Status='live', Symbol='ZYG11A', Aliases=['ZYG11'], description='zyg-11 family member A, cell cycle regulator', other_designations='protein zyg-11 homolog A|ZYG-11A early embryogenesis protein|zyg-11 homolog A', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=52842736, end_position_on_the_genomic_accession=52894998, orientation='plus', exon_count=15, OMIM=[618675], no_hdr0=''),
    440603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440603, CurrentID=0, Status='live', Symbol='BCL2L15', Aliases=['Bfk', 'C1orf178'], description='BCL2 like 15', other_designations='bcl-2-like protein 15|bcl2-L-15|pro-apoptotic Bcl-2 protein', map_location='1p13.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=113876816, end_position_on_the_genomic_accession=113887581, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    440672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440672, CurrentID=0, Status='live', Symbol='NUDT4B', Aliases=['DIPP-2B', 'NUDT4P1'], description='nudix hydrolase 4B', other_designations='diphosphoinositol polyphosphate phosphohydrolase NUDT4B|nucleoside diphosphate-linked moiety X motif 4B|nudix (nucleoside diphosphate linked moiety X)-type motif 4 pseudogene 1|nudix motif 4B', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148748774, end_position_on_the_genomic_accession=148752415, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    440686 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440686, CurrentID=0, Status='live', Symbol='H3-2', Aliases=['HIST2H3PS2', 'p06'], description='H3.2 histone (putative)', other_designations='histone HIST2H3PS2|histone 2, H3, pseudogene 2|histone H3.2|histone cluster 2 H3 pseudogene 2', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=143902386, end_position_on_the_genomic_accession=143905977, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440689, CurrentID=0, Status='live', Symbol='H2BC18', Aliases=['HIST2H2BF'], description='H2B clustered histone 18', other_designations='histone H2B type 2-F|histone cluster 2 H2B family member f|histone cluster 2, H2bf', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149782689, end_position_on_the_genomic_accession=149812370, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440695, CurrentID=0, Status='live', Symbol='ETV3L', Aliases=[], description='ETS variant transcription factor 3 like', other_designations='ETS translocation variant 3-like protein|ETS variant 3 like|ets variant 3-like|ets variant gene 3-like', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=157092043, end_position_on_the_genomic_accession=157112832, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    440699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440699, CurrentID=0, Status='live', Symbol='LRRC52', Aliases=[], description='leucine rich repeat containing 52', other_designations='leucine-rich repeat-containing protein 52|BK channel auxiliary gamma subunit LRRC52|BK channel auxilliary gamma subunit LRRC52', map_location='1q24.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=165544000, end_position_on_the_genomic_accession=165563957, orientation='plus', exon_count=2, OMIM=[615218], no_hdr0=''),
    440712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440712, CurrentID=0, Status='live', Symbol='RHEX', Aliases=['C1orf186'], description='regulator of hemoglobinization and erythroid cell expansion', other_designations='regulator of hemoglobinization and erythroid cell expansion protein|regulator of human erythroid cell expansion protein|uncharacterized protein C1orf186', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206053173, end_position_on_the_genomic_accession=206102449, orientation='plus', exon_count=7, OMIM=[616088], no_hdr0=''),
    440730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440730, CurrentID=0, Status='live', Symbol='TRIM67', Aliases=['TNL'], description='tripartite motif containing 67', other_designations='tripartite motif-containing protein 67|TRIM9-like protein TNL', map_location='1q42.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=231162058, end_position_on_the_genomic_accession=231221565, orientation='plus', exon_count=10, OMIM=[610584], no_hdr0=''),
    440738 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440738, CurrentID=0, Status='live', Symbol='MAP1LC3C', Aliases=['ATG8J', 'LC3C'], description='microtubule associated protein 1 light chain 3 gamma', other_designations='microtubule-associated proteins 1A/1B light chain 3C|LC3-like protein 2|MAP1 light chain 3-like protein 2|MAP1 light chain 3-like protein 3|MAP1A/MAP1B LC3 C|MAP1A/MAP1B light chain 3 C|autophagy-related protein LC3 C|autophagy-related ubiquitin-like modifier LC3 C', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241995194, end_position_on_the_genomic_accession=242001393, orientation='minus', exon_count=5, OMIM=[609605], no_hdr0=''),
    440804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440804, CurrentID=0, Status='live', Symbol='RIMBP3B', Aliases=['RIM-BP3.2', 'RIM-BP3.B', 'RIMBP3.2'], description='RIMS binding protein 3B', other_designations='RIMS-binding protein 3B|RIMS binding protein 3.2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21383751, end_position_on_the_genomic_accession=21389169, orientation='plus', exon_count=1, OMIM=[612700], no_hdr0=''),
    440822 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440822, CurrentID=0, Status='live', Symbol='PIWIL3', Aliases=['HIWI3'], description='piwi like RNA-mediated gene silencing 3', other_designations='piwi-like protein 3|piwi-like 3', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=24719034, end_position_on_the_genomic_accession=24774720, orientation='minus', exon_count=23, OMIM=[610314], no_hdr0=''),
    440829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440829, CurrentID=0, Status='live', Symbol='SHISA8', Aliases=['C22orf17', 'Orf26'], description='shisa family member 8', other_designations='protein shisa-8|CTA-250D10.17|putative protein shisa-8|shisa homolog 8', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41906049, end_position_on_the_genomic_accession=41915093, orientation='minus', exon_count=5, OMIM=[617329], no_hdr0=''),
    440836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440836, CurrentID=0, Status='live', Symbol='ODF3B', Aliases=['FAP123', 'ODF3L3'], description='outer dense fiber of sperm tails 3B', other_designations="outer dense fiber protein 3B|orf2 5' to PD-ECGF/TP|outer dense fiber protein 3-like protein 3", map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50530426, end_position_on_the_genomic_accession=50532498, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    440854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440854, CurrentID=0, Status='live', Symbol='CAPN14', Aliases=[], description='calpain 14', other_designations='calpain-14|CANP 14|calcium-activated neutral proteinase 14', map_location='2p23.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=31173056, end_position_on_the_genomic_accession=31233970, orientation='minus', exon_count=26, OMIM=[610229], no_hdr0=''),
    440955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440955, CurrentID=0, Status='live', Symbol='TMEM89', Aliases=[], description='transmembrane protein 89', other_designations='transmembrane protein 89', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48620759, end_position_on_the_genomic_accession=48621769, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440956, CurrentID=0, Status='live', Symbol='IQCF6', Aliases=[], description='IQ motif containing F6', other_designations='IQ domain-containing protein F6', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51778563, end_position_on_the_genomic_accession=51779237, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    440957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=440957, CurrentID=0, Status='live', Symbol='SMIM4', Aliases=['C3orf78'], description='small integral membrane protein 4', other_designations='small integral membrane protein 4|UPF0640 protein C3orf78', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52535986, end_position_on_the_genomic_accession=52541890, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    441024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441024, CurrentID=0, Status='live', Symbol='MTHFD2L', Aliases=[], description='methylenetetrahydrofolate dehydrogenase (NADP+ dependent) 2 like', other_designations='probable bifunctional methylenetetrahydrofolate dehydrogenase/cyclohydrolase 2|MTHFD2-like|NADP-dependent methylenetetrahydrofolate dehydrogenase 2-like protein|tetrahydrofolate dehydrogenase/cyclohydrolase', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=74123273, end_position_on_the_genomic_accession=74303099, orientation='plus', exon_count=26, OMIM=[614047], no_hdr0=''),
    441027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441027, CurrentID=0, Status='live', Symbol='TMEM150C', Aliases=['TTN3'], description='transmembrane protein 150C', other_designations='transmembrane protein 150C|tentonin 3', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82483176, end_position_on_the_genomic_accession=82562253, orientation='minus', exon_count=9, OMIM=[617292], no_hdr0=''),
    441054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441054, CurrentID=0, Status='live', Symbol='C4orf47', Aliases=[], description='chromosome 4 open reading frame 47', other_designations='UPF0602 protein C4orf47', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=185405227, end_position_on_the_genomic_accession=185449828, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    441061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441061, CurrentID=0, Status='live', Symbol='MARCHF11', Aliases=['MARCH-XI', 'MARCH11', 'RNF226'], description='membrane associated ring-CH-type finger 11', other_designations='E3 ubiquitin-protein ligase MARCHF11|E3 ubiquitin-protein ligase MARCH11|RING-type E3 ubiquitin transferase MARCH11|RING-type E3 ubiquitin transferase MARCHF11|membrane associated ring finger 11|membrane-associated RING finger protein 11|membrane-associated RING-CH protein XI|membrane-associated ring finger (C3HC4) 11', map_location='5p15.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=16067139, end_position_on_the_genomic_accession=16179791, orientation='minus', exon_count=4, OMIM=[613338], no_hdr0=''),
    441150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441150, CurrentID=0, Status='live', Symbol='C6orf226', Aliases=[], description='chromosome 6 open reading frame 226', other_designations='uncharacterized protein C6orf226', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42890265, end_position_on_the_genomic_accession=42890821, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    441151 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441151, CurrentID=0, Status='live', Symbol='TMEM151B', Aliases=['C6orf137', 'TMEM193', 'bA444E17.5'], description='transmembrane protein 151B', other_designations='transmembrane protein 151B|transmembrane protein 193', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44270450, end_position_on_the_genomic_accession=44279444, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    441155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441155, CurrentID=0, Status='live', Symbol='LOC441155', Aliases=[], description='zinc finger CCCH-type domain-containing-like', other_designations='zinc finger CCCH-type domain-containing-like|zinc finger CCCH-type containing 11A-like', map_location='6q12', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=65301418, end_position_on_the_genomic_accession=65306069, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    441161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441161, CurrentID=0, Status='live', Symbol='OOEP', Aliases=['C6orf156', 'FLOPED', 'HOEP19', 'KHDC2'], description='oocyte expressed protein', other_designations='oocyte-expressed protein homolog|KH homology domain containing 2|KH homology domain-containing protein 2|oocyte and embryo protein 19|oocyte expressed protein homolog (dog)|oocyte- and embryo-specific protein 19', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73368555, end_position_on_the_genomic_accession=73369897, orientation='minus', exon_count=3, OMIM=[611689], no_hdr0=''),
    441168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441168, CurrentID=0, Status='live', Symbol='CALHM6', Aliases=['C6orf187', 'FAM26F', 'INAM', 'dJ93H18.5'], description='calcium homeostasis modulator family member 6', other_designations='calcium homeostasis modulator protein 6|IFN regulatory factor 3-dependent NK-activating molecule|family with sequence similarity 26 member F|protein FAM26F', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116461375, end_position_on_the_genomic_accession=116463782, orientation='plus', exon_count=3, OMIM=[617305], no_hdr0=''),
    441234 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441234, CurrentID=0, Status='live', Symbol='ZNF716', Aliases=[], description='zinc finger protein 716', other_designations='zinc finger protein 716', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=57450177, end_position_on_the_genomic_accession=57473559, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    441239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441239, CurrentID=0, Status='live', Symbol='LOC441239', Aliases=[], description='uncharacterized LOC441239', other_designations='uncharacterized protein LOC441239', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64887750, end_position_on_the_genomic_accession=64890100, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    441250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441250, CurrentID=0, Status='live', Symbol='TYW1B', Aliases=['LINC00069', 'NCRNA00069', 'RSAFD2'], description='tRNA-yW synthesizing protein 1 homolog B', other_designations='S-adenosyl-L-methionine-dependent tRNA 4-demethylwyosine synthase TYW1B|long intergenic non-protein coding RNA 69|radical S-adenosyl methionine and flavodoxin domain-containing protein 2|radical S-adenosyl methionine and flavodoxin domains 1|tRNA wybutosine-synthesizing protein 1 homolog B|tRNA-yW synthesizing protein 1 homolog B (non-protein coding)', map_location='7q11.22-q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=72574513, end_position_on_the_genomic_accession=72828200, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    441251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441251, CurrentID=0, Status='live', Symbol='SPDYE7P', Aliases=[], description='speedy/RINGO cell cycle regulator family member E7, pseudogene', other_designations='putative speedy protein E7|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E7, pseudogene|speedy protein E7 pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=72862757, end_position_on_the_genomic_accession=72871506, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    441272 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441272, CurrentID=0, Status='live', Symbol='SPDYE3', Aliases=['SPDYB2'], description='speedy/RINGO cell cycle regulator family member E3', other_designations='speedy protein E3|Putative WBSCR19-like protein 7|putative Speedy protein E3|speedy homolog E3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100306798, end_position_on_the_genomic_accession=100322196, orientation='plus', exon_count=10, OMIM=[617625], no_hdr0=''),
    441273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441273, CurrentID=0, Status='live', Symbol='SPDYE2', Aliases=['SPDYB2-L1', 'SPDYB2L1'], description='speedy/RINGO cell cycle regulator family member E2', other_designations='speedy protein E2|Speedy B2-like 1|putative Speedy protein E2|speedy homolog E2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102551232, end_position_on_the_genomic_accession=102565227, orientation='plus', exon_count=9, OMIM=[617624], no_hdr0=''),
    441282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441282, CurrentID=0, Status='live', Symbol='AKR1B15', Aliases=['AKR1B10L', 'AKR1B10L', 'AK1R1B7', 'AKR1R1B7'], description='aldo-keto reductase family 1 member B15', other_designations='aldo-keto reductase family 1 member B15|estradiol 17-beta-dehydrogenase AKR1B15|farnesol dehydrogenase|putative aldo-keto reductase family 1 member B15|testosterone 17beta-dehydrogenase', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=134549110, end_position_on_the_genomic_accession=134579869, orientation='plus', exon_count=12, OMIM=[616336], no_hdr0=''),
    441294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441294, CurrentID=0, Status='live', Symbol='CTAGE15', Aliases=['CTAGE15P', 'cTAGE-15'], description='CTAGE family member 15', other_designations='cTAGE family member 15|CTAGE family, member 15, pseudogene|protein cTAGE-15', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=143571801, end_position_on_the_genomic_accession=143574387, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    441308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441308, CurrentID=0, Status='live', Symbol='OR4F21', Aliases=['OR4F21P'], description='olfactory receptor family 4 subfamily F member 21', other_designations='olfactory receptor 4F21|olfactory receptor, family 4, subfamily F, member 21 pseudogene', map_location='8p23.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=166086, end_position_on_the_genomic_accession=167024, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    441376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441376, CurrentID=0, Status='live', Symbol='AARD', Aliases=['C8orf85'], description='alanine and arginine rich domain containing protein', other_designations='alanine and arginine-rich domain-containing protein', map_location='8q24.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=116938207, end_position_on_the_genomic_accession=116944487, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    441381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441381, CurrentID=0, Status='live', Symbol='LRRC24', Aliases=['LRRC14OS'], description='leucine rich repeat containing 24', other_designations='leucine-rich repeat-containing protein 24', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144522388, end_position_on_the_genomic_accession=144527033, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    441452 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441452, CurrentID=0, Status='live', Symbol='SPATA31C1', Aliases=['FAM75C1', 'SPATA31C2'], description='SPATA31 subfamily C member 1', other_designations='putative spermatogenesis-associated protein 31C1|family with sequence similarity 75, member C1|spermatogenesis-associated protein 31C1|spermatogenesis-associated protein 31C2', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=87913936, end_position_on_the_genomic_accession=87923657, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    441457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441457, CurrentID=0, Status='live', Symbol='NUTM2G', Aliases=['FAM22G', 'NUTMG'], description='NUT family member 2G', other_designations='NUT family member 2G|family with sequence similarity 22, member G|family with sequence similarity 22, pseudogene|protein FAM22G', map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=96928843, end_position_on_the_genomic_accession=96942971, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    441459 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441459, CurrentID=0, Status='live', Symbol='ANKRD18B', Aliases=['bA255A11.3', 'bA255A11.5'], description='ankyrin repeat domain 18B', other_designations='ankyrin repeat domain-containing protein 18B', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=33524251, end_position_on_the_genomic_accession=33575442, orientation='plus', exon_count=22, OMIM=[618930], no_hdr0=''),
    441476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441476, CurrentID=0, Status='live', Symbol='STPG3', Aliases=['C9orf173'], description='sperm-tail PG-rich repeat containing 3', other_designations='protein STPG3|sperm-tail PG-rich repeat-containing protein 3', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137250840, end_position_on_the_genomic_accession=137253483, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    441478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441478, CurrentID=0, Status='live', Symbol='NRARP', Aliases=[], description='NOTCH regulated ankyrin repeat protein', other_designations='notch-regulated ankyrin repeat-containing protein', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137299631, end_position_on_the_genomic_accession=137302271, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    441495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441495, CurrentID=0, Status='live', Symbol='CENPVL2', Aliases=['CENPVP2'], description='centromere protein V like 2', other_designations='centromere protein V-like protein 2', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=51681212, end_position_on_the_genomic_accession=51682831, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    441518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441518, CurrentID=0, Status='live', Symbol='RTL8B', Aliases=['CXX1c', 'FAM127C', 'MAR8B', 'SIRH4'], description='retrotransposon Gag like 8B', other_designations='retrotransposon Gag-like protein 8B|Sushi-Ichi retrotransposon homolog 1|family with sequence similarity 127 member C|mammalian retrotransposon derived protein 8B|mammalian retrotransposon-derived 2|protein FAM127C', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135020513, end_position_on_the_genomic_accession=135022542, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    441519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441519, CurrentID=0, Status='live', Symbol='CT45A3', Aliases=['CT45-3', 'CT45-4', 'CT45.3', 'CT45.4', 'CT45A4'], description='cancer/testis antigen family 45 member A3', other_designations='cancer/testis antigen family 45 member A3|cancer/testis antigen 45-3|cancer/testis antigen 45-4|cancer/testis antigen 45A3|cancer/testis antigen 45A4|cancer/testis antigen CT45-3|cancer/testis antigen family 45 member A4', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135760044, end_position_on_the_genomic_accession=135768191, orientation='minus', exon_count=6, OMIM=[300794], no_hdr0=''),
    441521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441521, CurrentID=0, Status='live', Symbol='CT45A5', Aliases=['CT45-3', 'CT45-4', 'CT45-6', 'CT45.5', 'CT455', 'CT45A3', 'CT45A4', 'CT45A6', 'CT45A7'], description='cancer/testis antigen family 45 member A5', other_designations='cancer/testis antigen family 45 member A5|Cancer/testis antigen 45-3|Cancer/testis antigen 45-4|Cancer/testis antigen 45-6|Cancer/testis antigen 45A3|Cancer/testis antigen 45A4|Cancer/testis antigen 45A6|Cancer/testis antigen 45A7|Cancer/testis antigen family 45 member A3|Cancer/testis antigen family 45 member A4|Cancer/testis antigen family 45 member A6|Cancer/testis antigen family 45 member A7|cancer/testis antigen 45-5|cancer/testis antigen 45A5|cancer/testis antigen CT45-5', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135775852, end_position_on_the_genomic_accession=135785514, orientation='minus', exon_count=5, OMIM=[300796], no_hdr0=''),
    441525 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441525, CurrentID=0, Status='live', Symbol='SPANXN4', Aliases=['CT11.9'], description='SPANX family member N4', other_designations='sperm protein associated with the nucleus on the X chromosome N4|cancer/testis antigen family 11, member 9|nuclear-associated protein SPAN-Xn4', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=143025928, end_position_on_the_genomic_accession=143038637, orientation='plus', exon_count=4, OMIM=[300667], no_hdr0=''),
    441531 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441531, CurrentID=0, Status='live', Symbol='PGAM4', Aliases=['PGAM-B', 'PGAM1', 'PGAM3', 'dJ1000K24.1'], description='phosphoglycerate mutase family member 4', other_designations='phosphoglycerate mutase 4|phosphoglycerate mutase family 3|phosphoglycerate mutase processed protein|probable phosphoglycerate mutase 4', map_location='Xq21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=77967949, end_position_on_the_genomic_accession=77969638, orientation='minus', exon_count=1, OMIM=[300567], no_hdr0=''),
    441549 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441549, CurrentID=0, Status='live', Symbol='CDNF', Aliases=['ARMETL1'], description='cerebral dopamine neurotrophic factor', other_designations='cerebral dopamine neurotrophic factor|ARMET-like protein 1|arginine-rich, mutated in early stage tumors-like 1|conserved dopamine neurotrophic factor', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14819245, end_position_on_the_genomic_accession=14838073, orientation='minus', exon_count=4, OMIM=[611233], no_hdr0=''),
    441581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441581, CurrentID=0, Status='live', Symbol='FRG2B', Aliases=[], description='FSHD region gene 2 family member B', other_designations='protein FRG2-like-1|FSHD region gene 2 protein family member B|HSA10-FRG2', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133623895, end_position_on_the_genomic_accession=133626795, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    441608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441608, CurrentID=0, Status='live', Symbol='OR5B3', Aliases=['OR11-239', 'OR5B13', 'OST129'], description='olfactory receptor family 5 subfamily B member 3', other_designations='olfactory receptor 5B3|olfactory receptor 5B13|olfactory receptor OR11-239|olfactory receptor, family 5, subfamily B, member 13', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=58402464, end_position_on_the_genomic_accession=58406874, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    441631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441631, CurrentID=0, Status='live', Symbol='TSPAN11', Aliases=['VSSW1971'], description='tetraspanin 11', other_designations='tetraspanin-11|tspan-11', map_location='12p11.21', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=30926433, end_position_on_the_genomic_accession=31016502, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    441639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441639, CurrentID=0, Status='live', Symbol='OR9K2', Aliases=['OR12-2'], description='olfactory receptor family 9 subfamily K member 2', other_designations='olfactory receptor 9K2|olfactory receptor OR12-2', map_location='12q13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=55126406, end_position_on_the_genomic_accession=55132750, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    441669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441669, CurrentID=0, Status='live', Symbol='OR4Q3', Aliases=['C14orf13', 'HSA6', 'OR14-3', 'OR4Q4', 'c14_5008'], description='olfactory receptor family 4 subfamily Q member 3', other_designations='olfactory receptor 4Q3|olfactory receptor 4Q4|olfactory receptor OR14-3|olfactory receptor, family 4, subfamily Q, member 4', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19744740, end_position_on_the_genomic_accession=19752334, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    441670 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441670, CurrentID=0, Status='live', Symbol='OR4M1', Aliases=['OR14-7'], description='olfactory receptor family 4 subfamily M member 1', other_designations='olfactory receptor 4M1|olfactory receptor OR14-7', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=19773504, end_position_on_the_genomic_accession=19783696, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    441864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441864, CurrentID=0, Status='live', Symbol='TARM1', Aliases=['OLT-2'], description='T cell-interacting, activating receptor on myeloid cells 1', other_designations='T-cell-interacting, activating receptor on myeloid cells protein 1|OSCAR-like transcript-2 protein', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=54069895, end_position_on_the_genomic_accession=54081365, orientation='minus', exon_count=6, OMIM=[616802], no_hdr0=''),
    441869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441869, CurrentID=0, Status='live', Symbol='ANKRD65', Aliases=[], description='ankyrin repeat domain 65', other_designations='ankyrin repeat domain-containing protein 65', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1418420, end_position_on_the_genomic_accession=1422471, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    441871 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441871, CurrentID=0, Status='live', Symbol='PRAMEF7', Aliases=[], description='PRAME family member 7', other_designations='PRAME family member 7', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=12916647, end_position_on_the_genomic_accession=12920480, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    441873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441873, CurrentID=0, Status='live', Symbol='PRAMEF25', Aliases=[], description='PRAME family member 25', other_designations='PRAME family member 25|putative PRAME family member 25', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13070774, end_position_on_the_genomic_accession=13078038, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    441925 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441925, CurrentID=0, Status='live', Symbol='BECN2', Aliases=['BECN1L1', 'BECN1P1'], description='beclin 2', other_designations='beclin-2|Beclin-1-like protein 1|beclin-1 autophagy-related pseudogene 1', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=241957767, end_position_on_the_genomic_accession=241959062, orientation='plus', exon_count=1, OMIM=[615687], no_hdr0=''),
    441933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=441933, CurrentID=0, Status='live', Symbol='OR13G1', Aliases=['OR1-37'], description='olfactory receptor family 13 subfamily G member 1', other_designations='olfactory receptor 13G1|olfactory receptor OR1-37', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=247670812, end_position_on_the_genomic_accession=247679739, orientation='minus', exon_count=2, OMIM=[611677], no_hdr0=''),
    442038 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442038, CurrentID=0, Status='live', Symbol='SULT1C3', Aliases=['ST1C3'], description='sulfotransferase family 1C member 3', other_designations='sulfotransferase 1C3|sulfotransferase family, cytosolic, 1C, member 3', map_location='2q12.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=108239968, end_position_on_the_genomic_accession=108265608, orientation='plus', exon_count=10, OMIM=[617151], no_hdr0=''),
    442117 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442117, CurrentID=0, Status='live', Symbol='GALNTL6', Aliases=['GALNACT20', 'GALNT17', 'GalNAc-T6L'], description='polypeptide N-acetylgalactosaminyltransferase like 6', other_designations='polypeptide N-acetylgalactosaminyltransferase-like 6|GaNTase 17|GalNAc transferase 17|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 17|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase 20|UDP-N-acetyl-alpha-D-galactosamine:polypeptide N-acetylgalactosaminyltransferase-like 6|galNAc-T17|polypeptide GalNAc transferase 17|polypeptide GalNAc transferase-like 6|pp-GaNTase 17|protein-UDP acetylgalactosaminyltransferase 17|putative polypeptide N-acetylgalactosaminyltransferase 17', map_location='4q34.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=171812656, end_position_on_the_genomic_accession=173041559, orientation='plus', exon_count=21, OMIM=[615138], no_hdr0=''),
    442179 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442179, CurrentID=0, Status='live', Symbol='OR1F12', Aliases=['OR1F12PQ', 'OR6-12', 'hs6M1-35P', 'OR1F12'], description='olfactory receptor family 1 subfamily F member 12', other_designations='olfactory receptor 1F12|olfactory receptor OR6-12|seven transmembrane helix receptor', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=28073316, end_position_on_the_genomic_accession=28074329, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    442184 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442184, CurrentID=0, Status='live', Symbol='OR2B3', Aliases=['6M1-1P', 'OR6-14', 'OR6-4', 'OR2B3'], description='olfactory receptor family 2 subfamily B member 3', other_designations='putative olfactory receptor 2B3|hs6M1-1|olfactory receptor 6-4|olfactory receptor OR6-14', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29086208, end_position_on_the_genomic_accession=29087313, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    442185 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442185, CurrentID=0, Status='live', Symbol='OR2J1', Aliases=['6M1-4PP', 'OR6-15', 'OR6-5', 'dJ80I19.2', 'hs6M1-4', 'OR2J1'], description='olfactory receptor family 2 subfamily J member 1', other_designations='olfactory receptor 2J1|olfactory receptor 6-5|olfactory receptor OR6-15|olfactory receptor, family 2, subfamily J, member 1 pseudogene', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29099490, end_position_on_the_genomic_accession=29102701, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    442186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442186, CurrentID=0, Status='live', Symbol='OR2J3', Aliases=['6M1-3', 'C3HEXS', 'HS6M1-3', 'OR6-16', 'OR6-6', 'OR6.3.6', 'ORL671'], description='olfactory receptor family 2 subfamily J member 3', other_designations='olfactory receptor 2J3|olfactory receptor 6-6|olfactory receptor OR6-16', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29108058, end_position_on_the_genomic_accession=29114770, orientation='plus', exon_count=4, OMIM=[615016], no_hdr0=''),
    442191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442191, CurrentID=0, Status='live', Symbol='OR14J1', Aliases=['OR5U1', 'OR6-25', 'bA150A6.4', 'hs6M1-28'], description='olfactory receptor family 14 subfamily J member 1', other_designations='olfactory receptor 14J1|olfactory receptor 5U1|olfactory receptor OR6-25|olfactory receptor, family 5, subfamily U member 1', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29301701, end_position_on_the_genomic_accession=29313017, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    442194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442194, CurrentID=0, Status='live', Symbol='OR10C1', Aliases=['OR10C1P', 'OR10C2', 'OR6-31', 'hs6M1-17'], description='olfactory receptor family 10 subfamily C member 1', other_designations='olfactory receptor 10C1|olfactory receptor 10C2|olfactory receptor OR6-31|olfactory receptor, family 10, subfamily C, member 2|seven transmembrane helix receptor', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=29439306, end_position_on_the_genomic_accession=29440977, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    442213 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442213, CurrentID=0, Status='live', Symbol='PTCHD4', Aliases=['C6orf138', 'PTCH53', 'dJ402H5.2'], description='patched domain containing 4', other_designations='patched domain-containing protein 4|p53-regulated patched protein|patched domain-containing protein C6orf138', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=47856673, end_position_on_the_genomic_accession=48111197, orientation='minus', exon_count=6, OMIM=[616908], no_hdr0=''),
    442247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442247, CurrentID=0, Status='live', Symbol='RFPL4B', Aliases=['RNF211'], description='ret finger protein like 4B', other_designations='ret finger protein-like 4B|RING finger protein 211', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=112347330, end_position_on_the_genomic_accession=112351294, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    442319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442319, CurrentID=0, Status='live', Symbol='ZNF727', Aliases=['ZNF727P'], description='zinc finger protein 727', other_designations='putative zinc finger protein 727|zinc finger protein 727 pseudogene', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64043194, end_position_on_the_genomic_accession=64085339, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    442361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442361, CurrentID=0, Status='live', Symbol='OR2A2', Aliases=['OR2A17PP', 'OR7-11', 'OST008', 'OR2A2'], description='olfactory receptor family 2 subfamily A member 2', other_designations='olfactory receptor 2A2|olfactory receptor 2A17|olfactory receptor OR7-11|olfactory receptor, family 2, subfamily A, member 17 pseudogene|olfactory receptor, family 2, subfamily A, member 2 pseudogene', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144109583, end_position_on_the_genomic_accession=144110539, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    442425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442425, CurrentID=0, Status='live', Symbol='FOXB2', Aliases=['bA159H20.4'], description='forkhead box B2', other_designations='forkhead box protein B2', map_location='9q21.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=77019655, end_position_on_the_genomic_accession=77020953, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    442444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442444, CurrentID=0, Status='live', Symbol='FAM47C', Aliases=[], description='family with sequence similarity 47 member C', other_designations='putative protein FAM47C', map_location='Xp21.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=37008366, end_position_on_the_genomic_accession=37011664, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    442572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442572, CurrentID=0, Status='live', Symbol='SPDYE21', Aliases=['SPDYE21P'], description='speedy/RINGO cell cycle regulator family member E21', other_designations='putative speedy protein E21|Putative WBSCR19-like protein 8|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E21, pseudogene', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=67276941, end_position_on_the_genomic_accession=67289005, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    442590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442590, CurrentID=0, Status='live', Symbol='SPDYE5', Aliases=[], description='speedy/RINGO cell cycle regulator family member E5', other_designations='speedy protein E5|putative Speedy protein E5|speedy homolog E5', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75492320, end_position_on_the_genomic_accession=75504316, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    442721 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442721, CurrentID=0, Status='live', Symbol='LMOD2', Aliases=['C-LMOD', 'CLMOD'], description='leiomodin 2', other_designations='leiomodin-2|cardiac leiomodin|leiomodin 2 (cardiac)', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=123655866, end_position_on_the_genomic_accession=123664290, orientation='plus', exon_count=3, OMIM=[608006], no_hdr0=''),
    442862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442862, CurrentID=0, Status='live', Symbol='PRY2', Aliases=['PTPN13LY2'], description='PTPN13 like Y-linked 2', other_designations='PTPN13-like protein, Y-linked|PTPN13-like, Y-linked, centromeric|testis-specific PTP-BL-related Y protein|testis-specific PTP-BL-related protein on Y', map_location='Yq11.223', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=22071756, end_position_on_the_genomic_accession=22096007, orientation='minus', exon_count=5, OMIM=[400041], no_hdr0=''),
    442867 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442867, CurrentID=0, Status='live', Symbol='BPY2B', Aliases=['VCY2B'], description='basic charge Y-linked 2B', other_designations='testis-specific basic protein Y 2|basic charge, Y-linked 2|basic protein on Y chromosome 2|variable charge, Y-linked, 2|variably charged protein Y 2', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=24618004, end_position_on_the_genomic_accession=24639207, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    442868 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=442868, CurrentID=0, Status='live', Symbol='BPY2C', Aliases=['VCY2C'], description='basic charge Y-linked 2C', other_designations='testis-specific basic protein Y 2|basic charge, Y-linked 2|basic protein on Y chromosome 2|variable charge, Y-linked, 2|variably charged protein Y 2', map_location='Yq11.23', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=25030901, end_position_on_the_genomic_accession=25052104, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    444882 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=444882, CurrentID=0, Status='live', Symbol='IGFL4', Aliases=[], description='IGF like family member 4', other_designations='insulin growth factor-like family member 4', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46039182, end_position_on_the_genomic_accession=46077629, orientation='minus', exon_count=8, OMIM=[610547], no_hdr0=''),
    445328 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445328, CurrentID=0, Status='live', Symbol='ARHGEF35', Aliases=['ARHGEF5L'], description='Rho guanine nucleotide exchange factor 35', other_designations='rho guanine nucleotide exchange factor 35|Rho guanine nucleotide exchange factor (GEF) 35|rho guanine nucleotide exchange factor 5-like protein', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144186083, end_position_on_the_genomic_accession=144195879, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    445329 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445329, CurrentID=0, Status='live', Symbol='SULT1A4', Aliases=['HAST3', 'M-PST', 'ST1A3', 'ST1A3/ST1A4', 'ST1A4', 'STM', 'TL-PST'], description='sulfotransferase family 1A member 4', other_designations='sulfotransferase 1A4|SLX1B-SULT1A4|Sulfotransferase 1A3|aryl sulfotransferase 1A3/1A4|catecholamine-sulfating phenol sulfotransferase|monoamine-sulfating phenol sulfotransferase|placental estrogen sulfotransferase|sulfokinase|sulfotransferase family, cytosolic, 1A, phenol-preferring, member 4|sulfotransferase, monoamine-preferring|thermolabile phenol sulfotransferase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29459913, end_position_on_the_genomic_accession=29464966, orientation='plus', exon_count=8, OMIM=[615819], no_hdr0=''),
    445347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445347, CurrentID=0, Status='live', Symbol='TARP', Aliases=['CD3G', 'TCRG', 'TCRGC1', 'TCRGC2', 'TCRGV'], description='TCR gamma alternate reading frame protein', other_designations='TCR gamma alternate reading frame protein|T cell receptor gamma chain variable|T-cell receptor gamma-chain constant region|TCR V3-JP2-Cgamma2|TCR- gamma V-IV|Vgamma9ChainTCRMOP|antigen, T-cell receptor', map_location='7p14.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=38239577, end_position_on_the_genomic_accession=38276741, orientation='minus', exon_count=10, OMIM=[609642], no_hdr0=''),
    445372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445372, CurrentID=0, Status='live', Symbol='TRIM6-TRIM34', Aliases=['IFP1', 'RNF21', 'RNF89', 'TRIM34', 'TRIM6'], description='TRIM6-TRIM34 readthrough', other_designations='tripartite motif-containing 6 and tripartite motif-containing 34|RING finger protein 21|RING finger protein 89|RING-type E3 ubiquitin transferase TRIM6|Tripartite motif-containing protein 34|Tripartite motif-containing protein 6|interferon-responsive finger protein 1 long form', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=5596637, end_position_on_the_genomic_accession=5644398, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    445571 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445571, CurrentID=0, Status='live', Symbol='CBWD3', Aliases=['bA561O23.1'], description='COBW domain containing 3', other_designations='COBW domain-containing protein 3|cobalamin synthase W domain-containing protein 3|cobalamin synthetase W domain-containing protein 3', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=68241866, end_position_on_the_genomic_accession=68300035, orientation='plus', exon_count=19, OMIM=[611080], no_hdr0=''),
    445582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445582, CurrentID=0, Status='live', Symbol='POTEE', Aliases=['A26C1', 'A26C1A', 'CT104.2', 'POTE-2', 'POTE2', 'POTE2gamma'], description='POTE ankyrin domain family member E', other_designations='POTE ankyrin domain family member E|ANKRD26-like family C member 1A|cancer/testis antigen family 104, member 2|prostate, ovary, testis-expressed protein on chromosome 2|protein expressed in prostate, ovary, testis, and placenta 2', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131209536, end_position_on_the_genomic_accession=131265278, orientation='plus', exon_count=18, OMIM=[608914], no_hdr0=''),
    445815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=445815, CurrentID=0, Status='live', Symbol='PALM2AKAP2', Aliases=['AKAP-2', 'AKAP-KL', 'AKAP2', 'AKAPKL', 'MISP2', 'PALM2', 'PALM2-AKAP2', 'PRKA2'], description='PALM2 and AKAP2 fusion', other_designations='A-kinase anchor protein 2|PALM2-AKAP2 protein|paralemmin-2|A kinase (PRKA) anchor protein 2|A-kinase anchoring protein 2|PALM2-AKAP2 fusion|PALM2-AKAP2 readthrough|paralemmin 2|protein kinase A anchoring protein 2|protein kinase A2', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=109640787, end_position_on_the_genomic_accession=110172512, orientation='plus', exon_count=15, OMIM=[604582], no_hdr0=''),
    448831 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=448831, CurrentID=0, Status='live', Symbol='FRG2', Aliases=['FRG2A'], description='FSHD region gene 2', other_designations='protein FRG2|FSHD region gene 2 protein', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=190024367, end_position_on_the_genomic_accession=190027256, orientation='minus', exon_count=4, OMIM=[609032], no_hdr0=''),
    448834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=448834, CurrentID=0, Status='live', Symbol='KPRP', Aliases=['C1orf45'], description='keratinocyte proline rich protein', other_designations='keratinocyte proline-rich protein|keratinocyte expressed, proline-rich protein', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152758025, end_position_on_the_genomic_accession=152762053, orientation='plus', exon_count=3, OMIM=[613260], no_hdr0=''),
    448835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=448835, CurrentID=0, Status='live', Symbol='LCE6A', Aliases=['C1orf44'], description='late cornified envelope 6A', other_designations='late cornified envelope protein 6A', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152842830, end_position_on_the_genomic_accession=152844211, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    474170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474170, CurrentID=0, Status='live', Symbol='LRRC37A2', Aliases=['LRRC37'], description='leucine rich repeat containing 37 member A2', other_designations='leucine-rich repeat-containing protein 37A2|c114 SLIT-like testicular protein', map_location='17q21.31-q21.32', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46512710, end_position_on_the_genomic_accession=47049128, orientation='plus', exon_count=15, OMIM=[616556], no_hdr0=''),
    474343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474343, CurrentID=0, Status='live', Symbol='SPIN2B', Aliases=['SPIN-2', 'SPIN-2B', 'SPIN2_duplicate', 'TDRD26', 'dJ323P24.2'], description='spindlin family member 2B', other_designations='spindlin-2B|spindlin family, member 2 duplicate|spindlin-like protein 2B|telomeric SPIN2 copy', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=57112142, end_position_on_the_genomic_accession=57121905, orientation='minus', exon_count=6, OMIM=[300517], no_hdr0=''),
    474344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474344, CurrentID=0, Status='live', Symbol='GIMAP6', Aliases=['IAN-2', 'IAN-6', 'IAN2', 'IAN6'], description='GTPase, IMAP family member 6', other_designations='GTPase IMAP family member 6|immune associated nucleotide 2|immune associated nucleotide 6|immune-associated nucleotide-binding protein 6', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150625375, end_position_on_the_genomic_accession=150632385, orientation='minus', exon_count=3, OMIM=[616960], no_hdr0=''),
    474354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474354, CurrentID=0, Status='live', Symbol='LRRC18', Aliases=['UNQ933', 'UNQ9338', 'VKGE9338'], description='leucine rich repeat containing 18', other_designations='leucine-rich repeat-containing protein 18', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=48909480, end_position_on_the_genomic_accession=48940126, orientation='minus', exon_count=7, OMIM=[619002], no_hdr0=''),
    474381 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474381, CurrentID=0, Status='live', Symbol='H2AB2', Aliases=['H2A.Bbd', 'H2AB3', 'H2AFB2'], description='H2A.B variant histone 2', other_designations='histone H2A-Bbd type 2/3|H2A Barr body deficient|H2A histone family member B2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155380709, end_position_on_the_genomic_accession=155381299, orientation='plus', exon_count=1, OMIM=[301038], no_hdr0=''),
    474382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474382, CurrentID=0, Status='live', Symbol='H2AB1', Aliases=['H2A.B', 'H2A.Bbd', 'H2AFB1'], description='H2A.B variant histone 1', other_designations='histone H2A-Bbd type 1|H2A Barr body-deficient|H2A histone family member B1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154884972, end_position_on_the_genomic_accession=154885558, orientation='plus', exon_count=1, OMIM=[301037], no_hdr0=''),
    474383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474383, CurrentID=0, Status='live', Symbol='F8A2', Aliases=['HAP40'], description='coagulation factor VIII associated 2', other_designations='40-kDa huntingtin-associated protein|coagulation factor VIII-associated (intronic transcript) 2|cpG island protein|factor VIII intron 22 protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155382095, end_position_on_the_genomic_accession=155383801, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    474384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=474384, CurrentID=0, Status='live', Symbol='F8A3', Aliases=['HAP40'], description='coagulation factor VIII associated 3', other_designations='40-kDa huntingtin-associated protein|coagulation factor VIII-associated (intronic transcript) 3|cpG island protein|factor VIII intron 22 protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155456914, end_position_on_the_genomic_accession=155458620, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    492307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=492307, CurrentID=0, Status='live', Symbol='PPDPFL', Aliases=['C8orf22'], description='pancreatic progenitor cell differentiation and proliferation factor like', other_designations='pancreatic progenitor cell differentiation and proliferation factor-like protein|exocrine differentiation and proliferation factor-like protein', map_location='8q11.21', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=49054336, end_position_on_the_genomic_accession=49076093, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    492311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=492311, CurrentID=0, Status='live', Symbol='IGIP', Aliases=['C5orf53'], description='IgA inducing protein', other_designations='IgA-inducing protein homolog|IgA-inducing protein homolog (Bos taurus)', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140125937, end_position_on_the_genomic_accession=140129392, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    493753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493753, CurrentID=0, Status='live', Symbol='COA5', Aliases=['6330578E17Rik', 'C2orf64', 'CEMCOX3', 'MC4DN9', 'Pet191'], description='cytochrome c oxidase assembly factor 5', other_designations='cytochrome c oxidase assembly factor 5|protein C2orf64', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=98599314, end_position_on_the_genomic_accession=98608512, orientation='minus', exon_count=3, OMIM=[613920], no_hdr0=''),
    493829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493829, CurrentID=0, Status='live', Symbol='TRIM72', Aliases=['MG53'], description='tripartite motif containing 72', other_designations='tripartite motif-containing protein 72|mitsugumin-53|tripartite motif containing 72, E3 ubiquitin protein ligase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=31214119, end_position_on_the_genomic_accession=31231537, orientation='plus', exon_count=8, OMIM=[613288], no_hdr0=''),
    493856 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493856, CurrentID=0, Status='live', Symbol='CISD2', Aliases=['ERIS', 'Miner1', 'NAF-1', 'WFS2', 'ZCD2'], description='CDGSH iron sulfur domain 2', other_designations='CDGSH iron-sulfur domain-containing protein 2|endoplasmic reticulum intermembrane small protein|mitoNEET-related 1 protein|nutrient-deprivation autophagy factor-1|zinc finger, CDGSH-type domain 2', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=102868992, end_position_on_the_genomic_accession=102892807, orientation='plus', exon_count=3, OMIM=[611507], no_hdr0=''),
    493860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493860, CurrentID=0, Status='live', Symbol='CCDC73', Aliases=['NY-SAR-79'], description='coiled-coil domain containing 73', other_designations='coiled-coil domain-containing protein 73|sarcoma antigen NY-SAR-79', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32602721, end_position_on_the_genomic_accession=32794662, orientation='minus', exon_count=18, OMIM=[612328], no_hdr0=''),
    493861 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493861, CurrentID=0, Status='live', Symbol='EID3', Aliases=['NS4EB', 'NSE4B', 'NSMCE4B'], description='EP300 interacting inhibitor of differentiation 3', other_designations='EP300-interacting inhibitor of differentiation 3|E1A-like inhibitor of differentiation 3|EID-1-like inhibitor of differentiation 3|EID-3|NSE4 homolog B|non-SMC element 4 homolog B|non-structural maintenance of chromosomes element 4 homolog B|testis tissue sperm-binding protein Li 96mP', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=104303739, end_position_on_the_genomic_accession=104305205, orientation='plus', exon_count=1, OMIM=[612986], no_hdr0=''),
    493869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493869, CurrentID=0, Status='live', Symbol='GPX8', Aliases=['EPLA847', 'GPx-8', 'GSHPx-8', 'UNQ847'], description='glutathione peroxidase 8 (putative)', other_designations='probable glutathione peroxidase 8', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=55160155, end_position_on_the_genomic_accession=55167297, orientation='plus', exon_count=4, OMIM=[617172], no_hdr0=''),
    493901 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493901, CurrentID=0, Status='live', Symbol='RNASE12', Aliases=['HEL-S-85p', 'RAI1'], description='ribonuclease A family member 12 (inactive)', other_designations='probable inactive ribonuclease-like protein 12|epididymis secretory sperm binding protein Li 85p|ribonuclease A I1|ribonuclease, RNase A family, 12 (non-active)|ribonuclease-like protein 12', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=20590073, end_position_on_the_genomic_accession=20590823, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    493911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=493911, CurrentID=0, Status='live', Symbol='PHOSPHO2', Aliases=[], description='phosphatase, orphan 2', other_designations='pyridoxal phosphate phosphatase PHOSPHO2', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169694469, end_position_on_the_genomic_accession=169701708, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    494115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494115, CurrentID=0, Status='live', Symbol='RBMXL1', Aliases=['RBM1'], description='RBMX like 1', other_designations='RNA binding motif protein, X-linked-like-1|RNA binding motif protein, X-linked like 1|heterogeneous nuclear ribonucleoprotein G-like 1', map_location='1p22.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=88979456, end_position_on_the_genomic_accession=88992629, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    494118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494118, CurrentID=0, Status='live', Symbol='SPANXN1', Aliases=['CT11.6'], description='SPANX family member N1', other_designations='sperm protein associated with the nucleus on the X chromosome N1|cancer/testis antigen family 11, member 6|nuclear-associated protein SPAN-Xn1', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=145247503, end_position_on_the_genomic_accession=145256208, orientation='plus', exon_count=2, OMIM=[300664], no_hdr0=''),
    494119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494119, CurrentID=0, Status='live', Symbol='SPANXN2', Aliases=['CT11.7', 'SPANX-N2'], description='SPANX family member N2', other_designations='sperm protein associated with the nucleus on the X chromosome N2|cancer/testis antigen family 11, member 7|nuclear-associated protein SPAN-Xn2', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=143712035, end_position_on_the_genomic_accession=143720668, orientation='minus', exon_count=2, OMIM=[300665], no_hdr0=''),
    494143 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494143, CurrentID=0, Status='live', Symbol='CHAC2', Aliases=['GCG1'], description='ChaC glutathione specific gamma-glutamylcyclotransferase 2', other_designations='glutathione-specific gamma-glutamylcyclotransferase 2|ChaC cation transport regulator homolog 2|ChaC, cation transport regulator-like 2|cation transport regulator-like protein 2|gamma-GCG 2|gamma-GCT acting on glutathione homolog 2|putative glutathione-specific gamma-glutamylcyclotransferase 2', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53767783, end_position_on_the_genomic_accession=53775196, orientation='plus', exon_count=3, OMIM=[617446], no_hdr0=''),
    494188 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494188, CurrentID=0, Status='live', Symbol='FBXO47', Aliases=[], description='F-box protein 47', other_designations='F-box only protein 47', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38936278, end_position_on_the_genomic_accession=38967476, orientation='minus', exon_count=11, OMIM=[609498], no_hdr0=''),
    494197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494197, CurrentID=0, Status='live', Symbol='SPANXN5', Aliases=['CT11.10', 'SPANX-N5'], description='SPANX family member N5', other_designations='sperm protein associated with the nucleus on the X chromosome N5|cancer/testis antigen family 11, member 10|nuclear-associated protein SPAN-Xn5', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52796144, end_position_on_the_genomic_accession=52797427, orientation='minus', exon_count=2, OMIM=[300668], no_hdr0=''),
    494470 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494470, CurrentID=0, Status='live', Symbol='RNF165', Aliases=['ARKL2', 'Ark2C', 'RNF111L2'], description='ring finger protein 165', other_designations='E3 ubiquitin-protein ligase RNF165', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=46334018, end_position_on_the_genomic_accession=46463145, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    494513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494513, CurrentID=0, Status='live', Symbol='PJVK', Aliases=['DFNB59'], description='pejvakin', other_designations='pejvakin|autosomal recessive deafness type 59 protein', map_location='2q31.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=178450592, end_position_on_the_genomic_accession=178467549, orientation='plus', exon_count=10, OMIM=[610219], no_hdr0=''),
    494551 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=494551, CurrentID=0, Status='live', Symbol='WEE2', Aliases=['OOMD5', 'WEE1B'], description='WEE2 oocyte meiosis inhibiting kinase', other_designations='wee1-like protein kinase 2|WEE1 homolog 2|wee1-like protein kinase 1B|wee1B kinase', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141708353, end_position_on_the_genomic_accession=141731271, orientation='plus', exon_count=12, OMIM=[614084], no_hdr0=''),
    497189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=497189, CurrentID=0, Status='live', Symbol='TIFAB', Aliases=[], description='TIFA inhibitor', other_designations='TRAF-interacting protein with FHA domain-containing protein B|TIFA-like protein|TIFA-related protein TIFAB|TRAF-interacting protein with forkhead-associated domain, family member B', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=135444226, end_position_on_the_genomic_accession=135452351, orientation='minus', exon_count=2, OMIM=[612663], no_hdr0=''),
    497190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=497190, CurrentID=0, Status='live', Symbol='CLEC18B', Aliases=['MRCL2'], description='C-type lectin domain family 18 member B', other_designations='C-type lectin domain family 18 member B|mannose receptor-like 2|mannose receptor-like protein 1|secretory protein LOC497190', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=74408631, end_position_on_the_genomic_accession=74422248, orientation='minus', exon_count=16, OMIM=[616572], no_hdr0=''),
    497661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=497661, CurrentID=0, Status='live', Symbol='C18orf32', Aliases=[], description='chromosome 18 open reading frame 32', other_designations='UPF0729 protein C18orf32|putative NF-kappa-B-activating protein 200|putative NFkB activating protein', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49477243, end_position_on_the_genomic_accession=49487234, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    503497 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503497, CurrentID=0, Status='live', Symbol='MS4A13', Aliases=[], description='membrane spanning 4-domains A13', other_designations='membrane-spanning 4-domains subfamily A member 13|testis-expressed transmembrane protein 4|testis-expressed transmembrane-4 protein', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60515382, end_position_on_the_genomic_accession=60543424, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    503542 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503542, CurrentID=0, Status='live', Symbol='SPRN', Aliases=['SHADOO', 'SHO', 'bA108K14.1'], description='shadow of prion protein', other_designations='shadow of prion protein|hypothetical protein BC004409|protein shadoo|shadow of prion protein homolog', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=133420666, end_position_on_the_genomic_accession=133424625, orientation='minus', exon_count=2, OMIM=[610447], no_hdr0=''),
    503582 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503582, CurrentID=0, Status='live', Symbol='ARGFX', Aliases=[], description='arginine-fifty homeobox', other_designations='arginine-fifty homeobox', map_location='3q13.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=121567949, end_position_on_the_genomic_accession=121590622, orientation='plus', exon_count=5, OMIM=[611164], no_hdr0=''),
    503614 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503614, CurrentID=0, Status='live', Symbol='DEFB107B', Aliases=['HsT21816'], description='defensin beta 107B', other_designations='beta-defensin 107|beta-defensin 7|defensin, beta 107', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7495911, end_position_on_the_genomic_accession=7509311, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    503618 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503618, CurrentID=0, Status='live', Symbol='DEFB104B', Aliases=['BD-4', 'DEFB-4', 'hBD-4'], description='defensin beta 104B', other_designations='beta-defensin 104|beta-defensin 4|defensin, beta 104', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7470308, end_position_on_the_genomic_accession=7475082, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    503834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503834, CurrentID=0, Status='live', Symbol='DPRX', Aliases=[], description='divergent-paired related homeobox', other_designations='divergent paired-related homeobox', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53601114, end_position_on_the_genomic_accession=53637057, orientation='plus', exon_count=5, OMIM=[611165], no_hdr0=''),
    503835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503835, CurrentID=0, Status='live', Symbol='DUXA', Aliases=[], description='double homeobox A', other_designations='double homeobox protein A', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57154021, end_position_on_the_genomic_accession=57167485, orientation='minus', exon_count=6, OMIM=[611168], no_hdr0=''),
    503841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=503841, CurrentID=0, Status='live', Symbol='DEFB106B', Aliases=['BD-6', 'DEFB-6'], description='defensin beta 106B', other_designations='beta-defensin 106|beta-defensin 6|defensin, beta 106', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7482504, end_position_on_the_genomic_accession=7486400, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    504180 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=504180, CurrentID=0, Status='live', Symbol='DEFB105B', Aliases=['BD-5', 'DEFB-5'], description='defensin beta 105B', other_designations='beta-defensin 105|beta-defensin 5|defensin, beta 105', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7487679, end_position_on_the_genomic_accession=7489593, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    504189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=504189, CurrentID=0, Status='live', Symbol='OR8U8', Aliases=[], description='olfactory receptor family 8 subfamily U member 8', other_designations='olfactory receptor 8U8', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    504190 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=504190, CurrentID=0, Status='live', Symbol='OR8U9', Aliases=[], description='olfactory receptor family 8 subfamily U member 9', other_designations='olfactory receptor 8U9', map_location='11q1', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    504191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=504191, CurrentID=0, Status='live', Symbol='OR9G9', Aliases=['OR9G1'], description='olfactory receptor family 9 subfamily G member 9', other_designations='olfactory receptor 9G9', map_location='11q11', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    541465 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=541465, CurrentID=0, Status='live', Symbol='CT45A6', Aliases=['CT45-5', 'CT45-6', 'CT45.6', 'CT45A5', 'CT45A7'], description='cancer/testis antigen family 45 member A6', other_designations='cancer/testis antigen family 45 member A6|Cancer/testis antigen 45-5|Cancer/testis antigen 45A5|Cancer/testis antigen 45A7|Cancer/testis antigen family 45 member A5|Cancer/testis antigen family 45 member A7|cancer/testis antigen 45-4/6|cancer/testis antigen 45-6|cancer/testis antigen 45A4/45A6|cancer/testis antigen 45A6|cancer/testis antigen CT45-6|cancer/testis antigen family 45 member A4/A6', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135794685, end_position_on_the_genomic_accession=135802787, orientation='minus', exon_count=5, OMIM=[300797], no_hdr0=''),
    541466 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=541466, CurrentID=0, Status='live', Symbol='CT45A1', Aliases=['CT45', 'CT45-1', 'CT45.1'], description='cancer/testis antigen family 45 member A1', other_designations='cancer/testis antigen family 45 member A1|cancer/testis antigen 45-1|cancer/testis antigen 45A1|cancer/testis antigen CT45-1', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135708398, end_position_on_the_genomic_accession=135723318, orientation='plus', exon_count=7, OMIM=[300648], no_hdr0=''),
    541468 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=541468, CurrentID=0, Status='live', Symbol='LURAP1', Aliases=['C1orf190', 'LRAP35a', 'LRP35A'], description='leucine rich adaptor protein 1', other_designations='leucine rich adaptor protein 1|NF-kappa-B activator C1orf190|leucine repeat adapter protein 35A|leucine repeat adaptor protein 35a', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46203334, end_position_on_the_genomic_accession=46221256, orientation='plus', exon_count=2, OMIM=[616129], no_hdr0=''),
    541565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=541565, CurrentID=0, Status='live', Symbol='C8orf58', Aliases=[], description='chromosome 8 open reading frame 58', other_designations='uncharacterized protein C8orf58', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22599599, end_position_on_the_genomic_accession=22604142, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    541578 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=541578, CurrentID=0, Status='live', Symbol='EOLA2', Aliases=['CXorf40B'], description='endothelium and lymphocyte associated ASCH domain 2', other_designations='protein EOLA2|protein CXorf40B', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149924152, end_position_on_the_genomic_accession=149938845, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    548313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=548313, CurrentID=0, Status='live', Symbol='SSX4B', Aliases=['CT5.4'], description='SSX family member 4B', other_designations='protein SSX4|cancer/testis antigen 5.4|synovial sarcoma, X breakpoint 4B', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48402082, end_position_on_the_genomic_accession=48411960, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    548593 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=548593, CurrentID=0, Status='live', Symbol='SLX1A', Aliases=['GIYD1'], description='SLX1 homolog A, structure-specific endonuclease subunit', other_designations='structure-specific endonuclease subunit SLX1|GIY-YIG domain-containing protein 1|SLX1 structure-specific endonuclease subunit homolog A', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30193843, end_position_on_the_genomic_accession=30197566, orientation='plus', exon_count=6, OMIM=[615822], no_hdr0=''),
    548596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=548596, CurrentID=0, Status='live', Symbol='CKMT1A', Aliases=['CKMT1', 'U-MtCK', 'mia-CK'], description='creatine kinase, mitochondrial 1A', other_designations='creatine kinase U-type, mitochondrial|acidic-type mitochondrial creatine kinase|creatine kinase, mitochondrial 1 (ubiquitous)|ubiquitous mitochondrial creatine kinase', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43692644, end_position_on_the_genomic_accession=43699222, orientation='plus', exon_count=11, OMIM=[613415], no_hdr0=''),
    548644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=548644, CurrentID=0, Status='live', Symbol='POLR2J3', Aliases=['POLR2J2', 'RPB11b1', 'RPB11b2'], description='RNA polymerase II subunit J3', other_designations='DNA-directed RNA polymerase II subunit RPB11-b2|DNA-directed RNA polymerase II subunit 11|DNA-directed RNA polymerase II subunit J2|DNA-directed RNA polymerase II subunit J3|DNA-directed RNA polymerase II subunit RPB11-b1|RNA polymerase II subunit B11-b1|RNA polymerase II subunit B11-b2|polymerase (RNA) II (DNA directed) polypeptide J3|polymerase (RNA) II subunit J3', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102537919, end_position_on_the_genomic_accession=102572621, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    548645 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=548645, CurrentID=0, Status='live', Symbol='DNAJC25', Aliases=['bA16L21.2.1'], description='DnaJ heat shock protein family (Hsp40) member C25', other_designations='dnaJ homolog subfamily C member 25|DnaJ (Hsp40) homolog, subfamily C , member 25|DnaJ-like protein', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111631334, end_position_on_the_genomic_accession=111654345, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    550631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=550631, CurrentID=0, Status='live', Symbol='CCDC157', Aliases=[], description='coiled-coil domain containing 157', other_designations='coiled-coil domain-containing protein 157', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30356624, end_position_on_the_genomic_accession=30378673, orientation='plus', exon_count=14, OMIM=[619391], no_hdr0=''),
    550643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=550643, CurrentID=0, Status='live', Symbol='NBDY', Aliases=['LINC01420', 'NoBody'], description='negative regulator of P-body association', other_designations='negative regulator of P-body association|P-body dissociating protein|long intergenic non-protein coding RNA 1420|non-annotated P-body dissociating polypeptide|protein NoBody', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=56729242, end_position_on_the_genomic_accession=56819179, orientation='plus', exon_count=3, OMIM=[300992], no_hdr0=''),
    552889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=552889, CurrentID=0, Status='live', Symbol='ATXN7L3B', Aliases=['lnc-SCA7'], description='ataxin 7 like 3B', other_designations='ataxin-7-like protein 3B|putative ataxin-7-like protein 3B', map_location='12q21.1', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=74537835, end_position_on_the_genomic_accession=74545430, orientation='plus', exon_count=1, OMIM=[615579], no_hdr0=''),
    552891 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=552891, CurrentID=0, Status='live', Symbol='DNAJC25-GNG10', Aliases=[], description='DNAJC25-GNG10 readthrough', other_designations='DNAJC25-GNG10 protein|DNAJC25-GNG10 readthrough transcript', map_location='9q31.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=111631334, end_position_on_the_genomic_accession=111670226, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    552900 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=552900, CurrentID=0, Status='live', Symbol='BOLA2', Aliases=['BOLA2AB', 'My016', 'BOLA2'], description='bolA family member 2', other_designations='bolA-like protein 2|BolA-like protein 2 member A|bolA homolog 2', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29453588, end_position_on_the_genomic_accession=29454964, orientation='minus', exon_count=2, OMIM=[613182], no_hdr0=''),
    553115 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=553115, CurrentID=0, Status='live', Symbol='PEF1', Aliases=['ABP32A', 'PEF1'], description='penta-EF-hand domain containing 1', other_designations='peflin|PEF protein with a long N-terminal hydrophobic domain|epididymis secretory sperm binding protein', map_location='1p35.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=31629866, end_position_on_the_genomic_accession=31644876, orientation='minus', exon_count=7, OMIM=[610033], no_hdr0=''),
    553128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=553128, CurrentID=0, Status='live', Symbol='KIR2DL5B', Aliases=['KIR2DL5', 'KIR2DL5.2', 'KIR2DLX'], description='killer cell immunoglobulin like receptor, two Ig domains and long cytoplasmic tail 5B', other_designations='killer cell immunoglobulin-like receptor 2DL5B|CD158 antigen-like family member F2|killer Ig receptor|killer cell immunoglobulin-like receptor 2DL5|killer cell immunoglobulin-like receptor 2DLX|killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 5|killer cell immunoglobulin-like receptor, two domains, long cytoplasmic tail, 5B|killer-cell Ig-like receptor', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[615727], no_hdr0=''),
    553158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=553158, CurrentID=0, Status='live', Symbol='PRR5-ARHGAP8', Aliases=[], description='PRR5-ARHGAP8 readthrough', other_designations='PRR5-ARHGAP8 fusion protein|PRR5-ARHGAP8 fusion', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=44702204, end_position_on_the_genomic_accession=44862784, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    554226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554226, CurrentID=0, Status='live', Symbol='ANKRD30BL', Aliases=['ANKRD30BP3', 'NCRNA00164'], description='ankyrin repeat domain 30B like', other_designations='putative ankyrin repeat domain-containing protein 30B-like|ankyrin repeat domain 30B pseudogene 3', map_location='2q21.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=132147591, end_position_on_the_genomic_accession=132258033, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    554235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554235, CurrentID=0, Status='live', Symbol='ASPDH', Aliases=[], description='aspartate dehydrogenase domain containing', other_designations='putative L-aspartate dehydrogenase|aspartate dehydrogenase domain-containing protein', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50511600, end_position_on_the_genomic_accession=50514684, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    554251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554251, CurrentID=0, Status='live', Symbol='FBXO48', Aliases=[], description='F-box protein 48', other_designations='F-box only protein 48', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=68459422, end_position_on_the_genomic_accession=68467325, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    554282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554282, CurrentID=0, Status='live', Symbol='FAM72C', Aliases=[], description='family with sequence similarity 72 member C', other_designations='protein FAM72C|RP5-998N21.9', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=143955287, end_position_on_the_genomic_accession=143973564, orientation='minus', exon_count=8, OMIM=[616853], no_hdr0=''),
    554313 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=554313, CurrentID=0, Status='live', Symbol='H4C15', Aliases=['H4-16', 'H4/o', 'H4C1', 'H4C11', 'H4C12', 'H4C13', 'H4C14', 'H4C2', 'H4C3', 'H4C4', 'H4C5', 'H4C6', 'H4C8', 'H4C9', 'HIST2H4B'], description='H4 clustered histone 15', other_designations='histone H4|histone 2, H4b|histone cluster 2 H4 family member b|histone cluster 2, H4b', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149853262, end_position_on_the_genomic_accession=149861159, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    574414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=574414, CurrentID=0, Status='live', Symbol='PRR9', Aliases=[], description='proline rich 9', other_designations='proline-rich protein 9', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=153217584, end_position_on_the_genomic_accession=153219310, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    574431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=574431, CurrentID=0, Status='live', Symbol='C1orf147', Aliases=[], description='chromosome 1 open reading frame 147', other_designations='', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    574537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=574537, CurrentID=0, Status='live', Symbol='UGT2A2', Aliases=['UDPGT 2A2'], description='UDP glucuronosyltransferase family 2 member A2', other_designations='UDP-glucuronosyltransferase 2A2|UDP glucuronosyltransferase 2 family, polypeptide A2', map_location='4q13.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=69588417, end_position_on_the_genomic_accession=69639642, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    594855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=594855, CurrentID=0, Status='live', Symbol='CPLX3', Aliases=['CPX-III', 'CPXIII', 'Nbla11589'], description='complexin 3', other_designations='complexin-3|CPX III|complexin III|epididymis secretory sperm binding protein', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74826627, end_position_on_the_genomic_accession=74831802, orientation='plus', exon_count=3, OMIM=[609585], no_hdr0=''),
    594857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=594857, CurrentID=0, Status='live', Symbol='NPS', Aliases=[], description='neuropeptide S', other_designations='neuropeptide S|prepro-neuropeptide S', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=127549309, end_position_on_the_genomic_accession=127553540, orientation='plus', exon_count=3, OMIM=[609513], no_hdr0=''),
    606495 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=606495, CurrentID=0, Status='live', Symbol='CYB5RL', Aliases=[], description='cytochrome b5 reductase like', other_designations='NADH-cytochrome b5 reductase-like', map_location='1p32.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=54169651, end_position_on_the_genomic_accession=54200030, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    613037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613037, CurrentID=0, Status='live', Symbol='NPIPB13', Aliases=[], description='nuclear pore complex interacting protein family, member B13', other_designations='nuclear pore complex-interacting protein family member B13|Putative NPIP-like protein LOC613037|nuclear pore complex interacting protein member', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30222735, end_position_on_the_genomic_accession=30248413, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    613209 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613209, CurrentID=0, Status='live', Symbol='DEFB135', Aliases=['DEFB136'], description='defensin beta 135', other_designations='beta-defensin 135|beta-defensin 136', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11982256, end_position_on_the_genomic_accession=11984590, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    613210 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613210, CurrentID=0, Status='live', Symbol='DEFB136', Aliases=['DEFB137'], description='defensin beta 136', other_designations='beta-defensin 136|beta-defensin 137', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11973937, end_position_on_the_genomic_accession=11974599, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    613211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613211, CurrentID=0, Status='live', Symbol='DEFB134', Aliases=[], description='defensin beta 134', other_designations='beta-defensin 134|beta-defensin 135', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=11993174, end_position_on_the_genomic_accession=12000752, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    613212 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613212, CurrentID=0, Status='live', Symbol='CTXN3', Aliases=['KABE'], description='cortexin 3', other_designations='cortexin-3|kidney and brain-expressed protein', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127649082, end_position_on_the_genomic_accession=127658630, orientation='plus', exon_count=4, OMIM=[618746], no_hdr0=''),
    613227 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=613227, CurrentID=0, Status='live', Symbol='HIGD1C', Aliases=['GM921'], description='HIG1 hypoxia inducible domain family member 1C', other_designations='HIG1 domain family member 1C|HIG1 domain family, member 1C', map_location='12q13.12', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=50936111, end_position_on_the_genomic_accession=50972592, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    619189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=619189, CurrentID=0, Status='live', Symbol='SERINC4', Aliases=[], description='serine incorporator 4', other_designations='serine incorporator 4', map_location='15q15.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=43794162, end_position_on_the_genomic_accession=43800220, orientation='minus', exon_count=12, OMIM=[614550], no_hdr0=''),
    619208 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=619208, CurrentID=0, Status='live', Symbol='FAM229B', Aliases=['C6orf225'], description='family with sequence similarity 229 member B', other_designations='protein FAM229B|UPF0731 protein C6orf225', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=112087591, end_position_on_the_genomic_accession=112102790, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    619279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=619279, CurrentID=0, Status='live', Symbol='ZNF704', Aliases=['Gig1'], description='zinc finger protein 704', other_designations='zinc finger protein 704', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=80628451, end_position_on_the_genomic_accession=80884416, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    619373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=619373, CurrentID=0, Status='live', Symbol='MBOAT4', Aliases=['FKSG89', 'GOAT', 'OACT4'], description='membrane bound O-acyltransferase domain containing 4', other_designations='ghrelin O-acyltransferase|O-acyltransferase (membrane bound) domain containing 4|O-acyltransferase domain-containing protein 4|membrane-bound O-acyltransferase domain-containing protein 4', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30131454, end_position_on_the_genomic_accession=30148768, orientation='minus', exon_count=4, OMIM=[611940], no_hdr0=''),
    641339 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641339, CurrentID=0, Status='live', Symbol='ZNF674', Aliases=['MRX92', 'ZNF673B'], description='zinc finger protein 674', other_designations='zinc finger protein 674|zinc finger family member 674', map_location='Xp11.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=46497725, end_position_on_the_genomic_accession=46545466, orientation='minus', exon_count=8, OMIM=[300573], no_hdr0=''),
    641371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641371, CurrentID=0, Status='live', Symbol='ACOT1', Aliases=['ACH2', 'CTE-1', 'LACH2'], description='acyl-CoA thioesterase 1', other_designations='acyl-coenzyme A thioesterase 1|CTE-I|CTE-Ib|inducible cytosolic acyl-coenzyme A thioester hydrolase|long chain acyl-CoA hydrolase|long chain acyl-CoA thioester hydrolase|palmitoyl-coenzyme A thioesterase', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73493021, end_position_on_the_genomic_accession=73543799, orientation='plus', exon_count=10, OMIM=[614313], no_hdr0=''),
    641372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641372, CurrentID=0, Status='live', Symbol='ACOT6', Aliases=['C14orf42', 'c14_5530'], description='acyl-CoA thioesterase 6', other_designations='putative acyl-coenzyme A thioesterase 6|putative acyl-CoA thioesterase 6', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=73610945, end_position_on_the_genomic_accession=73619888, orientation='plus', exon_count=5, OMIM=[614267], no_hdr0=''),
    641455 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641455, CurrentID=0, Status='live', Symbol='POTEM', Aliases=['ACT', 'P704P', 'POTE14beta'], description='POTE ankyrin domain family member M', other_designations='putative POTE ankyrin domain family member M|ANKRD26-like family C member ENSP00000349402|prostate-specific P704P', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=18967434, end_position_on_the_genomic_accession=19003752, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    641517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641517, CurrentID=0, Status='live', Symbol='DEFB109B', Aliases=['DEF109P1B', 'DEFB109', 'DEFB109P1B', 'HBD9'], description='defensin beta 109B', other_designations='putative beta-defensin 109B|defensin beta 109 pseudogene 1B|defensin, beta 9 pseudogene', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7312846, end_position_on_the_genomic_accession=7319951, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    641649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641649, CurrentID=0, Status='live', Symbol='TMEM91', Aliases=['DSPC3', 'IFITMD6'], description='transmembrane protein 91', other_designations='transmembrane protein 91|dispanin subfamily C member 3|interferon induced transmembrane protein domain containing 6', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41363947, end_position_on_the_genomic_accession=41384083, orientation='plus', exon_count=7, OMIM=[618294], no_hdr0=''),
    641700 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641700, CurrentID=0, Status='live', Symbol='ECSCR', Aliases=['ARIA', 'ECSM2'], description='endothelial cell surface expressed chemotaxis and apoptosis regulator', other_designations='endothelial cell-specific chemotaxis regulator|apoptosis regulator through modulating IAP expression|endothelial cell-specific molecule 2', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139448560, end_position_on_the_genomic_accession=139462743, orientation='minus', exon_count=11, OMIM=[615736], no_hdr0=''),
    641776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=641776, CurrentID=0, Status='live', Symbol='SPDYE14', Aliases=['SPDYE13P', 'SPDYE14'], description='speedy/RINGO cell cycle regulator family member E14', other_designations='speedy/RINGO cell cycle regulator family member E14|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene|speedy/RINGO cell cycle regulator family member E14, pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75237205, end_position_on_the_genomic_accession=75317429, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    642273 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642273, CurrentID=0, Status='live', Symbol='FAM110C', Aliases=[], description='family with sequence similarity 110 member C', other_designations='protein FAM110C', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38814, end_position_on_the_genomic_accession=47077, orientation='minus', exon_count=6, OMIM=[611395], no_hdr0=''),
    642446 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642446, CurrentID=0, Status='live', Symbol='TRIM64B', Aliases=[], description='tripartite motif containing 64B', other_designations='putative tripartite motif-containing protein 64B', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89870188, end_position_on_the_genomic_accession=89878456, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    642475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642475, CurrentID=0, Status='live', Symbol='MROH6', Aliases=['C8orf73'], description='maestro heat like repeat family member 6', other_designations='maestro heat-like repeat-containing protein family member 6', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143566189, end_position_on_the_genomic_accession=143572772, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    642515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642515, CurrentID=0, Status='live', Symbol='PRRT1B', Aliases=['DSPD2', 'IFITMD8'], description='proline rich transmembrane protein 1B', other_designations='proline rich transmembrane protein 1B|dispanin subfamily D member 2|proline-rich transmembrane protein 1-like', map_location='9q34.13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=131545523, end_position_on_the_genomic_accession=131559199, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    642517 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642517, CurrentID=0, Status='live', Symbol='AGAP9', Aliases=['AGAP-9', 'CTGLF6', 'bA301J7.2'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 9', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 9|centaurin-gamma-like family member 6', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47501854, end_position_on_the_genomic_accession=47523638, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    642574 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642574, CurrentID=0, Status='live', Symbol='IQANK1', Aliases=['FAM83H-AS1', 'FAM83HAS1', 'onco-lncRNA-3'], description='IQ motif and ankyrin repeat containing 1', other_designations='IQ motif and ankyrin repeat domain-containing protein 1|FAM83H antisense RNA 1 (head to head)|IQ motif and ankyrin repeat domain-containing protein LOC642574|putative IQ motif and ankyrin repeat domain-containing protein LOC642574', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143734139, end_position_on_the_genomic_accession=143790702, orientation='plus', exon_count=15, OMIM=[618942], no_hdr0=''),
    642597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642597, CurrentID=0, Status='live', Symbol='AKAIN1', Aliases=['C18orf42'], description='A-kinase anchor inhibitor 1', other_designations='A-kinase anchor protein inhibitor 1|A kinase (PRKA) anchor inhibitor 1|A-kinase anchor protein C18orf42', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5142911, end_position_on_the_genomic_accession=5197691, orientation='minus', exon_count=3, OMIM=[616427], no_hdr0=''),
    642612 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642612, CurrentID=0, Status='live', Symbol='TRIM49C', Aliases=['TRIM49L2'], description='tripartite motif containing 49C', other_designations='tripartite motif-containing protein 49C|Tripartite motif-containing protein LOC642612|tripartite motif containing 49-like 2|tripartite motif-containing protein 49-like protein 2', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=90031106, end_position_on_the_genomic_accession=90073546, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    642623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642623, CurrentID=0, Status='live', Symbol='UBTFL1', Aliases=['C11orf27', 'HMGPI'], description='upstream binding transcription factor like 1', other_designations='upstream-binding factor 1-like protein 1|putative upstream-binding factor 1-like protein 1|upstream binding transcription factor, RNA polymerase I-like 1', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=90085950, end_position_on_the_genomic_accession=90087131, orientation='plus', exon_count=1, OMIM=[613696], no_hdr0=''),
    642636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642636, CurrentID=0, Status='live', Symbol='RAD21L1', Aliases=['RAD21L', 'dJ545L17.2'], description='RAD21 cohesin complex component like 1', other_designations='double-strand-break repair protein rad21-like protein 1|RAD21-like 1', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=1226043, end_position_on_the_genomic_accession=1255876, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    642658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642658, CurrentID=0, Status='live', Symbol='SCX', Aliases=['SCXAB', 'bHLHa48', 'SCX'], description='scleraxis bHLH transcription factor', other_designations='basic helix-loop-helix transcription factor scleraxis|class A basic helix-loop-helix protein 41|class A basic helix-loop-helix protein 48|class II bHLH protein scleraxis|scleraxis basic helix-loop-helix transcription factor|scleraxis homolog A|scleraxis homolog B', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144265060, end_position_on_the_genomic_accession=144268483, orientation='plus', exon_count=3, OMIM=[609067], no_hdr0=''),
    642778 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642778, CurrentID=0, Status='live', Symbol='NPIPA3', Aliases=[], description='nuclear pore complex interacting protein family member A3', other_designations='nuclear pore complex-interacting protein family member A3', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14706473, end_position_on_the_genomic_accession=14726338, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    642797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642797, CurrentID=0, Status='live', Symbol='DNAH10OS', Aliases=[], description='dynein axonemal heavy chain 10 opposite strand', other_designations='dynein, axonemal, heavy chain 10 opposite strand (non-protein coding)', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    642799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642799, CurrentID=0, Status='live', Symbol='NPIPA2', Aliases=['NPIP', 'NPIPA1'], description='nuclear pore complex interacting protein family member A2', other_designations='nuclear pore complex-interacting protein family member A2|Nuclear pore complex-interacting protein family member A1', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14745595, end_position_on_the_genomic_accession=14765448, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    642819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642819, CurrentID=0, Status='live', Symbol='ZNF487', Aliases=['KRBO1P', 'ZNF487'], description='zinc finger protein 487', other_designations='putative zinc finger protein 487|KRAB domain only 1|KRAB domain only protein 1|zinc finger protein 487, pseudogene', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43436848, end_position_on_the_genomic_accession=43483184, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    642843 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642843, CurrentID=0, Status='live', Symbol='CPSF4L', Aliases=[], description='cleavage and polyadenylation specific factor 4 like', other_designations='putative cleavage and polyadenylation specificity factor subunit 4-like protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=73242343, end_position_on_the_genomic_accession=73263778, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    642938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642938, CurrentID=0, Status='live', Symbol='INSYN2A', Aliases=['C10orf141', 'FAM196A', 'INSYN2'], description='inhibitory synaptic factor 2A', other_designations='inhibitory synaptic factor 2A|family with sequence similarity 196 member A|inhibitory synaptic protein 2|protein FAM196A', map_location='10q26.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=127135430, end_position_on_the_genomic_accession=127196591, orientation='minus', exon_count=7, OMIM=[617129], no_hdr0=''),
    642968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642968, CurrentID=0, Status='live', Symbol='FAM163B', Aliases=['C9orf166'], description='family with sequence similarity 163 member B', other_designations='protein FAM163B|cebelin-like', map_location='9q34.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=133577076, end_position_on_the_genomic_accession=133609389, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    642987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=642987, CurrentID=0, Status='live', Symbol='TMEM232', Aliases=[], description='transmembrane protein 232', other_designations='transmembrane protein 232', map_location='5q22.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=110387255, end_position_on_the_genomic_accession=110738936, orientation='minus', exon_count=28, OMIM=[], no_hdr0=''),
    643008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643008, CurrentID=0, Status='live', Symbol='SMIM5', Aliases=['C17orf109', 'PP12104'], description='small integral membrane protein 5', other_designations='small integral membrane protein 5', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75633434, end_position_on_the_genomic_accession=75641406, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    643037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643037, CurrentID=0, Status='live', Symbol='C11orf97', Aliases=['LINC01171'], description='chromosome 11 open reading frame 97', other_designations='uncharacterized protein C11orf97|long intergenic non-protein coding RNA 1171', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=94512461, end_position_on_the_genomic_accession=94532123, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    643136 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643136, CurrentID=0, Status='live', Symbol='ZC3H11B', Aliases=['ZC3HDC11B'], description='zinc finger CCCH-type containing 11B', other_designations='zinc finger CCCH domain-containing protein 11B|zinc finger CCCH-type domain containing 11B', map_location='1q41', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=219608012, end_position_on_the_genomic_accession=219613145, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    643155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643155, CurrentID=0, Status='live', Symbol='SMIM15', Aliases=['C5orf43'], description='small integral membrane protein 15', other_designations='small integral membrane protein 15|UPF0542 protein C5orf43', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=61157704, end_position_on_the_genomic_accession=61162468, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    643161 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643161, CurrentID=0, Status='live', Symbol='FAM25A', Aliases=['bA96C23.5'], description='family with sequence similarity 25 member A', other_designations='protein FAM25A|Protein FAM25C|Protein FAM25G|protein FAM25', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87020294, end_position_on_the_genomic_accession=87024730, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    643226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643226, CurrentID=0, Status='live', Symbol='GRXCR2', Aliases=['DFNB101'], description='glutaredoxin and cysteine rich domain containing 2', other_designations='glutaredoxin domain-containing cysteine-rich protein 2|GRXCR1-like protein|glutaredoxin domain-containing cysteine-rich protein 1-like protein|glutaredoxin, cysteine rich 2', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=145858521, end_position_on_the_genomic_accession=145931673, orientation='minus', exon_count=4, OMIM=[615762], no_hdr0=''),
    643236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643236, CurrentID=0, Status='live', Symbol='TMEM72', Aliases=['C10orf127', 'KSP37'], description='transmembrane protein 72', other_designations='transmembrane protein 72|kidney-specific secretory protein of 37 kDa', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=44911337, end_position_on_the_genomic_accession=44937010, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    643246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643246, CurrentID=0, Status='live', Symbol='MAP1LC3B2', Aliases=['ATG8G'], description='microtubule associated protein 1 light chain 3 beta 2', other_designations='microtubule-associated proteins 1A/1B light chain 3 beta 2|Microtubule-associated proteins 1A/1B light chain 3B-like protein', map_location='12q24.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=116559381, end_position_on_the_genomic_accession=116576606, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    643311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643311, CurrentID=0, Status='live', Symbol='CT47B1', Aliases=['CT47.13', 'CT47A13'], description='cancer/testis antigen family 47 member B1', other_designations='cancer/testis antigen 47B|cancer/testis CT47 family, member 13|cancer/testis antigen 47.13|cancer/testis antigen family 147, member B1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120872552, end_position_on_the_genomic_accession=120875887, orientation='minus', exon_count=3, OMIM=[300790], no_hdr0=''),
    643314 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643314, CurrentID=0, Status='live', Symbol='KIAA0754', Aliases=[], description='KIAA0754', other_designations='uncharacterized protein KIAA0754', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=39409073, end_position_on_the_genomic_accession=39416482, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    643338 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643338, CurrentID=0, Status='live', Symbol='C15orf62', Aliases=[], description='chromosome 15 open reading frame 62', other_designations='uncharacterized protein C15orf62, mitochondrial', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40769980, end_position_on_the_genomic_accession=40772449, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    643376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643376, CurrentID=0, Status='live', Symbol='BTBD18', Aliases=[], description='BTB domain containing 18', other_designations='BTB/POZ domain-containing protein 18|BTB (POZ) domain containing 18|hCG1730474', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=57743514, end_position_on_the_genomic_accession=57753176, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    643382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643382, CurrentID=0, Status='live', Symbol='TMEM253', Aliases=['C14orf176', 'C14orf95', 'NCRNA00220'], description='transmembrane protein 253', other_designations='transmembrane protein 253|transmembrane protein C14orf176', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=21098836, end_position_on_the_genomic_accession=21103724, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    643394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643394, CurrentID=0, Status='live', Symbol='SPINK9', Aliases=['LEKTI2'], description='serine peptidase inhibitor Kazal type 9', other_designations='serine protease inhibitor Kazal-type 9|lymphoepithelial Kazal-type-related inhibitor 2', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148323219, end_position_on_the_genomic_accession=148341974, orientation='plus', exon_count=5, OMIM=[613511], no_hdr0=''),
    643414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643414, CurrentID=0, Status='live', Symbol='LIPK', Aliases=['LIPL2', 'bA186O14.2'], description='lipase family member K', other_designations='lipase member K|lipase K|lipase-like abhydrolase domain-containing protein 2|lipase-like, ab-hydrolase domain containing 2', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88706225, end_position_on_the_genomic_accession=88753092, orientation='plus', exon_count=15, OMIM=[613922], no_hdr0=''),
    643418 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643418, CurrentID=0, Status='live', Symbol='LIPN', Aliases=['ARCI8', 'LI4', 'LIPL4', 'bA186O14.3'], description='lipase family member N', other_designations='lipase member N|lipase-like abhydrolase domain-containing protein 4', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=88757226, end_position_on_the_genomic_accession=88783662, orientation='plus', exon_count=12, OMIM=[613924], no_hdr0=''),
    643596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643596, CurrentID=0, Status='live', Symbol='RNF224', Aliases=[], description='ring finger protein 224', other_designations='RING finger protein 224', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137227502, end_position_on_the_genomic_accession=137229640, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    643641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643641, CurrentID=0, Status='live', Symbol='ZNF862', Aliases=[], description='zinc finger protein 862', other_designations='zinc finger protein 862', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149838375, end_position_on_the_genomic_accession=149867479, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    643664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643664, CurrentID=0, Status='live', Symbol='SLC35G6', Aliases=['AMAC1L3', 'TMEM21B'], description='solute carrier family 35 member G6', other_designations='solute carrier family 35 member G6|acyl-malonyl condensing enzyme 1-like 3|acyl-malonyl-condensing enzyme 1-like protein 3|protein AMAC1L3|transmembrane protein 21B', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7481446, end_position_on_the_genomic_accession=7483496, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    643669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643669, CurrentID=0, Status='live', Symbol='CCER2', Aliases=[], description='coiled-coil glutamate rich protein 2', other_designations='coiled-coil domain-containing glutamate-rich protein 2', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38908171, end_position_on_the_genomic_accession=38914371, orientation='minus', exon_count=7, OMIM=[617634], no_hdr0=''),
    643677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643677, CurrentID=0, Status='live', Symbol='CCDC168', Aliases=['C13orf40'], description='coiled-coil domain containing 168', other_designations='coiled-coil domain-containing protein 168', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102729367, end_position_on_the_genomic_accession=102759072, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    643680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643680, CurrentID=0, Status='live', Symbol='MS4A4E', Aliases=[], description='membrane spanning 4-domains A4E', other_designations='putative membrane-spanning 4-domains subfamily A member 4E', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60200270, end_position_on_the_genomic_accession=60243137, orientation='minus', exon_count=11, OMIM=[608401], no_hdr0=''),
    643699 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643699, CurrentID=0, Status='live', Symbol='GOLGA8N', Aliases=['GOLGA8R'], description='golgin A8 family member N', other_designations='golgin subfamily A member 8N', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32593456, end_position_on_the_genomic_accession=32607310, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    643707 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643707, CurrentID=0, Status='live', Symbol='GOLGA6L4', Aliases=[], description='golgin A6 family like 4', other_designations='golgin subfamily A member 6-like protein 4|golgi autoantigen, golgin subfamily a, 6-like 4|putative golgin subfamily A member 6-like protein 4', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84235773, end_position_on_the_genomic_accession=84245358, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    643803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643803, CurrentID=0, Status='live', Symbol='KRTAP24-1', Aliases=['KAP24.1'], description='keratin associated protein 24-1', other_designations='keratin-associated protein 24-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30281309, end_position_on_the_genomic_accession=30282950, orientation='minus', exon_count=1, OMIM=[618927], no_hdr0=''),
    643812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643812, CurrentID=0, Status='live', Symbol='KRTAP27-1', Aliases=[], description='keratin associated protein 27-1', other_designations='keratin-associated protein 27-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30337013, end_position_on_the_genomic_accession=30337694, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    643834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643834, CurrentID=0, Status='live', Symbol='PGA3', Aliases=[], description='pepsinogen A3', other_designations='pepsin A-3|pepsinogen 3, group I (pepsinogen A)|pepsinogen-3', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61203515, end_position_on_the_genomic_accession=61213098, orientation='plus', exon_count=9, OMIM=[169710], no_hdr0=''),
    643836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643836, CurrentID=0, Status='live', Symbol='ZFP62', Aliases=['ZET', 'ZNF755'], description='ZFP62 zinc finger protein', other_designations='zinc finger protein 62 homolog|zfp-62', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=180843580, end_position_on_the_genomic_accession=180861276, orientation='minus', exon_count=6, OMIM=[610281], no_hdr0=''),
    643847 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643847, CurrentID=0, Status='live', Symbol='PGA4', Aliases=[], description='pepsinogen A4', other_designations='pepsin A-4|pepsinogen 4, group I (pepsinogen A)|pepsinogen-4|pregnancy-associated glycoprotein', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=61222347, end_position_on_the_genomic_accession=61231694, orientation='plus', exon_count=9, OMIM=[169720], no_hdr0=''),
    643853 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643853, CurrentID=0, Status='live', Symbol='TMPPE', Aliases=[], description='transmembrane protein with metallophosphoesterase domain', other_designations='transmembrane protein with metallophosphoesterase domain', map_location='3p22.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=33090422, end_position_on_the_genomic_accession=33097146, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    643854 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643854, CurrentID=0, Status='live', Symbol='CTAGE9', Aliases=[], description='CTAGE family member 9', other_designations='cTAGE family member 9|cutaneous T-cell lymphoma-associated antigen 9|protein cTAGE-9', map_location='6q23.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=131708441, end_position_on_the_genomic_accession=131711017, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    643862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643862, CurrentID=0, Status='live', Symbol='SPDYE10', Aliases=['SPDYE10P'], description='speedy/RINGO cell cycle regulator family member E10', other_designations='speedy/RINGO cell cycle regulator family member E10, pseudogene|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73104008, end_position_on_the_genomic_accession=73155431, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    643866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643866, CurrentID=0, Status='live', Symbol='CBLN3', Aliases=['PRO1486'], description='cerebellin 3 precursor', other_designations='cerebellin-3', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24426545, end_position_on_the_genomic_accession=24429668, orientation='minus', exon_count=3, OMIM=[612978], no_hdr0=''),
    643904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643904, CurrentID=0, Status='live', Symbol='RNF222', Aliases=[], description='ring finger protein 222', other_designations='RING finger protein 222|RING finger protein LOC643904', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=8390702, end_position_on_the_genomic_accession=8397835, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    643905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643905, CurrentID=0, Status='live', Symbol='PRR21', Aliases=[], description='proline rich 21', other_designations='putative proline-rich protein 21', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    643909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643909, CurrentID=0, Status='live', Symbol='SPDYE9', Aliases=['SPDYE9P'], description='speedy/RINGO cell cycle regulator family member E9', other_designations='speedy/RINGO cell cycle regulator family member E9|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy homolog E9, pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene|speedy/RINGO cell cycle regulator family member E9, pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73075972, end_position_on_the_genomic_accession=73086038, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    643965 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643965, CurrentID=0, Status='live', Symbol='TMEM88B', Aliases=[], description='transmembrane protein 88B', other_designations='transmembrane protein 88B', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1425871, end_position_on_the_genomic_accession=1430255, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    643988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=643988, CurrentID=0, Status='live', Symbol='FNDC10', Aliases=['C1orf233'], description='fibronectin type III domain containing 10', other_designations='fibronectin type III domain-containing protein 10|fibronectin type-III domain-containing transmembrane protein C1orf233', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1598012, end_position_on_the_genomic_accession=1600135, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    644019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644019, CurrentID=0, Status='live', Symbol='CBWD6', Aliases=['CBWD7'], description='COBW domain containing 6', other_designations='COBW domain-containing protein 6|COBW domain containing 7|cobalamin synthase W domain-containing protein 6|cobalamin synthetase W domain-containing protein 6|putative COBW domain-containing protein 7|putative cobalamin synthase W domain-containing protein 7', map_location='9p11.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=41131309, end_position_on_the_genomic_accession=41198865, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    644041 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644041, CurrentID=0, Status='live', Symbol='C18orf63', Aliases=['DKFZP781G0119'], description='chromosome 18 open reading frame 63', other_designations='uncharacterized protein C18orf63', map_location='18q22.3', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=74315839, end_position_on_the_genomic_accession=74359189, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    644054 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644054, CurrentID=0, Status='live', Symbol='FAM25C', Aliases=['bA164N7.4'], description='family with sequence similarity 25 member C', other_designations='protein FAM25C|Protein FAM25G|protein FAM25', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47995322, end_position_on_the_genomic_accession=47999791, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    644070 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644070, CurrentID=0, Status='live', Symbol='GSG1L2', Aliases=[], description='GSG1 like 2', other_designations='germ cell-specific gene 1-like protein 2|GSG1-like protein 2|germ cell-specific gene 1-like protein 2-like|putative germ cell-specific gene 1-like protein 2', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=9800608, end_position_on_the_genomic_accession=9822079, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    644096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644096, CurrentID=0, Status='live', Symbol='SDHAF1', Aliases=['LYRM8', 'MC2DN2'], description='succinate dehydrogenase complex assembly factor 1', other_designations='succinate dehydrogenase assembly factor 1, mitochondrial|LYR motif containing 8|LYR motif-containing protein 8|SDH assembly factor 1', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=35995188, end_position_on_the_genomic_accession=35996312, orientation='plus', exon_count=1, OMIM=[612848], no_hdr0=''),
    644100 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644100, CurrentID=0, Status='live', Symbol='ARL14EPL', Aliases=[], description='ADP ribosylation factor like GTPase 14 effector protein like', other_designations='ARL14 effector protein-like|ADP-ribosylation factor-like 14 effector protein-like', map_location='5q23.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=116032472, end_position_on_the_genomic_accession=116059489, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    644139 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644139, CurrentID=0, Status='live', Symbol='PIRT', Aliases=[], description='phosphoinositide interacting regulator of transient receptor potential channels', other_designations='phosphoinositide-interacting protein|phosphoinositide-interacting regulator of TRPV1', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10822470, end_position_on_the_genomic_accession=10838087, orientation='minus', exon_count=2, OMIM=[612068], no_hdr0=''),
    644145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644145, CurrentID=0, Status='live', Symbol='EXOC1L', Aliases=[], description='exocyst complex component 1 like', other_designations='exocyst complex component 1-like|exocyst -like pseudogene|exocyst complex component 1 pseudogene', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=55819790, end_position_on_the_genomic_accession=55837489, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    644150 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644150, CurrentID=0, Status='live', Symbol='WIPF3', Aliases=['CR16'], description='WAS/WASL interacting protein family member 3', other_designations='WAS/WASL-interacting protein family member 3|corticosteroids and regional expression protein 16 homolog', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=29806508, end_position_on_the_genomic_accession=29917065, orientation='plus', exon_count=10, OMIM=[612432], no_hdr0=''),
    644168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644168, CurrentID=0, Status='live', Symbol='DRGX', Aliases=['DRG11', 'PRRXL1'], description='dorsal root ganglia homeobox', other_designations='dorsal root ganglia homeobox protein|paired related homeobox-like 1|paired-like homeodomain trancription factor DRG11', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49364066, end_position_on_the_genomic_accession=49396089, orientation='minus', exon_count=8, OMIM=[606701], no_hdr0=''),
    644186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644186, CurrentID=0, Status='live', Symbol='SYCE3', Aliases=['C22orf41', 'THEG2'], description='synaptonemal complex central element protein 3', other_designations='synaptonemal complex central element protein 3|testis highly expressed gene 2 protein|testis highly expressed protein 2', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50551112, end_position_on_the_genomic_accession=50562919, orientation='minus', exon_count=4, OMIM=[615775], no_hdr0=''),
    644353 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644353, CurrentID=0, Status='live', Symbol='ZCCHC18', Aliases=['PNMA7B', 'SIZN2'], description='zinc finger CCHC-type containing 18', other_designations='zinc finger CCHC domain-containing protein 18|paraneoplastic Ma antigen family member 7B|putative zinc finger CCHC domain-containing protein 18|zinc finger, CCHC domain containing 12 pseudogene 1', map_location='Xq22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=104112445, end_position_on_the_genomic_accession=104121330, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    644414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644414, CurrentID=0, Status='live', Symbol='DEFB131A', Aliases=['DEFB-31', 'DEFB131'], description='defensin beta 131A', other_designations='beta-defensin 131A|beta-defensin 131|beta-defensin 31|defensin beta 131|defensin, beta 31', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9444414, end_position_on_the_genomic_accession=9450666, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    644524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644524, CurrentID=0, Status='live', Symbol='NKX2-4', Aliases=['NKX2.4', 'NKX2D'], description='NK2 homeobox 4', other_designations='homeobox protein Nkx-2.4|NK2 transcription factor homolog D|NK2 transcription factor related, locus 4', map_location='20p11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=21395365, end_position_on_the_genomic_accession=21397526, orientation='minus', exon_count=2, OMIM=[607808], no_hdr0=''),
    644538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644538, CurrentID=0, Status='live', Symbol='SMIM10', Aliases=['CXorf69'], description='small integral membrane protein 10', other_designations='small integral membrane protein 10', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=134990991, end_position_on_the_genomic_accession=134992473, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    644591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644591, CurrentID=0, Status='live', Symbol='PPIAL4G', Aliases=['COAS-2'], description='peptidylprolyl isomerase A like 4G', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4G|PPIase A-like 4A|PPIase A-like 4G|chromosome 1-amplified sequence 2|peptidylprolyl cis-trans isomerase A-like 4|peptidylprolyl cis-trans isomerase A-like 4A|peptidylprolyl cis-trans isomerase A-like 4G|peptidylprolyl isomerase A (cyclophilin A)-like 4G', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148482548, end_position_on_the_genomic_accession=148483302, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    644596 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644596, CurrentID=0, Status='live', Symbol='SMIM10L2B', Aliases=['LINC00086', 'LINC00087', 'NCRNA00086', 'NCRNA00087', 'SMIM10L2A'], description='small integral membrane protein 10 like 2B', other_designations='small integral membrane protein 10-like protein 2B|Small integral membrane protein 10-like protein 2A|long intergenic non-protein coding RNA 87', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135094985, end_position_on_the_genomic_accession=135098712, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    644672 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644672, CurrentID=0, Status='live', Symbol='CLDN25', Aliases=[], description='claudin 25', other_designations='putative claudin-25', map_location='11q23.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=113779796, end_position_on_the_genomic_accession=113780485, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    644815 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644815, CurrentID=0, Status='live', Symbol='FAM83G', Aliases=['PAWS1'], description='family with sequence similarity 83 member G', other_designations='protein FAM83G|protein associated with SMAD1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18968789, end_position_on_the_genomic_accession=19006143, orientation='minus', exon_count=7, OMIM=[615886], no_hdr0=''),
    644844 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644844, CurrentID=0, Status='live', Symbol='PHGR1', Aliases=[], description='proline, histidine and glycine rich 1', other_designations='proline, histidine and glycine-rich protein 1|proline-histidine-glycin-rich protein 1|proline/histidine/glycine-rich 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40351033, end_position_on_the_genomic_accession=40356434, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    644890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644890, CurrentID=0, Status='live', Symbol='MEIG1', Aliases=['SPATA39', 'bA2K17.3'], description='meiosis/spermiogenesis associated 1', other_designations='meiosis expressed gene 1 protein homolog|meiosis expressed gene 1 homolog|spermatogenesis associated 39', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14954228, end_position_on_the_genomic_accession=14988050, orientation='plus', exon_count=6, OMIM=[614174], no_hdr0=''),
    644943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644943, CurrentID=0, Status='live', Symbol='RASSF10', Aliases=[], description='Ras association domain family member 10', other_designations='ras association domain-containing protein 10|Ras association (RalGDS/AF-6) domain family (N-terminal) member 10', map_location='11p15.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=13009316, end_position_on_the_genomic_accession=13012119, orientation='plus', exon_count=1, OMIM=[614713], no_hdr0=''),
    644974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644974, CurrentID=0, Status='live', Symbol='ALG1L2', Aliases=[], description='ALG1 chitobiosyldiphosphodolichol beta-mannosyltransferase like 2', other_designations='putative glycosyltransferase ALG1L2|asparagine-linked glycosylation 1-like 2', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130081831, end_position_on_the_genomic_accession=130103799, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    644994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=644994, CurrentID=0, Status='live', Symbol='SMIM23', Aliases=['C5orf50'], description='small integral membrane protein 23', other_designations='small integral membrane protein 23|CTB-78H18.1', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=171772637, end_position_on_the_genomic_accession=171791136, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    645027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645027, CurrentID=0, Status='live', Symbol='EVPLL', Aliases=[], description='envoplakin like', other_designations='envoplakin-like protein', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18377673, end_position_on_the_genomic_accession=18389652, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    645037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645037, CurrentID=0, Status='live', Symbol='GAGE2B', Aliases=['CT4.2', 'GAGE-2', 'GAGE-2B'], description='G antigen 2B', other_designations='G antigen 2B/2C|cancer/testis antigen 4.2|g antigen 2A/2B', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300726], no_hdr0=''),
    645051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645051, CurrentID=0, Status='live', Symbol='GAGE13', Aliases=['GAGE-12A', 'GAGE-13', 'GAGE12A'], description='G antigen 13', other_designations='G antigen 13|G antigen 12A', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49331582, end_position_on_the_genomic_accession=49338949, orientation='plus', exon_count=5, OMIM=[300734], no_hdr0=''),
    645073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645073, CurrentID=0, Status='live', Symbol='GAGE12G', Aliases=['AL4', 'CT4.7', 'GAGE-12G'], description='G antigen 12G', other_designations='G antigen 12G|G antigen 12F/G/I|G antigen 12I|cancer/testis antigen 4.7', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49570397, end_position_on_the_genomic_accession=49577757, orientation='plus', exon_count=5, OMIM=[300731], no_hdr0=''),
    645104 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645104, CurrentID=0, Status='live', Symbol='CLRN2', Aliases=['DFNB117'], description='clarin 2', other_designations='clarin-2', map_location='4p15.32', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=17515165, end_position_on_the_genomic_accession=17527104, orientation='plus', exon_count=3, OMIM=[618988], no_hdr0=''),
    645121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645121, CurrentID=0, Status='live', Symbol='CCNI2', Aliases=[], description='cyclin I family member 2', other_designations='cyclin-I2', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=132747426, end_position_on_the_genomic_accession=132754403, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    645142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645142, CurrentID=0, Status='live', Symbol='PPIAL4D', Aliases=[], description='peptidylprolyl isomerase A like 4D', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4D|PPIase A-like 4D|peptidylprolyl isomerase A (cyclophilin A)-like 4D', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145241415, end_position_on_the_genomic_accession=145242174, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    645191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645191, CurrentID=0, Status='live', Symbol='LINGO3', Aliases=['LERN2', 'LRRN6B'], description='leucine rich repeat and Ig domain containing 3', other_designations='leucine-rich repeat and immunoglobulin-like domain-containing nogo receptor-interacting protein 3|leucine rich repeat neuronal 6B|leucine-rich repeat neuronal protein 2|leucine-rich repeat neuronal protein 6B', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=2287164, end_position_on_the_genomic_accession=2308154, orientation='minus', exon_count=2, OMIM=[609792], no_hdr0=''),
    645202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645202, CurrentID=0, Status='live', Symbol='LOC645202', Aliases=[], description='golgin A6 family-like', other_designations='golgin A6 family-like', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28347851, end_position_on_the_genomic_accession=28358086, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    645359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645359, CurrentID=0, Status='live', Symbol='PRAMEF26', Aliases=['PRAMEF25'], description='PRAME family member 26', other_designations='putative PRAME family member 26|PRAME family member 25', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13148907, end_position_on_the_genomic_accession=13156009, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    645369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645369, CurrentID=0, Status='live', Symbol='TMEM200C', Aliases=['TTMA'], description='transmembrane protein 200C', other_designations='transmembrane protein 200C|transmembrane protein TTMA|two transmembrane domain family member A|two transmembrane domain-containing family member A', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5882339, end_position_on_the_genomic_accession=5898701, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    645382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645382, CurrentID=0, Status='live', Symbol='PRAMEF33', Aliases=['PRAMEF33P'], description='PRAME family member 33', other_designations='PRAME family member 33|PRAME family member 10-like|PRAME family member 33, pseudogene', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13303539, end_position_on_the_genomic_accession=13308907, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    645402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645402, CurrentID=0, Status='live', Symbol='USP17L4', Aliases=[], description='ubiquitin specific peptidase 17 like family member 4', other_designations='inactive ubiquitin carboxyl-terminal hydrolase 17-like protein 4', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7337115, end_position_on_the_genomic_accession=7338707, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    645414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645414, CurrentID=0, Status='live', Symbol='PRAMEF19', Aliases=[], description='PRAME family member 19', other_designations='PRAME family member 19|PRAME family member-like', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13368441, end_position_on_the_genomic_accession=13372469, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    645425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645425, CurrentID=0, Status='live', Symbol='PRAMEF20', Aliases=['PRAMEF21'], description='PRAME family member 20', other_designations='PRAME family member 20|PRAME family member 20/21|PRAME family member 21', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13410450, end_position_on_the_genomic_accession=13421328, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    645426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645426, CurrentID=0, Status='live', Symbol='TMEM191C', Aliases=[], description='transmembrane protein 191C', other_designations='transmembrane protein 191C|KB-1323B2.6', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21467387, end_position_on_the_genomic_accession=21469935, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    645432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645432, CurrentID=0, Status='live', Symbol='ARRDC5', Aliases=[], description='arrestin domain containing 5', other_designations='arrestin domain-containing protein 5', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4867614, end_position_on_the_genomic_accession=4915469, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    645745 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645745, CurrentID=0, Status='live', Symbol='MT1HL1', Aliases=['MT1P2'], description='metallothionein 1H like 1', other_designations='metallothionein 1H-like protein 1|MT-1H-like protein', map_location='1q43', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=237004103, end_position_on_the_genomic_accession=237004441, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    645811 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645811, CurrentID=0, Status='live', Symbol='CCDC154', Aliases=['C16orf29'], description='coiled-coil domain containing 154', other_designations='coiled-coil domain-containing protein 154', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1434383, end_position_on_the_genomic_accession=1444556, orientation='minus', exon_count=17, OMIM=[618740], no_hdr0=''),
    645832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645832, CurrentID=0, Status='live', Symbol='SEBOX', Aliases=['OG-9', 'OG9', 'OG9X'], description='SEBOX homeobox', other_designations='homeobox protein SEBOX|homeobox OG-9|skin-, embryo-, brain- and oocyte-specific homeobox', map_location='17q11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=28363506, end_position_on_the_genomic_accession=28365199, orientation='minus', exon_count=3, OMIM=[610975], no_hdr0=''),
    645836 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645836, CurrentID=0, Status='live', Symbol='USP17L3', Aliases=['USP17B', 'USP17F'], description='ubiquitin specific peptidase 17 like family member 3', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 3|deubiquitinating enzyme 17-like protein 3|ubiquitin specific peptidase 17-like 3|ubiquitin thioesterase 17-like protein 3|ubiquitin-specific-processing protease 17-like protein 3', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7976393, end_position_on_the_genomic_accession=7977985, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    645864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645864, CurrentID=0, Status='live', Symbol='MAGEB17', Aliases=[], description='MAGE family member B17', other_designations='melanoma-associated antigen B17|melanoma antigen family B, 17 (pseudogene)|melanoma antigen family B17', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=16167481, end_position_on_the_genomic_accession=16172394, orientation='plus', exon_count=3, OMIM=[300763], no_hdr0=''),
    645961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645961, CurrentID=0, Status='live', Symbol='SPATA31C2', Aliases=['FAM75C2'], description='SPATA31 subfamily C member 2', other_designations='putative spermatogenesis-associated protein 31C2|family with sequence similarity 75, member C2|spermatogenesis-associated protein 31C2', map_location='9q22.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=88129305, end_position_on_the_genomic_accession=88138475, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    645974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=645974, CurrentID=0, Status='live', Symbol='PABPC1L2B', Aliases=['RBM32B'], description='poly(A) binding protein cytoplasmic 1 like 2B', other_designations='polyadenylate-binding protein 1-like 2|RNA binding motif protein 32B|RNA-binding motif protein 32|RNA-binding protein 32', map_location='Xq13.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=73002939, end_position_on_the_genomic_accession=73006106, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    646000 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646000, CurrentID=0, Status='live', Symbol='SLC35G4', Aliases=['AMAC1L1P', 'SLC35G4'], description='solute carrier family 35 member G4', other_designations='putative solute carrier family 35 member G4|acyl-malonyl-condensing enzyme 1-like protein 1|protein AMAC1L1|putative solute carrier family 35 member G4 pseudogene|solute carrier family 35, member G4, pseudogene', map_location='18p11.21', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=11609596, end_position_on_the_genomic_accession=11610612, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    646019 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646019, CurrentID=0, Status='live', Symbol='CBY3', Aliases=[], description='chibby family member 3', other_designations='protein chibby homolog 3|chibby homolog 3', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=179678560, end_position_on_the_genomic_accession=179681034, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    646174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646174, CurrentID=0, Status='live', Symbol='C16orf90', Aliases=[], description='chromosome 16 open reading frame 90', other_designations='uncharacterized protein C16orf90', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3493484, end_position_on_the_genomic_accession=3496652, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    646262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646262, CurrentID=0, Status='live', Symbol='LACTBL1', Aliases=[], description='lactamase beta like 1', other_designations='putative beta-lactamase-like 1', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=22953043, end_position_on_the_genomic_accession=22972866, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    646424 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646424, CurrentID=0, Status='live', Symbol='SPINK8', Aliases=[], description='serine peptidase inhibitor Kazal type 8 (putative)', other_designations='serine protease inhibitor Kazal-type 8', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=48306842, end_position_on_the_genomic_accession=48333909, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    646457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646457, CurrentID=0, Status='live', Symbol='C19orf67', Aliases=[], description='chromosome 19 open reading frame 67', other_designations='UPF0575 protein C19orf67', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=14080642, end_position_on_the_genomic_accession=14086153, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    646480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646480, CurrentID=0, Status='live', Symbol='FABP9', Aliases=['PERF', 'PERF15', 'T-FABP', 'TLBP'], description='fatty acid binding protein 9', other_designations='fatty acid-binding protein 9|fatty acid binding protein 9, testis|testis lipid binding protein|testis-type fatty acid-binding protein', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81458253, end_position_on_the_genomic_accession=81461579, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    646486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646486, CurrentID=0, Status='live', Symbol='FABP12', Aliases=[], description='fatty acid binding protein 12', other_designations='fatty acid-binding protein 12|Probable fatty acid-binding protein ENSP00000353650|fatty acid binding protein ORF|intracellular fatty acid-binding protein FABP12', map_location='8q21.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=81524673, end_position_on_the_genomic_accession=81590664, orientation='minus', exon_count=7, OMIM=[618923], no_hdr0=''),
    646498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646498, CurrentID=0, Status='live', Symbol='C3orf84', Aliases=[], description='chromosome 3 open reading frame 84', other_designations='uncharacterized protein C3orf84', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=49177539, end_position_on_the_genomic_accession=49192684, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    646603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646603, CurrentID=0, Status='live', Symbol='C4orf51', Aliases=[], description='chromosome 4 open reading frame 51', other_designations='uncharacterized protein C4orf51', map_location='4q31.21', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=145680100, end_position_on_the_genomic_accession=145792401, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    646625 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646625, CurrentID=0, Status='live', Symbol='URAD', Aliases=['PRHOXNB'], description='ureidoimidazoline (2-oxo-4-hydroxy-4-carboxy-5-) decarboxylase', other_designations='putative 2-oxo-4-hydroxy-4-carboxy-5-ureidoimidazoline decarboxylase|OHCU decarboxylase|parahox cluster neighbor', map_location='13q12.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=27977717, end_position_on_the_genomic_accession=27988693, orientation='minus', exon_count=2, OMIM=[615804], no_hdr0=''),
    646627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646627, CurrentID=0, Status='live', Symbol='LYPD8', Aliases=[], description='LY6/PLAUR domain containing 8', other_designations='ly6/PLAUR domain-containing protein 8|phospholipase inhibitor', map_location='1q44', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=248739415, end_position_on_the_genomic_accession=248755759, orientation='minus', exon_count=7, OMIM=[617067], no_hdr0=''),
    646643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646643, CurrentID=0, Status='live', Symbol='SBK2', Aliases=['SGK069'], description='SH3 domain binding kinase family member 2', other_designations='serine/threonine-protein kinase SBK2|SH3-binding domain kinase family, member 2|Sugen kinase 69', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55528611, end_position_on_the_genomic_accession=55537174, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    646658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646658, CurrentID=0, Status='live', Symbol='SYNDIG1L', Aliases=['CAPUCIN', 'DSPC1', 'IFITMD4', 'TMEM90A'], description='synapse differentiation inducing 1 like', other_designations='synapse differentiation-inducing gene protein 1-like|caudate- and putamen-enriched sequence|dispanin subfamily C member 1|interferon induced transmembrane protein domain containing 4|transmembrane protein 90A', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=74405893, end_position_on_the_genomic_accession=74477080, orientation='minus', exon_count=5, OMIM=[609999], no_hdr0=''),
    646754 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646754, CurrentID=0, Status='live', Symbol='TRIM64C', Aliases=[], description='tripartite motif containing 64C', other_designations='tripartite motif-containing protein 64C|putative tripartite motif-containing protein 64C', map_location='11p11.12', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=49053714, end_position_on_the_genomic_accession=49059112, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    646799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646799, CurrentID=0, Status='live', Symbol='ZAR1L', Aliases=['Z3CXXC7', 'ZAR2'], description='zygote arrest 1 like', other_designations='ZAR1-like protein|zinc finger, 3CxxC-type 7', map_location='13q13.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=32303699, end_position_on_the_genomic_accession=32315363, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    646817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646817, CurrentID=0, Status='live', Symbol='SETSIP', Aliases=['SETP18'], description='SET like protein', other_designations='protein SETSIP|SET nuclear oncogene pseudogene|SET pseudogene 18|SET pseudogene protein 18|SET similar protein', map_location='1p22.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=92074436, end_position_on_the_genomic_accession=92075472, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    646851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646851, CurrentID=0, Status='live', Symbol='FAM227A', Aliases=[], description='family with sequence similarity 227 member A', other_designations='protein FAM227A|Protein FAM227A', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38578118, end_position_on_the_genomic_accession=38656629, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    646862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646862, CurrentID=0, Status='live', Symbol='RNF225', Aliases=[], description='ring finger protein 225', other_designations='RING finger protein 225', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=58395656, end_position_on_the_genomic_accession=58397079, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    646864 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646864, CurrentID=0, Status='live', Symbol='ZNF723', Aliases=['ZNF723P'], description='zinc finger protein 723', other_designations='zinc finger protein 723', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22820075, end_position_on_the_genomic_accession=22859398, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    646892 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646892, CurrentID=0, Status='live', Symbol='SH2D7', Aliases=[], description='SH2 domain containing 7', other_designations='SH2 domain-containing protein 7|Putative SH2 domain-containing protein LOC646892', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=78089895, end_position_on_the_genomic_accession=78104362, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    646951 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646951, CurrentID=0, Status='live', Symbol='MINDY4B', Aliases=['C3orf76', 'FAM188B2'], description='MINDY family member 4B', other_designations='inactive ubiquitin carboxyl-terminal hydrolase MINDY-4B|epididymis secretory sperm binding protein|family with sequence similarity 188 member B2|protein FAM188B2|putative UPF0526 protein B', map_location='3q25.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=150870376, end_position_on_the_genomic_accession=150905439, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    646960 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646960, CurrentID=0, Status='live', Symbol='PRSS56', Aliases=['MCOP6'], description='serine protease 56', other_designations='serine protease 56|protease, serine 56|putative serine protease 56', map_location='2q37.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=232520388, end_position_on_the_genomic_accession=232525716, orientation='plus', exon_count=13, OMIM=[613858], no_hdr0=''),
    646962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=646962, CurrentID=0, Status='live', Symbol='HRCT1', Aliases=['LGLL338', 'PRO537', 'UNQ338'], description='histidine rich carboxyl terminus 1', other_designations='histidine-rich carboxyl terminus protein 1', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35906202, end_position_on_the_genomic_accession=35907136, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    647024 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647024, CurrentID=0, Status='live', Symbol='C6orf132', Aliases=['bA7K24.2'], description='chromosome 6 open reading frame 132', other_designations='uncharacterized protein C6orf132', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42101119, end_position_on_the_genomic_accession=42142620, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    647042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647042, CurrentID=0, Status='live', Symbol='GOLGA6L10', Aliases=['GOLGA6L18'], description='golgin A6 family like 10', other_designations='golgin subfamily A member 6-like protein 10|golgi autoantigen, golgin subfamily a, 6-like 10|golgin A6 family-like 18|putative golgin subfamily A member 6-like protein 10', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=82339993, end_position_on_the_genomic_accession=82349475, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    647060 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647060, CurrentID=0, Status='live', Symbol='SPATA31A1', Aliases=['C9orf36', 'C9orf36A', 'FAM75A1', 'FAM75A2', 'SPATA31A2'], description='SPATA31 subfamily A member 1', other_designations='spermatogenesis-associated protein 31A1|SPATA31 subfamily A, member 2|family with sequence similarity 75, member A1|family with sequence similarity 75, member A2|protein FAM75A1|protein FAM75A2|spermatogenesis-associated protein 31A2', map_location='9p12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=39355667, end_position_on_the_genomic_accession=39361962, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    647087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647087, CurrentID=0, Status='live', Symbol='STMP1', Aliases=['C7orf73', 'Mm47', 'PL-5283'], description='short transmembrane mitochondrial protein 1', other_designations='short transmembrane mitochondrial protein 1|uncharacterized protein C7orf73', map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135662514, end_position_on_the_genomic_accession=135676416, orientation='plus', exon_count=3, OMIM=[618755], no_hdr0=''),
    647135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647135, CurrentID=0, Status='live', Symbol='SRGAP2B', Aliases=['SRGAP2L', 'SRGAP2P2'], description='SLIT-ROBO Rho GTPase activating protein 2B', other_designations='SLIT-ROBO Rho GTPase-activating protein 2B|SLIT-ROBO Rho GTPase activating protein 2 pseudogene 2|SLIT-ROBO Rho GTPase activating protein 2B (pseudogene)', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=144887191, end_position_on_the_genomic_accession=145095380, orientation='minus', exon_count=15, OMIM=[614703], no_hdr0=''),
    647166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647166, CurrentID=0, Status='live', Symbol='C13orf42', Aliases=['LINC00371', 'LINC00372'], description='chromosome 13 open reading frame 42', other_designations='uncharacterized protein C13orf42|long intergenic non-protein coding RNA 371|long intergenic non-protein coding RNA 372', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51082119, end_position_on_the_genomic_accession=51172388, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    647174 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647174, CurrentID=0, Status='live', Symbol='SERPINE3', Aliases=[], description='serpin family E member 3', other_designations='serpin E3|nexin-related serine protease inhibitor|serpin peptidase inhibitor, clade E (nexin, plasminogen activator inhibitor type 1), member 3', map_location='13q14.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=51335804, end_position_on_the_genomic_accession=51365454, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    647219 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647219, CurrentID=0, Status='live', Symbol='ASCL5', Aliases=['ASH-5', 'bHLHa47'], description='achaete-scute family bHLH transcription factor 5', other_designations='achaete-scute homolog 5|achaete-scute complex homolog 5|class A basic helix-loop-helix protein 47', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=201113943, end_position_on_the_genomic_accession=201127184, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    647264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647264, CurrentID=0, Status='live', Symbol='LOC647264', Aliases=[], description='keratin-associated protein 21-1', other_designations='keratin-associated protein 21-1', map_location='13q21.31', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=63832361, end_position_on_the_genomic_accession=63833053, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    647286 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647286, CurrentID=0, Status='live', Symbol='RD3L', Aliases=['TDRD9-AS1', 'TDRD9AS1'], description='RD3 like', other_designations='protein RD3-like|TDRD9 antisense 1|TDRD9 antisense RNA 1 (non-protein coding)|retinal degeneration 3 like|retinal degeneration protein 3-like', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103940426, end_position_on_the_genomic_accession=103942529, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    647309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647309, CurrentID=0, Status='live', Symbol='GMNC', Aliases=['GEMC1'], description='geminin coiled-coil domain containing', other_designations='geminin coiled-coil domain-containing protein 1', map_location='3q28', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=190843271, end_position_on_the_genomic_accession=190864200, orientation='minus', exon_count=7, OMIM=[614448], no_hdr0=''),
    647310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647310, CurrentID=0, Status='live', Symbol='TEX22', Aliases=[], description='testis expressed 22', other_designations='testis-expressed protein 22|testis expressed gene 22|testis-expressed sequence 22 protein', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105398499, end_position_on_the_genomic_accession=105413859, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    647589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=647589, CurrentID=0, Status='live', Symbol='ANHX', Aliases=[], description='anomalous homeobox', other_designations='anomalous homeobox protein', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133218312, end_position_on_the_genomic_accession=133236133, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    648791 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=648791, CurrentID=0, Status='live', Symbol='PPP1R3G', Aliases=[], description='protein phosphatase 1 regulatory subunit 3G', other_designations='protein phosphatase 1 regulatory subunit 3G|protein phosphatase 1, regulatory (inhibitor) subunit 3G|putative protein phosphatase 1 regulatory inhibitor subunit 3G', map_location='6p25.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=5085341, end_position_on_the_genomic_accession=5089487, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    649137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=649137, CurrentID=0, Status='live', Symbol='ZSCAN5C', Aliases=['ZNF495CP', 'ZSCAN5C'], description='zinc finger and SCAN domain containing 5C', other_designations='zinc finger and SCAN domain-containing protein 5C|putative zinc finger and SCAN domain-containing protein 5C|zinc finger and SCAN domain containing 5C, pseudogene|zinc finger and SCAN domain-containing protein 5-like protein 2|zinc finger and SCAN domain-containing protein 5C pseudogene', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56202273, end_position_on_the_genomic_accession=56209200, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    649238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=649238, CurrentID=0, Status='live', Symbol='PNMA6E', Aliases=[], description='PNMA family member 6E', other_designations='paraneoplastic antigen Ma6E|paraneoplastic Ma antigen family member 6E|putative paraneoplastic antigen-like protein 6B-like', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153395639, end_position_on_the_genomic_accession=153414404, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    649330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=649330, CurrentID=0, Status='live', Symbol='HNRNPCL3', Aliases=['HNRNPCL2', 'HNRNPCL4'], description='heterogeneous nuclear ribonucleoprotein C like 3', other_designations='heterogeneous nuclear ribonucleoprotein C-like 3|Heterogeneous nuclear ribonucleoprotein C-like 4|heterogeneous nuclear ribonucleoprotein C-like 2|hnRNP C-like-2', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13060769, end_position_on_the_genomic_accession=13062878, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    651746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=651746, CurrentID=0, Status='live', Symbol='ANKRD33B', Aliases=[], description='ankyrin repeat domain 33B', other_designations='ankyrin repeat domain-containing protein 33B|Ankyrin repeat domain-containing protein LOC651746', map_location='5p15.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=10564070, end_position_on_the_genomic_accession=10657816, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    652968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=652968, CurrentID=0, Status='live', Symbol='CASTOR1', Aliases=['GATSL3'], description='cytosolic arginine sensor for mTORC1 subunit 1', other_designations='cytosolic arginine sensor for mTORC1 subunit 1|GATS protein like 3|GATS-like protein 3|cellular arginine sensor for mTORC1 protein 1', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30285117, end_position_on_the_genomic_accession=30289505, orientation='minus', exon_count=9, OMIM=[617034], no_hdr0=''),
    652991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=652991, CurrentID=0, Status='live', Symbol='SKOR2', Aliases=['CH18515', 'CORL2', 'FUSSEL18'], description='SKI family transcriptional corepressor 2', other_designations='SKI family transcriptional corepressor 2|LBX1 corepressor 1-like protein|functional Smad-suppressing element on chromosome 18|functional smad suppressing element 18|fussel-18|ladybird homeobox corepressor 1-like protein', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=47206169, end_position_on_the_genomic_accession=47251660, orientation='minus', exon_count=10, OMIM=[617138], no_hdr0=''),
    653061 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653061, CurrentID=0, Status='live', Symbol='GOLGA8S', Aliases=[], description='golgin A8 family member S', other_designations='golgin subfamily A member 8S', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23354748, end_position_on_the_genomic_accession=23368489, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    653067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653067, CurrentID=0, Status='live', Symbol='XAGE1B', Aliases=['CT12.1', 'CT12.1C', 'CT12.1D', 'CT12.1E', 'CT12.1b', 'CTP9', 'GAGED2', 'XAGE-1', 'XAGE1', 'XAGE1C', 'XAGE1D', 'XAGE1E'], description='X antigen family member 1B', other_designations='X antigen family member 1|G antigen family D member 2|X antigen family member 1E|X antigen family, member 1C|X antigen family, member 1D|cancer/testis antigen 12.1|cancer/testis antigen family 12, member 1b|cancer/testis antigen family 12, member 1c|cancer/testis antigen family 12, member 1d|cancer/testis antigen family 12, member 1e|cancer/testis associated protein|protein XAGE-1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52512074, end_position_on_the_genomic_accession=52517068, orientation='minus', exon_count=4, OMIM=[300289, 300744, 300745], no_hdr0=''),
    653073 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653073, CurrentID=0, Status='live', Symbol='GOLGA8J', Aliases=[], description='golgin A8 family member J', other_designations='golgin subfamily A member 8J|Golgin subfamily A member 8-like protein 3', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30082628, end_position_on_the_genomic_accession=30096711, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    653075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653075, CurrentID=0, Status='live', Symbol='GOLGA8T', Aliases=[], description='golgin A8 family member T', other_designations='golgin subfamily A member 8T', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30131257, end_position_on_the_genomic_accession=30148748, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    653082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653082, CurrentID=0, Status='live', Symbol='ZDHHC11B', Aliases=['DHHC-11B'], description='zinc finger DHHC-type containing 11B', other_designations='probable palmitoyltransferase ZDHHC11B|zinc finger DHHC domain-containing protein 11B', map_location='5p15.33', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=710355, end_position_on_the_genomic_accession=784749, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    653121 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653121, CurrentID=0, Status='live', Symbol='ZBTB8A', Aliases=['BOZF1', 'ZBTB8', 'ZNF916A'], description='zinc finger and BTB domain containing 8A', other_designations='zinc finger and BTB domain-containing protein 8A|BTB/POZ and zinc-finger domain-containing factor|BTB/POZ and zinc-finger domains factor on chromosome 1|zinc finger and BTB domain containing 8', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32539427, end_position_on_the_genomic_accession=32605941, orientation='plus', exon_count=5, OMIM=[618742], no_hdr0=''),
    653125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653125, CurrentID=0, Status='live', Symbol='GOLGA8K', Aliases=[], description='golgin A8 family member K', other_designations='golgin subfamily A member 8K|Golgin subfamily A member 8K', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32389599, end_position_on_the_genomic_accession=32403292, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    653140 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653140, CurrentID=0, Status='live', Symbol='FAM228A', Aliases=['C2orf84'], description='family with sequence similarity 228 member A', other_designations='protein FAM228A|UPF0638 protein C2orf84', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=24175053, end_position_on_the_genomic_accession=24191698, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    653145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653145, CurrentID=0, Status='live', Symbol='ANXA8', Aliases=['ANX8', 'CH17-360D5.2'], description='annexin A8', other_designations='annexin A8|VAC-beta|annexin VIII|annexin-8|vascular anticoagulant-beta', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47467993, end_position_on_the_genomic_accession=47991879, orientation='minus', exon_count=16, OMIM=[602396], no_hdr0=''),
    653149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653149, CurrentID=0, Status='live', Symbol='NBPF6', Aliases=[], description='NBPF member 6', other_designations='neuroblastoma breakpoint family member 6', map_location='1p13.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=108421496, end_position_on_the_genomic_accession=108471920, orientation='plus', exon_count=23, OMIM=[613996], no_hdr0=''),
    653166 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653166, CurrentID=0, Status='live', Symbol='OR1D4', Aliases=['OR17-30'], description='olfactory receptor family 1 subfamily D member 4', other_designations='olfactory receptor 1D4|olfactory receptor 17-30|olfactory receptor OR17-1|olfactory receptor pseudogene|olfactory receptor, family 1, subfamily D, member 4 pseudogene', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=3240676, end_position_on_the_genomic_accession=3241614, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    653192 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653192, CurrentID=0, Status='live', Symbol='TRIM43B', Aliases=[], description='tripartite motif containing 43B', other_designations='tripartite motif-containing protein 43B|tripartite motif-containing protein 43-like protein 1', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=95476967, end_position_on_the_genomic_accession=95484754, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    653220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653220, CurrentID=0, Status='live', Symbol='XAGE1A', Aliases=['CT12.1', 'CT12.1A', 'CT12.1B', 'CTP9', 'GAGED2', 'XAGE-1', 'XAGE1', 'XAGE1B'], description='X antigen family member 1A', other_designations='X antigen family member 1|G antigen family D member 2|G antigen, family D, 2|X antigen family member 1B|cancer/testis antigen 12.1|cancer/testis antigen family 12, member 1a|cancer/testis antigen family 12, member 1b|cancer/testis associated protein|protein XAGE-1', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52495808, end_position_on_the_genomic_accession=52500815, orientation='plus', exon_count=4, OMIM=[300742, 300743], no_hdr0=''),
    653240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653240, CurrentID=0, Status='live', Symbol='KRTAP4-11', Aliases=['KAP4.11', 'KAP4.14', 'KRTAP4-14', 'KRTAP4.14'], description='keratin associated protein 4-11', other_designations='keratin-associated protein 4-11|keratin-associated protein 4-14|keratin-associated protein 4.11|keratin-associated protein 4.14|ultrahigh sulfur keratin-associated protein 4.14', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41117181, end_position_on_the_genomic_accession=41118373, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    653247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653247, CurrentID=0, Status='live', Symbol='PRB2', Aliases=['IB-9', 'PRPPRB1', 'Ps', 'cP7'], description='proline rich protein BstNI subfamily 2', other_designations='basic salivary proline-rich protein 2|Basic proline-rich peptide P-E|con1 glycoprotein|proline-rich protein BstNI, subfamily-2 (parotid size variant)|salivary proline-rich protein 2', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11391540, end_position_on_the_genomic_accession=11395567, orientation='minus', exon_count=4, OMIM=[168810], no_hdr0=''),
    653269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653269, CurrentID=0, Status='live', Symbol='POTEI', Aliases=['POTE2beta'], description='POTE ankyrin domain family member I', other_designations='POTE ankyrin domain family member I', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130459455, end_position_on_the_genomic_accession=130509707, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    653275 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653275, CurrentID=0, Status='live', Symbol='CFC1B', Aliases=[], description='cripto, FRL-1, cryptic family 1B', other_designations='cryptic family protein 1B', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130521212, end_position_on_the_genomic_accession=130528603, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    653282 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653282, CurrentID=0, Status='live', Symbol='CT47A7', Aliases=['CT47.7'], description='cancer/testis antigen family 47 member A7', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 7', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120953282, end_position_on_the_genomic_accession=120956600, orientation='minus', exon_count=4, OMIM=[300786], no_hdr0=''),
    653308 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653308, CurrentID=0, Status='live', Symbol='ASAH2B', Aliases=['ASAH2C', 'ASAH2L', 'bA449O16.3', 'bA98I6.3'], description='N-acylsphingosine amidohydrolase 2B', other_designations='putative inactive neutral ceramidase B|ASAH2-like protein|N-acylsphingosine amidohydrolase (non-lysosomal ceramidase) 2B|putative inactive N-acylsphingosine amidohydrolase 2B|putative inactive non-lysosomal ceramidase B', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=50739936, end_position_on_the_genomic_accession=50759255, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    653319 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653319, CurrentID=0, Status='live', Symbol='KIAA0895L', Aliases=[], description='KIAA0895 like', other_designations='uncharacterized protein KIAA0895-like', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=67175599, end_position_on_the_genomic_accession=67183963, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    653333 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653333, CurrentID=0, Status='live', Symbol='FAM86B2', Aliases=[], description='family with sequence similarity 86 member B2', other_designations='putative protein N-methyltransferase FAM86B2|protein FAM86B2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12424421, end_position_on_the_genomic_accession=12436400, orientation='minus', exon_count=8, OMIM=[616123], no_hdr0=''),
    653361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653361, CurrentID=0, Status='live', Symbol='NCF1', Aliases=['CGD1A', 'NOXO2', 'SH3PXD1A', 'p47phox', 'NCF1'], description='neutrophil cytosolic factor 1', other_designations='neutrophil cytosol factor 1|47 kDa autosomal chronic granulomatous disease protein|47 kDa neutrophil oxidase factor|NADPH oxidase organizer 2|NCF-1|NCF-47K|SH3 and PX domain-containing protein 1A|neutrophil NADPH oxidase factor 1|neutrophil cytosolic factor 1, (chronic granulomatous disease, autosomal 1)|nox organizer 2|nox-organizing protein 2|p47-phox', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74774011, end_position_on_the_genomic_accession=74789315, orientation='plus', exon_count=11, OMIM=[608512], no_hdr0=''),
    653404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653404, CurrentID=0, Status='live', Symbol='FOXD4L6', Aliases=[], description='forkhead box D4 like 6', other_designations='forkhead box protein D4-like 6|FOXD4-like 6', map_location='9p11.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=41126435, end_position_on_the_genomic_accession=41128681, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    653423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653423, CurrentID=0, Status='live', Symbol='SPAG11A', Aliases=['EDDM2A', 'HE2'], description='sperm associated antigen 11A', other_designations='sperm-associated antigen 11A|epididymal protein 2A|human epididymis-specific protein 2|sperm antigen HE2', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7847923, end_position_on_the_genomic_accession=7863797, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    653427 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653427, CurrentID=0, Status='live', Symbol='FOXD4L5', Aliases=['bA15J10.2'], description='forkhead box D4 like 5', other_designations='forkhead box protein D4-like 5|FOXD4-like 5', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=65282101, end_position_on_the_genomic_accession=65285209, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    653437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653437, CurrentID=0, Status='live', Symbol='AQP12B', Aliases=['INSSA3'], description='aquaporin 12B', other_designations='aquaporin-12B|AQP-12B|insulin synthesis associated 3', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240676418, end_position_on_the_genomic_accession=240685743, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    653464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653464, CurrentID=0, Status='live', Symbol='SRGAP2C', Aliases=['SRGAP2P1'], description='SLIT-ROBO Rho GTPase activating protein 2C', other_designations='SLIT-ROBO Rho GTPase-activating protein 2C|SLIT-ROBO Rho GTPase activating protein 2 pseudogene 1', map_location='1p11.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=121184975, end_position_on_the_genomic_accession=121392874, orientation='plus', exon_count=10, OMIM=[614704], no_hdr0=''),
    653486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653486, CurrentID=0, Status='live', Symbol='SCGB1C2', Aliases=['SCGB1C1'], description='secretoglobin family 1C member 2', other_designations='secretoglobin family 1C member 2|Secretoglobin RYD5|Secretoglobin family 1C member 1|secretoglobin, family 1C, member 1-like', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=132346, end_position_on_the_genomic_accession=139067, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    653489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653489, CurrentID=0, Status='live', Symbol='RGPD3', Aliases=['RGP3'], description='RANBP2 like and GRIP domain containing 3', other_designations='ranBP2-like and GRIP domain-containing protein 3', map_location='2q12.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=106403406, end_position_on_the_genomic_accession=106470935, orientation='minus', exon_count=27, OMIM=[612706], no_hdr0=''),
    653499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653499, CurrentID=0, Status='live', Symbol='LGALS7B', Aliases=['GAL7', 'Gal-7', 'HKL-14', 'LGALS7', 'PI7'], description='galectin 7B', other_designations='galectin-7|keratinocyte lectin 14|lectin galactoside-binding soluble 7|lectin, galactoside-binding, soluble, 7B|p53-induced gene 1 protein|p53-induced protein 1', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=38789200, end_position_on_the_genomic_accession=38791754, orientation='plus', exon_count=4, OMIM=[617139], no_hdr0=''),
    653505 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653505, CurrentID=0, Status='live', Symbol='PPIAL4A', Aliases=['COAS-2', 'COAS2', 'PPIAL4', 'PPIAL4B'], description='peptidylprolyl isomerase A like 4A', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4A|PPIase A-like 4B|PPIase A-like 4G|chromosome 1-amplified sequence 2|chromosome one-amplified sequence 2|cyclophilin homolog overexpressed in liver cancer|cyclophilin-LC (COAS2)|peptidyl-prolyl cis-trans isomerase A-like 4A/B/C|peptidylprolyl cis-trans isomerase A-like 4B|peptidylprolyl isomerase A (cyclophilin A)-like 4A|peptidylprolyl isomerase A (cyclophilin A)-like 4B', map_location='1p11.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=120889771, end_position_on_the_genomic_accession=120890530, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    653509 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653509, CurrentID=0, Status='live', Symbol='SFTPA1', Aliases=['COLEC4', 'PSAP', 'PSP-A', 'PSPA', 'SFTP1B', 'SP-A', 'SP-A1', 'SP-A1 beta', 'SP-A1 delta', 'SP-A1 epsilon', 'SP-A1 gamma', 'SPA', 'SPA1', 'SFTPA1'], description='surfactant protein A1', other_designations='pulmonary surfactant-associated protein A1|35 kDa pulmonary surfactant-associated protein|alveolar proteinosis protein|collectin-4|surfactant protein A1B|surfactant, pulmonary-associated protein A1A|surfactant, pulmonary-associated protein A1B', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79610939, end_position_on_the_genomic_accession=79615455, orientation='plus', exon_count=8, OMIM=[178630], no_hdr0=''),
    653519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653519, CurrentID=0, Status='live', Symbol='GPR89A', Aliases=['GPHR', 'GPR89', 'GPR89B', 'SH120', 'UNQ192'], description='G protein-coupled receptor 89A', other_designations='Golgi pH regulator A|protein GPR89|putative MAPK-activating protein PM01|putative NF-kappa-B-activating protein 90', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145607987, end_position_on_the_genomic_accession=145670977, orientation='plus', exon_count=17, OMIM=[612821], no_hdr0=''),
    653550 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653550, CurrentID=0, Status='live', Symbol='TP53TG3C', Aliases=['TP53TG3', 'TP53TG3E', 'TP53TG3F'], description='TP53 target 3C', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=33191770, end_position_on_the_genomic_accession=33196865, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    653567 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653567, CurrentID=0, Status='live', Symbol='TMEM236', Aliases=['FAM23A', 'FAM23B', 'bA162I21.2', 'bA16O1.2'], description='transmembrane protein 236', other_designations='transmembrane protein 236|family with sequence similarity 23, member A|family with sequence similarity 23, member B', map_location='10p12.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=17752110, end_position_on_the_genomic_accession=17800916, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    653583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653583, CurrentID=0, Status='live', Symbol='PHLDB3', Aliases=[], description='pleckstrin homology like domain family B member 3', other_designations='pleckstrin homology-like domain family B member 3', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43474341, end_position_on_the_genomic_accession=43504916, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    653598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653598, CurrentID=0, Status='live', Symbol='PPIAL4C', Aliases=['COAS-2'], description='peptidylprolyl isomerase A like 4C', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4A/B/C|PPIase A-like 4A|PPIase A-like 4C|chromosome 1-amplified sequence 2|chromosome one-amplified sequence 2|cyclophilin homolog overexpressed in liver cancer|peptidylprolyl isomerase A (cyclophilin A)-like 4C', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149583848, end_position_on_the_genomic_accession=149584607, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    653604 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653604, CurrentID=0, Status='live', Symbol='H3C13', Aliases=['H3C14', 'H3C15', 'HIST2H3D'], description='H3 clustered histone 13', other_designations='histone H3.2|H3-clustered histone 14|H3-clustered histone 15|histone 2, H3d|histone cluster 2 H3 family member d|histone cluster 2, H3d', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149813225, end_position_on_the_genomic_accession=149813693, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    653606 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653606, CurrentID=0, Status='live', Symbol='PRAMEF22', Aliases=['PRAMEF3L'], description='PRAME family member 22', other_designations='PRAME family member 22', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    653619 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653619, CurrentID=0, Status='live', Symbol='PRAMEF15', Aliases=[], description='PRAME family member 15', other_designations='PRAME family member 9/15', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13315581, end_position_on_the_genomic_accession=13322598, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    653641 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653641, CurrentID=0, Status='live', Symbol='GOLGA6C', Aliases=[], description='golgin A6 family member C', other_designations='golgin subfamily A member 6C|Golgin subfamily A member 6C|golgi autoantigen, golgin subfamily a, 6C|putative golgin subfamily A member 6C', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75258334, end_position_on_the_genomic_accession=75273455, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    653643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653643, CurrentID=0, Status='live', Symbol='GOLGA6D', Aliases=[], description='golgin A6 family member D', other_designations='golgin subfamily A member 6D|golgi autoantigen, golgin subfamily a, 6D|putative golgin subfamily A member 6D', map_location='15q24.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=75282835, end_position_on_the_genomic_accession=75295530, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    653656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653656, CurrentID=0, Status='live', Symbol='MBD3L4', Aliases=[], description='methyl-CpG binding domain protein 3 like 4', other_designations='putative methyl-CpG-binding domain protein 3-like 4|MBD3-like 4|MBD3-like protein 4|Putative methyl-CpG-binding domain protein 3-like 4', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7037749, end_position_on_the_genomic_accession=7040179, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    653657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653657, CurrentID=0, Status='live', Symbol='MBD3L3', Aliases=[], description='methyl-CpG binding domain protein 3 like 3', other_designations='putative methyl-CpG-binding domain protein 3-like 3|MBD3-like 3|MBD3-like protein 3', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7056207, end_position_on_the_genomic_accession=7058676, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    653689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653689, CurrentID=0, Status='live', Symbol='GSTT2B', Aliases=['GSTT2P'], description='glutathione S-transferase theta 2B', other_designations='glutathione S-transferase theta-2B|GST class-theta-2|glutathione S-transferase theta 2', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23957414, end_position_on_the_genomic_accession=23961206, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    653720 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653720, CurrentID=0, Status='live', Symbol='GOLGA8M', Aliases=[], description='golgin A8 family member M', other_designations='golgin subfamily A member 8M|Putative golgin subfamily A member 6-like protein 7', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28698583, end_position_on_the_genomic_accession=28738556, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    653781 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653781, CurrentID=0, Status='live', Symbol='POTEJ', Aliases=['POTE2beta'], description='POTE ankyrin domain family member J', other_designations='POTE ankyrin domain family member J', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130611078, end_position_on_the_genomic_accession=130658448, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    653784 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653784, CurrentID=0, Status='live', Symbol='MZT2A', Aliases=['FAM128A', 'MOZART2A'], description='mitotic spindle organizing protein 2A', other_designations='mitotic-spindle organizing protein 2A|family with sequence similarity 128, member A|mitotic-spindle organizing protein associated with a ring of gamma-tubulin 2A', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=131469724, end_position_on_the_genomic_accession=131493080, orientation='minus', exon_count=8, OMIM=[613449], no_hdr0=''),
    653808 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653808, CurrentID=0, Status='live', Symbol='ZG16', Aliases=['JCLN', 'JCLN1A', 'ZG16'], description='zymogen granule protein 16', other_designations='zymogen granule membrane protein 16|jacalin-like lectin domain containing|secretory lectin ZG16|zymogen granule protein 16 homolog', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29760804, end_position_on_the_genomic_accession=29782973, orientation='plus', exon_count=5, OMIM=[617311], no_hdr0=''),
    653820 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653820, CurrentID=0, Status='live', Symbol='FAM72B', Aliases=['p17'], description='family with sequence similarity 72 member B', other_designations='protein FAM72B|RP11-439A17.6|amyloid-beta peptide-induced protein p17', map_location='1p11.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=121167646, end_position_on_the_genomic_accession=121184340, orientation='minus', exon_count=4, OMIM=[614711], no_hdr0=''),
    653857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=653857, CurrentID=0, Status='live', Symbol='ACTR3C', Aliases=['ARP11'], description='actin related protein 3C', other_designations='actin-related protein 3C|ARP3 actin related protein 3 homolog C|actin-related Arp11|actin-related protein 11', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149881359, end_position_on_the_genomic_accession=150323669, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    654231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654231, CurrentID=0, Status='live', Symbol='OCM', Aliases=['OCM1', 'OM', 'ONCM'], description='oncomodulin', other_designations='oncomodulin-1|beta parvalbumin|hCG18255|parvalbumin beta', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5859718, end_position_on_the_genomic_accession=5886363, orientation='plus', exon_count=5, OMIM=[164795], no_hdr0=''),
    654254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654254, CurrentID=0, Status='live', Symbol='ZNF732', Aliases=[], description='zinc finger protein 732', other_designations='zinc finger protein 732|zinc finger protein LOC654254', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=270675, end_position_on_the_genomic_accession=305474, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    654346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654346, CurrentID=0, Status='live', Symbol='LGALS9C', Aliases=['Gal-9B', 'LGALS9B'], description='galectin 9C', other_designations='galectin-9C|Galectin-9-like protein A|Galectin-9B|gal-9C|galectin 9 like|galectin-9-like protein B|lectin, galactoside-binding, soluble, 9 (galectin 9) pseudogene|lectin, galactoside-binding, soluble, 9C', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=18476785, end_position_on_the_genomic_accession=18494945, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    654364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654364, CurrentID=0, Status='live', Symbol='NME1-NME2', Aliases=['NM23-LV', 'NMELV'], description='NME1-NME2 readthrough', other_designations='NME1-NME2 protein|NME1-NME2 readthrough transcript', map_location='17q21.33', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=51153559, end_position_on_the_genomic_accession=51171744, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    654429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654429, CurrentID=0, Status='live', Symbol='LRTM2', Aliases=[], description='leucine rich repeats and transmembrane domains 2', other_designations='leucine-rich repeat and transmembrane domain-containing protein 2', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=1820267, end_position_on_the_genomic_accession=1836753, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    654463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654463, CurrentID=0, Status='live', Symbol='FER1L6', Aliases=['C8ORFK23'], description='fer-1 like family member 6', other_designations='fer-1-like protein 6|fer-1-like 6', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123851987, end_position_on_the_genomic_accession=124120061, orientation='plus', exon_count=47, OMIM=[], no_hdr0=''),
    654483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654483, CurrentID=0, Status='live', Symbol='BOLA2B', Aliases=['BOLA2'], description='bolA family member 2B', other_designations='bolA-like protein 2|BolA-like protein 2 member B|bolA homolog 2B|bolA-like protein 2B', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30192932, end_position_on_the_genomic_accession=30193666, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    654502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654502, CurrentID=0, Status='live', Symbol='IQCJ', Aliases=[], description='IQ motif containing J', other_designations='IQ domain-containing protein J|calmodulin binding protein', map_location='3q25.32', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=159069319, end_position_on_the_genomic_accession=159266307, orientation='plus', exon_count=5, OMIM=[611622], no_hdr0=''),
    654790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=654790, CurrentID=0, Status='live', Symbol='PCP4L1', Aliases=['IQM1'], description='Purkinje cell protein 4 like 1', other_designations='Purkinje cell protein 4-like protein 1|PCP4-like protein 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161258734, end_position_on_the_genomic_accession=161285450, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    677790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=677790, CurrentID=0, Status='live', Symbol='TMEM78', Aliases=[], description='transmembrane protein 78', other_designations='', map_location='1q42.13', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    692094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=692094, CurrentID=0, Status='live', Symbol='MSMP', Aliases=['PSMP'], description='microseminoprotein, prostate associated', other_designations='prostate-associated microseminoprotein|PC3 prostate cancer cell-secreted microprotein', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35752990, end_position_on_the_genomic_accession=35754276, orientation='minus', exon_count=3, OMIM=[612191], no_hdr0=''),
    692312 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=692312, CurrentID=0, Status='live', Symbol='PPAN-P2RY11', Aliases=['BXDC3', 'P2RY11', 'P2Y11', 'PPAN', 'SSF1', 'Ssf-1'], description='PPAN-P2RY11 readthrough', other_designations='PPAN-P2RY11 protein|Brix domain-containing protein 3|P2Y purinoceptor 11|PPAN-P2RY11 readthrough transcript|Peter Pan homolog|SSF1/P2Y11 protein|Suppressor of SWI4 1 homolog', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10106362, end_position_on_the_genomic_accession=10115372, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    723790 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=723790, CurrentID=0, Status='live', Symbol='H2AC19', Aliases=['H2A/R', 'H2AC18', 'HIST2H2AA4'], description='H2A clustered histone 19', other_designations='histone H2A type 2-A|H2A-clustered histone 18|histone 2, H2aa4|histone H2A/r|histone cluster 2 H2A family member a4|histone cluster 2, H2aa4', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149851061, end_position_on_the_genomic_accession=149851594, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    723961 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=723961, CurrentID=0, Status='live', Symbol='INS-IGF2', Aliases=['INSIGF'], description='INS-IGF2 readthrough', other_designations='insulin, isoform 2|INS-IGF2 readthrough transcript protein|insulin|insulin- insulin-like growth factor 2 read-through product', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=2129117, end_position_on_the_genomic_accession=2161209, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    724066 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=724066, CurrentID=0, Status='live', Symbol='ATXN8', Aliases=[], description='ataxin 8', other_designations='ataxin-8|protein 1C2', map_location='13q21', chromosome='13', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[613289], no_hdr0=''),
    727800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727800, CurrentID=0, Status='live', Symbol='RNF208', Aliases=[], description='ring finger protein 208', other_designations='RING finger protein 208', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137220259, end_position_on_the_genomic_accession=137223408, orientation='minus', exon_count=2, OMIM=[618993], no_hdr0=''),
    727830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727830, CurrentID=0, Status='live', Symbol='SPATA31A3', Aliases=['FAM75A3'], description='SPATA31 subfamily A member 3', other_designations='spermatogenesis-associated protein 31A3|family with sequence similarity 75, member A3|protein FAM75A3', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=66986304, end_position_on_the_genomic_accession=66992550, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    727832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727832, CurrentID=0, Status='live', Symbol='GOLGA6L6', Aliases=[], description='golgin A6 family like 6', other_designations='golgin subfamily A member 6-like protein 6|golgi autoantigen, golgin subfamily a, 6-like 6|putative golgin subfamily A member 6-like protein 6', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=20531856, end_position_on_the_genomic_accession=20541800, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    727837 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727837, CurrentID=0, Status='live', Symbol='SSX2B', Aliases=['CT5.2', 'CT5.2b', 'HOM-MEL-40', 'SSX'], description='SSX family member 2B', other_designations='protein SSX2|cancer/testis antigen 5.2|cancer/testis antigen family 5, member 2b|synovial sarcoma, X breakpoint 2B|tumor antigen HOM-MEL-40', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52751252, end_position_on_the_genomic_accession=52761536, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    727851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727851, CurrentID=0, Status='live', Symbol='RGPD8', Aliases=['RANBP2L1', 'RGP8', 'RanBP2alpha'], description='RANBP2 like and GRIP domain containing 8', other_designations='RANBP2-like and GRIP domain-containing protein 8|RAN binding protein 2-like 1|ran-binding protein 2-like 3|ranBP2-like 3|ranBP2L3', map_location='2q14.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=112368369, end_position_on_the_genomic_accession=112433645, orientation='minus', exon_count=27, OMIM=[602752], no_hdr0=''),
    727857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727857, CurrentID=0, Status='live', Symbol='BHLHA9', Aliases=['BHLHF42', 'CCSPD'], description='basic helix-loop-helix family member a9', other_designations='class A basic helix-loop-helix protein 9|Fingerin|class F basic helix-loop-helix factor 42|class II basic helix-loop-helix protein', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1270444, end_position_on_the_genomic_accession=1271815, orientation='plus', exon_count=1, OMIM=[615416], no_hdr0=''),
    727866 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727866, CurrentID=0, Status='live', Symbol='FAM156B', Aliases=['TMEM29B'], description='family with sequence similarity 156 member B', other_designations='protein FAM156A/FAM156B|protein FAM156A|transmembrane protein 29|transmembrane protein 29/29B|transmembrane protein 29B', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52891592, end_position_on_the_genomic_accession=52908560, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    727897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727897, CurrentID=0, Status='live', Symbol='MUC5B', Aliases=['MG1', 'MUC-5B', 'MUC5', 'MUC9'], description='mucin 5B, oligomeric mucus/gel-forming', other_designations='mucin-5B|cervical mucin MUC5B|high molecular weight salivary mucin MG1|mucin 5, subtype B, tracheobronchial|sublingual gland mucin', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=1223066, end_position_on_the_genomic_accession=1262172, orientation='plus', exon_count=49, OMIM=[600770], no_hdr0=''),
    727905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727905, CurrentID=0, Status='live', Symbol='SPATA31A5', Aliases=['FAM75A5'], description='SPATA31 subfamily A member 5', other_designations='spermatogenesis-associated protein 31A5|family with sequence similarity 75, member A5|protein FAM75A5', map_location='9q12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=60914372, end_position_on_the_genomic_accession=60920653, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    727909 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727909, CurrentID=0, Status='live', Symbol='GOLGA8Q', Aliases=[], description='golgin A8 family member Q', other_designations='golgin subfamily A member 8Q', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30552050, end_position_on_the_genomic_accession=30565684, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    727910 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727910, CurrentID=0, Status='live', Symbol='TLCD2', Aliases=[], description='TLC domain containing 2', other_designations='TLC domain-containing protein 2', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=1702816, end_position_on_the_genomic_accession=1710377, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    727936 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727936, CurrentID=0, Status='live', Symbol='GXYLT2', Aliases=['GLT8D4'], description='glucoside xylosyltransferase 2', other_designations='glucoside xylosyltransferase 2|glycosyltransferase 8 domain containing 4|glycosyltransferase 8 domain-containing protein 4', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=72888046, end_position_on_the_genomic_accession=72976915, orientation='plus', exon_count=7, OMIM=[613322], no_hdr0=''),
    727940 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727940, CurrentID=0, Status='live', Symbol='RHOXF2B', Aliases=[], description='Rhox homeobox family member 2B', other_designations='rhox homeobox family member 2B', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120072264, end_position_on_the_genomic_accession=120077690, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    727957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=727957, CurrentID=0, Status='live', Symbol='MROH1', Aliases=['HEATR7A'], description='maestro heat like repeat family member 1', other_designations='maestro heat-like repeat-containing protein family member 1|HEAT repeat containing 7A|HEAT repeat-containing protein 7A', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=144148016, end_position_on_the_genomic_accession=144261938, orientation='plus', exon_count=51, OMIM=[], no_hdr0=''),
    728036 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728036, CurrentID=0, Status='live', Symbol='CT47A10', Aliases=['CT47', 'CT47.10'], description='cancer/testis antigen family 47 member A10', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 10|cancer/testis antigen 47', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120938701, end_position_on_the_genomic_accession=120942121, orientation='minus', exon_count=4, OMIM=[300789], no_hdr0=''),
    728042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728042, CurrentID=0, Status='live', Symbol='CT47A9', Aliases=['CT47.9'], description='cancer/testis antigen family 47 member A9', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 9', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120943561, end_position_on_the_genomic_accession=120946981, orientation='minus', exon_count=4, OMIM=[300788], no_hdr0=''),
    728047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728047, CurrentID=0, Status='live', Symbol='GOLGA8O', Aliases=[], description='golgin A8 family member O', other_designations='golgin subfamily A member 8O|Golgin subfamily A member 6-like protein 11|Golgin subfamily A member 8O', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32441914, end_position_on_the_genomic_accession=32461753, orientation='minus', exon_count=21, OMIM=[], no_hdr0=''),
    728049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728049, CurrentID=0, Status='live', Symbol='CT47A8', Aliases=['CT47.8'], description='cancer/testis antigen family 47 member A8', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 8', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120948422, end_position_on_the_genomic_accession=120951842, orientation='minus', exon_count=4, OMIM=[300787], no_hdr0=''),
    728062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728062, CurrentID=0, Status='live', Symbol='CT47A6', Aliases=['CT47.6'], description='cancer/testis antigen family 47 member A6', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 6', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120958165, end_position_on_the_genomic_accession=120961588, orientation='minus', exon_count=4, OMIM=[300785], no_hdr0=''),
    728072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728072, CurrentID=0, Status='live', Symbol='CT47A5', Aliases=['CT47.5'], description='cancer/testis antigen family 47 member A5', other_designations='cancer/testis antigen 47A|CT47|cancer/testis CT47 family, member 5|cancer/testis antigen 47', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120963026, end_position_on_the_genomic_accession=120966446, orientation='minus', exon_count=4, OMIM=[300784], no_hdr0=''),
    728075 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728075, CurrentID=0, Status='live', Symbol='CT47A4', Aliases=['CT47.4'], description='cancer/testis antigen family 47 member A4', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 4', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120967886, end_position_on_the_genomic_accession=120971306, orientation='minus', exon_count=4, OMIM=[300783], no_hdr0=''),
    728082 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728082, CurrentID=0, Status='live', Symbol='CT47A3', Aliases=['CT47.3'], description='cancer/testis antigen family 47 member A3', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 3', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120972746, end_position_on_the_genomic_accession=120976166, orientation='minus', exon_count=4, OMIM=[300782], no_hdr0=''),
    728090 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728090, CurrentID=0, Status='live', Symbol='CT47A2', Aliases=['CT47.2'], description='cancer/testis antigen family 47 member A2', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 2', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120977606, end_position_on_the_genomic_accession=120981026, orientation='minus', exon_count=4, OMIM=[300781], no_hdr0=''),
    728096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728096, CurrentID=0, Status='live', Symbol='CT47A1', Aliases=['CT47.1'], description='cancer/testis antigen family 47 member A1', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 1', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120982476, end_position_on_the_genomic_accession=120985886, orientation='minus', exon_count=4, OMIM=[300780], no_hdr0=''),
    728113 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728113, CurrentID=0, Status='live', Symbol='ANXA8L1', Aliases=['ANXA8', 'ANXA8L2', 'VAC-beta', 'bA145E20.2'], description='annexin A8 like 1', other_designations='annexin A8-like protein 1|annexin A8-like protein 2|annexin A8L2|annexin VIII|annexin-8|vascular anticoagulant-beta', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=46375776, end_position_on_the_genomic_accession=46391778, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    728116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728116, CurrentID=0, Status='live', Symbol='ZBTB8B', Aliases=['ZNF916B'], description='zinc finger and BTB domain containing 8B', other_designations='zinc finger and BTB domain-containing protein 8B|putative zinc finger and BTB domain-containing protein 8B', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32465072, end_position_on_the_genomic_accession=32496686, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    728118 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728118, CurrentID=0, Status='live', Symbol='NUTM2A', Aliases=['FAM22A'], description='NUT family member 2A', other_designations='NUT family member 2A|family with sequence similarity 22, member A|protein FAM22A', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87221899, end_position_on_the_genomic_accession=87235372, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    728130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728130, CurrentID=0, Status='live', Symbol='NUTM2D', Aliases=['FAM22D'], description='NUT family member 2D', other_designations='NUT family member 2D|NUT family member 2A pseudogene|family with sequence similarity 22, member D|protein FAM22D', map_location='10q23.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87357744, end_position_on_the_genomic_accession=87370695, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    728137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728137, CurrentID=0, Status='live', Symbol='TSPY3', Aliases=['CT78', 'TSPY', 'TSPY1', 'TSPY10'], description='testis specific protein Y-linked 3', other_designations='testis-specific Y-encoded protein 3|Cancer/testis antigen 78|Testis-specific Y-encoded protein 1|Testis-specific Y-encoded protein 10', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=9398421, end_position_on_the_genomic_accession=9401224, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    728194 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728194, CurrentID=0, Status='live', Symbol='RSPH10B2', Aliases=[], description='radial spoke head 10 homolog B2', other_designations='radial spoke head 10 homolog B', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6754109, end_position_on_the_genomic_accession=6798775, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    728215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728215, CurrentID=0, Status='live', Symbol='NALF1', Aliases=['FAM155A', 'NLF-1'], description='NALCN channel auxiliary factor 1', other_designations='transmembrane protein FAM155A|family with sequence similarity 155 member A', map_location='13q33.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=107163510, end_position_on_the_genomic_accession=107867496, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    728224 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728224, CurrentID=0, Status='live', Symbol='KRTAP4-8', Aliases=['KAP4.8', 'KRTAP4.8'], description='keratin associated protein 4-8', other_designations='keratin-associated protein 4-8|keratin associated protein 4.8|ultrahigh sulfur keratin-associated protein 4.8', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41096981, end_position_on_the_genomic_accession=41098142, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    728226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728226, CurrentID=0, Status='live', Symbol='GGTLC3', Aliases=['GGT'], description='gamma-glutamyltransferase light chain family member 3', other_designations='putative glutathione hydrolase light chain 3|gamma-glutamyltransferase light chain 3|putative gamma-glutamyltransferase light chain 3', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18516335, end_position_on_the_genomic_accession=18518165, orientation='minus', exon_count=5, OMIM=[612340], no_hdr0=''),
    728229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728229, CurrentID=0, Status='live', Symbol='TMEM191B', Aliases=[], description='transmembrane protein 191B', other_designations='transmembrane protein 191B', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=18527802, end_position_on_the_genomic_accession=18531920, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    728239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728239, CurrentID=0, Status='live', Symbol='MAGED4', Aliases=['MAGE-D4', 'MAGE-E1', 'MAGE1', 'MAGEE1'], description='MAGE family member D4', other_designations='melanoma-associated antigen D4|MAGE-D4 antigen|MAGE-E1 antigen|melanoma antigen family D, 4|melanoma antigen family D4', map_location='Xp11.22', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=52184888, end_position_on_the_genomic_accession=52192268, orientation='plus', exon_count=14, OMIM=[300702], no_hdr0=''),
    728255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728255, CurrentID=0, Status='live', Symbol='KRTAP1-4', Aliases=['KAP1.4', 'KRTAP1.4'], description='keratin associated protein 1-4', other_designations='keratin-associated protein 1-4|high sulfur keratin-associated protein 1.4|keratin-associated protein 1.4', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41029351, end_position_on_the_genomic_accession=41030195, orientation='minus', exon_count=1, OMIM=[608821], no_hdr0=''),
    728269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728269, CurrentID=0, Status='live', Symbol='MAGEA9B', Aliases=[], description='MAGE family member A9B', other_designations='melanoma-associated antigen 9|CT1.9|MAGE-9 antigen|cancer/testis antigen 1.9|melanoma antigen family A, 9B|melanoma antigen family A9B', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149581653, end_position_on_the_genomic_accession=149587468, orientation='minus', exon_count=5, OMIM=[300764], no_hdr0=''),
    728276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728276, CurrentID=0, Status='live', Symbol='CLEC19A', Aliases=[], description='C-type lectin domain containing 19A', other_designations='C-type lectin domain family 19 member A', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=19285731, end_position_on_the_genomic_accession=19310947, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    728279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728279, CurrentID=0, Status='live', Symbol='KRTAP2-2', Aliases=['KAP2.1', 'KAP2.2', 'KRTAP2-1', 'KRTAP2.1A', 'KRTAP2.1B'], description='keratin associated protein 2-2', other_designations='putative keratin-associated protein ENSP00000381495|High sulfur keratin-associated protein 2.1|Keratin-associated protein 2-1|Keratin-associated protein 2.1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41054498, end_position_on_the_genomic_accession=41055230, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    728294 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728294, CurrentID=0, Status='live', Symbol='D2HGDH', Aliases=['D2HGD'], description='D-2-hydroxyglutarate dehydrogenase', other_designations='D-2-hydroxyglutarate dehydrogenase, mitochondrial', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=241734629, end_position_on_the_genomic_accession=241768816, orientation='plus', exon_count=21, OMIM=[609186], no_hdr0=''),
    728299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728299, CurrentID=0, Status='live', Symbol='KRTAP19-8', Aliases=[], description='keratin associated protein 19-8', other_designations='keratin-associated protein 19-8', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=31038159, end_position_on_the_genomic_accession=31038476, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    728310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728310, CurrentID=0, Status='live', Symbol='GOLGA6L7', Aliases=['GOLGA6L7P'], description='golgin A6 family like 7', other_designations='golgin subfamily A member 6-like protein 7|golgi autoantigen, golgin subfamily a, 6-like 7 (pseudogene)|golgin A6 family-like 7, pseudogene|golgin A6 family-like 9 pseudogene', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28841832, end_position_on_the_genomic_accession=28848644, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    728318 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728318, CurrentID=0, Status='live', Symbol='KRTAP9-1', Aliases=['KAP9.1', 'KRTAP9L3'], description='keratin associated protein 9-1', other_designations='keratin-associated protein 9-1|keratin associated protein 9-like 3|putative keratin-associated protein 9-2-like 3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41189887, end_position_on_the_genomic_accession=41190639, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728340, CurrentID=0, Status='live', Symbol='GTF2H2C', Aliases=['GTF2H2C_2'], description='GTF2H2 family member C', other_designations='general transcription factor IIH subunit 2-like protein|general transcription factor IIH polypeptide 2-like protein|general transcription factor IIH, polypeptide 2C', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69560191, end_position_on_the_genomic_accession=69595221, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    728343 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728343, CurrentID=0, Status='live', Symbol='NXF2B', Aliases=['TCP11X2', 'bA353J17.1'], description='nuclear RNA export factor 2B', other_designations='nuclear RNA export factor 2|T-complex protein 11 X-linked protein 2|TAP-like protein 2|cancer/testis antigen 39', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102360395, end_position_on_the_genomic_accession=102440008, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    728358 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728358, CurrentID=0, Status='live', Symbol='DEFA1B', Aliases=['HNP-1', 'HP-1', 'HP1'], description='defensin alpha 1B', other_designations='neutrophil defensin 1', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=6996766, end_position_on_the_genomic_accession=6999198, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    728361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728361, CurrentID=0, Status='live', Symbol='OVOL3', Aliases=['HOVO3'], description='ovo like zinc finger 3', other_designations='putative transcription factor ovo-like protein 3|OVO homolog-like 3|ovo-like 3', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=36111143, end_position_on_the_genomic_accession=36113711, orientation='plus', exon_count=4, OMIM=[616442], no_hdr0=''),
    728369 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728369, CurrentID=0, Status='live', Symbol='USP17L24', Aliases=['USP17L25', 'USP17L26', 'USP17L27', 'USP17L28', 'USP17L29', 'USP17L30'], description='ubiquitin specific peptidase 17 like family member 24', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 24|deubiquitinating enzyme 17|ubiquitin thioesterase 17|ubiquitin-specific-processing protease 17', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9325165, end_position_on_the_genomic_accession=9326757, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728373, CurrentID=0, Status='live', Symbol='USP17L25', Aliases=[], description='ubiquitin specific peptidase 17 like family member 25', other_designations='ubiquitin specific peptidase 17 like family member 25', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9329911, end_position_on_the_genomic_accession=9331503, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728378, CurrentID=0, Status='live', Symbol='POTEF', Aliases=['A26C1B', 'ACTB', 'POTE2alpha', 'POTEACTIN'], description='POTE ankyrin domain family member F', other_designations='POTE ankyrin domain family member F|ANKRD26-like family C member 1B|POTE-2 alpha-actin|beta actin|chimeric POTE-actin protein|prostate, ovary, testis expressed protein on chromosome 2', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=130073535, end_position_on_the_genomic_accession=130129222, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    728379 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728379, CurrentID=0, Status='live', Symbol='USP17L26', Aliases=[], description='ubiquitin specific peptidase 17 like family member 26', other_designations='ubiquitin specific peptidase 17 like family member 26', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9334658, end_position_on_the_genomic_accession=9336250, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728386, CurrentID=0, Status='live', Symbol='USP17L5', Aliases=[], description='ubiquitin specific peptidase 17 like family member 5', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 5|deubiquitinating enzyme 17-like protein 5|ubiquitin thioesterase 17-like protein 5|ubiquitin thiolesterase 17-like protein 5|ubiquitin-specific-processing protease 17-like protein 5', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9339403, end_position_on_the_genomic_accession=9340995, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728392 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728392, CurrentID=0, Status='live', Symbol='LOC728392', Aliases=[], description='uncharacterized LOC728392', other_designations='uncharacterized protein LOC728392', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=5499427, end_position_on_the_genomic_accession=5501006, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    728393 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728393, CurrentID=0, Status='live', Symbol='USP17L27', Aliases=[], description='ubiquitin specific peptidase 17 like family member 27', other_designations='ubiquitin specific peptidase 17 like family member 27', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9344148, end_position_on_the_genomic_accession=9345740, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728395, CurrentID=0, Status='live', Symbol='TSPY4', Aliases=['TSPY10', 'TSPY8'], description='testis specific protein Y-linked 4', other_designations='testis-specific Y-encoded protein 4', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=9337489, end_position_on_the_genomic_accession=9340285, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    728400 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728400, CurrentID=0, Status='live', Symbol='USP17L28', Aliases=[], description='ubiquitin specific peptidase 17 like family member 28', other_designations='ubiquitin specific peptidase 17 like family member 28', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9348893, end_position_on_the_genomic_accession=9350485, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728403 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728403, CurrentID=0, Status='live', Symbol='TSPY8', Aliases=[], description='testis specific protein Y-linked 8', other_designations='testis-specific Y-encoded protein 8', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=9357797, end_position_on_the_genomic_accession=9360600, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    728405 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728405, CurrentID=0, Status='live', Symbol='USP17L29', Aliases=[], description='ubiquitin specific peptidase 17 like family member 29', other_designations='ubiquitin specific peptidase 17 like family member 29', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9353638, end_position_on_the_genomic_accession=9355230, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728419, CurrentID=0, Status='live', Symbol='USP17L30', Aliases=[], description='ubiquitin specific peptidase 17 like family member 30', other_designations='ubiquitin specific peptidase 17 like family member 30', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9363129, end_position_on_the_genomic_accession=9364721, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728441, CurrentID=0, Status='live', Symbol='GGT2', Aliases=['GGT', 'GGT 2'], description='gamma-glutamyltransferase 2', other_designations='inactive glutathione hydrolase 2|gamma-glutamyltranspeptidase 2|glutathione hydrolase 2|inactive gamma-glutamyltranspeptidase 2', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=21207972, end_position_on_the_genomic_accession=21283023, orientation='minus', exon_count=22, OMIM=[137181], no_hdr0=''),
    728458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728458, CurrentID=0, Status='live', Symbol='OPN1MW2', Aliases=['GOP'], description='opsin 1, medium wave sensitive 2', other_designations='medium-wave-sensitive opsin 1|green cone photoreceptor pigment|green-sensitive opsin|opsin 1 (cone pigments), medium-wave-sensitive 2|opsin 1 cone pigments medium-wave-sensitive 2', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154219756, end_position_on_the_genomic_accession=154233286, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    728464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728464, CurrentID=0, Status='live', Symbol='METTL24', Aliases=['C6orf186'], description='methyltransferase like 24', other_designations='methyltransferase-like protein 24|UPF0624 protein C6orf186', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=110243940, end_position_on_the_genomic_accession=110358349, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    728489 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728489, CurrentID=0, Status='live', Symbol='DNLZ', Aliases=['C9orf151', 'HEP', 'HEP1', 'TIMM15', 'ZIM17', 'bA413M3.2'], description='DNL-type zinc finger', other_designations='DNL-type zinc finger protein|HSP70 escort protein|RP11-413M3.2|hsp70-escort protein 1|mtHsp70-escort protein|translocase of inner mitochondrial membrane 15 homolog', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=136359483, end_position_on_the_genomic_accession=136363744, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    728492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728492, CurrentID=0, Status='live', Symbol='SERF1B', Aliases=['FAM2B', 'H4F5C', 'h4F5'], description='small EDRK-rich factor 1B', other_designations='small EDRK-rich factor 1|SMA modifier 1|protein 4F5|small EDRK-rich factor 1B (centromeric)', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=70025251, end_position_on_the_genomic_accession=70043113, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    728498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728498, CurrentID=0, Status='live', Symbol='GOLGA8H', Aliases=['GOLGA6L11'], description='golgin A8 family member H', other_designations='golgin subfamily A member 8H|Golgin subfamily A member 8-like protein 1|golgi autoantigen, golgin subfamily a, 6-like 11', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30604028, end_position_on_the_genomic_accession=30617752, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    728524 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728524, CurrentID=0, Status='live', Symbol='SPDYE8', Aliases=['SPDYE8P', 'SPDYE9'], description='speedy/RINGO cell cycle regulator family member E8', other_designations='speedy/RINGO cell cycle regulator family member E8|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E pseudogene|speedy homolog E8, pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene|speedy/RINGO cell cycle regulator family member E8, pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73019719, end_position_on_the_genomic_accession=73029766, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    728537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728537, CurrentID=0, Status='live', Symbol='C2orf92', Aliases=['LINC01125'], description='chromosome 2 open reading frame 92', other_designations='uncharacterized protein C2orf92|long intergenic non-protein coding RNA 1125', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=97663922, end_position_on_the_genomic_accession=97703066, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    728568 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728568, CurrentID=0, Status='live', Symbol='C12orf73', Aliases=['BR', 'BRAWNIN'], description='chromosome 12 open reading frame 73', other_designations='protein BRAWNIN|uncharacterized protein C12orf73', map_location='12q23.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=103950194, end_position_on_the_genomic_accession=103965755, orientation='minus', exon_count=7, OMIM=[618812], no_hdr0=''),
    728577 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728577, CurrentID=0, Status='live', Symbol='CNTNAP3B', Aliases=[], description='contactin associated protein family member 3B', other_designations='contactin-associated protein-like 3B|cell recognition molecule Caspr3b|contactin associated protein like 3B', map_location='9p11.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=41890536, end_position_on_the_genomic_accession=42129426, orientation='minus', exon_count=24, OMIM=[], no_hdr0=''),
    728586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728586, CurrentID=0, Status='live', Symbol='CCDC192', Aliases=['LINC01183'], description='coiled-coil domain containing 192', other_designations='coiled-coil domain-containing protein 192|long intergenic non-protein coding RNA 1183', map_location='5q23.2-q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127702200, end_position_on_the_genomic_accession=127941517, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    728588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728588, CurrentID=0, Status='live', Symbol='MS4A18', Aliases=[], description='membrane spanning 4-domains A18', other_designations='membrane-spanning 4-domains subfamily A member 18', map_location='11q12.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60722909, end_position_on_the_genomic_accession=60745028, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    728591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728591, CurrentID=0, Status='live', Symbol='CCDC169', Aliases=['C13orf38'], description='coiled-coil domain containing 169', other_designations='coiled-coil domain-containing protein 169|RP11-251J8.1', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36222004, end_position_on_the_genomic_accession=36297814, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    728597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728597, CurrentID=0, Status='live', Symbol='DCDC2C', Aliases=[], description='doublecortin domain containing 2C', other_designations='doublecortin domain-containing protein 2C|doublecortin domain containing 2C pseudogene', map_location='2p25.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=3703575, end_position_on_the_genomic_accession=3848008, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    728621 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728621, CurrentID=0, Status='live', Symbol='CCDC30', Aliases=['PFD6L', 'PFDN6L'], description='coiled-coil domain containing 30', other_designations='coiled-coil domain-containing protein 30|prefoldin subunit 6-like protein', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42456107, end_position_on_the_genomic_accession=42657190, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    728637 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728637, CurrentID=0, Status='live', Symbol='MEIKIN', Aliases=[], description='meiotic kinetochore factor', other_designations='meiosis-specific kinetochore protein', map_location='5q31.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=131806990, end_position_on_the_genomic_accession=131945663, orientation='minus', exon_count=13, OMIM=[616232], no_hdr0=''),
    728642 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728642, CurrentID=0, Status='live', Symbol='CDK11A', Aliases=['CDC2L2', 'CDC2L3', 'CDK11-p110', 'CDK11-p46', 'CDK11-p58', 'PITSLRE', 'p58GTA'], description='cyclin dependent kinase 11A', other_designations='cyclin-dependent kinase 11A|PITSLRE B|PITSLRE serine/threonine-protein kinase CDC2L2|cell division cycle 2-like 2 (PITSLRE proteins)|cell division cycle 2-like protein kinase 2|cell division protein kinase 11A|galactosyltransferase-associated protein kinase p58/GTA', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1702379, end_position_on_the_genomic_accession=1724357, orientation='minus', exon_count=20, OMIM=[116951], no_hdr0=''),
    728656 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728656, CurrentID=0, Status='live', Symbol='DMRTC1B', Aliases=[], description='DMRT like family C1B', other_designations='doublesex- and mab-3-related transcription factor C1|DMRT-like family C1', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72776890, end_position_on_the_genomic_accession=72848803, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    728661 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728661, CurrentID=0, Status='live', Symbol='SLC35E2B', Aliases=['SLC35E2'], description='solute carrier family 35 member E2B', other_designations='solute carrier family 35 member E2B', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1659798, end_position_on_the_genomic_accession=1692795, orientation='minus', exon_count=12, OMIM=[619315], no_hdr0=''),
    728689 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728689, CurrentID=0, Status='live', Symbol='EIF3CL', Aliases=[], description='eukaryotic translation initiation factor 3 subunit C like', other_designations='eukaryotic translation initiation factor 3 subunit C-like protein|eIF3 p110|eukaryotic translation initiation factor 3 subunit 8|eukaryotic translation initiation factor 3, subunit 8, 110kDa-like', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28379581, end_position_on_the_genomic_accession=28403885, orientation='minus', exon_count=23, OMIM=[], no_hdr0=''),
    728695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728695, CurrentID=0, Status='live', Symbol='SPANXB1', Aliases=['B1', 'CT11.2', 'SPANX-B', 'SPANXB', 'SPANXB2', 'SPANXF1', 'SPANXF2'], description='SPANX family member B1', other_designations='sperm protein associated with the nucleus on the X chromosome B1|SPANX family member B/F|SPANX family member F1|SPANX family, member B2|SPANX family, member F2|cancer/testis antigen 11.2|cancer/testis antigen family 11, member 2|nuclear-associated protein SPAN-Xb|nuclear-associated protein SPAN-Xf|sperm protein associated with the nucleus on the X chromosome B/F|sperm protein associated with the nucleus, X chromosome, family member B1', map_location='Xq27.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141002594, end_position_on_the_genomic_accession=141003706, orientation='plus', exon_count=2, OMIM=[300669], no_hdr0=''),
    728712 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728712, CurrentID=0, Status='live', Symbol='SPANXA2', Aliases=['CT11.1', 'CT11.3', 'SPANX', 'SPANX-A', 'SPANX-C', 'SPANXA', 'SPANXC'], description='SPANX family member A2', other_designations='sperm protein associated with the nucleus on the X chromosome A|Cancer/testis antigen 11.3|Cancer/testis-associated protein CTp11|Nuclear-associated protein SPAN-Xc|SPANX family member A|Sperm protein associated with the nucleus on the X chromosome C|cancer/testis antigen 11.1|nuclear-associated protein SPAN-Xa|sperm protein associated with the nucleus, X chromosome, family member A2', map_location='Xq27.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=141589708, end_position_on_the_genomic_accession=141590762, orientation='plus', exon_count=2, OMIM=[300493], no_hdr0=''),
    728734 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728734, CurrentID=0, Status='live', Symbol='NPIPB8', Aliases=[], description='nuclear pore complex interacting protein family member B8', other_designations='nuclear pore complex-interacting protein family member B8|Nuclear pore complex-interacting protein family member B8', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28637891, end_position_on_the_genomic_accession=28658744, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    728741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728741, CurrentID=0, Status='live', Symbol='NPIPB6', Aliases=['NPIPB'], description='nuclear pore complex interacting protein family member B6', other_designations='nuclear pore complex-interacting protein family member B6|nuclear pore complex-interacting protein B type', map_location='16p12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28342517, end_position_on_the_genomic_accession=28364780, orientation='minus', exon_count=14, OMIM=[], no_hdr0=''),
    728763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728763, CurrentID=0, Status='live', Symbol='CROCC2', Aliases=[], description='ciliary rootlet coiled-coil, rootletin family member 2', other_designations='ciliary rootlet coiled-coil protein 2|putative ciliary rootlet coiled-coil protein 2|putative ciliary rootlet coiled-coil protein-like 3 protein|rootletin-like', map_location='2q37.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=240906160, end_position_on_the_genomic_accession=240993311, orientation='plus', exon_count=32, OMIM=[], no_hdr0=''),
    728780 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728780, CurrentID=0, Status='live', Symbol='ANKDD1B', Aliases=[], description='ankyrin repeat and death domain containing 1B', other_designations='ankyrin repeat and death domain-containing protein 1B|ankyrin repeat and death domain-containing protein ENSP00000345065', map_location='5q13.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=75611289, end_position_on_the_genomic_accession=75671846, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    728819 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728819, CurrentID=0, Status='live', Symbol='C1GALT1C1L', Aliases=[], description='C1GALT1 specific chaperone 1 like', other_designations='C1GALT1-specific chaperone 1-like protein', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43675151, end_position_on_the_genomic_accession=43676429, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    728833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728833, CurrentID=0, Status='live', Symbol='FAM72D', Aliases=['GCUD2'], description='family with sequence similarity 72 member D', other_designations='protein FAM72D|gastric cancer up-regulated protein 2|gastric cancer up-regulated-2', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145093805, end_position_on_the_genomic_accession=145112696, orientation='plus', exon_count=7, OMIM=[614712], no_hdr0=''),
    728841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728841, CurrentID=0, Status='live', Symbol='NBPF8', Aliases=['NBPF8P'], description='NBPF member 8', other_designations='putative neuroblastoma breakpoint family member 8|neuroblastoma breakpoint family member 8|neuroblastoma breakpoint family, member 8, pseudogene', map_location='1p11.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=120415027, end_position_on_the_genomic_accession=120469676, orientation='plus', exon_count=27, OMIM=[613998], no_hdr0=''),
    728858 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728858, CurrentID=0, Status='live', Symbol='C12orf71', Aliases=[], description='chromosome 12 open reading frame 71', other_designations='uncharacterized protein C12orf71', map_location='12p11.23', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27081057, end_position_on_the_genomic_accession=27084127, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    728888 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728888, CurrentID=0, Status='live', Symbol='NPIPB11', Aliases=['NPIP'], description='nuclear pore complex interacting protein family member B11', other_designations='nuclear pore complex-interacting protein family member B11|NPIP-like locus|hepatitis B virus pre-pre-S promoter DNA-binding protein|pps22-1 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29381318, end_position_on_the_genomic_accession=29404545, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    728911 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728911, CurrentID=0, Status='live', Symbol='CT45A2', Aliases=['CT45-2', 'CT45.2', 'CT45A8', 'CT45A9'], description='cancer/testis antigen family 45 member A2', other_designations='cancer/testis antigen family 45 member A2|Cancer/testis antigen 45A8|Cancer/testis antigen 45A9|Cancer/testis antigen family 45 member A8|Cancer/testis antigen family 45 member A9|cancer/testis antigen 45-2|cancer/testis antigen 45A2|cancer/testis antigen CT45', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135811668, end_position_on_the_genomic_accession=135820062, orientation='minus', exon_count=5, OMIM=[300793], no_hdr0=''),
    728927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728927, CurrentID=0, Status='live', Symbol='ZNF736', Aliases=[], description='zinc finger protein 736', other_designations='zinc finger protein 736|KRAB-containing zinc-finger repressor protein', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64313961, end_position_on_the_genomic_accession=64356634, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    728945 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728945, CurrentID=0, Status='live', Symbol='PPIAL4F', Aliases=[], description='peptidylprolyl isomerase A like 4F', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4F|PPIase A-like 4F|cyclophilin-LC (COAS2) pseudogene|peptidylprolyl isomerase A (cyclophilin A)-like 4F', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=144592893, end_position_on_the_genomic_accession=144593652, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    728957 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=728957, CurrentID=0, Status='live', Symbol='ZNF705D', Aliases=['ZNF705C'], description='zinc finger protein 705D', other_designations='zinc finger protein 705D|putative zinc finger protein 705C|zinc finger protein 705C', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12089338, end_position_on_the_genomic_accession=12115516, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    729020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729020, CurrentID=0, Status='live', Symbol='RPEL1', Aliases=[], description='ribulose-5-phosphate-3-epimerase like 1', other_designations='ribulose-phosphate 3-epimerase-like protein 1|hCG2024410|rcRPE protein|ribulose-5-phosphate-3-epimerase-like protein 1', map_location='10q24.33', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=103245887, end_position_on_the_genomic_accession=103248016, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    729025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729025, CurrentID=0, Status='live', Symbol='SLC15A5', Aliases=[], description='solute carrier family 15 member 5', other_designations='solute carrier family 15 member 5|Peptide/histidine transporter ENSP00000340402', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=16188485, end_position_on_the_genomic_accession=16277685, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    729059 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729059, CurrentID=0, Status='live', Symbol='TEX46', Aliases=['C1orf234', 'TEX#'], description='testis expressed 46', other_designations='testis-expressed protein 46|uncharacterized protein C1orf234', map_location='1p36.12', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=23010834, end_position_on_the_genomic_accession=23015852, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    729085 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729085, CurrentID=0, Status='live', Symbol='GASK1A', Aliases=['C3orf41', 'FAM198A'], description='golgi associated kinase 1A', other_designations='Golgi-associated kinase 1A|family with sequence similarity 198 member A|protein FAM198A', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42979311, end_position_on_the_genomic_accession=43057715, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    729092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729092, CurrentID=0, Status='live', Symbol='AGAP5', Aliases=['CTGLF2'], description='ArfGAP with GTPase domain, ankyrin repeat and PH domain 5', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 5|AGAP-5|centaurin, gamma-like family, member 2', map_location='10q22.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=73674295, end_position_on_the_genomic_accession=73698109, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    729201 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729201, CurrentID=0, Status='live', Symbol='SPACA5B', Aliases=['LYZL5B'], description='sperm acrosome associated 5B', other_designations='sperm acrosome-associated protein 5|SLLP-X|lysozyme-like protein 5|sperm-specific lysozyme-like protein X', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=48130626, end_position_on_the_genomic_accession=48132620, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    729230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729230, CurrentID=0, Status='live', Symbol='CCR2', Aliases=['CC-CKR-2', 'CCR-2A', 'CCR2B', 'CD192', 'CKR2', 'CKR2A', 'CKR2B', 'CMKBR2', 'MCP-1-R', 'CCR2'], description='C-C motif chemokine receptor 2', other_designations='C-C chemokine receptor type 2|MCP-1 receptor|chemokine (C-C motif) receptor 2|monocyte chemoattractant protein 1 receptor|monocyte chemotactic protein 1 receptor', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46354111, end_position_on_the_genomic_accession=46360940, orientation='plus', exon_count=3, OMIM=[601267], no_hdr0=''),
    729233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729233, CurrentID=0, Status='live', Symbol='PRR20B', Aliases=['PRR20', 'PRR20A', 'PRR20C', 'PRR20D', 'PRR20E'], description='proline rich 20B', other_designations='proline-rich protein 20B|FLJ40296 protein family member|Proline-rich protein 20A|Proline-rich protein 20C|Proline-rich protein 20D|Proline-rich protein 20E', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57147488, end_position_on_the_genomic_accession=57150509, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    729238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729238, CurrentID=0, Status='live', Symbol='SFTPA2', Aliases=['COLEC5', 'PSAP', 'PSP-A', 'PSPA', 'SFTP1B', 'SP-2A', 'SP-A', 'SPA2', 'SPAII', 'SFTPA2'], description='surfactant protein A2', other_designations='pulmonary surfactant-associated protein A2|35 kDa pulmonary surfactant-associated protein|alveolar proteinosis protein|collectin 5|surfactant, pulmonary-associated protein A2A', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79555852, end_position_on_the_genomic_accession=79560459, orientation='minus', exon_count=8, OMIM=[178642], no_hdr0=''),
    729240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729240, CurrentID=0, Status='live', Symbol='PRR20C', Aliases=['PRR20', 'PRR20A', 'PRR20B', 'PRR20D', 'PRR20E'], description='proline rich 20C', other_designations='proline-rich protein 20C|FLJ40296 protein family member|Proline-rich protein 20A|Proline-rich protein 20B|Proline-rich protein 20D|Proline-rich protein 20E', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57154061, end_position_on_the_genomic_accession=57157082, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    729246 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729246, CurrentID=0, Status='live', Symbol='PRR20D', Aliases=['PRR20', 'PRR20A', 'PRR20B', 'PRR20C', 'PRR20E'], description='proline rich 20D', other_designations='proline-rich protein 20D|FLJ40296 protein family member|Proline-rich protein 20A|Proline-rich protein 20B|Proline-rich protein 20C|Proline-rich protein 20E', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57160632, end_position_on_the_genomic_accession=57163653, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    729250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729250, CurrentID=0, Status='live', Symbol='PRR20E', Aliases=['PRR20', 'PRR20A', 'PRR20B', 'PRR20C', 'PRR20D'], description='proline rich 20E', other_designations='proline-rich protein 20E|FLJ40296 protein family member|Proline-rich protein 20A|Proline-rich protein 20B|Proline-rich protein 20C|Proline-rich protein 20D', map_location='13q21.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=57167197, end_position_on_the_genomic_accession=57170218, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    729262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729262, CurrentID=0, Status='live', Symbol='NUTM2B', Aliases=['FAM22B', 'bA119F19.1'], description='NUT family member 2B', other_designations='NUT family member 2B|family with sequence similarity 22, member B|protein FAM22B', map_location='10q22.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=79703227, end_position_on_the_genomic_accession=79712758, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    729264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729264, CurrentID=0, Status='live', Symbol='TP53TG3D', Aliases=['TP53TG3', 'TP53TG3B', 'TP53TG3C', 'TP53TG3E', 'TP53TG3F'], description='TP53 target 3D', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=32251603, end_position_on_the_genomic_accession=32255928, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    729330 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729330, CurrentID=0, Status='live', Symbol='OC90', Aliases=['PLA2L'], description='otoconin 90', other_designations='otoconin-90|phospholipase A2 homolog', map_location='8q24.22', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=132024216, end_position_on_the_genomic_accession=132059382, orientation='minus', exon_count=14, OMIM=[601658], no_hdr0=''),
    729355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729355, CurrentID=0, Status='live', Symbol='TP53TG3B', Aliases=['TP53TG3E', 'TP53TG3F'], description='TP53 target 3B', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=33360877, end_position_on_the_genomic_accession=33363487, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    729359 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729359, CurrentID=0, Status='live', Symbol='PLIN4', Aliases=['KIAA1881', 'S3-12'], description='perilipin 4', other_designations='perilipin-4|adipocyte protein S3-12', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=4502192, end_position_on_the_genomic_accession=4520285, orientation='minus', exon_count=9, OMIM=[613247], no_hdr0=''),
    729384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729384, CurrentID=0, Status='live', Symbol='TRIM49D2', Aliases=['TRIM48L1', 'TRIM49D1P', 'TRIM49L', 'TRIM49L1', 'TRIM49D2'], description='tripartite motif containing 49D2', other_designations='tripartite motif-containing protein 49D|tripartite motif containing 49D2, pseudogene|tripartite motif-containing protein 49-like protein 1|tripartite motif-containing protein 49D1', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=89924064, end_position_on_the_genomic_accession=89933063, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    729396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729396, CurrentID=0, Status='live', Symbol='GAGE12J', Aliases=['GAGE11'], description='G antigen 12J', other_designations='G antigen 12J|G antigen 11', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49322037, end_position_on_the_genomic_accession=49329384, orientation='plus', exon_count=5, OMIM=[300733], no_hdr0=''),
    729408 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729408, CurrentID=0, Status='live', Symbol='GAGE2D', Aliases=['CT4.8', 'GAGE-2D', 'GAGE-8', 'GAGE8'], description='G antigen 2D', other_designations='G antigen 2D|cancer/testis antigen 4.8', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300735], no_hdr0=''),
    729422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729422, CurrentID=0, Status='live', Symbol='GAGE12C', Aliases=['GAGE-12B'], description='G antigen 12C', other_designations='G antigen 12B/C/D/E|GAGE-12C|g antigen 12C/D/E', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49532177, end_position_on_the_genomic_accession=49539538, orientation='plus', exon_count=5, OMIM=[300727], no_hdr0=''),
    729428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729428, CurrentID=0, Status='live', Symbol='GAGE12B', Aliases=['GAGE-12B'], description='G antigen 12B', other_designations='G antigen 12B/C/D/E', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49341164, end_position_on_the_genomic_accession=49529982, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    729431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729431, CurrentID=0, Status='live', Symbol='GAGE12E', Aliases=['GAGE-12B'], description='G antigen 12E', other_designations='G antigen 12B/C/D/E', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49551289, end_position_on_the_genomic_accession=49558645, orientation='plus', exon_count=5, OMIM=[300729], no_hdr0=''),
    729438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729438, CurrentID=0, Status='live', Symbol='CASTOR2', Aliases=['GATSL1', 'GATSL2'], description='cytosolic arginine sensor for mTORC1 subunit 2', other_designations='cytosolic arginine sensor for mTORC1 subunit 2|GATS protein like 2|GATS protein-like 1|GATS-like protein 1|GATS-like protein 2|cellular arginine sensor for mTORC1 protein 2|cytosolic arginine sensor for mTORC1 subunit 1', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74964693, end_position_on_the_genomic_accession=75031531, orientation='plus', exon_count=9, OMIM=[617033], no_hdr0=''),
    729440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729440, CurrentID=0, Status='live', Symbol='CCDC61', Aliases=['VFL3'], description='coiled-coil domain containing 61', other_designations='centrosomal protein CCDC61|VFL3 homolog|coiled-coil domain-containing protein 61|variable flagellar number 3 homolog (C. reinhardtii)', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=45995457, end_position_on_the_genomic_accession=46018616, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    729442 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729442, CurrentID=0, Status='live', Symbol='GAGE12H', Aliases=[], description='G antigen 12H', other_designations='G antigen 12H|GAGE-12H', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49579949, end_position_on_the_genomic_accession=49587301, orientation='plus', exon_count=5, OMIM=[300732], no_hdr0=''),
    729447 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729447, CurrentID=0, Status='live', Symbol='GAGE2A', Aliases=['CT4.2', 'GAGE-2', 'GAGE-2A', 'GAGE2'], description='G antigen 2A', other_designations='G antigen 2A/2B|G antigen 2|cancer/testis antigen 4.2|cancer/testis antigen family 4, member 2', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49589496, end_position_on_the_genomic_accession=49596824, orientation='plus', exon_count=5, OMIM=[300720], no_hdr0=''),
    729458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729458, CurrentID=0, Status='live', Symbol='MBD3L2B', Aliases=[], description='methyl-CpG binding domain protein 3 like 2B', other_designations='methyl-CpG-binding domain protein 3-like 2B', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7018969, end_position_on_the_genomic_accession=7021431, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    729475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729475, CurrentID=0, Status='live', Symbol='RAD51AP2', Aliases=[], description='RAD51 associated protein 2', other_designations='RAD51-associated protein 2', map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=17510579, end_position_on_the_genomic_accession=17538329, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    729515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729515, CurrentID=0, Status='live', Symbol='TMEM242', Aliases=['BM033', 'C6orf35'], description='transmembrane protein 242', other_designations='transmembrane protein 242|UPF0463 transmembrane protein C6orf35', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=157289025, end_position_on_the_genomic_accession=157323519, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    729528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729528, CurrentID=0, Status='live', Symbol='PRAMEF14', Aliases=[], description='PRAME family member 14', other_designations='PRAME family member 14', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13341892, end_position_on_the_genomic_accession=13347134, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    729533 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729533, CurrentID=0, Status='live', Symbol='FAM72A', Aliases=['LMPIP', 'Ugene', 'p17'], description='family with sequence similarity 72 member A', other_designations='protein FAM72A|LMP1-induced protein|latent membrane protein 1-induced protein', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=206186179, end_position_on_the_genomic_accession=206205773, orientation='minus', exon_count=8, OMIM=[614710], no_hdr0=''),
    729540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729540, CurrentID=0, Status='live', Symbol='RGPD6', Aliases=['RGP6', 'RGPD7', 'RanBP2L1', 'RanBP2L2'], description='RANBP2 like and GRIP domain containing 6', other_designations='RANBP2-like and GRIP domain-containing protein 5/6|RANBP2-like and GRIP domain-containing protein 7|ran-binding protein 2-like 1/2|ranBP2-like 1/2', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110513802, end_position_on_the_genomic_accession=110611056, orientation='minus', exon_count=30, OMIM=[612709], no_hdr0=''),
    729597 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729597, CurrentID=0, Status='live', Symbol='SPDYE6', Aliases=[], description='speedy/RINGO cell cycle regulator family member E6', other_designations='speedy protein E6|Putative speedy protein E6|speedy homolog E6', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102345746, end_position_on_the_genomic_accession=102356444, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    729627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729627, CurrentID=0, Status='live', Symbol='PRR23A', Aliases=[], description='proline rich 23A', other_designations='proline-rich protein 23A|UPF0572 protein ENSP00000372650|proline-rich protein 23C', map_location='3q23', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=139003962, end_position_on_the_genomic_accession=139006268, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    729665 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729665, CurrentID=0, Status='live', Symbol='CCDC175', Aliases=['C14orf38', 'c14_5395'], description='coiled-coil domain containing 175', other_designations='coiled-coil domain-containing protein 175', map_location='14q23.1', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=59505067, end_position_on_the_genomic_accession=59577276, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    729747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729747, CurrentID=0, Status='live', Symbol='ZNF878', Aliases=[], description='zinc finger protein 878', other_designations='zinc finger protein 878', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12043647, end_position_on_the_genomic_accession=12052961, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    729759 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729759, CurrentID=0, Status='live', Symbol='OR4F29', Aliases=['OR7-21'], description='olfactory receptor family 4 subfamily F member 29', other_designations='olfactory receptor 4F3/4F16/4F29|olfactory receptor OR1-1|olfactory receptor OR7-21|seven transmembrane helix receptor', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=450740, end_position_on_the_genomic_accession=451678, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    729767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729767, CurrentID=0, Status='live', Symbol='CEACAM18', Aliases=[], description='CEA cell adhesion molecule 18', other_designations='carcinoembryonic antigen-related cell adhesion molecule 18|carcinoembryonic antigen related cell adhesion molecule 18', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51478543, end_position_on_the_genomic_accession=51491261, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    729830 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729830, CurrentID=0, Status='live', Symbol='FHIP1A', Aliases=['FAM160A1', 'FHIP-L'], description='FHF complex subunit HOOK interacting protein 1A', other_designations='FHF complex subunit HOOK interacting protein 1A|protein FAM160A1|FTS and Hook-interacting protein like|family with sequence similarity 160 member A1', map_location='4q31.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=151409143, end_position_on_the_genomic_accession=151670503, orientation='plus', exon_count=18, OMIM=[], no_hdr0=''),
    729852 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729852, CurrentID=0, Status='live', Symbol='UMAD1', Aliases=['RPA3-AS1', 'RPA3OS'], description='UBAP1-MVB12-associated (UMA) domain containing 1', other_designations='UBAP1-MVB12-associated (UMA)-domain containing protein 1|RPA3 antisense RNA 1|RPA3 opposite strand', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=7640752, end_position_on_the_genomic_accession=7879223, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    729857 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729857, CurrentID=0, Status='live', Symbol='RGPD2', Aliases=['NUP358', 'RANBP2L2', 'RGP2'], description='RANBP2 like and GRIP domain containing 2', other_designations='RANBP2-like and GRIP domain-containing protein 2|Ran binding protein 2-like 2|nucleoporin|ran-binding protein 2-like 2|ranBP2-like 2', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=87755960, end_position_on_the_genomic_accession=87992819, orientation='minus', exon_count=32, OMIM=[612705], no_hdr0=''),
    729873 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729873, CurrentID=0, Status='live', Symbol='TBC1D3', Aliases=['PRC17A', 'TBC1D3C', 'TBC1D3D', 'TBC1D3F', 'TBC1D3L', 'TBC1D3'], description='TBC1 domain family member 3', other_designations='TBC1 domain family member 3|Rab GTPase-activating protein PRC17|TBC1 domain family member 3C|TBC1 domain family member 3L|TBC1 domain family, member 3F|prostate cancer gene 17 protein|protein TRE17-alpha', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38181659, end_position_on_the_genomic_accession=38192555, orientation='minus', exon_count=14, OMIM=[607741], no_hdr0=''),
    729877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729877, CurrentID=0, Status='live', Symbol='TBC1D3H', Aliases=[], description='TBC1 domain family member 3H', other_designations='TBC1 domain family member 3H|TBC1 domain family member 3-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36377531, end_position_on_the_genomic_accession=36388452, orientation='minus', exon_count=14, OMIM=[610811], no_hdr0=''),
    729920 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729920, CurrentID=0, Status='live', Symbol='CRPPA', Aliases=['ISPD', 'LGMDR20', 'MDDGA7', 'MDDGC7', 'Nip', 'hISPD'], description='CDP-L-ribitol pyrophosphorylase A', other_designations='D-ribitol-5-phosphate cytidylyltransferase|2-C-methyl-D-erythritol 4-phosphate cytidylyltransferase-like protein|4-diphosphocytidyl-2C-methyl-D-erythritol synthase homolog|isoprenoid synthase domain containing|notch1-induced protein|testicular tissue protein Li 97', map_location='7p21.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16087525, end_position_on_the_genomic_accession=16421538, orientation='minus', exon_count=10, OMIM=[614631], no_hdr0=''),
    729956 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729956, CurrentID=0, Status='live', Symbol='SHISA7', Aliases=['CKAMP59'], description='shisa family member 7', other_designations='protein shisa-7|GABA(A) receptor auxiliary subunit Shisa7|UPF0626 protein A|cystine-knot AMPAR modulating protein of 59 kDa|shisa homolog 7', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55428740, end_position_on_the_genomic_accession=55443300, orientation='minus', exon_count=4, OMIM=[617328], no_hdr0=''),
    729967 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729967, CurrentID=0, Status='live', Symbol='MORN2', Aliases=['BLOCK27', 'MOPT'], description='MORN repeat containing 2', other_designations='MORN repeat-containing protein 2|MORN motif protein in testis|protein containing single MORN motif in testis', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38875976, end_position_on_the_genomic_accession=38882709, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    729974 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729974, CurrentID=0, Status='live', Symbol='RFPL4AL1', Aliases=['RNF210B'], description='ret finger protein like 4A like 1', other_designations='ret finger protein-like 4A-like protein 1', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55769118, end_position_on_the_genomic_accession=55773420, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    729978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729978, CurrentID=0, Status='live', Symbol='NPIPB2', Aliases=[], description='nuclear pore complex interacting protein family member B2', other_designations='putative nuclear pore complex-interacting protein family member B2|putative NPIP-like protein LOC729978', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=11927263, end_position_on_the_genomic_accession=11976650, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    729991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729991, CurrentID=0, Status='live', Symbol='BORCS8', Aliases=['MEF2BNB'], description='BLOC-1 related complex subunit 8', other_designations='BLOC-1-related complex subunit 8|MEF2B neighbor gene protein|protein MEF2BNB', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19176906, end_position_on_the_genomic_accession=19192152, orientation='minus', exon_count=6, OMIM=[616601], no_hdr0=''),
    729993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=729993, CurrentID=0, Status='live', Symbol='SHISA9', Aliases=['CKAMP44'], description='shisa family member 9', other_designations='protein shisa-9|cystine-knot AMPAR modulating protein|shisa homolog 9', map_location='16p13.12', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=12901598, end_position_on_the_genomic_accession=13563427, orientation='plus', exon_count=9, OMIM=[613346], no_hdr0=''),
    730005 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730005, CurrentID=0, Status='live', Symbol='SEC14L6', Aliases=[], description='SEC14 like lipid binding 6', other_designations='putative SEC14-like protein 6|SEC14-like 6', map_location='22q12.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=30522797, end_position_on_the_genomic_accession=30546741, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    730051 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730051, CurrentID=0, Status='live', Symbol='ZNF814', Aliases=[], description='zinc finger protein 814', other_designations='zinc finger protein 814', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57869381, end_position_on_the_genomic_accession=57889037, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    730087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730087, CurrentID=0, Status='live', Symbol='ZNF726', Aliases=['ZNF92P3'], description='zinc finger protein 726', other_designations='zinc finger protein 726|zinc finger protein 92 pseudogene 3', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23914886, end_position_on_the_genomic_accession=23944714, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    730094 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730094, CurrentID=0, Status='live', Symbol='MOSMO', Aliases=['ATTHOG', 'BC030336', 'C16orf52'], description='modulator of smoothened', other_designations='modulator of smoothened protein|Attenuator of Hedgehog|uncharacterized protein C16orf52', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22008111, end_position_on_the_genomic_accession=22084654, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    730098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730098, CurrentID=0, Status='live', Symbol='LOC730098', Aliases=[], description='uncharacterized LOC730098', other_designations='uncharacterized protein LOC730098', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34664163, end_position_on_the_genomic_accession=34666636, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    730112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730112, CurrentID=0, Status='live', Symbol='FAM166B', Aliases=[], description='family with sequence similarity 166 member B', other_designations='protein FAM166B', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=35561830, end_position_on_the_genomic_accession=35563878, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    730130 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730130, CurrentID=0, Status='live', Symbol='TMEM229A', Aliases=[], description='transmembrane protein 229A', other_designations='transmembrane protein 229A', map_location='7q31.32', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=124030921, end_position_on_the_genomic_accession=124033067, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    730159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730159, CurrentID=0, Status='live', Symbol='TEX50', Aliases=[], description='testis expressed 50', other_designations='testis-expressed protein 50', map_location='1q25.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=173603003, end_position_on_the_genomic_accession=173637130, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    730249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730249, CurrentID=0, Status='live', Symbol='ACOD1', Aliases=['CAD', 'IRG1'], description='aconitate decarboxylase 1', other_designations='cis-aconitate decarboxylase|cis-aconitic acid decarboxylase|immune-responsive gene 1 protein homolog|immunoresponsive 1 homolog', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=76948511, end_position_on_the_genomic_accession=76958638, orientation='plus', exon_count=5, OMIM=[615275], no_hdr0=''),
    730262 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730262, CurrentID=0, Status='live', Symbol='PPIAL4E', Aliases=['COAS2', 'PPIAL4F'], description='peptidylprolyl isomerase A like 4E', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4E|PPIase A-like 4E|PPIase A-like 4F|Peptidyl-prolyl cis-trans isomerase A-like 4F|peptidylprolyl isomerase A (cyclophilin A)-like 4E', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=144372875, end_position_on_the_genomic_accession=144373634, orientation='minus', exon_count=1, OMIM=[608608], no_hdr0=''),
    730291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730291, CurrentID=0, Status='live', Symbol='ZNF735', Aliases=['ZNF735P'], description='zinc finger protein 735', other_designations='putative zinc finger protein 735|zinc finger protein 735 pseudogene', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64207203, end_position_on_the_genomic_accession=64220290, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    730394 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730394, CurrentID=0, Status='live', Symbol='GTF2H2C_2', Aliases=['GTF2H2D'], description='GTF2H2 family member C, copy 2', other_designations='general transcription factor IIH subunit 2-like protein|general transcription factor IIH polypeptide 2-like protein|general transcription factor IIH, polypeptide 2D', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    730755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=730755, CurrentID=0, Status='live', Symbol='KRTAP2-3', Aliases=['KAP2.3', 'KAP2.4', 'KRTAP2-4', 'KRTAP2.3', 'KRTAP2.4'], description='keratin associated protein 2-3', other_designations='keratin-associated protein 2-3|Keratin-associated protein 2-4|Keratin-associated protein 2.4|high sulfur keratin-associated protein 2.4|keratin-associated protein 2.3', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41059240, end_position_on_the_genomic_accession=41060114, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    731220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=731220, CurrentID=0, Status='live', Symbol='RFX8', Aliases=[], description='regulatory factor X8', other_designations='DNA-binding protein RFX8|RFX family member 8, lacking RFX DNA binding domain|regulatory factor X, 8', map_location='2q11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=101397344, end_position_on_the_genomic_accession=101475179, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    751071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=751071, CurrentID=0, Status='live', Symbol='CSKMT', Aliases=['CS-KMT', 'METTL12', 'U99HG'], description='citrate synthase lysine methyltransferase', other_designations='citrate synthase-lysine N-methyltransferase CSKMT, mitochondrial|methyltransferase like 12|methyltransferase-like protein 12, mitochondrial', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62665253, end_position_on_the_genomic_accession=62668108, orientation='plus', exon_count=2, OMIM=[617897], no_hdr0=''),
    752014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=752014, CurrentID=0, Status='live', Symbol='CEMP1', Aliases=['CP-23', 'CP23'], description='cementum protein 1', other_designations='cementoblastoma-derived protein 1|cementum protein 23', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=2530035, end_position_on_the_genomic_accession=2531408, orientation='minus', exon_count=1, OMIM=[611113], no_hdr0=''),
    767558 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=767558, CurrentID=0, Status='live', Symbol='LUZP6', Aliases=['MPD6', 'MTPNUT'], description='leucine zipper protein 6', other_designations="leucine zipper protein 6|myeloproliferative disease-associated 6 kDa antigen|myeloproliferative disease-associated SEREX antigen|myeloproliferative disease-associated antigen, 6-kD|myotrophin 3'UTR transcript", map_location='7q33', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=135926760, end_position_on_the_genomic_accession=135977359, orientation='minus', exon_count=4, OMIM=[611050], no_hdr0=''),
    768206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=768206, CurrentID=0, Status='live', Symbol='PRCD', Aliases=['RP36'], description='photoreceptor disc component', other_designations='photoreceptor disk component PRCD|progressive rod-cone degeneration protein', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=76527586, end_position_on_the_genomic_accession=76555339, orientation='plus', exon_count=8, OMIM=[610598], no_hdr0=''),
    768211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=768211, CurrentID=0, Status='live', Symbol='RELL1', Aliases=[], description='RELT like 1', other_designations='RELT-like protein 1|receptor expressed in lymphoid tissues like 1|tmp_locus_29', map_location='4p14', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=37590804, end_position_on_the_genomic_accession=37686403, orientation='minus', exon_count=8, OMIM=[611212], no_hdr0=''),
    768239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=768239, CurrentID=0, Status='live', Symbol='PSAPL1', Aliases=[], description='prosaposin like 1', other_designations='proactivator polypeptide-like 1|prosaposin-like protein 1', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=7430285, end_position_on_the_genomic_accession=7434930, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    780776 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=780776, CurrentID=0, Status='live', Symbol='TVP23A', Aliases=['FAM18A', 'YDR084C'], description='trans-golgi network vesicle protein 23 homolog A', other_designations='Golgi apparatus membrane protein TVP23 homolog A|family with sequence similarity 18, member A|protein FAM18A', map_location='16p13.13', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=10758034, end_position_on_the_genomic_accession=10818902, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    790955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=790955, CurrentID=0, Status='live', Symbol='UQCC3', Aliases=['C11orf83', 'CCDS41658.1', 'MC3DN9', 'UNQ655'], description='ubiquinol-cytochrome c reductase complex assembly factor 3', other_designations='ubiquinol-cytochrome-c reductase complex assembly factor 3|UPF0723 protein C11orf83|assembly factor CBP4 homolog', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62671673, end_position_on_the_genomic_accession=62673686, orientation='plus', exon_count=2, OMIM=[616097], no_hdr0=''),
    790969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=790969, CurrentID=0, Status='live', Symbol='ZNF705F', Aliases=[], description='zinc finger protein 705F', other_designations='', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100008586 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100008586, CurrentID=0, Status='live', Symbol='GAGE12F', Aliases=['AL4', 'CT4.7', 'GAGE-7', 'GAGE-7B', 'GAGE-8', 'GAGE7', 'GAGE7B'], description='G antigen 12F', other_designations='G antigen 12F|Cancer/testis antigen 4.7|G antigen 12G|G antigen 12I|G antigen 7|GAGE-12F|g antigen 12F/G/I', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49560842, end_position_on_the_genomic_accession=49568205, orientation='plus', exon_count=5, OMIM=[300730], no_hdr0=''),
    100033411 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100033411, CurrentID=0, Status='live', Symbol='DUXB', Aliases=[], description='double homeobox B', other_designations='double homeobox protein B', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75693893, end_position_on_the_genomic_accession=75701461, orientation='minus', exon_count=5, OMIM=[618698], no_hdr0=''),
    100037417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100037417, CurrentID=0, Status='live', Symbol='DDTL', Aliases=['DDT', 'KB-226F1.2'], description='D-dopachrome tautomerase like', other_designations='D-dopachrome decarboxylase-like protein|D-dopachrome decarboxylase|D-dopachrome tautomerase-like protein|Phenylpyruvate tautomerase II', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23966222, end_position_on_the_genomic_accession=23972556, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    100049579 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100049579, CurrentID=0, Status='live', Symbol='OCTN3', Aliases=[], description='organic cation transporter 3', other_designations='', map_location='5q31', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100049587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100049587, CurrentID=0, Status='live', Symbol='SIGLEC14', Aliases=[], description='sialic acid binding Ig like lectin 14', other_designations='sialic acid-binding Ig-like lectin 14|siglec-14', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=51639478, end_position_on_the_genomic_accession=51646852, orientation='minus', exon_count=8, OMIM=[618132], no_hdr0=''),
    100101267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100101267, CurrentID=0, Status='live', Symbol='POM121C', Aliases=['POM121-2'], description='POM121 transmembrane nucleoporin C', other_designations='nuclear envelope pore membrane protein POM 121C|POM121 membrane glycoprotein C|nuclear pore membrane protein 121-2|pore membrane protein of 121 kDa C', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75416786, end_position_on_the_genomic_accession=75486299, orientation='minus', exon_count=17, OMIM=[615754], no_hdr0=''),
    100101268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100101268, CurrentID=0, Status='live', Symbol='SPDYE12', Aliases=['SPDYE12P'], description='speedy/RINGO cell cycle regulator family member E12', other_designations='speedy/RINGO cell cycle regulator family member E12, pseudogene|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=74904302, end_position_on_the_genomic_accession=74915078, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100101467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100101467, CurrentID=0, Status='live', Symbol='ZSCAN30', Aliases=['ZNF-WYM', 'ZNF397OS', 'ZNF917'], description='zinc finger and SCAN domain containing 30', other_designations='zinc finger and SCAN domain-containing protein 30|ZNF397 opposite strand|zinc finger protein 397 opposite strand|zinc finger protein 397OS', map_location='18q12.2', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=35251059, end_position_on_the_genomic_accession=35290261, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100101629 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100101629, CurrentID=0, Status='live', Symbol='GAGE8', Aliases=['CT4.8', 'GAGE-8'], description='G antigen 8', other_designations='G antigen 2D|cancer/testis antigen 4.8|cancer/testis antigen family 4, member 8', map_location='Xp11', chromosome='X', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[300638], no_hdr0=''),
    100113407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100113407, CurrentID=0, Status='live', Symbol='TMEM170B', Aliases=[], description='transmembrane protein 170B', other_designations='transmembrane protein 170B', map_location='6p24.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=11537749, end_position_on_the_genomic_accession=11583524, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100125288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100125288, CurrentID=0, Status='live', Symbol='ZGLP1', Aliases=['GATAD3', 'GLP-1', 'GLP1'], description='zinc finger GATA like protein 1', other_designations='GATA-type zinc finger protein 1|GATA zinc finger domain containing 3|GATA-like protein 1', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=10304803, end_position_on_the_genomic_accession=10309557, orientation='minus', exon_count=4, OMIM=[611639], no_hdr0=''),
    100126572 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100126572, CurrentID=0, Status='live', Symbol='GJE1', Aliases=['CX23'], description='gap junction protein epsilon 1', other_designations='putative gap junction epsilon-1 protein|connexin-23|gap junction protein, epsilon 1, 23kDa', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=142133159, end_position_on_the_genomic_accession=142134922, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100127206 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100127206, CurrentID=0, Status='live', Symbol='MINAR2', Aliases=['KIAA1024L'], description='membrane integral NOTCH2 associated receptor 2', other_designations='major intrinsically disordered NOTCH2-binding receptor 1-like|KIAA1024 like|UPF0258 protein KIAA1024-like|major intrinsically disordered Notch2-binding receptor 1-like', map_location='5q23.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=129748094, end_position_on_the_genomic_accession=129766732, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100127983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100127983, CurrentID=0, Status='live', Symbol='C8orf88', Aliases=[], description='chromosome 8 open reading frame 88', other_designations='uncharacterized protein C8orf88', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=90958471, end_position_on_the_genomic_accession=90985393, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100128071 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128071, CurrentID=0, Status='live', Symbol='FAM229A', Aliases=[], description='family with sequence similarity 229 member A', other_designations='protein FAM229A', map_location='1p35.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=32361270, end_position_on_the_genomic_accession=32362485, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100128327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128327, CurrentID=0, Status='live', Symbol='TRAPPC3L', Aliases=['BET3L', 'bA259P20.2'], description='trafficking protein particle complex subunit 3L', other_designations='trafficking protein particle complex subunit 3-like protein|BET3-like protein|TRAPPC3-like protein|trafficking protein particle complex 3 like|trafficking protein particle complex subunit 3 like', map_location='6q22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=116494989, end_position_on_the_genomic_accession=116545684, orientation='minus', exon_count=5, OMIM=[614137], no_hdr0=''),
    100128553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128553, CurrentID=0, Status='live', Symbol='CTAGE4', Aliases=['cTAGE-4'], description='CTAGE family member 4', other_designations='cTAGE family member 4|cutaneous T-cell lymphoma-associated antigen 4|cutaneous-T-cell-lymphoma-specific tumor antigen 4|protein cTAGE-4', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144183466, end_position_on_the_genomic_accession=144186080, orientation='plus', exon_count=1, OMIM=[608910], no_hdr0=''),
    100128569 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128569, CurrentID=0, Status='live', Symbol='C19orf71', Aliases=[], description='chromosome 19 open reading frame 71', other_designations='uncharacterized protein C19orf71', map_location='19p13.3', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=3539174, end_position_on_the_genomic_accession=3544030, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100128731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128731, CurrentID=0, Status='live', Symbol='OST4', Aliases=[], description='oligosaccharyltransferase complex subunit 4, non-catalytic', other_designations='dolichyl-diphosphooligosaccharide--protein glycosyltransferase subunit 4|oligosaccharyltransferase 4 homolog', map_location='2p23.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=27070472, end_position_on_the_genomic_accession=27071654, orientation='minus', exon_count=3, OMIM=[618932], no_hdr0=''),
    100128908 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128908, CurrentID=0, Status='live', Symbol='LMLN2', Aliases=[], description='leishmanolysin like peptidase 2', other_designations='leishmanolysin-like peptidase 2|leishmanolysin homolog', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23099062, end_position_on_the_genomic_accession=23104989, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    100128927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100128927, CurrentID=0, Status='live', Symbol='ZBTB42', Aliases=['LCCS6', 'ZNF925'], description='zinc finger and BTB domain containing 42', other_designations='zinc finger and BTB domain-containing protein 42', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=104800554, end_position_on_the_genomic_accession=104804712, orientation='plus', exon_count=2, OMIM=[613915], no_hdr0=''),
    100129098 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129098, CurrentID=0, Status='live', Symbol='LOC100129098', Aliases=[], description='uncharacterized LOC100129098', other_designations='uncharacterized protein LOC100129098', map_location='8q11.23', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=54465594, end_position_on_the_genomic_accession=54470426, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100129128 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129128, CurrentID=0, Status='live', Symbol='KHDC1L', Aliases=[], description='KH domain containing 1 like', other_designations='putative KHDC1-like protein|KH homology domain containing 1-like|RP11-257K9.7', map_location='6q13', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=73223544, end_position_on_the_genomic_accession=73225496, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100129216 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129216, CurrentID=0, Status='live', Symbol='DEFB131B', Aliases=[], description='defensin beta 131B', other_designations='beta-defensin 131B|defensin, beta 131', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71878453, end_position_on_the_genomic_accession=71884561, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100129239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129239, CurrentID=0, Status='live', Symbol='CXorf51A', Aliases=['CXorf51', 'CXorf51B'], description='chromosome X open reading frame 51A', other_designations='uncharacterized protein CXorf51A|Uncharacterized protein CXorf51B', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=146814106, end_position_on_the_genomic_accession=146814744, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100129250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129250, CurrentID=0, Status='live', Symbol='SMIM27', Aliases=['C9orf133', 'TOPORS-AS1'], description='small integral membrane protein 27', other_designations='small integral membrane protein 27|TOPORS antisense RNA 1 (non-protein coding)', map_location='9p21.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=32550976, end_position_on_the_genomic_accession=32566860, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100129271 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129271, CurrentID=0, Status='live', Symbol='C1orf68', Aliases=['LEP7', 'XP32'], description='chromosome 1 open reading frame 68', other_designations='skin-specific protein 32|skin-specific protein (xp32)', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152719522, end_position_on_the_genomic_accession=152720470, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100129278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129278, CurrentID=0, Status='live', Symbol='TDRD15', Aliases=[], description='tudor domain containing 15', other_designations='tudor domain-containing protein 15|tudor domain-containing protein 6-like', map_location='2p24.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=21123932, end_position_on_the_genomic_accession=21147325, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100129307 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129307, CurrentID=0, Status='live', Symbol='LOC100129307', Aliases=[], description='putative UPF0607 protein ENSP00000383144', other_designations='putative UPF0607 protein ENSP00000383144|UPF0607 protein ENSP00000383144-like', map_location='13q22.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=77661374, end_position_on_the_genomic_accession=77662803, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100129361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129361, CurrentID=0, Status='live', Symbol='SMIM10L1', Aliases=[], description='small integral membrane protein 10 like 1', other_designations='small integral membrane protein 10-like protein 1|Small integral membrane protein 10-like protein 1|chromosome X open reading frame 69-like', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=11171194, end_position_on_the_genomic_accession=11176016, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100129407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129407, CurrentID=0, Status='live', Symbol='FAM236A', Aliases=['DMRTC1-AS1', 'LINC00684'], description='family with sequence similarity 235 member A', other_designations='protein FAM236A|DMRTC1 antisense RNA 1 (non-protein coding)|long intergenic non-protein coding RNA 684', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72938206, end_position_on_the_genomic_accession=72938958, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100129480 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129480, CurrentID=0, Status='live', Symbol='MKRN2OS', Aliases=['C3orf83', 'MKRN2-AS1'], description='MKRN2 opposite strand', other_designations='MKRN2 opposite strand protein|MKRN2 antisense RNA 1 (non-protein coding)|MKRN2 antisense gene protein 1', map_location='3p25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=12539131, end_position_on_the_genomic_accession=12561227, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100129515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129515, CurrentID=0, Status='live', Symbol='ETDB', Aliases=['ETDA', 'LINC00633'], description='embryonic testis differentiation homolog B', other_designations='Embryonic testis differentiation protein homolog B-like|embryonic testis differentiation protein|long intergenic non-protein coding RNA 633', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135116145, end_position_on_the_genomic_accession=135120588, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100129520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129520, CurrentID=0, Status='live', Symbol='TEX13C', Aliases=[], description='TEX13 family member C', other_designations='putative testis-expressed protein 13C|testis expressed sequence 13-like|testis-expressed sequence 13C protein', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=125319871, end_position_on_the_genomic_accession=125325214, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100129528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129528, CurrentID=0, Status='live', Symbol='MUC8', Aliases=[], description='mucin 8', other_designations='LOW QUALITY PROTEIN: nascent polypeptide-associated complex subunit alpha, muscle-specific form-like|mucin 8, tracheobronchial', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132471571, end_position_on_the_genomic_accession=132476638, orientation='minus', exon_count=3, OMIM=[601932], no_hdr0=''),
    100129543 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129543, CurrentID=0, Status='live', Symbol='ZNF730', Aliases=[], description='zinc finger protein 730', other_designations='putative zinc finger protein 730', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=23074989, end_position_on_the_genomic_accession=23147886, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    100129583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129583, CurrentID=0, Status='live', Symbol='FAM47E', Aliases=[], description='family with sequence similarity 47 member E', other_designations='protein FAM47E', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76214040, end_position_on_the_genomic_accession=76283783, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100129654 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129654, CurrentID=0, Status='live', Symbol='TCF24', Aliases=['TCF-24', 'bHLHa25'], description='transcription factor 24', other_designations='transcription factor 24', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66946501, end_position_on_the_genomic_accession=66962592, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100129669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129669, CurrentID=0, Status='live', Symbol='IZUMO3', Aliases=['C9orf134', 'bA20A20.1'], description='IZUMO family member 3', other_designations='izumo sperm-egg fusion protein 3', map_location='9p21.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=24542952, end_position_on_the_genomic_accession=24545930, orientation='minus', exon_count=7, OMIM=[618896], no_hdr0=''),
    100129792 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129792, CurrentID=0, Status='live', Symbol='CCDC152', Aliases=['CH5400'], description='coiled-coil domain containing 152', other_designations='coiled-coil domain-containing protein 152', map_location='5p12', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=42756818, end_position_on_the_genomic_accession=42802439, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100129842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129842, CurrentID=0, Status='live', Symbol='ZNF737', Aliases=['ZNF102'], description='zinc finger protein 737', other_designations='zinc finger protein 737|zinc finger protein 102 (Y3)', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=20531230, end_position_on_the_genomic_accession=20565821, orientation='minus', exon_count=8, OMIM=[603984], no_hdr0=''),
    100129924 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129924, CurrentID=0, Status='live', Symbol='TMEM269', Aliases=[], description='transmembrane protein 269', other_designations='transmembrane protein 269', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=42784991, end_position_on_the_genomic_accession=42800827, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100129969 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100129969, CurrentID=0, Status='live', Symbol='FAM205C', Aliases=['FAM205CP'], description='family with sequence similarity 205 member C', other_designations='protein FAM205C|FAM205C pseudogene|family with sequence similarity 205, member C, pseudogene|protein FAM205CP|putative family with sequence similarity 205, member C protein|transmembrane protein C9orf144B pseudogene', map_location='9p13.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=34889066, end_position_on_the_genomic_accession=34895764, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100130086 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130086, CurrentID=0, Status='live', Symbol='HSFX2', Aliases=[], description='heat shock transcription factor family, X-linked 2', other_designations='heat shock transcription factor, X-linked', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149592512, end_position_on_the_genomic_accession=149595314, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100130274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130274, CurrentID=0, Status='live', Symbol='CCDC166', Aliases=[], description='coiled-coil domain containing 166', other_designations='coiled-coil domain-containing protein 166', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143706694, end_position_on_the_genomic_accession=143708109, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100130301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130301, CurrentID=0, Status='live', Symbol='C8orf89', Aliases=[], description='chromosome 8 open reading frame 89', other_designations='putative uncharacterized protein C8orf89', map_location='8q21.11', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=73241331, end_position_on_the_genomic_accession=73285932, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100130302 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130302, CurrentID=0, Status='live', Symbol='SUPT20HL1', Aliases=['FAM48B1', 'SPT20L'], description='SUPT20H like 1', other_designations='transcription factor SPT20 homolog-like 1|SPT20 homolog, SAGA complex component like 1|family with sequence similarity 48, member B1|suppressor of Ty 20 homolog-like 1', map_location='Xp22.11', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=24360639, end_position_on_the_genomic_accession=24367839, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100130311 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130311, CurrentID=0, Status='live', Symbol='C17orf107', Aliases=[], description='chromosome 17 open reading frame 107', other_designations='uncharacterized protein C17orf107', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=4899536, end_position_on_the_genomic_accession=4902934, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100130348 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130348, CurrentID=0, Status='live', Symbol='TMEM262', Aliases=[], description='transmembrane protein 262', other_designations='transmembrane protein 262', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=65088376, end_position_on_the_genomic_accession=65089110, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100130361 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130361, CurrentID=0, Status='live', Symbol='CXorf49', Aliases=['CXorf49B'], description='chromosome X open reading frame 49', other_designations='uncharacterized protein CXorf49', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71714371, end_position_on_the_genomic_accession=71718285, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100130519 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130519, CurrentID=0, Status='live', Symbol='TMEM221', Aliases=[], description='transmembrane protein 221', other_designations='transmembrane protein 221|Putative transmembrane protein ENSP00000342162', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17435509, end_position_on_the_genomic_accession=17448839, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100130520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130520, CurrentID=0, Status='live', Symbol='CD300H', Aliases=['CD300Hs'], description='CD300H molecule (gene/pseudogene)', other_designations='protein CD300H|CD300 antigen-like family member H|CD300c molecule-like', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74557229, end_position_on_the_genomic_accession=74567512, orientation='minus', exon_count=5, OMIM=[616560], no_hdr0=''),
    100130613 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130613, CurrentID=0, Status='live', Symbol='PRR32', Aliases=['CXorf64'], description='proline rich 32', other_designations='proline-rich protein 32', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=126819729, end_position_on_the_genomic_accession=126821786, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100130705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130705, CurrentID=0, Status='live', Symbol='ATP6V1FNB', Aliases=[], description='ATP6V1F neighbor', other_designations='protein ATP6V1FNB|ATP6V1F neighbor gene protein', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=128866330, end_position_on_the_genomic_accession=128872047, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100130733 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130733, CurrentID=0, Status='live', Symbol='LRRC70', Aliases=['SLRN'], description='leucine rich repeat containing 70', other_designations='leucine-rich repeat-containing protein 70|synleurin', map_location='5q12.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=62578819, end_position_on_the_genomic_accession=62581446, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100130742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130742, CurrentID=0, Status='live', Symbol='LRRC69', Aliases=[], description='leucine rich repeat containing 69', other_designations='leucine-rich repeat-containing protein 69', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=91102619, end_position_on_the_genomic_accession=91219257, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    100130771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130771, CurrentID=0, Status='live', Symbol='EFCAB10', Aliases=[], description='EF-hand calcium binding domain 10', other_designations='EF-hand calcium-binding domain-containing protein 10|EF-hand domain-containing protein', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=105565124, end_position_on_the_genomic_accession=105581493, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100130827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130827, CurrentID=0, Status='live', Symbol='SBK3', Aliases=['SGK110'], description='SH3 domain binding kinase family member 3', other_designations='uncharacterized serine/threonine-protein kinase SBK3|SH3-binding domain kinase family member 3|Sugen kinase 110', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55540558, end_position_on_the_genomic_accession=55545543, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100130890 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130890, CurrentID=0, Status='live', Symbol='TSTD3', Aliases=[], description='thiosulfate sulfurtransferase like domain containing 3', other_designations='thiosulfate sulfurtransferase/rhodanese-like domain-containing protein 3|rhodanese domain-containing protein 3|thiosulfate sulfurtransferase (rhodanese)-like domain containing 3', map_location='6q16.2', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=99425442, end_position_on_the_genomic_accession=99579288, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    100130933 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130933, CurrentID=0, Status='live', Symbol='SMIM6', Aliases=['C17orf110', 'ELN'], description='small integral membrane protein 6', other_designations='small integral membrane protein 6|endoregulin', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75646251, end_position_on_the_genomic_accession=75647974, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100130958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130958, CurrentID=0, Status='live', Symbol='SYCE1L', Aliases=['MRP2'], description='synaptonemal complex central element protein 1 like', other_designations='synaptonemal complex central element protein 1-like|meiosis-related protein', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=77199408, end_position_on_the_genomic_accession=77213215, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    100130988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100130988, CurrentID=0, Status='live', Symbol='SPATA48', Aliases=['C7orf72'], description='spermatogenesis associated 48', other_designations='spermatogenesis-associated protein 48|uncharacterized protein C7orf72', map_location='7p12.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=50095861, end_position_on_the_genomic_accession=50159256, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100131017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131017, CurrentID=0, Status='live', Symbol='ZNF316', Aliases=['MZF-3'], description='zinc finger protein 316', other_designations='zinc finger protein 316', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6637318, end_position_on_the_genomic_accession=6658279, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100131107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131107, CurrentID=0, Status='live', Symbol='LOC100131107', Aliases=[], description='putative UPF0607 protein ENSP00000383783', other_designations='putative UPF0607 protein ENSP00000383783|UPF0607 protein ENSP00000383783-like', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=152079413, end_position_on_the_genomic_accession=152080924, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100131137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131137, CurrentID=0, Status='live', Symbol='BSPH1', Aliases=['BSP1', 'ELSPBP2'], description='binder of sperm protein homolog 1', other_designations='binder of sperm protein homolog 1|binder of sperm 1|bovine seminal plasma protein homolog 1|bovine seminal plasma protein-like 1|epididymal sperm binding protein 2', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=47967258, end_position_on_the_genomic_accession=47992170, orientation='minus', exon_count=7, OMIM=[612213], no_hdr0=''),
    100131187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131187, CurrentID=0, Status='live', Symbol='TSTD1', Aliases=['KAT', 'TST'], description='thiosulfate sulfurtransferase like domain containing 1', other_designations='thiosulfate:glutathione sulfurtransferase|putative thiosulfate sulfurtransferase KAT|thiosulfate sulfurtransferase (rhodanese)-like domain containing 1|thiosulfate sulfurtransferase/rhodanese-like domain-containing protein 1', map_location='1q23.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=161037631, end_position_on_the_genomic_accession=161038964, orientation='minus', exon_count=4, OMIM=[616041], no_hdr0=''),
    100131211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131211, CurrentID=0, Status='live', Symbol='NEMP2', Aliases=['TMEM194B'], description='nuclear envelope integral membrane protein 2', other_designations='nuclear envelope integral membrane protein 2|UPF0571 transmembrane protein|transmembrane protein 194B', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=190454088, end_position_on_the_genomic_accession=190607126, orientation='minus', exon_count=14, OMIM=[616497], no_hdr0=''),
    100131244 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131244, CurrentID=0, Status='live', Symbol='ANKRD63', Aliases=[], description='ankyrin repeat domain 63', other_designations='ankyrin repeat domain-containing protein 63', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40278372, end_position_on_the_genomic_accession=40283064, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100131303 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131303, CurrentID=0, Status='live', Symbol='DPEP2NB', Aliases=[], description='DPEP2 neighbor', other_designations='DPEP2 neighbor protein|CTC-479C5.6', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=68013436, end_position_on_the_genomic_accession=68015911, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100131378 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131378, CurrentID=0, Status='live', Symbol='C11orf91', Aliases=[], description='chromosome 11 open reading frame 91', other_designations='uncharacterized protein C11orf91', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=33698261, end_position_on_the_genomic_accession=33703026, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100131390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131390, CurrentID=0, Status='live', Symbol='SP9', Aliases=['ZNF990'], description='Sp9 transcription factor', other_designations='transcription factor Sp9|Sp9 transcription factor homolog|zinc finger protein 990', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=174334954, end_position_on_the_genomic_accession=174338500, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100131439 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131439, CurrentID=0, Status='live', Symbol='CD300LD', Aliases=['CD300D', 'CLM-4', 'CLM-5', 'CMRF35-A4', 'CMRF35A4'], description='CD300 molecule like family member d', other_designations='CMRF35-like molecule 5|CD300 antigen-like family member D|CMRF35-like molecule 4|immune receptor CD300d', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=74579365, end_position_on_the_genomic_accession=74592283, orientation='minus', exon_count=4, OMIM=[616301], no_hdr0=''),
    100131539 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131539, CurrentID=0, Status='live', Symbol='ZNF705E', Aliases=[], description='zinc finger protein 705E', other_designations='putative zinc finger protein 705E', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71814039, end_position_on_the_genomic_accession=71821548, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100131608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131608, CurrentID=0, Status='live', Symbol='PRR23D1', Aliases=['PRR23D2'], description='proline rich 23 domain containing 1', other_designations='proline-rich protein 23D1|Proline-rich protein 23D2|proline-rich protein 23C-like', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7536671, end_position_on_the_genomic_accession=7542450, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100131755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131755, CurrentID=0, Status='live', Symbol='ARMCX4', Aliases=['CXorf35', 'GASP4'], description='armadillo repeat containing X-linked 4', other_designations='armadillo repeat-containing X-linked protein 4|armadillo repeat containing, X-linked 4 pseudogene', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101418278, end_position_on_the_genomic_accession=101535988, orientation='plus', exon_count=18, OMIM=[301046], no_hdr0=''),
    100131801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131801, CurrentID=0, Status='live', Symbol='PET100', Aliases=['C19orf79', 'MC4DN12'], description='PET100 cytochrome c oxidase chaperone', other_designations='protein PET100 homolog, mitochondrial|PET100 homolog', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7629793, end_position_on_the_genomic_accession=7631956, orientation='plus', exon_count=5, OMIM=[614770], no_hdr0=''),
    100131827 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131827, CurrentID=0, Status='live', Symbol='ZNF717', Aliases=['OB1', 'X17', 'ZNF838'], description='zinc finger protein 717', other_designations='zinc finger protein 717|krueppel-like factor X17|kruppel-like zinc finger factor X17|zinc finger protein 838', map_location='3p12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=75729961, end_position_on_the_genomic_accession=75785578, orientation='minus', exon_count=6, OMIM=[618405], no_hdr0=''),
    100131897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131897, CurrentID=0, Status='live', Symbol='INSYN2B', Aliases=['C5orf57', 'FAM196B'], description='inhibitory synaptic factor family member 2B', other_designations='protein INSYN2B|family with sequence similarity 196 member B|protein FAM196B', map_location='5q35.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=169861303, end_position_on_the_genomic_accession=169980508, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100131902 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131902, CurrentID=0, Status='live', Symbol='KRTAP25-1', Aliases=['KAP25.1'], description='keratin associated protein 25-1', other_designations='keratin-associated protein 25-1', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30289145, end_position_on_the_genomic_accession=30289514, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100131980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100131980, CurrentID=0, Status='live', Symbol='ZNF705G', Aliases=[], description='zinc finger protein 705G', other_designations='putative zinc finger protein 705G', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7355517, end_position_on_the_genomic_accession=7385558, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100132015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132015, CurrentID=0, Status='live', Symbol='TEX13D', Aliases=[], description='TEX13 family member D', other_designations='testis-expressed protein 13D', map_location='Xq25', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=124332660, end_position_on_the_genomic_accession=124336863, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100132074 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132074, CurrentID=0, Status='live', Symbol='FOXO6', Aliases=[], description='forkhead box O6', other_designations='forkhead box protein O6', map_location='1p34.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=41361434, end_position_on_the_genomic_accession=41383590, orientation='plus', exon_count=3, OMIM=[611457], no_hdr0=''),
    100132146 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132146, CurrentID=0, Status='live', Symbol='FAM240A', Aliases=[], description='family with sequence similarity 240 member A', other_designations='protein FAM240A', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=46612525, end_position_on_the_genomic_accession=46626543, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100132202 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132202, CurrentID=0, Status='live', Symbol='LOC100132202', Aliases=[], description='golgin subfamily A member 6-like protein 22', other_designations='golgin subfamily A member 6-like protein 22', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28553470, end_position_on_the_genomic_accession=28563779, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100132247 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132247, CurrentID=0, Status='live', Symbol='NPIPB5', Aliases=[], description='nuclear pore complex interacting protein family member B5', other_designations='nuclear pore complex-interacting protein family member B5|nuclear pore complex interacting protein related', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22506783, end_position_on_the_genomic_accession=22536535, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100132285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132285, CurrentID=0, Status='live', Symbol='KIR2DS2', Aliases=['183ActI', 'CD158J', 'CD158b', 'KIR-2DS2', 'KIR2DL1', 'NKAT-5', 'NKAT5', 'cl-49'], description='killer cell immunoglobulin like receptor, two Ig domains and short cytoplasmic tail 2', other_designations='killer cell immunoglobulin-like receptor 2DS2|CD158 antigen-like family member J|KIR2DS2 Killer-cell Immunoglobulin-like Receptor|MHC class I NK cell receptor|NK receptor 183 ActI|killer cell immunoglobulin-like receptor KIR2DS2|killer cell immunoglobulin-like receptor, two domains, short cytoplasmic tail, 2|killer-cell Ig-like receptor|killer-cell immunoglobulin-like receptor two domains short tail 2 protein|natural killer associated transcript 5|natural killer cell inhibitory receptor|p58 killer cell inhibitory receptor KIR-K7a|p58 natural killer cell receptor clone CL-49', map_location='19q13.4', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[604953], no_hdr0=''),
    100132304 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132304, CurrentID=0, Status='live', Symbol='FAM236B', Aliases=[], description='family with sequence similarity 236 member B', other_designations='protein FAM236B|family with sequence similarity 235 member B', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72781865, end_position_on_the_genomic_accession=72782660, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100132386 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132386, CurrentID=0, Status='live', Symbol='KRTAP4-9', Aliases=['KAP4.9'], description='keratin associated protein 4-9', other_designations='keratin-associated protein 4-9|keratin-associated protein 4.9|ultrahigh sulfur keratin-associated protein 4.9', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41105389, end_position_on_the_genomic_accession=41106488, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100132396 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132396, CurrentID=0, Status='live', Symbol='ZNF705B', Aliases=[], description='zinc finger protein 705B', other_designations='zinc finger protein 705B|Putative zinc finger protein 705D-like protein LOC100132396|putative zinc finger protein 705B', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7926337, end_position_on_the_genomic_accession=7952413, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100132399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132399, CurrentID=0, Status='live', Symbol='GAGE12D', Aliases=['GAGE-12B'], description='G antigen 12D', other_designations='G antigen 12B/C/D/E|GAGE-12D|g antigen 12C/D/E', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49541733, end_position_on_the_genomic_accession=49549094, orientation='plus', exon_count=5, OMIM=[300728], no_hdr0=''),
    100132406 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132406, CurrentID=0, Status='live', Symbol='NBPF10', Aliases=['AB6', 'AG1', 'NBPF9'], description='NBPF member 10', other_designations='neuroblastoma breakpoint family member 10', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=146064699, end_position_on_the_genomic_accession=146144804, orientation='minus', exon_count=90, OMIM=[614000], no_hdr0=''),
    100132463 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132463, CurrentID=0, Status='live', Symbol='CLDN24', Aliases=['CLDN21'], description='claudin 24', other_designations='putative claudin-24|claudin 21', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183321764, end_position_on_the_genomic_accession=183322426, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100132476 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132476, CurrentID=0, Status='live', Symbol='KRTAP4-7', Aliases=['KAP4.7', 'KRTAP4.7'], description='keratin associated protein 4-7', other_designations='putative keratin-associated protein 4-X|Ultrahigh sulfur keratin-associated protein 4.7', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41084207, end_position_on_the_genomic_accession=41085144, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100132565 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132565, CurrentID=0, Status='live', Symbol='GOLGA8F', Aliases=[], description='golgin A8 family member F', other_designations='golgin A8 family member F|golgi autoantigen, golgin subfamily a, 8F|golgin A8 family, member F pseudogene|golgin-like hypothetical protein LOC440321', map_location='15q13.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=28378621, end_position_on_the_genomic_accession=28392021, orientation='plus', exon_count=21, OMIM=[], no_hdr0=''),
    100132916 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132916, CurrentID=0, Status='live', Symbol='SHISAL2B', Aliases=['FAM159B'], description='shisa like 2B', other_designations='protein shisa-like-2B|family with sequence similarity 159 member B|membrane protein FAM159B', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=64690503, end_position_on_the_genomic_accession=64718190, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100132963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132963, CurrentID=0, Status='live', Symbol='SMIM9', Aliases=['CXorf68'], description='small integral membrane protein 9', other_designations='small integral membrane protein 9', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154823348, end_position_on_the_genomic_accession=154834662, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100132994 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100132994, CurrentID=0, Status='live', Symbol='CXorf49B', Aliases=['CXorf49'], description='chromosome X open reading frame 49B', other_designations='uncharacterized protein CXorf49', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71763349, end_position_on_the_genomic_accession=71767204, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100133053 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133053, CurrentID=0, Status='live', Symbol='CXorf51B', Aliases=['CXorf51A'], description='chromosome X open reading frame 51B', other_designations='uncharacterized protein CXorf51B', map_location='Xq27.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=146809771, end_position_on_the_genomic_accession=146810411, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100133093 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133093, CurrentID=0, Status='live', Symbol='FAM25G', Aliases=['FAM25A', 'FAM25B', 'FAM25C', 'bA301J7.4'], description='family with sequence similarity 25 member G', other_designations='protein FAM25G|Protein FAM25C|protein FAM25', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47487219, end_position_on_the_genomic_accession=47491700, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100133251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133251, CurrentID=0, Status='live', Symbol='PRR23D2', Aliases=['PRR23D1'], description='proline rich 23 domain containing 2', other_designations='proline-rich protein 23D2|Proline-rich protein 23D1|proline-rich protein 23C-like', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7778591, end_position_on_the_genomic_accession=7784165, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100133267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133267, CurrentID=0, Status='live', Symbol='DEFB130B', Aliases=[], description='defensin beta 130B', other_designations='beta-defensin 130B|beta-defensin 130-like|defensin, beta 130-like', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=12064389, end_position_on_the_genomic_accession=12071747, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100133315 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133315, CurrentID=0, Status='live', Symbol='LOC100133315', Aliases=[], description='XRCC1 N-terminal domain containing 1-like', other_designations='putative short transient receptor potential channel 2-like protein|XRCC1 N-terminal domain containing 1-like protein|trpC2-like protein', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=71865509, end_position_on_the_genomic_accession=71928594, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100133941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100133941, CurrentID=0, Status='live', Symbol='CD24', Aliases=['CD24A'], description='CD24 molecule', other_designations='signal transducer CD24|CD24 antigen (small cell lung carcinoma cluster 4 antigen)', map_location='6q21', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=106969831, end_position_on_the_genomic_accession=106976855, orientation='minus', exon_count=5, OMIM=[600074], no_hdr0=''),
    100134444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100134444, CurrentID=0, Status='live', Symbol='KCNJ18', Aliases=['KIR2.6', 'TTPP2'], description='potassium inwardly rectifying channel subfamily J member 18', other_designations='inward rectifier potassium channel 18|inward rectifier K(+) channel Kir2.6|inwardly rectifying potassium channel 18|potassium channel, inwardly rectifying subfamily J, member 18|potassium voltage-gated channel subfamily J member 18|thyrotoxic periodic paralysis susceptibility ion channel', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=21692523, end_position_on_the_genomic_accession=21705700, orientation='plus', exon_count=4, OMIM=[613236], no_hdr0=''),
    100134934 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100134934, CurrentID=0, Status='live', Symbol='TEN1', Aliases=['C17orf106'], description='TEN1 subunit of CST complex', other_designations='CST complex subunit TEN1|TEN1 telomerase capping complex subunit homolog|TEN1, CST complex subunit|protein telomeric pathways with STN1 homolog|telomere length regulation protein TEN1 homolog|telomeric pathways in association with Stn1, number 1', map_location='17q25.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=75979240, end_position_on_the_genomic_accession=76000586, orientation='plus', exon_count=4, OMIM=[613130], no_hdr0=''),
    100134938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100134938, CurrentID=0, Status='live', Symbol='UPK3BL1', Aliases=['UPK3BL', 'UPLP'], description='uroplakin 3B like 1', other_designations='uroplakin-3b-like protein 1|uroplakin 3C protein|uroplakin-3-like protein|uroplakin-like protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102637025, end_position_on_the_genomic_accession=102642791, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100137047 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100137047, CurrentID=0, Status='live', Symbol='JMJD7', Aliases=[], description='jumonji domain containing 7', other_designations='bifunctional peptidase and (3S)-lysyl hydroxylase JMJD7|L-lysine (3S)-hydroxylase JMJD7|jmjC domain-containing protein 7|jumonji domain-containing protein 7', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41828092, end_position_on_the_genomic_accession=41837581, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    100137049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100137049, CurrentID=0, Status='live', Symbol='PLA2G4B', Aliases=['HsT16992', 'cPLA2-beta'], description='phospholipase A2 group IVB', other_designations='cytosolic phospholipase A2 beta|lysophospholipase A1 group IVB|phospholipase A2, group IVB (cytosolic)', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=41838847, end_position_on_the_genomic_accession=41848143, orientation='plus', exon_count=20, OMIM=[606088], no_hdr0=''),
    100141515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100141515, CurrentID=0, Status='live', Symbol='C17orf99', Aliases=['IL-40', 'UNQ464'], description='chromosome 17 open reading frame 99', other_designations='protein IL-40|GLPG464|interleukin-40|uncharacterized protein C17orf99', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78146035, end_position_on_the_genomic_accession=78166297, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    100142659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100142659, CurrentID=0, Status='live', Symbol='CTAGE8', Aliases=['CTAGE4'], description='CTAGE family member 8', other_designations='cTAGE family member 8|CTAGE family, member 4 pseudogene|Cutaneous T-cell lymphoma-associated antigen 8|Protein cTAGE-4|Protein cTAGE-8|cTAGE family member 4', map_location='7q35', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=144266674, end_position_on_the_genomic_accession=144269288, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100144748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100144748, CurrentID=0, Status='live', Symbol='KLLN', Aliases=['CWS4', 'KILLIN'], description='killin, p53 regulated DNA replication inhibitor', other_designations='killin', map_location='10q23.31', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=87859158, end_position_on_the_genomic_accession=87863533, orientation='minus', exon_count=1, OMIM=[612105], no_hdr0=''),
    100151643 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100151643, CurrentID=0, Status='live', Symbol='KRTAP20-4', Aliases=['KAP20.4'], description='keratin associated protein 20-4', other_designations='putative keratin-associated protein 20-4', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30620627, end_position_on_the_genomic_accession=30620850, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100169851 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100169851, CurrentID=0, Status='live', Symbol='PATE3', Aliases=['HEL-127', 'PATE-DJ'], description='prostate and testis expressed 3', other_designations='prostate and testis expressed protein 3|PATE-like protein DJ|acrosomal vesicle protein HEL-127|secreted TFP/Ly-6/uPAR protein PATE-DJ', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=125785996, end_position_on_the_genomic_accession=125791600, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100170229 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100170229, CurrentID=0, Status='live', Symbol='SRRM5', Aliases=['ZNF576'], description='serine/arginine repetitive matrix 5', other_designations='serine/arginine repetitive matrix protein 5|zinc finger protein 576', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43612088, end_position_on_the_genomic_accession=43614498, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100170765 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100170765, CurrentID=0, Status='live', Symbol='ERICH4', Aliases=['C19orf69'], description='glutamate rich 4', other_designations='glutamate-rich protein 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=41442426, end_position_on_the_genomic_accession=41444765, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100170841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100170841, CurrentID=0, Status='live', Symbol='EPOP', Aliases=['C17orf96', 'PRR28'], description='elongin BC and polycomb repressive complex 2 associated protein', other_designations='elongin BC and Polycomb repressive complex 2-associated protein|proline rich 28|proline-rich protein 28|uncharacterized protein C17orf96', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38671703, end_position_on_the_genomic_accession=38674957, orientation='minus', exon_count=1, OMIM=[617795], no_hdr0=''),
    100187907 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100187907, CurrentID=0, Status='live', Symbol='TRAP', Aliases=[], description='triiodothyronine receptor auxiliary protein', other_designations='', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[190445], no_hdr0=''),
    100188893 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100188893, CurrentID=0, Status='live', Symbol='TOMM6', Aliases=['OBTP', 'TOM6'], description='translocase of outer mitochondrial membrane 6', other_designations='mitochondrial import receptor subunit TOM6 homolog|over-expressed breast tumor protein|overexpressed breast tumor protein|translocase of outer membrane 6 kDa subunit homolog|translocase of outer mitochondrial membrane 6 homolog', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=41787694, end_position_on_the_genomic_accession=41789895, orientation='plus', exon_count=3, OMIM=[616168], no_hdr0=''),
    100190949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100190949, CurrentID=0, Status='live', Symbol='C5orf52', Aliases=[], description='chromosome 5 open reading frame 52', other_designations='uncharacterized protein C5orf52', map_location='5q33.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=157670399, end_position_on_the_genomic_accession=157680176, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    100191040 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100191040, CurrentID=0, Status='live', Symbol='C2CD4D', Aliases=['FAM148D'], description='C2 calcium dependent domain containing 4D', other_designations='C2 calcium-dependent domain-containing protein 4D|family with sequence similarity 148, member D', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151837818, end_position_on_the_genomic_accession=151840557, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100271715 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100271715, CurrentID=0, Status='live', Symbol='ARHGEF33', Aliases=[], description='Rho guanine nucleotide exchange factor 33', other_designations='rho guanine nucleotide exchange factor 33|DH and coiled-coil domain-containing protein ENSP00000381780|Rho guanine nucleotide exchange factor (GEF) 33', map_location='2p22.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=38889875, end_position_on_the_genomic_accession=38975454, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    100271846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100271846, CurrentID=0, Status='live', Symbol='ERVV-2', Aliases=['ENVV2', 'HERV-V2'], description='endogenous retrovirus group V member 2, envelope', other_designations='endogenous retrovirus group V member 2 Env polyprotein|HERV-V_19q13.41 provirus ancestral Env polyprotein 2|endogenous retrovirus HSV2|endogenous retrovirus group V, member 2|envelope glycoprotein ENVV2|envelope protein ENVV2', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53044740, end_position_on_the_genomic_accession=53051680, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100271849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100271849, CurrentID=0, Status='live', Symbol='MEF2B', Aliases=['RSRFR2'], description='myocyte enhancer factor 2B', other_designations='myocyte-specific enhancer factor 2B|MADS box transcription enhancer factor 2, polypeptide B (myocyte enhancer factor 2B)|serum response factor-like protein 2', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=19145567, end_position_on_the_genomic_accession=19170263, orientation='minus', exon_count=9, OMIM=[600661], no_hdr0=''),
    100271927 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100271927, CurrentID=0, Status='live', Symbol='RASA4B', Aliases=[], description='RAS p21 protein activator 4B', other_designations='ras GTPase-activating protein 4B|putative Ras GTPase-activating protein 4B', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102479976, end_position_on_the_genomic_accession=102517777, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    100272147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100272147, CurrentID=0, Status='live', Symbol='CMC4', Aliases=['C6.1B', 'MTCP1', 'MTCP1B', 'MTCP1NB', 'p8', 'p8MTCP1'], description='C-X9-C motif containing 4', other_designations='cx9C motif-containing protein 4|C-x(9)-C motif containing 4 homolog|MTCP-1 type A|mature T-cell proliferation 1 neighbor protein|mature T-cell proliferation-1 type A|protein p8 MTCP-1', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=155061622, end_position_on_the_genomic_accession=155071136, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100286986 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100286986, CurrentID=0, Status='live', Symbol='LOC100286986', Aliases=[], description='atrophin-domain containing', other_designations='uncharacterized protein LOC100286986', map_location='18p11.31', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=5592975, end_position_on_the_genomic_accession=5630451, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100287045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287045, CurrentID=0, Status='live', Symbol='FAM90A26', Aliases=['FAM90A26P'], description='family with sequence similarity 90 member A26', other_designations='putative protein FAM90A26|family with sequence similarity 90, member A26, pseudogene', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9173117, end_position_on_the_genomic_accession=9176730, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    100287144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287144, CurrentID=0, Status='live', Symbol='USP17L10', Aliases=[], description='ubiquitin specific peptidase 17 like family member 10', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 10', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9210657, end_position_on_the_genomic_accession=9212249, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287171 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287171, CurrentID=0, Status='live', Symbol='WASHC1', Aliases=['FAM39E', 'WASH', 'WASH1'], description='WASH complex subunit 1', other_designations='WASH complex subunit 1|CXYorf1-like protein on chromosome 9|FLJ00075 protein|WAS protein family homolog 1|actin nucleation promoting factor|family with sequence similarity 39, member E', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=14475, end_position_on_the_genomic_accession=30487, orientation='minus', exon_count=16, OMIM=[613632], no_hdr0=''),
    100287178 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287178, CurrentID=0, Status='live', Symbol='USP17L11', Aliases=[], description='ubiquitin specific peptidase 17 like family member 11', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 11', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9215405, end_position_on_the_genomic_accession=9216997, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287205 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287205, CurrentID=0, Status='live', Symbol='USP17L12', Aliases=[], description='ubiquitin specific peptidase 17 like family member 12', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 12', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9220152, end_position_on_the_genomic_accession=9221744, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287226, CurrentID=0, Status='live', Symbol='ZNF729', Aliases=[], description='zinc finger protein 729', other_designations='zinc finger protein 729', map_location='19p12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=22286441, end_position_on_the_genomic_accession=22317176, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    100287238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287238, CurrentID=0, Status='live', Symbol='USP17L13', Aliases=[], description='ubiquitin specific peptidase 17 like family member 13', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 13', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9224896, end_position_on_the_genomic_accession=9226488, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287284 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287284, CurrentID=0, Status='live', Symbol='MANSC4', Aliases=[], description='MANSC domain containing 4', other_designations='MANSC domain-containing protein 4|MANSC domain-containing protein ENSP00000370673', map_location='12p11.22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=27762427, end_position_on_the_genomic_accession=27780236, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100287327 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287327, CurrentID=0, Status='live', Symbol='USP17L17', Aliases=[], description='ubiquitin specific peptidase 17 like family member 17', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 17', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9243879, end_position_on_the_genomic_accession=9245471, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287364 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287364, CurrentID=0, Status='live', Symbol='USP17L18', Aliases=[], description='ubiquitin specific peptidase 17 like family member 18', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 18', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9248630, end_position_on_the_genomic_accession=9250222, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287399 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287399, CurrentID=0, Status='live', Symbol='POTEB2', Aliases=['POTE-15', 'POTEB'], description='POTE ankyrin domain family member B2', other_designations='POTE ankyrin domain family member B2|ANKRD26-like family B member 1|POTE ankyrin domain family member B|Prostate, ovary, testis-expressed protein on chromosome 15', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=20835372, end_position_on_the_genomic_accession=20866428, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    100287404 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287404, CurrentID=0, Status='live', Symbol='USP17L19', Aliases=[], description='ubiquitin specific peptidase 17 like family member 19', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 19', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9253378, end_position_on_the_genomic_accession=9254970, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287441, CurrentID=0, Status='live', Symbol='USP17L20', Aliases=[], description='ubiquitin specific peptidase 17 like family member 20', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 20', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9258124, end_position_on_the_genomic_accession=9259716, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287478, CurrentID=0, Status='live', Symbol='USP17L21', Aliases=[], description='ubiquitin specific peptidase 17 like family member 21', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 21', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9262872, end_position_on_the_genomic_accession=9264464, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287482, CurrentID=0, Status='live', Symbol='SMKR1', Aliases=[], description='small lysine rich protein 1', other_designations='small lysine-rich protein 1', map_location='7q32.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=129502531, end_position_on_the_genomic_accession=129512918, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100287513 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287513, CurrentID=0, Status='live', Symbol='USP17L22', Aliases=[], description='ubiquitin specific peptidase 17 like family member 22', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 22', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9267619, end_position_on_the_genomic_accession=9269211, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100287520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287520, CurrentID=0, Status='live', Symbol='GLYATL1B', Aliases=['GLYATL1P3'], description='glycine-N-acyltransferase like 1B', other_designations='putative glycine N-acyltransferase-like protein 1B|glycine-N-acyltransferase like 1 pseudogene 3', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59086307, end_position_on_the_genomic_accession=59094786, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100287718 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287718, CurrentID=0, Status='live', Symbol='ANKRD66', Aliases=[], description='ankyrin repeat domain 66', other_designations='ankyrin repeat domain-containing protein 66', map_location='6p12.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=46746929, end_position_on_the_genomic_accession=46759506, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100287898 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287898, CurrentID=0, Status='live', Symbol='TTC34', Aliases=[], description='tetratricopeptide repeat domain 34', other_designations='tetratricopeptide repeat protein 34|TPR repeat protein 34|TPR repeat-containing protein ENSP00000383873', map_location='1p36.32', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=2636988, end_position_on_the_genomic_accession=2800868, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100287932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287932, CurrentID=0, Status='live', Symbol='TIMM23', Aliases=['TIM23'], description='translocase of inner mitochondrial membrane 23', other_designations='mitochondrial import inner membrane translocase subunit Tim23|translocase of inner mitochondrial membrane 23 homolog|translocase of the inner mitochondrial membrane', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=45972489, end_position_on_the_genomic_accession=46003742, orientation='plus', exon_count=8, OMIM=[605034], no_hdr0=''),
    100287979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100287979, CurrentID=0, Status='live', Symbol='TTTY13C', Aliases=[], description='testis-specific transcript, Y-linked 13C', other_designations='', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100288072 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288072, CurrentID=0, Status='live', Symbol='SDR42E2', Aliases=[], description='short chain dehydrogenase/reductase family 42E, member 2', other_designations='putative short-chain dehydrogenase/reductase family 42E member 2|putative 3-beta-HSD family protein ENSP00000330812', map_location='16p12.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=22162506, end_position_on_the_genomic_accession=22191751, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    100288142 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288142, CurrentID=0, Status='live', Symbol='NBPF20', Aliases=[], description='NBPF member 20', other_designations='neuroblastoma breakpoint family member 20', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145289900, end_position_on_the_genomic_accession=145405778, orientation='minus', exon_count=138, OMIM=[614007], no_hdr0=''),
    100288287 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288287, CurrentID=0, Status='live', Symbol='KRTAP22-2', Aliases=['KAP22.2'], description='keratin associated protein 22-2', other_designations='keratin-associated protein 22-2', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30590105, end_position_on_the_genomic_accession=30590397, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100288323 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288323, CurrentID=0, Status='live', Symbol='KRTAP21-3', Aliases=[], description='keratin associated protein 21-3', other_designations='keratin-associated protein 21-3', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=30718525, end_position_on_the_genomic_accession=30718777, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100288332 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288332, CurrentID=0, Status='live', Symbol='NPIPA5', Aliases=['NPIP'], description='nuclear pore complex interacting protein family member A5', other_designations='nuclear pore complex-interacting protein family member A5', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=15363613, end_position_on_the_genomic_accession=15381467, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    100288413 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288413, CurrentID=0, Status='live', Symbol='ERVMER34-1', Aliases=['HEMO', 'envMER34'], description='endogenous retrovirus group MER34 member 1, envelope', other_designations='endogenous retroviral envelope protein HEMO|HERV-MER_4q12 provirus ancestral Env polyprotein|LP9056 protein|endogenous MER34 (medium-reiteration-frequency-family-34) ORF|endogenous retrovirus group MER34 member 1 Env polyprotein|endogenous retrovirus group MER34, member 1|human endogenous MER34 ORF', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=52742553, end_position_on_the_genomic_accession=52751425, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100288485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288485, CurrentID=0, Status='live', Symbol='MTRNR2L7', Aliases=['HN7'], description='MT-RNR2 like 7', other_designations='humanin-like 7|MTRNR2-like 7|humanin-like protein 7', map_location='10p11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=37601438, end_position_on_the_genomic_accession=37602931, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100288520 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288520, CurrentID=0, Status='live', Symbol='USP17L15', Aliases=[], description='ubiquitin specific peptidase 17 like family member 15', other_designations='ubiquitin carboxyl-terminal hydrolase 17-like protein 15', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=9234385, end_position_on_the_genomic_accession=9236046, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100288687 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288687, CurrentID=0, Status='live', Symbol='DUX4', Aliases=['DUX4L'], description='double homeobox 4', other_designations='double homeobox protein 4|double homeobox protein 10|double homeobox protein 4/10', map_location='4q35.2', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=190173774, end_position_on_the_genomic_accession=190185911, orientation='plus', exon_count=7, OMIM=[606009], no_hdr0=''),
    100288695 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288695, CurrentID=0, Status='live', Symbol='LIMS4', Aliases=['LIMS3L'], description='LIM zinc finger domain containing 4', other_designations='LIM and senescent cell antigen-like-containing domain protein 4|LIM and senescent cell antigen-like domains 3-like|LIM and senescent cell antigen-like-containing domain protein 3-like|LIM-type zinc finger domains 4|particularly interesting new Cys-His protein 3', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110386341, end_position_on_the_genomic_accession=110473075, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    100288797 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288797, CurrentID=0, Status='live', Symbol='TMEM239', Aliases=[], description='transmembrane protein 239', other_designations='transmembrane protein 239', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=2815871, end_position_on_the_genomic_accession=2820284, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100288801 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288801, CurrentID=0, Status='live', Symbol='FRG2C', Aliases=[], description='FSHD region gene 2 family member C', other_designations='protein FRG2-like-2|FSHD region gene 2 family, member C-like|FSHD region gene 2 protein family member C|HSA3-FRG2', map_location='3p12.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=75646761, end_position_on_the_genomic_accession=75667217, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100288814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288814, CurrentID=0, Status='live', Symbol='CLDN34', Aliases=[], description='claudin 34', other_designations='claudin-34', map_location='Xp22.2', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=9967358, end_position_on_the_genomic_accession=9968352, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100288842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288842, CurrentID=0, Status='live', Symbol='B3GALT9', Aliases=['B3GNT10'], description='beta-1,3-galactosyltransferase 9', other_designations='beta-1,3-galactosyltransferase 9|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 10 (putative)|UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase 5 pseudogene|putative UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase LOC100288842|putative UDP-GlcNAc:betaGal beta-1,3-N-acetylglucosaminyltransferase LOC402377', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=120793467, end_position_on_the_genomic_accession=120801787, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100288966 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100288966, CurrentID=0, Status='live', Symbol='LOC100288966', Aliases=['A26B3', 'ANKRD21', 'POTE', 'POTED'], description='POTE ankyrin domain family member D-like', other_designations='uncharacterized protein LOC100288966|ANKRD26-like family B member 3|Ankyrin repeat domain-containing protein 21|POTE ankyrin domain family member D|Prostate, ovary, testis-expressed protein|Protein POTE', map_location='', chromosome='Un', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100289087 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289087, CurrentID=0, Status='live', Symbol='TSPY10', Aliases=['CT78', 'TSPY', 'TSPY1', 'TSPY3'], description='testis specific protein Y-linked 10', other_designations='testis-specific Y-encoded protein 10|Cancer/testis antigen 78|Testis-specific Y-encoded protein 1|Testis-specific Y-encoded protein 3', map_location='Yp11.2', chromosome='Y', genomic_nucleotide_accession_version='NC_000024.10', start_position_on_the_genomic_accession=9527880, end_position_on_the_genomic_accession=9530676, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100289187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289187, CurrentID=0, Status='live', Symbol='TMEM225B', Aliases=['GS1-259H13.2'], description='transmembrane protein 225B', other_designations='transmembrane protein 225B|transmembrane protein 225-like', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99572366, end_position_on_the_genomic_accession=99611045, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    100289255 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289255, CurrentID=0, Status='live', Symbol='TMEM238L', Aliases=['FORCP', 'LINC00675'], description='transmembrane protein 238 like', other_designations='transmembrane protein 238-like|FOXA1-Regulated Conserved Small Protein|long intergenic non-protein coding RNA 675|putative transmembrane protein LOC100289255', map_location='17p13.1-p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=10794908, end_position_on_the_genomic_accession=10804099, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100289279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289279, CurrentID=0, Status='live', Symbol='CNTNAP3C', Aliases=[], description='contactin associated protein family member 3C', other_designations='contactin-associated protein-like 3|contactin associated protein like 3C|contactin associated protein-like 3-like', map_location='9q12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=61330592, end_position_on_the_genomic_accession=61461350, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    100289462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289462, CurrentID=0, Status='live', Symbol='DEFB4B', Aliases=['DEFB4P'], description='defensin beta 4B', other_designations='beta-defensin 4B|beta defensin 2|defensin, beta 4, pseudogene', map_location='8p23.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=7414855, end_position_on_the_genomic_accession=7416863, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100289635 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289635, CurrentID=0, Status='live', Symbol='ZNF605', Aliases=[], description='zinc finger protein 605', other_designations='zinc finger protein 605', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132918306, end_position_on_the_genomic_accession=132956306, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100289678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100289678, CurrentID=0, Status='live', Symbol='ZNF783', Aliases=[], description='zinc finger family member 783', other_designations='protein ZNF783', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=149262196, end_position_on_the_genomic_accession=149284994, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100293516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100293516, CurrentID=0, Status='live', Symbol='ZNF587B', Aliases=[], description='zinc finger protein 587B', other_designations='zinc finger protein 587B', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=57830299, end_position_on_the_genomic_accession=57846238, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100293534 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100293534, CurrentID=0, Status='live', Symbol='C4B_2', Aliases=[], description='complement component 4B (Chido blood group), copy 2', other_designations='complement C4-B-like', map_location='6p21.3 alternate reference locus', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100302652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100302652, CurrentID=0, Status='live', Symbol='GPR75-ASB3', Aliases=['ASB-3', 'ASB3'], description='GPR75-ASB3 readthrough', other_designations='GPR75-ASB3 protein|Ankyrin repeat and SOCS box protein 3', map_location='2p16.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=53670293, end_position_on_the_genomic_accession=53859967, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100302736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100302736, CurrentID=0, Status='live', Symbol='TMED7-TICAM2', Aliases=['MyD88-4', 'TICAM-2', 'TICAM2', 'TIRAP3', 'TIRP', 'TRAM'], description='TMED7-TICAM2 readthrough', other_designations='TRAM adaptor with GOLD domain|Putative NF-kappa-B-activating protein 502|TIR domain-containing adapter molecule 2|TMED7-TICAM2 read-through transcript|Toll-like receptor adaptor protein 3|Toll/interleukin-1 receptor domain-containing protein', map_location='5q22.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=115578496, end_position_on_the_genomic_accession=115626036, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100303755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100303755, CurrentID=0, Status='live', Symbol='PET117', Aliases=['CSRP2BP', 'MC4DN19'], description='PET117 cytochrome c oxidase chaperone', other_designations='protein PET117 homolog, mitochondrial|PET117 homolog|alternative protein CSRP2BP', map_location='20p11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=18137863, end_position_on_the_genomic_accession=18143169, orientation='plus', exon_count=2, OMIM=[614771], no_hdr0=''),
    100310812 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100310812, CurrentID=0, Status='live', Symbol='SPDYE2B', Aliases=['SPDYE2L'], description='speedy/RINGO cell cycle regulator family member E2B', other_designations='speedy protein E2B|WBSCR19-like protein 3|putative WBSCR19-like protein 3|putative speedy protein E2-like protein', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102649122, end_position_on_the_genomic_accession=102663525, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    100310846 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100310846, CurrentID=0, Status='live', Symbol='ANKRD61', Aliases=[], description='ankyrin repeat domain 61', other_designations='ankyrin repeat domain-containing protein 61', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6031376, end_position_on_the_genomic_accession=6036552, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100316904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100316904, CurrentID=0, Status='live', Symbol='SAP25', Aliases=[], description='Sin3A associated protein 25', other_designations='histone deacetylase complex subunit SAP25|25 kDa Sin3-associated polypeptide|Sin3 corepressor complex subunit SAP25|Sin3A-associated protein, 25kDa|sin3-associated polypeptide, 25kDa|sin3A-binding protein 25', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=100572228, end_position_on_the_genomic_accession=100573900, orientation='minus', exon_count=6, OMIM=[619230], no_hdr0=''),
    100329135 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100329135, CurrentID=0, Status='live', Symbol='TRPC5OS', Aliases=['TRPC5-AS1'], description='TRPC5 opposite strand', other_designations='putative uncharacterized protein TRPC5OS|TRPC5 antisense RNA 1 (non-protein coding)|TRPC5 opposite strand protein', map_location='Xq23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=111876051, end_position_on_the_genomic_accession=111903990, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100381270 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100381270, CurrentID=0, Status='live', Symbol='ZBED6', Aliases=['MGR'], description='zinc finger BED-type containing 6', other_designations='zinc finger BED domain-containing protein 6', map_location='1q32.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=203797523, end_position_on_the_genomic_accession=203801074, orientation='plus', exon_count=1, OMIM=[613512], no_hdr0=''),
    100419008 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100419008, CurrentID=0, Status='live', Symbol='PRR20G', Aliases=[], description='proline rich 20G', other_designations='proline-rich protein 20G|proline rich 20B pseudogene|proline rich 20B-like', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=127283783, end_position_on_the_genomic_accession=127288046, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100421372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100421372, CurrentID=0, Status='live', Symbol='LOC100421372', Aliases=[], description='zinc finger and SCAN domain containing 29', other_designations='zinc finger and SCAN domain containing 29', map_location='10p13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=14838306, end_position_on_the_genomic_accession=14846999, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100423062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100423062, CurrentID=0, Status='live', Symbol='IGLL5', Aliases=['IGL', 'IGLV', 'VL-MAR'], description='immunoglobulin lambda like polypeptide 5', other_designations='immunoglobulin lambda-like polypeptide 5|G lambda-1|anti HBs antibody light-chain Fab fragment|germline immunoglobulin lambda 1|immunoglobin anti-granzymeB light chain variable region|immunoglobulin lambda 1 light chain|immunoglobulin lambda 2 light chain|immunoglobulin lambda 3 light chain|immunoglobulin lambda light chain variable region|immunoglobulin lambda-3 surrogate light chain|immunoglobulin light chain variable region EM1-PPS-4-L1-1|omega light chain protein 14.1', map_location='22q11.22', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=22887816, end_position_on_the_genomic_accession=22896111, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100431172 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100431172, CurrentID=0, Status='live', Symbol='KLRF2', Aliases=['NKp65'], description='killer cell lectin like receptor F2', other_designations='killer cell lectin-like receptor subfamily F member 2|activating coreceptor NKp65|killer cell lectin-like receptor subfamily F, member 2|lectin-like receptor F2', map_location='12p13.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=9881489, end_position_on_the_genomic_accession=9895833, orientation='plus', exon_count=6, OMIM=[618814], no_hdr0=''),
    100462977 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100462977, CurrentID=0, Status='live', Symbol='MTRNR2L1', Aliases=['HN1'], description='MT-RNR2 like 1', other_designations='humanin-like 1|MTRNR2-like 1|humanin-like protein 1', map_location='17p11.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=22523415, end_position_on_the_genomic_accession=22524663, orientation='plus', exon_count=1, OMIM=[616985], no_hdr0=''),
    100462981 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100462981, CurrentID=0, Status='live', Symbol='MTRNR2L2', Aliases=['HN2'], description='MT-RNR2 like 2', other_designations='humanin-like 2|MTRNR2-like 2|humanin-like protein 2', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=80650000, end_position_on_the_genomic_accession=80651008, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100462983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100462983, CurrentID=0, Status='live', Symbol='MTRNR2L3', Aliases=['HN3'], description='MT-RNR2 like 3', other_designations='humanin-like 3|MTRNR2-like 3|humanin-like protein 3', map_location='20q13.31', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=57358447, end_position_on_the_genomic_accession=57359498, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100463285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463285, CurrentID=0, Status='live', Symbol='MTRNR2L4', Aliases=['HN4'], description='MT-RNR2 like 4', other_designations='humanin-like 4|MTRNR2-like 4|humanin-like protein 4', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=3370979, end_position_on_the_genomic_accession=3372668, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100463289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463289, CurrentID=0, Status='live', Symbol='MTRNR2L5', Aliases=['HN5'], description='MT-RNR2 like 5', other_designations='humanin-like 5|MTRNR2-like 5|humanin-like protein 5', map_location='10q21.1', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=55599042, end_position_on_the_genomic_accession=55600728, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100463482 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463482, CurrentID=0, Status='live', Symbol='MTRNR2L6', Aliases=['HN6'], description='MT-RNR2 like 6', other_designations='humanin-like 6|MTRNR2-like 6|humanin-like protein 6', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=142666299, end_position_on_the_genomic_accession=142667693, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100463486 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463486, CurrentID=0, Status='live', Symbol='MTRNR2L8', Aliases=['HN8'], description='MT-RNR2 like 8', other_designations='humanin-like 8|MTRNR2-like 8|humanin-like protein 8', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=10507894, end_position_on_the_genomic_accession=10509186, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100463487 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463487, CurrentID=0, Status='live', Symbol='MTRNR2L9', Aliases=['HN9'], description='MT-RNR2 like 9', other_designations='humanin-like 9|MT-RNR2-like 9 (pseudogene)|MTRNR2-like 9|humanin-like protein 9', map_location='6q11.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=61574130, end_position_on_the_genomic_accession=61574630, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100463488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100463488, CurrentID=0, Status='live', Symbol='MTRNR2L10', Aliases=['HN10'], description='MT-RNR2 like 10', other_designations='humanin-like 10|MTRNR2-like 10|humanin-like protein 10', map_location='Xp11.21', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=55181392, end_position_on_the_genomic_accession=55182442, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100499483 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100499483, CurrentID=0, Status='live', Symbol='CCDC180', Aliases=['C9orf174', 'CFAP76', 'FAP76'], description='coiled-coil domain containing 180', other_designations="coiled-coil domain-containing protein 180|Behcet's Disease Associated Gene 1", map_location='9q22.33', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=97307337, end_position_on_the_genomic_accession=97378751, orientation='plus', exon_count=39, OMIM=[], no_hdr0=''),
    100500938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100500938, CurrentID=0, Status='live', Symbol='CCDC179', Aliases=[], description='coiled-coil domain containing 179', other_designations='coiled-coil domain-containing protein 179', map_location='11p14.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=22846922, end_position_on_the_genomic_accession=22860971, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100505385 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505385, CurrentID=0, Status='live', Symbol='IQCJ-SCHIP1', Aliases=[], description='IQCJ-SCHIP1 readthrough', other_designations='IQCJ-SCHIP1 readthrough transcript protein|IQ motif containing J-schwannomin interacting protein 1 fusion protein|IQ motif containing J-schwannomin interacting protein 1 read-through transcript', map_location='3q25.32-q25.33', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=159069319, end_position_on_the_genomic_accession=159897359, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    100505478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505478, CurrentID=0, Status='live', Symbol='TEX48', Aliases=[], description='testis expressed 48', other_designations='testis-expressed protein 48', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114666434, end_position_on_the_genomic_accession=114682192, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100505502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505502, CurrentID=0, Status='live', Symbol='LOC100505502', Aliases=[], description='putative UPF0607 protein FLJ37424', other_designations='putative UPF0607 protein FLJ37424', map_location='10p11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=31361427, end_position_on_the_genomic_accession=31399755, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    100505573 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505573, CurrentID=0, Status='live', Symbol='INAFM2', Aliases=['LINC00984', 'OGU1'], description='InaF motif containing 2', other_designations='putative transmembrane protein INAFM2|inaF-motif-containing protein 2|osteogenesis up-regulated transcript 1|osteogenesis upregulating transcript 1', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40323669, end_position_on_the_genomic_accession=40326715, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100505591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505591, CurrentID=0, Status='live', Symbol='LRRC3C', Aliases=[], description='leucine rich repeat containing 3C', other_designations='leucine-rich repeat-containing protein 3C|putative LRRC3-like protein ENSP00000367157', map_location='17q21.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=39927732, end_position_on_the_genomic_accession=39944999, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100505705 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505705, CurrentID=0, Status='live', Symbol='SDIM1', Aliases=[], description='stress responsive DNAJB4 interacting membrane protein 1', other_designations='', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100505724 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505724, CurrentID=0, Status='live', Symbol='KRTAP9-7', Aliases=['KAP9.7', 'KRTAP9L1'], description='keratin associated protein 9-7', other_designations='keratin-associated protein 9-7|keratin associated protein 9-like 1|putative keratin-associated protein 9-2-like 1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41275698, end_position_on_the_genomic_accession=41276207, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100505741 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505741, CurrentID=0, Status='live', Symbol='SPATA1', Aliases=['SP-2', 'SPAP1'], description='spermatogenesis associated 1', other_designations='spermatogenesis-associated protein 1|sperm-specific protein SP-2', map_location='1p22.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=84506301, end_position_on_the_genomic_accession=84556495, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    100505753 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505753, CurrentID=0, Status='live', Symbol='KRTAP16-1', Aliases=['KAP16.1'], description='keratin associated protein 16-1', other_designations='keratin-associated protein 16-1|putative keratin-associated protein 10-like ENSP00000375147', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41307700, end_position_on_the_genomic_accession=41309309, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100505767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505767, CurrentID=0, Status='live', Symbol='SPDYE18', Aliases=[], description='speedy/RINGO cell cycle regulator family member E18', other_designations='speedy/RINGO cell cycle regulator family member E18', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77050391, end_position_on_the_genomic_accession=77062558, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    100505841 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505841, CurrentID=0, Status='live', Symbol='LOC100505841', Aliases=[], description='zinc finger protein 474-like', other_designations='uncharacterized protein LOC100505841', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=122129559, end_position_on_the_genomic_accession=122182658, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    100505876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505876, CurrentID=0, Status='live', Symbol='CEBPZOS', Aliases=['CEBPZ-AS1'], description='CEBPZ opposite strand', other_designations='protein CEBPZOS|CEBPZ antisense RNA 1', map_location='2p22.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=37196493, end_position_on_the_genomic_accession=37216193, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    100505989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505989, CurrentID=0, Status='live', Symbol='SMIM31', Aliases=['LINC01207'], description='small integral membrane protein 31', other_designations='small integral membrane protein 31|long intergenic non-protein coding RNA 1207', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=164754131, end_position_on_the_genomic_accession=164803795, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100505993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100505993, CurrentID=0, Status='live', Symbol='TMEM210', Aliases=[], description='transmembrane protein 210', other_designations='transmembrane protein 210', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=137170858, end_position_on_the_genomic_accession=137172056, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100506013 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506013, CurrentID=0, Status='live', Symbol='APELA', Aliases=['ELA', 'Ende', 'tdl'], description='apelin receptor early endogenous ligand', other_designations='apelin receptor early endogenous ligand|protein Elabela|protein Toddler', map_location='4q32.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=164877023, end_position_on_the_genomic_accession=164899063, orientation='plus', exon_count=4, OMIM=[615594], no_hdr0=''),
    100506049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506049, CurrentID=0, Status='live', Symbol='LRRC72', Aliases=['CFAP279', 'FAP279'], description='leucine rich repeat containing 72', other_designations='leucine-rich repeat-containing protein 72|leucine-rich repeat-containing protein ENSP00000371558', map_location='7p21.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=16526825, end_position_on_the_genomic_accession=16581568, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100506084 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506084, CurrentID=0, Status='live', Symbol='ARL17B', Aliases=['ARL17', 'ARL17A'], description='ADP ribosylation factor like GTPase 17B', other_designations='ADP-ribosylation factor-like protein 17|ADP-ribosylation factor 7|ADP-ribosylation factor-like 17B', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46274184, end_position_on_the_genomic_accession=46361787, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100506127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506127, CurrentID=0, Status='live', Symbol='GVQW3', Aliases=[], description='GVQW motif containing 3', other_designations='protein GVQW3|GVQW motif-containing protein 3', map_location='11q13.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=76381316, end_position_on_the_genomic_accession=76414634, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100506144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506144, CurrentID=0, Status='live', Symbol='TMEM35B', Aliases=['ZMYM6NB'], description='transmembrane protein 35B', other_designations='transmembrane protein 35B|ZMYM6 neighbor protein', map_location='1p34.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=34981526, end_position_on_the_genomic_accession=34985347, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100506164 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506164, CurrentID=0, Status='live', Symbol='HSFX1', Aliases=['LW-1'], description='heat shock transcription factor family, X-linked 1', other_designations='heat shock transcription factor, X-linked|testicular secretory protein Li 21', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149774068, end_position_on_the_genomic_accession=149776867, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100506243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506243, CurrentID=0, Status='live', Symbol='KRBOX1', Aliases=[], description='KRAB box domain containing 1', other_designations='KRAB domain-containing protein 1', map_location='3p22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=42936386, end_position_on_the_genomic_accession=42942792, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100506374 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506374, CurrentID=0, Status='live', Symbol='EDDM13', Aliases=[], description='epididymal protein 13', other_designations='epididymal protein 13', map_location='19q13.43', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=56272748, end_position_on_the_genomic_accession=56310454, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    100506376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506376, CurrentID=0, Status='live', Symbol='TTLL10-AS1', Aliases=[], description='TTLL10 antisense RNA 1', other_designations='BUD13 homolog|predicted GPI-anchored protein 58|TTLL10 antisense RNA 1 (non-protein coding)', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1173055, end_position_on_the_genomic_accession=1179648, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100506540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506540, CurrentID=0, Status='live', Symbol='SPTY2D1OS', Aliases=['SPTY2D1-AS1'], description='SPTY2D1 opposite strand', other_designations='putative transmembrane protein SPTY2D1OS|SPTY2D1 antisense RNA 1 (non-protein coding)', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18599789, end_position_on_the_genomic_accession=18609874, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100506564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506564, CurrentID=0, Status='live', Symbol='THEGL', Aliases=[], description='theg spermatid protein like', other_designations='testicular haploid expressed gene protein-like|theg spermatid-like protein', map_location='4q12', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=56530575, end_position_on_the_genomic_accession=56626214, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    100506581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506581, CurrentID=0, Status='live', Symbol='C16orf95', Aliases=[], description='chromosome 16 open reading frame 95', other_designations='uncharacterized protein C16orf95', map_location='16q24.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=87302814, end_position_on_the_genomic_accession=87317392, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100506658 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506658, CurrentID=0, Status='live', Symbol='OCLN', Aliases=['BLCPMG', 'PPP1R115', 'PTORCH1'], description='occludin', other_designations='occludin|phosphatase 1, regulatory subunit 115', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69492547, end_position_on_the_genomic_accession=69558104, orientation='plus', exon_count=10, OMIM=[602876], no_hdr0=''),
    100506736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506736, CurrentID=0, Status='live', Symbol='SLFN12L', Aliases=[], description='schlafen family member 12 like', other_designations='schlafen family member 12-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35464254, end_position_on_the_genomic_accession=35537861, orientation='minus', exon_count=11, OMIM=[614956], no_hdr0=''),
    100506742 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100506742, CurrentID=0, Status='live', Symbol='CASP12', Aliases=['CASP-12P1', 'CASP12'], description='caspase 12 (gene/pseudogene)', other_designations='inactive caspase-12|caspase 12 pseudogene 1', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=104885718, end_position_on_the_genomic_accession=104898460, orientation='minus', exon_count=9, OMIM=[608633], no_hdr0=''),
    100507003 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507003, CurrentID=0, Status='live', Symbol='GFY', Aliases=['Goofy'], description='golgi associated olfactory signaling regulator', other_designations='Golgi-associated olfactory signaling regulator|Golgi protein in olfactory neurons|protein Goofy', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=49423747, end_position_on_the_genomic_accession=49428987, orientation='plus', exon_count=5, OMIM=[618696], no_hdr0=''),
    100507027 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507027, CurrentID=0, Status='live', Symbol='MRLN', Aliases=['LINC00948', 'Linc-RAM', 'M1', 'MLN', 'MUSER1'], description='myoregulin', other_designations='myoregulin|Linc-RNA activator of myogenesis|long intergenic non-protein coding RNA 948|muscle enriched RNA 1|muscle specific 1', map_location='10q21.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=59736692, end_position_on_the_genomic_accession=59753455, orientation='minus', exon_count=4, OMIM=[616246], no_hdr0=''),
    100507050 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507050, CurrentID=0, Status='live', Symbol='TPBGL', Aliases=[], description='trophoblast glycoprotein like', other_designations='trophoblast glycoprotein-like', map_location='11q13.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=75240774, end_position_on_the_genomic_accession=75243704, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100507055 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507055, CurrentID=0, Status='live', Symbol='LRCOL1', Aliases=[], description='leucine rich colipase like 1', other_designations='leucine-rich colipase-like protein 1', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132603151, end_position_on_the_genomic_accession=132610582, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100507096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507096, CurrentID=0, Status='live', Symbol='GIMD1', Aliases=[], description='GIMAP family P-loop NTPase domain containing 1', other_designations='GTPase IMAP family member GIMD1|GIMAP family P-loop NTPase domain-containing protein 1', map_location='4q24', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=106357392, end_position_on_the_genomic_accession=106368778, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100507170 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507170, CurrentID=0, Status='live', Symbol='CT47A12', Aliases=['CT47', 'CT47.12'], description='cancer/testis antigen family 47 member A12', other_designations='cancer/testis antigen 47A|cancer/testis CT47 family, member 12|cancer/testis antigen 47|cancer/testis antigen 47A family member', map_location='Xq24', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=120877490, end_position_on_the_genomic_accession=120932399, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100507203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507203, CurrentID=0, Status='live', Symbol='SMLR1', Aliases=[], description='small leucine rich protein 1', other_designations='small leucine-rich protein 1', map_location='6q23.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=130827406, end_position_on_the_genomic_accession=130837135, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100507221 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507221, CurrentID=0, Status='live', Symbol='LOC100507221', Aliases=[], description='uncharacterized LOC100507221', other_designations='uncharacterized protein LOC100507221', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=32264029, end_position_on_the_genomic_accession=32280475, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100507249 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507249, CurrentID=0, Status='live', Symbol='C8orf17', Aliases=['MOST-1', 'MOST1'], description='chromosome 8 putative open reading frame 17', other_designations='MOLT-4 T-cell lymphoblastic leukemia sequence tag-1|MOLT-4 sequence tag-1', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[616992], no_hdr0=''),
    100507290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507290, CurrentID=0, Status='live', Symbol='ZNF865', Aliases=[], description='zinc finger protein 865', other_designations='zinc finger protein 865', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55605647, end_position_on_the_genomic_accession=55617269, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100507341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507341, CurrentID=0, Status='live', Symbol='SMIM18', Aliases=[], description='small integral membrane protein 18', other_designations='small integral membrane protein 18', map_location='8p12', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=30637771, end_position_on_the_genomic_accession=30646064, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100507421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507421, CurrentID=0, Status='live', Symbol='TMEM178B', Aliases=[], description='transmembrane protein 178B', other_designations='transmembrane protein 178B', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=141073402, end_position_on_the_genomic_accession=141511338, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100507436 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507436, CurrentID=0, Status='live', Symbol='MICA', Aliases=['MIC-A', 'PERB11.1'], description='MHC class I polypeptide-related sequence A', other_designations='MHC class I polypeptide-related sequence A|HLA class I antigen|MHC class I chain-related protein A|MHC class I related chain A|MHC class I related sequence A|major histocompatibility complex class I chain-related protein A|stress inducible class I homolog|truncated MHC class I polypeptide-related sequence A|truncated MICA', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31400711, end_position_on_the_genomic_accession=31415315, orientation='plus', exon_count=7, OMIM=[600169], no_hdr0=''),
    100507527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507527, CurrentID=0, Status='live', Symbol='THEG5', Aliases=[], description='testis highly expressed protein 5', other_designations='uncharacterized protein LOC100507527', map_location='19q12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=31588174, end_position_on_the_genomic_accession=31593785, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100507537 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507537, CurrentID=0, Status='live', Symbol='STRIT1', Aliases=['DWORF'], description='small transmembrane regulator of ion transport 1', other_designations='sarcoplasmic/endoplasmic reticulum calcium ATPase regulator DWORF|SERCA regulator DWORF|Sarcoplasmic/endoplasmic reticulum calcium ATPase regulator DWORF', map_location='3q25.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=155290227, end_position_on_the_genomic_accession=155293683, orientation='minus', exon_count=3, OMIM=[616891], no_hdr0=''),
    100507588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507588, CurrentID=0, Status='live', Symbol='TGFBR3L', Aliases=['GEMP', 'TGFR-3L'], description='transforming growth factor beta receptor 3 like', other_designations='transforming growth factor-beta receptor type 3-like protein|TGF-beta receptor type III-like protein|TGF-beta receptor type-3-like protein|gonadotroph enriched membrane protein|transforming growth factor, beta receptor III-like|transforming growth factor-beta receptor type III-like protein', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=7914830, end_position_on_the_genomic_accession=7919097, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100507607 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507607, CurrentID=0, Status='live', Symbol='NPIPB9', Aliases=[], description='nuclear pore complex interacting protein family member B9', other_designations='nuclear pore complex-interacting protein family member B9|Nuclear pore complex-interacting protein family member B9', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=28735500, end_position_on_the_genomic_accession=28772909, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    100507608 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507608, CurrentID=0, Status='live', Symbol='KRTAP9-6', Aliases=['KAP9.6', 'KRTAP9.6', 'KRTAP9L2'], description='keratin associated protein 9-6', other_designations='keratin-associated protein 9-6|keratin associated protein 9-like 2|putative keratin-associated protein 9-2-like 2', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41265378, end_position_on_the_genomic_accession=41265860, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100507650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507650, CurrentID=0, Status='live', Symbol='RNF212B', Aliases=['C14orf164'], description='ring finger protein 212B', other_designations='RING finger protein 212B|RING finger protein C14orf164-like', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23185284, end_position_on_the_genomic_accession=23273477, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    100507679 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507679, CurrentID=0, Status='live', Symbol='MUC22', Aliases=['PBMUCL1'], description='mucin 22', other_designations='mucin-22|panbronchiolitis-related mucin-like protein 1', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31005952, end_position_on_the_genomic_accession=31035402, orientation='plus', exon_count=5, OMIM=[613917], no_hdr0=''),
    100507703 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507703, CurrentID=0, Status='live', Symbol='LOC100507703', Aliases=[], description='HLA class I histocompatibility antigen, A-69 alpha chain-like', other_designations='MHC class I antigen|major histocompatibility complex, class I, A', map_location='', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100507747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100507747, CurrentID=0, Status='live', Symbol='C13orf46', Aliases=[], description='chromosome 13 open reading frame 46', other_designations='uncharacterized protein C13orf46', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113953705, end_position_on_the_genomic_accession=113975026, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    100509620 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100509620, CurrentID=0, Status='live', Symbol='LOC100509620', Aliases=[], description='putative aquaporin-7-like protein 3', other_designations='putative aquaporin-7-like protein 3', map_location='2q11.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=94587227, end_position_on_the_genomic_accession=94605174, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100526664 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526664, CurrentID=0, Status='live', Symbol='LY75-CD302', Aliases=['CD205', 'CLEC13B', 'DEC-205', 'LY75', 'Ly-75', 'gp200-MR6'], description='LY75-CD302 readthrough', other_designations='LY75-CD302 fusion protein|C-type lectin domain family 13 member B|DEC-205/DCL-1 fusion|Lymphocyte antigen 75', map_location='2q24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=159768628, end_position_on_the_genomic_accession=159904756, orientation='minus', exon_count=39, OMIM=[], no_hdr0=''),
    100526693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526693, CurrentID=0, Status='live', Symbol='ARPC4-TTLL3', Aliases=['ARC20', 'ARPC4', 'p20-ARC'], description='ARPC4-TTLL3 readthrough', other_designations='ARPC4-TTLL3 fusion protein|ARPC4-TTLL3 read-through transcript|Actin-related protein 2/3 complex subunit 4|Arp2/3 complex 20 kDa subunit', map_location='3p25.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=9792548, end_position_on_the_genomic_accession=9836356, orientation='plus', exon_count=12, OMIM=[], no_hdr0=''),
    100526694 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526694, CurrentID=0, Status='live', Symbol='MSANTD3-TMEFF1', Aliases=['C9orf2', 'C9orf3-TMEFF1', 'C9orf30-TMEFF1', 'H7365', 'TMEFF1', 'TR-1'], description='MSANTD3-TMEFF1 readthrough', other_designations='MSANTD3-TMEFF1 fusion protein|C9orf30-TMEFF1 readthrough|Tomoregulin-1|Transmembrane protein with EGF-like and one follistatin-like domain', map_location='9q31.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=100441906, end_position_on_the_genomic_accession=100577636, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100526737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526737, CurrentID=0, Status='live', Symbol='RBM14-RBM4', Aliases=['COAZ', 'PSP2', 'RBM14', 'SIP'], description='RBM14-RBM4 readthrough', other_designations='RBM14-RBM4 protein|Paraspeckle protein 2|RBM14/RBM4 fusion|RNA-binding motif protein 14|RNA-binding protein 14|RRM-containing coactivator activator/modulator|SYT-interacting protein|Synaptotagmin-interacting protein|transcriptional coactivator CoAZ', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=66616630, end_position_on_the_genomic_accession=66646468, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100526739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526739, CurrentID=0, Status='live', Symbol='CENPS-CORT', Aliases=['APITD1', 'APITD1-CORT', 'CENP-S', 'CENPS', 'FAAP16', 'MHF1'], description='CENPS-CORT readthrough', other_designations='APITD1-CORT protein|APITD1-CORT readthrough|Apoptosis-inducing TAF9-like domain-containing protein 1|Centromere protein S|FANCM-associated histone fold protein 1|FANCM-interacting histone fold protein 1|Fanconi anemia-associated polypeptide of 16 kDa', map_location='1p36.22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=10430433, end_position_on_the_genomic_accession=10452153, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100526740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526740, CurrentID=0, Status='live', Symbol='ATP5MF-PTCD1', Aliases=['ATP5J2-PTCD1'], description='ATP5MF-PTCD1 readthrough', other_designations='ATP5J2-PTCD1 fusion protein|ATP5J2-PTCD1 read-through transcript|ATP5J2-PTCD1 readthrough', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99416739, end_position_on_the_genomic_accession=99466167, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    100526760 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526760, CurrentID=0, Status='live', Symbol='ABHD14A-ACY1', Aliases=[], description='ABHD14A-ACY1 readthrough', other_designations='ABHD14A-ACY1 readthrough (NMD candidate)|ABHD14A-ACY1 readthrough (non-protein coding)', map_location='3p21.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=51975064, end_position_on_the_genomic_accession=51989197, orientation='plus', exon_count=17, OMIM=[], no_hdr0=''),
    100526761 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526761, CurrentID=0, Status='live', Symbol='CCDC169-SOHLH2', Aliases=['C13orf38-SOHLH2', 'SOHLH2', 'TEB1'], description='CCDC169-SOHLH2 readthrough', other_designations='CCDC169-SOHLH2 protein|C13orf38-SOHLH2 readthrough|Spermatogenesis- and oogenesis-specific basic helix-loop-helix-containing protein 2', map_location='13q13.3', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=36168217, end_position_on_the_genomic_accession=36297814, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    100526767 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526767, CurrentID=0, Status='live', Symbol='RNF103-CHMP3', Aliases=['CGI149', 'CHMP3', 'NEDF', 'RNF103-VPS24', 'VPS24', 'hVps24'], description='RNF103-CHMP3 readthrough', other_designations='RNF103-CHMP3 protein|Charged multivesicular body protein 3|Chromatin-modifying protein 3|Neuroendocrine differentiation factor|RNF103-CHMP3 read-through|RNF103-VPS24 readthrough|Vacuolar protein sorting-associated protein 24', map_location='2p11.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=86503430, end_position_on_the_genomic_accession=86721122, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100526771 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526771, CurrentID=0, Status='live', Symbol='SMIM35', Aliases=['TMPRSS4-AS1'], description='small integral membrane protein 35', other_designations='small integral membrane protein 35|TMPRSS4 antisense RNA 1 (non-protein coding)', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=118000027, end_position_on_the_genomic_accession=118089911, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100526772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526772, CurrentID=0, Status='live', Symbol='STIMATE-MUSTN1', Aliases=['TMEM110-MUSTN1'], description='STIMATE-MUSTN1 readthrough', other_designations='TMEM110-MUSTN1 fusion protein|TMEM110-MUSTN1 read-through transcript|TMEM110-MUSTN1 readthrough', map_location='3p21.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=52833121, end_position_on_the_genomic_accession=52897548, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100526773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526773, CurrentID=0, Status='live', Symbol='EPPIN-WFDC6', Aliases=['SPINLW1-WFDC6'], description='EPPIN-WFDC6 readthrough', other_designations='SPINLW1-WFDC6 fusion protein|SPINLW1-WFDC6 read-through transcript|SPINLW1-WFDC6 readthrough', map_location='20q13.12', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=45536280, end_position_on_the_genomic_accession=45547401, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100526783 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526783, CurrentID=0, Status='live', Symbol='ARPIN-AP3S2', Aliases=['ARPIN', 'C15orf38', 'C15orf38-AP3S2'], description='ARPIN-AP3S2 readthrough', other_designations='C15orf38-AP3S2 fusion protein|Arp2/3 inhibition protein|C15orf38-AP3S2 readthrough', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=89830599, end_position_on_the_genomic_accession=89912952, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100526794 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526794, CurrentID=0, Status='live', Symbol='NT5C1B-RDH14', Aliases=['AIRP', 'NT5C1B', 'cN-IB', 'cN1B'], description='NT5C1B-RDH14 readthrough', other_designations="NT5C1B-RDH14 protein|Cytosolic 5'-nucleotidase 1B|Cytosolic 5'-nucleotidase IB|NT5C1B-RDH14 read-through transcript", map_location='2p24.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=18554723, end_position_on_the_genomic_accession=18589569, orientation='minus', exon_count=11, OMIM=[], no_hdr0=''),
    100526832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526832, CurrentID=0, Status='live', Symbol='PHOSPHO2-KLHL23', Aliases=[], description='PHOSPHO2-KLHL23 readthrough', other_designations='kelch-like protein 23', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=169694469, end_position_on_the_genomic_accession=169751878, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100526835 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526835, CurrentID=0, Status='live', Symbol='FPGT-TNNI3K', Aliases=['CARK', 'TNNI3K'], description='FPGT-TNNI3K readthrough', other_designations='FPGT-TNNI3K fusion protein|Cardiac ankyrin repeat kinase|Cardiac troponin I-interacting kinase|Serine/threonine-protein kinase TNNI3K|TNNI3-interacting kinase', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74198242, end_position_on_the_genomic_accession=74544428, orientation='plus', exon_count=28, OMIM=[], no_hdr0=''),
    100526842 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100526842, CurrentID=0, Status='live', Symbol='RPL17-C18orf32', Aliases=['PD-1', 'RPL17'], description='RPL17-C18orf32 readthrough', other_designations='RPL17-C18orf32 protein|60S ribosomal protein L17|60S ribosomal protein L23|Large ribosomal subunit protein uL22', map_location='18q21.1', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=49481178, end_position_on_the_genomic_accession=49492465, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100527943 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100527943, CurrentID=0, Status='live', Symbol='TGIF2-RAB5IF', Aliases=['TGIF2-C20orf24'], description='TGIF2-RAB5IF readthrough', other_designations='TGIF2-C20orf24 protein|TGIF2-C20orf24 readthrough', map_location='20q11.23', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=36574515, end_position_on_the_genomic_accession=36612557, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100527949 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100527949, CurrentID=0, Status='live', Symbol='GIMAP1-GIMAP5', Aliases=[], description='GIMAP1-GIMAP5 readthrough', other_designations='GIMAP1-GIMAP5 protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150716613, end_position_on_the_genomic_accession=150743646, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100527963 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100527963, CurrentID=0, Status='live', Symbol='PMF1-BGLAP', Aliases=['PMF-1', 'PMF1'], description='PMF1-BGLAP readthrough', other_designations='PMF1-BGLAP protein|polyamine-modulated factor 1', map_location='1q22', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=156212988, end_position_on_the_genomic_accession=156243332, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100527978 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100527978, CurrentID=0, Status='live', Symbol='TLCD4-RWDD3', Aliases=['TMEM56-RWDD3'], description='TLCD4-RWDD3 readthrough', other_designations='TMEM56-RWDD3 protein|TMEM56-RWDD3 readthrough', map_location='1p21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=95117923, end_position_on_the_genomic_accession=95244955, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    100528017 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528017, CurrentID=0, Status='live', Symbol='SAA2-SAA4', Aliases=[], description='SAA2-SAA4 readthrough', other_designations='SAA2-SAA4 protein|SAA2-SAA4 read-through transcript', map_location='11p15.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=18231355, end_position_on_the_genomic_accession=18248668, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100528020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528020, CurrentID=0, Status='live', Symbol='FAM187A', Aliases=[], description='family with sequence similarity 187 member A', other_designations='Ig-like V-type domain-containing protein FAM187A', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44903433, end_position_on_the_genomic_accession=44905390, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    100528021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528021, CurrentID=0, Status='live', Symbol='ST20-MTHFS', Aliases=['MTHFS'], description='ST20-MTHFS readthrough', other_designations='ST20-MTHFS protein|5,10-methenyl-tetrahydrofolate synthetase|5-formyltetrahydrofolate cyclo-ligase|Methenyl-THF synthetase', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=79843547, end_position_on_the_genomic_accession=79923092, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100528030 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528030, CurrentID=0, Status='live', Symbol='POC1B-GALNT4', Aliases=['GALNT4', 'GalNAc-T4'], description='POC1B-GALNT4 readthrough', other_designations='POC1B-GALNT4 protein|POC1B-GALNT4 fusion|Polypeptide GalNAc transferase 4|Polypeptide N-acetylgalactosaminyltransferase 4|Protein-UDP acetylgalactosaminyltransferase 4|UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 4|pp-GaNTase 4', map_location='12q21.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=89519412, end_position_on_the_genomic_accession=89526262, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100528032 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528032, CurrentID=0, Status='live', Symbol='KLRC4-KLRK1', Aliases=[], description='KLRC4-KLRK1 readthrough', other_designations='NKG2-D type II integral membrane protein|NK cell receptor D|NKG2-D-activating NK receptor|killer cell lectin-like receptor subfamily K member 1', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10372353, end_position_on_the_genomic_accession=10410146, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    100528062 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528062, CurrentID=0, Status='live', Symbol='ARMCX5-GPRASP2', Aliases=['ARMCX5-GPRASP2-BHLHB9-LINC00630', 'bHLHb9', 'p60TRP'], description='ARMCX5-GPRASP2 readthrough', other_designations='G-protein coupled receptor-associated sorting protein 2|protein BHLHb9|ARMCX5-GPRASP2-BHLHB9-LINC00630 readthrough|transcription regulator of 60 kDa', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102599348, end_position_on_the_genomic_accession=102908064, orientation='plus', exon_count=32, OMIM=[], no_hdr0=''),
    100528064 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100528064, CurrentID=0, Status='live', Symbol='NEDD8-MDP1', Aliases=[], description='NEDD8-MDP1 readthrough', other_designations='NEDD8-MDP1 protein|NEDD8-MDP1 read-through transcript', map_location='14q12', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=24213943, end_position_on_the_genomic_accession=24232367, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100529063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529063, CurrentID=0, Status='live', Symbol='BCL2L2-PABPN1', Aliases=[], description='BCL2L2-PABPN1 readthrough', other_designations='BCL2L2-PABPN1 protein', map_location='14q11.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=23306833, end_position_on_the_genomic_accession=23326163, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100529097 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529097, CurrentID=0, Status='live', Symbol='RPL36A-HNRNPH2', Aliases=[], description='RPL36A-HNRNPH2 readthrough', other_designations='RPL36A-HNRNPH2 protein', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=101391011, end_position_on_the_genomic_accession=101414133, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100529141 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529141, CurrentID=0, Status='live', Symbol='LGTN', Aliases=[], description='ligatin', other_designations='', map_location='', chromosome='', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[151625], no_hdr0=''),
    100529144 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529144, CurrentID=0, Status='live', Symbol='CORO7-PAM16', Aliases=['CORO7', 'Coronin-7', 'Crn7'], description='CORO7-PAM16 readthrough', other_designations='CORO7-PAM16 protein|70 kDa WD repeat tumor rejection antigen homolog', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4340251, end_position_on_the_genomic_accession=4416596, orientation='minus', exon_count=31, OMIM=[], no_hdr0=''),
    100529215 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529215, CurrentID=0, Status='live', Symbol='ZNF559-ZNF177', Aliases=[], description='ZNF559-ZNF177 readthrough', other_designations='zinc finger protein 177', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=9324179, end_position_on_the_genomic_accession=9382617, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    100529239 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529239, CurrentID=0, Status='live', Symbol='RPS10-NUDT3', Aliases=[], description='RPS10-NUDT3 readthrough', other_designations='RPS10-NUDT3 protein|ribosomal protein S10 homologue', map_location='6p21.31', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=34287194, end_position_on_the_genomic_accession=34426069, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    100529240 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529240, CurrentID=0, Status='live', Symbol='ZNF816-ZNF321P', Aliases=['ZNF816-ZNF321'], description='ZNF816-ZNF321P readthrough', other_designations='ZNF816-ZNF321 protein|ZNF816-ZNF321 read-through transcript|ZNF816-ZNF321 readthrough', map_location='19q13.41', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=52927135, end_position_on_the_genomic_accession=52962881, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100529241 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529241, CurrentID=0, Status='live', Symbol='HSPE1-MOB4', Aliases=['HSPE1-PHOCN'], description='HSPE1-MOB4 readthrough', other_designations='HSPE1-MOB4 protein', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=197500379, end_position_on_the_genomic_accession=197553699, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100529251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529251, CurrentID=0, Status='live', Symbol='CKLF-CMTM1', Aliases=[], description='CKLF-CMTM1 readthrough', other_designations='CKLF-CMTM1 protein', map_location='16q21', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66552576, end_position_on_the_genomic_accession=66579135, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100529257 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529257, CurrentID=0, Status='live', Symbol='SYNJ2BP-COX16', Aliases=[], description='SYNJ2BP-COX16 readthrough', other_designations='SYNJ2BP-COX16 protein', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=70325081, end_position_on_the_genomic_accession=70417090, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100529261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100529261, CurrentID=0, Status='live', Symbol='CHURC1-FNTB', Aliases=['FNTB', 'FTase-beta'], description='CHURC1-FNTB readthrough', other_designations='CHURC1-FNTB protein|CAAX farnesyltransferase subunit beta|Protein farnesyltransferase subunit beta|Ras proteins prenyltransferase subunit beta', map_location='14q23.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=64914361, end_position_on_the_genomic_accession=65062655, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    100532726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100532726, CurrentID=0, Status='live', Symbol='NDUFC2-KCTD14', Aliases=[], description='NDUFC2-KCTD14 readthrough', other_designations='NADH dehydrogenase [ubiquinone] 1 subunit C2, isoform 2|NADH dehydrogenase [ubiquinone] 1 subunit C2|NDUFC2-KCTD14 readthrough transcript protein', map_location='11q14.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=78015715, end_position_on_the_genomic_accession=78079862, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100532731 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100532731, CurrentID=0, Status='live', Symbol='COMMD3-BMI1', Aliases=['BMI1', 'PCGF4', 'RNF51'], description='COMMD3-BMI1 readthrough', other_designations='COMMD3-BMI1 read-through protein|Polycomb complex protein BMI-1|Polycomb group RING finger protein 4|RING finger protein 51', map_location='10p12.2', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=22316388, end_position_on_the_genomic_accession=22331484, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    100532736 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100532736, CurrentID=0, Status='live', Symbol='MICOS10-NBL1', Aliases=['C1orf151-NBL1', 'DAN', 'DAND1', 'MINOS1-NBL1', 'NBL1'], description='MICOS10-NBL1 readthrough', other_designations='C1orf151-NBL1 read-through protein|MINOS1-NBL1 readthrough|Neuroblastoma suppressor of tumorigenicity 1|Protein N03|Zinc finger protein DAN', map_location='1p36.13', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=19596979, end_position_on_the_genomic_accession=19658452, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100533105 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533105, CurrentID=0, Status='live', Symbol='C8orf44-SGK3', Aliases=[], description='C8orf44-SGK3 readthrough', other_designations='serine/threonine-protein kinase Sgk3|cytokine-independent survival kinase|serum/glucocorticoid-regulated kinase 3', map_location='8q13.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=66667596, end_position_on_the_genomic_accession=66862022, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    100533106 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533106, CurrentID=0, Status='live', Symbol='ZHX1-C8orf76', Aliases=[], description='ZHX1-C8orf76 readthrough', other_designations='zinc fingers and homeoboxes protein 1, isoform 2|ZHX1-C8orf76 readthrough transcript protein|zinc fingers and homeoboxes protein 1', map_location='8q24.13', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=123226191, end_position_on_the_genomic_accession=123274286, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100533177 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533177, CurrentID=0, Status='live', Symbol='KRTAP29-1', Aliases=['KAP29.2'], description='keratin associated like protein 29-1', other_designations='keratin-associated protein 29-1|Keratin-associated protein 29.2|keratin associated protein 29-1', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=41301826, end_position_on_the_genomic_accession=41302851, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100533181 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533181, CurrentID=0, Status='live', Symbol='FXYD6-FXYD2', Aliases=['FXYD6'], description='FXYD6-FXYD2 readthrough', other_designations='FXYD6-FXYD2 read-through protein|FXYD domain-containing ion transport regulator 6|Phosphohippolin', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=117820057, end_position_on_the_genomic_accession=117876658, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    100533183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533183, CurrentID=0, Status='live', Symbol='ZNF664-RFLNA', Aliases=[], description='ZNF664-RFLNA readthrough', other_designations='refilin-A|ZNF664-FAM101A readthrough|filamin-interacting protein FAM101A|regulator of filamin protein A', map_location='12q24.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=123973215, end_position_on_the_genomic_accession=124316024, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100533467 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533467, CurrentID=0, Status='live', Symbol='BIVM-ERCC5', Aliases=['ERCC5-202'], description='BIVM-ERCC5 readthrough', other_designations='BIVM-ERCC5 protein', map_location='13q33.1', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=102807146, end_position_on_the_genomic_accession=102875995, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    100533496 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533496, CurrentID=0, Status='live', Symbol='TVP23C-CDRT4', Aliases=['FAM18B2', 'FAM18B2-CDRT4', 'TVP23C'], description='TVP23C-CDRT4 readthrough', other_designations='uncharacterized protein LOC100533496|FAM18B2-CDRT4 readthrough|Golgi apparatus membrane protein TVP23 homolog C', map_location='17p12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=15436015, end_position_on_the_genomic_accession=15563483, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100533952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533952, CurrentID=0, Status='live', Symbol='RBAK-RBAKDN', Aliases=['RBAK', 'RBAK-LOC389458', 'ZNF769', 'hRBaK'], description='RBAK-RBAKDN readthrough', other_designations='RBAK-RBAKDN readthrough|RB-associated KRAB repressor|RB-associated KRAB zinc finger protein|RBAK-LOC389458 readthrough|Zinc finger protein 769', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5045860, end_position_on_the_genomic_accession=5073221, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    100533997 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100533997, CurrentID=0, Status='live', Symbol='MAGEA10-MAGEA5', Aliases=['CT1.5'], description='MAGEA10-MAGEA5 readthrough', other_designations='melanoma-associated antigen 5|MAGE-5 antigen|cancer/testis antigen 1.5', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152114049, end_position_on_the_genomic_accession=152138577, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    100534012 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100534012, CurrentID=0, Status='live', Symbol='TNFAIP8L2-SCNM1', Aliases=['SCNM1'], description='TNFAIP8L2-SCNM1 readthrough', other_designations='TNFAIP8L2-SCNM1 protein|Sodium channel modifier 1', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=151156649, end_position_on_the_genomic_accession=151170296, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100534592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100534592, CurrentID=0, Status='live', Symbol='URGCP-MRPS24', Aliases=[], description='URGCP-MRPS24 readthrough', other_designations='uncharacterized protein LOC100534592', map_location='7p13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=43866558, end_position_on_the_genomic_accession=43906596, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100534599 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100534599, CurrentID=0, Status='live', Symbol='ISY1-RAB43', Aliases=['ISY1'], description='ISY1-RAB43 readthrough', other_designations='ISY1-RAB43 protein|Pre-mRNA-splicing factor ISY1 homolog', map_location='3q21.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=129087572, end_position_on_the_genomic_accession=129161063, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    100631383 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100631383, CurrentID=0, Status='live', Symbol='FAM47E-STBD1', Aliases=['FAM47E'], description='FAM47E-STBD1 readthrough', other_designations='Protein FAM47E-like|Protein FAM47E', map_location='4q21.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=76251721, end_position_on_the_genomic_accession=76311130, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    100652748 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100652748, CurrentID=0, Status='live', Symbol='TIMM23B', Aliases=[], description='translocase of inner mitochondrial membrane 23 homolog B', other_designations='mitochondrial import inner membrane translocase subunit Tim23B|putative mitochondrial import inner membrane translocase subunit Tim23B', map_location='10q11.23', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=49942053, end_position_on_the_genomic_accession=49974850, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    100652777 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100652777, CurrentID=0, Status='live', Symbol='LOC100652777', Aliases=[], description='group 10 secretory phospholipase A2-like', other_designations='group 10 secretory phospholipase A2-like', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14709055, end_position_on_the_genomic_accession=14733780, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    100652824 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100652824, CurrentID=0, Status='live', Symbol='KIAA2012', Aliases=[], description='KIAA2012', other_designations='uncharacterized protein KIAA2012', map_location='2q33.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=202073255, end_position_on_the_genomic_accession=202205188, orientation='plus', exon_count=26, OMIM=[], no_hdr0=''),
    100653049 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100653049, CurrentID=0, Status='live', Symbol='LOC100653049', Aliases=[], description='keratin, type I cuticular Ha4', other_designations='keratin, type I cuticular Ha4', map_location='', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100653133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100653133, CurrentID=0, Status='live', Symbol='LOC100653133', Aliases=[], description='golgin subfamily A member 6-like protein 1', other_designations='golgin subfamily A member 6-like protein 1', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32489200, end_position_on_the_genomic_accession=32494945, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100653515 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100653515, CurrentID=0, Status='live', Symbol='CEP295NL', Aliases=['DDC8', 'KIAA1731NL'], description='CEP295 N-terminal like', other_designations='protein DDC8 homolog|KIAA1731 N-terminal like protein|differential display clone 8', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=78890579, end_position_on_the_genomic_accession=78903201, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100820829 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100820829, CurrentID=0, Status='live', Symbol='MYZAP', Aliases=['GCOM1', 'Gup', 'MYOZAP'], description='myocardial zonula adherens protein', other_designations='myocardial zonula adherens protein|GRINL1A complex locus upstream|GRINL1A upstream protein|myocardial intercalated disc protein|myocardium-enriched ZO1-associated protein|myocardium-enriched zonula adherens protein|myocardium-enriched zonula occludens-1-associated protein', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=57591904, end_position_on_the_genomic_accession=57685364, orientation='plus', exon_count=13, OMIM=[614071], no_hdr0=''),
    100861412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100861412, CurrentID=0, Status='live', Symbol='FSBP', Aliases=[], description='fibrinogen silencer binding protein', other_designations='fibrinogen silencer-binding protein', map_location='8q22.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=94427716, end_position_on_the_genomic_accession=94436944, orientation='minus', exon_count=2, OMIM=[616306], no_hdr0=''),
    100861540 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100861540, CurrentID=0, Status='live', Symbol='CYP3A7-CYP3A51P', Aliases=['CYP3A7', 'CYP3A7-3AP1', 'CYP3A7-CYP3AP1', 'CYP3A7.1L', 'CYPIIIA7'], description='CYP3A7-CYP3A51P readthrough', other_designations='CYP3A7-CYP3A51P protein|CYP3A7-CYP3AP1 readthrough|Cytochrome P450 3A7|Cytochrome P450-HFLA', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=99684677, end_position_on_the_genomic_accession=99735196, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    100862671 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100862671, CurrentID=0, Status='live', Symbol='TMEM265', Aliases=['IFITMD8'], description='transmembrane protein 265', other_designations='transmembrane protein 265', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30740642, end_position_on_the_genomic_accession=30745196, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    100874261 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100874261, CurrentID=0, Status='live', Symbol='CCDC200', Aliases=['LINC00854', 'TMEM106A-AS1'], description='coiled-coil domain containing 200', other_designations='coiled-coil domain-containing protein 200|TMEM106A antisense RNA 1 (non-protein coding)|TMEM106A antisense RNA 1 (tail to tail)|long intergenic non-protein coding RNA 854', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43221417, end_position_on_the_genomic_accession=43231269, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    100885848 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100885848, CurrentID=0, Status='live', Symbol='PTGES3L', Aliases=[], description='prostaglandin E synthase 3 like', other_designations='putative protein PTGES3L|prostaglandin E synthase 3 (cytosolic)-like', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42968103, end_position_on_the_genomic_accession=42980080, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    100885850 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100885850, CurrentID=0, Status='live', Symbol='PTGES3L-AARSD1', Aliases=[], description='PTGES3L-AARSD1 readthrough', other_designations='PTGES3L-AARSD1 protein', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42950526, end_position_on_the_genomic_accession=42980528, orientation='minus', exon_count=18, OMIM=[], no_hdr0=''),
    100913187 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100913187, CurrentID=0, Status='live', Symbol='APOBEC3A_B', Aliases=['A3A', 'APOBEC3A'], description='APOBEC3A and APOBEC3B deletion hybrid', other_designations='probable DNA dC->dU-editing enzyme APOBEC-3A|DNA dC->dU-editing enzyme APOBEC-3A|Phorbolin-1', map_location='22q13 alternate reference locus', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100996331 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996331, CurrentID=0, Status='live', Symbol='POTEB', Aliases=['A26B1', 'CT104.5', 'POTE-15', 'POTE152', 'POTEB'], description='POTE ankyrin domain family member B', other_designations='POTE ankyrin domain family member B|ANKRD26-like family B, member 1|POTE ankyrin domain family member B2|cancer/testis antigen family 104, member 5|prostate, ovary, testis-expressed protein on chromosome 15|protein expressed in prostate, ovary, testis, and placenta 15', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=21846329, end_position_on_the_genomic_accession=21877735, orientation='minus', exon_count=12, OMIM=[608912], no_hdr0=''),
    100996401 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996401, CurrentID=0, Status='live', Symbol='LOC100996401', Aliases=[], description='transmembrane protein 191A', other_designations='', map_location='22q11.21', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100996492 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996492, CurrentID=0, Status='live', Symbol='CTXND1', Aliases=['LINC01314'], description='cortexin domain containing 1', other_designations='cortexin domain-containing 1|long intergenic non-protein coding RNA 1314', map_location='15q25.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=80195481, end_position_on_the_genomic_accession=80252213, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    100996521 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996521, CurrentID=0, Status='live', Symbol='CTXND2', Aliases=[], description='cortexin domain containing 2', other_designations='cortexin domain containing 2', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=150887253, end_position_on_the_genomic_accession=150913292, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100996598 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996598, CurrentID=0, Status='live', Symbol='LOC100996598', Aliases=[], description='uncharacterized LOC100996598', other_designations='uncharacterized protein LOC100996598', map_location='22q13.2', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=41369082, end_position_on_the_genomic_accession=41370396, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    100996631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996631, CurrentID=0, Status='live', Symbol='TCP11X1', Aliases=[], description='t-complex 11 family, X-linked 1', other_designations='T-complex protein 11 X-linked protein 1|T-complex protein 11 homolog', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102215301, end_position_on_the_genomic_accession=102226795, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    100996648 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996648, CurrentID=0, Status='live', Symbol='TCP11X2', Aliases=[], description='t-complex 11 family, X-linked 2', other_designations='T-complex protein 11 homolog', map_location='Xq22.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=102460319, end_position_on_the_genomic_accession=102471812, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    100996693 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996693, CurrentID=0, Status='live', Symbol='SPEGNB', Aliases=[], description='SPEG neighbor', other_designations='SPEG neighbor protein', map_location='2q35', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=219496131, end_position_on_the_genomic_accession=219498287, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100996701 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996701, CurrentID=0, Status='live', Symbol='LOC100996701', Aliases=[], description='uncharacterized LOC100996701', other_designations='uncharacterized protein LOC100996701', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=131663774, end_position_on_the_genomic_accession=131665416, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    100996709 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996709, CurrentID=0, Status='live', Symbol='LOC100996709', Aliases=[], description='ADP-ribosylation factor-like protein 17', other_designations='ADP-ribosylation factor-like protein 17', map_location='', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100996717 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996717, CurrentID=0, Status='live', Symbol='NOTCH2NLC', Aliases=['ETM6', 'N2N', 'NIID', 'NOTCH2NL', 'NOTCH2NLA'], description='notch 2 N-terminal like C', other_designations='notch homolog 2 N-terminal-like protein C|Notch homolog 2 N-terminal-like protein A', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149390621, end_position_on_the_genomic_accession=149471833, orientation='plus', exon_count=5, OMIM=[618025], no_hdr0=''),
    100996746 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996746, CurrentID=0, Status='live', Symbol='SPDYE11', Aliases=[], description='speedy/RINGO cell cycle regulator family member E11', other_designations='putative speedy protein E11', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=73047862, end_position_on_the_genomic_accession=73057911, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    100996750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996750, CurrentID=0, Status='live', Symbol='LOC100996750', Aliases=['KAP4.7', 'KRTAP4-7', 'KRTAP4.7'], description='keratin-associated protein 4-7', other_designations='keratin-associated protein 4-7|Keratin-associated protein 4.7|Ultrahigh sulfur keratin-associated protein 4.7', map_location='', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    100996758 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996758, CurrentID=0, Status='live', Symbol='NPY4R2', Aliases=['CH17-360D5.1', 'NPY4-R', 'NPY4R', 'PP1', 'PPYR1'], description='neuropeptide Y receptor Y4-2', other_designations='neuropeptide Y receptor type 4-2|Neuropeptide Y receptor type 4|Neuropeptide Y receptor type 4-2|Pancreatic polypeptide receptor 1|neuropeptide Y receptor Y42', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47913999, end_position_on_the_genomic_accession=47926069, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    100996763 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996763, CurrentID=0, Status='live', Symbol='NOTCH2NLB', Aliases=['N2N', 'NOTCH2NL', 'NOTCH2NLA'], description='notch 2 N-terminal like B', other_designations='notch homolog 2 N-terminal-like protein B|Notch homolog 2 N-terminal-like protein A', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=148595855, end_position_on_the_genomic_accession=148712499, orientation='minus', exon_count=9, OMIM=[618024], no_hdr0=''),
    100996928 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996928, CurrentID=0, Status='live', Symbol='FMC1-LUC7L2', Aliases=['C7orf55', 'C7orf55-LUC7L2', 'FMC1'], description='FMC1-LUC7L2 readthrough', other_designations='C7orf55-LUC7L2 protein|ATP synthase assembly factor FMC1, mitochondrial|C7orf55-LUC7L2 readthrough|Formation of mitochondrial complex V assembly factor 1 homolog|Protein FMC1 homolog', map_location='7q34', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=139341337, end_position_on_the_genomic_accession=139423454, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    100996939 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=100996939, CurrentID=0, Status='live', Symbol='PYURF', Aliases=['PREY'], description='PIGY upstream open reading frame', other_designations='protein preY, mitochondrial|PIGY upstream reading frame protein', map_location='4q22.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=88520998, end_position_on_the_genomic_accession=88523776, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    101059906 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101059906, CurrentID=0, Status='live', Symbol='LOC101059906', Aliases=[], description='collagen alpha-2(IV) chain-like', other_designations='collagen alpha-2(IV) chain-like', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=528484, end_position_on_the_genomic_accession=532263, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    101059915 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101059915, CurrentID=0, Status='live', Symbol='LOC101059915', Aliases=[], description='chromosome X open reading frame 49-like', other_designations='Uncharacterized protein CXorf49-like|uncharacterized protein CXorf49-like', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=71667546, end_position_on_the_genomic_accession=71671527, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    101059918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101059918, CurrentID=0, Status='live', Symbol='GOLGA8R', Aliases=[], description='golgin A8 family member R', other_designations='golgin subfamily A member 8R', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30400562, end_position_on_the_genomic_accession=30414260, orientation='minus', exon_count=19, OMIM=[], no_hdr0=''),
    101059938 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101059938, CurrentID=0, Status='live', Symbol='NPIPA7', Aliases=['NPIPA8'], description='nuclear pore complex interacting protein family member A7', other_designations='nuclear pore complex-interacting protein family member A7|Nuclear pore complex-interacting protein family member A8', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=16376940, end_position_on_the_genomic_accession=16393972, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    101059953 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101059953, CurrentID=0, Status='live', Symbol='NPIPA8', Aliases=['LCR16a9', 'NPIPA7'], description='nuclear pore complex interacting protein family member A8', other_designations='nuclear pore complex-interacting protein family member A8|Nuclear pore complex-interacting protein family member A7|morpheus gene family member 9', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18317919, end_position_on_the_genomic_accession=18335860, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    101060200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060200, CurrentID=0, Status='live', Symbol='ZNF891', Aliases=[], description='zinc finger protein 891', other_designations='zinc finger protein 891|hCG1646157', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=133104779, end_position_on_the_genomic_accession=133130274, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    101060211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060211, CurrentID=0, Status='live', Symbol='CT45A7', Aliases=['CT45-5', 'CT45-6', 'CT45A5', 'CT45A6'], description='cancer/testis antigen family 45 member A7', other_designations='cancer/testis antigen family 45 member A7|Cancer/testis antigen 45-5|Cancer/testis antigen 45-6|Cancer/testis antigen 45A5|Cancer/testis antigen 45A6|Cancer/testis antigen family 45 member A5|Cancer/testis antigen family 45 member A6|cancer/testis antigen 45A7|cancer/testis antigen family 45 member A5-like', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135829229, end_position_on_the_genomic_accession=135837319, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    101060226 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060226, CurrentID=0, Status='live', Symbol='NBPF19', Aliases=[], description='NBPF member 19', other_designations='neuroblastoma breakpoint family member 19', map_location='1q21.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=149475045, end_position_on_the_genomic_accession=149556361, orientation='plus', exon_count=94, OMIM=[614006], no_hdr0=''),
    101060233 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060233, CurrentID=0, Status='live', Symbol='OPN1MW3', Aliases=['GCP', 'GOP', 'OPN1MW'], description='opsin 1, medium wave sensitive 3', other_designations='medium-wave-sensitive opsin 3|green cone photoreceptor pigment|green-sensitive opsin|opsin 1 (cone pigments), medium-wave-sensitive 3|opsin 1 cone pigments medium-wave-sensitive 3', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=154257560, end_position_on_the_genomic_accession=154271090, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    101060301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060301, CurrentID=0, Status='live', Symbol='HNRNPCL4', Aliases=['HNRNPCL3'], description='heterogeneous nuclear ribonucleoprotein C like 4', other_designations='heterogeneous nuclear ribonucleoprotein C-like 4|Heterogeneous nuclear ribonucleoprotein C-like 3', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13163914, end_position_on_the_genomic_accession=13165631, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    101060321 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060321, CurrentID=0, Status='live', Symbol='TBC1D3G', Aliases=['TBC1D3C', 'TBC1D3D'], description='TBC1 domain family member 3G', other_designations='TBC1 domain family member 3G|TBC1 domain family member 3C|TBC1 domain family member-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36322242, end_position_on_the_genomic_accession=36334759, orientation='plus', exon_count=14, OMIM=[610810], no_hdr0=''),
    101060341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060341, CurrentID=0, Status='live', Symbol='LOC101060341', Aliases=[], description='putative uncharacterized protein FLJ44672', other_designations='putative uncharacterized protein FLJ44672|uncharacterized protein LOC101060341', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=55746453, end_position_on_the_genomic_accession=55750715, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    101060351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060351, CurrentID=0, Status='live', Symbol='TBC1D3K', Aliases=[], description='TBC1 domain family member 3K', other_designations='TBC1 domain family member 3K|TBC1 domain family member-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37923805, end_position_on_the_genomic_accession=37935371, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    101060376 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060376, CurrentID=0, Status='live', Symbol='TBC1D3L', Aliases=[], description='TBC1 domain family member 3L', other_designations='TBC1 domain family member 3L', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=37978155, end_position_on_the_genomic_accession=37989060, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    101060389 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060389, CurrentID=0, Status='live', Symbol='TBC1D3D', Aliases=['PRC17', 'TBC1D3', 'TBC1D3A', 'TBC1D3H'], description='TBC1 domain family member 3D', other_designations='TBC1 domain family member 3D|Prostate cancer gene 17 protein|Rab GTPase-activating protein PRC17|TBC1 domain family member 3|TBC1 domain family, member 3H|TRE17 alpha protein', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38004033, end_position_on_the_genomic_accession=38014908, orientation='plus', exon_count=16, OMIM=[610807], no_hdr0=''),
    101060445 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060445, CurrentID=0, Status='live', Symbol='LOC101060445', Aliases=[], description='uncharacterized LOC101060445', other_designations='', map_location='', chromosome='9', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    101060588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060588, CurrentID=0, Status='live', Symbol='LOC101060588', Aliases=[], description='uncharacterized LOC101060588', other_designations='uncharacterized protein LOC101060588', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32484093, end_position_on_the_genomic_accession=32485241, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    101060684 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101060684, CurrentID=0, Status='live', Symbol='NBPF26', Aliases=[], description='NBPF member 26', other_designations='neuroblastoma breakpoint family member 26', map_location='1p11.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=120805556, end_position_on_the_genomic_accession=120842215, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    101180976 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101180976, CurrentID=0, Status='live', Symbol='IFNL4', Aliases=['IFNAN'], description='interferon lambda 4 (gene/pseudogene)', other_designations='interferon lambda-4|IFN-lambda-4|interferon, lambda 4', map_location='19q13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=39246314, end_position_on_the_genomic_accession=39248856, orientation='minus', exon_count=5, OMIM=[615090], no_hdr0=''),
    101241878 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101241878, CurrentID=0, Status='live', Symbol='USP17L23', Aliases=[], description='ubiquitin specific peptidase 17 like family member 23', other_designations='Putative ubiquitin carboxyl-terminal hydrolase 17-like protein 23', map_location='4p16.1', chromosome='4', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    101410538 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101410538, CurrentID=0, Status='live', Symbol='MMP24OS', Aliases=['MMP24-AS1'], description='MMP24 opposite strand', other_designations='protein MMP24OS|MMP24 antisense RNA 1', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35276352, end_position_on_the_genomic_accession=35278122, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    101927345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927345, CurrentID=0, Status='live', Symbol='LOC101927345', Aliases=[], description='putative ankyrin repeat domain-containing protein 20A12 pseudogene', other_designations='putative ankyrin repeat domain-containing protein 20A12 pseudogene', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=9361333, end_position_on_the_genomic_accession=9376651, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    101927367 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927367, CurrentID=0, Status='live', Symbol='SMIM36', Aliases=[], description='small integral membrane protein 36', other_designations='small integral membrane protein 36', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=55449863, end_position_on_the_genomic_accession=55458538, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    101927375 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927375, CurrentID=0, Status='live', Symbol='LOC101927375', Aliases=[], description='ankyrin repeat domain-containing protein 26-like', other_designations='ankyrin repeat domain-containing protein 26-like|uncharacterized protein LOC101927375', map_location='13q12.12', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=24541677, end_position_on_the_genomic_accession=24567324, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    101927423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927423, CurrentID=0, Status='live', Symbol='PANO1', Aliases=['PANO'], description='proapoptotic nucleolar protein 1', other_designations='proapoptotic nucleolar protein 1|pre-mRNA-splicing factor cwc22-like', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=796633, end_position_on_the_genomic_accession=799179, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    101927581 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927581, CurrentID=0, Status='live', Symbol='CCDC182', Aliases=[], description='coiled-coil domain containing 182', other_designations='coiled-coil domain-containing protein 182|coiled-coil domain-containing protein ENSP00000299415', map_location='17q22', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=57744495, end_position_on_the_genomic_accession=57745299, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    101927601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927601, CurrentID=0, Status='live', Symbol='GOLGA6L19', Aliases=[], description='golgin A6 family like 19', other_designations='putative golgin subfamily A member 6-like protein 19', map_location='15q25.2 alternate reference locus', chromosome='15', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    101927685 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927685, CurrentID=0, Status='live', Symbol='HSFX4', Aliases=[], description='heat shock transcription factor family, X-linked member 4', other_designations='heat shock transcription factor, X-linked member 4', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149929573, end_position_on_the_genomic_accession=149931287, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    101927788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101927788, CurrentID=0, Status='live', Symbol='LOC101927788', Aliases=[], description='uncharacterized LOC101927788', other_designations='', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30403791, end_position_on_the_genomic_accession=30433771, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    101928108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928108, CurrentID=0, Status='live', Symbol='LY6L', Aliases=[], description='lymphocyte antigen 6 family member L', other_designations='lymphocyte antigen 6L|lymphocyte antigen 6 complex locus protein L', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=143080630, end_position_on_the_genomic_accession=143083486, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    101928147 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928147, CurrentID=0, Status='live', Symbol='C21orf140', Aliases=['FAM243A'], description='chromosome 21 open reading frame 140', other_designations='protein FAM243A|family with sequence similarity 243 member A|uncharacterized protein C21orf140', map_location='21q22.12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=34400112, end_position_on_the_genomic_accession=34401072, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    101928268 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928268, CurrentID=0, Status='live', Symbol='LOC101928268', Aliases=[], description='uncharacterized LOC101928268', other_designations='uncharacterized protein LOC101928268', map_location='7p14.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=30460050, end_position_on_the_genomic_accession=30469217, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    101928527 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928527, CurrentID=0, Status='live', Symbol='PIGBOS1', Aliases=['HP06981'], description='PIGB opposite strand 1', other_designations='protein PIGBOS1|PIGB opposite strand protein 1', map_location='15q21.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=55317184, end_position_on_the_genomic_accession=55348725, orientation='minus', exon_count=3, OMIM=[618809], no_hdr0=''),
    101928601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928601, CurrentID=0, Status='live', Symbol='MEI4', Aliases=[], description='meiotic double-stranded break formation protein 4', other_designations='meiosis-specific protein MEI4|meiosis-specific 4 homolog|meiosis-specific protein MEI4-like', map_location='6q14.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=77650274, end_position_on_the_genomic_accession=77927045, orientation='plus', exon_count=7, OMIM=[618417], no_hdr0=''),
    101928603 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928603, CurrentID=0, Status='live', Symbol='ARMH2', Aliases=['C6orf229'], description='armadillo like helical domain containing 2', other_designations='armadillo-like helical domain-containing protein 2|uncharacterized protein C6orf229', map_location='6p22.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=24797335, end_position_on_the_genomic_accession=24798917, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    101928677 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928677, CurrentID=0, Status='live', Symbol='ETDA', Aliases=[], description='embryonic testis differentiation homolog A', other_designations='embryonic testis differentiation homolog A', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135252012, end_position_on_the_genomic_accession=135257841, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    101928917 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928917, CurrentID=0, Status='live', Symbol='HSFX3', Aliases=[], description='heat shock transcription factor family, X-linked member 3', other_designations='heat shock transcription factor, X-linked member 3|heat shock transcription factor, X-linked-like', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=149548210, end_position_on_the_genomic_accession=149549924, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    101928991 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101928991, CurrentID=0, Status='live', Symbol='CCDC92B', Aliases=[], description='coiled-coil domain containing 92B', other_designations='coiled-coil domain containing 92B', map_location='17p13.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=2720801, end_position_on_the_genomic_accession=2749652, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    101929355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929355, CurrentID=0, Status='live', Symbol='CFAP97D2', Aliases=[], description='CFAP97 domain containing 2', other_designations='uncharacterized protein CFAP97D2|CFAP97 domain-containing protein 2|uncharacterized protein C17orf105 homolog', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=114173082, end_position_on_the_genomic_accession=114223032, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    101929469 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929469, CurrentID=0, Status='live', Symbol='TEX52', Aliases=[], description='testis expressed 52', other_designations='testis-expressed protein 52', map_location='12p13.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=2849046, end_position_on_the_genomic_accession=2857039, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    101929601 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929601, CurrentID=0, Status='live', Symbol='LOC101929601', Aliases=[], description='putative exonuclease GOR', other_designations='putative exonuclease GOR', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85735314, end_position_on_the_genomic_accession=85737397, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    101929627 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929627, CurrentID=0, Status='live', Symbol='LOC101929627', Aliases=[], description='putative exonuclease GOR', other_designations='putative exonuclease GOR', map_location='8q21.2', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=85744489, end_position_on_the_genomic_accession=85746516, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    101929726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929726, CurrentID=0, Status='live', Symbol='MYMX', Aliases=['MINION', 'hMINION'], description='myomixer, myoblast fusion factor', other_designations='protein myomixer|microprotein inducer of fusion|myomerger|protein minion', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=44192365, end_position_on_the_genomic_accession=44218236, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    101929773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929773, CurrentID=0, Status='live', Symbol='LOC101929773', Aliases=[], description='UDP-glucuronosyltransferase 2B10-like', other_designations='UDP-glucuronosyltransferase 2B10-like', map_location='', chromosome='4', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    101929805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929805, CurrentID=0, Status='live', Symbol='LOC101929805', Aliases=[], description='neuroblastoma breakpoint family member 6-like protein', other_designations='neuroblastoma breakpoint family member 6-like protein|uncharacterized protein LOC101929805|myomegalin-like', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=145133552, end_position_on_the_genomic_accession=145149891, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    101929926 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929926, CurrentID=0, Status='live', Symbol='TEX51', Aliases=[], description='testis expressed 51', other_designations='testis-expressed protein 51', map_location='2q14.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=126898878, end_position_on_the_genomic_accession=126902097, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    101929937 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929937, CurrentID=0, Status='live', Symbol='LOC101929937', Aliases=[], description='uncharacterized LOC101929937', other_designations='uncharacterized protein LOC101929937', map_location='20p13', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=346266, end_position_on_the_genomic_accession=353538, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    101929983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929983, CurrentID=0, Status='live', Symbol='PRAMEF27', Aliases=[], description='PRAME family member 27', other_designations='PRAME family member 27', map_location='1p36.21', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=13049476, end_position_on_the_genomic_accession=13056575, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    101929989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101929989, CurrentID=0, Status='live', Symbol='LITAFD', Aliases=[], description='LITAF domain containing', other_designations='LITAF domain-containing protein|lITAF domain-containing protein|LITAF-like protein', map_location='16p13.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=8881975, end_position_on_the_genomic_accession=8888317, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    101930420 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101930420, CurrentID=0, Status='live', Symbol='LOC101930420', Aliases=[], description='DNA primase large subunit-like', other_designations='DNA primase large subunit-like', map_location='3q11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=91373548, end_position_on_the_genomic_accession=91513924, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    101930434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=101930434, CurrentID=0, Status='live', Symbol='LOC101930434', Aliases=[], description='putative golgin subfamily A member 8I', other_designations='putative golgin subfamily A member 8I', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30798436, end_position_on_the_genomic_accession=30802763, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    102157402 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102157402, CurrentID=0, Status='live', Symbol='AK6', Aliases=['AD-004', 'CGI-137', 'CINAP', 'CIP', 'hCINAP'], description='adenylate kinase 6', other_designations='adenylate kinase isoenzyme 6|ATP-AMP transphosphorylase 6|adrenal gland protein AD-004|coilin interacting nuclear ATPase protein|coilin interacting protein', map_location='5q13.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=69350984, end_position_on_the_genomic_accession=69369824, orientation='minus', exon_count=6, OMIM=[619357], no_hdr0=''),
    102288414 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102288414, CurrentID=0, Status='live', Symbol='C11orf98', Aliases=['C11orf48'], description='chromosome 11 open reading frame 98', other_designations='uncharacterized protein C11orf98', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=62662817, end_position_on_the_genomic_accession=62665216, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    102723382 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723382, CurrentID=0, Status='live', Symbol='LOC102723382', Aliases=[], description='ankyrin repeat domain-containing protein 20B-like', other_designations='ankyrin repeat domain-containing protein 20B-like', map_location='', chromosome='Un', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723407 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723407, CurrentID=0, Status='live', Symbol='LOC102723407', Aliases=['IGH', 'IGH@', 'IGHV4', 'IGHV4-30', 'IGHV4-38-2', 'IGHV4-b', 'IGVH', 'IGVH4-39', 'IGVH4-b', 'IGVH4b', 'IgA', 'IgT', 'ighv'], description='immunoglobulin heavy variable 4-38-2-like', other_designations='immunoglobulin heavy variable 4-38-2-like|IG c1051_heavy_IGHV4-39_IGHD7-27_IGHJ3|IG c1120_heavy_IGHV4-39_IGHD3-22_IGHJ4|IG c1168_heavy_IGHV4-39_IGHD2-2_IGHJ5|IG c116_heavy_IGHV4-39_IGHD7-27_IGHJ4|IG c1418_heavy_IGHV4-39_IGHD3-3_IGHJ4|IG c151_heavy_IGHV4-39_IGHD5-24_IGHJ6|IG c168_heavy_IGHV4-39_IGHD6-13_IGHJ5|IG c192_heavy_IGHV4-39_IGHD3-10_IGHJ2|IG c20_heavy_IGHV4-39_IGHD3-3_IGHJ5|IG c29_heavy_IGHV4-39_IGHD4-11_IGHJ6|IG c381_heavy_IGHV4-39_IGHD3-3_IGHJ2|IG c446_heavy_IGHV4-39_IGHD3-22_IGHJ3|IG c477_heavy_IGHV4-39_IGHD6-13_IGHJ4|IG c630_heavy_IGHV4-39_IGHD6-19_IGHJ4|IG c641_heavy_IGHV4-39_IGHD2-2_IGHJ5|IG c735_heavy_IGHV4-39_IGHD2-15_IGHJ4|IG c741_heavy_IGHV4-39_IGHD2-2_IGHJ5|IG c764_heavy_IGHV4-39_IGHD7-27_IGHJ4|IG c904_heavy_IGHV4-39_IGHD7-27_IGHJ2|IG c912_heavy_IGHV4-39_IGHD3-22_IGHJ3|IG c991_heavy_IGHV4-39_IGHD3-3_IGHJ6|IGH + IGL c235_heavy_IGHV4-39_IGHD3-22_IGHJ2|IGH + IGL c448_heavy_IGHV4-39_IGHD6-13_IGHJ4|IGH + IGL c4_heavy_IGHV4-39_IGHD1-1_IGHJ4|IGH c1053_heavy_IGHV4-39_IGHD6-13_IGHJ3|IGH c1102_heavy_IGHV4-39_IGHD2-15_IGHJ3|IGH c1272_heavy_IGHV4-39_IGHD3-9_IGHJ3|IGH c1411_heavy_IGHV4-39_IGHD5-12_IGHJ4|IGH c1486_heavy_IGHV4-39_IGHD1-7_IGHJ4|IGH c1491_heavy_IGHV4-39_IGHD3-10_IGHJ1|IGH c1510_heavy_IGHV4-39_IGHD5-18_IGHJ4|IGH c1535_heavy_IGHV4-39_IGHD5-18_IGHJ4|IGH c1642_heavy_IGHV4-39_IGHD2-21_IGHJ3|IGH c1856_heavy_IGHV4-39_IGHD3-10_IGHJ4|IGH c1858_heavy_IGHV4-39_IGHD2-21_IGHJ3|IGH c1876_heavy_IGHV4-39_IGHD5-18_IGHJ5|IGH c1890_heavy_IGHV4-39_IGHD5-12_IGHJ4|IGH c1911_heavy_IGHV4-39_IGHD5-18_IGHJ4|IGH c1914_heavy_IGHV4-39_IGHD6-6_IGHJ4|IGH c1939_heavy_IGHV4-39_IGHD4-23_IGHJ2|IGH c1953_heavy_IGHV4-39_IGHD5-18_IGHJ5|IGH c1974_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c1992_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c2014_heavy_IGHV4-39_IGHD4-23_IGHJ3|IGH c2026_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c2034_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c2040_heavy_IGHV4-39_IGHD1-26_IGHJ3|IGH c2067_heavy_IGHV4-39_IGHD1-26_IGHJ3|IGH c2096_heavy_IGHV4-39_IGHD2-21_IGHJ3|IGH c2102_heavy_IGHV4-39_IGHD4-23_IGHJ3|IGH c2110_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c2130_heavy_IGHV4-39_IGHD2-2_IGHJ4|IGH c2159_heavy_IGHV4-39_IGHD4-23_IGHJ2|IGH c2167_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c2170_heavy_IGHV4-39_IGHD1-26_IGHJ5|IGH c2222_heavy_IGHV4-39_IGHD2-21_IGHJ3|IGH c2270_heavy_IGHV4-39_IGHD5-12_IGHJ4|IGH c2288_heavy_IGHV4-39_IGHD1-26_IGHJ5|IGH c2371_heavy_IGHV4-39_IGHD3-9_IGHJ4|IGH c2411_heavy_IGHV4-39_IGHD2-21_IGHJ2|IGH c2425_heavy_IGHV4-39_IGHD3-22_IGHJ1|IGH c2468_heavy_IGHV4-39_IGHD1-26_IGHJ5|IGH c2568_heavy_IGHV4-39_IGHD2-15_IGHJ4|IGH c265_heavy_IGHV4-39_IGHD3-16_IGHJ4|IGH c2661_heavy_IGHV4-39_IGHD3-22_IGHJ3|IGH c2794_heavy_IGHV4-39_IGHD1-26_IGHJ2|IGH c2868_heavy_IGHV4-39_IGHD5-12_IGHJ4|IGH c2893_heavy_IGHV4-39_IGHD3-22_IGHJ5|IGH c2974_heavy_IGHV4-39_IGHD2-15_IGHJ6|IGH c305_heavy_IGHV4-39_IGHD3-9_IGHJ4|IGH c3082_heavy_IGHV4-39_IGHD5-5_IGHJ3|IGH c3141_heavy_IGHV4-39_IGHD3-22_IGHJ1|IGH c3146_heavy_IGHV4-39_IGHD2-15_IGHJ4|IGH c3226_heavy_IGHV4-39_IGHD4-17_IGHJ4|IGH c3281_heavy_IGHV4-39_IGHD2-15_IGHJ4|IGH c331_heavy_IGHV4-39_IGHD3-10_IGHJ5|IGH c3433_heavy_IGHV4-39_IGHD5-24_IGHJ4|IGH c3478_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c3490_heavy_IGHV4-39_IGHD5-24_IGHJ4|IGH c3495_heavy_IGHV4-39_IGHD3-9_IGHJ4|IGH c3535_heavy_IGHV4-39_IGHD5-24_IGHJ5|IGH c3563_heavy_IGHV4-39_IGHD3-9_IGHJ4|IGH c3693_heavy_IGHV4-39_IGHD3-22_IGHJ6|IGH c3724_heavy_IGHV4-39_IGHD3-10_IGHJ5|IGH c3725_heavy_IGHV4-28_IGHD5-12_IGHJ5|IGH c3746_heavy_IGHV4-39_IGHD6-19_IGHJ3|IGH c3754_heavy_IGHV4-39_IGHD6-19_IGHJ4|IGH c3858_heavy_IGHV4-39_IGHD2-2_IGHJ4|IGH c3911_heavy_IGHV4-39_IGHD3-22_IGHJ4|IGH c3974_heavy_IGHV4-39_IGHD3-22_IGHJ3|IGH c3980_heavy_IGHV4-39_IGHD5-12_IGHJ2|IGH c4013_heavy_IGHV4-39_IGHD6-19_IGHJ4|IGH c4023_heavy_IGHV4-39_IGHD3-22_IGHJ3|IGH c4142_heavy_IGHV4-39_IGHD6-13_IGHJ4|IGH c4162_heavy_IGHV4-39_IGHD6-13_IGHJ4|IGH c4168_heavy_IGHV4-39_IGHD3-22_IGHJ6|IGH c4193_heavy_IGHV4-39_IGHD4-17_IGHJ4|IGH c4197_heavy_IGHV4-39_IGHD5-18_IGHJ3|IGH c632_heavy_IGHV4-39_IGHD3-10_IGHJ4|IGH c933_heavy_IGHV4-39_IGHD6-19_IGHJ6|Ig heavy chain variable region (VDJ)|IgM rheumatoid factor immunoglobulin heavy chain|anti-SARS-CoV-2 immunoglobulin heavy chain variable region|anti-cardiolipin immunoglobulin heavy chain|anti-peanut 2S albumin immunoglobulin heavy chain variable region|anti-thrombospondin immunoglobulin heavy chain variable region|hybrid Ig/T-cell receptor precursor VH-DJ|immunglobulin heavy chain variable region|immunoglobulin E heavy chain variable region|immunoglobulin alpha heavy chain variable region|immunoglobulin heavy chain CDR3|immunoglobulin heavy chain variable region|immunoglobulin mu heavy chain variable region|immunoglobulin variable region|non-productive immunoglobulin heavy chain CDR3', map_location='', chromosome='14', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723451 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723451, CurrentID=0, Status='live', Symbol='FAM243B', Aliases=[], description='family with sequence similarity 243 member B', other_designations='protein FAM243B|uncharacterized protein C21orf140', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=7769588, end_position_on_the_genomic_accession=7770548, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    102723475 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723475, CurrentID=0, Status='live', Symbol='KCNE1B', Aliases=[], description='potassium voltage-gated channel subfamily E regulatory subunit 1B', other_designations='potassium voltage-gated channel subfamily E member 1B|potassium channel, voltage gated subfamily E regulatory beta subunit 1B', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=7816677, end_position_on_the_genomic_accession=7829632, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    102723502 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723502, CurrentID=0, Status='live', Symbol='LOC102723502', Aliases=[], description='POTE ankyrin domain family member B-like', other_designations='POTE ankyrin domain family member B-like', map_location='', chromosome='15', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723532 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723532, CurrentID=0, Status='live', Symbol='LOC102723532', Aliases=[], description='olfactory receptor 4N4-like', other_designations='olfactory receptor 4N4', map_location='', chromosome='15', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723547 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723547, CurrentID=0, Status='live', Symbol='CSAG2', Aliases=['CSAG3', 'CSAG3B', 'CT24.2', 'TRAG-3', 'TRAG3'], description='CSAG family member 2', other_designations='chondrosarcoma-associated gene 2/3 protein|CSAG family, member 3B|cancer/testis antigen 24.2|cancer/testis antigen family 24, member 2|chondrosarcoma-associated gene 2/3 protein-like|taxol resistance associated gene 3|taxol-resistant-associated gene 3 protein', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=152708261, end_position_on_the_genomic_accession=152713861, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    102723553 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723553, CurrentID=0, Status='live', Symbol='SMIM11B', Aliases=[], description='small integral membrane protein 11B', other_designations='uncharacterized protein LOC102723553', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=7744951, end_position_on_the_genomic_accession=7772253, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    102723555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723555, CurrentID=0, Status='live', Symbol='SPDYE16', Aliases=[], description='speedy/RINGO cell cycle regulator family member E16', other_designations='putative speedy protein E16|WBSCR19-like protein 5-like', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76531313, end_position_on_the_genomic_accession=76543297, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    102723623 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723623, CurrentID=0, Status='live', Symbol='LOC102723623', Aliases=[], description='golgin subfamily A member 6-like protein 6', other_designations='golgin subfamily A member 6-like protein 6', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=23324535, end_position_on_the_genomic_accession=23334306, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    102723631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723631, CurrentID=0, Status='live', Symbol='CT45A10', Aliases=['CT45-5', 'CT45A5'], description='cancer/testis antigen family 45 member A10', other_designations='cancer/testis antigen family 45 member A10|Cancer/testis antigen 45-5|Cancer/testis antigen 45A10|Cancer/testis antigen 45A5|Cancer/testis antigen family 45 member A5|cancer/testis antigen family 45 member A-like', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135881065, end_position_on_the_genomic_accession=135893444, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    102723655 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723655, CurrentID=0, Status='live', Symbol='LOC102723655', Aliases=['TP53TG3', 'TP53TG3B', 'TP53TG3C', 'TP53TG3D', 'TP53TG3E', 'TP53TG3F'], description='TP53-target gene 3 protein', other_designations='tP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723680 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723680, CurrentID=0, Status='live', Symbol='CT45A9', Aliases=['CT45-2', 'CT45A2', 'CT45A8'], description='cancer/testis antigen family 45 member A9', other_designations='cancer/testis antigen family 45 member A9|Cancer/testis antigen 45-2|Cancer/testis antigen 45A2|Cancer/testis antigen 45A8|Cancer/testis antigen family 45 member A2|Cancer/testis antigen family 45 member A8|cancer/testis antigen 45A9', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135863418, end_position_on_the_genomic_accession=135871812, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    102723713 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723713, CurrentID=0, Status='live', Symbol='LOC102723713', Aliases=['TP53TG3', 'TP53TG3A', 'TP53TG3B', 'TP53TG3C', 'TP53TG3D', 'TP53TG3E', 'TP53TG3F'], description='TP53-target gene 3 protein', other_designations='tP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723728 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723728, CurrentID=0, Status='live', Symbol='LOC102723728', Aliases=[], description='nodal modulator 3-like', other_designations='nodal modulator 3-like', map_location='16p12.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=18417325, end_position_on_the_genomic_accession=18434790, orientation='minus', exon_count=9, OMIM=[], no_hdr0=''),
    102723737 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723737, CurrentID=0, Status='live', Symbol='CT45A8', Aliases=['CT45-2', 'CT45A2', 'CT45A9'], description='cancer/testis antigen family 45 member A8', other_designations='cancer/testis antigen family 45 member A8|Cancer/testis antigen 45-2|Cancer/testis antigen 45A2|Cancer/testis antigen 45A9|Cancer/testis antigen family 45 member A2|Cancer/testis antigen family 45 member A9|cancer/testis antigen 45A8', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135846497, end_position_on_the_genomic_accession=135854588, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    102723750 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723750, CurrentID=0, Status='live', Symbol='LOC102723750', Aliases=[], description='uncharacterized LOC102723750', other_designations='uncharacterized protein LOC102723750', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=74601853, end_position_on_the_genomic_accession=74615079, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    102723796 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723796, CurrentID=0, Status='live', Symbol='TLE7', Aliases=['chico'], description='TLE family member 7', other_designations='transducin-like enhancer protein 7|transducin like enhancer of split family member 7|transducin-like enhancer protein 2', map_location='16q22.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=71429980, end_position_on_the_genomic_accession=71442054, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    102723849 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723849, CurrentID=0, Status='live', Symbol='SPDYE17', Aliases=[], description='speedy/RINGO cell cycle regulator family member E17', other_designations='putative speedy protein E17', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=77022306, end_position_on_the_genomic_accession=77032361, orientation='minus', exon_count=8, OMIM=[], no_hdr0=''),
    102723859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723859, CurrentID=0, Status='live', Symbol='TBC1D3E', Aliases=['PRC17', 'TBC1D3', 'TBC1D3A', 'TBC1DE3'], description='TBC1 domain family member 3E', other_designations='TBC1 domain family member 3E|Prostate cancer gene 17 protein|Protein TRE17-alpha|Rab GTPase-activating protein PRC17|TBC1 domain family member 3|TBC1 domain family member-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=38118408, end_position_on_the_genomic_accession=38138868, orientation='plus', exon_count=19, OMIM=[610808], no_hdr0=''),
    102723899 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723899, CurrentID=0, Status='live', Symbol='PTTG1IP2', Aliases=[], description='PTTG1IP family member 2', other_designations='PTTG1IP family member 2', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90469639, end_position_on_the_genomic_accession=90513397, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    102723930 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723930, CurrentID=0, Status='live', Symbol='LOC102723930', Aliases=[], description='uncharacterized LOC102723930', other_designations='uncharacterized protein LOC102723930', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102723971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723971, CurrentID=0, Status='live', Symbol='LOC102723971', Aliases=[], description='lipocalin 1-like', other_designations='beta-lactoglobulin|beta-lactoglobulin-like', map_location='9q34.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=135614183, end_position_on_the_genomic_accession=135619893, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    102723996 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102723996, CurrentID=0, Status='live', Symbol='LOC102723996', Aliases=[], description='ICOS ligand', other_designations='ICOS ligand', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=5022044, end_position_on_the_genomic_accession=5046678, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    102724014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724014, CurrentID=0, Status='live', Symbol='LOC102724014', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC102724014', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724023, CurrentID=0, Status='live', Symbol='GATD3B', Aliases=['KNP-I'], description='glutamine amidotransferase class 1 domain containing 3B', other_designations='glutamine amidotransferase-like class 1 domain-containing protein 3B, mitochondrial|ES1 protein homolog, mitochondrial|glutamine amidotransferase like class 1 domain containing 3B|keio novel protein-I', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=5116341, end_position_on_the_genomic_accession=5128369, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    102724052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724052, CurrentID=0, Status='live', Symbol='LOC102724052', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC102724052', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724101 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724101, CurrentID=0, Status='live', Symbol='TP53TG3E', Aliases=['TP53TG3', 'TP53TG3B', 'TP53TG3C', 'TP53TG3D', 'TP53TG3F'], description='TP53 target 3 family member E', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=33301850, end_position_on_the_genomic_accession=33306945, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    102724127 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724127, CurrentID=0, Status='live', Symbol='TP53TG3F', Aliases=['TP53TG3', 'TP53TG3B', 'TP53TG3C', 'TP53TG3D', 'TP53TG3E'], description='TP53 target 3 family member F', other_designations='TP53-target gene 3 protein|TP53-inducible gene 3 protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=33457156, end_position_on_the_genomic_accession=33462258, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    102724159 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724159, CurrentID=0, Status='live', Symbol='LOC102724159', Aliases=[], description='periodic tryptophan protein 2 homolog', other_designations='periodic tryptophan protein 2 homolog', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=5130871, end_position_on_the_genomic_accession=5154658, orientation='minus', exon_count=22, OMIM=[], no_hdr0=''),
    102724183 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724183, CurrentID=0, Status='live', Symbol='LOC102724183', Aliases=[], description='Wnt family member 9-like', other_designations='', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=43927595, end_position_on_the_genomic_accession=43934517, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    102724197 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724197, CurrentID=0, Status='live', Symbol='LOC102724197', Aliases=['GGT2'], description='inactive glutathione hydrolase 2', other_designations='inactive glutathione hydrolase 2|putative glutathione hydrolase 3 proenzyme|putative glutathione hydrolase light chain 3|gamma-glutamyl transpeptidase', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724200 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724200, CurrentID=0, Status='live', Symbol='LOC102724200', Aliases=[], description='trafficking protein particle complex subunit 10-like', other_designations='trafficking protein particle complex subunit 10-like', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=5156151, end_position_on_the_genomic_accession=5231500, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    102724231 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724231, CurrentID=0, Status='live', Symbol='C3orf86', Aliases=['LINC00694'], description='chromosome 3 putative open reading frame 86', other_designations='uncharacterized protein C3orf86|long intergenic non-protein coding RNA 694', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44421132, end_position_on_the_genomic_accession=44439898, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    102724250 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724250, CurrentID=0, Status='live', Symbol='LOC102724250', Aliases=[], description='neuroblastoma breakpoint family member 1', other_designations='neuroblastoma breakpoint family member 1', map_location='', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724265 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724265, CurrentID=0, Status='live', Symbol='LOC102724265', Aliases=[], description='uncharacterized LOC102724265', other_designations='uncharacterized protein LOC102724265', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69425655, end_position_on_the_genomic_accession=69429624, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    102724334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724334, CurrentID=0, Status='live', Symbol='LOC102724334', Aliases=[], description='histone H2B type F-S-like', other_designations='histone H2B type F-S-like', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=5972922, end_position_on_the_genomic_accession=5973355, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    102724428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724428, CurrentID=0, Status='live', Symbol='SIK1B', Aliases=['SIK', 'SIK-1', 'SIK1', 'SNF1LK'], description='salt inducible kinase 1B (putative)', other_designations='probable serine/threonine-protein kinase SIK1B|Salt-inducible kinase 1|Serine/threonine-protein kinase SNF1-like kinase 1|Serine/threonine-protein kinase SNF1LK|salt-inducible kinase 1B|serine/threonine-protein kinase SIK1', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6111131, end_position_on_the_genomic_accession=6123778, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    102724473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724473, CurrentID=0, Status='live', Symbol='GAGE10', Aliases=['GAGE-10'], description='G antigen 10', other_designations='G antigen 10', map_location='Xp11.23', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=49303646, end_position_on_the_genomic_accession=49319844, orientation='plus', exon_count=5, OMIM=[300737], no_hdr0=''),
    102724474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724474, CurrentID=0, Status='live', Symbol='LOC102724474', Aliases=[], description='WAS/WASL-interacting protein family member 2-like', other_designations='WAS/WASL-interacting protein family member 2-like', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113150211, end_position_on_the_genomic_accession=113153986, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    102724485 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724485, CurrentID=0, Status='live', Symbol='LOC102724485', Aliases=[], description='putative cyclin-Y-like protein 3', other_designations='putative cyclin-Y-like protein 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=34351504, end_position_on_the_genomic_accession=34380899, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    102724488 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724488, CurrentID=0, Status='live', Symbol='LOC102724488', Aliases=[], description='synaptotagmin-15', other_designations='synaptotagmin-15', map_location='10q11.22', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=47744717, end_position_on_the_genomic_accession=47765208, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    102724536 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724536, CurrentID=0, Status='live', Symbol='PRR33', Aliases=['C11orf89'], description='proline rich 33', other_designations='proline-rich protein 33', map_location='11p15.5', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724560 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724560, CurrentID=0, Status='live', Symbol='CBSL', Aliases=['CBS'], description='cystathionine beta-synthase like', other_designations='cystathionine beta-synthase|cystathionine beta-synthase-like protein|beta-thionase|serine sulfhydrase', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6444868, end_position_on_the_genomic_accession=6468621, orientation='minus', exon_count=25, OMIM=[], no_hdr0=''),
    102724594 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724594, CurrentID=0, Status='live', Symbol='U2AF1L5', Aliases=[], description='U2 small nuclear RNA auxiliary factor 1 like 5', other_designations='splicing factor U2AF 35 kDa subunit-like protein|U2 small nuclear RNA auxiliary factor 1-like protein 5|splicing factor U2AF 35 kDa subunit', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6484623, end_position_on_the_genomic_accession=6499969, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    102724631 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724631, CurrentID=0, Status='live', Symbol='POTEB3', Aliases=['POTE-15', 'POTEB'], description='POTE ankyrin domain family member B3', other_designations='POTE ankyrin domain family member B3|ANKRD26-like family B member 1|POTE ankyrin domain family member B|POTE ankyrin domain family, member B-like|prostate, ovary, testis-expressed protein on chromosome 15', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=21405401, end_position_on_the_genomic_accession=21440499, orientation='minus', exon_count=13, OMIM=[], no_hdr0=''),
    102724652 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724652, CurrentID=0, Status='live', Symbol='CRYAA2', Aliases=['CRYAA'], description='crystallin alpha A2', other_designations='alpha-crystallin A2 chain|alpha-crystallin A chain', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6499203, end_position_on_the_genomic_accession=6564489, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    102724657 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724657, CurrentID=0, Status='live', Symbol='MSANTD5', Aliases=[], description='Myb/SANT DNA binding domain containing 5', other_designations='putative uncharacterized protein MSANTD5|Myb/SANT DNA binding domain-containing protein 5', map_location='5q35.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=178691534, end_position_on_the_genomic_accession=178707472, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    102724770 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724770, CurrentID=0, Status='live', Symbol='LOC102724770', Aliases=[], description='protein DGCR6', other_designations='protein DGCR6|DiGeorge syndrome critical region 6', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724788 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724788, CurrentID=0, Status='live', Symbol='LOC102724788', Aliases=[], description='proline dehydrogenase 1, mitochondrial', other_designations='proline dehydrogenase 1, mitochondrial', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724813 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724813, CurrentID=0, Status='live', Symbol='LOC102724813', Aliases=[], description='protein FRG1B', other_designations='protein FRG1B', map_location='', chromosome='9', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102724862 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724862, CurrentID=0, Status='live', Symbol='TBC1D3I', Aliases=['PRC17', 'TBC1D3', 'TBC1D3A'], description='TBC1 domain family member 3I', other_designations='TBC1 domain family member 3I|Prostate cancer gene 17 protein|Protein TRE17-alpha|Rab GTPase-activating protein PRC17|TBC1 domain family member 3|TBC1 domain family member-like', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=36253639, end_position_on_the_genomic_accession=36264601, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    102724877 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724877, CurrentID=0, Status='live', Symbol='LOC102724877', Aliases=[], description='uncharacterized LOC102724877', other_designations='uncharacterized protein LOC102724877', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=194069316, end_position_on_the_genomic_accession=194123474, orientation='plus', exon_count=10, OMIM=[], no_hdr0=''),
    102724971 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102724971, CurrentID=0, Status='live', Symbol='LOC102724971', Aliases=['IGH', 'IGHV4', 'IGHV4-04', 'IGHV4-4', 'IGHV@', 'IGVH', 'IgA', 'V4-4b', 'ighv'], description='putative V-set and immunoglobulin domain-containing-like protein IGHV4OR15-8', other_designations='putative V-set and immunoglobulin domain-containing-like protein IGHV4OR15-8|Ig H-chain V-region (DP-69)|Ig heavy chain gene variable region V(11)|anti-SARS-CoV-2 immunoglobulin heavy chain variable region|anti-ZIKV immunoglobulin heavy chain variable region|circulating B cell antibody heavy chain variable region|immunoglobulin alpha heavy chain variable region|immunoglobulin heavy chain CDR3|immunoglobulin heavy chain V region|immunoglobulin heavy chain VHDJ region|immunoglobulin heavy chain variable region|immunoglobulin mu heavy chain variable region|immunoglobulin variable region|immunoglobulin variable region heavy chain|rotavirus-specific intestinal-homing antibody heavy chain variable region', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=21742069, end_position_on_the_genomic_accession=21742917, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    102725023 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102725023, CurrentID=0, Status='live', Symbol='LOC102725023', Aliases=['KIR2DS3'], description='killer cell immunoglobulin-like receptor 2DS3-like', other_designations='killer cell immunoglobulin-like receptor 2DS3-like|killer cell immunoglobulin-like receptor 2DS3 allele 0020101', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102725035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102725035, CurrentID=0, Status='live', Symbol='LOC102725035', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    102725191 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102725191, CurrentID=0, Status='live', Symbol='LOC102725191', Aliases=[], description='uncharacterized LOC102725191', other_designations='uncharacterized LOC102725191', map_location='7p21.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=12483344, end_position_on_the_genomic_accession=12542188, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    102800317 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=102800317, CurrentID=0, Status='live', Symbol='TPTEP2-CSNK1E', Aliases=['LOC400927-CSNK1E'], description='TPTEP2-CSNK1E readthrough', other_designations='casein kinase I isoform epsilon|CKI-epsilon|LOC400927-CSNK1E readthrough', map_location='22q13.1', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=38290691, end_position_on_the_genomic_accession=38398915, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    104326056 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=104326056, CurrentID=0, Status='live', Symbol='ZNF511-PRAP1', Aliases=[], description='ZNF511-PRAP1 readthrough', other_designations='', map_location='10q26.3', chromosome='10', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    104909134 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=104909134, CurrentID=0, Status='live', Symbol='LINC02210-CRHR1', Aliases=['CRHR1-IT1-CRHR1', 'MGC57346-CRHR1'], description='LINC02210-CRHR1 readthrough', other_designations='CRHR1-IT1-CRHR1 protein|CRHR1-IT1-CRHR1 readthrough', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=45620346, end_position_on_the_genomic_accession=45835828, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    105180390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105180390, CurrentID=0, Status='live', Symbol='SPDYE13', Aliases=['SPDYE13P'], description='speedy/RINGO cell cycle regulator family member E13', other_designations='speedy/RINGO cell cycle regulator family member E13|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene|speedy/RINGO cell cycle regulator family member E13, pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75280790, end_position_on_the_genomic_accession=75289501, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    105180391 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105180391, CurrentID=0, Status='live', Symbol='SPDYE15', Aliases=['SPDYE15P'], description='speedy/RINGO cell cycle regulator family member E15', other_designations='putative speedy protein E15|Williams Beuren syndrome chromosome region 19 pseudogene|speedy homolog E1 pseudogene|speedy/RINGO cell cycle regulator family member E1 pseudogene|speedy/RINGO cell cycle regulator family member E15, pseudogene', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=75335343, end_position_on_the_genomic_accession=75345396, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    105369274 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369274, CurrentID=0, Status='live', Symbol='OR4N4C', Aliases=[], description='olfactory receptor family 4 subfamily N member 4C', other_designations='olfactory receptor family 4 subfamily N member 4C|olfactory receptor 4N4', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=21638579, end_position_on_the_genomic_accession=21653034, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105369591 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369591, CurrentID=0, Status='live', Symbol='LOC105369591', Aliases=[], description='uncharacterized LOC105369591', other_designations='uncharacterized protein LOC105369591', map_location='11q24.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=126123806, end_position_on_the_genomic_accession=126140638, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    105369669 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369669, CurrentID=0, Status='live', Symbol='LOC105369669', Aliases=[], description='uncharacterized LOC105369669', other_designations='uncharacterized protein LOC105369669', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=14746666, end_position_on_the_genomic_accession=14770662, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105369869 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369869, CurrentID=0, Status='live', Symbol='LOC105369869', Aliases=[], description='uncharacterized LOC105369869', other_designations='uncharacterized protein LOC105369869', map_location='12q21.31', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=80931626, end_position_on_the_genomic_accession=80938065, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105369889 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369889, CurrentID=0, Status='live', Symbol='LOC105369889', Aliases=[], description='uncharacterized LOC105369889', other_designations='', map_location='', chromosome='12', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105369914 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105369914, CurrentID=0, Status='live', Symbol='LOC105369914', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC105369914', map_location='12q22', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=94648408, end_position_on_the_genomic_accession=94651098, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105370092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105370092, CurrentID=0, Status='live', Symbol='LOC105370092', Aliases=[], description='uncharacterized LOC105370092', other_designations='', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132427420, end_position_on_the_genomic_accession=132438841, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    105370706 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105370706, CurrentID=0, Status='live', Symbol='LOC105370706', Aliases=[], description='uncharacterized LOC105370706', other_designations='uncharacterized protein LOC105370706|uncharacterized protein C14orf56', map_location='14q24.2', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=71190251, end_position_on_the_genomic_accession=71228231, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    105370980 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105370980, CurrentID=0, Status='live', Symbol='LOC105370980', Aliases=[], description='putative uncharacterized protein UNQ9370/PRO34162', other_designations='putative uncharacterized protein UNQ9370/PRO34162', map_location='15q26.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=93206066, end_position_on_the_genomic_accession=93208048, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    105371045 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371045, CurrentID=0, Status='live', Symbol='PERCC1', Aliases=['DIAR11', 'ICR', 'gs104'], description='proline and glutamate rich with coiled coil 1', other_designations='protein PERCC1|proline and glutamage-rich protein with a coiled coil domain|protein LOC105371045', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=1431078, end_position_on_the_genomic_accession=1434441, orientation='plus', exon_count=2, OMIM=[618656], no_hdr0=''),
    105371063 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371063, CurrentID=0, Status='live', Symbol='LOC105371063', Aliases=[], description='putative uncharacterized protein encoded by LINC00596', other_designations='putative uncharacterized protein encoded by LINC00596', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=4254514, end_position_on_the_genomic_accession=4255336, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105371095 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371095, CurrentID=0, Status='live', Symbol='LOC105371095', Aliases=[], description='collagen alpha-3(IX) chain-like', other_designations='collagen alpha-3(IX) chain-like', map_location='16p13.12-p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14695760, end_position_on_the_genomic_accession=14704205, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105371242 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371242, CurrentID=0, Status='live', Symbol='PPIAL4H', Aliases=[], description='peptidylprolyl isomerase A like 4H', other_designations='peptidyl-prolyl cis-trans isomerase A-like 4H|PPIase A-like 4H|peptidyl-prolyl cis-trans isomerase A-like 4C', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=146344006, end_position_on_the_genomic_accession=146344765, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    105371253 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371253, CurrentID=0, Status='live', Symbol='LOC105371253', Aliases=[], description='uncharacterized LOC105371253', other_designations='uncharacterized protein LOC105371253', map_location='16q12.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=51133302, end_position_on_the_genomic_accession=51135246, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105371346 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371346, CurrentID=0, Status='live', Symbol='CPHXL', Aliases=['CPHXL1'], description='cytoplasmic polyadenylated homeobox like', other_designations='cytoplasmic polyadenylated homeobox-like|cytoplasmic polyadenylated homeobox 1', map_location='16q23.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=75714131, end_position_on_the_genomic_accession=75726490, orientation='minus', exon_count=3, OMIM=[618700], no_hdr0=''),
    105371419 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371419, CurrentID=0, Status='live', Symbol='LOC105371419', Aliases=[], description='uncharacterized LOC105371419', other_designations='uncharacterized protein LOC105371419', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89846857, end_position_on_the_genomic_accession=89854277, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105371932 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105371932, CurrentID=0, Status='live', Symbol='LOC105371932', Aliases=[], description='uncharacterized LOC105371932', other_designations='uncharacterized protein LOC105371932', map_location='17q12', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=35241324, end_position_on_the_genomic_accession=35247472, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    105372204 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372204, CurrentID=0, Status='live', Symbol='LOC105372204', Aliases=[], description='uncharacterized LOC105372204', other_designations='uncharacterized protein LOC105372204', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=76053751, end_position_on_the_genomic_accession=76056546, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105372267 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372267, CurrentID=0, Status='live', Symbol='NFILZ', Aliases=['LINC01862'], description='NFIL3 like basic leucine zipper', other_designations='NFIL3 like protein|long intergenic non-protein coding RNA 1862|nuclear factor interleukin-3-regulated protein-like', map_location='19p13.2', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=8630633, end_position_on_the_genomic_accession=8681151, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    105372280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372280, CurrentID=0, Status='live', Symbol='GNG14', Aliases=[], description='G protein subunit gamma 14', other_designations='putative guanine nucleotide-binding protein G(I)/G(S)/G(O) subunit gamma-14|guanine nucleotide binding protein (G protein), gamma 12-like', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12687998, end_position_on_the_genomic_accession=12688422, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    105372412 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372412, CurrentID=0, Status='live', Symbol='LOC105372412', Aliases=[], description='phospholipase A2 inhibitor and Ly6/PLAUR domain-containing protein-like', other_designations='phospholipase A2 inhibitor and Ly6/PLAUR domain-containing protein-like', map_location='19q13.31', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=43687557, end_position_on_the_genomic_accession=43700540, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    105372440 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372440, CurrentID=0, Status='live', Symbol='LOC105372440', Aliases=[], description='uncharacterized LOC105372440', other_designations='uncharacterized LOC105372440|CTD-2568A17.1', map_location='19q13.33', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=50785728, end_position_on_the_genomic_accession=50786160, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105372704 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105372704, CurrentID=0, Status='live', Symbol='LOC105372704', Aliases=[], description='uncharacterized LOC105372704', other_designations='uncharacterized protein LOC105372704', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62000728, end_position_on_the_genomic_accession=62002628, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105373057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373057, CurrentID=0, Status='live', Symbol='LOC105373057', Aliases=[], description='DNA-directed RNA polymerase II subunit RPB1-like', other_designations='DNA-directed RNA polymerase II subunit RPB1-like', map_location='22q13.31', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=43836042, end_position_on_the_genomic_accession=43838860, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105373091 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373091, CurrentID=0, Status='live', Symbol='LOC105373091', Aliases=[], description='atherin-like', other_designations='atherin-like', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=49849503, end_position_on_the_genomic_accession=49851083, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105373102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373102, CurrentID=0, Status='live', Symbol='LOC105373102', Aliases=[], description='uncharacterized LOC105373102', other_designations='uncharacterized protein LOC105373102', map_location='X;Y', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=1392349, end_position_on_the_genomic_accession=1396881, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    105373251 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373251, CurrentID=0, Status='live', Symbol='FAM236D', Aliases=['FAM236C'], description='family with sequence similarity 236 member D', other_designations='protein FAM236D|Protein FAM236C|family with sequence similarity 235 member D', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72807425, end_position_on_the_genomic_accession=72808210, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105373297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373297, CurrentID=0, Status='live', Symbol='ERVFC1', Aliases=['Fc1env', 'HERV-Fc1env'], description='endogenous retrovirus group FC1 Env polyprotein', other_designations='endogenous retrovirus group FC1 Env polyprotein|HERV-F(c)1_Xq21.33 provirus ancestral Env polyprotein|envelope polyprotein', map_location='Xq21.33', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=97841749, end_position_on_the_genomic_accession=97849381, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105373377 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373377, CurrentID=0, Status='live', Symbol='PNMA6F', Aliases=['PNMA6BL'], description='PNMA family member 6F', other_designations='paraneoplastic antigen Ma6F|paraneoplastic Ma antigen family member 6F|paraneoplastic antigen-like protein 6B', map_location='Xq28', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=153317680, end_position_on_the_genomic_accession=153321767, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105373989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105373989, CurrentID=0, Status='live', Symbol='LOC105373989', Aliases=[], description='putative cuticle collagen 91', other_designations='putative cuticle collagen 91', map_location='2q14.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=120342450, end_position_on_the_genomic_accession=120345993, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105374103 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105374103, CurrentID=0, Status='live', Symbol='LOC105374103', Aliases=[], description='uncharacterized LOC105374103', other_designations='uncharacterized protein LOC105374103', map_location='3q22.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=130143281, end_position_on_the_genomic_accession=130148818, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105374301 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105374301, CurrentID=0, Status='live', Symbol='LOC105374301', Aliases=[], description='mucin-1-like', other_designations='mucin-1-like', map_location='3q29', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=195993944, end_position_on_the_genomic_accession=196002217, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105375107 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375107, CurrentID=0, Status='live', Symbol='LOC105375107', Aliases=[], description='uncharacterized LOC105375107', other_designations='uncharacterized protein LOC105375107', map_location='6p22.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=27312169, end_position_on_the_genomic_accession=27313736, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105375112 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375112, CurrentID=0, Status='live', Symbol='LOC105375112', Aliases=[], description='putative protein FAM157B', other_designations='probable serine/threonine-protein kinase DDB_G0277071|putative protein FAM157B', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=31567, end_position_on_the_genomic_accession=37939, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    105375116 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375116, CurrentID=0, Status='live', Symbol='LOC105375116', Aliases=[], description='TRIO and F-actin-binding protein-like', other_designations='TRIO and F-actin-binding protein-like', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=176194, end_position_on_the_genomic_accession=180728, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105375355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375355, CurrentID=0, Status='live', Symbol='UPK3B', Aliases=['P35', 'UP3B', 'UPIIIB'], description='uroplakin 3B', other_designations='uroplakin-3b|uroplakin IIIb', map_location='7q11.23', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=76510552, end_position_on_the_genomic_accession=76516522, orientation='plus', exon_count=6, OMIM=[611887], no_hdr0=''),
    105375809 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375809, CurrentID=0, Status='live', Symbol='LOC105375809', Aliases=[], description='platelet endothelial aggregation receptor 1-like', other_designations='platelet endothelial aggregation receptor 1-like', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=110343873, end_position_on_the_genomic_accession=110347091, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    105375816 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375816, CurrentID=0, Status='live', Symbol='LOC105375816', Aliases=[], description='putative coiled-coil domain-containing protein 144C', other_designations='putative coiled-coil domain-containing protein 144C', map_location='8q11.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47088584, end_position_on_the_genomic_accession=47092691, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105375817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105375817, CurrentID=0, Status='live', Symbol='LOC105375817', Aliases=[], description='POTE ankyrin domain family member A-like', other_designations='POTE ankyrin domain family member A-like', map_location='8q11.1', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=47100920, end_position_on_the_genomic_accession=47123457, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    105376230 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376230, CurrentID=0, Status='live', Symbol='TEX53', Aliases=[], description='testis expressed 53', other_designations='testis-expressed protein 53', map_location='9q32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=114656304, end_position_on_the_genomic_accession=114657805, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105376335 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376335, CurrentID=0, Status='live', Symbol='LOC105376335', Aliases=[], description='serine/arginine repetitive matrix protein 1-like', other_designations='serine/arginine repetitive matrix protein 1-like', map_location='9q21.32', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=83920901, end_position_on_the_genomic_accession=83924885, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105376341 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376341, CurrentID=0, Status='live', Symbol='LOC105376341', Aliases=[], description='uncharacterized LOC105376341', other_designations='uncharacterized protein LOC105376341', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=951546, end_position_on_the_genomic_accession=956381, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105376714 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376714, CurrentID=0, Status='live', Symbol='LOC105376714', Aliases=[], description='uncharacterized LOC105376714', other_designations='uncharacterized protein LOC105376714', map_location='15q21.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=45445697, end_position_on_the_genomic_accession=45477920, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    105376722 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376722, CurrentID=0, Status='live', Symbol='LOC105376722', Aliases=[], description='uncharacterized LOC105376722', other_designations='uncharacterized protein LOC105376722', map_location='15q25.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=84361567, end_position_on_the_genomic_accession=84391835, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    105376747 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376747, CurrentID=0, Status='live', Symbol='LOC105376747', Aliases=[], description='collagen alpha-3(IX) chain-like', other_designations='collagen alpha-3(IX) chain-like', map_location='16p13.11', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=14734878, end_position_on_the_genomic_accession=14743326, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105376875 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105376875, CurrentID=0, Status='live', Symbol='LOC105376875', Aliases=[], description='uncharacterized LOC105376875', other_designations='uncharacterized protein LOC105376875', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79680284, end_position_on_the_genomic_accession=79688319, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105377310 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105377310, CurrentID=0, Status='live', Symbol='LOC105377310', Aliases=[], description='syncytin-1-like', other_designations='syncytin-1-like', map_location='4q21.22', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=82469552, end_position_on_the_genomic_accession=82480384, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    105377805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105377805, CurrentID=0, Status='live', Symbol='LOC105377805', Aliases=[], description='basic salivary proline-rich protein 4-like', other_designations='basic salivary proline-rich protein 3-like|basic salivary proline-rich protein 4-like|translation initiation factor IF-2-like', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113741875, end_position_on_the_genomic_accession=113759067, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    105378148 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378148, CurrentID=0, Status='live', Symbol='LOC105378148', Aliases=[], description='uncharacterized LOC105378148', other_designations='uncharacterized protein LOC105378148', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169330538, end_position_on_the_genomic_accession=169340507, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105378193 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378193, CurrentID=0, Status='live', Symbol='LOC105378193', Aliases=[], description='peptidyl-prolyl cis-trans isomerase CYP95-like', other_designations='peptidyl-prolyl cis-trans isomerase CYP95-like', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=112013691, end_position_on_the_genomic_accession=112027858, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105378220 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378220, CurrentID=0, Status='live', Symbol='MARCOL', Aliases=[], description='MARCO like', other_designations='MARCO-like protein|CTC-295J13.3|mARCO-like protein', map_location='5q32', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=148238525, end_position_on_the_genomic_accession=148243580, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    105378696 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378696, CurrentID=0, Status='live', Symbol='TMEM275', Aliases=[], description='transmembrane protein 275', other_designations='transmembrane protein 275', map_location='1p33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46532166, end_position_on_the_genomic_accession=46535515, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    105378803 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378803, CurrentID=0, Status='live', Symbol='LRRC53', Aliases=[], description='leucine rich repeat containing 53', other_designations='leucine-rich repeat-containing protein 53', map_location='1p31.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=74468980, end_position_on_the_genomic_accession=74540227, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    105378947 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378947, CurrentID=0, Status='live', Symbol='LOC105378947', Aliases=[], description='proline-rich extensin-like protein EPR1', other_designations='proline-rich extensin-like protein EPR1', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=586287, end_position_on_the_genomic_accession=611297, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    105378952 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378952, CurrentID=0, Status='live', Symbol='KLF18', Aliases=[], description='Kruppel like factor 18', other_designations='Kruppel-like factor 18|KLF pseudogene', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=44137821, end_position_on_the_genomic_accession=44141631, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    105378955 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378955, CurrentID=0, Status='live', Symbol='LOC105378955', Aliases=[], description='tripartite motif-containing protein 43B', other_designations='tripartite motif-containing protein LOC642612', map_location='11q14.3', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105378979 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105378979, CurrentID=0, Status='live', Symbol='LOC105378979', Aliases=[], description='growth/differentiation factor 3', other_designations='growth/differentiation factor 3', map_location='5q11.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=56766395, end_position_on_the_genomic_accession=56772871, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105379198 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379198, CurrentID=0, Status='live', Symbol='LOC105379198', Aliases=[], description='uncharacterized LOC105379198', other_designations='uncharacterized protein LOC105379198', map_location='5q23.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=127218439, end_position_on_the_genomic_accession=127230384, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    105379417 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379417, CurrentID=0, Status='live', Symbol='LOC105379417', Aliases=[], description='ankyrin repeat domain-containing protein 20A2-like', other_designations='ankyrin repeat domain-containing protein 20A2-like', map_location='', chromosome='Un', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379473 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379473, CurrentID=0, Status='live', Symbol='LOC105379473', Aliases=[], description='uncharacterized LOC105379473', other_designations='uncharacterized protein LOC105379473', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=33385983, end_position_on_the_genomic_accession=33387715, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    105379528 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379528, CurrentID=0, Status='live', Symbol='LOC105379528', Aliases=['IGH', 'IGHV3-D'], description='uncharacterized LOC105379528', other_designations='immunoglobulin heavy chain variable region', map_location='', chromosome='14', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379545, CurrentID=0, Status='live', Symbol='LOC105379545', Aliases=[], description='uncharacterized LOC105379545', other_designations='uncharacterized protein LOC105379545', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379554 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379554, CurrentID=0, Status='live', Symbol='LOC105379554', Aliases=[], description='maFF-interacting protein', other_designations='maFF-interacting protein', map_location='', chromosome='Un', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379561 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379561, CurrentID=0, Status='live', Symbol='LOC105379561', Aliases=[], description='uncharacterized LOC105379561', other_designations='uncharacterized protein LOC105379561|XX-C2158C12.1', map_location='', chromosome='Un', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379589 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379589, CurrentID=0, Status='live', Symbol='LOC105379589', Aliases=[], description='uncharacterized protein FLJ40521-like', other_designations='uncharacterized protein FLJ40521-like', map_location='', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    105379752 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=105379752, CurrentID=0, Status='live', Symbol='LOC105379752', Aliases=[], description='putative uncharacterized protein FLJ46204', other_designations='putative uncharacterized protein FLJ46204', map_location='7q36.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=158777042, end_position_on_the_genomic_accession=158785211, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    106707243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=106707243, CurrentID=0, Status='live', Symbol='PRH1-TAS2R14', Aliases=[], description='PRH1-TAS2R14 readthrough', other_designations='uncharacterized protein LOC106707243', map_location='12p13.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=10937410, end_position_on_the_genomic_accession=11171611, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    106821730 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=106821730, CurrentID=0, Status='live', Symbol='BUB1B-PAK6', Aliases=['PAK-5', 'PAK-6', 'PAK5', 'PAK6'], description='BUB1B-PAK6 readthrough', other_designations='serine/threonine-protein kinase PAK 6|p21-activated kinase 6', map_location='15q15.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=40217428, end_position_on_the_genomic_accession=40277487, orientation='plus', exon_count=11, OMIM=[], no_hdr0=''),
    106865373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=106865373, CurrentID=0, Status='live', Symbol='GET1-SH3BGR', Aliases=['WRB-SH3BGR'], description='GET1-SH3BGR readthrough', other_designations='WRB-SH3BGR readthrough', map_location='21q22.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=39380326, end_position_on_the_genomic_accession=39515504, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    107080638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107080638, CurrentID=0, Status='live', Symbol='TBC1D7-LOC100130357', Aliases=[], description='TBC1D7-LOC100130357 readthrough', other_designations='TBC1 domain family member 7', map_location='6p24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=13266536, end_position_on_the_genomic_accession=13328537, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    107080644 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107080644, CurrentID=0, Status='live', Symbol='CNPY3-GNMT', Aliases=[], description='CNPY3-GNMT readthrough', other_designations='Glycine N-methyltransferase-like', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42929480, end_position_on_the_genomic_accession=42963880, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    107181291 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107181291, CurrentID=0, Status='live', Symbol='PYDC5', Aliases=['POP3'], description='pyrin domain containing 5', other_designations='pyrin domain-containing protein 5|pyrin domain-only protein 3', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=158999971, end_position_on_the_genomic_accession=159000312, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107282092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107282092, CurrentID=0, Status='live', Symbol='BOLA2-SMG1P6', Aliases=[], description='BOLA2-SMG1P6 readthrough', other_designations='BOLA2-SMG1P6 protein|BOLA2-SMG1P6 readthrough protein', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29442905, end_position_on_the_genomic_accession=29454964, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    107303344 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107303344, CurrentID=0, Status='live', Symbol='SETDB2-PHF11', Aliases=[], description='SETDB2-PHF11 readthrough', other_designations='SETDB2-PHF11 protein', map_location='13q14.2', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=49444274, end_position_on_the_genomic_accession=49528976, orientation='plus', exon_count=23, OMIM=[], no_hdr0=''),
    107983958 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983958, CurrentID=0, Status='live', Symbol='LOC107983958', Aliases=[], description='uncharacterized LOC107983958', other_designations='uncharacterized protein LOC107983958', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=111623249, end_position_on_the_genomic_accession=111637452, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107983962 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983962, CurrentID=0, Status='live', Symbol='LOC107983962', Aliases=[], description='translation initiation factor IF-2-like', other_designations='', map_location='1p31.3', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107983983 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983983, CurrentID=0, Status='live', Symbol='LOC107983983', Aliases=[], description='uncharacterized LOC107983983', other_designations='uncharacterized protein LOC107983983', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=22183503, end_position_on_the_genomic_accession=22185526, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107983987 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983987, CurrentID=0, Status='live', Symbol='SMIM34B', Aliases=[], description='small integral membrane protein 34B', other_designations='small integral membrane protein 34B', map_location='21p11.2', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=7788703, end_position_on_the_genomic_accession=7793939, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107983988 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983988, CurrentID=0, Status='live', Symbol='SPEM3', Aliases=[], description='SPEM family member 3', other_designations='uncharacterized protein SPEM3', map_location='17p13.1', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=7428857, end_position_on_the_genomic_accession=7432820, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    107983989 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983989, CurrentID=0, Status='live', Symbol='LOC107983989', Aliases=[], description='uncharacterized LOC107983989', other_designations='uncharacterized protein LOC107983989', map_location='10p15.3', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=2497765, end_position_on_the_genomic_accession=2501966, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107983993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107983993, CurrentID=0, Status='live', Symbol='UPK3BL2', Aliases=[], description='uroplakin 3B like 2', other_designations='uroplakin-3b-like protein 2|Uroplakin-3b-like protein 2', map_location='7q22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=102537919, end_position_on_the_genomic_accession=102544788, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    107984014 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984014, CurrentID=0, Status='live', Symbol='LOC107984014', Aliases=[], description='uncharacterized LOC107984014', other_designations='uncharacterized protein LOC107984014', map_location='7q36.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=154058557, end_position_on_the_genomic_accession=154064392, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    107984025 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984025, CurrentID=0, Status='live', Symbol='LOC107984025', Aliases=[], description='golgin subfamily A member 8M-like', other_designations='golgin subfamily A member 8M-like', map_location='15q13.2', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=30791514, end_position_on_the_genomic_accession=30795775, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    107984124 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984124, CurrentID=0, Status='live', Symbol='LOC107984124', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC107984124', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22953619, end_position_on_the_genomic_accession=23000054, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984126, CurrentID=0, Status='live', Symbol='LOC107984126', Aliases=[], description='zinc finger protein 658B-like', other_designations='zinc finger protein 658B-like', map_location='9q12', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=61002335, end_position_on_the_genomic_accession=61003885, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107984153 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984153, CurrentID=0, Status='live', Symbol='LOC107984153', Aliases=[], description='uncharacterized LOC107984153', other_designations='uncharacterized protein LOC107984153', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107984156 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984156, CurrentID=0, Status='live', Symbol='LOC107984156', Aliases=[], description='ADP-ribosylation factor-like protein 17', other_designations='ADP-ribosylation factor-like protein 17', map_location='', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107984189 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984189, CurrentID=0, Status='live', Symbol='LOC107984189', Aliases=[], description='uncharacterized protein C10orf142-like', other_designations='uncharacterized protein C10orf142-like', map_location='10q11.21', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=43825757, end_position_on_the_genomic_accession=43826300, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984203 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984203, CurrentID=0, Status='live', Symbol='LOC107984203', Aliases=[], description='endogenous retrovirus group K member 6 Env polyprotein', other_designations='endogenous retrovirus group K member 6 Env polyprotein', map_location='10p14', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=6825173, end_position_on_the_genomic_accession=6828853, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984264 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984264, CurrentID=0, Status='live', Symbol='LOC107984264', Aliases=[], description='transmembrane protein 108-like', other_designations='transmembrane protein 108-like', map_location='10q24.32', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=102839199, end_position_on_the_genomic_accession=102844110, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984345 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984345, CurrentID=0, Status='live', Symbol='SMIM38', Aliases=[], description='small integral membrane protein 38', other_designations='small integral membrane protein 38', map_location='11q13.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=69155573, end_position_on_the_genomic_accession=69162440, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107984351 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984351, CurrentID=0, Status='live', Symbol='LOC107984351', Aliases=[], description='protein GVQW2-like', other_designations='protein GVQW2-like', map_location='11p13', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=32475731, end_position_on_the_genomic_accession=32483540, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107984449 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984449, CurrentID=0, Status='live', Symbol='LOC107984449', Aliases=[], description='uncharacterized LOC107984449', other_designations='uncharacterized protein LOC107984449', map_location='12q24.32', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=127060113, end_position_on_the_genomic_accession=127146493, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107984512 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984512, CurrentID=0, Status='live', Symbol='LOC107984512', Aliases=[], description='uncharacterized LOC107984512', other_designations='uncharacterized protein LOC107984512', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=54005201, end_position_on_the_genomic_accession=54008751, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984590 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984590, CurrentID=0, Status='live', Symbol='LOC107984590', Aliases=[], description='proline-rich extensin-like protein EPR1', other_designations='proline-rich extensin-like protein EPR1', map_location='13q34', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=113010424, end_position_on_the_genomic_accession=113013239, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107984638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984638, CurrentID=0, Status='live', Symbol='LOC107984638', Aliases=[], description='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 2', other_designations='arf-GAP with GTPase, ANK repeat and PH domain-containing protein 2', map_location='14q24.3', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=77027791, end_position_on_the_genomic_accession=77029281, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107984640 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984640, CurrentID=0, Status='live', Symbol='LBHD2', Aliases=[], description='LBH domain containing 2', other_designations='LBH domain-containing protein 2', map_location='14q32.32', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103084210, end_position_on_the_genomic_accession=103090027, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107984678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984678, CurrentID=0, Status='live', Symbol='LOC107984678', Aliases=[], description='uncharacterized LOC107984678', other_designations='', map_location='', chromosome='14', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107984817 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984817, CurrentID=0, Status='live', Symbol='LOC107984817', Aliases=[], description='uncharacterized LOC107984817', other_designations='uncharacterized protein LOC107984817', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=89831631, end_position_on_the_genomic_accession=89835961, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107984832 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984832, CurrentID=0, Status='live', Symbol='LOC107984832', Aliases=[], description='uncharacterized LOC107984832', other_designations='uncharacterized protein LOC107984832', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29154296, end_position_on_the_genomic_accession=29220863, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    107984833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984833, CurrentID=0, Status='live', Symbol='LOC107984833', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC107984833', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=29289365, end_position_on_the_genomic_accession=29290955, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107984876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984876, CurrentID=0, Status='live', Symbol='LOC107984876', Aliases=['LA16c-306A4.2'], description='uncharacterized LOC107984876', other_designations='uncharacterized protein LOC107984876', map_location='16p13.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=900534, end_position_on_the_genomic_accession=903740, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107984973 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107984973, CurrentID=0, Status='live', Symbol='LOC107984973', Aliases=[], description='atherin-like', other_designations='', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107985021 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985021, CurrentID=0, Status='live', Symbol='LOC107985021', Aliases=[], description='flocculation protein FLO11-like', other_designations='flocculation protein FLO11-like', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80720259, end_position_on_the_genomic_accession=80730169, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    107985022 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985022, CurrentID=0, Status='live', Symbol='LOC107985022', Aliases=[], description='uncharacterized LOC107985022', other_designations='uncharacterized protein LOC107985022', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=80960214, end_position_on_the_genomic_accession=80961386, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107985108 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985108, CurrentID=0, Status='live', Symbol='LOC107985108', Aliases=[], description='uncharacterized LOC107985108', other_designations='', map_location='1q21.1', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107985149 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985149, CurrentID=0, Status='live', Symbol='LOC107985149', Aliases=[], description='histidine-rich protein PFHRP-II-like', other_designations='histidine-rich protein PFHRP-II-like', map_location='18q23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=79345846, end_position_on_the_genomic_accession=79347763, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    107985309 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985309, CurrentID=0, Status='live', Symbol='LOC107985309', Aliases=[], description='uncharacterized LOC107985309', other_designations='', map_location='19p13.12', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=13988357, end_position_on_the_genomic_accession=13999659, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107985555 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985555, CurrentID=0, Status='live', Symbol='LOC107985555', Aliases=[], description='coiled-coil domain-containing protein 188-like', other_designations='coiled-coil domain-containing protein 188-like|uncharacterized protein LOC107985555', map_location='22q11.23', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=23392982, end_position_on_the_genomic_accession=23394813, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    107985556 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985556, CurrentID=0, Status='live', Symbol='LOC107985556', Aliases=[], description='vegetative cell wall protein gp1-like', other_designations='vegetative cell wall protein gp1-like', map_location='22q13.33', chromosome='22', genomic_nucleotide_accession_version='NC_000022.11', start_position_on_the_genomic_accession=50432336, end_position_on_the_genomic_accession=50434959, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107985678 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985678, CurrentID=0, Status='live', Symbol='LOC107985678', Aliases=[], description='uncharacterized LOC107985678', other_designations='uncharacterized protein LOC107985678', map_location='Xp11.4', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=41334304, end_position_on_the_genomic_accession=41337401, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107985729 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985729, CurrentID=0, Status='live', Symbol='LOC107985729', Aliases=[], description='uncharacterized LOC107985729', other_designations='uncharacterized protein LOC107985729', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=1433233, end_position_on_the_genomic_accession=1435626, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107985773 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985773, CurrentID=0, Status='live', Symbol='LOC107985773', Aliases=[], description='uncharacterized LOC107985773', other_designations='uncharacterized protein LOC107985773', map_location='2q13', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=109343976, end_position_on_the_genomic_accession=109346956, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107985795 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985795, CurrentID=0, Status='live', Symbol='LOC107985795', Aliases=[], description='uncharacterized LOC107985795', other_designations='uncharacterized protein LOC107985795', map_location='2p16.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=56183193, end_position_on_the_genomic_accession=56184133, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107985805 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985805, CurrentID=0, Status='live', Symbol='LOC107985805', Aliases=[], description='sine oculis-binding protein homolog', other_designations='sine oculis-binding protein homolog', map_location='2q31.1', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=176104637, end_position_on_the_genomic_accession=176107184, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107985876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107985876, CurrentID=0, Status='live', Symbol='LOC107985876', Aliases=[], description='uncharacterized LOC107985876', other_designations='uncharacterized protein LOC107985876', map_location='2p21', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=43064036, end_position_on_the_genomic_accession=43069656, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107986096 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986096, CurrentID=0, Status='live', Symbol='MDFIC2', Aliases=[], description='MyoD family inhibitor domain containing 2', other_designations='myoD family inhibitor domain-containing protein 2', map_location='3p13', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=70194479, end_position_on_the_genomic_accession=70312638, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    107986217 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986217, CurrentID=0, Status='live', Symbol='LOC107986217', Aliases=[], description='DNA-directed RNA polymerase II subunit 1-like', other_designations='DNA-directed RNA polymerase II subunit 1-like', map_location='4q35.1', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=183333033, end_position_on_the_genomic_accession=183337620, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107986675 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986675, CurrentID=0, Status='live', Symbol='LOC107986675', Aliases=[], description='uncharacterized LOC107986675', other_designations='', map_location='6q27', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=169959500, end_position_on_the_genomic_accession=169982736, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107986755 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986755, CurrentID=0, Status='live', Symbol='LOC107986755', Aliases=[], description='uncharacterized LOC107986755', other_designations='uncharacterized protein LOC107986755', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=1059928, end_position_on_the_genomic_accession=1073681, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    107986762 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986762, CurrentID=0, Status='live', Symbol='LOC107986762', Aliases=[], description='uncharacterized LOC107986762', other_designations='uncharacterized protein LOC107986762', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=5606232, end_position_on_the_genomic_accession=5619235, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    107986800 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986800, CurrentID=0, Status='live', Symbol='LOC107986800', Aliases=[], description='putative uncharacterized protein FLJ44672', other_designations='putative uncharacterized protein FLJ44672|uncharacterized protein LOC107986800', map_location='7p11.2', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=56375684, end_position_on_the_genomic_accession=56380828, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    107986818 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986818, CurrentID=0, Status='live', Symbol='FAM237B', Aliases=[], description='family with sequence similarity 237 member B', other_designations='protein FAM237B', map_location='7q21.13', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=90316807, end_position_on_the_genomic_accession=90321304, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107986860 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986860, CurrentID=0, Status='live', Symbol='LOC107986860', Aliases=[], description='endogenous retrovirus group K member 19 Env polyprotein-like', other_designations='endogenous retrovirus group K member 19 Env polyprotein-like', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=150549060, end_position_on_the_genomic_accession=150564075, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107986982 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107986982, CurrentID=0, Status='live', Symbol='LOC107986982', Aliases=[], description='MAGE-like protein 2', other_designations='MAGE-like protein 2', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=140620807, end_position_on_the_genomic_accession=140625255, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107987004 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987004, CurrentID=0, Status='live', Symbol='LOC107987004', Aliases=[], description='coiled-coil domain-containing protein 86-like', other_designations='coiled-coil domain-containing protein 86-like', map_location='9q13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=63044412, end_position_on_the_genomic_accession=63046084, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107987020 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987020, CurrentID=0, Status='live', Symbol='LOC107987020', Aliases=[], description='uncharacterized LOC107987020', other_designations='', map_location='9q13', chromosome='9', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987042 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987042, CurrentID=0, Status='live', Symbol='LOC107987042', Aliases=[], description='phosphatidylinositol 4,5-bisphosphate 5-phosphatase A-like', other_designations='phosphatidylinositol 4,5-bisphosphate 5-phosphatase A-like', map_location='9p24.3', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=706948, end_position_on_the_genomic_accession=709615, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107987044 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987044, CurrentID=0, Status='live', Symbol='LOC107987044', Aliases=[], description='uncharacterized LOC107987044', other_designations='uncharacterized protein LOC107987044', map_location='9p24.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=5113419, end_position_on_the_genomic_accession=5115001, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107987067 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987067, CurrentID=0, Status='live', Symbol='LOC107987067', Aliases=[], description='formin-2-like', other_designations='formin-2-like', map_location='9q13', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=64719881, end_position_on_the_genomic_accession=64721240, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107987125 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987125, CurrentID=0, Status='live', Symbol='LOC107987125', Aliases=[], description='uncharacterized LOC107987125', other_designations='uncharacterized protein LOC107987125', map_location='9q33.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=121810573, end_position_on_the_genomic_accession=121815588, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107987155 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987155, CurrentID=0, Status='live', Symbol='OOSP4B', Aliases=[], description='oocyte secreted protein family member 4B', other_designations='oocyte-secreted protein 4B', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=60023803, end_position_on_the_genomic_accession=60031095, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    107987158 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987158, CurrentID=0, Status='live', Symbol='LOC107987158', Aliases=[], description='uncharacterized LOC107987158', other_designations='uncharacterized protein LOC107987158', map_location='11p15.4', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=3142104, end_position_on_the_genomic_accession=3150002, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107987211 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987211, CurrentID=0, Status='live', Symbol='LOC107987211', Aliases=[], description='uncharacterized LOC107987211', other_designations='uncharacterized protein LOC107987211', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=105728132, end_position_on_the_genomic_accession=105733257, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107987235 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987235, CurrentID=0, Status='live', Symbol='LOC107987235', Aliases=[], description='putative uncharacterized protein MGC34800', other_designations='putative uncharacterized protein MGC34800', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=34388895, end_position_on_the_genomic_accession=34389821, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107987236 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987236, CurrentID=0, Status='live', Symbol='LOC107987236', Aliases=[], description='sal-like protein 3', other_designations='sal-like protein 3', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=34385075, end_position_on_the_genomic_accession=34388569, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107987238 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987238, CurrentID=0, Status='live', Symbol='LOC107987238', Aliases=[], description='proline-rich proteoglycan 2-like', other_designations='proline-rich proteoglycan 2-like', map_location='16q24.3', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=88823266, end_position_on_the_genomic_accession=88824779, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107987243 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987243, CurrentID=0, Status='live', Symbol='LOC107987243', Aliases=[], description='uncharacterized LOC107987243', other_designations='uncharacterized protein LOC107987243', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=44987589, end_position_on_the_genomic_accession=45022392, orientation='minus', exon_count=7, OMIM=[], no_hdr0=''),
    107987248 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987248, CurrentID=0, Status='live', Symbol='LOC107987248', Aliases=[], description='intercellular adhesion molecule 1-like', other_designations='intercellular adhesion molecule 1-like', map_location='17q23.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=63885851, end_position_on_the_genomic_accession=63886703, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    107987254 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987254, CurrentID=0, Status='live', Symbol='LOC107987254', Aliases=[], description='uncharacterized protein FAM215A-like', other_designations='uncharacterized protein FAM215A-like', map_location='17q21.31', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=46341589, end_position_on_the_genomic_accession=46343761, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    107987269 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987269, CurrentID=0, Status='live', Symbol='LOC107987269', Aliases=[], description='uncharacterized LOC107987269', other_designations='uncharacterized protein LOC107987269', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46716530, end_position_on_the_genomic_accession=46719412, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    107987285 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987285, CurrentID=0, Status='live', Symbol='LOC107987285', Aliases=[], description='uncharacterized LOC107987285', other_designations='uncharacterized protein LOC107987285', map_location='20q13.33', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=62714046, end_position_on_the_genomic_accession=62718207, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    107987288 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987288, CurrentID=0, Status='live', Symbol='LOC107987288', Aliases=[], description='uncharacterized LOC107987288', other_designations='uncharacterized protein LOC107987288', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6134475, end_position_on_the_genomic_accession=6135752, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107987289 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987289, CurrentID=0, Status='live', Symbol='LOC107987289', Aliases=[], description='helicase SRCAP-like', other_designations='helicase SRCAP-like', map_location='21p12', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=6135285, end_position_on_the_genomic_accession=6142051, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    107987372 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987372, CurrentID=0, Status='live', Symbol='LOC107987372', Aliases=[], description='uncharacterized LOC107987372', other_designations='uncharacterized protein LOC107987372', map_location='', chromosome='9', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987373 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987373, CurrentID=0, Status='live', Symbol='LOC107987373', Aliases=[], description='39S ribosomal protein L23, mitochondrial', other_designations='39S ribosomal protein L23, mitochondrial', map_location='', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987423 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987423, CurrentID=0, Status='live', Symbol='LOC107987423', Aliases=[], description='liver carboxylesterase 1-like', other_designations='liver carboxylesterase 1-like', map_location='', chromosome='16', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987425 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987425, CurrentID=0, Status='live', Symbol='LOC107987425', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987432, CurrentID=0, Status='live', Symbol='LOC107987432', Aliases=[], description='putative POM121-like protein 1-like', other_designations='putative POM121-like protein 1-like', map_location='', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987433 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987433, CurrentID=0, Status='live', Symbol='LOC107987433', Aliases=[], description='putative POM121-like protein 1-like', other_designations='putative POM121-like protein 1-like', map_location='', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987441 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987441, CurrentID=0, Status='live', Symbol='LOC107987441', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987457 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987457, CurrentID=0, Status='live', Symbol='LOC107987457', Aliases=[], description='phostensin-like', other_designations='phostensin-like', map_location='', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987462, CurrentID=0, Status='live', Symbol='LOC107987462', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987464 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987464, CurrentID=0, Status='live', Symbol='LOC107987464', Aliases=[], description='uncharacterized LOC107987464', other_designations='uncharacterized protein LOC107987464', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987477 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987477, CurrentID=0, Status='live', Symbol='LOC107987477', Aliases=[], description='uncharacterized LOC107987477', other_designations='uncharacterized protein LOC107987477', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987478 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987478, CurrentID=0, Status='live', Symbol='LOC107987478', Aliases=[], description='cytochrome P450 2D6-like', other_designations='cytochrome P450 2D6-like', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987479 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987479, CurrentID=0, Status='live', Symbol='LOC107987479', Aliases=['CYP2D6'], description='cytochrome P450 2D6', other_designations='cytochrome P450 2D6|cytochrome P4502D6', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    107987545 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=107987545, CurrentID=0, Status='live', Symbol='LOC107987545', Aliases=[], description='olfactory receptor 2A7', other_designations='olfactory receptor 2A7', map_location='', chromosome='7', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    109504726 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=109504726, CurrentID=0, Status='live', Symbol='ERV3-1-ZNF117', Aliases=['h-PLK'], description='ERV3-1-ZNF117 readthrough', other_designations='zinc finger protein 117|provirus-linked krueppel|zinc finger protein HPF9', map_location='7q11.21', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=64971776, end_position_on_the_genomic_accession=65006746, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    109703458 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=109703458, CurrentID=0, Status='live', Symbol='HTD2', Aliases=[], description='hydroxyacyl-thioester dehydratase type 2', other_designations='hydroxyacyl-thioester dehydratase type 2, mitochondrial|3-hydroxyacyl-[acyl-carrier-protein] dehydratase', map_location='3p14.3', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=58306245, end_position_on_the_genomic_accession=58320193, orientation='plus', exon_count=7, OMIM=[], no_hdr0=''),
    109729126 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=109729126, CurrentID=0, Status='live', Symbol='FAM236C', Aliases=['FAM236D'], description='family with sequence similarity 236 member C', other_designations='protein FAM236C', map_location='Xq13.1', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=72912006, end_position_on_the_genomic_accession=72913401, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    110091775 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110091775, CurrentID=0, Status='live', Symbol='CFAP298-TCP10L', Aliases=['C21orf59-TCP10L', 'C21orf77', 'LINC00846'], description='CFAP298-TCP10L readthrough', other_designations='uncharacterized protein LOC110091775|C21orf59-TCP10L readthrough|long intergenic non-protein coding RNA 846', map_location='21q22.11', chromosome='21', genomic_nucleotide_accession_version='NC_000021.9', start_position_on_the_genomic_accession=32563492, end_position_on_the_genomic_accession=32612377, orientation='minus', exon_count=12, OMIM=[], no_hdr0=''),
    110116772 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110116772, CurrentID=0, Status='live', Symbol='ZNF765-ZNF761', Aliases=[], description='ZNF765-ZNF761 readthrough', other_designations='zinc finger protein 761', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=53395149, end_position_on_the_genomic_accession=53458261, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    110117498 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110117498, CurrentID=0, Status='live', Symbol='P3R3URF', Aliases=[], description='PIK3R3 upstream open reading frame', other_designations='PIK3R3 upstream open reading frame protein|PIK3R3 upstream reading frame', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46175486, end_position_on_the_genomic_accession=46176488, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    110117499 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110117499, CurrentID=0, Status='live', Symbol='P3R3URF-PIK3R3', Aliases=['LOC110117498-PIK3R3'], description='P3R3URF-PIK3R3 readthrough', other_designations='LOC110117498-PIK3R3 readthrough', map_location='1p34.1', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=46040140, end_position_on_the_genomic_accession=46176488, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    110354863 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110354863, CurrentID=0, Status='live', Symbol='ZNF660-ZNF197', Aliases=[], description='ZNF660-ZNF197 readthrough', other_designations='zinc finger protein 197|pVHL-associated KRAB domain-containing protein|zinc finger protein with KRAB and SCAN domains 9', map_location='3p21.31', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=44584964, end_position_on_the_genomic_accession=44648471, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    110384692 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110384692, CurrentID=0, Status='live', Symbol='LOC110384692', Aliases=[], description='complement C4A (Rodgers blood group)-like', other_designations='complement C4A (Rodgers blood group)-like', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    110599563 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110599563, CurrentID=0, Status='live', Symbol='LY6G6F-LY6G6D', Aliases=['G6F-LY6G6D', 'MEGT-1', 'MEGT1'], description='LY6G6F-LY6G6D readthrough', other_designations='LY6G6F-LY6G6D protein|megakaryocyte-enhanced gene transcript 1 protein', map_location='6p21.33', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=31706866, end_position_on_the_genomic_accession=31717919, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    110599564 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110599564, CurrentID=0, Status='live', Symbol='EEF1AKMT4', Aliases=[], description='EEF1A lysine methyltransferase 4', other_designations='EEF1A lysine methyltransferase 4|eukaryotic translation elongation factor 1 alpha lysine specific methyltransferase 4', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184249672, end_position_on_the_genomic_accession=184258759, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    110599583 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110599583, CurrentID=0, Status='live', Symbol='EEF1AKMT4-ECE2', Aliases=['ECE-2', 'ECE2'], description='EEF1AKMT4-ECE2 readthrough', other_designations='EEF1AKMT4-ECE2 readthrough transcript protein|Endothelin-converting enzyme 2', map_location='3q27.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=184249672, end_position_on_the_genomic_accession=184293031, orientation='plus', exon_count=19, OMIM=[], no_hdr0=''),
    110599588 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110599588, CurrentID=0, Status='live', Symbol='ASDURF', Aliases=['ASNSD1', 'ASNSD1-SEP', 'NS3TP1'], description='ASNSD1 upstream open reading frame', other_designations='ASNSD1 upstream open reading frame protein|ASNSD1 upstream reading frame|Asparagine synthetase domain-containing protein 1|HCV NS3-transactivated protein 1|alternative protein ASNSD1', map_location='2q32.2', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=189661459, end_position_on_the_genomic_accession=189666401, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    110806277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806277, CurrentID=0, Status='live', Symbol='PNMA8C', Aliases=[], description='PNMA family member 8C', other_designations='paraneoplastic antigen-like protein 8C|paraneoplastic Ma antigen family member 8C', map_location='19q13.32', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=46424697, end_position_on_the_genomic_accession=46428936, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    110806278 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806278, CurrentID=0, Status='live', Symbol='SPRR5', Aliases=[], description='small proline rich protein 5', other_designations='putative small proline-rich protein 5', map_location='1q21.3', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    110806279 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806279, CurrentID=0, Status='live', Symbol='SMIM28', Aliases=[], description='small integral membrane protein 28', other_designations='small integral membrane protein 28', map_location='6q24.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=138377905, end_position_on_the_genomic_accession=138383486, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    110806280 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806280, CurrentID=0, Status='live', Symbol='CCDC194', Aliases=[], description='coiled-coil domain containing 194', other_designations='coiled-coil domain-containing protein 194', map_location='19p13.11', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=17389069, end_position_on_the_genomic_accession=17394593, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    110806281 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806281, CurrentID=0, Status='live', Symbol='CCDC195', Aliases=[], description='coiled-coil domain containing 195', other_designations='putative coiled-coil domain-containing protein 195', map_location='2q36.2', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    110806290 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806290, CurrentID=0, Status='live', Symbol='MYOCOS', Aliases=[], description='myocilin opposite strand', other_designations='myocilin opposite strand protein', map_location='1q24.3', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=171619763, end_position_on_the_genomic_accession=171626888, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    110806296 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806296, CurrentID=0, Status='live', Symbol='C1orf232', Aliases=[], description='chromosome 1 open reading frame 230', other_designations='uncharacterized protein C1orf232', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=26164101, end_position_on_the_genomic_accession=26168963, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    110806297 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806297, CurrentID=0, Status='live', Symbol='FAM240B', Aliases=[], description='family with sequence similarity 240 member B', other_designations='protein FAM240B', map_location='9p13.1', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=38694266, end_position_on_the_genomic_accession=38720133, orientation='minus', exon_count=4, OMIM=[], no_hdr0=''),
    110806298 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806298, CurrentID=0, Status='live', Symbol='C17orf113', Aliases=[], description='chromosome 17 open reading frame 113', other_designations='transmembrane protein C17orf113', map_location='17q21.2', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=42038232, end_position_on_the_genomic_accession=42050601, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    110806299 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=110806299, CurrentID=0, Status='live', Symbol='ETDC', Aliases=[], description='embryonic testis differentiation homolog C', other_designations='embryonic testis differentiation protein homolog C', map_location='Xq26.3', chromosome='X', genomic_nucleotide_accession_version='NC_000023.11', start_position_on_the_genomic_accession=135309480, end_position_on_the_genomic_accession=135309659, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    111064647 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111064647, CurrentID=0, Status='live', Symbol='CSNKA2IP', Aliases=[], description="casein kinase 2 subunit alpha' interacting protein", other_designations="casein kinase II subunit alpha'-interacting protein|casein kinase 2 alpha prime interacting protein", map_location='3p11.1', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=88338456, end_position_on_the_genomic_accession=88467594, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    111064649 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111064649, CurrentID=0, Status='live', Symbol='SMIM33', Aliases=[], description='small integral membrane protein 33', other_designations='small integral membrane protein 33', map_location='5q31.2', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=139471004, end_position_on_the_genomic_accession=139473700, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    111064650 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111064650, CurrentID=0, Status='live', Symbol='C19orf85', Aliases=[], description='chromosome 19 open reading frame 85', other_designations='uncharacterized protein C19orf85', map_location='19q13.42', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=55463001, end_position_on_the_genomic_accession=55464751, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    111089941 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111089941, CurrentID=0, Status='live', Symbol='MMP24-AS1-EDEM2', Aliases=[], description='MMP24-AS1-EDEM2 readthrough', other_designations='ER degradation-enhancing alpha-mannosidase-like protein 2', map_location='20q11.22', chromosome='20', genomic_nucleotide_accession_version='NC_000020.11', start_position_on_the_genomic_accession=35115364, end_position_on_the_genomic_accession=35278122, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    111188157 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111188157, CurrentID=0, Status='live', Symbol='LYNX1-SLURP2', Aliases=[], description='LYNX1-SLURP2 readthrough', other_designations='LYNX1-SLURP2 protein', map_location='8q24.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=142764338, end_position_on_the_genomic_accession=142777872, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    111216276 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111216276, CurrentID=0, Status='live', Symbol='PMIS2', Aliases=['IFITMD9'], description='PMIS2 transmembrane protein', other_designations='transmembrane protein PMIS2', map_location='19q13.12', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    111216277 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111216277, CurrentID=0, Status='live', Symbol='TEX54', Aliases=[], description='testis expressed 54', other_designations='testis-expressed protein 54', map_location='11q12.3', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    111240474 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111240474, CurrentID=0, Status='live', Symbol='CRYZL2P-SEC16B', Aliases=[], description='CRYZL2P-SEC16B readthrough', other_designations='protein transport protein Sec16B|SEC16 homolog B|leucine zipper transcription regulator 2|regucalcin gene promoter region-related protein p117', map_location='1q25.2', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=177928788, end_position_on_the_genomic_accession=178037976, orientation='minus', exon_count=38, OMIM=[], no_hdr0=''),
    111644133 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=111644133, CurrentID=0, Status='live', Symbol='THSD8', Aliases=[], description='thrombospondin type 1 domain containing 8', other_designations='thrombospondin type-1 domain-containing protein 8', map_location='19p13.13', chromosome='19', genomic_nucleotide_accession_version='NC_000019.10', start_position_on_the_genomic_accession=12802069, end_position_on_the_genomic_accession=12804389, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    112163659 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112163659, CurrentID=0, Status='live', Symbol='TMDD1', Aliases=['C12orf81', 'hCG1648055'], description='transmembrane and death domain 1', other_designations='transmembrane and death domain protein 1|Uncharacterized protein C12orf81', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=51813921, end_position_on_the_genomic_accession=51814925, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    112267855 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267855, CurrentID=0, Status='live', Symbol='LOC112267855', Aliases=[], description='uncharacterized LOC112267855', other_designations='uncharacterized protein LOC112267855', map_location='5q31.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=140574982, end_position_on_the_genomic_accession=140595106, orientation='minus', exon_count=10, OMIM=[], no_hdr0=''),
    112267859 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267859, CurrentID=0, Status='live', Symbol='LOC112267859', Aliases=[], description='putative aquaporin-7-like protein 3', other_designations='putative aquaporin-7-like protein 3', map_location='9q21.11', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=65882227, end_position_on_the_genomic_accession=65896610, orientation='plus', exon_count=8, OMIM=[], no_hdr0=''),
    112267876 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267876, CurrentID=0, Status='live', Symbol='LOC112267876', Aliases=[], description='H19 opposite tumor suppressor-like', other_designations='uncharacterized protein LOC112267876', map_location='', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112267881 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267881, CurrentID=0, Status='live', Symbol='LOC112267881', Aliases=[], description='killer cell immunoglobulin-like receptor 2DL1-like', other_designations='killer cell immunoglobulin-like receptor 2DL1-like|killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 1-like|truncated killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 1 variant A|truncated killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 1 variant AB|truncated killer cell immunoglobulin-like receptor two domains long cytoplasmic tail 1 variant B', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112267897 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267897, CurrentID=0, Status='live', Symbol='LOC112267897', Aliases=[], description='keratin-associated protein 21-1-like', other_designations='keratin-associated protein 6-2-like', map_location='13q21.31', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=63746102, end_position_on_the_genomic_accession=63747788, orientation='plus', exon_count=1, OMIM=[], no_hdr0=''),
    112267904 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267904, CurrentID=0, Status='live', Symbol='LOC112267904', Aliases=[], description='uncharacterized LOC112267904', other_designations='uncharacterized protein LOC112267904', map_location='11q22.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=107591419, end_position_on_the_genomic_accession=107598561, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    112267968 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267968, CurrentID=0, Status='live', Symbol='LOC112267968', Aliases=[], description='uncharacterized LOC112267968', other_designations='uncharacterized protein LOC112267968', map_location='6q25.3', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=159058596, end_position_on_the_genomic_accession=159121478, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    112267992 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112267992, CurrentID=0, Status='live', Symbol='LOC112267992', Aliases=[], description='uncharacterized LOC112267992', other_designations='uncharacterized protein LOC112267992', map_location='7p22.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=6950450, end_position_on_the_genomic_accession=6959989, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    112268015 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268015, CurrentID=0, Status='live', Symbol='LOC112268015', Aliases=[], description='uncharacterized LOC112268015', other_designations='', map_location='8q21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=89616937, end_position_on_the_genomic_accession=89629195, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    112268052 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268052, CurrentID=0, Status='live', Symbol='LOC112268052', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC112268052', map_location='9q31.2', chromosome='9', genomic_nucleotide_accession_version='NC_000009.12', start_position_on_the_genomic_accession=107281852, end_position_on_the_genomic_accession=107283631, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    112268076 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268076, CurrentID=0, Status='live', Symbol='LOC112268076', Aliases=[], description='uncharacterized LOC112268076', other_designations='uncharacterized protein LOC112268076', map_location='11q13.2', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=67922035, end_position_on_the_genomic_accession=67956964, orientation='minus', exon_count=6, OMIM=[], no_hdr0=''),
    112268080 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268080, CurrentID=0, Status='live', Symbol='LOC112268080', Aliases=[], description='6.8 kDa mitochondrial proteolipid-like', other_designations='6.8 kDa mitochondrial proteolipid-like', map_location='11q21', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=93219734, end_position_on_the_genomic_accession=93222540, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    112268092 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268092, CurrentID=0, Status='live', Symbol='LOC112268092', Aliases=[], description='uncharacterized LOC112268092', other_designations='uncharacterized protein LOC112268092', map_location='12p12.3', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=19301533, end_position_on_the_genomic_accession=19308069, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    112268102 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268102, CurrentID=0, Status='live', Symbol='LOC112268102', Aliases=[], description='uncharacterized LOC112268102', other_designations='', map_location='12q24.33', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=132440997, end_position_on_the_genomic_accession=132442893, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    112268119 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268119, CurrentID=0, Status='live', Symbol='LOC112268119', Aliases=[], description='protein SPT2 homolog', other_designations='protein SPT2 homolog', map_location='13q14.11', chromosome='13', genomic_nucleotide_accession_version='NC_000013.11', start_position_on_the_genomic_accession=39601324, end_position_on_the_genomic_accession=39609018, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    112268131 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268131, CurrentID=0, Status='live', Symbol='LOC112268131', Aliases=[], description='uncharacterized LOC112268131', other_designations='uncharacterized protein LOC112268131', map_location='14q32.33', chromosome='14', genomic_nucleotide_accession_version='NC_000014.9', start_position_on_the_genomic_accession=103701816, end_position_on_the_genomic_accession=103710499, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    112268145 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268145, CurrentID=0, Status='live', Symbol='LOC112268145', Aliases=[], description='uncharacterized LOC112268145', other_designations='uncharacterized protein LOC112268145', map_location='15q24.1', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=72637078, end_position_on_the_genomic_accession=72649543, orientation='plus', exon_count=9, OMIM=[], no_hdr0=''),
    112268168 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268168, CurrentID=0, Status='live', Symbol='LOC112268168', Aliases=[], description='putative uncharacterized protein encoded by LINC00269', other_designations='putative uncharacterized protein encoded by LINC00269', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=66713664, end_position_on_the_genomic_accession=66714505, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    112268186 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268186, CurrentID=0, Status='live', Symbol='LOC112268186', Aliases=[], description='basic proline-rich protein-like', other_designations='basic proline-rich protein-like', map_location='17q25.3', chromosome='17', genomic_nucleotide_accession_version='NC_000017.11', start_position_on_the_genomic_accession=81344888, end_position_on_the_genomic_accession=81346462, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    112268260 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268260, CurrentID=0, Status='live', Symbol='LOC112268260', Aliases=[], description='uncharacterized LOC112268260', other_designations='uncharacterized protein LOC112268260', map_location='1p36.33', chromosome='1', genomic_nucleotide_accession_version='NC_000001.11', start_position_on_the_genomic_accession=350706, end_position_on_the_genomic_accession=476822, orientation='minus', exon_count=16, OMIM=[], no_hdr0=''),
    112268320 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268320, CurrentID=0, Status='live', Symbol='LOC112268320', Aliases=[], description='PRAME family member 3', other_designations='PRAME family member 3', map_location='', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268334 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268334, CurrentID=0, Status='live', Symbol='LOC112268334', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268336 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268336, CurrentID=0, Status='live', Symbol='LOC112268336', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268337 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268337, CurrentID=0, Status='live', Symbol='LOC112268337', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268340 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268340, CurrentID=0, Status='live', Symbol='LOC112268340', Aliases=[], description='leukocyte immunoglobulin-like receptor subfamily B member 3', other_designations='leukocyte immunoglobulin-like receptor subfamily B member 3', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268342 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268342, CurrentID=0, Status='live', Symbol='LOC112268342', Aliases=[], description='uncharacterized LOC112268342', other_designations='uncharacterized protein LOC112268342', map_location='', chromosome='22', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268347 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268347, CurrentID=0, Status='live', Symbol='LOC112268347', Aliases=[], description='putative POM121-like protein 1-like', other_designations='putative POM121-like protein 1-like', map_location='', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268350 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268350, CurrentID=0, Status='live', Symbol='LOC112268350', Aliases=[], description='uncharacterized LOC112268350', other_designations='uncharacterized protein LOC112268350', map_location='', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268354 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268354, CurrentID=0, Status='live', Symbol='LOC112268354', Aliases=[], description='killer cell immunoglobulin-like receptor 2DL4-like', other_designations='killer cell immunoglobulin-like receptor 2DL4-like', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268355 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268355, CurrentID=0, Status='live', Symbol='LOC112268355', Aliases=[], description='killer cell immunoglobulin-like receptor 3DS1-like', other_designations='killer cell immunoglobulin-like receptor 3DS1-like', map_location='', chromosome='19', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268384 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268384, CurrentID=0, Status='live', Symbol='LOC112268384', Aliases=[], description='olfactory receptor 2A1/2A42-like', other_designations='olfactory receptor 2A1/2A42-like', map_location='', chromosome='7', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268387 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268387, CurrentID=0, Status='live', Symbol='LOC112268387', Aliases=[], description='putative protein FAM90A16P/FAM90A17P', other_designations='putative protein FAM90A16P/FAM90A17P', map_location='', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268390 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268390, CurrentID=0, Status='live', Symbol='LOC112268390', Aliases=[], description='putative protein FAM90A12P', other_designations='putative protein FAM90A12P', map_location='', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268395 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268395, CurrentID=0, Status='live', Symbol='LOC112268395', Aliases=[], description='putative protein FAM90A15P', other_designations='putative protein FAM90A15P', map_location='', chromosome='8', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112268437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268437, CurrentID=0, Status='live', Symbol='LOC112268437', Aliases=['AAK1'], description='uncharacterized protein FLJ45252', other_designations='uncharacterized protein FLJ45252|alternative protein AAK1', map_location='2p13.3', chromosome='2', genomic_nucleotide_accession_version='NC_000002.12', start_position_on_the_genomic_accession=69463825, end_position_on_the_genomic_accession=69468704, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    112268444 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112268444, CurrentID=0, Status='live', Symbol='LOC112268444', Aliases=[], description='translation initiation factor IF-2-like', other_designations='uncharacterized protein LOC112268444', map_location='3p22.2', chromosome='3', genomic_nucleotide_accession_version='NC_000003.12', start_position_on_the_genomic_accession=37175864, end_position_on_the_genomic_accession=37199669, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    112441426 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441426, CurrentID=0, Status='live', Symbol='TMEM271', Aliases=[], description='transmembrane protein 271', other_designations='transmembrane protein 271', map_location='4p16.3', chromosome='4', genomic_nucleotide_accession_version='NC_000004.12', start_position_on_the_genomic_accession=573880, end_position_on_the_genomic_accession=576295, orientation='minus', exon_count=1, OMIM=[], no_hdr0=''),
    112441428 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441428, CurrentID=0, Status='live', Symbol='SCYGR1', Aliases=['KRTAP28-1'], description='small cysteine and glycine repeat containing 1', other_designations='small cysteine and glycine repeat-containing protein 1|keratin associated protein 28-1', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441429 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441429, CurrentID=0, Status='live', Symbol='SCYGR3', Aliases=['KRTAP28-3'], description='small cysteine and glycine repeat containing 3', other_designations='small cysteine and glycine repeat-containing protein 3|keratin associated protein 28-3', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441430 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441430, CurrentID=0, Status='live', Symbol='SCYGR4', Aliases=['KRTAP28-4'], description='small cysteine and glycine repeat containing 4', other_designations='small cysteine and glycine repeat-containing protein 4|keratin associated protein 28-4', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441431 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441431, CurrentID=0, Status='live', Symbol='SCYGR6', Aliases=['KRTAP28-6'], description='small cysteine and glycine repeat containing 6', other_designations='small cysteine and glycine repeat-containing protein 6|keratin associated protein 28-6', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441432 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441432, CurrentID=0, Status='live', Symbol='SCYGR8', Aliases=['KRTAP28-8'], description='small cysteine and glycine repeat containing 8', other_designations='small cysteine and glycine repeat-containing protein 8|keratin associated protein 28-8', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441434 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441434, CurrentID=0, Status='live', Symbol='SHLD3', Aliases=['CTC-534A2.2', 'RINN1'], description='shieldin complex subunit 3', other_designations='shieldin complex subunit 3|REV7-interacting novel NHEJ regulator 1|shield complex subunit 3', map_location='5q12.3', chromosome='5', genomic_nucleotide_accession_version='NC_000005.10', start_position_on_the_genomic_accession=65625027, end_position_on_the_genomic_accession=65630928, orientation='plus', exon_count=2, OMIM=[618030], no_hdr0=''),
    112441435 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441435, CurrentID=0, Status='live', Symbol='SCYGR2', Aliases=['KRTAP28-2'], description='small cysteine and glycine repeat containing 2', other_designations='small cysteine and glycine repeat-containing protein 2|keratin associated protein 28-2', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441437 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441437, CurrentID=0, Status='live', Symbol='SCYGR5', Aliases=['KRTAP28-5'], description='small cysteine and glycine repeat containing 5', other_designations='small cysteine and glycine repeat-containing protein 5|keratin associated protein 28-5', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112441438 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112441438, CurrentID=0, Status='live', Symbol='SCYGR7', Aliases=['KRTAP28-7'], description='small cysteine and glycine repeat containing 7', other_designations='small cysteine and glycine repeat-containing protein 7|keratin associated protein 28-7', map_location='2q36.3', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112577461 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112577461, CurrentID=0, Status='live', Symbol='OOSP3', Aliases=[], description='oocyte secreted protein family member 3', other_designations='oocyte-secreted protein 3', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=59880267, end_position_on_the_genomic_accession=59930197, orientation='plus', exon_count=5, OMIM=[], no_hdr0=''),
    112577462 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112577462, CurrentID=0, Status='live', Symbol='OOSP4A', Aliases=[], description='oocyte secreted protein family member 4A', other_designations='oocyte-secreted protein 4A', map_location='11q12.1', chromosome='11', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    112577516 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112577516, CurrentID=0, Status='live', Symbol='LOC112577516', Aliases=[], description='carbohydrate-binding protein AQN-1-like', other_designations='carbohydrate-binding protein AQN-1-like', map_location='10q26.13', chromosome='10', genomic_nucleotide_accession_version='NC_000010.11', start_position_on_the_genomic_accession=122672850, end_position_on_the_genomic_accession=122679494, orientation='plus', exon_count=4, OMIM=[], no_hdr0=''),
    112577592 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112577592, CurrentID=0, Status='live', Symbol='LOC112577592', Aliases=[], description='uncharacterized LOC112577592', other_designations='uncharacterized LOC112577592', map_location='18p11.23', chromosome='18', genomic_nucleotide_accession_version='NC_000018.10', start_position_on_the_genomic_accession=7455999, end_position_on_the_genomic_accession=7461006, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    112694756 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=112694756, CurrentID=0, Status='live', Symbol='LOC112694756', Aliases=['ALDA', 'ALDOA'], description='uncharaterized LOC112694756', other_designations='uncharaterized LOC112694756|Fructose-bisphosphate aldolase A|Lung cancer antigen NY-LU-1|Muscle-type aldolase', map_location='16p11.2', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=30053151, end_position_on_the_genomic_accession=30070414, orientation='plus', exon_count=13, OMIM=[], no_hdr0=''),
    113455421 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113455421, CurrentID=0, Status='live', Symbol='DERPC', Aliases=['CHTF8'], description='DERPC proline and glycine rich nuclear protein', other_designations='decreased expression in renal and prostate cancer protein|Protein DERPC|chromosome transmission fidelity protein 8 homolog', map_location='16q22.1', chromosome='16', genomic_nucleotide_accession_version='NC_000016.10', start_position_on_the_genomic_accession=69118010, end_position_on_the_genomic_accession=69132588, orientation='minus', exon_count=5, OMIM=[], no_hdr0=''),
    113523636 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113523636, CurrentID=0, Status='live', Symbol='SMIM40', Aliases=[], description='small integral membrane protein 40', other_designations='small integral membrane protein 40', map_location='6p21.32', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=33323628, end_position_on_the_genomic_accession=33329279, orientation='minus', exon_count=3, OMIM=[], no_hdr0=''),
    113523638 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113523638, CurrentID=0, Status='live', Symbol='SMIM41', Aliases=[], description='small integral membrane protein 41', other_designations='small integral membrane protein 41', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=52079704, end_position_on_the_genomic_accession=52108255, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    113523639 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=113523639, CurrentID=0, Status='live', Symbol='SMIM39', Aliases=[], description='small integral membrane protein 39', other_designations='small integral membrane protein 39', map_location='2q21.1', chromosome='2', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    114108587 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114108587, CurrentID=0, Status='live', Symbol='ATF7-NPFF', Aliases=[], description='ATF7-NPFF readthrough', other_designations='ATF7-NPFF readthrough protein', map_location='12q13.13', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=53506688, end_position_on_the_genomic_accession=53626382, orientation='minus', exon_count=15, OMIM=[], no_hdr0=''),
    114118903 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114118903, CurrentID=0, Status='live', Symbol='ARHGAP11A-SCG5', Aliases=[], description='ARHGAP11A-SCG5 readthrough', other_designations='ARHGAP11A-SCG5 protein', map_location='15q13.3', chromosome='15', genomic_nucleotide_accession_version='NC_000015.10', start_position_on_the_genomic_accession=32615476, end_position_on_the_genomic_accession=32697098, orientation='plus', exon_count=14, OMIM=[], no_hdr0=''),
    114483833 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114483833, CurrentID=0, Status='live', Symbol='H2BE1', Aliases=[], description='H2B.E variant histone 1', other_designations='histone H2B type 2-E1|novel histone H2B-like protein', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151207837, end_position_on_the_genomic_accession=151210488, orientation='minus', exon_count=2, OMIM=[], no_hdr0=''),
    114483834 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114483834, CurrentID=0, Status='live', Symbol='ABCF2-H2BE1', Aliases=[], description='ABCF2-H2BE1 readthrough', other_designations='ABCF2-H2B protein|ABCF2-H2B readthrough', map_location='7q36.1', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=151207837, end_position_on_the_genomic_accession=151227205, orientation='minus', exon_count=17, OMIM=[], no_hdr0=''),
    114515518 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114515518, CurrentID=0, Status='live', Symbol='CCDC201', Aliases=[], description='coiled-coil domain containing 201', other_designations='coiled-coil domain-containing protein 201', map_location='7p12.3', chromosome='7', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    114841035 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114841035, CurrentID=0, Status='live', Symbol='LOC114841035', Aliases=[], description='Uncharacterized protein LOC114841035', other_designations='Uncharacterized protein LOC114841035', map_location='11q13.1', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=64241095, end_position_on_the_genomic_accession=64244132, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    114841037 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=114841037, CurrentID=0, Status='live', Symbol='GUCA1ANB', Aliases=[], description='GUCA1A neighbor', other_designations='putative uncharacterized protein GUCA1ANB', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42155406, end_position_on_the_genomic_accession=42163418, orientation='plus', exon_count=2, OMIM=[], no_hdr0=''),
    115072896 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115072896, CurrentID=0, Status='live', Symbol='SLCO1B3-SLCO1B7', Aliases=['LST-3TM12', 'OATP1B3-1B7'], description='SLCO1B3-SLCO1B7 readthrough', other_designations='SLCO1B3-SLCO1B7', map_location='12p12.2', chromosome='12', genomic_nucleotide_accession_version='NC_000012.12', start_position_on_the_genomic_accession=20815674, end_position_on_the_genomic_accession=21091222, orientation='plus', exon_count=16, OMIM=[], no_hdr0=''),
    115253422 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=115253422, CurrentID=0, Status='live', Symbol='DUS4L-BCAP29', Aliases=[], description='DUS4L-BCAP29 readthrough', other_designations='DUS4L-BCAP29 protein', map_location='7q22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=107563971, end_position_on_the_genomic_accession=107623317, orientation='plus', exon_count=15, OMIM=[], no_hdr0=''),
    116033993 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116033993, CurrentID=0, Status='live', Symbol='FOXL3', Aliases=[], description='forkhead box L3', other_designations='forkhead box L3|forkhead box L1-like', map_location='7p22.3', chromosome='7', genomic_nucleotide_accession_version='NC_000007.14', start_position_on_the_genomic_accession=290170, end_position_on_the_genomic_accession=291488, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    116804918 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=116804918, CurrentID=0, Status='live', Symbol='TBCEL-TECTA', Aliases=[], description='TBCEL-TECTA readthrough', other_designations='Uncharacterized LOC116804918', map_location='11q23.3', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=121024102, end_position_on_the_genomic_accession=121191490, orientation='plus', exon_count=30, OMIM=[], no_hdr0=''),
    117981789 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=117981789, CurrentID=0, Status='live', Symbol='SMIM42', Aliases=[], description='small integral membrane protein 42', other_designations='small integral membrane protein 42', map_location='1q23.1', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    118142757 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118142757, CurrentID=0, Status='live', Symbol='LOC118142757', Aliases=['GUCA1A', 'GUCA1ANB-GUCA1A'], description='GUCA1ANB-GUCA1A readthrough', other_designations='guanylyl cyclase-activating protein 1', map_location='6p21.1', chromosome='6', genomic_nucleotide_accession_version='NC_000006.12', start_position_on_the_genomic_accession=42155406, end_position_on_the_genomic_accession=42180056, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    118568799 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118568799, CurrentID=0, Status='live', Symbol='ZNF593OS', Aliases=[], description='ZNF593 opposite strand', other_designations='putative transmembrane protein ZNF593OS', map_location='1p36.11', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    118568804 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118568804, CurrentID=0, Status='live', Symbol='OR4M2B', Aliases=[], description='olfactory receptor family 4 subfamily M member 2B', other_designations='olfactory receptor 4M2', map_location='15q11.2', chromosome='15', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    118827814 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=118827814, CurrentID=0, Status='live', Symbol='C1orf21-DT', Aliases=[], description='C1orf21 divergent transcript', other_designations='', map_location='1q25.3', chromosome='1', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    119139905 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=119139905, CurrentID=0, Status='live', Symbol='C17orf114', Aliases=[], description='chromosome 17 open reading frame 114', other_designations='uncharacterized protein C17orf114', map_location='17p13.2', chromosome='17', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    120356739 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120356739, CurrentID=0, Status='live', Symbol='LRRC51', Aliases=[], description='leucine rich repeat containing 51', other_designations='leucine-rich repeat-containing protein 51', map_location='', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72080850, end_position_on_the_genomic_accession=72096895, orientation='plus', exon_count=6, OMIM=[], no_hdr0=''),
    120356740 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120356740, CurrentID=0, Status='live', Symbol='TOMT', Aliases=['COMT2'], description='transmembrane O-methyltransferase', other_designations='transmembrane O-methyltransferase', map_location='', chromosome='11', genomic_nucleotide_accession_version='NC_000011.10', start_position_on_the_genomic_accession=72105928, end_position_on_the_genomic_accession=72109596, orientation='plus', exon_count=3, OMIM=[], no_hdr0=''),
    120766137 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=120766137, CurrentID=0, Status='live', Symbol='HRURF', Aliases=['U2HR'], description='HR upstream open reading frame', other_designations='HR upstream open reading frame|HR upstream reading frame', map_location='8p21.3', chromosome='8', genomic_nucleotide_accession_version='NC_000008.11', start_position_on_the_genomic_accession=22130458, end_position_on_the_genomic_accession=22131010, orientation='minus', exon_count=1, OMIM=[619257], no_hdr0=''),
    121232370 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121232370, CurrentID=0, Status='live', Symbol='FAM151B-DT', Aliases=[], description='FAM151B divergent transcript', other_designations='', map_location='5q14.1', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    121232371 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121232371, CurrentID=0, Status='live', Symbol='FAM174A-DT', Aliases=[], description='FAM174A divergent transcript', other_designations='', map_location='5q21.1', chromosome='5', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
    121725057 : ntncbi(tax_id=9606, Org_name='Homo sapiens', GeneID=121725057, CurrentID=0, Status='live', Symbol='LOC121725057', Aliases=[], description='uncharacterized LOC121725057', other_designations='uncharacterized LOC121725057', map_location='6p21.2', chromosome='6', genomic_nucleotide_accession_version='', start_position_on_the_genomic_accession='', end_position_on_the_genomic_accession='', orientation='', exon_count='', OMIM=[], no_hdr0=''),
}
